
#include <pmu-events/pmu-events.h>
#include "util/header.h"
#include "util/pmu.h"
#include <string.h>
#include <stddef.h>

struct compact_pmu_event {
  int offset;
};

static const char *const big_c_string =
/* offset=0 */ "Backend\000"
/* offset=8 */ "BadSpec\000"
/* offset=16 */ "Bad\000"
/* offset=20 */ "BigFoot\000"
/* offset=28 */ "BrMispredicts\000"
/* offset=42 */ "Branches\000"
/* offset=51 */ "CacheMisses\000"
/* offset=63 */ "CodeGen\000"
/* offset=71 */ "Compute\000"
/* offset=79 */ "Cor\000"
/* offset=83 */ "DSB\000"
/* offset=87 */ "DSBmiss\000"
/* offset=95 */ "DataSharing\000"
/* offset=107 */ "Fed\000"
/* offset=111 */ "FetchBW\000"
/* offset=119 */ "FetchLat\000"
/* offset=128 */ "Flops\000"
/* offset=134 */ "FpScalar\000"
/* offset=143 */ "FpVector\000"
/* offset=152 */ "Frontend\000"
/* offset=161 */ "Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000"
/* offset=231 */ "HPC\000"
/* offset=235 */ "IcMiss\000"
/* offset=242 */ "InsType\000"
/* offset=250 */ "IntVector\000"
/* offset=260 */ "IoBW\000"
/* offset=265 */ "L2Evicts\000"
/* offset=274 */ "MachineClears\000"
/* offset=288 */ "Mem\000"
/* offset=292 */ "MemoryBW\000"
/* offset=301 */ "MemoryBound\000"
/* offset=313 */ "MemoryLat\000"
/* offset=323 */ "MemoryTLB\000"
/* offset=333 */ "Memory_BW\000"
/* offset=343 */ "Memory_Lat\000"
/* offset=354 */ "Metrics contributing to tma_alu_op_utilization category\000"
/* offset=410 */ "Metrics contributing to tma_assists category\000"
/* offset=455 */ "Metrics contributing to tma_backend_bound category\000"
/* offset=506 */ "Metrics contributing to tma_backend_bound_aux category\000"
/* offset=561 */ "Metrics contributing to tma_bad_speculation category\000"
/* offset=614 */ "Metrics contributing to tma_base category\000"
/* offset=656 */ "Metrics contributing to tma_branch_resteers category\000"
/* offset=709 */ "Metrics contributing to tma_core_bound category\000"
/* offset=757 */ "Metrics contributing to tma_dram_bound category\000"
/* offset=805 */ "Metrics contributing to tma_dtlb_load category\000"
/* offset=852 */ "Metrics contributing to tma_dtlb_store category\000"
/* offset=900 */ "Metrics contributing to tma_fetch_bandwidth category\000"
/* offset=953 */ "Metrics contributing to tma_fetch_latency category\000"
/* offset=1004 */ "Metrics contributing to tma_fp_arith category\000"
/* offset=1050 */ "Metrics contributing to tma_fp_vector category\000"
/* offset=1097 */ "Metrics contributing to tma_frontend_bound category\000"
/* offset=1149 */ "Metrics contributing to tma_heavy_operations category\000"
/* offset=1203 */ "Metrics contributing to tma_int_operations category\000"
/* offset=1255 */ "Metrics contributing to tma_l1_bound category\000"
/* offset=1301 */ "Metrics contributing to tma_l3_bound category\000"
/* offset=1347 */ "Metrics contributing to tma_light_operations category\000"
/* offset=1401 */ "Metrics contributing to tma_load_op_utilization category\000"
/* offset=1458 */ "Metrics contributing to tma_machine_clears category\000"
/* offset=1510 */ "Metrics contributing to tma_mem_bandwidth category\000"
/* offset=1561 */ "Metrics contributing to tma_mem_latency category\000"
/* offset=1610 */ "Metrics contributing to tma_mem_scheduler category\000"
/* offset=1661 */ "Metrics contributing to tma_memory_bound category\000"
/* offset=1711 */ "Metrics contributing to tma_microcode_sequencer category\000"
/* offset=1768 */ "Metrics contributing to tma_mite category\000"
/* offset=1810 */ "Metrics contributing to tma_nuke category\000"
/* offset=1852 */ "Metrics contributing to tma_ports_utilization category\000"
/* offset=1907 */ "Metrics contributing to tma_ports_utilized_0 category\000"
/* offset=1961 */ "Metrics contributing to tma_ports_utilized_3m category\000"
/* offset=2016 */ "Metrics contributing to tma_resource_bound category\000"
/* offset=2068 */ "Metrics contributing to tma_retiring category\000"
/* offset=2114 */ "Metrics contributing to tma_serializing_operation category\000"
/* offset=2173 */ "Metrics contributing to tma_store_bound category\000"
/* offset=2222 */ "Metrics contributing to tma_store_op_utilization category\000"
/* offset=2280 */ "Metrics for top-down breakdown at level 1\000"
/* offset=2322 */ "Metrics for top-down breakdown at level 2\000"
/* offset=2364 */ "Metrics for top-down breakdown at level 3\000"
/* offset=2406 */ "Metrics for top-down breakdown at level 4\000"
/* offset=2448 */ "Metrics for top-down breakdown at level 5\000"
/* offset=2490 */ "Metrics for top-down breakdown at level 6\000"
/* offset=2532 */ "Metrics related by the issue $issue2P\000"
/* offset=2570 */ "Metrics related by the issue $issueBC\000"
/* offset=2608 */ "Metrics related by the issue $issueBM\000"
/* offset=2646 */ "Metrics related by the issue $issueBW\000"
/* offset=2684 */ "Metrics related by the issue $issueD0\000"
/* offset=2722 */ "Metrics related by the issue $issueFB\000"
/* offset=2760 */ "Metrics related by the issue $issueFL\000"
/* offset=2798 */ "Metrics related by the issue $issueL1\000"
/* offset=2836 */ "Metrics related by the issue $issueLat\000"
/* offset=2875 */ "Metrics related by the issue $issueMC\000"
/* offset=2913 */ "Metrics related by the issue $issueMS\000"
/* offset=2951 */ "Metrics related by the issue $issueMV\000"
/* offset=2989 */ "Metrics related by the issue $issueRFO\000"
/* offset=3028 */ "Metrics related by the issue $issueSL\000"
/* offset=3066 */ "Metrics related by the issue $issueSO\000"
/* offset=3104 */ "Metrics related by the issue $issueSmSt\000"
/* offset=3144 */ "Metrics related by the issue $issueSpSt\000"
/* offset=3184 */ "Metrics related by the issue $issueSyncxn\000"
/* offset=3226 */ "Metrics related by the issue $issueTLB\000"
/* offset=3265 */ "MicroSeq\000"
/* offset=3274 */ "OS\000"
/* offset=3277 */ "Offcore\000"
/* offset=3285 */ "PGO\000"
/* offset=3289 */ "Pipeline\000"
/* offset=3298 */ "PortsUtil\000"
/* offset=3308 */ "Power\000"
/* offset=3314 */ "Prefetches\000"
/* offset=3325 */ "Ret\000"
/* offset=3329 */ "Retire\000"
/* offset=3336 */ "SMT\000"
/* offset=3340 */ "Server\000"
/* offset=3347 */ "Snoop\000"
/* offset=3353 */ "SoC\000"
/* offset=3357 */ "Summary\000"
/* offset=3365 */ "TmaL1\000"
/* offset=3371 */ "TmaL2\000"
/* offset=3377 */ "TmaL3mem\000"
/* offset=3386 */ "TopdownL1\000"
/* offset=3396 */ "TopdownL2\000"
/* offset=3406 */ "TopdownL3\000"
/* offset=3416 */ "TopdownL4\000"
/* offset=3426 */ "TopdownL5\000"
/* offset=3436 */ "TopdownL6\000"
/* offset=3446 */ "\000Average_Frequency\000\000cycles / CPU_CLK_UNHALTED.REF_TSC * msr@tsc@ / 1e9\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000"
/* offset=3582 */ "\000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000"
/* offset=3686 */ "\000C1_Core_Residency\000Power\000cstate_core@c1\\-residency@ / TSC\000\000C1 residency percent per core\000\000100%\000\000\000\00000"
/* offset=3786 */ "\000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000"
/* offset=3887 */ "\000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000"
/* offset=3987 */ "\000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000"
/* offset=4088 */ "\000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000"
/* offset=4188 */ "\000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000"
/* offset=4289 */ "\000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000"
/* offset=4389 */ "\000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000"
/* offset=4490 */ "\000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000"
/* offset=4591 */ "\000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000"
/* offset=4692 */ "\000CLKS\000\000cycles\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000"
/* offset=4787 */ "\000CPI\000\0001 / IPC\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000"
/* offset=4856 */ "\000CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000"
/* offset=4879 */ "\000CPU_Utilization\000\000CPU_CLK_UNHALTED.REF_TSC / msr@tsc@\000\000Average CPU Utilization\000\000\000\000\000\00000"
/* offset=4965 */ "\000DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000"
/* offset=5030 */ "\000DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000"
/* offset=5125 */ "\000DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000"
/* offset=5260 */ "\000DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=5329 */ "\000DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=5400 */ "\000Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000"
/* offset=5567 */ "\000IPC\000\000INST_RETIRED.ANY / cycles\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000"
/* offset=5654 */ "\000IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000"
/* offset=5718 */ "\000Instructions\000\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000\000\000\000\000\00000"
/* offset=5795 */ "\000IpBranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=5930 */ "\000IpMispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000\000\00000"
/* offset=6075 */ "\000Kernel_Utilization\000\000cycles:k / cycles\000\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000"
/* offset=6188 */ "\000L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000"
/* offset=6260 */ "\000L3_Cache_Fill_BW\000\00064 * LONGEST_LAT_CACHE.MISS / 1e9\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=6385 */ "\000M1\000\000ipc + M2\000\000\000\000\000\000\000\00000"
/* offset=6408 */ "\000M2\000\000ipc + M1\000\000\000\000\000\000\000\00000"
/* offset=6431 */ "\000M3\000\0001 / M3\000\000\000\000\000\000\000\00000"
/* offset=6452 */ "\000Turbo_Utilization\000\000cycles / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000"
/* offset=6571 */ "\000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000"
/* offset=6689 */ "\000all_l1_data_cache_fills\000l1_dcache\000ls_any_fills_from_sys.all\000\000All L1 data cache fills\000\000\000\000\000\00000"
/* offset=6782 */ "\000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Accesses\000\000\000\000\000\00000"
/* offset=6931 */ "\000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2.all + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000All L2 cache accesses\000\000\000\000\000\00000"
/* offset=7092 */ "\000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2.all\000\000All L2 cache hits\000\000\000\000\000\00000"
/* offset=7199 */ "\000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2\000\000All L2 Cache Hits\000\000\000\000\000\00000"
/* offset=7302 */ "\000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Misses\000\000\000\000\000\00000"
/* offset=7437 */ "\000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000All L2 cache misses\000\000\000\000\000\00000"
/* offset=7580 */ "\000all_remote_links_outbound\000data_fabric\000remote_outbound_data_controller_0 + remote_outbound_data_controller_1 + remote_outbound_data_controller_2 + remote_outbound_data_controller_3\000\000Approximate: Outbound data bytes for all Remote Links for a node (die)\000\0003e-5MiB\000\000\000\00000"
/* offset=7847 */ "\000all_tlbs_flushed\000tlb\000ls_tlb_flush.all\000\000All TLBs flushed\000\000\000\000\000\00000"
/* offset=7911 */ "\000backend_bound\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.backend_stalls, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of backend stalls\000\000100%\000\000\000\00000"
/* offset=8093 */ "\000backend_bound_cpu\000PipelineL2;backend_bound_group\000backend_bound * (1 - d_ratio(ex_no_retire.load_not_complete, ex_no_retire.not_complete))\000\000Fraction of dispatch slots that remained unused because of stalls not related to the memory subsystem\000\000100%\000\000\000\00000"
/* offset=8346 */ "\000backend_bound_memory\000PipelineL2;backend_bound_group\000backend_bound * d_ratio(ex_no_retire.load_not_complete, ex_no_retire.not_complete)\000\000Fraction of dispatch slots that remained unused because of stalls due to the memory subsystem\000\000100%\000\000\000\00000"
/* offset=8588 */ "\000bad_speculation\000PipelineL1\000d_ratio(de_src_op_disp.all - ex_ret_ops, total_dispatch_slots)\000\000Fraction of dispatched ops that did not retire\000\000100%\000\000\000\00000"
/* offset=8738 */ "\000bad_speculation_mispredicts\000PipelineL2;bad_speculation_group\000d_ratio(bad_speculation * ex_ret_brn_misp, ex_ret_brn_misp + resyncs_or_nc_redirects)\000\000Fraction of dispatched ops that were flushed due to branch mispredicts\000\000100%\000\000\000\00000"
/* offset=8969 */ "\000bad_speculation_pipeline_restarts\000PipelineL2;bad_speculation_group\000d_ratio(bad_speculation * resyncs_or_nc_redirects, ex_ret_brn_misp + resyncs_or_nc_redirects)\000\000Fraction of dispatched ops that were flushed due to pipeline restarts (resyncs)\000\000100%\000\000\000\00000"
/* offset=9223 */ "\000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-Time Branch Misprediction Ratio (Non-Speculative)\000\000100%\000\000\000\00000"
/* offset=9378 */ "\000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-time branch misprediction ratio (non-speculative)\000\000100%\000\000\000\00000"
/* offset=9533 */ "\000cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000"
/* offset=9605 */ "\000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000"
/* offset=9780 */ "\000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000"
/* offset=9927 */ "\000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000"
/* offset=10047 */ "\000dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=10112 */ "\000dram_read_data_for_local_processor\000data_fabric\000local_processor_read_data_beats_cs0 + local_processor_read_data_beats_cs1 + local_processor_read_data_beats_cs2 + local_processor_read_data_beats_cs3 + local_processor_read_data_beats_cs4 + local_processor_read_data_beats_cs5 + local_processor_read_data_beats_cs6 + local_processor_read_data_beats_cs7 + local_processor_read_data_beats_cs8 + local_processor_read_data_beats_cs9 + local_processor_read_data_beats_cs10 + local_processor_read_data_beats_cs11\000\000DRAM read data for local processor\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=10676 */ "\000dram_read_data_for_remote_processor\000data_fabric\000remote_processor_read_data_beats_cs0 + remote_processor_read_data_beats_cs1 + remote_processor_read_data_beats_cs2 + remote_processor_read_data_beats_cs3 + remote_processor_read_data_beats_cs4 + remote_processor_read_data_beats_cs5 + remote_processor_read_data_beats_cs6 + remote_processor_read_data_beats_cs7 + remote_processor_read_data_beats_cs8 + remote_processor_read_data_beats_cs9 + remote_processor_read_data_beats_cs10 + remote_processor_read_data_beats_cs11\000\000DRAM read data for remote processor\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=11254 */ "\000dram_write_data_for_local_processor\000data_fabric\000local_processor_write_data_beats_cs0 + local_processor_write_data_beats_cs1 + local_processor_write_data_beats_cs2 + local_processor_write_data_beats_cs3 + local_processor_write_data_beats_cs4 + local_processor_write_data_beats_cs5 + local_processor_write_data_beats_cs6 + local_processor_write_data_beats_cs7 + local_processor_write_data_beats_cs8 + local_processor_write_data_beats_cs9 + local_processor_write_data_beats_cs10 + local_processor_write_data_beats_cs11\000\000DRAM write data for local processor\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=11832 */ "\000dram_write_data_for_remote_processor\000data_fabric\000remote_processor_write_data_beats_cs0 + remote_processor_write_data_beats_cs1 + remote_processor_write_data_beats_cs2 + remote_processor_write_data_beats_cs3 + remote_processor_write_data_beats_cs4 + remote_processor_write_data_beats_cs5 + remote_processor_write_data_beats_cs6 + remote_processor_write_data_beats_cs7 + remote_processor_write_data_beats_cs8 + remote_processor_write_data_beats_cs9 + remote_processor_write_data_beats_cs10 + remote_processor_write_data_beats_cs11\000\000DRAM write data for remote processor\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=12424 */ "\000dtlb_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=12911 */ "\000dtlb_2nd_level_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=13408 */ "\000dtlb_2nd_level_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=13834 */ "\000dtlb_2nd_level_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=14264 */ "\000dtlb_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=14680 */ "\000dtlb_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=15100 */ "\000frontend_bound\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.no_ops_from_frontend, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because the frontend did not supply enough instructions/ops\000\000100%\000\000\000\00000"
/* offset=15323 */ "\000frontend_bound_bandwidth\000PipelineL2;frontend_bound_group\000d_ratio(de_no_dispatch_per_slot.no_ops_from_frontend - 6 * cpu@de_no_dispatch_per_slot.no_ops_from_frontend\\,cmask\\=0x6@, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of a bandwidth bottleneck in the frontend (such as decode or op cache fetch bandwidth)\000\000100%\000\000\000\00000"
/* offset=15680 */ "\000frontend_bound_latency\000PipelineL2;frontend_bound_group\000d_ratio(6 * cpu@de_no_dispatch_per_slot.no_ops_from_frontend\\,cmask\\=0x6@, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of a latency bottleneck in the frontend (such as instruction cache or TLB misses)\000\000100%\000\000\000\00000"
/* offset=15983 */ "\000ic_fetch_miss_ratio\000\000d_ratio(ic_tag_hit_miss.instruction_cache_miss, ic_tag_hit_miss.all_instruction_cache_accesses)\000\000Instruction cache miss ratio for all fetches. An instruction cache miss will not be counted by this metric if it is an OC hit\000\000100%\000\000\000\00000"
/* offset=16239 */ "\000ic_fetch_miss_ratio\000l2_cache\000d_ratio(ic_tag_hit_miss.instruction_cache_miss, ic_tag_hit_miss.all_instruction_cache_accesses)\000\000Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000"
/* offset=16418 */ "\000ic_fetch_miss_ratio\000l2_cache\000d_ratio(l2_cache_req_stat.ic_access_in_l2, bp_l1_tlb_fetch_hit + bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_miss)\000\000L1 Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000"
/* offset=16617 */ "\000ic_fetch_miss_ratio\000l2_cache\000d_ratio(l2_cache_req_stat.ic_access_in_l2, bp_l1_tlb_fetch_hit + bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_tlb_miss)\000\000L1 Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000"
/* offset=16820 */ "\000icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=16888 */ "\000io_bandwidth_read\000\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000"
/* offset=17218 */ "\000io_bandwidth_read\000\000UNC_CHA_TOR_INSERTS.IO_PCIRDCUR * 64 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000"
/* offset=17417 */ "\000io_bandwidth_read\000\000cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x19e@ * 64 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000"
/* offset=17634 */ "\000io_bandwidth_write\000\000(UNC_CHA_TOR_INSERTS.IO_HIT_ITOM + UNC_CHA_TOR_INSERTS.IO_MISS_ITOM + UNC_CHA_TOR_INSERTS.IO_HIT_ITOMCACHENEAR + UNC_CHA_TOR_INSERTS.IO_MISS_ITOMCACHENEAR) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000"
/* offset=17954 */ "\000io_bandwidth_write\000\000(UNC_CHA_TOR_INSERTS.IO_ITOM + UNC_CHA_TOR_INSERTS.IO_ITOMCACHENEAR) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000"
/* offset=18187 */ "\000io_bandwidth_write\000\000(UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART0 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART1 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART2 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000"
/* offset=18522 */ "\000io_bandwidth_write\000\000(cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x1c8\\,filter_tid\\=0x3e@ + cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x180\\,filter_tid\\=0x3e@) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000"
/* offset=18826 */ "\000io_bandwidth_write\000\000cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x1c8\\,filter_tid\\=0x3e@ * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000"
/* offset=19058 */ "\000itlb_2nd_level_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=19568 */ "\000itlb_2nd_level_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=19992 */ "\000itlb_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=20492 */ "\000itlb_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000"
/* offset=20906 */ "\000l1_data_cache_fills_from_different_ccx\000l1_dcache\000ls_any_fills_from_sys.remote_cache\000\000L1 data cache fills from another CCX cache in any NUMA node\000\000\000\000\000\00000"
/* offset=21059 */ "\000l1_data_cache_fills_from_memory\000l1_dcache\000ls_any_fills_from_sys.dram_io_all\000\000L1 data cache fills from DRAM or MMIO in any NUMA node\000\000\000\000\000\00000"
/* offset=21199 */ "\000l1_data_cache_fills_from_remote_node\000l1_dcache\000ls_any_fills_from_sys.far_all\000\000L1 data cache fills from a different NUMA node\000\000\000\000\000\00000"
/* offset=21332 */ "\000l1_data_cache_fills_from_same_ccx\000l1_dcache\000ls_any_fills_from_sys.local_all\000\000L1 data cache fills from within the same CCX\000\000\000\000\000\00000"
/* offset=21462 */ "\000l1_demand_data_cache_fills_from_far_cache\000l1_dcache\000ls_dmnd_fills_from_sys.far_cache\000\000L1 demand data cache fills from another CCX cache in a different NUMA node\000\000\000\000\000\00000"
/* offset=21631 */ "\000l1_demand_data_cache_fills_from_far_memory\000l1_dcache\000ls_dmnd_fills_from_sys.dram_io_far\000\000L1 demand data cache fills from DRAM or MMIO in a different NUMA node\000\000\000\000\000\00000"
/* offset=21798 */ "\000l1_demand_data_cache_fills_from_local_l2\000l1_dcache\000ls_dmnd_fills_from_sys.local_l2\000\000L1 demand data cache fills from local L2 cache\000\000\000\000\000\00000"
/* offset=21937 */ "\000l1_demand_data_cache_fills_from_near_cache\000l1_dcache\000ls_dmnd_fills_from_sys.near_cache\000\000L1 demand data cache fills from another CCX cache in the same NUMA node\000\000\000\000\000\00000"
/* offset=22105 */ "\000l1_demand_data_cache_fills_from_near_memory\000l1_dcache\000ls_dmnd_fills_from_sys.dram_io_near\000\000L1 demand data cache fills from DRAM or MMIO in the same NUMA node\000\000\000\000\000\00000"
/* offset=22271 */ "\000l1_demand_data_cache_fills_from_same_ccx\000l1_dcache\000ls_dmnd_fills_from_sys.local_ccx\000\000L1 demand data cache fills from within the same CCX\000\000\000\000\000\00000"
/* offset=22416 */ "\000l1_dtlb_misses\000tlb\000ls_l1_d_tlb_miss.all\000\000L1 data TLB misses\000\000\000\000\000\00000"
/* offset=22484 */ "\000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=22730 */ "\000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000"
/* offset=22820 */ "\000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_tlb_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000"
/* offset=22914 */ "\000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_hit + bp_l1_tlb_miss_l2_tlb_miss.all\000\000L1 instruction TLB misses\000\000\000\000\000\00000"
/* offset=23027 */ "\000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_hit + bp_l1_tlb_miss_l2_tlb_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000"
/* offset=23125 */ "\000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=23335 */ "\000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=23550 */ "\000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=23743 */ "\000l2_cache_accesses_from_l1_dc_misses\000l2_cache\000l2_request_g1.all_dc\000\000L2 cache accesses from L1 data cache misses (including prefetch)\000\000\000\000\000\00000"
/* offset=23883 */ "\000l2_cache_accesses_from_l1_ic_misses\000l2_cache\000l2_request_g1.cacheable_ic_read\000\000L2 cache accesses from L1 instruction cache misses (including prefetch)\000\000\000\000\000\00000"
/* offset=24041 */ "\000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Accesses from L2 HWPF\000\000\000\000\000\00000"
/* offset=24176 */ "\000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2.all + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000L2 cache accesses from L2 cache hardware prefetcher\000\000\000\000\000\00000"
/* offset=24344 */ "\000l2_cache_hits_from_l1_dc_miss\000l2_cache\000l2_cache_req_stat.dc_hit_in_l2\000\000L2 cache hits from L1 data cache misses\000\000\000\000\000\00000"
/* offset=24463 */ "\000l2_cache_hits_from_l1_ic_miss\000l2_cache\000l2_cache_req_stat.ic_hit_in_l2\000\000L2 cache hits from L1 instruction cache misses\000\000\000\000\000\00000"
/* offset=24589 */ "\000l2_cache_hits_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2.all\000\000L2 cache hits from L2 cache hardware prefetcher\000\000\000\000\000\00000"
/* offset=24699 */ "\000l2_cache_misses_from_l1_dc_miss\000l2_cache\000l2_cache_req_stat.ls_rd_blk_c\000\000L2 cache misses from L1 data cache misses\000\000\000\000\000\00000"
/* offset=24821 */ "\000l2_cache_misses_from_l1_ic_miss\000l2_cache\000l2_cache_req_stat.ic_fill_miss\000\000L2 cache misses from L1 instruction cache misses\000\000\000\000\000\00000"
/* offset=24951 */ "\000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Misses from L2 Cache HWPF\000\000\000\000\000\00000"
/* offset=25073 */ "\000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Misses from L2 HWPF\000\000\000\000\000\00000"
/* offset=25189 */ "\000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000L2 cache misses from L2 cache hardware prefetcher\000\000\000\000\000\00000"
/* offset=25334 */ "\000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=25514 */ "\000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=25728 */ "\000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=25947 */ "\000l2_demand_data_read_mpi\000\000MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=26145 */ "\000l2_demand_data_read_mpi\000\000MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=26348 */ "\000l2_dtlb_misses\000tlb\000ls_l1_d_tlb_miss.all_l2_miss\000\000L2 data TLB misses and data page walks\000\000\000\000\000\00000"
/* offset=26444 */ "\000l2_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_miss.all\000\000L2 instruction TLB misses and instruction page walks\000\000\000\000\000\00000"
/* offset=26556 */ "\000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=26748 */ "\000l3_cache_accesses\000l3_cache\000l3_lookup_state.all_coherent_accesses_to_l3\000\000L3 cache accesses\000\000\000\000\000\00000"
/* offset=26846 */ "\000l3_misses\000l3_cache\000l3_lookup_state.l3_miss\000\000L3 misses (including cacheline state change requests)\000\000\000\000\000\00000"
/* offset=26952 */ "\000l3_read_miss_latency\000l3_cache\000l3_xi_sampled_latency.all * 10 / l3_xi_sampled_latency_requests.all\000\000Average L3 read miss latency (in core clocks)\000\0001core clocks\000\000\000\00000"
/* offset=27117 */ "\000l3_read_miss_latency\000l3_cache\000xi_sys_fill_latency * 16 / xi_ccx_sdp_req1.all_l3_miss_req_typs\000\000Average L3 Read Miss Latency (in core clocks)\000\0001core clocks\000\000\000\00000"
/* offset=27278 */ "\000l3_read_miss_latency\000l3_cache\000xi_sys_fill_latency * 16 / xi_ccx_sdp_req1\000\000Average L3 Read Miss Latency (in core clocks)\000\0001core clocks\000\000\000\00000"
/* offset=27418 */ "\000llc_code_read_mpi_demand_plus_prefetch\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_CRD + UNC_CHA_TOR_INSERTS.IA_MISS_CRD_PREF) / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=27715 */ "\000llc_code_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x181@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x191@) / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=28053 */ "\000llc_code_read_mpi_demand_plus_prefetch\000\000UNC_CHA_TOR_INSERTS.IA_MISS_CRD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=28309 */ "\000llc_code_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12CC0233@ / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=28587 */ "\000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000"
/* offset=28970 */ "\000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40433@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40433@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000"
/* offset=29347 */ "\000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40433@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40433@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000"
/* offset=29730 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=30170 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40432@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=30592 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40432@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=31020 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=31464 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40431@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=31888 */ "\000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40431@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=32318 */ "\000llc_data_read_mpi_demand_plus_prefetch\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFDATA + UNC_CHA_TOR_INSERTS.IA_MISS_DRD + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF) / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=32657 */ "\000llc_data_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x192@) / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=32995 */ "\000llc_data_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12D40433@ / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=33273 */ "\000llc_demand_data_read_miss_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000"
/* offset=33606 */ "\000llc_demand_data_read_miss_latency_for_local_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=34002 */ "\000llc_demand_data_read_miss_latency_for_remote_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000"
/* offset=34403 */ "\000llc_demand_data_read_miss_to_dram_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to DRAM in nano seconds\000\0001ns\000\000\000\00000"
/* offset=34774 */ "\000llc_demand_data_read_miss_to_pmem_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to Intel(R) Optane(TM) Persistent Memory(PMEM) in nano seconds\000\0001ns\000\000\000\00000"
/* offset=35184 */ "\000llc_miss_local_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000"
/* offset=35388 */ "\000llc_miss_local_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000"
/* offset=35595 */ "\000llc_miss_remote_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000"
/* offset=35802 */ "\000llc_miss_remote_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000"
/* offset=36012 */ "\000loads_per_instr\000\000MEM_INST_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=36195 */ "\000loads_per_instr\000\000MEM_UOPS_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=36378 */ "\000local_socket_inbound_data_to_cpu\000data_fabric\000local_socket_inf0_inbound_data_beats_ccm0 + local_socket_inf1_inbound_data_beats_ccm0 + local_socket_inf0_inbound_data_beats_ccm1 + local_socket_inf1_inbound_data_beats_ccm1 + local_socket_inf0_inbound_data_beats_ccm2 + local_socket_inf1_inbound_data_beats_ccm2 + local_socket_inf0_inbound_data_beats_ccm3 + local_socket_inf1_inbound_data_beats_ccm3 + local_socket_inf0_inbound_data_beats_ccm4 + local_socket_inf1_inbound_data_beats_ccm4 + local_socket_inf0_inbound_data_beats_ccm5 + local_socket_inf1_inbound_data_beats_ccm5 + local_socket_inf0_inbound_data_beats_ccm6 + local_socket_inf1_inbound_data_beats_ccm6 + local_socket_inf0_inbound_data_beats_ccm7 + local_socket_inf1_inbound_data_beats_ccm7\000\000Local socket inbound data to the CPU (e.g. read data)\000\0003.0517578125e-5MiB\000\000\000\00000"
/* offset=37206 */ "\000local_socket_outbound_data_from_all_links\000data_fabric\000local_socket_outbound_data_beats_link0 + local_socket_outbound_data_beats_link1 + local_socket_outbound_data_beats_link2 + local_socket_outbound_data_beats_link3 + local_socket_outbound_data_beats_link4 + local_socket_outbound_data_beats_link5 + local_socket_outbound_data_beats_link6 + local_socket_outbound_data_beats_link7\000\000Outbound data from all links (local socket)\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=37656 */ "\000local_socket_outbound_data_from_cpu\000data_fabric\000local_socket_inf0_outbound_data_beats_ccm0 + local_socket_inf1_outbound_data_beats_ccm0 + local_socket_inf0_outbound_data_beats_ccm1 + local_socket_inf1_outbound_data_beats_ccm1 + local_socket_inf0_outbound_data_beats_ccm2 + local_socket_inf1_outbound_data_beats_ccm2 + local_socket_inf0_outbound_data_beats_ccm3 + local_socket_inf1_outbound_data_beats_ccm3 + local_socket_inf0_outbound_data_beats_ccm4 + local_socket_inf1_outbound_data_beats_ccm4 + local_socket_inf0_outbound_data_beats_ccm5 + local_socket_inf1_outbound_data_beats_ccm5 + local_socket_inf0_outbound_data_beats_ccm6 + local_socket_inf1_outbound_data_beats_ccm6 + local_socket_inf0_outbound_data_beats_ccm7 + local_socket_inf1_outbound_data_beats_ccm7\000\000Local socket outbound data from the CPU (e.g. write data)\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=38506 */ "\000local_socket_upstream_dma_read_data\000data_fabric\000local_socket_upstream_read_beats_iom0 + local_socket_upstream_read_beats_iom1 + local_socket_upstream_read_beats_iom2 + local_socket_upstream_read_beats_iom3\000\000Local socket upstream DMA read data\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=38774 */ "\000local_socket_upstream_dma_write_data\000data_fabric\000local_socket_upstream_write_beats_iom0 + local_socket_upstream_write_beats_iom1 + local_socket_upstream_write_beats_iom2 + local_socket_upstream_write_beats_iom3\000\000Local socket upstream DMA write data\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=39048 */ "\000macro_ops_dispatched\000decoder\000de_dis_cops_from_decoder.disp_op_type.any_integer_dispatch + de_dis_cops_from_decoder.disp_op_type.any_fp_dispatch\000\000Macro-ops Dispatched\000\000\000\000\000\00000"
/* offset=39222 */ "\000macro_ops_dispatched\000decoder\000de_src_op_disp.all\000\000Macro-ops dispatched\000\000\000\000\000\00000"
/* offset=39300 */ "\000macro_ops_retired\000\000ex_ret_ops\000\000Macro-ops retired\000\000\000\000\000\00000"
/* offset=39357 */ "\000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=39475 */ "\000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=39612 */ "\000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=39732 */ "\000memory_extra_write_bw_due_to_directory_updates\000\000(UNC_CHA_DIR_UPDATE.HA + UNC_CHA_DIR_UPDATE.TOR + UNC_M2M_DIRECTORY_UPDATE.ANY) * 64 / 1e6 / duration_time\000\000Memory write bandwidth (MB/sec) caused by directory updates; includes DDR and Intel(R) Optane(TM) Persistent Memory(PMEM)\000\0001MB/s\000\000\000\00000"
/* offset=40023 */ "\000nps1_die_to_dram\000data_fabric\000dram_channel_data_controller_0 + dram_channel_data_controller_1 + dram_channel_data_controller_2 + dram_channel_data_controller_3 + dram_channel_data_controller_4 + dram_channel_data_controller_5 + dram_channel_data_controller_6 + dram_channel_data_controller_7\000\000Approximate: Combined DRAM B/bytes of all channels on a NPS1 node (die)\000\0006.1e-5MiB\000\000\000\00001"
/* offset=40404 */ "\000numa_reads_addressed_to_local_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=40864 */ "\000numa_reads_addressed_to_local_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=41255 */ "\000numa_reads_addressed_to_local_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=41615 */ "\000numa_reads_addressed_to_remote_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=42080 */ "\000numa_reads_addressed_to_remote_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=42475 */ "\000numa_reads_addressed_to_remote_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000"
/* offset=42838 */ "\000op_cache_fetch_miss_ratio\000\000d_ratio(op_cache_hit_miss.op_cache_miss, op_cache_hit_miss.all_op_cache_accesses)\000\000Op cache miss ratio for all fetches\000\000100%\000\000\000\00000"
/* offset=42996 */ "\000op_cache_fetch_miss_ratio\000l2_cache\000d_ratio(op_cache_hit_miss.op_cache_miss, op_cache_hit_miss.all_op_cache_accesses)\000\000Op Cache (64B) Fetch Miss Ratio\000\000\000\000\000\00000"
/* offset=43154 */ "\000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=43424 */ "\000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=43654 */ "\000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=43946 */ "\000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=44198 */ "\000percent_uops_delivered_from_loop_stream_detector\000\000(UOPS_ISSUED.ANY - IDQ.MITE_UOPS - IDQ.MS_UOPS - IDQ.DSB_UOPS) / UOPS_ISSUED.ANY\000\000Uops delivered from loop stream detector(LSD) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=44453 */ "\000percent_uops_delivered_from_loop_stream_detector\000\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from loop stream detector(LSD) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=44654 */ "\000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=44896 */ "\000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000"
/* offset=45098 */ "\000pmem_memory_bandwidth_read\000\000UNC_M_PMM_RPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=45264 */ "\000pmem_memory_bandwidth_total\000\000(UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS) * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=45452 */ "\000pmem_memory_bandwidth_write\000\000UNC_M_PMM_WPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=45620 */ "\000qpi_data_transmit_bw\000\000UNC_Q_TxL_FLITS_G0.DATA * 8 / 1e6 / duration_time\000\000Intel(R) Quick Path Interconnect (QPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=45778 */ "\000remote_socket_inbound_data_to_cpu\000data_fabric\000remote_socket_inf0_inbound_data_beats_ccm0 + remote_socket_inf1_inbound_data_beats_ccm0 + remote_socket_inf0_inbound_data_beats_ccm1 + remote_socket_inf1_inbound_data_beats_ccm1 + remote_socket_inf0_inbound_data_beats_ccm2 + remote_socket_inf1_inbound_data_beats_ccm2 + remote_socket_inf0_inbound_data_beats_ccm3 + remote_socket_inf1_inbound_data_beats_ccm3 + remote_socket_inf0_inbound_data_beats_ccm4 + remote_socket_inf1_inbound_data_beats_ccm4 + remote_socket_inf0_inbound_data_beats_ccm5 + remote_socket_inf1_inbound_data_beats_ccm5 + remote_socket_inf0_inbound_data_beats_ccm6 + remote_socket_inf1_inbound_data_beats_ccm6 + remote_socket_inf0_inbound_data_beats_ccm7 + remote_socket_inf1_inbound_data_beats_ccm7\000\000Remote socket inbound data to the CPU (e.g. read data)\000\0003.0517578125e-5MiB\000\000\000\00000"
/* offset=46624 */ "\000remote_socket_outbound_data_from_cpu\000data_fabric\000remote_socket_inf0_outbound_data_beats_ccm0 + remote_socket_inf1_outbound_data_beats_ccm0 + remote_socket_inf0_outbound_data_beats_ccm1 + remote_socket_inf1_outbound_data_beats_ccm1 + remote_socket_inf0_outbound_data_beats_ccm2 + remote_socket_inf1_outbound_data_beats_ccm2 + remote_socket_inf0_outbound_data_beats_ccm3 + remote_socket_inf1_outbound_data_beats_ccm3 + remote_socket_inf0_outbound_data_beats_ccm4 + remote_socket_inf1_outbound_data_beats_ccm4 + remote_socket_inf0_outbound_data_beats_ccm5 + remote_socket_inf1_outbound_data_beats_ccm5 + remote_socket_inf0_outbound_data_beats_ccm6 + remote_socket_inf1_outbound_data_beats_ccm6 + remote_socket_inf0_outbound_data_beats_ccm7 + remote_socket_inf1_outbound_data_beats_ccm7\000\000Remote socket outbound data from the CPU (e.g. write data)\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=47492 */ "\000remote_socket_upstream_dma_read_data\000data_fabric\000remote_socket_upstream_read_beats_iom0 + remote_socket_upstream_read_beats_iom1 + remote_socket_upstream_read_beats_iom2 + remote_socket_upstream_read_beats_iom3\000\000Remote socket upstream DMA read data\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=47766 */ "\000remote_socket_upstream_dma_write_data\000data_fabric\000remote_socket_upstream_write_beats_iom0 + remote_socket_upstream_write_beats_iom1 + remote_socket_upstream_write_beats_iom2 + remote_socket_upstream_write_beats_iom3\000\000Remote socket upstream DMA write data\000\0006.103515625e-5MiB\000\000\000\00000"
/* offset=48046 */ "\000retiring\000PipelineL1\000d_ratio(ex_ret_ops, total_dispatch_slots)\000\000Fraction of dispatch slots used by ops that retired\000\000100%\000\000\000\00000"
/* offset=48173 */ "\000retiring_fastpath\000PipelineL2;retiring_group\000retiring * (1 - d_ratio(ex_ret_ucode_ops, ex_ret_ops))\000\000Fraction of dispatch slots used by fastpath ops that retired\000\000100%\000\000\000\00000"
/* offset=48346 */ "\000retiring_microcode\000PipelineL2;retiring_group\000retiring * d_ratio(ex_ret_ucode_ops, ex_ret_ops)\000\000Fraction of dispatch slots used by microcode ops that retired\000\000100%\000\000\000\00000"
/* offset=48515 */ "\000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000"
/* offset=48678 */ "\000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000"
/* offset=48738 */ "\000smt_contention\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.smt_contention, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because the other thread was selected\000\000100%\000\000\000\00000"
/* offset=48933 */ "\000sse_avx_stalls\000\000fp_disp_faults.sse_avx_all\000\000Mixed SSE/AVX stalls\000\000\000\000\000\00000"
/* offset=49006 */ "\000stores_per_instr\000\000MEM_INST_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=49192 */ "\000stores_per_instr\000\000MEM_UOPS_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000"
/* offset=49378 */ "\000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000"
/* offset=50173 */ "\000tma_alloc_restriction\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.ALLOC_RESTRICTIONS / tma_info_core_slots\000tma_alloc_restriction > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to certain allocation restrictions\000\000100%\000\000\000\00000"
/* offset=50452 */ "\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5 + UOPS_DISPATCHED.PORT_6) / (4 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000"
/* offset=50804 */ "\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5_11 + UOPS_DISPATCHED.PORT_6) / (5 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000"
/* offset=51159 */ "\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000"
/* offset=51523 */ "\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002"
/* offset=51887 */ "\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5) / (3 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002"
/* offset=52229 */ "\000tma_amx_busy\000Compute;HPC;Server;TopdownL5;tma_L5_group;tma_ports_utilized_0_group\000EXE.AMX_BUSY / tma_info_core_core_clks\000tma_amx_busy > 0.5 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles where the Advanced Matrix Extensions (AMX) execution engine was busy with tile (arithmetic) operations\000\000100%\000\000\000\00000"
/* offset=52640 */ "\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * (FP_ASSIST.ANY + OTHER_ASSISTS.ANY) / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=53706 */ "\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * ASSISTS.ANY / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=54742 */ "\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=55794 */ "\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=56852 */ "\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * cpu@ASSISTS.ANY\\,umask\\=0x1B@ / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=57906 */ "\000tma_avx_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00063 * ASSISTS.SSE_AVX_MIX / tma_info_thread_slots\000tma_avx_assists > 0.1\000This metric estimates fraction of slots the CPU retired uops as a result of handing SSE to AVX* or AVX* to SSE transition Assists\000\000100%\000\000\000\00000"
/* offset=58180 */ "\000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=59207 */ "\000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 5 * cpu@INT_MISC.RECOVERY_CYCLES\\,cmask\\=1\\,edge@ / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=60282 */ "\000tma_backend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_BE_BOUND.ALL / tma_info_core_slots\000tma_backend_bound > 0.1\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.   The rest of these subevents count backend stalls, in cycles, due to an outstanding request which is memory bound vs core bound.   The subevents are not slot based events and therefore can not be precisely added or subtracted from the Backend_Bound_Aux subevents which are slot based\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=61074 */ "\000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1\000\00002"
/* offset=62006 */ "\000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002"
/* offset=62896 */ "\000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - tma_frontend_bound - (UOPS_ISSUED.ANY + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00000"
/* offset=63873 */ "\000tma_backend_bound_aux\000Default;TopdownL1;tma_L1_group\000tma_backend_bound\000tma_backend_bound_aux > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that UOPS must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.  All of these subevents count backend stalls, in slots, due to a resource limitation.   These are not cycle based events and therefore can not be precisely added or subtracted from the Backend_Bound subevents which are cycle based.  These subevents are supplementary to Backend_Bound and can be used to analyze results from a resource perspective at allocation\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=64724 */ "\000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=65434 */ "\000tma_bad_speculation\000Default;TopdownL1;tma_L1_group\000(tma_info_core_slots - (TOPDOWN_FE_BOUND.ALL + TOPDOWN_BE_BOUND.ALL + TOPDOWN_RETIRING.ALL)) / tma_info_core_slots\000tma_bad_speculation > 0.15\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ). Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=66401 */ "\000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000"
/* offset=67170 */ "\000tma_base\000TopdownL2;tma_L2_group;tma_retiring_group\000(TOPDOWN_RETIRING.ALL - UOPS_RETIRED.MS) / tma_info_core_slots\000tma_base > 0.6\000Counts the number of uops that are not from the microsequencer\000\000100%\000\000TopdownL2\000\00000"
/* offset=67383 */ "\000tma_branch_detect\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_DETECT / tma_info_core_slots\000tma_branch_detect > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000100%\000\000\000\00000"
/* offset=68110 */ "\000tma_branch_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * BR_INST_RETIRED.ALL_BRANCHES / (tma_retiring * tma_info_thread_slots)\000tma_branch_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions\000\000100%\000\000\000\00000"
/* offset=68445 */ "\000tma_branch_mispredicts\000BadSpec;BrMispredicts;Default;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000topdown\\-br\\-mispredict / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=69335 */ "\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000"
/* offset=70171 */ "\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001"
/* offset=71007 */ "\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001"
/* offset=71807 */ "\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001"
/* offset=72606 */ "\000tma_branch_mispredicts\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MISPREDICT / tma_info_core_slots\000tma_branch_mispredicts > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to branch mispredicts\000\000100%\000\000TopdownL2\000\00000"
/* offset=72884 */ "\000tma_branch_resteer\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_RESTEER / tma_info_core_slots\000tma_branch_resteer > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000\000100%\000\000\000\00000"
/* offset=73206 */ "\000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000"
/* offset=73983 */ "\000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000"
/* offset=74739 */ "\000tma_cisc\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.CISC / tma_info_core_slots\000tma_cisc > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to the microcode sequencer (MS)\000\000100%\000\000\000\00000"
/* offset=74979 */ "\000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources. Sample with: FRONTEND_RETIRED.MS_FLOWS\000100%\000\000\000\00000"
/* offset=75737 */ "\000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000"
/* offset=76455 */ "\000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002"
/* offset=77173 */ "\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000"
/* offset=77914 */ "\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - tma_branch_mispredicts / tma_bad_speculation) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000"
/* offset=78615 */ "\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000MACHINE_CLEARS.COUNT * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000"
/* offset=79280 */ "\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000MACHINE_CLEARS.COUNT * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000"
/* offset=79989 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(18.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM + 16.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=81165 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(29 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM + 23.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=82339 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD))) + 44 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=83652 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 43.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=84957 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 44 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=86309 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(49 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 48 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=87604 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=89451 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=91007 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=92570 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) + 43 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=94435 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) + 43 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=96010 */ "\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(76 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 75.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=97307 */ "\000tma_core_bound\000Backend;Compute;Default;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=98081 */ "\000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000"
/* offset=98830 */ "\000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001"
/* offset=99571 */ "\000tma_core_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1\000Counts the number of cycles due to backend bound stalls that are core execution bound and not attributed to outstanding demand load or store stalls\000\000100%\000\000TopdownL2\000\00000"
/* offset=99868 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00016.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=100830 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00023.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=101792 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=103058 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=104182 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=105306 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=106581 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=107711 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043.5 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=108844 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00044 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=109985 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00044 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=111165 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00048 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD + MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=112298 */ "\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00075.5 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD + MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=113433 */ "\000tma_decode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.DECODE / tma_info_core_slots\000tma_decode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to decode stalls\000\000100%\000\000\000\00000"
/* offset=113664 */ "\000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000"
/* offset=114219 */ "\000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000"
/* offset=114774 */ "\000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000"
/* offset=115329 */ "\000tma_disambiguation\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.DISAMBIGUATION / MACHINE_CLEARS.SLOW)\000tma_disambiguation > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory disambiguation\000\000100%\000\000\000\00000"
/* offset=115591 */ "\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\00010 * ARITH.DIVIDER_UOPS / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000"
/* offset=116146 */ "\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000"
/* offset=116697 */ "\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIV_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000"
/* offset=117244 */ "\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000"
/* offset=117798 */ "\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000"
/* offset=118350 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00003"
/* offset=118981 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003"
/* offset=119617 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003"
/* offset=120256 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_MISC_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003"
/* offset=120903 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003"
/* offset=121545 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound - tma_pmm_bound if #has_pmem > 0 else CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound)\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001"
/* offset=122373 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks - tma_pmm_bound if #has_pmem > 0 else MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks)\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001"
/* offset=122993 */ "\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001"
/* offset=123623 */ "\000tma_dram_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_BOUND_STALLS.LOAD\000tma_dram_bound > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000\000100%\000\000\000\00001"
/* offset=124017 */ "\000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000"
/* offset=124667 */ "\000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000"
/* offset=125300 */ "\000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000"
/* offset=125933 */ "\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000"
/* offset=126842 */ "\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000\000\00000"
/* offset=127727 */ "\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000"
/* offset=128710 */ "\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000"
/* offset=129662 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000"
/* offset=130701 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000"
/* offset=131664 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000"
/* offset=132703 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_LOAD_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000"
/* offset=133795 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_LOAD_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000"
/* offset=134887 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=136052 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - MEMORY_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=137218 */ "\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(9 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00002"
/* offset=138383 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000"
/* offset=139263 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=140197 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000"
/* offset=141077 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_STORE_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000"
/* offset=142011 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_STORE_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000"
/* offset=142945 */ "\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(9 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=143879 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(110 * tma_info_system_average_frequency * (OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM + OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM) + 47.5 * tma_info_system_average_frequency * (OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE + OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE)) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=144891 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(110 * tma_info_system_average_frequency * (OFFCORE_RESPONSE.DEMAND_RFO.L3_MISS.REMOTE_HITM + OFFCORE_RESPONSE.PF_L2_RFO.L3_MISS.REMOTE_HITM) + 47.5 * tma_info_system_average_frequency * (OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE)) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=145955 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(200 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_MISS.REMOTE_HITM + 60 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=146842 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00022 * tma_info_system_average_frequency * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=147700 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00032.5 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=148497 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00048 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=149292 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00054 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=150087 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=150914 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=151736 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=152564 */ "\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00080 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=153359 */ "\000tma_fast_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.FASTNUKE / tma_info_core_slots\000tma_fast_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear classified as a fast nuke due to memory ordering, memory disambiguation and memory renaming\000\000100%\000\000\000\00000"
/* offset=153696 */ "\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000"
/* offset=154534 */ "\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00002"
/* offset=155428 */ "\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001"
/* offset=156284 */ "\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.REQUEST_FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001"
/* offset=157148 */ "\000tma_fetch_bandwidth\000Default;FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=158121 */ "\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=159069 */ "\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=159852 */ "\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=160611 */ "\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=161551 */ "\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=162460 */ "\000tma_fetch_bandwidth\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_BANDWIDTH / tma_info_core_slots\000tma_fetch_bandwidth > 0.1\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000\000100%\000\000TopdownL2\000\00000"
/* offset=162800 */ "\000tma_fetch_latency\000Default;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000topdown\\-fetch\\-lat / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=163606 */ "\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000(5 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE - INT_MISC.UOP_DROPPING) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000"
/* offset=164336 */ "\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000"
/* offset=165040 */ "\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000"
/* offset=165697 */ "\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000"
/* offset=166384 */ "\000tma_fetch_latency\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_LATENCY / tma_info_core_slots\000tma_fetch_latency > 0.15\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000\000100%\000\000TopdownL2\000\00000"
/* offset=166719 */ "\000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000max(0, tma_heavy_operations - tma_microcode_sequencer)\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000"
/* offset=167347 */ "\000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000"
/* offset=167967 */ "\000tma_fp_amx\000Compute;Flops;HPC;Pipeline;Server;TopdownL4;tma_L4_group;tma_fp_arith_group\000cpu@AMX_OPS_RETIRED.BF16\\,cmask\\=1@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_amx > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) matrix uops fraction the CPU has retired (aggregated across all supported FP datatypes in AMX engine)\000This metric approximates arithmetic floating-point (FP) matrix uops fraction the CPU has retired (aggregated across all supported FP datatypes in AMX engine). Refer to AMX_Busy and GFLOPs metrics for actual AMX utilization and FP performance, resp\000100%\000\000\000\00000"
/* offset=168617 */ "\000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector + tma_fp_amx\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001"
/* offset=169131 */ "\000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000"
/* offset=169632 */ "\000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001"
/* offset=170133 */ "\000tma_fp_assist\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.FP_ASSIST / MACHINE_CLEARS.SLOW)\000tma_fp_assist > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to FP assists\000\000100%\000\000\000\00000"
/* offset=170369 */ "\000tma_fp_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00030 * ASSISTS.FP / tma_info_thread_slots\000tma_fp_assists > 0.1\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. FP Assist may apply when working with very small floating point values (so-called Denormals)\000100%\000\000\000\00000"
/* offset=170835 */ "\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=171419 */ "\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=172037 */ "\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR) / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=172771 */ "\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=173429 */ "\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=174074 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=174786 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=175532 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ + FP_ARITH_INST_RETIRED2.VECTOR) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=176343 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=177065 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00001"
/* offset=177787 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=178522 */ "\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00001"
/* offset=179244 */ "\000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.128B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=180064 */ "\000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=180800 */ "\000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=181523 */ "\000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.256B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=182343 */ "\000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=183079 */ "\000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=183802 */ "\000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.512B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=184622 */ "\000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=185358 */ "\000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=186081 */ "\000tma_fpdiv_uops\000TopdownL3;tma_L3_group;tma_base_group\000UOPS_RETIRED.FPDIV / tma_info_core_slots\000tma_fpdiv_uops > 0.2\000Counts the number of floating point divide operations per uop\000\000100%\000\000\000\00000"
/* offset=186270 */ "\000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=187466 */ "\000tma_frontend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_FE_BOUND.ALL / tma_info_core_slots\000tma_frontend_bound > 0.2\000Counts the number of issue slots  that were not consumed by the backend due to frontend stalls\000\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=187717 */ "\000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1\000\00000"
/* offset=188788 */ "\000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000"
/* offset=189812 */ "\000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.MACRO_FUSED / (tma_retiring * tma_info_thread_slots)\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000"
/* offset=190426 */ "\000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * UOPS_RETIRED.MACRO_FUSED / UOPS_RETIRED.RETIRE_SLOTS\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000"
/* offset=191027 */ "\000tma_heavy_operations\000Default;Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000topdown\\-heavy\\-ops / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences. Sample with: UOPS_RETIRED.HEAVY\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=191743 */ "\000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000(UOPS_RETIRED.RETIRE_SLOTS + UOPS_RETIRED.MACRO_FUSED - INST_RETIRED.ANY) / tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000"
/* offset=192366 */ "\000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer + tma_retiring * (UOPS_DECODED.DEC0 - cpu@UOPS_DECODED.DEC0\\,cmask\\=1@) / IDQ.MITE_UOPS\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000"
/* offset=193003 */ "\000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000"
/* offset=193552 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(ICACHE_16B.IFDATA_STALL + 2 * cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@) / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000"
/* offset=194092 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000"
/* offset=194575 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000"
/* offset=194894 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFETCH_STALL / tma_info_thread_clks - tma_itlb_misses\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000"
/* offset=195231 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_16B.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000"
/* offset=195718 */ "\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_DATA.STALLS / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000"
/* offset=196200 */ "\000tma_icache_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ICACHE / tma_info_core_slots\000tma_icache_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to instruction cache misses\000\000100%\000\000\000\00000"
/* offset=196454 */ "\000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00000"
/* offset=197105 */ "\000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001"
/* offset=197756 */ "\000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_mispredicts_resteers\000\000\000\000\00000"
/* offset=198371 */ "\000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=198640 */ "\000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=198902 */ "\000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=199161 */ "\000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=199501 */ "\000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=199731 */ "\000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=199999 */ "\000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000tma_info_core_ipmispredict\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=200246 */ "\000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001"
/* offset=200566 */ "\000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001"
/* offset=201191 */ "\000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001"
/* offset=201806 */ "\000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000"
/* offset=202249 */ "\000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001"
/* offset=202880 */ "\000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000"
/* offset=203428 */ "\000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.CONDITIONAL + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000"
/* offset=204014 */ "\000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001"
/* offset=204415 */ "\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=205415 */ "\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00001"
/* offset=206415 */ "\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=207397 */ "\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=208349 */ "\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00001"
/* offset=209301 */ "\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=210181 */ "\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=211038 */ "\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=211900 */ "\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=212748 */ "\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=213573 */ "\000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001"
/* offset=214466 */ "\000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001"
/* offset=215311 */ "\000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001"
/* offset=215858 */ "\000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000"
/* offset=216037 */ "\000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000"
/* offset=216209 */ "\000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.NOT_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000"
/* offset=216379 */ "\000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000(BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000"
/* offset=216577 */ "\000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000"
/* offset=216744 */ "\000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00001"
/* offset=217012 */ "\000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000"
/* offset=217249 */ "\000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000"
/* offset=217520 */ "\000tma_info_core_clks\000\000CPU_CLK_UNHALTED.CORE\000\000\000\000\000\000\000\00000"
/* offset=217572 */ "\000tma_info_core_clks_p\000\000CPU_CLK_UNHALTED.CORE_P\000\000\000\000\000\000\000\00000"
/* offset=217628 */ "\000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000"
/* offset=217937 */ "\000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000"
/* offset=218080 */ "\000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000"
/* offset=218245 */ "\000tma_info_core_cpi\000\000tma_info_core_clks / INST_RETIRED.ANY\000\000Cycles Per Instruction\000\000\000\000\000\00000"
/* offset=218334 */ "\000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001"
/* offset=218790 */ "\000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000"
/* offset=219153 */ "\000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001"
/* offset=219516 */ "\000tma_info_core_flopc\000Flops;Ret\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000"
/* offset=219831 */ "\000tma_info_core_flopc\000Flops;Ret\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001"
/* offset=220213 */ "\000tma_info_core_flopc\000Flops;Ret\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR_HALF + 2 * (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED2.COMPLEX_SCALAR_HALF) + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * (FP_ARITH_INST_RETIRED2.128B_PACKED_HALF + cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@) + 16 * (FP_ARITH_INST_RETIRED2.256B_PACKED_HALF + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) + 32 * FP_ARITH_INST_RETIRED2.512B_PACKED_HALF + 4 * AMX_OPS_RETIRED.BF16\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001"
/* offset=220813 */ "\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(FP_ARITH_DISPATCHED.PORT_0 + FP_ARITH_DISPATCHED.PORT_1 + FP_ARITH_DISPATCHED.PORT_5) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001"
/* offset=221371 */ "\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000"
/* offset=221959 */ "\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000"
/* offset=222547 */ "\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001"
/* offset=223135 */ "\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000(UOPS_EXECUTED.CORE / 2 / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@) if #SMT_on else UOPS_EXECUTED.CORE / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@))\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000"
/* offset=223534 */ "\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_DISPATCHED.THREAD / (cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000"
/* offset=223808 */ "\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000"
/* offset=224070 */ "\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000"
/* offset=224339 */ "\000tma_info_core_ipc\000\000INST_RETIRED.ANY / tma_info_core_clks\000\000Instructions Per Cycle\000\000\000\000\000\00000"
/* offset=224428 */ "\000tma_info_core_ipmispredict\000Bad;BadSpec;BrMispredicts;TopdownL1;tma_L1_group\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000TopdownL1\000\00000"
/* offset=224644 */ "\000tma_info_core_slots\000\0005 * tma_info_core_clks\000\000\000\000\000\000\000\00000"
/* offset=224698 */ "\000tma_info_core_upi\000\000UOPS_RETIRED.ALL / INST_RETIRED.ANY\000\000Uops Per Instruction\000\000\000\000\000\00000"
/* offset=224783 */ "\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000"
/* offset=225245 */ "\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000"
/* offset=225687 */ "\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_lcp\000\000\000\000\00000"
/* offset=226105 */ "\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 5 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000"
/* offset=226538 */ "\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 6 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000"
/* offset=226971 */ "\000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / DSB2MITE_SWITCHES.COUNT\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000"
/* offset=227202 */ "\000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000"
/* offset=227463 */ "\000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000"
/* offset=227629 */ "\000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@ + 2\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000"
/* offset=227819 */ "\000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000"
/* offset=228005 */ "\000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_DATA.STALLS / cpu@ICACHE_DATA.STALLS\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000"
/* offset=228181 */ "\000tma_info_frontend_inst_miss_cost_dramhit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_DRAM_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in DRAM\000\000\000\000\000\00000"
/* offset=228355 */ "\000tma_info_frontend_inst_miss_cost_l2hit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_L2_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in the L2\000\000\000\000\000\00000"
/* offset=228527 */ "\000tma_info_frontend_inst_miss_cost_l3hit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_LLC_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in the L3\000\000\000\000\000\00000"
/* offset=228700 */ "\000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=228926 */ "\000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=229132 */ "\000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000"
/* offset=229285 */ "\000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000"
/* offset=229446 */ "\000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache)\000\000\000\000\000\00000"
/* offset=229598 */ "\000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000"
/* offset=229748 */ "\000tma_info_inst_mix_branch_mispredict_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.ALL_BRANCHES\000\000Ratio of all branches which mispredict\000\000\000\000\000\00000"
/* offset=229899 */ "\000tma_info_inst_mix_branch_mispredict_to_unknown_branch_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BACLEARS.ANY\000\000Ratio between Mispredicted branches and unknown branches\000\000\000\000\000\00000"
/* offset=230070 */ "\000tma_info_inst_mix_fpdiv_uop_ratio\000\000100 * UOPS_RETIRED.FPDIV / UOPS_RETIRED.ALL\000\000Percentage of all uops which are FPDiv uops\000\000\000\000\000\00000"
/* offset=230202 */ "\000tma_info_inst_mix_idiv_uop_ratio\000\000100 * UOPS_RETIRED.IDIV / UOPS_RETIRED.ALL\000\000Percentage of all uops which are IDiv uops\000\000\000\000\000\00000"
/* offset=230331 */ "\000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000"
/* offset=230525 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\0001 / (tma_fp_scalar + tma_fp_vector)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000"
/* offset=230883 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR + (cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ + FP_ARITH_INST_RETIRED2.VECTOR))\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000"
/* offset=231407 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000"
/* offset=231865 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00001"
/* offset=232323 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000"
/* offset=232781 */ "\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00001"
/* offset=233239 */ "\000tma_info_inst_mix_iparith_amx_f16\000Flops;FpVector;InsType;Server\000INST_RETIRED.ANY / AMX_OPS_RETIRED.BF16\000tma_info_inst_mix_iparith_amx_f16 < 10\000Instructions per FP Arithmetic AMX operation (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AMX operation (lower number means higher occurrence rate). Operations factored per matrices' sizes of the AMX instructions\000\000\000\000\00000"
/* offset=233632 */ "\000tma_info_inst_mix_iparith_amx_int8\000InsType;IntVector;Server\000INST_RETIRED.ANY / AMX_OPS_RETIRED.INT8\000tma_info_inst_mix_iparith_amx_int8 < 10\000Instructions per Integer Arithmetic AMX operation (lower number means higher occurrence rate)\000Instructions per Integer Arithmetic AMX operation (lower number means higher occurrence rate). Operations factored per matrices' sizes of the AMX instructions\000\000\000\000\00000"
/* offset=234032 */ "\000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.128B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=234529 */ "\000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=234984 */ "\000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.256B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=235475 */ "\000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=235924 */ "\000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.512B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=236413 */ "\000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=236860 */ "\000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=237287 */ "\000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=237714 */ "\000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=237917 */ "\000tma_info_inst_mix_ipbranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurance rate)\000\000\000\000\000\00000"
/* offset=238069 */ "\000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=238268 */ "\000tma_info_inst_mix_ipcall\000\000INST_RETIRED.ANY / BR_INST_RETIRED.CALL\000\000Instruction per (near) call (lower number means higher occurance rate)\000\000\000\000\000\00000"
/* offset=238414 */ "\000tma_info_inst_mix_ipfarbranch\000\000INST_RETIRED.ANY / (BR_INST_RETIRED.FAR_BRANCH / 2)\000\000Instructions per Far Branch\000\000\000\000\000\00000"
/* offset=238534 */ "\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00001"
/* offset=239076 */ "\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=239525 */ "\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00001"
/* offset=239974 */ "\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=240442 */ "\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / tma_info_core_flopc\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=240649 */ "\000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=240831 */ "\000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=241013 */ "\000tma_info_inst_mix_ipload\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000\000Instructions per Load\000\000\000\000\000\00000"
/* offset=241116 */ "\000tma_info_inst_mix_ipmisp_cond_ntaken\000\000INST_RETIRED.ANY / (BR_MISP_RETIRED.COND - BR_MISP_RETIRED.COND_TAKEN)\000\000Instructions per retired conditional Branch Misprediction where the branch was not taken\000\000\000\000\000\00000"
/* offset=241323 */ "\000tma_info_inst_mix_ipmisp_cond_taken\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000\000Instructions per retired conditional Branch Misprediction where the branch was taken\000\000\000\000\000\00000"
/* offset=241500 */ "\000tma_info_inst_mix_ipmisp_indirect\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000\000Instructions per retired indirect call or jump Branch Misprediction\000\000\000\000\000\00000"
/* offset=241656 */ "\000tma_info_inst_mix_ipmisp_ret\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.RETURN\000\000Instructions per retired return Branch Misprediction\000\000\000\000\000\00000"
/* offset=241790 */ "\000tma_info_inst_mix_ipmispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Instructions per retired Branch Misprediction\000\000\000\000\000\00000"
/* offset=241925 */ "\000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=242111 */ "\000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=242297 */ "\000tma_info_inst_mix_ipstore\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000\000Instructions per Store\000\000\000\000\000\00000"
/* offset=242403 */ "\000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000"
/* offset=242664 */ "\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 11\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000"
/* offset=243000 */ "\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 13\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000"
/* offset=243336 */ "\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000"
/* offset=243671 */ "\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000"
/* offset=243975 */ "\000tma_info_inst_mix_microcode_uop_ratio\000\000100 * UOPS_RETIRED.MS / UOPS_RETIRED.ALL\000\000Percentage of all uops which are ucode ops\000\000\000\000\000\00000"
/* offset=244107 */ "\000tma_info_inst_mix_x87_uop_ratio\000\000100 * UOPS_RETIRED.X87 / UOPS_RETIRED.ALL\000\000Percentage of all uops which are x87 uops\000\000\000\000\000\00000"
/* offset=244233 */ "\000tma_info_l1_bound_address_alias_blocks\000\000100 * LD_BLOCKS.4K_ALIAS / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a address aliasing block\000\000\000\000\000\00000"
/* offset=244408 */ "\000tma_info_l1_bound_load_splits\000\000100 * MEM_UOPS_RETIRED.SPLIT_LOADS / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads that are splits\000\000\000\000\000\00000"
/* offset=244570 */ "\000tma_info_l1_bound_store_fwd_blocks\000\000100 * LD_BLOCKS.DATA_UNKNOWN / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a store forward or unknown store address block\000\000\000\000\000\00000"
/* offset=244767 */ "\000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000"
/* offset=244940 */ "\000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=245107 */ "\000tma_info_memory_core_l2_evictions_nonsilent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.NON_SILENT / tma_info_inst_mix_instructions\000\000Rate of non silent evictions from the L2 cache per Kilo instruction\000\000\000\000\000\00000"
/* offset=245315 */ "\000tma_info_memory_core_l2_evictions_silent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.SILENT / tma_info_inst_mix_instructions\000\000Rate of silent evictions from the L2 cache per Kilo instruction where the evicted lines are dropped (no writeback to L3 or memory)\000\000\000\000\000\00000"
/* offset=245579 */ "\000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=245772 */ "\000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=245946 */ "\000tma_info_memory_cycles_per_demand_load_dram_hit\000\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_LOAD_UOPS_RETIRED.DRAM_HIT\000\000Cycle cost per DRAM hit\000\000\000\000\000\00000"
/* offset=246092 */ "\000tma_info_memory_cycles_per_demand_load_l2_hit\000\000MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_LOAD_UOPS_RETIRED.L2_HIT\000\000Cycle cost per L2 hit\000\000\000\000\000\00000"
/* offset=246230 */ "\000tma_info_memory_cycles_per_demand_load_l3_hit\000\000MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_LOAD_UOPS_RETIRED.L3_HIT\000\000Cycle cost per LLC hit\000\000\000\000\000\00000"
/* offset=246370 */ "\000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000"
/* offset=246596 */ "\000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=246761 */ "\000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=246931 */ "\000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000"
/* offset=247124 */ "\000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000"
/* offset=247320 */ "\000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000"
/* offset=247507 */ "\000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=247680 */ "\000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=247858 */ "\000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * (OFFCORE_REQUESTS.ALL_DATA_RD - OFFCORE_REQUESTS.DEMAND_DATA_RD + L2_RQSTS.ALL_DEMAND_MISS + L2_RQSTS.SWPF_MISS) / tma_info_inst_mix_instructions\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000"
/* offset=248167 */ "\000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000"
/* offset=248363 */ "\000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000"
/* offset=248567 */ "\000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=248732 */ "\000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=248902 */ "\000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.LLC_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000"
/* offset=249073 */ "\000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000"
/* offset=249310 */ "\000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001"
/* offset=249558 */ "\000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / MEM_LOAD_COMPLETED.L1_MISS_ANY\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000"
/* offset=249773 */ "\000tma_info_memory_memloadpki\000\0001e3 * MEM_UOPS_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000load ops retired per 1000 instruction\000\000\000\000\000\00000"
/* offset=249900 */ "\000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000"
/* offset=250232 */ "\000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001"
/* offset=250564 */ "\000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000"
/* offset=250757 */ "\000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000"
/* offset=250951 */ "\000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000"
/* offset=251156 */ "\000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000"
/* offset=251364 */ "\000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.L3_MISS_DEMAND_DATA_RD / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000"
/* offset=251574 */ "\000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,umask\\=0x10@ / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000"
/* offset=251794 */ "\000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000"
/* offset=251970 */ "\000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=252139 */ "\000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=252284 */ "\000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=252467 */ "\000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000"
/* offset=252636 */ "\000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000"
/* offset=252866 */ "\000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000"
/* offset=253106 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION + 7 * (DTLB_STORE_MISSES.WALK_COMPLETED + DTLB_LOAD_MISSES.WALK_COMPLETED + ITLB_MISSES.WALK_COMPLETED)) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000"
/* offset=253557 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000"
/* offset=253898 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING + EPT.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00002"
/* offset=254261 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000"
/* offset=254605 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (4 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000"
/* offset=254949 */ "\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * (DTLB_STORE_MISSES.WALK_COMPLETED + DTLB_LOAD_MISSES.WALK_COMPLETED + ITLB_MISSES.WALK_COMPLETED)) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000"
/* offset=255439 */ "\000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000"
/* offset=255682 */ "\000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000"
/* offset=255902 */ "\000tma_info_pipeline_ipassist\000Pipeline;Ret;Retire\000INST_RETIRED.ANY / cpu@ASSISTS.ANY\\,umask\\=0x1B@\000tma_info_pipeline_ipassist < 100e3\000Instructions per a microcode Assist invocation\000Instructions per a microcode Assist invocation. See Assists tree node for details (lower number means higher occurrence rate)\000\000\000\000\00000"
/* offset=256213 */ "\000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000"
/* offset=256405 */ "\000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001"
/* offset=256601 */ "\000tma_info_pipeline_strings_cycles\000Pipeline;Ret\000INST_RETIRED.REP_ITERATION / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000tma_info_pipeline_strings_cycles > 0.1\000Estimated fraction of retirement-cycles dealing with repeat instructions\000\000\000\000\000\00000"
/* offset=256830 */ "\000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000"
/* offset=257006 */ "\000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000"
/* offset=257114 */ "\000tma_info_system_cpu_utilization\000\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000"
/* offset=257211 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=257611 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=257973 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_mem_bandwidth\000\000\000\000\00000"
/* offset=258309 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=258687 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=259027 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_mem_bandwidth\000\000\000\000\00000"
/* offset=259341 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (arb@event\\=0x81\\,umask\\=0x1@ + arb@event\\=0x84\\,umask\\=0x1@) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=259745 */ "\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (arb@event\\=0x81\\,umask\\=0x1@ + arb@event\\=0x84\\,umask\\=0x1@) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=260111 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00001"
/* offset=260736 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000"
/* offset=261268 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00001"
/* offset=261800 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000"
/* offset=262284 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000"
/* offset=262835 */ "\000tma_info_system_gflops\000Cor;Flops;HPC\000tma_info_core_flopc / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000"
/* offset=263119 */ "\000tma_info_system_io_read_bw\000IoBW;Mem;Server;SoC\000(UNC_CHA_TOR_INSERTS.IO_HIT_ITOM + UNC_CHA_TOR_INSERTS.IO_MISS_ITOM + UNC_CHA_TOR_INSERTS.IO_HIT_ITOMCACHENEAR + UNC_CHA_TOR_INSERTS.IO_MISS_ITOMCACHENEAR) * 64 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Reads [GB / sec]\000\000\000\000\000\00000"
/* offset=263422 */ "\000tma_info_system_io_read_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Reads [GB / sec]\000\000\000\000\000\00000"
/* offset=263736 */ "\000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000"
/* offset=264048 */ "\000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000UNC_CHA_TOR_INSERTS.IO_PCIRDCUR * 64 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000"
/* offset=264229 */ "\000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000"
/* offset=264539 */ "\000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000"
/* offset=264694 */ "\000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000"
/* offset=264902 */ "\000tma_info_system_kernel_utilization\000Summary\000cpu@CPU_CLK_UNHALTED.CORE@k / CPU_CLK_UNHALTED.CORE\000\000Fraction of cycles spent in Kernel mode\000\000\000\000\000\00000"
/* offset=265046 */ "\000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / cha_0@event\\=0x0@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=265435 */ "\000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / uncore_cha_0@event\\=0x1@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=265831 */ "\000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_M_RPQ_OCCUPANCY / UNC_M_RPQ_INSERTS) / imc_0@event\\=0x0@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=266184 */ "\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / UNC_ARB_DAT_OCCUPANCY.RD@cmask\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=266484 */ "\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / cpu@UNC_ARB_DAT_OCCUPANCY.RD\\,cmask\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=266789 */ "\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_TRK_OCCUPANCY.DATA_READ / UNC_ARB_TRK_OCCUPANCY.DATA_READ@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=267104 */ "\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=267423 */ "\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182\\,thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=267776 */ "\000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000"
/* offset=268041 */ "\000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / cha_0@event\\=0x0@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=268467 */ "\000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / uncore_cha_0@event\\=0x1@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=268900 */ "\000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_M_PMM_RPQ_OCCUPANCY.ALL / UNC_M_PMM_RPQ_INSERTS) / imc_0@event\\=0x0@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000"
/* offset=269302 */ "\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\000(UNC_ARB_TRK_OCCUPANCY.RD + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.RD\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000"
/* offset=269667 */ "\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_ARB_TRK_OCCUPANCY.DATA_READ / UNC_ARB_TRK_REQUESTS.DATA_READ) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000"
/* offset=270073 */ "\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000"
/* offset=270482 */ "\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_INSERTS.MISS_OPCODE@filter_opc\\=0x182@) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000"
/* offset=270925 */ "\000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000"
/* offset=271130 */ "\000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / arb@event\\=0x81\\,umask\\=0x1@\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000"
/* offset=271339 */ "\000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000"
/* offset=271515 */ "\000tma_info_system_pmm_read_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_RPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for reads [GB / sec]\000\000\000\000\000\00000"
/* offset=271706 */ "\000tma_info_system_pmm_write_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_WPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000"
/* offset=271899 */ "\000tma_info_system_power_license0_utilization\000Power\000(CORE_POWER.LVL0_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks)\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000"
/* offset=272373 */ "\000tma_info_system_power_license0_utilization\000Power\000CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000"
/* offset=272769 */ "\000tma_info_system_power_license1_utilization\000Power\000(CORE_POWER.LVL1_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000"
/* offset=273292 */ "\000tma_info_system_power_license1_utilization\000Power\000CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000"
/* offset=273737 */ "\000tma_info_system_power_license2_utilization\000Power\000(CORE_POWER.LVL2_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000"
/* offset=274252 */ "\000tma_info_system_power_license2_utilization\000Power\000CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000"
/* offset=274689 */ "\000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000"
/* offset=274904 */ "\000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000"
/* offset=275116 */ "\000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000"
/* offset=275234 */ "\000tma_info_system_socket_clks\000SoC\000cbox_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000"
/* offset=275354 */ "\000tma_info_system_socket_clks\000SoC\000cha_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000"
/* offset=275473 */ "\000tma_info_system_socket_clks\000SoC\000uncore_cha_0@event\\=0x1@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000"
/* offset=275599 */ "\000tma_info_system_tiops\000Cor;HPC;IntVector;Server\0008 * AMX_OPS_RETIRED.INT8 / 1e12 / duration_time\000\000Tera Integer (matrix) Operations Per Second\000\000\000\000\000\00000"
/* offset=275747 */ "\000tma_info_system_turbo_utilization\000Power\000tma_info_core_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000"
/* offset=275899 */ "\000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000"
/* offset=276053 */ "\000tma_info_system_upi_data_transmit_bw\000Server;SoC\000UNC_UPI_TxL_FLITS.ALL_DATA * 64 / 9 / 1e6\000\000Cross-socket Ultra Path Interconnect (UPI) data transmit bandwidth for data only [MB / sec]\000\000\000\000\000\00000"
/* offset=276244 */ "\000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000"
/* offset=276380 */ "\000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000"
/* offset=276493 */ "\000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_DISPATCHED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000"
/* offset=276774 */ "\000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000"
/* offset=277053 */ "\000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000"
/* offset=277181 */ "\000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000"
/* offset=277349 */ "\000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000"
/* offset=277503 */ "\000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000"
/* offset=277706 */ "\000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000"
/* offset=277851 */ "\000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000"
/* offset=278007 */ "\000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000"
/* offset=278166 */ "\000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 7.5\000Instruction per taken branch\000\000\000\000\000\00000"
/* offset=278338 */ "\000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 9\000Instruction per taken branch\000\000\000\000\000\00000"
/* offset=278508 */ "\000tma_int_amx\000Compute;HPC;IntVector;Pipeline;Server;TopdownL4;tma_L4_group;tma_int_operations_group\000cpu@AMX_OPS_RETIRED.INT8\\,cmask\\=1@ / (tma_retiring * tma_info_thread_slots)\000tma_int_amx > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric approximates arithmetic Integer (Int) matrix uops fraction the CPU has retired (aggregated across all supported Int datatypes in AMX engine)\000This metric approximates arithmetic Integer (Int) matrix uops fraction the CPU has retired (aggregated across all supported Int datatypes in AMX engine). Refer to AMX_Busy and TIOPs metrics for actual AMX utilization and Int performance, resp\000100%\000\000\000\00000"
/* offset=279166 */ "\000tma_int_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_int_vector_128b + tma_int_vector_256b + tma_shuffles + tma_int_amx\000tma_int_operations > 0.1 & tma_light_operations > 0.6\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired)\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Vector/Matrix Int operations and shuffles are counted. Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain\000100%\000\000\000\00000"
/* offset=279722 */ "\000tma_int_vector_128b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(INT_VEC_RETIRED.ADD_128 + INT_VEC_RETIRED.VNNI_128) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_128b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=280490 */ "\000tma_int_vector_256b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(INT_VEC_RETIRED.ADD_256 + INT_VEC_RETIRED.MUL_256 + INT_VEC_RETIRED.VNNI_256) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_256b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=281284 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(12 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000"
/* offset=281782 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000"
/* offset=282280 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * ITLB_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000"
/* offset=282859 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * ITLB_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000"
/* offset=283405 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000"
/* offset=283903 */ "\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_TAG.STALLS / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000"
/* offset=284396 */ "\000tma_itlb_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ITLB / tma_info_core_slots\000tma_itlb_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000\000100%\000\000\000\00000"
/* offset=284668 */ "\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000"
/* offset=285754 */ "\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000"
/* offset=286851 */ "\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((EXE_ACTIVITY.BOUND_ON_LOADS - MEMORY_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000"
/* offset=287936 */ "\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) - CYCLE_ACTIVITY.STALLS_L1D_PENDING) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000"
/* offset=289070 */ "\000tma_l1_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000LD_HEAD.L1_BOUND_AT_RET / tma_info_core_clks\000tma_l1_bound > 0.1\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a load block\000\000100%\000\000\000\00000"
/* offset=289318 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00000"
/* offset=289893 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000"
/* offset=290473 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_PENDING - CYCLE_ACTIVITY.STALLS_L2_PENDING) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000"
/* offset=291059 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L1D_MISS - MEMORY_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001"
/* offset=291636 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + L1D_PEND_MISS.FB_FULL_PERIODS) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001"
/* offset=292417 */ "\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001"
/* offset=293205 */ "\000tma_l2_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_L2_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_BOUND_STALLS.LOAD\000tma_l2_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 Cache\000\000100%\000\000\000\00001"
/* offset=293573 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000"
/* offset=294213 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L2_MISS - MEMORY_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000"
/* offset=294855 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00003"
/* offset=295561 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003"
/* offset=296272 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003"
/* offset=296986 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_MISC_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003"
/* offset=297708 */ "\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003"
/* offset=298425 */ "\000tma_l3_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_LLC_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_BOUND_STALLS.LOAD\000tma_l3_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000\000100%\000\000\000\00000"
/* offset=298837 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00017 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=299800 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00017.5 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=300765 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00019 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=301728 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001"
/* offset=302819 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001"
/* offset=303915 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.LLC_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001"
/* offset=305017 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00033 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=305980 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00041 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001"
/* offset=307218 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00041 * (MEM_LOAD_UOPS_RETIRED.LLC_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001"
/* offset=308465 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0006.5 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=309429 */ "\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0009 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=310391 */ "\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DECODE.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000"
/* offset=311046 */ "\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000"
/* offset=311704 */ "\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000"
/* offset=312331 */ "\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage\000100%\000\000\000\00000"
/* offset=312934 */ "\000tma_ld_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * MEM_SCHEDULER_BLOCK.LD_BUF / MEM_SCHEDULER_BLOCK.ALL\000tma_ld_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to load buffer full\000\000100%\000\000\000\00000"
/* offset=313227 */ "\000tma_light_operations\000Default;Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=314141 */ "\000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000"
/* offset=315030 */ "\000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000"
/* offset=315911 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000"
/* offset=316428 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002"
/* offset=316945 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00002"
/* offset=317465 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002"
/* offset=317952 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3 / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000"
/* offset=318374 */ "\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3_10 / (3 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00000"
/* offset=318802 */ "\000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000"
/* offset=319201 */ "\000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00002"
/* offset=319600 */ "\000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000"
/* offset=320002 */ "\000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\000200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00001"
/* offset=321002 */ "\000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\000200 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00001"
/* offset=322011 */ "\000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00043.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000"
/* offset=322701 */ "\000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00059.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000"
/* offset=323391 */ "\000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00071 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000"
/* offset=324079 */ "\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(12 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (11 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00000"
/* offset=324936 */ "\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(12 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (9 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00000"
/* offset=325792 */ "\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001"
/* offset=326649 */ "\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001"
/* offset=327416 */ "\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001"
/* offset=328183 */ "\000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(LSD.CYCLES_ACTIVE - LSD.CYCLES_OK) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000"
/* offset=328884 */ "\000tma_machine_clears\000BadSpec;Default;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=329816 */ "\000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000"
/* offset=330723 */ "\000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001"
/* offset=331622 */ "\000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001"
/* offset=332460 */ "\000tma_machine_clears\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MACHINE_CLEARS / tma_info_core_slots\000tma_machine_clears > 0.05\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000\000100%\000\000TopdownL2\000\00000"
/* offset=332837 */ "\000tma_mba_stalls\000MemoryBW;Offcore;Server;TopdownL5;tma_L5_group;tma_mem_bandwidth_group\000INT_MISC.MBA_STALLS / tma_info_thread_clks\000tma_mba_stalls > 0.1 & (tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to memory bandwidth Allocation feature (RDT's memory bandwidth throttling)\000\000100%\000\000\000\00000"
/* offset=333270 */ "\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000"
/* offset=334406 */ "\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000"
/* offset=335504 */ "\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000"
/* offset=336602 */ "\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_info_system_dram_bw_use\000100%\000\000\000\00000"
/* offset=337674 */ "\000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: \000100%\000\000\000\00000"
/* offset=338387 */ "\000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000"
/* offset=339154 */ "\000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000"
/* offset=339885 */ "\000tma_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.MEM_SCHEDULER / tma_info_core_slots\000tma_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000\000100%\000\000\000\00000"
/* offset=340193 */ "\000tma_memory_bound\000Backend;Default;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000topdown\\-mem\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2;Default\000TopdownL2\00000"
/* offset=341091 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001"
/* offset=342540 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000"
/* offset=343499 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001"
/* offset=344458 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + RESOURCE_STALLS.SB) / (CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001"
/* offset=345532 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001"
/* offset=346683 */ "\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001"
/* offset=347826 */ "\000tma_memory_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000min(tma_backend_bound, LD_HEAD.ANY_AT_RET / tma_info_core_clks + tma_store_bound)\000tma_memory_bound > 0.2\000Counts the number of cycles the core is stalled due to stores or loads\000\000100%\000\000TopdownL2\000\00000"
/* offset=348087 */ "\000tma_memory_fence\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00013 * MISC2_RETIRED.LFENCE / tma_info_thread_clks\000tma_memory_fence > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to LFENCE Instructions\000\000100%\000\000\000\00000"
/* offset=348484 */ "\000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00000"
/* offset=348825 */ "\000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001"
/* offset=349166 */ "\000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_UOP_RETIRED.ANY / (tma_retiring * tma_info_thread_slots)\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001"
/* offset=349528 */ "\000tma_memory_ordering\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.MEMORY_ORDERING / MACHINE_CLEARS.SLOW)\000tma_memory_ordering > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory ordering\000\000100%\000\000\000\00000"
/* offset=349787 */ "\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.MS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000"
/* offset=350591 */ "\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000"
/* offset=351433 */ "\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000"
/* offset=352279 */ "\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000"
/* offset=353132 */ "\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost\000100%\000\000\000\00000"
/* offset=353858 */ "\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost\000100%\000\000\000\00000"
/* offset=354628 */ "\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000"
/* offset=355452 */ "\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000tma_branch_mispredicts / tma_bad_speculation * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000"
/* offset=356236 */ "\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000"
/* offset=357035 */ "\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000"
/* offset=357790 */ "\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000"
/* offset=358572 */ "\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000"
/* offset=359354 */ "\000tma_mite_4wide\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_mite_group\000(cpu@IDQ.MITE_UOPS\\,cmask\\=4@ - cpu@IDQ.MITE_UOPS\\,cmask\\=5@) / tma_info_thread_clks\000tma_mite_4wide > 0.05 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where (only) 4 uops were delivered by the MITE pipeline\000\000100%\000\000\000\00000"
/* offset=359750 */ "\000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000160 * ASSISTS.SSE_AVX_MIX / tma_info_thread_clks\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=360262 */ "\000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=360777 */ "\000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000"
/* offset=362006 */ "\000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000"
/* offset=363235 */ "\000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * cpu@UOPS_RETIRED.MS\\,cmask\\=1\\,edge@ / (tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY) / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: FRONTEND_RETIRED.MS_FLOWS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000"
/* offset=364554 */ "\000tma_ms_uops\000TopdownL2;tma_L2_group;tma_retiring_group\000UOPS_RETIRED.MS / tma_info_core_slots\000tma_ms_uops > 0.05\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS)\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows\000100%\000\000TopdownL2\000\00000"
/* offset=364968 */ "\000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - INST_RETIRED.MACRO_FUSED) / (tma_retiring * tma_info_thread_slots)\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000"
/* offset=365594 */ "\000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - UOPS_RETIRED.MACRO_FUSED) / UOPS_RETIRED.RETIRE_SLOTS\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000"
/* offset=366207 */ "\000tma_non_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.NON_MEM_SCHEDULER / tma_info_core_slots\000tma_non_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000\000100%\000\000\000\00000"
/* offset=366608 */ "\000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000"
/* offset=367158 */ "\000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / UOPS_RETIRED.RETIRE_SLOTS\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000"
/* offset=367695 */ "\000tma_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.NUKE / tma_info_core_slots\000tma_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear (slow nuke)\000\000100%\000\000\000\00000"
/* offset=367938 */ "\000tma_other_fb\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.OTHER / tma_info_core_slots\000tma_other_fb > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to other common frontend stalls not categorized\000\000100%\000\000\000\00000"
/* offset=368203 */ "\000tma_other_l1\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.OTHER_AT_RET / tma_info_core_clks\000tma_other_l1 > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a number of other load blocks\000\000100%\000\000\000\00000"
/* offset=368462 */ "\000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_int_operations + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001"
/* offset=369076 */ "\000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_branch_instructions + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001"
/* offset=369645 */ "\000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00000"
/* offset=370238 */ "\000tma_other_load_store\000TopdownL3;tma_L3_group;tma_memory_bound_group\000max(0, tma_memory_bound - (tma_store_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_dram_bound))\000tma_other_load_store > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hits in the L2, LLC, DRAM or MMIO (Non-DRAM) but could not be correctly attributed or cycles in which the load miss is waiting on a request buffer\000\000100%\000\000\000\00000"
/* offset=370678 */ "\000tma_other_ret\000TopdownL3;tma_L3_group;tma_base_group\000(TOPDOWN_RETIRING.ALL - UOPS_RETIRED.MS - UOPS_RETIRED.FPDIV) / tma_info_core_slots\000tma_other_ret > 0.3\000Counts the number of uops retired excluding ms and fp div uops\000\000100%\000\000\000\00000"
/* offset=370909 */ "\000tma_page_fault\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.PAGE_FAULT / MACHINE_CLEARS.SLOW)\000tma_page_fault > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to page faults\000\000100%\000\000\000\00000"
/* offset=371149 */ "\000tma_page_faults\000TopdownL5;tma_L5_group;tma_assists_group\00099 * ASSISTS.PAGE_FAULT / tma_info_thread_slots\000tma_page_faults > 0.05\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. A Page Fault may apply on first application access to a memory page. Note operating system handling of page faults accounts for the majority of its cost\000100%\000\000\000\00000"
/* offset=371650 */ "\000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00000"
/* offset=373560 */ "\000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00001"
/* offset=375470 */ "\000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00000"
/* offset=377276 */ "\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=377934 */ "\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=378550 */ "\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=379171 */ "\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=379797 */ "\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=380383 */ "\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=380965 */ "\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=381505 */ "\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=382050 */ "\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=382600 */ "\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=383110 */ "\000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000"
/* offset=383564 */ "\000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000\000100%\000\000\000\00000"
/* offset=383844 */ "\000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000"
/* offset=384298 */ "\000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000\000100%\000\000\000\00000"
/* offset=384578 */ "\000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Related metrics: tma_split_stores\000100%\000\000\000\00000"
/* offset=384945 */ "\000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000"
/* offset=385354 */ "\000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=385958 */ "\000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=386530 */ "\000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=387139 */ "\000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=387708 */ "\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=388354 */ "\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=388958 */ "\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=389567 */ "\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=390181 */ "\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=390755 */ "\000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000"
/* offset=391176 */ "\000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000\000100%\000\000\000\00000"
/* offset=391440 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((EXE_ACTIVITY.EXE_BOUND_0_PORTS + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000"
/* offset=392550 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000"
/* offset=393765 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * cpu@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@)) / tma_info_thread_clks if ARITH.DIV_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * cpu@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000"
/* offset=395006 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001"
/* offset=396135 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001"
/* offset=397341 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001"
/* offset=398843 */ "\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001"
/* offset=400041 */ "\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_NONE / 2 if #SMT_on else CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_core_core_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=400762 */ "\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (CYCLE_ACTIVITY.STALLS_TOTAL - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=401522 */ "\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=402317 */ "\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=403081 */ "\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=403843 */ "\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_1 - UOPS_EXECUTED.CORE_CYCLES_GE_2) / 2 if #SMT_on else EXE_ACTIVITY.1_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=405006 */ "\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=406224 */ "\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=407482 */ "\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=408697 */ "\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=409809 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_2 - UOPS_EXECUTED.CORE_CYCLES_GE_3) / 2 if #SMT_on else EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=410836 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=411919 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=412962 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=414085 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=415124 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=416142 */ "\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=417118 */ "\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_GE_3 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_3) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000"
/* offset=417616 */ "\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000"
/* offset=418342 */ "\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000"
/* offset=418848 */ "\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000"
/* offset=419352 */ "\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000"
/* offset=420009 */ "\000tma_predecode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.PREDECODE / tma_info_core_slots\000tma_predecode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to wrong predecodes\000\000100%\000\000\000\00000"
/* offset=420252 */ "\000tma_register\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REGISTER / tma_info_core_slots\000tma_register > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000\000100%\000\000\000\00000"
/* offset=420540 */ "\000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(135.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 135.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00000"
/* offset=421613 */ "\000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 180 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00001"
/* offset=423367 */ "\000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(200 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) + 180 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00001"
/* offset=425139 */ "\000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00002"
/* offset=426210 */ "\000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(97 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 97 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00000"
/* offset=427277 */ "\000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000108 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000"
/* offset=428000 */ "\000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000127 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000"
/* offset=428723 */ "\000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000149 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000"
/* offset=429446 */ "\000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000310 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00001"
/* offset=430480 */ "\000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000310 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00001"
/* offset=431523 */ "\000tma_reorder_buffer\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REORDER_BUFFER / tma_info_core_slots\000tma_reorder_buffer > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000\000100%\000\000\000\00000"
/* offset=431803 */ "\000tma_resource_bound\000TopdownL2;tma_L2_group;tma_backend_bound_aux_group\000tma_backend_bound\000tma_resource_bound > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count\000100%\000\000TopdownL2\000\00000"
/* offset=432289 */ "\000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=433318 */ "\000tma_retiring\000Default;TopdownL1;tma_L1_group\000TOPDOWN_RETIRING.ALL / tma_info_core_slots\000tma_retiring > 0.75\000Counts the numer of issue slots  that result in retirement slots\000\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=433528 */ "\000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000"
/* offset=434458 */ "\000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1\000\00000"
/* offset=435381 */ "\000tma_rsv\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * MEM_SCHEDULER_BLOCK.RSV / MEM_SCHEDULER_BLOCK.ALL\000tma_rsv > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to RSV full relative\000\000100%\000\000\000\00000"
/* offset=435660 */ "\000tma_serialization\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.SERIALIZATION / tma_info_core_slots\000tma_serialization > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000\000100%\000\000\000\00000"
/* offset=435994 */ "\000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000PARTIAL_RAT_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: PARTIAL_RAT_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=436702 */ "\000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=437404 */ "\000tma_shuffles\000HPC;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group\000INT_VEC_RETIRED.SHUFFLES / (tma_retiring * tma_info_thread_slots)\000tma_shuffles > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents Shuffle (cross \"vector lane\" data transfers) uops fraction the CPU has retired\000\000100%\000\000\000\00000"
/* offset=437735 */ "\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000140 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000"
/* offset=438256 */ "\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00037 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000"
/* offset=438776 */ "\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00040 * ROB_MISC_EVENTS.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000"
/* offset=439299 */ "\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000CPU_CLK_UNHALTED.PAUSE / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: CPU_CLK_UNHALTED.PAUSE_INST\000100%\000\000\000\00000"
/* offset=439817 */ "\000tma_smc\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.SMC / MACHINE_CLEARS.SLOW)\000tma_smc > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to SMC\000\000100%\000\000\000\00000"
/* offset=440028 */ "\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001"
/* offset=440531 */ "\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000"
/* offset=441070 */ "\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001"
/* offset=441609 */ "\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00002"
/* offset=442148 */ "\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001"
/* offset=442687 */ "\000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000"
/* offset=443184 */ "\000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000"
/* offset=443681 */ "\000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000"
/* offset=444174 */ "\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000"
/* offset=444921 */ "\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000"
/* offset=445630 */ "\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(XQ.FULL_CYCLES + L1D_PEND_MISS.L2_STALLS) / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000"
/* offset=446331 */ "\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000L1D_PEND_MISS.L2_STALL / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000"
/* offset=447012 */ "\000tma_st_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_store_bound\000tma_st_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to store buffer full\000\000100%\000\000\000\00000"
/* offset=447249 */ "\000tma_stlb_hit\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.DTLB_MISS_AT_RET / tma_info_core_clks\000tma_stlb_hit > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a first level TLB miss\000\000100%\000\000\000\00000"
/* offset=447505 */ "\000tma_stlb_miss\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.PGWALK_AT_RET / tma_info_core_clks\000tma_stlb_miss > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a second level TLB miss requiring a page walk\000\000100%\000\000\000\00000"
/* offset=447783 */ "\000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000"
/* offset=448531 */ "\000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000"
/* offset=449269 */ "\000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000"
/* offset=450007 */ "\000tma_store_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000tma_mem_scheduler * (MEM_SCHEDULER_BLOCK.ST_BUF / MEM_SCHEDULER_BLOCK.ALL)\000tma_store_bound > 0.1\000Counts the number of cycles the core is stalled due to store buffer full\000\000100%\000\000\000\00000"
/* offset=450251 */ "\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000"
/* offset=451203 */ "\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.ST_ADDR_AT_RET / tma_info_core_clks\000tma_store_fwd_blk > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a store forward block\000\000100%\000\000\000\00000"
/* offset=451466 */ "\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000"
/* offset=452365 */ "\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 11 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00002"
/* offset=453264 */ "\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00002"
/* offset=454162 */ "\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001"
/* offset=455060 */ "\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(MEM_STORE_RETIRED.L2_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000"
/* offset=455967 */ "\000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000"
/* offset=456422 */ "\000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000"
/* offset=456845 */ "\000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000"
/* offset=457124 */ "\000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000"
/* offset=457513 */ "\000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000"
/* offset=457909 */ "\000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000"
/* offset=458764 */ "\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\00010 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000"
/* offset=459384 */ "\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\0009 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000"
/* offset=460003 */ "\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000INT_MISC.UNKNOWN_BRANCH_CYCLES / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000"
/* offset=460655 */ "\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000tma_branch_resteers - tma_mispredicts_resteers - tma_clears_resteers\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000"
/* offset=461303 */ "\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000tma_branch_resteers - tma_mispredicts_resteers - tma_clears_resteers\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000"
/* offset=461970 */ "\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=462490 */ "\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=462958 */ "\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_DISPATCHED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=463482 */ "\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=464004 */ "\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=464511 */ "\000total_dispatch_slots\000\0006 * ls_not_halted_cyc\000\000Total dispatch slots (upto 6 instructions can be dispatched in each cycle)\000\000\000\000\000\00000"
/* offset=464639 */ "\000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000"
/* offset=464801 */ "\000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000"
/* offset=464989 */ "\000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000"
/* offset=465189 */ "\000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000"
/* offset=465340 */ "\000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000"
/* offset=465493 */ "\000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000"
/* offset=465652 */ "\000uncore_frequency\000\000UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000"
/* offset=465803 */ "\000upi_data_transmit_bw\000\000UNC_UPI_TxL_FLITS.ALL_DATA * 7.111111111111111 / 1e6 / duration_time\000\000Intel(R) Ultra Path Interconnect (UPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000"
/* offset=465980 */ "agu_bypass_cancel.count\000\000pipeline\000This event counts executed load operations with all the following traits: 1. addressing of the format [base + offset], 2. the offset is between 1 and 2047, 3. the address specified in the base register is in one page and the address [base+offset] is in an\000event=0xb6,period=100003,umask=0x1\000\00000\000\000"
/* offset=466310 */ "all_data_cache_accesses\000\000recommended\000All L1 Data Cache Accesses\000event=0x29,umask=0x07\000\00000\000\000"
/* offset=466401 */ "all_data_cache_accesses\000\000recommended\000All data cache accesses\000event=0x29,umask=0x07\000\00000\000\000"
/* offset=466489 */ "all_dc_accesses\000\000recommended\000All L1 Data Cache Accesses\000event=0x29,umask=0x07\000\00000\000\000"
/* offset=466572 */ "all_tlbs_flushed\000\000recommended\000All TLBs Flushed\000event=0x78,umask=0xdf\000\00000\000\000"
/* offset=466646 */ "all_tlbs_flushed\000\000recommended\000All TLBs Flushed\000event=0x78,umask=0xff\000\00000\000\000"
/* offset=466720 */ "amx_ops_retired.bf16\000\000pipeline\000AMX retired arithmetic BF16 operations\000event=0xce,period=1000003,umask=0x2\000\00000\000Number of AMX-based retired arithmetic bfloat16 (BF16) floating-point operations. Counts TDPBF16PS FP instructions. SW to use operation multiplier of 4\000"
/* offset=466982 */ "amx_ops_retired.int8\000\000pipeline\000AMX retired arithmetic integer 8-bit operations\000event=0xce,period=1000003,umask=0x1\000\00000\000Number of AMX-based retired arithmetic integer operations of 8-bit width source operands. Counts TDPB[SS,UU,US,SU]D instructions. SW should use operation multiplier of 8\000"
/* offset=467271 */ "arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000" /* also: cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
/* offset=467371 */ "arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=467480 */ "arith.div_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000"
/* offset=467764 */ "arith.div_active\000cpu_core\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000"
/* offset=468073 */ "arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000event=0x14,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=468280 */ "arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0x14,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000"
/* offset=468568 */ "arith.divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.DIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00010\000\000"
/* offset=468710 */ "arith.divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.DIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00010\000\000"
/* offset=468877 */ "arith.divider_uops\000\000pipeline\000Any uop executed by the Divider. (This includes all divide uops, sqrt, ...)\000event=0x14,period=2000003,umask=0x2\000\00000\000\000"
/* offset=469023 */ "arith.fp_divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.FPDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00010\000\000"
/* offset=469170 */ "arith.fp_divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.FPDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00010\000\000"
/* offset=469342 */ "arith.fpdiv_active\000\000floating point\000ARITH.FPDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000"
/* offset=469445 */ "arith.fpdiv_active\000cpu_core\000floating point\000ARITH.FPDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000"
/* offset=469573 */ "arith.fpdiv_active\000cpu_core\000floating point\000This event counts the cycles the floating point divider is busy. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000"
/* offset=469746 */ "arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000This event counts the number of the divide operations executed\000"
/* offset=469914 */ "arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x4\000\00000\000Divide operations executed\000"
/* offset=470046 */ "arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000Cycles that the divider is active, includes INT and FP. Set 'edge =1, cmask=1' to count the number of divides\000"
/* offset=470283 */ "arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000This event counts the number of the divide operations executed. Uses edge-detect and a cmask value of 1 on ARITH.FPU_DIV_ACTIVE to get the number of the divide operations executed\000"
/* offset=470590 */ "arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000\000"
/* offset=470718 */ "arith.idiv_active\000\000pipeline\000This event counts the cycles the integer divider is busy\000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=470852 */ "arith.idiv_active\000cpu_core\000pipeline\000This event counts the cycles the integer divider is busy. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=471011 */ "arith.int_divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.IDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00010\000\000"
/* offset=471158 */ "arith.int_divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.IDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00010\000\000"
/* offset=471330 */ "arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000"
/* offset=471420 */ "assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x1b\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware. Examples include AD (page Access Dirty), FP and AVX related assists\000"
/* offset=471702 */ "assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x7\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware Examples include AD (page Access Dirty), FP and AVX related assists\000"
/* offset=471982 */ "assists.any\000cpu_core\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware. Unit: cpu_core \000event=0xc1,period=100003,umask=0x1b\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware. Examples include AD (page Access Dirty), FP and AVX related assists\000"
/* offset=472289 */ "assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000"
/* offset=472431 */ "assists.fp\000cpu_core\000floating point\000Counts all microcode FP assists. Unit: cpu_core \000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000"
/* offset=472598 */ "assists.hardware\000cpu_core\000other\000ASSISTS.HARDWARE. Unit: cpu_core \000event=0xc1,period=100003,umask=0x4\000\00000\000\000"
/* offset=472704 */ "assists.page_fault\000\000other\000ASSISTS.PAGE_FAULT\000event=0xc1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=472790 */ "assists.page_fault\000cpu_core\000other\000ASSISTS.PAGE_FAULT. Unit: cpu_core \000event=0xc1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=472901 */ "assists.sse_avx_mix\000\000floating point\000ASSISTS.SSE_AVX_MIX\000event=0xc1,period=1000003,umask=0x10\000\00000\000\000"
/* offset=472999 */ "assists.sse_avx_mix\000cpu_core\000floating point\000ASSISTS.SSE_AVX_MIX. Unit: cpu_core \000event=0xc1,period=1000003,umask=0x10\000\00000\000\000"
/* offset=473122 */ "avx_insts.all\000\000floating point\000Approximate counts of AVX & AVX2 256-bit instructions, including non-arithmetic instructions, loads, and stores.  May count non-AVX instructions that employ 256-bit operations, including (but not necessarily limited to) rep string instructions that use 256-bit loads and stores for optimized performance, XSAVE* and XRSTOR*, and operations that transition the x87 FPU data registers between x87 and MMX\000event=0xc6,period=2000003,umask=0x7\000\00000\000Note that a whole rep string only counts AVX_INST.ALL once\000"
/* offset=473654 */ "baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000"
/* offset=473765 */ "baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000"
/* offset=473868 */ "baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000"
/* offset=473969 */ "baclears.all\000\000frontend\000BACLEARs asserted for any branch type\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the number of times a BACLEAR is signaled for any reason, including, but not limited to indirect branch/call,  Jcc (Jump on Conditional Code/Jump if Condition is Met) branch, unconditional branch/call, and returns\000"
/* offset=474290 */ "baclears.all\000\000frontend\000Counts the number of baclears\000event=0xe6,period=200003,umask=0x1\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.ANY event counts the number of baclears for any type of branch\000"
/* offset=474681 */ "baclears.all\000\000frontend\000Counts the number of times the front end resteers for any branch as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x1\000\00000\000\000"
/* offset=474875 */ "baclears.any\000\000frontend\000BACLEARS asserted\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000"
/* offset=474957 */ "baclears.any\000\000frontend\000Clears due to Unknown Branches\000event=0x60,period=100003,umask=0x1\000\00000\000Number of times the front-end is resteered when it finds a branch instruction in a fetch line. This is called Unknown Branch which occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000"
/* offset=475317 */ "baclears.any\000\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=475810 */ "baclears.any\000\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=476303 */ "baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000"
/* offset=476800 */ "baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000Number of front end re-steers due to BPU misprediction\000"
/* offset=477106 */ "baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000"
/* offset=477358 */ "baclears.any\000cpu_atom\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches. Unit: cpu_atom \000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=477876 */ "baclears.any\000cpu_atom\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches. Unit: cpu_atom \000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=478394 */ "baclears.any\000cpu_core\000frontend\000Clears due to Unknown Branches. Unit: cpu_core \000event=0x60,period=100003,umask=0x1\000\00000\000Number of times the front-end is resteered when it finds a branch instruction in a fetch line. This is called Unknown Branch which occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000"
/* offset=478779 */ "baclears.cond\000\000frontend\000BACLEARs asserted for conditional branch\000event=0xe6,period=200003,umask=0x10\000\00000\000Counts BACLEARS on Jcc (Jump on Conditional Code/Jump if Condition is Met) branches\000"
/* offset=478968 */ "baclears.cond\000\000frontend\000Counts the number of BACLEARS due to a conditional jump\000event=0xe6,period=200003,umask=0x10\000\00000\000\000"
/* offset=479089 */ "baclears.cond\000\000frontend\000Counts the number of JCC baclears\000event=0xe6,period=200003,umask=0x10\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.COND event counts the number of JCC (Jump on Conditional Code) baclears\000"
/* offset=479495 */ "baclears.cond\000\000frontend\000Counts the number of times the front end resteers for conditional branches as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x10\000\00000\000\000"
/* offset=479701 */ "baclears.indirect\000\000frontend\000Counts the number of BACLEARS due to an indirect branch\000event=0xe6,period=200003,umask=0x2\000\00000\000\000"
/* offset=479825 */ "baclears.return\000\000frontend\000BACLEARs asserted for return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000Counts BACLEARS on return instructions\000"
/* offset=479965 */ "baclears.return\000\000frontend\000Counts the number of BACLEARS due to a return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000\000"
/* offset=480084 */ "baclears.return\000\000frontend\000Counts the number of RETURN baclears\000event=0xe6,period=200003,umask=0x8\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.RETURN event counts the number of RETURN baclears\000"
/* offset=480472 */ "baclears.return\000\000frontend\000Counts the number of times the front end resteers for RET branches as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x8\000\00000\000\000"
/* offset=480671 */ "baclears.uncond\000\000frontend\000Counts the number of BACLEARS due to a direct, unconditional jump\000event=0xe6,period=200003,umask=0x4\000\00000\000\000"
/* offset=480803 */ "bogus_br\000\000pipeline\000Bogus branches\000event=0xe4,period=2000000,umask=0x1\000\00000\000\000"
/* offset=480878 */ "bp_de_redirect\000\000branch\000Decode Redirects\000event=0x91\000\00000\000The number of times the instruction decoder overrides the predicted target\000"
/* offset=481008 */ "bp_de_redirect\000\000branch\000Decoder Overrides Existing Branch Prediction (speculative)\000event=0x91\000\00000\000\000"
/* offset=481106 */ "bp_de_redirect\000\000branch\000Instruction decoder corrects the predicted target and resteers the branch predictor\000event=0x91\000\00000\000\000"
/* offset=481229 */ "bp_dyn_ind_pred\000\000branch\000Dynamic Indirect Predictions\000event=0x8e\000\00000\000Indirect Branch Prediction for potential multi-target branch (speculative)\000"
/* offset=481372 */ "bp_dyn_ind_pred\000\000branch\000Dynamic Indirect Predictions\000event=0x8e\000\00000\000The number of times a branch used the indirect predictor to make a prediction\000"
/* offset=481518 */ "bp_dyn_ind_pred\000\000branch\000Dynamic indirect predictions (branch used the indirect predictor to make a prediction)\000event=0x8e\000\00000\000\000"
/* offset=481645 */ "bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000"
/* offset=481705 */ "bp_l1_btb_correct\000\000branch\000L1 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8a\000\00000\000\000"
/* offset=481812 */ "bp_l1_tlb_fetch_hit.all\000\000memory\000Instruction fetches that hit in the L1 ITLB for all page sizes\000event=0x94,umask=0x07\000\00000\000\000"
/* offset=481934 */ "bp_l1_tlb_fetch_hit.if1g\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 1GB page\000event=0x94,umask=0x04\000\00000\000\000"
/* offset=482087 */ "bp_l1_tlb_fetch_hit.if1g\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instruction TLB hit (1G page size)\000event=0x94,umask=0x04\000\00000\000\000"
/* offset=482244 */ "bp_l1_tlb_fetch_hit.if1g\000\000memory\000Instruction fetches that hit in the L1 ITLB for 1G pages\000event=0x94,umask=0x04\000\00000\000\000"
/* offset=482361 */ "bp_l1_tlb_fetch_hit.if2m\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 2MB page\000event=0x94,umask=0x02\000\00000\000\000"
/* offset=482514 */ "bp_l1_tlb_fetch_hit.if2m\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instruction TLB hit (2M page size)\000event=0x94,umask=0x02\000\00000\000\000"
/* offset=482671 */ "bp_l1_tlb_fetch_hit.if2m\000\000memory\000Instruction fetches that hit in the L1 ITLB for 2M pages\000event=0x94,umask=0x02\000\00000\000\000"
/* offset=482788 */ "bp_l1_tlb_fetch_hit.if4k\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 4KB page\000event=0x94,umask=0x01\000\00000\000\000"
/* offset=482941 */ "bp_l1_tlb_fetch_hit.if4k\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instrcution TLB hit (4K or 16K page size)\000event=0x94,umask=0x01\000\00000\000\000"
/* offset=483105 */ "bp_l1_tlb_fetch_hit.if4k\000\000memory\000Instruction fetches that hit in the L1 ITLB for 4k or coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x94,umask=0x01\000\00000\000\000"
/* offset=483303 */ "bp_l1_tlb_fetch_hit\000\000branch\000The number of instruction fetches that hit in the L1 ITLB\000event=0x94,umask=0xff\000\00000\000\000"
/* offset=483416 */ "bp_l1_tlb_fetch_hit\000\000branch\000The number of instruction fetches that hit in the L1 ITLB\000event=0x94\000\00000\000\000"
/* offset=483518 */ "bp_l1_tlb_miss_l2_hit\000\000cache\000The number of instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000"
/* offset=483645 */ "bp_l1_tlb_miss_l2_miss\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs\000event=0x85\000\00000\000\000"
/* offset=483762 */ "bp_l1_tlb_miss_l2_tlb_hit\000\000cache\000L1 ITLB Miss, L2 ITLB Hit. The number of instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000"
/* offset=483920 */ "bp_l1_tlb_miss_l2_tlb_hit\000\000memory\000Instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000"
/* offset=484038 */ "bp_l1_tlb_miss_l2_tlb_miss.all\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for all page sizes\000event=0x85,umask=0x0f\000\00000\000\000"
/* offset=484214 */ "bp_l1_tlb_miss_l2_tlb_miss.coalesced_4k\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for >4K Coalesced page\000event=0x85,umask=0x08\000\00000\000\000"
/* offset=484461 */ "bp_l1_tlb_miss_l2_tlb_miss.coalesced_4k\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x85,umask=0x08\000\00000\000\000"
/* offset=484715 */ "bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 1GB page\000event=0x85,umask=0x04\000\00000\000\000"
/* offset=484887 */ "bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for 1G page\000event=0x85,umask=0x04\000\00000\000\000"
/* offset=485115 */ "bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 1G pages\000event=0x85,umask=0x04\000\00000\000\000"
/* offset=485286 */ "bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 2MB page\000event=0x85,umask=0x02\000\00000\000\000"
/* offset=485458 */ "bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for 2M page\000event=0x85,umask=0x02\000\00000\000\000"
/* offset=485686 */ "bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 2M pages\000event=0x85,umask=0x02\000\00000\000\000"
/* offset=485857 */ "bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 4KB page\000event=0x85,umask=0x01\000\00000\000\000"
/* offset=486029 */ "bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk to 4K page\000event=0x85,umask=0x01\000\00000\000\000"
/* offset=486256 */ "bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 4k pages\000event=0x85,umask=0x01\000\00000\000\000"
/* offset=486427 */ "bp_l1_tlb_miss_l2_tlb_miss\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs\000event=0x85,umask=0xff\000\00000\000\000"
/* offset=486559 */ "bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000"
/* offset=486619 */ "bp_l2_btb_correct\000\000branch\000L2 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8b\000\00000\000\000"
/* offset=486726 */ "bp_l2_btb_correct\000\000branch\000L2 branch prediction overrides existing prediction (speculative)\000event=0x8b\000\00000\000\000"
/* offset=486833 */ "bp_snp_re_sync\000\000cache\000The number of pipeline restarts caused by invalidating probes that hit on the instruction stream currently being executed. This would happen if the active instruction stream was being modified by another processor in an MP system - typically a highly unlikely event\000event=0x86\000\00000\000\000"
/* offset=487137 */ "bp_tlb_rel\000\000branch\000The number of ITLB reload requests\000event=0x99\000\00000\000\000"
/* offset=487207 */ "bp_tlb_rel\000\000cache\000The number of ITLB reload requests\000event=0x99\000\00000\000\000"
/* offset=487276 */ "bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000"
/* offset=487380 */ "bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000"
/* offset=487482 */ "bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000"
/* offset=487598 */ "br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000"
/* offset=487693 */ "br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000"
/* offset=487863 */ "br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired branch instructions\000"
/* offset=488060 */ "br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000\000"
/* offset=488171 */ "br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000Speculative and retired macro-conditional branches\000"
/* offset=488352 */ "br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired macro-conditional branch instructions\000"
/* offset=488587 */ "br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000\000"
/* offset=488718 */ "br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000Speculative and retired macro-unconditional branches excluding calls and indirects\000"
/* offset=488962 */ "br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000This event counts both taken and not taken speculative and retired macro-unconditional branch instructions, excluding calls and indirects\000"
/* offset=489261 */ "br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000\000"
/* offset=489423 */ "br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000Speculative and retired direct near calls\000"
/* offset=489591 */ "br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000This event counts both taken and not taken speculative and retired direct near calls\000"
/* offset=489802 */ "br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000\000"
/* offset=489929 */ "br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000Speculative and retired indirect branches excluding calls and returns\000"
/* offset=490163 */ "br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken speculative and retired indirect branches excluding calls and return branches\000"
/* offset=490448 */ "br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000\000"
/* offset=490613 */ "br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000This event counts both taken and not taken speculative and retired indirect branches that have a return mnemonic\000"
/* offset=490863 */ "br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000"
/* offset=491001 */ "br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000"
/* offset=491098 */ "br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000"
/* offset=491207 */ "br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000"
/* offset=491309 */ "br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000"
/* offset=491426 */ "br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000"
/* offset=491540 */ "br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000"
/* offset=491656 */ "br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000"
/* offset=491753 */ "br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000"
/* offset=491857 */ "br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000Not taken macro-conditional branches\000"
/* offset=492015 */ "br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000This event counts not taken macro-conditional branch instructions\000"
/* offset=492202 */ "br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000\000"
/* offset=492324 */ "br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000"
/* offset=492432 */ "br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000"
/* offset=492526 */ "br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000Taken speculative and retired macro-conditional branches\000"
/* offset=492721 */ "br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions\000"
/* offset=492945 */ "br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000\000"
/* offset=493084 */ "br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000"
/* offset=493361 */ "br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions excluding calls and indirect branches\000"
/* offset=493664 */ "br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000\000"
/* offset=493844 */ "br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000Taken speculative and retired direct near calls\000"
/* offset=494026 */ "br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000This event counts taken speculative and retired direct near calls\000"
/* offset=494226 */ "br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000\000"
/* offset=494361 */ "br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000Taken speculative and retired indirect branches excluding calls and returns\000"
/* offset=494609 */ "br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired indirect branches excluding calls and return branches\000"
/* offset=494883 */ "br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000\000"
/* offset=495056 */ "br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000Taken speculative and retired indirect calls\000"
/* offset=495234 */ "br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000This event counts taken speculative and retired indirect calls including both register and memory indirect\000"
/* offset=495474 */ "br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000\000"
/* offset=495608 */ "br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000Taken speculative and retired indirect branches with return mnemonic\000"
/* offset=495836 */ "br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired indirect branches that have a return mnemonic\000"
/* offset=496089 */ "br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000\000"
/* offset=496249 */ "br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009\000\00000\000Counts all (macro) branch instructions retired  Spec update: SKL091\000"
/* offset=496446 */ "br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000Branch instructions at retirement\000"
/* offset=496588 */ "br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000This event counts all (macro) branch instructions retired\000"
/* offset=496754 */ "br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000\000"
/* offset=496863 */ "br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000"
/* offset=497034 */ "br_inst_retired.all_branches\000\000pipeline\000Counts the number of branch instructions retired (Precise event)\000event=0xc4,period=200003\000\00000\000\000"
/* offset=497168 */ "br_inst_retired.all_branches\000\000pipeline\000Counts the number of branch instructions retired.. (Precise event)\000event=0xc4,period=200003\000\00000\000ALL_BRANCHES counts the number of any branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=497910 */ "br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000"
/* offset=498319 */ "br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000"
/* offset=498442 */ "br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003\000\00000\000Counts branch instructions retired for all branch types.  This is an architectural performance event (Must be precise)\000"
/* offset=498699 */ "br_inst_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000"
/* offset=499133 */ "br_inst_retired.all_branches\000cpu_core\000pipeline\000All branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000"
/* offset=499329 */ "br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000"
/* offset=499640 */ "br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000"
/* offset=499782 */ "br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS)  Spec update: BDW98 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: BDW98 (Must be precise)\000"
/* offset=500115 */ "br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000"
/* offset=500281 */ "br_inst_retired.all_taken_branches\000\000pipeline\000Counts the number of taken branch instructions retired (Must be precise)\000event=0xc4,period=200003,umask=0x80\000\00000\000ALL_TAKEN_BRANCHES counts the number of all taken branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Must be precise)\000"
/* offset=501060 */ "br_inst_retired.all_taken_branches\000\000pipeline\000Retired taken branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x80\000\00000\000Counts the number of taken branch instructions retired (Must be precise)\000"
/* offset=501294 */ "br_inst_retired.any1\000\000pipeline\000Retired branch instructions\000event=0xc4,period=2000000,umask=0xf\000\00000\000\000"
/* offset=501394 */ "br_inst_retired.any\000\000pipeline\000Retired branch instructions\000event=0xc4,period=2000000\000\00000\000\000"
/* offset=501483 */ "br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000CALL counts the number of near CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=502234 */ "br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000"
/* offset=502381 */ "br_inst_retired.call\000\000pipeline\000Retired near call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf9\000\00000\000Counts near CALL branch instructions retired (Must be precise)\000"
/* offset=502588 */ "br_inst_retired.call\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_CALL (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00010\000\000"
/* offset=502747 */ "br_inst_retired.call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_CALL (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf9\000\00010\000\000"
/* offset=502931 */ "br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000"
/* offset=503121 */ "br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000"
/* offset=503439 */ "br_inst_retired.cond\000\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000"
/* offset=503659 */ "br_inst_retired.cond\000cpu_atom\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0x7e\000\00000\000\000"
/* offset=503904 */ "br_inst_retired.cond\000cpu_core\000pipeline\000Conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000"
/* offset=504119 */ "br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000"
/* offset=504333 */ "br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000"
/* offset=504526 */ "br_inst_retired.cond_ntaken\000cpu_core\000pipeline\000Not taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000"
/* offset=504744 */ "br_inst_retired.cond_taken\000\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000"
/* offset=504924 */ "br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000"
/* offset=505131 */ "br_inst_retired.cond_taken\000cpu_atom\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfe\000\00000\000\000"
/* offset=505336 */ "br_inst_retired.cond_taken\000cpu_core\000pipeline\000Taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000"
/* offset=505568 */ "br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts the number of conditional branch instructions retired (Precise event)\000"
/* offset=505778 */ "br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired (Precise event)\000"
/* offset=505985 */ "br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000"
/* offset=506119 */ "br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000"
/* offset=506277 */ "br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000"
/* offset=506620 */ "br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000"
/* offset=506754 */ "br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000FAR counts the number of far branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=507498 */ "br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000"
/* offset=507645 */ "br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000"
/* offset=507863 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: BDW98\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: BDW98\000"
/* offset=508062 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: SKL091 (Precise event)\000"
/* offset=508295 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000"
/* offset=508475 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100003,umask=0x40\000\00000\000Number of far branches retired\000"
/* offset=508615 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000Number of far branches retired\000"
/* offset=508755 */ "br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000\000"
/* offset=508865 */ "br_inst_retired.far_branch\000\000pipeline\000Retired far branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xbf\000\00000\000Counts far branch instructions retired.  This includes far jump, far call and return, and Interrupt call and return (Must be precise)\000"
/* offset=509150 */ "br_inst_retired.far_branch\000cpu_atom\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xbf\000\00000\000\000"
/* offset=509393 */ "br_inst_retired.far_branch\000cpu_core\000pipeline\000Far branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000"
/* offset=509598 */ "br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000IND_CALL counts the number of near indirect CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=510375 */ "br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000"
/* offset=510535 */ "br_inst_retired.ind_call\000\000pipeline\000Retired near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfb\000\00000\000Counts near indirect CALL branch instructions retired (Must be precise)\000"
/* offset=510764 */ "br_inst_retired.ind_call\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT_CALL (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00010\000\000"
/* offset=510931 */ "br_inst_retired.ind_call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT_CALL (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfb\000\00010\000\000"
/* offset=511123 */ "br_inst_retired.indirect\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000"
/* offset=511305 */ "br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000"
/* offset=511574 */ "br_inst_retired.indirect\000cpu_atom\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xeb\000\00000\000\000"
/* offset=511781 */ "br_inst_retired.indirect\000cpu_core\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000"
/* offset=512075 */ "br_inst_retired.indirect_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000"
/* offset=512240 */ "br_inst_retired.indirect_call\000cpu_atom\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfb\000\00000\000\000"
/* offset=512430 */ "br_inst_retired.jcc\000\000pipeline\000Counts the number of JCC branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000JCC counts the number of conditional branch (JCC) instructions retired. Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=513180 */ "br_inst_retired.jcc\000\000pipeline\000Counts the number of branch instructions retired that were conditional jumps (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000"
/* offset=513344 */ "br_inst_retired.jcc\000\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000"
/* offset=513563 */ "br_inst_retired.jcc\000\000pipeline\000Retired conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x7e\000\00000\000Counts retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was taken and when it was not taken (Must be precise)\000"
/* offset=513900 */ "br_inst_retired.jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00010\000\000"
/* offset=514053 */ "br_inst_retired.jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0x7e\000\00010\000\000"
/* offset=514231 */ "br_inst_retired.mispred\000\000pipeline\000Retired mispredicted branch instructions (precise event) (Precise event)\000event=0xc5,period=200000\000\00000\000\000"
/* offset=514368 */ "br_inst_retired.mispred_not_taken\000\000pipeline\000Retired branch instructions that were mispredicted not-taken\000event=0xc4,period=200000,umask=0x2\000\00000\000\000"
/* offset=514513 */ "br_inst_retired.mispred_taken\000\000pipeline\000Retired branch instructions that were mispredicted taken\000event=0xc4,period=200000,umask=0x8\000\00000\000\000"
/* offset=514650 */ "br_inst_retired.near_call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000"
/* offset=514802 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000"
/* offset=515076 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000"
/* offset=515219 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000"
/* offset=515440 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired (Precise event)\000"
/* offset=515672 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000"
/* offset=515815 */ "br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000"
/* offset=515982 */ "br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000"
/* offset=516104 */ "br_inst_retired.near_call\000cpu_atom\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf9\000\00000\000\000"
/* offset=516281 */ "br_inst_retired.near_call\000cpu_core\000pipeline\000Direct and indirect near call instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000"
/* offset=516527 */ "br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000"
/* offset=516700 */ "br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000"
/* offset=516989 */ "br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000"
/* offset=517162 */ "br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3). (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000"
/* offset=517359 */ "br_inst_retired.near_return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000"
/* offset=517512 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired  Spec update: SKL091 (Precise event)\000"
/* offset=517737 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x8\000\00000\000Counts the number of near return instructions retired (Precise event)\000"
/* offset=517928 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000"
/* offset=518100 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired (Precise event)\000"
/* offset=518283 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000"
/* offset=518405 */ "br_inst_retired.near_return\000\000pipeline\000Return instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000"
/* offset=518551 */ "br_inst_retired.near_return\000cpu_atom\000pipeline\000Counts the number of near RET branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf7\000\00000\000\000"
/* offset=518729 */ "br_inst_retired.near_return\000cpu_core\000pipeline\000Return instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000"
/* offset=518926 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired  Spec update: SKL091 (Precise event)\000"
/* offset=519163 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000"
/* offset=519347 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Number of near taken branches retired (Precise event)\000"
/* offset=519528 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired (Precise event)\000"
/* offset=519723 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000"
/* offset=519851 */ "br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000"
/* offset=520003 */ "br_inst_retired.near_taken\000cpu_core\000pipeline\000Taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000"
/* offset=520212 */ "br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of branch instructions retired that were near indirect CALL or near indirect JMP (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000"
/* offset=520409 */ "br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000NON_RETURN_IND counts the number of near indirect JMP and near indirect CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=521242 */ "br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000"
/* offset=521430 */ "br_inst_retired.non_return_ind\000\000pipeline\000Retired instructions of near indirect Jmp or call (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xeb\000\00000\000Counts near indirect call or near indirect jmp branch instructions retired (Must be precise)\000"
/* offset=521696 */ "br_inst_retired.non_return_ind\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00010\000\000"
/* offset=521864 */ "br_inst_retired.non_return_ind\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xeb\000\00010\000\000"
/* offset=522057 */ "br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000"
/* offset=522269 */ "br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts the number of not taken branch instructions retired\000"
/* offset=522442 */ "br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired\000"
/* offset=522612 */ "br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000\000"
/* offset=522727 */ "br_inst_retired.pred_not_taken\000\000pipeline\000Retired branch instructions that were predicted not-taken\000event=0xc4,period=2000000,umask=0x1\000\00000\000\000"
/* offset=522867 */ "br_inst_retired.pred_taken\000\000pipeline\000Retired branch instructions that were predicted taken\000event=0xc4,period=2000000,umask=0x4\000\00000\000\000"
/* offset=522999 */ "br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000REL_CALL counts the number of near relative CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=523776 */ "br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000\000"
/* offset=523936 */ "br_inst_retired.rel_call\000\000pipeline\000Retired near relative call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfd\000\00000\000Counts near relative CALL branch instructions retired (Must be precise)\000"
/* offset=524165 */ "br_inst_retired.rel_call\000cpu_atom\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfd\000\00000\000\000"
/* offset=524350 */ "br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000RETURN counts the number of near RET branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=525103 */ "br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000"
/* offset=525251 */ "br_inst_retired.return\000\000pipeline\000Retired near return instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf7\000\00000\000Counts near return branch instructions retired (Must be precise)\000"
/* offset=525464 */ "br_inst_retired.return\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_RETURN (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00010\000\000"
/* offset=525627 */ "br_inst_retired.return\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_RETURN (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf7\000\00010\000\000"
/* offset=525815 */ "br_inst_retired.taken\000\000pipeline\000Retired taken branch instructions\000event=0xc4,period=2000000,umask=0xc\000\00000\000\000"
/* offset=525922 */ "br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of branch instructions retired that were conditional jumps and predicted taken (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000"
/* offset=526112 */ "br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000"
/* offset=526291 */ "br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of taken JCC branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000TAKEN_JCC counts the number of taken conditional branch (JCC) instructions retired. Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000"
/* offset=527065 */ "br_inst_retired.taken_jcc\000\000pipeline\000Retired conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfe\000\00000\000Counts Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were taken and does not count when the Jcc branch instruction were not taken (Must be precise)\000"
/* offset=527430 */ "br_inst_retired.taken_jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND_TAKEN (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00010\000\000"
/* offset=527595 */ "br_inst_retired.taken_jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND_TAKEN (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfe\000\00010\000\000"
/* offset=527785 */ "br_inst_type_retired.cond\000\000pipeline\000All macro conditional branch instructions\000event=0x88,period=2000000,umask=0x1\000\00000\000\000"
/* offset=527904 */ "br_inst_type_retired.cond_taken\000\000pipeline\000Only taken macro conditional branch instructions\000event=0x88,period=2000000,umask=0x41\000\00000\000\000"
/* offset=528037 */ "br_inst_type_retired.dir_call\000\000pipeline\000All non-indirect calls\000event=0x88,period=2000000,umask=0x10\000\00000\000\000"
/* offset=528142 */ "br_inst_type_retired.ind\000\000pipeline\000All indirect branches that are not calls\000event=0x88,period=2000000,umask=0x4\000\00000\000\000"
/* offset=528259 */ "br_inst_type_retired.ind_call\000\000pipeline\000All indirect calls, including both register and memory indirect\000event=0x88,period=2000000,umask=0x20\000\00000\000\000"
/* offset=528405 */ "br_inst_type_retired.ret\000\000pipeline\000All indirect branches that have a return mnemonic\000event=0x88,period=2000000,umask=0x8\000\00000\000\000"
/* offset=528531 */ "br_inst_type_retired.uncond\000\000pipeline\000All macro unconditional branch instructions, excluding calls and indirects\000event=0x88,period=2000000,umask=0x2\000\00000\000\000"
/* offset=528685 */ "br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000"
/* offset=528885 */ "br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000"
/* offset=529125 */ "br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000\000"
/* offset=529266 */ "br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000Speculative and retired mispredicted macro conditional branches\000"
/* offset=529473 */ "br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired mispredicted macro conditional branch instructions\000"
/* offset=529734 */ "br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000\000"
/* offset=529878 */ "br_misp_exec.all_direct_near_call\000\000pipeline\000Speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0xd0\000\00000\000\000"
/* offset=530018 */ "br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000Mispredicted indirect branches excluding calls and returns\000"
/* offset=530230 */ "br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken mispredicted indirect branches excluding calls and returns\000"
/* offset=530485 */ "br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000\000"
/* offset=530639 */ "br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000"
/* offset=530737 */ "br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000"
/* offset=530847 */ "br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000"
/* offset=530961 */ "br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000"
/* offset=531080 */ "br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000"
/* offset=531333 */ "br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000"
/* offset=531459 */ "br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000"
/* offset=531587 */ "br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000"
/* offset=531696 */ "br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000"
/* offset=531808 */ "br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000Not taken speculative and retired mispredicted macro conditional branches\000"
/* offset=532040 */ "br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000This event counts not taken speculative and retired mispredicted macro conditional branch instructions\000"
/* offset=532301 */ "br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000\000"
/* offset=532460 */ "br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000"
/* offset=532571 */ "br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000"
/* offset=532677 */ "br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000Taken speculative and retired mispredicted macro conditional branches\000"
/* offset=532898 */ "br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired mispredicted macro conditional branch instructions\000"
/* offset=533148 */ "br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000\000"
/* offset=533300 */ "br_misp_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0x90\000\00000\000\000"
/* offset=533448 */ "br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000"
/* offset=533722 */ "br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired mispredicted indirect branches excluding calls and returns\000"
/* offset=534014 */ "br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000\000"
/* offset=534200 */ "br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000Taken speculative and retired mispredicted indirect calls\000"
/* offset=534404 */ "br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000"
/* offset=534551 */ "br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000"
/* offset=534796 */ "br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired mispredicted indirect branches that have a return mnemonic\000"
/* offset=535066 */ "br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000\000"
/* offset=535230 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=535753 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=50021\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=536275 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path\000"
/* offset=536772 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Mispredicted branch instructions at retirement\000"
/* offset=536938 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000This event counts all mispredicted macro branch instructions retired\000"
/* offset=537126 */ "br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000\000"
/* offset=537246 */ "br_misp_retired.all_branches\000\000pipeline\000Counts the number of mispredicted branch instructions retired (Precise event)\000event=0xc5,period=200003\000\00000\000ALL_BRANCHES counts the number of any mispredicted branch instructions retired. This umask is an architecturally defined event. This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=537958 */ "br_misp_retired.all_branches\000\000pipeline\000Counts the number of mispredicted branch instructions retired (Precise event)\000event=0xc5,period=200003\000\00000\000\000"
/* offset=538105 */ "br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000"
/* offset=538916 */ "br_misp_retired.all_branches\000\000pipeline\000Mispredicted retired branch instructions (Precise Event)\000event=0xc5,period=20000,umask=0x4\000\00000\000\000"
/* offset=539051 */ "br_misp_retired.all_branches\000\000pipeline\000Retired mispredicted branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003\000\00000\000Counts mispredicted branch instructions retired including all branch types (Must be precise)\000"
/* offset=539295 */ "br_misp_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000"
/* offset=540131 */ "br_misp_retired.all_branches\000cpu_core\000pipeline\000All mispredicted branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=540679 */ "br_misp_retired.all_branches_cost\000cpu_core\000pipeline\000All mispredicted branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x44\000\00000\000\000"
/* offset=541027 */ "br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This event counts all mispredicted branch instructions retired. This is a precise event (Must be precise)\000"
/* offset=541281 */ "br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000"
/* offset=541568 */ "br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000"
/* offset=541717 */ "br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000"
/* offset=542028 */ "br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000"
/* offset=542201 */ "br_misp_retired.call\000\000pipeline\000Counts the number of mispredicted near CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf9\000\00000\000\000"
/* offset=542361 */ "br_misp_retired.cond\000\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000"
/* offset=542542 */ "br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000"
/* offset=542758 */ "br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000"
/* offset=542973 */ "br_misp_retired.cond\000cpu_atom\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0x7e\000\00000\000\000"
/* offset=543179 */ "br_misp_retired.cond\000cpu_core\000pipeline\000Mispredicted conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000"
/* offset=543420 */ "br_misp_retired.cond_cost\000cpu_core\000pipeline\000Mispredicted conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x51\000\00000\000\000"
/* offset=543768 */ "br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000"
/* offset=544064 */ "br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000"
/* offset=544359 */ "br_misp_retired.cond_ntaken\000cpu_core\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000"
/* offset=544680 */ "br_misp_retired.cond_ntaken_cost\000cpu_core\000pipeline\000Mispredicted non-taken conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x50\000\00000\000\000"
/* offset=545045 */ "br_misp_retired.cond_taken\000\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000"
/* offset=545238 */ "br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000"
/* offset=545483 */ "br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000"
/* offset=545727 */ "br_misp_retired.cond_taken\000cpu_atom\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfe\000\00000\000\000"
/* offset=545945 */ "br_misp_retired.cond_taken\000cpu_core\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000"
/* offset=546215 */ "br_misp_retired.cond_taken_cost\000cpu_core\000pipeline\000Mispredicted taken conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x41\000\00000\000\000"
/* offset=546575 */ "br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000"
/* offset=546808 */ "br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000"
/* offset=546955 */ "br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000"
/* offset=547126 */ "br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional retired branches (Precise Event)\000event=0xc5,period=20000,umask=0x1\000\00000\000\000"
/* offset=547261 */ "br_misp_retired.far_branch\000\000pipeline\000Counts the number of mispredicted far branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xbf\000\00000\000\000"
/* offset=547421 */ "br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000IND_CALL counts the number of mispredicted near indirect CALL branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=548123 */ "br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000"
/* offset=548296 */ "br_misp_retired.ind_call\000\000pipeline\000Retired mispredicted near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfb\000\00000\000Counts mispredicted near indirect CALL branch instructions retired, where the target address taken was not what the processor predicted (Must be precise)\000"
/* offset=548620 */ "br_misp_retired.ind_call\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT_CALL (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00010\000\000"
/* offset=548787 */ "br_misp_retired.ind_call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT_CALL (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfb\000\00010\000\000"
/* offset=548979 */ "br_misp_retired.indirect\000\000pipeline\000All miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000event=0xc5,period=50021,umask=0x80\000\00000\000Counts all miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000"
/* offset=549322 */ "br_misp_retired.indirect\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000"
/* offset=549517 */ "br_misp_retired.indirect\000\000pipeline\000Miss-predicted near indirect branch instructions retired (excluding returns) (Precise event)\000event=0xc5,period=100003,umask=0x80\000\00000\000Counts miss-predicted near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000"
/* offset=549816 */ "br_misp_retired.indirect\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xeb\000\00000\000\000"
/* offset=550036 */ "br_misp_retired.indirect\000cpu_core\000pipeline\000Miss-predicted near indirect branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc5,period=100003,umask=0x80\000\00000\000Counts miss-predicted near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000"
/* offset=550360 */ "br_misp_retired.indirect_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000"
/* offset=550538 */ "br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000"
/* offset=550809 */ "br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) calls, including both register and memory indirect (Precise event)\000"
/* offset=551068 */ "br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000"
/* offset=551327 */ "br_misp_retired.indirect_call\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfb\000\00000\000\000"
/* offset=551530 */ "br_misp_retired.indirect_call\000cpu_core\000pipeline\000Mispredicted indirect CALL retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000"
/* offset=551814 */ "br_misp_retired.indirect_call_cost\000cpu_core\000pipeline\000Mispredicted indirect CALL retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x42\000\00000\000\000"
/* offset=552153 */ "br_misp_retired.indirect_cost\000cpu_core\000pipeline\000Mispredicted near indirect branch instructions retired (excluding returns). This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=100003,umask=0xc0\000\00000\000\000"
/* offset=552527 */ "br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000"
/* offset=552707 */ "br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted JCC branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000JCC counts the number of mispredicted conditional branches (JCC) instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=553385 */ "br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were conditional jumps (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000"
/* offset=553562 */ "br_misp_retired.jcc\000\000pipeline\000Retired mispredicted conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0x7e\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was supposed to be taken and when it was not supposed to be taken (but the processor predicted the opposite condition) (Must be precise)\000"
/* offset=554008 */ "br_misp_retired.jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00010\000\000"
/* offset=554161 */ "br_misp_retired.jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0x7e\000\00010\000\000"
/* offset=554339 */ "br_misp_retired.near_call\000\000pipeline\000Direct and indirect mispredicted near call instructions retired (Precise event)\000event=0xc5,period=100007,umask=0x2\000\00000\000\000"
/* offset=554495 */ "br_misp_retired.near_call\000\000pipeline\000Direct and indirect mispredicted near call instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=100007,umask=0x2\000\00000\000\000"
/* offset=554675 */ "br_misp_retired.near_call\000\000pipeline\000Mispredicted direct and indirect near call instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts both taken and not taken retired mispredicted direct and indirect near calls, including both register and memory indirect (Precise event)\000"
/* offset=554975 */ "br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000"
/* offset=555097 */ "br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000"
/* offset=555365 */ "br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000"
/* offset=555535 */ "br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000"
/* offset=555802 */ "br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000"
/* offset=556063 */ "br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were taken but mispredicted (Precise event)\000"
/* offset=556324 */ "br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000"
/* offset=556494 */ "br_misp_retired.near_taken\000cpu_core\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000"
/* offset=556787 */ "br_misp_retired.near_taken_cost\000cpu_core\000pipeline\000Mispredicted taken near branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x60\000\00000\000\000"
/* offset=557140 */ "br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were near indirect CALL or near indirect JMP (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000"
/* offset=557350 */ "br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000NON_RETURN_IND counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=558108 */ "br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000"
/* offset=558309 */ "br_misp_retired.non_return_ind\000\000pipeline\000Retired mispredicted instructions of near indirect Jmp or near indirect call (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xeb\000\00000\000Counts mispredicted branch instructions retired that were near indirect call or near indirect jmp, where the target address taken was not what the processor predicted (Must be precise)\000"
/* offset=558694 */ "br_misp_retired.non_return_ind\000\000pipeline\000Retired mispredicted instructions of near indirect Jmp or near indirect call. (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xeb\000\00000\000Counts mispredicted branch instructions retired that were near indirect call or near indirect jmp, where the target address taken was not what the processor predicted (Must be precise)\000"
/* offset=559080 */ "br_misp_retired.non_return_ind\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00010\000\000"
/* offset=559248 */ "br_misp_retired.non_return_ind\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xeb\000\00010\000\000"
/* offset=559441 */ "br_misp_retired.not_taken\000\000pipeline\000Mispredicted not taken branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000\000"
/* offset=559585 */ "br_misp_retired.not_taken\000\000pipeline\000Mispredicted not taken branch instructions retired.(Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000\000"
/* offset=559752 */ "br_misp_retired.rel_call\000\000pipeline\000Counts the number of mispredicted near relative CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfd\000\00000\000\000"
/* offset=559925 */ "br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This event counts mispredicted return instructions retired (Precise event)\000"
/* offset=560165 */ "br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000"
/* offset=560471 */ "br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=50021,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000"
/* offset=560776 */ "br_misp_retired.ret\000cpu_core\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event). Unit: cpu_core \000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000"
/* offset=561107 */ "br_misp_retired.ret_cost\000cpu_core\000pipeline\000Mispredicted ret instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=100007,umask=0x48\000\00000\000\000"
/* offset=561439 */ "br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000RETURN counts the number of mispredicted near RET branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=562117 */ "br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000\000"
/* offset=562278 */ "br_misp_retired.return\000\000pipeline\000Retired mispredicted near return instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xf7\000\00000\000Counts mispredicted near RET branch instructions retired, where the return address taken was not what the processor predicted (Must be precise)\000"
/* offset=562583 */ "br_misp_retired.return\000cpu_atom\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xf7\000\00000\000\000"
/* offset=562769 */ "br_misp_retired.taken\000\000pipeline\000Mispredicted taken branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000"
/* offset=562905 */ "br_misp_retired.taken\000\000pipeline\000Mispredicted taken branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000"
/* offset=563065 */ "br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were conditional jumps and predicted taken (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000"
/* offset=563268 */ "br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000"
/* offset=563460 */ "br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted taken JCC branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000TAKEN_JCC counts the number of mispredicted taken conditional branch (JCC) instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000"
/* offset=564160 */ "br_misp_retired.taken_jcc\000\000pipeline\000Retired mispredicted conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfe\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were supposed to be taken but the processor predicted that it would not be taken (Must be precise)\000"
/* offset=564563 */ "br_misp_retired.taken_jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND_TAKEN (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00010\000\000"
/* offset=564728 */ "br_misp_retired.taken_jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND_TAKEN (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfe\000\00010\000\000"
/* offset=564918 */ "br_missp_type_retired.cond\000\000pipeline\000Mispredicted cond branch instructions retired\000event=0x89,period=200000,umask=0x1\000\00000\000\000"
/* offset=565041 */ "br_missp_type_retired.cond_taken\000\000pipeline\000Mispredicted and taken cond branch instructions retired\000event=0x89,period=200000,umask=0x11\000\00000\000\000"
/* offset=565181 */ "br_missp_type_retired.ind\000\000pipeline\000Mispredicted ind branches that are not calls\000event=0x89,period=200000,umask=0x2\000\00000\000\000"
/* offset=565302 */ "br_missp_type_retired.ind_call\000\000pipeline\000Mispredicted indirect calls, including both register and memory indirect\000event=0x89,period=200000,umask=0x8\000\00000\000\000"
/* offset=565456 */ "br_missp_type_retired.return\000\000pipeline\000Mispredicted return branches\000event=0x89,period=200000,umask=0x4\000\00000\000\000"
/* offset=565564 */ "btclear.any\000\000pipeline\000Counts the total number of BTCLEARS\000event=0xe8,period=200003\000\00000\000Counts the total number of BTCLEARS which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000"
/* offset=565760 */ "bus_bnr_drv.all_agents\000\000other\000Number of Bus Not Ready signals asserted\000event=0x61,period=200000,umask=0x20\000\00000\000\000"
/* offset=565872 */ "bus_bnr_drv.this_agent\000\000other\000Number of Bus Not Ready signals asserted\000event=0x61,period=200000\000\00000\000\000"
/* offset=565973 */ "bus_data_rcv.self\000\000other\000Bus cycles while processor receives data\000event=0x64,period=200000,umask=0x40\000\00000\000\000"
/* offset=566080 */ "bus_drdy_clocks.all_agents\000\000other\000Bus cycles when data is sent on the bus\000event=0x62,period=200000,umask=0x20\000\00000\000\000"
/* offset=566195 */ "bus_drdy_clocks.this_agent\000\000other\000Bus cycles when data is sent on the bus\000event=0x62,period=200000\000\00000\000\000"
/* offset=566299 */ "bus_hit_drv.all_agents\000\000other\000HIT signal asserted\000event=0x7a,period=200000,umask=0x20\000\00000\000\000"
/* offset=566390 */ "bus_hit_drv.this_agent\000\000other\000HIT signal asserted\000event=0x7a,period=200000\000\00000\000\000"
/* offset=566470 */ "bus_hitm_drv.all_agents\000\000other\000HITM signal asserted\000event=0x7b,period=200000,umask=0x20\000\00000\000\000"
/* offset=566563 */ "bus_hitm_drv.this_agent\000\000other\000HITM signal asserted\000event=0x7b,period=200000\000\00000\000\000"
/* offset=566645 */ "bus_io_wait.self\000\000other\000IO requests waiting in the bus queue\000event=0x7f,period=200000,umask=0x40\000\00000\000\000"
/* offset=566747 */ "bus_lock.all\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.SELF_LOCKS\000event=0x63,edge=1,period=200003\000\00010\000\000"
/* offset=566869 */ "bus_lock.block_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores\000event=0x63,period=200003,umask=0x2\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores. Counts on a per core basis\000"
/* offset=567167 */ "bus_lock.cycles_other_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.BLOCK_CYCLES\000event=0x63,period=200003,umask=0x2\000\00010\000\000"
/* offset=567309 */ "bus_lock.cycles_self_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.LOCK_CYCLES\000event=0x63,period=200003,umask=0x1\000\00010\000\000"
/* offset=567449 */ "bus_lock.lock_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued\000event=0x63,period=200003,umask=0x1\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued. Counts on a per core basis\000"
/* offset=567722 */ "bus_lock.self_locks\000\000other\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks\000event=0x63,edge=1,period=200003\000\00000\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks. Counts on a per core basis\000"
/* offset=568051 */ "bus_lock_clocks.all_agents\000\000other\000Bus cycles when a LOCK signal is asserted\000event=0x63,period=200000,umask=0xe0\000\00000\000\000"
/* offset=568168 */ "bus_lock_clocks.self\000\000other\000Bus cycles when a LOCK signal is asserted\000event=0x63,period=200000,umask=0x40\000\00000\000\000"
/* offset=568279 */ "bus_request_outstanding.all_agents\000\000other\000Outstanding cacheable data read bus requests duration\000event=0x60,period=200000,umask=0xe0\000\00000\000\000"
/* offset=568416 */ "bus_request_outstanding.self\000\000other\000Outstanding cacheable data read bus requests duration\000event=0x60,period=200000,umask=0x40\000\00000\000\000"
/* offset=568547 */ "bus_trans_any.all_agents\000\000other\000All bus transactions\000event=0x70,period=200000,umask=0xe0\000\00000\000\000"
/* offset=568641 */ "bus_trans_any.self\000\000other\000All bus transactions\000event=0x70,period=200000,umask=0x40\000\00000\000\000"
/* offset=568729 */ "bus_trans_brd.all_agents\000\000other\000Burst read bus transactions\000event=0x65,period=200000,umask=0xe0\000\00000\000\000"
/* offset=568830 */ "bus_trans_brd.self\000\000other\000Burst read bus transactions\000event=0x65,period=200000,umask=0x40\000\00000\000\000"
/* offset=568925 */ "bus_trans_burst.all_agents\000\000other\000Burst (full cache-line) bus transactions\000event=0x6e,period=200000,umask=0xe0\000\00000\000\000"
/* offset=569041 */ "bus_trans_burst.self\000\000other\000Burst (full cache-line) bus transactions\000event=0x6e,period=200000,umask=0x40\000\00000\000\000"
/* offset=569151 */ "bus_trans_def.all_agents\000\000other\000Deferred bus transactions\000event=0x6d,period=200000,umask=0xe0\000\00000\000\000"
/* offset=569250 */ "bus_trans_def.self\000\000other\000Deferred bus transactions\000event=0x6d,period=200000,umask=0x40\000\00000\000\000"
/* offset=569343 */ "bus_trans_ifetch.all_agents\000\000other\000Instruction-fetch bus transactions\000event=0x68,period=200000,umask=0xe0\000\00000\000\000"
/* offset=569454 */ "bus_trans_ifetch.self\000\000other\000Instruction-fetch bus transactions\000event=0x68,period=200000,umask=0x40\000\00000\000\000"
/* offset=569559 */ "bus_trans_inval.all_agents\000\000other\000Invalidate bus transactions\000event=0x69,period=200000,umask=0xe0\000\00000\000\000"
/* offset=569662 */ "bus_trans_inval.self\000\000other\000Invalidate bus transactions\000event=0x69,period=200000,umask=0x40\000\00000\000\000"
/* offset=569759 */ "bus_trans_io.all_agents\000\000other\000IO bus transactions\000event=0x6c,period=200000,umask=0xe0\000\00000\000\000"
/* offset=569851 */ "bus_trans_io.self\000\000other\000IO bus transactions\000event=0x6c,period=200000,umask=0x40\000\00000\000\000"
/* offset=569937 */ "bus_trans_mem.all_agents\000\000other\000Memory bus transactions\000event=0x6f,period=200000,umask=0xe0\000\00000\000\000"
/* offset=570034 */ "bus_trans_mem.self\000\000other\000Memory bus transactions\000event=0x6f,period=200000,umask=0x40\000\00000\000\000"
/* offset=570125 */ "bus_trans_p.all_agents\000\000other\000Partial bus transactions\000event=0x6b,period=200000,umask=0xe0\000\00000\000\000"
/* offset=570221 */ "bus_trans_p.self\000\000other\000Partial bus transactions\000event=0x6b,period=200000,umask=0x40\000\00000\000\000"
/* offset=570311 */ "bus_trans_pwr.all_agents\000\000other\000Partial write bus transaction\000event=0x6a,period=200000,umask=0xe0\000\00000\000\000"
/* offset=570414 */ "bus_trans_pwr.self\000\000other\000Partial write bus transaction\000event=0x6a,period=200000,umask=0x40\000\00000\000\000"
/* offset=570511 */ "bus_trans_rfo.all_agents\000\000other\000RFO bus transactions\000event=0x66,period=200000,umask=0xe0\000\00000\000\000"
/* offset=570605 */ "bus_trans_rfo.self\000\000other\000RFO bus transactions\000event=0x66,period=200000,umask=0x40\000\00000\000\000"
/* offset=570693 */ "bus_trans_wb.all_agents\000\000other\000Explicit writeback bus transactions\000event=0x67,period=200000,umask=0xe0\000\00000\000\000"
/* offset=570801 */ "bus_trans_wb.self\000\000other\000Explicit writeback bus transactions\000event=0x67,period=200000,umask=0x40\000\00000\000\000"
/* offset=570903 */ "busq_empty.self\000\000other\000Bus queue is empty\000event=0x7d,period=200000,umask=0x40\000\00000\000\000"
/* offset=570986 */ "c0_stalls.load_dram_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_DRAM_HIT\000event=0x34,period=200003,umask=0x4\000\00010\000\000"
/* offset=571133 */ "c0_stalls.load_l2_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_L2_HIT\000event=0x34,period=200003,umask=0x1\000\00010\000\000"
/* offset=571276 */ "c0_stalls.load_llc_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_LLC_HIT\000event=0x34,period=200003,umask=0x2\000\00010\000\000"
/* offset=571421 */ "cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000"
/* offset=571509 */ "cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000"
/* offset=571607 */ "core_power.license_1\000cpu_core\000other\000CORE_POWER.LICENSE_1. Unit: cpu_core \000event=0x28,period=200003,umask=0x2\000\00000\000\000"
/* offset=571721 */ "core_power.license_2\000cpu_core\000other\000CORE_POWER.LICENSE_2. Unit: cpu_core \000event=0x28,period=200003,umask=0x4\000\00000\000\000"
/* offset=571835 */ "core_power.license_3\000cpu_core\000other\000CORE_POWER.LICENSE_3. Unit: cpu_core \000event=0x28,period=200003,umask=0x8\000\00000\000\000"
/* offset=571949 */ "core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000"
/* offset=572304 */ "core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Counts Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000"
/* offset=572666 */ "core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000"
/* offset=573029 */ "core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Counts Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000"
/* offset=573399 */ "core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server michroarchtecture).  This includes high current AVX 512-bit instructions\000"
/* offset=573765 */ "core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server microarchtecture).  This includes high current AVX 512-bit instructions\000"
/* offset=574130 */ "core_power.throttle\000\000other\000Core cycles the core was throttled due to a pending power level request\000event=0x28,period=200003,umask=0x40\000\00000\000Core cycles the out-of-order engine was throttled due to a pending power level request\000"
/* offset=574356 */ "core_reject_l2q.all\000\000cache\000Counts the number of MEC requests that were not accepted into the L2Q because of any L2  queue reject condition. There is no concept of at-ret here. It might include requests due to instructions in the speculative path\000event=0x31,period=200003\000\00000\000\000"
/* offset=574632 */ "core_reject_l2q.all\000\000cache\000Counts the number of request that were not accepted into the L2Q because the L2Q is FULL\000event=0x31,period=200003\000\00000\000Counts the number of (demand and L1 prefetchers) core requests rejected by the L2Q due to a full or nearly full w condition which likely indicates back pressure from L2Q.  It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link.  The L2Q may also reject transactions  from a core to insure fairness between cores, or to delay a core?s dirty eviction when the address conflicts incoming external snoops.  (Note that L2 prefetcher requests that are dropped are not counted by this event.)\000"
/* offset=575373 */ "core_reject_l2q.all\000\000cache\000Requests rejected by the L2Q\000event=0x31,period=200003\000\00000\000Counts the number of demand and L1 prefetcher requests rejected by the L2Q due to a full or nearly full condition which likely indicates back pressure from L2Q. It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link. The L2Q may also reject transactions from a core to ensure fairness between cores, or to delay a core's dirty eviction when the address conflicts with incoming external snoops\000"
/* offset=575961 */ "core_reject_l2q.all\000\000cache\000Requests rejected by the L2Q\000event=0x31,period=200003\000\00000\000Counts the number of demand and L1 prefetcher requests rejected by the L2Q due to a full or nearly full condition which likely indicates back pressure from L2Q. It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link. The L2Q may also reject transactions from a core to insure fairness between cores, or to delay a core's dirty eviction when the address conflicts with incoming external snoops\000"
/* offset=576549 */ "core_reject_l2q.any\000\000cache\000Counts the number of core requests (demand and L1 prefetchers) rejected by the L2 queue (L2Q) due to a full condition\000event=0x31,period=200003\000\00000\000Counts the number of (demand and L1 prefetchers) core requests rejected by the L2 queue (L2Q) due to a full or nearly full condition, which likely indicates back pressure from L2Q.  It also counts requests that would have gone directly to the External Queue (XQ), but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link.  The L2Q may also reject transactions  from a core to ensure fairness between cores, or to delay a cores dirty eviction when the address conflicts incoming external snoops.  (Note that L2 prefetcher requests that are dropped are not counted by this event).  Counts on a per core basis\000"
/* offset=577373 */ "core_snoop_response.i_fwd_fe\000\000other\000Hit snoop reply with data, line invalidated\000event=0xef,period=1000003,umask=0x20\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated: removed from this core's cache, after the data is forwarded back to the requestor and indicating the data was found unmodified in the (FE) Forward or Exclusive State in this cores caches cache.  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=577840 */ "core_snoop_response.i_fwd_m\000\000other\000HitM snoop reply with data, line invalidated\000event=0xef,period=1000003,umask=0x10\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated: removed from this core's caches, after the data is forwarded back to the requestor, and indicating the data was found modified(M) in this cores caches cache (aka HitM response).  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=578291 */ "core_snoop_response.i_hit_fse\000\000other\000Hit snoop reply without sending the data, line invalidated\000event=0xef,period=1000003,umask=0x2\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated in this core's caches without being forwarded back to the requestor. The line was in Forward, Shared or Exclusive (FSE) state in this cores caches.  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=578726 */ "core_snoop_response.miss\000\000other\000Line not found snoop reply\000event=0xef,period=1000003,umask=0x1\000\00000\000Counts responses to snoops indicating that the data was not found (IHitI) in this core's caches. A single snoop response from the core counts on all hyperthreads of the Core\000"
/* offset=578999 */ "core_snoop_response.rsp_ifwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDFE\000event=0xef,period=2000003,umask=0x20\000\00000\000\000"
/* offset=579110 */ "core_snoop_response.rsp_ifwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDM\000event=0xef,period=2000003,umask=0x10\000\00000\000\000"
/* offset=579219 */ "core_snoop_response.rsp_ihitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITFSE\000event=0xef,period=2000003,umask=0x2\000\00000\000\000"
/* offset=579331 */ "core_snoop_response.rsp_ihiti\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITI\000event=0xef,period=2000003,umask=0x1\000\00000\000\000"
/* offset=579439 */ "core_snoop_response.rsp_sfwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDFE\000event=0xef,period=2000003,umask=0x40\000\00000\000\000"
/* offset=579550 */ "core_snoop_response.rsp_sfwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDM\000event=0xef,period=2000003,umask=0x8\000\00000\000\000"
/* offset=579658 */ "core_snoop_response.rsp_shitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_SHITFSE\000event=0xef,period=2000003,umask=0x4\000\00000\000\000"
/* offset=579770 */ "core_snoop_response.s_fwd_fe\000\000other\000Hit snoop reply with data, line kept in Shared state\000event=0xef,period=1000003,umask=0x40\000\00000\000Counts responses to snoops indicating the line may be kept on this core in the (S)hared state, after the data is forwarded back to the requestor, initially the data was found in the cache in the (FS) Forward or Shared state.  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=580203 */ "core_snoop_response.s_fwd_m\000\000other\000HitM snoop reply with data, line kept in Shared state\000event=0xef,period=1000003,umask=0x8\000\00000\000Counts responses to snoops indicating the line may be kept on this core in the (S)hared state, after the data is forwarded back to the requestor, initially the data was found in the cache in the (M)odified state.  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=580623 */ "core_snoop_response.s_hit_fse\000\000other\000Hit snoop reply without sending the data, line kept in Shared state\000event=0xef,period=1000003,umask=0x4\000\00000\000Counts responses to snoops indicating the line was kept on this core in the (S)hared state, and that the data was found unmodified but not forwarded back to the requestor, initially the data was found in the cache in the (FSE) Forward, Shared state or Exclusive state.  A single snoop response from the core counts on all hyperthreads of the core\000"
/* offset=581115 */ "cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000This event counts the unhalted core cycles during which the thread is in the ring 0 privileged mode\000"
/* offset=581329 */ "cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000Unhalted core cycles when the thread is in ring 0\000"
/* offset=581493 */ "cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000\000"
/* offset=581608 */ "cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000"
/* offset=581763 */ "cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000Number of intervals between processor halts while thread is in ring 0\000"
/* offset=581987 */ "cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000This event counts when there is a transition from ring 1,2 or 3 to ring0\000"
/* offset=582214 */ "cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000\000"
/* offset=582369 */ "cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000This event counts unhalted core cycles during which the thread is in rings 1, 2, or 3\000"
/* offset=582577 */ "cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000Unhalted core cycles when the thread is not in ring 0\000"
/* offset=582753 */ "cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000\000"
/* offset=582876 */ "cpu_atom\000tma_alloc_restriction\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.ALLOC_RESTRICTIONS / tma_info_core_slots\000tma_alloc_restriction > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to certain allocation restrictions. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=583180 */ "cpu_atom\000tma_backend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_BE_BOUND.ALL / tma_info_core_slots\000tma_backend_bound > 0.1\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.   The rest of these subevents count backend stalls, in cycles, due to an outstanding request which is memory bound vs core bound.   The subevents are not slot based events and therefore can not be precisely added or subtracted from the Backend_Bound_Aux subevents which are slot based\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=583997 */ "cpu_atom\000tma_backend_bound_aux\000Default;TopdownL1;tma_L1_group\000tma_backend_bound\000tma_backend_bound_aux > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that UOPS must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.  All of these subevents count backend stalls, in slots, due to a resource limitation.   These are not cycle based events and therefore can not be precisely added or subtracted from the Backend_Bound subevents which are cycle based.  These subevents are supplementary to Backend_Bound and can be used to analyze results from a resource perspective at allocation\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=584873 */ "cpu_atom\000tma_bad_speculation\000Default;TopdownL1;tma_L1_group\000(tma_info_core_slots - (cpu_atom@TOPDOWN_FE_BOUND.ALL@ + cpu_atom@TOPDOWN_BE_BOUND.ALL@ + cpu_atom@TOPDOWN_RETIRING.ALL@)) / tma_info_core_slots\000tma_bad_speculation > 0.15\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ). Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=585895 */ "cpu_atom\000tma_base\000TopdownL2;tma_L2_group;tma_retiring_group\000(cpu_atom@TOPDOWN_RETIRING.ALL@ - cpu_atom@UOPS_RETIRED.MS@) / tma_info_core_slots\000tma_base > 0.6\000Counts the number of uops that are not from the microsequencer. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=586153 */ "cpu_atom\000tma_branch_detect\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_DETECT / tma_info_core_slots\000tma_branch_detect > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Unit: cpu_atom \000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000100%\000\000\000\00000"
/* offset=586905 */ "cpu_atom\000tma_branch_mispredicts\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MISPREDICT / tma_info_core_slots\000tma_branch_mispredicts > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to branch mispredicts. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=587208 */ "cpu_atom\000tma_branch_resteer\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_RESTEER / tma_info_core_slots\000tma_branch_resteer > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=587555 */ "cpu_atom\000tma_cisc\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.CISC / tma_info_core_slots\000tma_cisc > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to the microcode sequencer (MS). Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=587820 */ "cpu_atom\000tma_core_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1\000Counts the number of cycles due to backend bound stalls that are core execution bound and not attributed to outstanding demand load or store stalls. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=588142 */ "cpu_atom\000tma_decode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.DECODE / tma_info_core_slots\000tma_decode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to decode stalls. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=588398 */ "cpu_atom\000tma_disambiguation\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.DISAMBIGUATION@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_disambiguation > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory disambiguation. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=588705 */ "cpu_atom\000tma_dram_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_DRAM_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_DRAM_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_dram_bound > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000\000100%\000\000\000\00001"
/* offset=589174 */ "cpu_atom\000tma_fast_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.FASTNUKE / tma_info_core_slots\000tma_fast_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear classified as a fast nuke due to memory ordering, memory disambiguation and memory renaming. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=589536 */ "cpu_atom\000tma_fetch_bandwidth\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_BANDWIDTH / tma_info_core_slots\000tma_fetch_bandwidth > 0.1\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=589901 */ "cpu_atom\000tma_fetch_latency\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_LATENCY / tma_info_core_slots\000tma_fetch_latency > 0.15\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=590261 */ "cpu_atom\000tma_fp_assist\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.FP_ASSIST@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_fp_assist > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to FP assists. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=590542 */ "cpu_atom\000tma_fpdiv_uops\000TopdownL3;tma_L3_group;tma_base_group\000UOPS_RETIRED.FPDIV / tma_info_core_slots\000tma_fpdiv_uops > 0.2\000Counts the number of floating point divide operations per uop. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=590756 */ "cpu_atom\000tma_frontend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_FE_BOUND.ALL / tma_info_core_slots\000tma_frontend_bound > 0.2\000Counts the number of issue slots  that were not consumed by the backend due to frontend stalls. Unit: cpu_atom \000\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=591032 */ "cpu_atom\000tma_icache_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ICACHE / tma_info_core_slots\000tma_icache_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to instruction cache misses. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=591311 */ "cpu_atom\000tma_info_core_clks\000\000cpu_atom@CPU_CLK_UNHALTED.CORE@\000\000Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591396 */ "cpu_atom\000tma_info_core_clks_p\000\000cpu_atom@CPU_CLK_UNHALTED.CORE_P@\000\000Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591485 */ "cpu_atom\000tma_info_core_cpi\000\000tma_info_core_clks / INST_RETIRED.ANY\000\000Cycles Per Instruction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591599 */ "cpu_atom\000tma_info_core_ipc\000\000INST_RETIRED.ANY / tma_info_core_clks\000\000Instructions Per Cycle. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591713 */ "cpu_atom\000tma_info_core_slots\000\0005 * tma_info_core_clks\000\000Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591790 */ "cpu_atom\000tma_info_core_upi\000\000UOPS_RETIRED.ALL / INST_RETIRED.ANY\000\000Uops Per Instruction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=591900 */ "cpu_atom\000tma_info_frontend_inst_miss_cost_dramhit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_DRAM_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in DRAM. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=592119 */ "cpu_atom\000tma_info_frontend_inst_miss_cost_l2hit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_L2_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in the L2. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=592336 */ "cpu_atom\000tma_info_frontend_inst_miss_cost_l3hit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_LLC_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in the L3. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=592554 */ "cpu_atom\000tma_info_inst_mix_branch_mispredict_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.ALL_BRANCHES\000\000Ratio of all branches which mispredict. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=592730 */ "cpu_atom\000tma_info_inst_mix_branch_mispredict_to_unknown_branch_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BACLEARS.ANY\000\000Ratio between Mispredicted branches and unknown branches. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=592926 */ "cpu_atom\000tma_info_inst_mix_fpdiv_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.FPDIV@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are FPDiv uops. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593093 */ "cpu_atom\000tma_info_inst_mix_idiv_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.IDIV@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are IDiv uops. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593257 */ "cpu_atom\000tma_info_inst_mix_ipbranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurance rate). Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593434 */ "cpu_atom\000tma_info_inst_mix_ipcall\000\000INST_RETIRED.ANY / BR_INST_RETIRED.CALL\000\000Instruction per (near) call (lower number means higher occurance rate). Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593605 */ "cpu_atom\000tma_info_inst_mix_ipfarbranch\000\000INST_RETIRED.ANY / (cpu_atom@BR_INST_RETIRED.FAR_BRANCH@ / 2)\000\000Instructions per Far Branch. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593760 */ "cpu_atom\000tma_info_inst_mix_ipload\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000\000Instructions per Load. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=593888 */ "cpu_atom\000tma_info_inst_mix_ipmisp_cond_ntaken\000\000INST_RETIRED.ANY / (cpu_atom@BR_MISP_RETIRED.COND@ - cpu_atom@BR_MISP_RETIRED.COND_TAKEN@)\000\000Instructions per retired conditional Branch Misprediction where the branch was not taken. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594140 */ "cpu_atom\000tma_info_inst_mix_ipmisp_cond_taken\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000\000Instructions per retired conditional Branch Misprediction where the branch was taken. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594342 */ "cpu_atom\000tma_info_inst_mix_ipmisp_indirect\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000\000Instructions per retired indirect call or jump Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594523 */ "cpu_atom\000tma_info_inst_mix_ipmisp_ret\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.RETURN\000\000Instructions per retired return Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594682 */ "cpu_atom\000tma_info_inst_mix_ipmispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Instructions per retired Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594842 */ "cpu_atom\000tma_info_inst_mix_ipstore\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000\000Instructions per Store. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=594973 */ "cpu_atom\000tma_info_inst_mix_microcode_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.MS@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are ucode ops. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=595140 */ "cpu_atom\000tma_info_inst_mix_x87_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.X87@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are x87 uops. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=595301 */ "cpu_atom\000tma_info_l1_bound_address_alias_blocks\000\000100 * cpu_atom@LD_BLOCKS.4K_ALIAS@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a address aliasing block. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=595511 */ "cpu_atom\000tma_info_l1_bound_load_splits\000\000100 * cpu_atom@MEM_UOPS_RETIRED.SPLIT_LOADS@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads that are splits. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=595708 */ "cpu_atom\000tma_info_l1_bound_store_fwd_blocks\000\000100 * cpu_atom@LD_BLOCKS.DATA_UNKNOWN@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a store forward or unknown store address block. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=595940 */ "cpu_atom\000tma_info_memory_cycles_per_demand_load_dram_hit\000\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_LOAD_UOPS_RETIRED.DRAM_HIT\000\000Cycle cost per DRAM hit. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596111 */ "cpu_atom\000tma_info_memory_cycles_per_demand_load_l2_hit\000\000MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_LOAD_UOPS_RETIRED.L2_HIT\000\000Cycle cost per L2 hit. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596274 */ "cpu_atom\000tma_info_memory_cycles_per_demand_load_l3_hit\000\000MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_LOAD_UOPS_RETIRED.L3_HIT\000\000Cycle cost per LLC hit. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596439 */ "cpu_atom\000tma_info_memory_memloadpki\000\0001e3 * cpu_atom@MEM_UOPS_RETIRED.ALL_LOADS@ / INST_RETIRED.ANY\000\000load ops retired per 1000 instruction. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596601 */ "cpu_atom\000tma_info_system_cpu_utilization\000\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596723 */ "cpu_atom\000tma_info_system_kernel_utilization\000Summary\000cpu_atom@CPU_CLK_UNHALTED.CORE@k / CPU_CLK_UNHALTED.CORE\000\000Fraction of cycles spent in Kernel mode. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=596897 */ "cpu_atom\000tma_info_system_turbo_utilization\000Power\000tma_info_core_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency. Unit: cpu_atom \000\000\000\000\000\00000"
/* offset=597074 */ "cpu_atom\000tma_itlb_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ITLB / tma_info_core_slots\000tma_itlb_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=597371 */ "cpu_atom\000tma_l1_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000LD_HEAD.L1_BOUND_AT_RET / tma_info_core_clks\000tma_l1_bound > 0.1\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a load block. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=597644 */ "cpu_atom\000tma_l2_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_L2_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_L2_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_l2_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 Cache. Unit: cpu_atom \000\000100%\000\000\000\00001"
/* offset=598087 */ "cpu_atom\000tma_l3_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_LLC_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_LLC_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_l3_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=598574 */ "cpu_atom\000tma_ld_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * cpu_atom@MEM_SCHEDULER_BLOCK.LD_BUF@ / MEM_SCHEDULER_BLOCK.ALL\000tma_ld_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to load buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=598902 */ "cpu_atom\000tma_machine_clears\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MACHINE_CLEARS / tma_info_core_slots\000tma_machine_clears > 0.05\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=599304 */ "cpu_atom\000tma_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.MEM_SCHEDULER / tma_info_core_slots\000tma_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=599637 */ "cpu_atom\000tma_memory_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000min(cpu_atom@TOPDOWN_BE_BOUND.ALL@ / tma_info_core_slots, cpu_atom@LD_HEAD.ANY_AT_RET@ / tma_info_core_clks + tma_store_bound)\000tma_memory_bound > 0.2\000Counts the number of cycles the core is stalled due to stores or loads. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000"
/* offset=599968 */ "cpu_atom\000tma_memory_ordering\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.MEMORY_ORDERING@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_memory_ordering > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory ordering. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=600272 */ "cpu_atom\000tma_ms_uops\000TopdownL2;tma_L2_group;tma_retiring_group\000UOPS_RETIRED.MS / tma_info_core_slots\000tma_ms_uops > 0.05\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS). Unit: cpu_atom \000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows\000100%\000\000TopdownL2\000\00000"
/* offset=600711 */ "cpu_atom\000tma_non_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.NON_MEM_SCHEDULER / tma_info_core_slots\000tma_non_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=601137 */ "cpu_atom\000tma_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.NUKE / tma_info_core_slots\000tma_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear (slow nuke). Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=601405 */ "cpu_atom\000tma_other_fb\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.OTHER / tma_info_core_slots\000tma_other_fb > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to other common frontend stalls not categorized. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=601695 */ "cpu_atom\000tma_other_l1\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.OTHER_AT_RET / tma_info_core_clks\000tma_other_l1 > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a number of other load blocks. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=601979 */ "cpu_atom\000tma_other_load_store\000TopdownL3;tma_L3_group;tma_memory_bound_group\000max(0, tma_memory_bound - (tma_store_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_dram_bound))\000tma_other_load_store > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hits in the L2, LLC, DRAM or MMIO (Non-DRAM) but could not be correctly attributed or cycles in which the load miss is waiting on a request buffer. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=602444 */ "cpu_atom\000tma_other_ret\000TopdownL3;tma_L3_group;tma_base_group\000(cpu_atom@TOPDOWN_RETIRING.ALL@ - cpu_atom@UOPS_RETIRED.MS@ - cpu_atom@UOPS_RETIRED.FPDIV@) / tma_info_core_slots\000tma_other_ret > 0.3\000Counts the number of uops retired excluding ms and fp div uops. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=602730 */ "cpu_atom\000tma_page_fault\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.PAGE_FAULT@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_page_fault > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to page faults. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=603015 */ "cpu_atom\000tma_predecode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.PREDECODE / tma_info_core_slots\000tma_predecode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to wrong predecodes. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=603283 */ "cpu_atom\000tma_register\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REGISTER / tma_info_core_slots\000tma_register > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls). Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=603596 */ "cpu_atom\000tma_reorder_buffer\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REORDER_BUFFER / tma_info_core_slots\000tma_reorder_buffer > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the reorder buffer being full (ROB stalls). Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=603901 */ "cpu_atom\000tma_resource_bound\000TopdownL2;tma_L2_group;tma_backend_bound_aux_group\000tma_backend_bound\000tma_resource_bound > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count\000100%\000\000TopdownL2\000\00000"
/* offset=604412 */ "cpu_atom\000tma_retiring\000Default;TopdownL1;tma_L1_group\000TOPDOWN_RETIRING.ALL / tma_info_core_slots\000tma_retiring > 0.75\000Counts the numer of issue slots  that result in retirement slots. Unit: cpu_atom \000\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=604647 */ "cpu_atom\000tma_rsv\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * cpu_atom@MEM_SCHEDULER_BLOCK.RSV@ / MEM_SCHEDULER_BLOCK.ALL\000tma_rsv > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to RSV full relative. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=604961 */ "cpu_atom\000tma_serialization\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.SERIALIZATION / tma_info_core_slots\000tma_serialization > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS). Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=605320 */ "cpu_atom\000tma_smc\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.SMC@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_smc > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to SMC. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=605576 */ "cpu_atom\000tma_st_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_store_bound\000tma_st_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to store buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=605838 */ "cpu_atom\000tma_stlb_hit\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.DTLB_MISS_AT_RET / tma_info_core_clks\000tma_stlb_hit > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a first level TLB miss. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=606119 */ "cpu_atom\000tma_stlb_miss\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.PGWALK_AT_RET / tma_info_core_clks\000tma_stlb_miss > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a second level TLB miss requiring a page walk. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=606422 */ "cpu_atom\000tma_store_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000tma_mem_scheduler * (cpu_atom@MEM_SCHEDULER_BLOCK.ST_BUF@ / cpu_atom@MEM_SCHEDULER_BLOCK.ALL@)\000tma_store_bound > 0.1\000Counts the number of cycles the core is stalled due to store buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=606711 */ "cpu_atom\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.ST_ADDR_AT_RET / tma_info_core_clks\000tma_store_fwd_blk > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a store forward block. Unit: cpu_atom \000\000100%\000\000\000\00000"
/* offset=606999 */ "cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000"
/* offset=607176 */ "cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000"
/* offset=607340 */ "cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000"
/* offset=607510 */ "cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000"
/* offset=607646 */ "cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000"
/* offset=607860 */ "cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000This is a fixed-frequency event programmed to general counters. It counts when the core is unhalted at 100 Mhz\000"
/* offset=608123 */ "cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000"
/* offset=608338 */ "cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000"
/* offset=608492 */ "cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000"
/* offset=608668 */ "cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000"
/* offset=608968 */ "cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000"
/* offset=609165 */ "cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=609363 */ "cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=609562 */ "cpu_clk_unhalted.bus\000\000pipeline\000Bus cycles when core is not halted\000event=0x3c,period=200000,umask=0x1\000\00000\000\000"
/* offset=609668 */ "cpu_clk_unhalted.c01\000\000pipeline\000Core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state\000event=0xec,period=2000003,umask=0x10\000\00000\000Counts core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000"
/* offset=610039 */ "cpu_clk_unhalted.c01\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x10\000\00000\000Counts core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000"
/* offset=610435 */ "cpu_clk_unhalted.c02\000\000pipeline\000Core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state\000event=0xec,period=2000003,umask=0x20\000\00000\000Counts core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000"
/* offset=610806 */ "cpu_clk_unhalted.c02\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x20\000\00000\000Counts core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000"
/* offset=611202 */ "cpu_clk_unhalted.c0_wait\000\000pipeline\000Core clocks when the thread is in the C0.1 or C0.2 or running a PAUSE in C0 ACPI state\000event=0xec,period=2000003,umask=0x70\000\00000\000Counts core clocks when the thread is in the C0.1 or C0.2 power saving optimized states (TPAUSE or UMWAIT instructions) or running the PAUSE instruction\000"
/* offset=611518 */ "cpu_clk_unhalted.c0_wait\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.1 or C0.2 or running a PAUSE in C0 ACPI state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x70\000\00000\000Counts core clocks when the thread is in the C0.1 or C0.2 power saving optimized states (TPAUSE or UMWAIT instructions) or running the PAUSE instruction\000"
/* offset=611859 */ "cpu_clk_unhalted.core\000\000pipeline\000Core cycles when core is not halted  (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1.  You cannot collect a PEBs record for this event\000"
/* offset=612341 */ "cpu_clk_unhalted.core\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=612440 */ "cpu_clk_unhalted.core\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000"
/* offset=612864 */ "cpu_clk_unhalted.core\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios.  The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. In systems with a constant core frequency, this event can give you a measurement of the elapsed time while the core was not in halt state by dividing the event count by the core frequency. This event is architecturally defined and is a designated fixed counter.  CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.CORE_P use the core frequency which may change from time to time.  CPU_CLK_UNHALTE.REF_TSC and CPU_CLK_UNHALTED.REF are not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  The fixed events are CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.REF_TSC and the programmable events are CPU_CLK_UNHALTED.CORE_P and CPU_CLK_UNHALTED.REF\000"
/* offset=614004 */ "cpu_clk_unhalted.core\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=614130 */ "cpu_clk_unhalted.core\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event). Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000"
/* offset=614579 */ "cpu_clk_unhalted.core\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000"
/* offset=614730 */ "cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000000\000\00000\000\000"
/* offset=614831 */ "cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000Core cycles when core is not halted.  This event uses a (_P)rogrammable general purpose performance counter\000"
/* offset=615039 */ "cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time\000"
/* offset=615434 */ "cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.THREAD_P]\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=615598 */ "cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000"
/* offset=616044 */ "cpu_clk_unhalted.core_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.THREAD_P]. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000"
/* offset=616233 */ "cpu_clk_unhalted.core_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000"
/* offset=616704 */ "cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000"
/* offset=617223 */ "cpu_clk_unhalted.distributed\000cpu_core\000pipeline\000Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000"
/* offset=617767 */ "cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000"
/* offset=618032 */ "cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000"
/* offset=618202 */ "cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000"
/* offset=618365 */ "cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000"
/* offset=618529 */ "cpu_clk_unhalted.one_thread_active\000cpu_core\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted. Unit: cpu_core \000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000"
/* offset=618819 */ "cpu_clk_unhalted.pause\000\000pipeline\000CPU_CLK_UNHALTED.PAUSE\000event=0xec,period=2000003,umask=0x40\000\00000\000\000"
/* offset=618917 */ "cpu_clk_unhalted.pause\000cpu_core\000pipeline\000CPU_CLK_UNHALTED.PAUSE. Unit: cpu_core \000event=0xec,period=2000003,umask=0x40\000\00000\000\000"
/* offset=619040 */ "cpu_clk_unhalted.pause_inst\000\000pipeline\000CPU_CLK_UNHALTED.PAUSE_INST\000event=0xec,cmask=1,edge=1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=619163 */ "cpu_clk_unhalted.pause_inst\000cpu_core\000pipeline\000CPU_CLK_UNHALTED.PAUSE_INST. Unit: cpu_core \000event=0xec,cmask=1,edge=1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=619311 */ "cpu_clk_unhalted.ref\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x0,umask=0x03,period=2000003\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000"
/* offset=619772 */ "cpu_clk_unhalted.ref\000\000pipeline\000Counts the number of unhalted reference clock cycles\000event=0x0,umask=0x03,period=2000003\000\00000\000\000"
/* offset=619897 */ "cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000Reference cycles when core is not halted.  This event uses a (_P)rogrammable general purpose performance counter\000"
/* offset=620122 */ "cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000Reference cycles when core is not halted.  This event uses a programmable general purpose performance counter\000"
/* offset=620344 */ "cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000This event counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time. This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time\000"
/* offset=620801 */ "cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000\000"
/* offset=620914 */ "cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000"
/* offset=621045 */ "cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000"
/* offset=621589 */ "cpu_clk_unhalted.ref_distributed\000cpu_core\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000"
/* offset=622158 */ "cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000"
/* offset=622318 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000"
/* offset=622795 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios.  The core frequency may change from time. This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  Divide this event count by core frequency to determine the elapsed time while the core was not in halt state.  Divide this event count by core frequency to determine the elapsed time while the core was not in halt state.  This event is architecturally defined and is a designated fixed counter.  CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.CORE_P use the core frequency which may change from time to time.  CPU_CLK_UNHALTE.REF_TSC and CPU_CLK_UNHALTED.REF are not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  The fixed events are CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.REF_TSC and the programmable events are CPU_CLK_UNHALTED.CORE_P and CPU_CLK_UNHALTED.REF\000"
/* offset=624035 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000\000"
/* offset=624176 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when core is not halted  (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction.  In mobile systems the core frequency may change from time.  This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  This event uses fixed counter 2.  You cannot collect a PEBs record for this event\000"
/* offset=624724 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=626122 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=627594 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=629105 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. \nNote: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  This event is clocked by base clock (100 Mhz) on Sandy Bridge. The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=630691 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000"
/* offset=631463 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state\000"
/* offset=632010 */ "cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000\000"
/* offset=632135 */ "cpu_clk_unhalted.ref_tsc\000cpu_atom\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event). Unit: cpu_atom \000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000"
/* offset=632637 */ "cpu_clk_unhalted.ref_tsc\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles. Unit: cpu_atom \000event=0,period=2000003,umask=0x3\000\00000\000\000"
/* offset=632803 */ "cpu_clk_unhalted.ref_tsc\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=634226 */ "cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000"
/* offset=634728 */ "cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=636170 */ "cpu_clk_unhalted.ref_tsc_p\000cpu_atom\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. Unit: cpu_atom \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000"
/* offset=636697 */ "cpu_clk_unhalted.ref_tsc_p\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000"
/* offset=638164 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000Counts core crystal clock cycles when the thread is unhalted\000"
/* offset=638353 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000"
/* offset=638482 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000"
/* offset=638697 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000"
/* offset=638913 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000"
/* offset=639130 */ "cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000"
/* offset=639277 */ "cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000"
/* offset=639446 */ "cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000"
/* offset=639739 */ "cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000"
/* offset=639929 */ "cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=640120 */ "cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=640312 */ "cpu_clk_unhalted.ring0_trans\000\000pipeline\000Counts when there is a transition from ring 1, 2 or 3 to ring 0\000event=0x3c,cmask=1,edge=1,period=100007\000\00000\000Counts when the Current Privilege Level (CPL) transitions from ring 1, 2 or 3 to ring 0 (Kernel)\000"
/* offset=640556 */ "cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000"
/* offset=641300 */ "cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000"
/* offset=642083 */ "cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000"
/* offset=642877 */ "cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000"
/* offset=643233 */ "cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=643347 */ "cpu_clk_unhalted.thread\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1\000"
/* offset=643775 */ "cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=643889 */ "cpu_clk_unhalted.thread\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter\000"
/* offset=644590 */ "cpu_clk_unhalted.thread\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=644718 */ "cpu_clk_unhalted.thread\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event). Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1\000"
/* offset=645171 */ "cpu_clk_unhalted.thread\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000"
/* offset=645324 */ "cpu_clk_unhalted.thread\000cpu_core\000pipeline\000Core cycles when the thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000"
/* offset=646093 */ "cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000"
/* offset=646325 */ "cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000"
/* offset=646479 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.CORE_P]\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=646643 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000"
/* offset=647092 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=647207 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000"
/* offset=647330 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000"
/* offset=647675 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000"
/* offset=648143 */ "cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000"
/* offset=648257 */ "cpu_clk_unhalted.thread_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.CORE_P]. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000"
/* offset=648446 */ "cpu_clk_unhalted.thread_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000"
/* offset=648920 */ "cpu_clk_unhalted.thread_p\000cpu_core\000pipeline\000Thread cycles when thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000"
/* offset=649413 */ "cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000"
/* offset=649647 */ "cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000"
/* offset=649803 */ "cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000"
/* offset=649905 */ "cpu_core\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(cpu_core@UOPS_DISPATCHED.PORT_0@ + cpu_core@UOPS_DISPATCHED.PORT_1@ + cpu_core@UOPS_DISPATCHED.PORT_5_11@ + cpu_core@UOPS_DISPATCHED.PORT_6@) / (5 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=650325 */ "cpu_core\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * cpu_core@ASSISTS.ANY\\,umask\\=0x1B@ / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Unit: cpu_core \000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000"
/* offset=651409 */ "cpu_core\000tma_avx_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00063 * cpu_core@ASSISTS.SSE_AVX_MIX@ / tma_info_thread_slots\000tma_avx_assists > 0.1\000This metric estimates fraction of slots the CPU retired uops as a result of handing SSE to AVX* or AVX* to SSE transition Assists. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=651718 */ "cpu_core\000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-be\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Unit: cpu_core \000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=652820 */ "cpu_core\000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations. Unit: cpu_core \000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=653555 */ "cpu_core\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000cpu_core@topdown\\-br\\-mispredict@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction. Unit: cpu_core \000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000"
/* offset=654495 */ "cpu_core\000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000"
/* offset=655276 */ "cpu_core\000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. Unit: cpu_core \000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources. Sample with: FRONTEND_RETIRED.MS_FLOWS\000100%\000\000\000\00000"
/* offset=656059 */ "cpu_core\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - tma_branch_mispredicts / tma_bad_speculation) * cpu_core@INT_MISC.CLEAR_RESTEER_CYCLES@ / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000"
/* offset=656795 */ "cpu_core\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(25 * tma_info_system_average_frequency * (cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD@ * (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ / (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ + cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD@))) + 24 * tma_info_system_average_frequency * cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS@) * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Unit: cpu_core \000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=658185 */ "cpu_core\000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck. Unit: cpu_core \000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000"
/* offset=658959 */ "cpu_core\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00024 * tma_info_system_average_frequency * (cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD@ + cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD@ * (1 - cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ / (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ + cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD@))) * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Unit: cpu_core \000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001"
/* offset=660187 */ "cpu_core\000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu_core@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu_core@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Unit: cpu_core \000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000"
/* offset=660777 */ "cpu_core\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIV_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active. Unit: cpu_core \000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000"
/* offset=661349 */ "cpu_core\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_core@MEMORY_ACTIVITY.STALLS_L3_MISS@ / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Unit: cpu_core \000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001"
/* offset=661910 */ "cpu_core\000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@IDQ.DSB_CYCLES_ANY@ - cpu_core@IDQ.DSB_CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline. Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000"
/* offset=662588 */ "cpu_core\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000"
/* offset=663596 */ "cpu_core\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu_core@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + cpu_core@DTLB_LOAD_MISSES.WALK_ACTIVE@, max(cpu_core@CYCLE_ACTIVITY.CYCLES_MEM_ANY@ - cpu_core@MEMORY_ACTIVITY.CYCLES_L1D_MISS@, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. Unit: cpu_core \000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=664822 */ "cpu_core\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu_core@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + cpu_core@DTLB_STORE_MISSES.WALK_ACTIVE@) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses. Unit: cpu_core \000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000"
/* offset=665796 */ "cpu_core\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00028 * tma_info_system_average_frequency * cpu_core@OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM@ / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. Unit: cpu_core \000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000"
/* offset=666626 */ "cpu_core\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. Unit: cpu_core \000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000"
/* offset=667489 */ "cpu_core\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues. Unit: cpu_core \000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000"
/* offset=668462 */ "cpu_core\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000cpu_core@topdown\\-fetch\\-lat@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) - cpu_core@INT_MISC.UOP_DROPPING@ / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues. Unit: cpu_core \000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000"
/* offset=669328 */ "cpu_core\000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000max(0, tma_heavy_operations - tma_microcode_sequencer)\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000"
/* offset=669981 */ "cpu_core\000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Unit: cpu_core \000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001"
/* offset=670507 */ "cpu_core\000tma_fp_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00030 * cpu_core@ASSISTS.FP@ / tma_info_thread_slots\000tma_fp_assists > 0.1\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. Unit: cpu_core \000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. FP Assist may apply when working with very small floating point values (so-called Denormals)\000100%\000\000\000\00000"
/* offset=671008 */ "cpu_core\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. Unit: cpu_core \000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=671738 */ "cpu_core\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. Unit: cpu_core \000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=672545 */ "cpu_core\000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. Unit: cpu_core \000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=673368 */ "cpu_core\000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. Unit: cpu_core \000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=674191 */ "cpu_core\000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-fe\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) - cpu_core@INT_MISC.UOP_DROPPING@ / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Unit: cpu_core \000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=675472 */ "cpu_core\000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@INST_RETIRED.MACRO_FUSED@ / (tma_retiring * tma_info_thread_slots)\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000"
/* offset=676121 */ "cpu_core\000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000cpu_core@topdown\\-heavy\\-ops@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences. Sample with: UOPS_RETIRED.HEAVY\000100%\000\000TopdownL2\000\00000"
/* offset=676887 */ "cpu_core\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_DATA.STALLS / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000"
/* offset=677394 */ "cpu_core\000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Unit: cpu_core \000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001"
/* offset=678070 */ "cpu_core\000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=678364 */ "cpu_core\000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=678651 */ "cpu_core\000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000cpu_core@BR_MISP_RETIRED.INDIRECT_CALL\\,umask\\=0x80@ / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=678971 */ "cpu_core\000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=679226 */ "cpu_core\000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=679519 */ "cpu_core\000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts. Unit: cpu_core \000\000\000\000\000\00001"
/* offset=679864 */ "cpu_core\000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Unit: cpu_core \000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001"
/* offset=680514 */ "cpu_core\000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Unit: cpu_core \000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000"
/* offset=680982 */ "cpu_core\000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Unit: cpu_core \000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001"
/* offset=681638 */ "cpu_core\000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((cpu_core@BR_INST_RETIRED.COND@ + 3 * cpu_core@BR_INST_RETIRED.NEAR_CALL@ + (cpu_core@BR_INST_RETIRED.NEAR_TAKEN@ - cpu_core@BR_INST_RETIRED.COND_TAKEN@ - 2 * cpu_core@BR_INST_RETIRED.NEAR_CALL@)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Unit: cpu_core \000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000"
/* offset=682261 */ "cpu_core\000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks. Unit: cpu_core \000\000\000\000\000\00001"
/* offset=682687 */ "cpu_core\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Unit: cpu_core \000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=683646 */ "cpu_core\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Unit: cpu_core \000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001"
/* offset=684501 */ "cpu_core\000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Unit: cpu_core \000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001"
/* offset=685371 */ "cpu_core\000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks. Unit: cpu_core \000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001"
/* offset=685943 */ "cpu_core\000tma_info_branches_callret\000Bad;Branches\000(cpu_core@BR_INST_RETIRED.NEAR_CALL@ + cpu_core@BR_INST_RETIRED.NEAR_RETURN@) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=686167 */ "cpu_core\000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=686364 */ "cpu_core\000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=686556 */ "cpu_core\000tma_info_branches_jump\000Bad;Branches\000(cpu_core@BR_INST_RETIRED.NEAR_TAKEN@ - cpu_core@BR_INST_RETIRED.COND_TAKEN@ - 2 * cpu_core@BR_INST_RETIRED.NEAR_CALL@) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=686848 */ "cpu_core\000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=687144 */ "cpu_core\000tma_info_core_core_clks\000SMT\000cpu_core@CPU_CLK_UNHALTED.DISTRIBUTED@\000\000Core actual clocks when any Logical Processor is active on the Physical Core. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=687322 */ "cpu_core\000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=687512 */ "cpu_core\000tma_info_core_flopc\000Flops;Ret\000(cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle. Unit: cpu_core \000\000\000\000\000\00001"
/* offset=687960 */ "cpu_core\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu_core@FP_ARITH_DISPATCHED.PORT_0@ + cpu_core@FP_ARITH_DISPATCHED.PORT_1@ + cpu_core@FP_ARITH_DISPATCHED.PORT_5@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Unit: cpu_core \000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001"
/* offset=688573 */ "cpu_core\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu_core@UOPS_EXECUTED.CORE_CYCLES_GE_1@ / 2 if #SMT_on else cpu_core@UOPS_EXECUTED.CORE_CYCLES_GE_1@)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=688880 */ "cpu_core\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / cpu_core@UOPS_ISSUED.ANY@\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 6 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Unit: cpu_core \000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000"
/* offset=689348 */ "cpu_core\000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu_core@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=689639 */ "cpu_core\000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu_core@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=689835 */ "cpu_core\000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_DATA.STALLS / cpu_core@ICACHE_DATA.STALLS\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=690041 */ "cpu_core\000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=690292 */ "cpu_core\000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=690523 */ "cpu_core\000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * cpu_core@FRONTEND_RETIRED.L2_MISS@ / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=690711 */ "cpu_core\000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * cpu_core@L2_RQSTS.CODE_RD_MISS@ / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=690907 */ "cpu_core\000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / cpu_core@UOPS_ISSUED.ANY@\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=691094 */ "cpu_core\000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=691269 */ "cpu_core\000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000cpu_core@INST_RETIRED.ANY@\000\000Total number of retired Instructions. Unit: cpu_core \000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000"
/* offset=691498 */ "cpu_core\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000"
/* offset=691991 */ "cpu_core\000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=692491 */ "cpu_core\000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=692985 */ "cpu_core\000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=693437 */ "cpu_core\000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000"
/* offset=693889 */ "cpu_core\000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=694117 */ "cpu_core\000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=694341 */ "cpu_core\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=694875 */ "cpu_core\000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=695082 */ "cpu_core\000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=695293 */ "cpu_core\000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu_core@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=695584 */ "cpu_core\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 13\000Instruction per taken branch. Unit: cpu_core \000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000"
/* offset=695945 */ "cpu_core\000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@L1D.REPLACEMENT@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=696153 */ "cpu_core\000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@L2_LINES_IN.ALL@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=696355 */ "cpu_core\000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * cpu_core@OFFCORE_REQUESTS.ALL_REQUESTS@ / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=696583 */ "cpu_core\000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@LONGEST_LAT_CACHE.MISS@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=696792 */ "cpu_core\000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=697053 */ "cpu_core\000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=697253 */ "cpu_core\000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.ALL_DEMAND_DATA_RD@ / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=697481 */ "cpu_core\000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (cpu_core@L2_RQSTS.REFERENCES@ - cpu_core@L2_RQSTS.MISS@) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=697722 */ "cpu_core\000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.DEMAND_DATA_RD_HIT@ / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=697944 */ "cpu_core\000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L2_MISS@ / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=698152 */ "cpu_core\000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * cpu_core@L2_RQSTS.MISS@ / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=698383 */ "cpu_core\000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.DEMAND_DATA_RD_MISS@ / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=698622 */ "cpu_core\000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L3_MISS@ / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=698822 */ "cpu_core\000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / MEM_LOAD_COMPLETED.L1_MISS_ANY\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=699062 */ "cpu_core\000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Unit: cpu_core \000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000"
/* offset=699419 */ "cpu_core\000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=699637 */ "cpu_core\000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=699856 */ "cpu_core\000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu_core@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=700094 */ "cpu_core\000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.L3_MISS_DEMAND_DATA_RD / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=700329 */ "cpu_core\000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=700530 */ "cpu_core\000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=700724 */ "cpu_core\000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=700932 */ "cpu_core\000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=701126 */ "cpu_core\000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * cpu_core@ITLB_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=701391 */ "cpu_core\000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * cpu_core@DTLB_LOAD_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=701666 */ "cpu_core\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(cpu_core@ITLB_MISSES.WALK_PENDING@ + cpu_core@DTLB_LOAD_MISSES.WALK_PENDING@ + cpu_core@DTLB_STORE_MISSES.WALK_PENDING@) / (4 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=702065 */ "cpu_core\000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * cpu_core@DTLB_STORE_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=702343 */ "cpu_core\000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu_core@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=702593 */ "cpu_core\000tma_info_pipeline_ipassist\000Pipeline;Ret;Retire\000INST_RETIRED.ANY / cpu_core@ASSISTS.ANY\\,umask\\=0x1B@\000tma_info_pipeline_ipassist < 100e3\000Instructions per a microcode Assist invocation. Unit: cpu_core \000Instructions per a microcode Assist invocation. See Assists tree node for details (lower number means higher occurrence rate)\000\000\000\000\00000"
/* offset=702934 */ "cpu_core\000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu_core@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired. Unit: cpu_core \000\000\000\000\000\00001"
/* offset=703160 */ "cpu_core\000tma_info_pipeline_strings_cycles\000Pipeline;Ret\000INST_RETIRED.REP_ITERATION / cpu_core@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000tma_info_pipeline_strings_cycles > 0.1\000Estimated fraction of retirement-cycles dealing with repeat instructions. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=703419 */ "cpu_core\000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=703620 */ "cpu_core\000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=703753 */ "cpu_core\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Unit: cpu_core \000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000"
/* offset=704178 */ "cpu_core\000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second. Unit: cpu_core \000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000"
/* offset=704795 */ "cpu_core\000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / cpu_core@BR_INST_RETIRED.FAR_BRANCH@u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=705139 */ "cpu_core\000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / cpu_core@INST_RETIRED.ANY_P@k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=705328 */ "cpu_core\000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=705561 */ "cpu_core\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / cpu_core@UNC_ARB_DAT_OCCUPANCY.RD\\,cmask\\=1@\000\000Average number of parallel data read requests to external memory. Unit: cpu_core \000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000"
/* offset=705896 */ "cpu_core\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\000(UNC_ARB_TRK_OCCUPANCY.RD + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.RD\000\000Average latency of data read request to external memory (in nanoseconds). Unit: cpu_core \000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000"
/* offset=706286 */ "cpu_core\000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=706516 */ "cpu_core\000tma_info_system_smt_2t_utilization\000SMT\000(1 - cpu_core@CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE@ / cpu_core@CPU_CLK_UNHALTED.REF_DISTRIBUTED@ if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=706773 */ "cpu_core\000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=706916 */ "cpu_core\000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=707095 */ "cpu_core\000tma_info_thread_clks\000Pipeline\000cpu_core@CPU_CLK_UNHALTED.THREAD@\000\000Per-Logical Processor actual clocks when the Logical Processor is active. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=707266 */ "cpu_core\000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=707404 */ "cpu_core\000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops. Unit: cpu_core \000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000"
/* offset=707708 */ "cpu_core\000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=707861 */ "cpu_core\000tma_info_thread_slots\000TmaL1;tma_L1_group\000cpu_core@TOPDOWN.SLOTS@\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward). Unit: cpu_core \000\000\000\000\000\00000"
/* offset=708050 */ "cpu_core\000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (cpu_core@TOPDOWN.SLOTS@ / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=708288 */ "cpu_core\000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=708469 */ "cpu_core\000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 9\000Instruction per taken branch. Unit: cpu_core \000\000\000\000\000\00000"
/* offset=708664 */ "cpu_core\000tma_int_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_int_vector_128b + tma_int_vector_256b + tma_shuffles\000tma_int_operations > 0.1 & tma_light_operations > 0.6\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Unit: cpu_core \000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Vector/Matrix Int operations and shuffles are counted. Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain\000100%\000\000\000\00000"
/* offset=709231 */ "cpu_core\000tma_int_vector_128b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(cpu_core@INT_VEC_RETIRED.ADD_128@ + cpu_core@INT_VEC_RETIRED.VNNI_128@) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_128b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Unit: cpu_core \000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=710044 */ "cpu_core\000tma_int_vector_256b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(cpu_core@INT_VEC_RETIRED.ADD_256@ + cpu_core@INT_VEC_RETIRED.MUL_256@ + cpu_core@INT_VEC_RETIRED.VNNI_256@) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_256b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Unit: cpu_core \000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=710893 */ "cpu_core\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_TAG.STALLS / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000"
/* offset=711411 */ "cpu_core\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L1D_MISS@) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache. Unit: cpu_core \000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000"
/* offset=712541 */ "cpu_core\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(cpu_core@MEMORY_ACTIVITY.STALLS_L1D_MISS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L2_MISS@) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads. Unit: cpu_core \000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001"
/* offset=713163 */ "cpu_core\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(cpu_core@MEMORY_ACTIVITY.STALLS_L2_MISS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L3_MISS@) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core. Unit: cpu_core \000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000"
/* offset=713850 */ "cpu_core\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0009 * tma_info_system_average_frequency * cpu_core@MEM_LOAD_RETIRED.L3_HIT@ * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited). Unit: cpu_core \000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000"
/* offset=714867 */ "cpu_core\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DECODE.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Unit: cpu_core \000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000"
/* offset=715547 */ "cpu_core\000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000"
/* offset=716461 */ "cpu_core\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3_10 / (3 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00000"
/* offset=716914 */ "cpu_core\000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB). Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=717338 */ "cpu_core\000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=717765 */ "cpu_core\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ - cpu_core@L2_RQSTS.ALL_RFO@) + cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@ * (10 * cpu_core@L2_RQSTS.RFO_HIT@ + min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO@))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Unit: cpu_core \000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001"
/* offset=718717 */ "cpu_core\000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@LSD.CYCLES_ACTIVE@ - cpu_core@LSD.CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit. Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000"
/* offset=719463 */ "cpu_core\000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears. Unit: cpu_core \000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000"
/* offset=720395 */ "cpu_core\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM). Unit: cpu_core \000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000"
/* offset=721571 */ "cpu_core\000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD@) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM). Unit: cpu_core \000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000"
/* offset=722383 */ "cpu_core\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000cpu_core@topdown\\-mem\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck. Unit: cpu_core \000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000"
/* offset=723331 */ "cpu_core\000tma_memory_fence\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00013 * cpu_core@MISC2_RETIRED.LFENCE@ / tma_info_thread_clks\000tma_memory_fence > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to LFENCE Instructions. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=723763 */ "cpu_core\000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@MEM_UOP_RETIRED.ANY@ / (tma_retiring * tma_info_thread_slots)\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses. Unit: cpu_core \000\000100%\000\000\000\00001"
/* offset=724160 */ "cpu_core\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.MS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit. Unit: cpu_core \000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000"
/* offset=724989 */ "cpu_core\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000tma_branch_mispredicts / tma_bad_speculation * cpu_core@INT_MISC.CLEAR_RESTEER_CYCLES@ / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000"
/* offset=725808 */ "cpu_core\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@IDQ.MITE_CYCLES_ANY@ - cpu_core@IDQ.MITE_CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000"
/* offset=726635 */ "cpu_core\000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000160 * cpu_core@ASSISTS.SSE_AVX_MIX@ / tma_info_thread_clks\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Unit: cpu_core \000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=727182 */ "cpu_core\000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * cpu_core@UOPS_RETIRED.MS\\,cmask\\=1\\,edge@ / (tma_retiring * tma_info_thread_slots / cpu_core@UOPS_ISSUED.ANY@) / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Unit: cpu_core \000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: FRONTEND_RETIRED.MS_FLOWS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000"
/* offset=728541 */ "cpu_core\000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (cpu_core@BR_INST_RETIRED.ALL_BRANCHES@ - cpu_core@INST_RETIRED.MACRO_FUSED@) / (tma_retiring * tma_info_thread_slots)\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000"
/* offset=729212 */ "cpu_core\000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@INST_RETIRED.NOP@ / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000"
/* offset=729797 */ "cpu_core\000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_int_operations + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. Unit: cpu_core \000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001"
/* offset=730436 */ "cpu_core\000tma_page_faults\000TopdownL5;tma_L5_group;tma_assists_group\00099 * cpu_core@ASSISTS.PAGE_FAULT@ / tma_info_thread_slots\000tma_page_faults > 0.05\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. Unit: cpu_core \000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. A Page Fault may apply on first application access to a memory page. Note operating system handling of page faults accounts for the majority of its cost\000100%\000\000\000\00000"
/* offset=730972 */ "cpu_core\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=731655 */ "cpu_core\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=732262 */ "cpu_core\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000"
/* offset=732933 */ "cpu_core\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu_core@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@) + (cpu_core@EXE_ACTIVITY.1_PORTS_UTIL@ + tma_retiring * cpu_core@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@)) / tma_info_thread_clks if cpu_core@ARITH.DIV_ACTIVE@ < cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@ else (cpu_core@EXE_ACTIVITY.1_PORTS_UTIL@ + tma_retiring * cpu_core@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related). Unit: cpu_core \000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000"
/* offset=734284 */ "cpu_core\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu_core@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000"
/* offset=735096 */ "cpu_core\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000"
/* offset=736233 */ "cpu_core\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000"
/* offset=737276 */ "cpu_core\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000"
/* offset=737958 */ "cpu_core\000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-retiring@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Unit: cpu_core \000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000"
/* offset=739062 */ "cpu_core\000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Unit: cpu_core \000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000"
/* offset=739789 */ "cpu_core\000tma_shuffles\000HPC;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group\000INT_VEC_RETIRED.SHUFFLES / (tma_retiring * tma_info_thread_slots)\000tma_shuffles > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents Shuffle (cross \"vector lane\" data transfers) uops fraction the CPU has retired. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=740145 */ "cpu_core\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000CPU_CLK_UNHALTED.PAUSE / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: CPU_CLK_UNHALTED.PAUSE_INST\000100%\000\000\000\00000"
/* offset=740688 */ "cpu_core\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu_core@LD_BLOCKS.NO_SR@ / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Unit: cpu_core \000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000"
/* offset=741262 */ "cpu_core\000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses. Unit: cpu_core \000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000"
/* offset=741780 */ "cpu_core\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(cpu_core@XQ.FULL_CYCLES@ + cpu_core@L1D_PEND_MISS.L2_STALLS@) / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Unit: cpu_core \000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000"
/* offset=742526 */ "cpu_core\000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Unit: cpu_core \000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000"
/* offset=743299 */ "cpu_core\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * cpu_core@LD_BLOCKS.STORE_FORWARD@ / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. Unit: cpu_core \000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000"
/* offset=744286 */ "cpu_core\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(cpu_core@MEM_STORE_RETIRED.L2_HIT@ * 10 * (1 - cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@) + (1 - cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@) * min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO@)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Unit: cpu_core \000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000"
/* offset=745288 */ "cpu_core\000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(cpu_core@UOPS_DISPATCHED.PORT_4_9@ + cpu_core@UOPS_DISPATCHED.PORT_7_8@) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000"
/* offset=745788 */ "cpu_core\000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB). Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=746202 */ "cpu_core\000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk. Unit: cpu_core \000\000100%\000\000\000\00000"
/* offset=746623 */ "cpu_core\000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * cpu_core@OCR.STREAMING_WR.ANY_RESPONSE@ / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Unit: cpu_core \000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000"
/* offset=747513 */ "cpu_core\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000INT_MISC.UNKNOWN_BRANCH_CYCLES / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000"
/* offset=748190 */ "cpu_core\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * cpu_core@UOPS_EXECUTED.X87@ / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage. Unit: cpu_core \000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000"
/* offset=748732 */ "cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000"
/* offset=748876 */ "cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000"
/* offset=749020 */ "cycle_activity.cycles_l1d_miss\000cpu_core\000pipeline\000Cycles while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000"
/* offset=749189 */ "cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request missing the L1 data cache\000"
/* offset=749439 */ "cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 cache miss loads. Set AnyThread to count per core\000"
/* offset=749644 */ "cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 data cache miss loads. Set Cmask=8 to count cycle\000"
/* offset=749849 */ "cycle_activity.cycles_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread, increment by 1. Note this is in DCU and connected to Umask 1. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=750161 */ "cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000"
/* offset=750304 */ "cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=750447 */ "cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss load* is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=750584 */ "cycle_activity.cycles_l2_miss\000cpu_core\000pipeline\000Cycles while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000"
/* offset=750752 */ "cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Counts number of cycles the CPU has at least one pending  demand* load request missing the L2 cache\000"
/* offset=750997 */ "cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads  Spec update: HSD78, HSM63, HSM80\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set Cmask=2 to count cycle  Spec update: HSD78, HSM63, HSM80\000"
/* offset=751258 */ "cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set AnyThread to count per core\000"
/* offset=751456 */ "cycle_activity.cycles_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=751759 */ "cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=1000003,umask=0x2\000\00000\000\000"
/* offset=751900 */ "cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=752041 */ "cycle_activity.cycles_l3_miss\000cpu_core\000memory\000Cycles while L3 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=2,period=1000003,umask=0x2\000\00000\000\000"
/* offset=752207 */ "cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request (that is cycles with non-completed load waiting for its data from memory subsystem)\000"
/* offset=752515 */ "cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set AnyThread to count per core\000"
/* offset=752706 */ "cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set Cmask=2 to count cycle\000"
/* offset=752892 */ "cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000"
/* offset=753037 */ "cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=2000003,umask=0x10\000\00000\000\000"
/* offset=753182 */ "cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=753325 */ "cycle_activity.cycles_mem_any\000cpu_core\000pipeline\000Cycles while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000"
/* offset=753495 */ "cycle_activity.cycles_no_dispatch\000\000pipeline\000Each cycle there was no dispatch for this thread, increment by 1. Note this is connect to Umask 2. No dispatch can be deduced from the UOPS_EXECUTED event\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000"
/* offset=753743 */ "cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Counts number of cycles nothing is executed on any execution port\000"
/* offset=753986 */ "cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline\000"
/* offset=754270 */ "cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Total execution stalls\000"
/* offset=754470 */ "cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000"
/* offset=754625 */ "cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000"
/* offset=754780 */ "cycle_activity.stalls_l1d_miss\000cpu_core\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000"
/* offset=754960 */ "cycle_activity.stalls_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread and no uops dispatched, increment by 1. Note this is in DCU and connected to Umask 1 and 2. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000"
/* offset=755301 */ "cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls due to L1 data cache misses\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Execution stalls due to L1 data cache miss loads. Set Cmask=0CH\000"
/* offset=755503 */ "cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request missing the L1 data cache\000"
/* offset=755810 */ "cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000"
/* offset=755963 */ "cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000"
/* offset=756116 */ "cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss load* is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000"
/* offset=756263 */ "cycle_activity.stalls_l2_miss\000cpu_core\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000"
/* offset=756441 */ "cycle_activity.stalls_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load and no uops dispatched on this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0 and 2\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000"
/* offset=756776 */ "cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses  Spec update: HSM63, HSM80\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2  Spec update: HSM63, HSM80\000"
/* offset=756987 */ "cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2\000"
/* offset=757144 */ "cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand* load request missing the L2 cache.(as a footprint) * includes also L1 HW prefetch requests that may or may not be required by demands\000"
/* offset=757545 */ "cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000"
/* offset=757696 */ "cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000"
/* offset=757847 */ "cycle_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000"
/* offset=758023 */ "cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline and there were memory instructions pending (waiting for data)\000"
/* offset=758325 */ "cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000"
/* offset=758459 */ "cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request\000"
/* offset=758739 */ "cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=1000003,umask=0x14\000\00000\000\000"
/* offset=758894 */ "cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=2000003,umask=0x14\000\00000\000\000"
/* offset=759049 */ "cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000"
/* offset=759202 */ "cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000"
/* offset=759312 */ "cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000"
/* offset=759422 */ "cycle_activity.stalls_total\000cpu_core\000pipeline\000Total execution stalls. Unit: cpu_core \000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000"
/* offset=759557 */ "cycles_div_busy.all\000\000pipeline\000Cycles a divider is busy\000event=0xcd,period=2000003\000\00000\000Counts core cycles if either divide unit is busy\000"
/* offset=759691 */ "cycles_div_busy.all\000\000pipeline\000Cycles the divider is busy.  Does not imply a stall waiting for the divider\000event=0xcd,period=2000003,umask=0x1\000\00000\000Cycles the divider is busy.This event counts the cycles when the divide unit is unable to accept a new divide UOP because it is busy processing a previously dispatched UOP. The cycles will be counted irrespective of whether or not another divide UOP is waiting to enter the divide unit (from the RS). This event might count cycles while a divide is in progress even if the RS is empty.  The divide instruction is one of the longest latency instructions in the machine.  Hence, it has a special event associated with it to help determine if divides are delaying the retirement of instructions\000"
/* offset=760429 */ "cycles_div_busy.all\000\000pipeline\000Cycles the number of core cycles when divider is busy.  Does not imply a stall waiting for the divider\000event=0xcd,period=2000003,umask=0x1\000\00000\000This event counts cycles when the divider is busy. More specifically cycles when the divide unit is unable to accept a new divide uop because it is busy processing a previously dispatched uop. The cycles will be counted irrespective of whether or not another divide uop is waiting to enter the divide unit (from the RS). This event counts integer divides, x87 divides, divss, divsd, sqrtss, sqrtsd event and does not count vector divides\000"
/* offset=761040 */ "cycles_div_busy.any\000\000pipeline\000This event is deprecated\000event=0xcd,period=2000003\000\00010\000\000"
/* offset=761126 */ "cycles_div_busy.fpdiv\000\000floating point\000Counts the number of cycles the floating point divider is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts the number of cycles the floating point divider is busy.  Does not imply a stall waiting for the divider\000"
/* offset=761378 */ "cycles_div_busy.fpdiv\000\000floating point\000Cycles the FP divide unit is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts core cycles the floating point divide unit is busy\000"
/* offset=761547 */ "cycles_div_busy.idiv\000\000pipeline\000Counts the number of cycles the integer divider is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts the number of cycles the integer divider is busy.  Does not imply a stall waiting for the divider\000"
/* offset=761778 */ "cycles_div_busy.idiv\000\000pipeline\000Cycles the integer divide unit is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts core cycles the integer divide unit is busy\000"
/* offset=761938 */ "cycles_icache_mem_stalled.icache_mem_stalled\000\000frontend\000Cycles during which instruction fetches are  stalled\000event=0x86,period=2000000,umask=0x1\000\00000\000\000"
/* offset=762087 */ "cycles_int_masked.cycles_int_masked\000\000other\000Cycles during which interrupts are disabled\000event=0xc6,period=2000000,umask=0x1\000\00000\000\000"
/* offset=762215 */ "cycles_int_masked.cycles_int_pending_and_masked\000\000other\000Cycles during which interrupts are pending and disabled\000event=0xc6,period=2000000,umask=0x2\000\00000\000\000"
/* offset=762367 */ "data_tlb_misses.dtlb_miss\000\000virtual memory\000Memory accesses that missed the DTLB\000event=0x8,period=200000,umask=0x7\000\00000\000\000"
/* offset=762485 */ "data_tlb_misses.dtlb_miss_ld\000\000virtual memory\000DTLB misses due to load operations\000event=0x8,period=200000,umask=0x5\000\00000\000\000"
/* offset=762604 */ "data_tlb_misses.dtlb_miss_st\000\000virtual memory\000DTLB misses due to store operations\000event=0x8,period=200000,umask=0x6\000\00000\000\000"
/* offset=762724 */ "data_tlb_misses.l0_dtlb_miss_ld\000\000virtual memory\000L0 DTLB misses due to load operations\000event=0x8,period=200000,umask=0x9\000\00000\000\000"
/* offset=762849 */ "data_tlb_misses.l0_dtlb_miss_st\000\000virtual memory\000L0 DTLB misses due to store operations\000event=0x8,period=200000,umask=0xa\000\00000\000\000"
/* offset=762975 */ "de_dis_cops_from_decoder.disp_op_type.any_fp_dispatch\000\000other\000Any FP dispatch. Types of Oops Dispatched from Decoder\000event=0xab,umask=0x04\000\00000\000\000"
/* offset=763118 */ "de_dis_cops_from_decoder.disp_op_type.any_integer_dispatch\000\000other\000Any Integer dispatch. Types of Oops Dispatched from Decoder\000event=0xab,umask=0x08\000\00000\000\000"
/* offset=763271 */ "de_dis_dispatch_token_stalls0.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x10\000\00000\000\000"
/* offset=763465 */ "de_dis_dispatch_token_stalls0.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x20\000\00000\000\000"
/* offset=763659 */ "de_dis_dispatch_token_stalls0.alsq1_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 1 Tokens unavailable\000event=0xaf,umask=0x01\000\00000\000\000"
/* offset=763856 */ "de_dis_dispatch_token_stalls0.alsq2_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 2 Tokens unavailable\000event=0xaf,umask=0x02\000\00000\000\000"
/* offset=764053 */ "de_dis_dispatch_token_stalls0.alsq3_0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 3_0 Tokens unavailable\000event=0xaf,umask=0x08\000\00000\000\000"
/* offset=764254 */ "de_dis_dispatch_token_stalls0.alsq3_0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ3_0_TokenStall\000event=0xaf,umask=0x04\000\00000\000\000"
/* offset=764446 */ "de_dis_dispatch_token_stalls0.alsq3_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 3 Tokens unavailable\000event=0xaf,umask=0x04\000\00000\000\000"
/* offset=764643 */ "de_dis_dispatch_token_stalls0.alu_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALU tokens total unavailable\000event=0xaf,umask=0x08\000\00000\000\000"
/* offset=764841 */ "de_dis_dispatch_token_stalls0.alu_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALU tokens total unavailable\000event=0xaf,umask=0x10\000\00000\000\000"
/* offset=765039 */ "de_dis_dispatch_token_stalls0.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. RETIRE Tokens unavailable\000event=0xaf,umask=0x20\000\00000\000\000"
/* offset=765237 */ "de_dis_dispatch_token_stalls0.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. RETIRE Tokens unavailable\000event=0xaf,umask=0x40\000\00000\000\000"
/* offset=765435 */ "de_dis_dispatch_token_stalls0.sc_agu_dispatch_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. SC AGU dispatch stall\000event=0xaf,umask=0x40\000\00000\000\000"
/* offset=765632 */ "de_dis_dispatch_token_stalls1.fp_flush_recovery_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. FP Flush recovery stall\000event=0xae,umask=0x80\000\00000\000\000"
/* offset=765946 */ "de_dis_dispatch_token_stalls1.fp_flush_recovery_stall\000\000other\000Number of cycles dispatch is stalled for floating-point flush recovery\000event=0xae,umask=0x80\000\00000\000\000"
/* offset=766105 */ "de_dis_dispatch_token_stalls1.fp_misc_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. FP Miscellaneous resource unavailable. Applies to the recovery of mispredicts with FP ops\000event=0xae,umask=0x80\000\00000\000\000"
/* offset=766367 */ "de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Floating point register file resource stall. Applies to all FP ops that have a destination register\000event=0xae,umask=0x20\000\00000\000\000"
/* offset=766756 */ "de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Floating point register file resource stall. Applies to all FP ops that have a destination register\000event=0xae,umask=0x20\000\00000\000\000"
/* offset=767032 */ "de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for floating-point register file tokens\000event=0xae,umask=0x20\000\00000\000\000"
/* offset=767196 */ "de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. FP scheduler resource stall. Applies to ops that use the FP scheduler\000event=0xae,umask=0x40\000\00000\000\000"
/* offset=767550 */ "de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. FP scheduler resource stall. Applies to ops that use the FP scheduler\000event=0xae,umask=0x40\000\00000\000\000"
/* offset=767791 */ "de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for floating-point scheduler tokens\000event=0xae,umask=0x40\000\00000\000\000"
/* offset=767946 */ "de_dis_dispatch_token_stalls1.int_phy_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Integer Physical Register File resource stall. Integer Physical Register File, applies to all ops that have an integer destination register\000event=0xae,umask=0x01\000\00000\000\000"
/* offset=768380 */ "de_dis_dispatch_token_stalls1.int_phy_reg_file_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for integer physical register file tokens\000event=0xae,umask=0x01\000\00000\000\000"
/* offset=768551 */ "de_dis_dispatch_token_stalls1.int_phy_reg_file_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Integer Physical Register File resource stall. Applies to all ops that have an integer destination register\000event=0xae,umask=0x01\000\00000\000\000"
/* offset=768841 */ "de_dis_dispatch_token_stalls1.int_sched_misc_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Integer Scheduler miscellaneous resource stall\000event=0xae,umask=0x08\000\00000\000\000"
/* offset=769068 */ "de_dis_dispatch_token_stalls1.load_queue_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Load Queue resource stall. Applies to all ops with load semantics\000event=0xae,umask=0x02\000\00000\000\000"
/* offset=769422 */ "de_dis_dispatch_token_stalls1.load_queue_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for Load queue token\000event=0xae,umask=0x02\000\00000\000\000"
/* offset=769566 */ "de_dis_dispatch_token_stalls1.load_queue_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Load queue resource stall. Applies to all ops with load semantics\000event=0xae,umask=0x02\000\00000\000\000"
/* offset=769808 */ "de_dis_dispatch_token_stalls1.store_queue_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Store Queue resource stall. Applies to all ops with store semantics\000event=0xae,umask=0x04\000\00000\000\000"
/* offset=770165 */ "de_dis_dispatch_token_stalls1.store_queue_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for store queue tokens\000event=0xae,umask=0x04\000\00000\000\000"
/* offset=770312 */ "de_dis_dispatch_token_stalls1.store_queue_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Store queue resource stall. Applies to all ops with store semantics\000event=0xae,umask=0x04\000\00000\000\000"
/* offset=770557 */ "de_dis_dispatch_token_stalls1.taken_branch_buffer_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Taken branch buffer resource stall\000event=0xae,umask=0x10\000\00000\000\000"
/* offset=770776 */ "de_dis_dispatch_token_stalls1.taken_brnch_buffer_rsrc\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Taken branch buffer resource stall\000event=0xae,umask=0x10\000\00000\000\000"
/* offset=771101 */ "de_dis_dispatch_token_stalls1.taken_brnch_buffer_rsrc\000\000other\000Number of cycles dispatch is stalled for taken branch buffer tokens\000event=0xae,umask=0x10\000\00000\000\000"
/* offset=771257 */ "de_dis_dispatch_token_stalls2.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x10\000\00000\000\000"
/* offset=771451 */ "de_dis_dispatch_token_stalls2.int_sch0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 0 available\000event=0xaf,umask=0x01\000\00000\000\000"
/* offset=771675 */ "de_dis_dispatch_token_stalls2.int_sch0_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 0 tokens\000event=0xaf,umask=0x01\000\00000\000\000"
/* offset=771834 */ "de_dis_dispatch_token_stalls2.int_sch1_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 1 available\000event=0xaf,umask=0x02\000\00000\000\000"
/* offset=772058 */ "de_dis_dispatch_token_stalls2.int_sch1_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 1 tokens\000event=0xaf,umask=0x02\000\00000\000\000"
/* offset=772217 */ "de_dis_dispatch_token_stalls2.int_sch2_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 2 available\000event=0xaf,umask=0x04\000\00000\000\000"
/* offset=772441 */ "de_dis_dispatch_token_stalls2.int_sch2_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 2 tokens\000event=0xaf,umask=0x04\000\00000\000\000"
/* offset=772600 */ "de_dis_dispatch_token_stalls2.int_sch3_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 3 available\000event=0xaf,umask=0x08\000\00000\000\000"
/* offset=772824 */ "de_dis_dispatch_token_stalls2.int_sch3_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 3 tokens\000event=0xaf,umask=0x08\000\00000\000\000"
/* offset=772983 */ "de_dis_dispatch_token_stalls2.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Insufficient Retire Queue tokens available\000event=0xaf,umask=0x20\000\00000\000\000"
/* offset=773198 */ "de_dis_dispatch_token_stalls2.retire_token_stall\000\000other\000Number of cycles dispatch is stalled for retire queue tokens\000event=0xaf,umask=0x20\000\00000\000\000"
/* offset=773342 */ "de_dis_ops_from_decoder.any_fp_dispatch\000\000other\000Number of ops dispatched to the floating-point unit\000event=0xab,umask=0x04\000\00000\000\000"
/* offset=773468 */ "de_dis_ops_from_decoder.disp_op_type.any_integer_dispatch\000\000other\000Number of ops dispatched to the integer execution unit\000event=0xab,umask=0x08\000\00000\000\000"
/* offset=773615 */ "de_dis_uop_queue_empty_di0\000\000other\000Cycles where the Micro-Op Queue is empty\000event=0xa9\000\00000\000\000"
/* offset=773706 */ "de_dis_uops_from_decoder.decoder_dispatched\000\000other\000Count of dispatched Ops from Decoder\000event=0xaa,umask=0x01\000\00000\000\000"
/* offset=773821 */ "de_dis_uops_from_decoder.opcache_dispatched\000\000other\000Count of dispatched Ops from OpCache\000event=0xaa,umask=0x02\000\00000\000\000"
/* offset=773936 */ "de_dis_uops_from_decoder\000\000other\000Ops dispatched from either the decoders, OpCache or both\000event=0xaa,umask=0xff\000\00000\000\000"
/* offset=774052 */ "de_no_dispatch_per_slot.backend_stalls\000\000other\000In each cycle counts ops unable to dispatch because of back-end stalls\000event=0x1a0,umask=0x1e\000\00000\000\000"
/* offset=774197 */ "de_no_dispatch_per_slot.no_ops_from_frontend\000\000other\000In each cycle counts dispatch slots left empty because the front-end did not supply ops\000event=0x1a0,umask=0x01\000\00000\000\000"
/* offset=774365 */ "de_no_dispatch_per_slot.smt_contention\000\000other\000In each cycle counts ops unable to dispatch because the dispatch cycle was granted to the other SMT thread\000event=0x1a0,umask=0x60\000\00000\000\000"
/* offset=774546 */ "de_op_queue_empty\000\000other\000Cycles when the op queue is empty. Such cycles indicate that the front-end is not delivering instructions fast enough\000event=0xa9\000\00000\000\000"
/* offset=774705 */ "de_src_op_disp.all\000\000other\000Ops dispatched from any source\000event=0xaa,umask=0x07\000\00000\000\000"
/* offset=774789 */ "de_src_op_disp.decoder\000\000other\000Ops fetched from instruction cache and dispatched\000event=0xaa,umask=0x01\000\00000\000\000"
/* offset=774896 */ "de_src_op_disp.loop_buffer\000\000other\000Ops dispatched from loop buffer\000event=0xaa,umask=0x04\000\00000\000\000"
/* offset=774989 */ "de_src_op_disp.op_cache\000\000other\000Ops fetched from op cache and dispatched\000event=0xaa,umask=0x02\000\00000\000\000"
/* offset=775088 */ "decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000"
/* offset=775692 */ "decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000"
/* offset=776295 */ "decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk\000"
/* offset=776818 */ "decode.lcp\000cpu_core\000frontend\000Stalls caused by changing prefix length of the instruction. Unit: cpu_core \000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk\000"
/* offset=777366 */ "decode.ms_busy\000\000frontend\000Cycles the Microcode Sequencer is busy\000event=0x87,period=500009,umask=0x2\000\00000\000\000"
/* offset=777470 */ "decode.ms_busy\000cpu_core\000frontend\000Cycles the Microcode Sequencer is busy. Unit: cpu_core \000event=0x87,period=500009,umask=0x2\000\00000\000\000"
/* offset=777599 */ "decode_restriction.predecode_wrong\000\000frontend\000Counts the number of times a decode restriction reduced the decode throughput due to wrong instruction length prediction\000event=0xe9,period=200003,umask=0x1\000\00000\000Counts the number of times a decode restriction reduced the decode throughput due to wrong instruction length prediction\000"
/* offset=777925 */ "decode_restriction.predecode_wrong\000\000frontend\000Counts the number of times a decode restriction reduces the decode throughput due to wrong instruction length prediction\000event=0xe9,period=200003,umask=0x1\000\00000\000\000"
/* offset=778131 */ "decode_restriction.predecode_wrong\000\000frontend\000Decode restrictions due to predicting wrong instruction length\000event=0xe9,period=200003,umask=0x1\000\00000\000Counts the number of times the prediction (from the predecode cache) for instruction length is incorrect\000"
/* offset=778383 */ "decode_stall.iq_full\000\000frontend\000Decode stall due to IQ full\000event=0x87,period=2000000,umask=0x2\000\00000\000\000"
/* offset=778483 */ "decode_stall.pfb_empty\000\000frontend\000Decode stall due to PFB empty\000event=0x87,period=2000000,umask=0x1\000\00000\000\000"
/* offset=778587 */ "dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\00000\000\000"
/* offset=778720 */ "div.ar\000\000pipeline\000Divide operations retired\000event=0x13,period=2000000,umask=0x81\000\00000\000\000"
/* offset=778805 */ "div.s\000\000pipeline\000Divide operations executed\000event=0x13,period=2000000,umask=0x1\000\00000\000\000"
/* offset=778889 */ "dl1.dirty_eviction\000\000cache\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches\000event=0x51,period=200003,umask=0x1\000\00000\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches.  Does not count evictions or dirty writebacks caused by snoops.  Does not count a replacement unless a (dirty) line was written back\000"
/* offset=779286 */ "dl1.dirty_eviction\000\000cache\000L1 Cache evictions for dirty data\000event=0x51,period=200003,umask=0x1\000\00000\000Counts when a modified (dirty) cache line is evicted from the data L1 cache and needs to be written back to memory.  No count will occur if the evicted line is clean, and hence does not require a writeback\000"
/* offset=779591 */ "dl1.replacement\000\000cache\000L1 Cache evictions for dirty data\000event=0x51,period=200003,umask=0x1\000\00000\000Counts when a modified (dirty) cache line is evicted from the data L1 cache and needs to be written back to memory.  No count will occur if the evicted line is clean, and hence does not require a writeback\000"
/* offset=779893 */ "dram_channel_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780073 */ "dram_channel_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x47,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780254 */ "dram_channel_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x87,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780435 */ "dram_channel_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780616 */ "dram_channel_data_controller_4\000amd_df\000data fabric\000Unit: amd_df \000event=0x107,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780798 */ "dram_channel_data_controller_5\000amd_df\000data fabric\000Unit: amd_df \000event=0x147,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=780980 */ "dram_channel_data_controller_6\000amd_df\000data fabric\000Unit: amd_df \000event=0x187,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=781162 */ "dram_channel_data_controller_7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1c7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000"
/* offset=781344 */ "dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000Number of DSB to MITE switches\000"
/* offset=781493 */ "dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000This event counts the number of the Decode Stream Buffer (DSB)-to-MITE switches including all misses because of missing Decode Stream Buffer (DSB) cache and u-arch forced misses.\nNote: Invoking MITE requires two or three cycles delay\000"
/* offset=781845 */ "dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000\000"
/* offset=781964 */ "dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE transitions count\000event=0xab,cmask=1,edge=1,period=100003,umask=0x2\000\00000\000Counts the number of Decode Stream Buffer (DSB a.k.a. Uop Cache)-to-MITE speculative transitions\000"
/* offset=782202 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0x61,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000"
/* offset=782565 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0xab,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000"
/* offset=782928 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. MM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.Penalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000"
/* offset=784002 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Cycles DSB to MITE switches caused delay\000"
/* offset=784188 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. \nMM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.\nPenalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000"
/* offset=785275 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts the cycles attributed to a switch from the Decoded Stream Buffer (DSB), which holds decoded instructions, to the legacy decode pipeline.  It excludes cycles when the back-end cannot  accept new micro-ops.  The penalty for these switches is potentially several cycles of instruction starvation, where no micro-ops are delivered to the back-end\000"
/* offset=785781 */ "dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000\000"
/* offset=785927 */ "dsb2mite_switches.penalty_cycles\000cpu_core\000frontend\000DSB-to-MITE switch true penalty cycles. Unit: cpu_core \000event=0x61,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000"
/* offset=786315 */ "dsb_fill.all_cancel\000\000frontend\000Cases of cancelling valid Decode Stream Buffer (DSB) fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0xa\000\00000\000\000"
/* offset=786479 */ "dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000DSB Fill encountered > 3 DSB lines\000"
/* offset=786689 */ "dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000\000"
/* offset=786865 */ "dsb_fill.other_cancel\000\000frontend\000Cases of cancelling valid DSB fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0x2\000\00000\000\000"
/* offset=787008 */ "dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000"
/* offset=787101 */ "dtlb_load_misses.demand_ld_walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0x82\000\00000\000\000"
/* offset=787316 */ "dtlb_load_misses.demand_ld_walk_duration\000\000virtual memory\000Demand load cycles page miss handler (PMH) is busy with this walk\000event=0x8,period=2000003,umask=0x84\000\00000\000\000"
/* offset=787480 */ "dtlb_load_misses.large_page_walk_completed\000\000virtual memory\000Page walk for a large page completed for Demand load\000event=0x8,period=100003,umask=0x88\000\00000\000\000"
/* offset=787632 */ "dtlb_load_misses.large_walk_completed\000\000virtual memory\000DTLB load miss large page walks\000event=0x8,period=200000,umask=0x80\000\00000\000\000"
/* offset=787758 */ "dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes an page walk of any page size\000event=0x8,period=100003,umask=0x81\000\00000\000Misses in all TLB levels that cause a page walk of any page size from demand loads\000"
/* offset=788035 */ "dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x8,period=100003,umask=0x1\000\00000\000This event counts load misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000"
/* offset=788320 */ "dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Counts demand data loads that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000"
/* offset=788623 */ "dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Misses in all TLB levels that cause a page walk of any page size\000"
/* offset=788831 */ "dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000\000"
/* offset=788975 */ "dtlb_load_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to loads that miss the PDE (Page Directory Entry) cache\000event=0x8,period=200003,umask=0x80\000\00000\000\000"
/* offset=789155 */ "dtlb_load_misses.pde_cache_miss\000\000virtual memory\000DTLB demand load misses with low part of linear-to-physical address translation missed\000event=0x8,period=100003,umask=0x80\000\00000\000DTLB demand load misses with low part of linear-to-physical address translation missed\000"
/* offset=789416 */ "dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000"
/* offset=789543 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to a demand load that did not start a page walk. Account for all page sizes. Will result in a DTLB write from STLB\000event=0x8,period=200003,umask=0x20\000\00000\000\000"
/* offset=789810 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000"
/* offset=789915 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x5f,period=100003,umask=0x4\000\00000\000Counts load operations that missed 1st level DTLB but hit the 2nd level\000"
/* offset=790162 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=100003,umask=0x10\000\00000\000This event counts load operations that miss the first DTLB level but hit the second and do not cause any page walks. The penalty in this case is approximately 7 cycles\000"
/* offset=790505 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000Number of cache load STLB hits. No page walk\000"
/* offset=790726 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000\000"
/* offset=790903 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x12,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000"
/* offset=791106 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000"
/* offset=791308 */ "dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=2000003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000"
/* offset=791511 */ "dtlb_load_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to a demand load that did not start a page walk. Accounts for all page sizes. Will result in a DTLB write from STLB. Unit: cpu_atom \000event=0x8,period=200003,umask=0x20\000\00000\000\000"
/* offset=791804 */ "dtlb_load_misses.stlb_hit\000cpu_core\000virtual memory\000Loads that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x12,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000"
/* offset=792032 */ "dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000This event counts load operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000"
/* offset=792298 */ "dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000\000"
/* offset=792438 */ "dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000This event counts load operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000"
/* offset=792704 */ "dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000\000"
/* offset=792844 */ "dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x12,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000"
/* offset=793108 */ "dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000"
/* offset=793371 */ "dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a load\000"
/* offset=793668 */ "dtlb_load_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load. Unit: cpu_core \000event=0x12,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000"
/* offset=793957 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=1000003,umask=0xe\000\00000\000\000"
/* offset=794124 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size\000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000"
/* offset=794527 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000"
/* offset=794649 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size  Spec update: BDM69\000event=0x8,period=100003,umask=0xe\000\00000\000\000"
/* offset=794873 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0x82\000\00000\000Misses in all TLB levels that caused page walk completed of any size by demand loads\000"
/* offset=795162 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0xe\000\00000\000Completed page walks in any TLB of any page size due to demand load misses\000"
/* offset=795440 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=795790 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=796139 */ "dtlb_load_misses.walk_completed\000\000virtual memory\000Load misses at all DTLB levels that cause completed page walks\000event=0x8,period=100003,umask=0x2\000\00000\000\000"
/* offset=796289 */ "dtlb_load_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size. Unit: cpu_atom \000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000"
/* offset=796717 */ "dtlb_load_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses. Unit: cpu_atom \000event=0x8,period=200003,umask=0xe\000\00000\000\000"
/* offset=796895 */ "dtlb_load_misses.walk_completed\000cpu_core\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=797270 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1GB pages. Includes page walks that page fault\000"
/* offset=797668 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x8\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=798011 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)\000event=0x8,period=2000003,umask=0x8\000\00000\000\000"
/* offset=798170 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data load to a 1G page\000event=0x8,period=2000003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=798514 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data load to a 1G page\000event=0x12,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=798859 */ "dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data load to a 1G page\000event=0x8,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=799203 */ "dtlb_load_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 1G page. Unit: cpu_core \000event=0x12,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=799573 */ "dtlb_load_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to a demand load to a 1GB page\000event=0x8,period=200003,umask=0x8\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 1GB pages.  The page walks can end with or without a page fault\000"
/* offset=799932 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 2M or 4M page\000event=0x8,period=200003,umask=0x4\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages. Includes page walks that page fault\000"
/* offset=800344 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=800737 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)\000event=0x8,period=2000003,umask=0x4\000\00000\000Completed page walks due to demand load misses that caused 2M/4M page walks in any TLB levels\000"
/* offset=801032 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data load to a 2M/4M page\000event=0x8,period=2000003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=801385 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand load to a 2M or 4M page\000event=0x8,period=200003,umask=0x4\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000"
/* offset=801756 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x12,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=802110 */ "dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x8,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=802463 */ "dtlb_load_misses.walk_completed_2m_4m\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 2M or 4M page. Unit: cpu_atom \000event=0x8,period=200003,umask=0x4\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages. Includes page walks that page fault\000"
/* offset=802900 */ "dtlb_load_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page. Unit: cpu_core \000event=0x12,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=803279 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 4K page\000event=0x8,period=200003,umask=0x2\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages. Includes page walks that page fault\000"
/* offset=803676 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x2\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=804055 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)\000event=0x8,period=2000003,umask=0x2\000\00000\000Completed page walks due to demand load misses that caused 4K page walks in any TLB levels\000"
/* offset=804341 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data load to a 4K page\000event=0x8,period=2000003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=804685 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand load to a 4K page\000event=0x8,period=200003,umask=0x2\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 4K pages.  The page walks can end with or without a page fault\000"
/* offset=805041 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x12,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=805386 */ "dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x8,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=805730 */ "dtlb_load_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 4K page. Unit: cpu_core \000event=0x12,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=806100 */ "dtlb_load_misses.walk_cycles\000\000virtual memory\000DTLB load miss page walk cycles\000event=0x8,period=200000,umask=0x4\000\00000\000\000"
/* offset=806216 */ "dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000"
/* offset=806459 */ "dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000"
/* offset=806696 */ "dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000"
/* offset=806932 */ "dtlb_load_misses.walk_duration\000\000virtual memory\000Demand load cycles page miss handler (PMH) is busy with this walk\000event=0x8,period=2000003,umask=0x84\000\00000\000Cycle PMH is busy with a walk due to demand loads\000"
/* offset=807135 */ "dtlb_load_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake microarchitecture\000"
/* offset=807481 */ "dtlb_load_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle\000event=0x8,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000"
/* offset=807898 */ "dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x12,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000"
/* offset=808161 */ "dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x8,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000"
/* offset=808423 */ "dtlb_load_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to a demand load every cycle\000event=0x8,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to a load (demand data loads or SW prefetches). Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000"
/* offset=808808 */ "dtlb_load_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding for Loads (demand or SW prefetch) in PMH every cycle. Unit: cpu_atom \000event=0x8,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for Loads (demand or SW prefetch) in PMH every cycle.  A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000"
/* offset=809250 */ "dtlb_load_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle. Unit: cpu_core \000event=0x12,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000"
/* offset=809538 */ "dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000"
/* offset=809622 */ "dtlb_misses.large_walk_completed\000\000virtual memory\000DTLB miss large page walks\000event=0x49,period=200000,umask=0x80\000\00000\000\000"
/* offset=809739 */ "dtlb_misses.pde_miss\000\000virtual memory\000DTLB misses caused by low part of address. Count also includes 2M page references because 2M pages do not use the PDE\000event=0x49,period=200000,umask=0x20\000\00000\000\000"
/* offset=809935 */ "dtlb_misses.pde_miss\000\000virtual memory\000DTLB misses caused by low part of address\000event=0x49,period=200000,umask=0x20\000\00000\000\000"
/* offset=810055 */ "dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000"
/* offset=810178 */ "dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000"
/* offset=810282 */ "dtlb_misses.walk_cycles\000\000virtual memory\000DTLB miss page walk cycles\000event=0x49,period=2000000,umask=0x4\000\00000\000\000"
/* offset=810390 */ "dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000"
/* offset=810679 */ "dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Counts demand data stores that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000"
/* offset=810986 */ "dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Miss in all TLB levels causes a page walk of any page size (4K/2M/4M/1G)\000"
/* offset=811205 */ "dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000\000"
/* offset=811352 */ "dtlb_store_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to stores that miss the PDE (Page Directory Entry) cache\000event=0x49,period=2000003,umask=0x80\000\00000\000\000"
/* offset=811536 */ "dtlb_store_misses.pde_cache_miss\000\000virtual memory\000DTLB store misses with low part of linear-to-physical address translation missed\000event=0x49,period=100003,umask=0x80\000\00000\000DTLB store misses with low part of linear-to-physical address translation missed\000"
/* offset=811787 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to stores that did not start a page walk. Account for all pages sizes. Will result in a DTLB write from STLB\000event=0x49,period=2000003,umask=0x20\000\00000\000\000"
/* offset=812051 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000"
/* offset=812322 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000\000"
/* offset=812500 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000"
/* offset=812771 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000\000"
/* offset=812949 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x13,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000"
/* offset=813152 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000"
/* offset=813355 */ "dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000"
/* offset=813551 */ "dtlb_store_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to stores that did not start a page walk. Accounts for all pages sizes. Will result in a DTLB write from STLB. Unit: cpu_atom \000event=0x49,period=2000003,umask=0x20\000\00000\000\000"
/* offset=813841 */ "dtlb_store_misses.stlb_hit\000cpu_core\000virtual memory\000Stores that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x13,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000"
/* offset=814069 */ "dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000This event counts store operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000"
/* offset=814338 */ "dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000\000"
/* offset=814480 */ "dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000This event counts store operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000"
/* offset=814749 */ "dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000\000"
/* offset=814891 */ "dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000"
/* offset=815192 */ "dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x13,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000"
/* offset=815445 */ "dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000"
/* offset=815698 */ "dtlb_store_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. Unit: cpu_core \000event=0x13,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000"
/* offset=815976 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=1000003,umask=0xe\000\00000\000\000"
/* offset=816146 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size\000event=0x49,period=2000003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000"
/* offset=816529 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size\000event=0x49,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000"
/* offset=816911 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0xe\000\00000\000\000"
/* offset=817084 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000Miss in all TLB levels causes a page walk that completes of any page size (4K/2M/4M/1G)\000"
/* offset=817324 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000\000"
/* offset=817477 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0xe\000\00000\000Completed page walks due to store miss in any TLB levels of any page size (4K/2M/4M/1G)\000"
/* offset=817717 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=818072 */ "dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=818427 */ "dtlb_store_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page. Unit: cpu_atom \000event=0x49,period=2000003,umask=0xe\000\00000\000\000"
/* offset=818622 */ "dtlb_store_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size. Unit: cpu_atom \000event=0x49,period=2000003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000"
/* offset=819030 */ "dtlb_store_misses.walk_completed\000cpu_core\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=819410 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000"
/* offset=819786 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=820133 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data store to a 1G page\000event=0x13,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=820481 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=820829 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (1G)  Spec update: BDM69\000event=0x49,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=821175 */ "dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks. (1G)\000event=0x49,period=100003,umask=0x8\000\00000\000\000"
/* offset=821337 */ "dtlb_store_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 1G page. Unit: cpu_core \000event=0x13,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=821710 */ "dtlb_store_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to a demand data store to a 1GB page\000event=0x49,period=2000003,umask=0x8\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 1GB pages.  The page walks can end with or without a page fault\000"
/* offset=822046 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 2M or 4M page\000event=0x49,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000"
/* offset=822438 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M or 4M page\000event=0x49,period=2000003,umask=0x4\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000"
/* offset=822786 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=823142 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x13,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=823499 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=823856 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 2M/4M pages.  The page walks can end with or without a page fault\000"
/* offset=824198 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)  Spec update: BDM69\000event=0x49,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=824557 */ "dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)\000event=0x49,period=100003,umask=0x4\000\00000\000Completed page walks due to store misses in one or more TLB levels of 2M/4M page structure\000"
/* offset=824814 */ "dtlb_store_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page. Unit: cpu_core \000event=0x13,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=825196 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 4K page\000event=0x49,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000"
/* offset=825573 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=825920 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=2000003,umask=0x2\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000"
/* offset=826253 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x13,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=826601 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=826949 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000"
/* offset=827282 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x49,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=827627 */ "dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)\000event=0x49,period=100003,umask=0x2\000\00000\000Completed page walks due to store misses in one or more TLB levels of 4K page structure\000"
/* offset=827875 */ "dtlb_store_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 4K page. Unit: cpu_core \000event=0x13,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=828248 */ "dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000"
/* offset=828492 */ "dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB store misses\000"
/* offset=828731 */ "dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000Cycles PMH is busy with this walk\000"
/* offset=828893 */ "dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000\000"
/* offset=829022 */ "dtlb_store_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake microarchitecture\000"
/* offset=829372 */ "dtlb_store_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle\000event=0x49,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000"
/* offset=829779 */ "dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x13,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000"
/* offset=830031 */ "dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x49,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000"
/* offset=830283 */ "dtlb_store_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to a demand data store every cycle\000event=0x49,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to a demand data store. Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000"
/* offset=830652 */ "dtlb_store_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle. Unit: cpu_atom \000event=0x49,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle. A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000"
/* offset=831097 */ "dtlb_store_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle. Unit: cpu_core \000event=0x13,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000"
/* offset=831374 */ "eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\00000\000\000"
/* offset=831500 */ "eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000\000\00000\000\000"
/* offset=831616 */ "ept.epde_hit\000\000virtual memory\000Counts the number of Extended Page Directory Entry hits\000event=0x4f,period=2000003,umask=0x1\000\00000\000Counts the number of Extended Page Directory Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000"
/* offset=831940 */ "ept.epde_miss\000\000virtual memory\000Counts the number of Extended Page Directory Entry misses\000event=0x4f,period=2000003,umask=0x2\000\00000\000Counts the number Extended Page Directory Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000"
/* offset=832266 */ "ept.epdpe_hit\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry hits\000event=0x4f,period=2000003,umask=0x4\000\00000\000Counts the number Extended Page Directory Pointer Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000"
/* offset=832604 */ "ept.epdpe_miss\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry misses\000event=0x4f,period=2000003,umask=0x8\000\00000\000Counts the number Extended Page Directory Pointer Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000"
/* offset=832947 */ "ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000"
/* offset=833208 */ "ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000This event counts cycles for an extended page table walk. The Extended Page directory cache differs from standard TLB caches by the operating system that use it. Virtual machine operating systems use the extended page directory cache, while guest operating systems use the standard TLB caches\000"
/* offset=833618 */ "ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000"
/* offset=833736 */ "ept.walk_cycles\000\000virtual memory\000Extended Page Table walk cycles\000event=0x4f,period=2000000,umask=0x10\000\00000\000\000"
/* offset=833842 */ "ept.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a EPT (Extended Page Table) walk for any request type\000event=0x4f,period=2000003,umask=0x10\000\00000\000Counts cycles for each PMH (Page Miss Handler) that is busy with an EPT (Extended Page Table) walk for any request type\000"
/* offset=834140 */ "ept.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle\000event=0x4f,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000"
/* offset=834568 */ "ept.walk_pending\000\000virtual memory\000Page walks outstanding due to walking the EPT every cycle\000event=0x4f,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk only while traversing the Extended Page Table (EPT), and does not count during the rest of the translation.  The EPT is used for translating Guest-Physical Addresses to Physical Addresses for Virtual Machine Monitors (VMMs).  Average cycles per walk can be calculated by dividing the count by number of walks\000"
/* offset=835049 */ "es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000"
/* offset=835131 */ "event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\00000\000UNC_CBO_HYPHEN\000"
/* offset=835239 */ "event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\00000\000UNC_CBO_TWO_HYPH\000"
/* offset=835353 */ "ex_div_busy\000\000core\000Div Cycles Busy count\000event=0xd3\000\00000\000\000"
/* offset=835409 */ "ex_div_busy\000\000core\000Number of cycles the divider is busy\000event=0xd3\000\00000\000\000"
/* offset=835480 */ "ex_div_count\000\000core\000Div Op Count\000event=0xd4\000\00000\000\000"
/* offset=835528 */ "ex_div_count\000\000core\000Divide ops executed\000event=0xd4\000\00000\000\000"
/* offset=835583 */ "ex_no_retire.all\000\000core\000Cycles with no retire for any reason\000event=0xd6,umask=0x1b\000\00000\000\000"
/* offset=835670 */ "ex_no_retire.empty\000\000core\000Cycles with no retire due  to the lack of valid ops in the retire queue (may be caused by front-end bottlenecks or pipeline redirects)\000event=0xd6,umask=0x01\000\00000\000\000"
/* offset=835857 */ "ex_no_retire.load_not_complete\000\000core\000Cycles with no retire while the oldest op is waiting for load data\000event=0xd6,umask=0xa2\000\00000\000\000"
/* offset=835988 */ "ex_no_retire.not_complete\000\000core\000Cycles with no retire while the oldest op is waiting to be executed\000event=0xd6,umask=0x02\000\00000\000\000"
/* offset=836115 */ "ex_no_retire.other\000\000core\000Cycles with no retire caused by other reasons (retire breaks, traps, faults, etc.)\000event=0xd6,umask=0x08\000\00000\000\000"
/* offset=836250 */ "ex_no_retire.thread_not_selected\000\000core\000Cycles with no retire because thread arbitration did not select the thread\000event=0xd6,umask=0x10\000\00000\000\000"
/* offset=836391 */ "ex_ret_brn\000\000branch\000Retired branch instructions (all types of architectural control flow changes, including exceptions and interrupts)\000event=0xc2\000\00000\000\000"
/* offset=836541 */ "ex_ret_brn\000\000core\000Retired Branch Instructions\000event=0xc2\000\00000\000The number of branch instructions retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000"
/* offset=836743 */ "ex_ret_brn_far\000\000branch\000Retired far control transfers (far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts). Far control transfers are not subject to branch prediction\000event=0xc6\000\00000\000\000"
/* offset=836953 */ "ex_ret_brn_far\000\000core\000Retired Far Control Transfers\000event=0xc6\000\00000\000The number of far control transfers retired including far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts. Far control transfers are not subject to branch prediction\000"
/* offset=837212 */ "ex_ret_brn_ind_misp\000\000branch\000Retired indirect branch instructions mispredicted (only EX mispredicts). Each misprediction incurs the same penalty as a mispredicted conditional branch instruction\000event=0xca\000\00000\000\000"
/* offset=837421 */ "ex_ret_brn_ind_misp\000\000core\000Retired Indirect Branch Instructions Mispredicted\000event=0xca\000\00000\000The number of indirect branches retired that were not correctly predicted. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction. Note that only EX mispredicts are counted\000"
/* offset=837724 */ "ex_ret_brn_ind_misp\000\000core\000Retired Indirect Branch Instructions Mispredicted\000event=0xca\000\00000\000\000"
/* offset=837816 */ "ex_ret_brn_misp\000\000branch\000Retired branch instructions mispredicted\000event=0xc3\000\00000\000\000"
/* offset=837897 */ "ex_ret_brn_misp\000\000core\000Retired Branch Instructions Mispredicted\000event=0xc3\000\00000\000The number of branch instructions retired, of any type, that were not correctly predicted. This includes those for which prediction is not attempted (far control transfers, exceptions and interrupts)\000"
/* offset=838175 */ "ex_ret_brn_misp\000\000core\000Retired Branch Instructions Mispredicted\000event=0xc3\000\00000\000The number of retired branch instructions, that were mispredicted\000"
/* offset=838319 */ "ex_ret_brn_resync\000\000core\000Retired Branch Resyncs\000event=0xc7\000\00000\000The number of resync branches. These reflect pipeline restarts due to certain microcode assists and events such as writes to the active instruction stream, among other things. Each occurrence reflects a restart penalty similar to a branch mispredict. This is relatively rare\000"
/* offset=838656 */ "ex_ret_brn_tkn\000\000branch\000Retired taken branch instructions (all types of architectural control flow changes, including exceptions and interrupts)\000event=0xc4\000\00000\000\000"
/* offset=838816 */ "ex_ret_brn_tkn\000\000core\000Retired Taken Branch Instructions\000event=0xc4\000\00000\000The number of taken branches that were retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000"
/* offset=839033 */ "ex_ret_brn_tkn_misp\000\000branch\000Retired taken branch instructions mispredicted\000event=0xc5\000\00000\000\000"
/* offset=839124 */ "ex_ret_brn_tkn_misp\000\000core\000Retired Taken Branch Instructions Mispredicted\000event=0xc5\000\00000\000The number of retired taken branch instructions that were mispredicted\000"
/* offset=839283 */ "ex_ret_cond\000\000branch\000Retired conditional branch instructions\000event=0xd1\000\00000\000\000"
/* offset=839359 */ "ex_ret_cond\000\000core\000Retired Conditional Branch Instructions\000event=0xd1\000\00000\000\000"
/* offset=839433 */ "ex_ret_cond_misp\000\000core\000Retired Conditional Branch Instructions Mispredicted\000event=0xd2\000\00000\000\000"
/* offset=839525 */ "ex_ret_cops\000\000core\000Retired Uops\000event=0xc1\000\00000\000The number of micro-ops retired. This count includes all processor activity (instructions, exceptions, interrupts, microcode assists, etc.). The number of events logged per cycle can vary from 0 to 8\000"
/* offset=839771 */ "ex_ret_cops\000\000core\000Retired Uops\000event=0xc1\000\00000\000The number of uOps retired. This includes all processor activity (instructions, exceptions, interrupts, microcode assists, etc.). The number of events logged per cycle can vary from 0 to 4\000"
/* offset=840006 */ "ex_ret_fus_brnch_inst\000\000core\000Retired Fused Instructions. The number of fuse-branch instructions retired per cycle. The number of events logged per cycle can vary from 0-8\000event=0x1d0\000\00000\000\000"
/* offset=840193 */ "ex_ret_fus_brnch_inst\000\000core\000The number of fused retired branch instructions retired per cycle. The number of events logged per cycle can vary from 0 to 3\000event=0x1d0\000\00000\000\000"
/* offset=840364 */ "ex_ret_fused_instr\000\000core\000Counts retired Fused Instructions\000event=0x1d0\000\00000\000\000"
/* offset=840440 */ "ex_ret_fused_instr\000\000core\000Retired fused instructions\000event=0x1d0\000\00000\000\000"
/* offset=840509 */ "ex_ret_ind_brch_instr\000\000branch\000Retired indirect branch instructions\000event=0xcc\000\00000\000\000"
/* offset=840592 */ "ex_ret_ind_brch_instr\000\000core\000Retired Indirect Branch Instructions. The number of indirect branches retired\000event=0xcc\000\00000\000\000"
/* offset=840714 */ "ex_ret_instr\000\000core\000Retired Instructions\000event=0xc0\000\00000\000\000"
/* offset=840770 */ "ex_ret_instr\000\000core\000Retired instructions\000event=0xc0\000\00000\000\000"
/* offset=840826 */ "ex_ret_mmx_fp_instr.mmx_instr\000\000core\000MMX instructions\000event=0xcb,umask=0x02\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. MMX instructions\000"
/* offset=841217 */ "ex_ret_mmx_fp_instr.sse_instr\000\000core\000SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000event=0xcb,umask=0x04\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000"
/* offset=841710 */ "ex_ret_mmx_fp_instr.sse_instr\000\000core\000SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000event=0xcb,umask=0x04\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS\000"
/* offset=842134 */ "ex_ret_mmx_fp_instr.x87_instr\000\000core\000x87 instructions\000event=0xcb,umask=0x01\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. x87 instructions\000"
/* offset=842525 */ "ex_ret_msprd_brnch_instr_dir_msmtch\000\000branch\000Retired branch instructions mispredicted due to direction mismatch\000event=0x1c7\000\00000\000\000"
/* offset=842653 */ "ex_ret_msprd_brnch_instr_dir_msmtch\000\000core\000Retired Mispredicted Branch Instructions due to Direction Mismatch\000event=0x1c7\000\00000\000The number of retired conditional branch instructions that were not correctly predicted because of a branch direction mismatch\000"
/* offset=842905 */ "ex_ret_near_ret\000\000branch\000Retired near returns (RET or RET Iw)\000event=0xc8\000\00000\000\000"
/* offset=842982 */ "ex_ret_near_ret\000\000core\000Retired Near Returns\000event=0xc8\000\00000\000The number of near return instructions (RET or RET Iw) retired\000"
/* offset=843103 */ "ex_ret_near_ret_mispred\000\000branch\000Retired near returns mispredicted. Each misprediction incurs the same penalty as a mispredicted conditional branch instruction\000event=0xc9\000\00000\000\000"
/* offset=843278 */ "ex_ret_near_ret_mispred\000\000core\000Retired Near Returns Mispredicted\000event=0xc9\000\00000\000The number of near returns retired that were not correctly predicted by the return address predictor. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction\000"
/* offset=843553 */ "ex_ret_ops\000\000core\000Retired Ops. Use macro_ops_retired instead\000event=0xc1\000\00000\000The number of macro-ops retired\000"
/* offset=843660 */ "ex_ret_ops\000\000core\000Retired macro-ops\000event=0xc1\000\00000\000\000"
/* offset=843711 */ "ex_ret_ucode_instr\000\000core\000Retired microcoded instructions\000event=0x1c1\000\00000\000\000"
/* offset=843785 */ "ex_ret_ucode_ops\000\000core\000Retired microcode ops\000event=0x1c2\000\00000\000\000"
/* offset=843847 */ "ex_ret_uncond_brnch_instr\000\000branch\000Retired unconditional branch instructions\000event=0x1c9\000\00000\000\000"
/* offset=843940 */ "ex_ret_uncond_brnch_instr_mispred\000\000branch\000Retired unconditional indirect branch instructions mispredicted\000event=0x1c8\000\00000\000\000"
/* offset=844063 */ "ex_tagged_ibs_ops.ibs_count_rollover\000\000core\000Tagged IBS Ops. Number of times an op could not be tagged by IBS because of a previous tagged op that has not retired\000event=0x1cf,umask=0x04\000\00000\000\000"
/* offset=844252 */ "ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000"
/* offset=844337 */ "ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000"
/* offset=844448 */ "ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000"
/* offset=844550 */ "ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000"
/* offset=844678 */ "exe.amx_busy\000\000other\000Counts the cycles where the AMX (Advance Matrix Extension) unit is busy performing an operation\000event=0xb7,period=2000003,umask=0x2\000\00000\000\000"
/* offset=844835 */ "exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=845109 */ "exe_activity.1_ports_util\000cpu_core\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=845408 */ "exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=845686 */ "exe_activity.2_ports_util\000cpu_core\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=845989 */ "exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=846244 */ "exe_activity.3_ports_util\000cpu_core\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=846524 */ "exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=846780 */ "exe_activity.4_ports_util\000cpu_core\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=847061 */ "exe_activity.bound_on_loads\000\000pipeline\000Cycles when the memory subsystem has an outstanding load. Increments by 4 for every such cycle\000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000Counts cycles when the memory subsystem has an outstanding load. Increments by 4 for every such cycle\000"
/* offset=847345 */ "exe_activity.bound_on_loads\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000\000"
/* offset=847497 */ "exe_activity.bound_on_loads\000cpu_core\000pipeline\000Execution stalls while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000\000"
/* offset=847674 */ "exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000"
/* offset=847925 */ "exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no outstanding load\000event=0xa6,period=2000003,umask=0x40\000\00000\000\000"
/* offset=848069 */ "exe_activity.bound_on_stores\000cpu_core\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall. Unit: cpu_core \000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000"
/* offset=848345 */ "exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load\000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000"
/* offset=848693 */ "exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles where no uops were executed, the Reservation Station was not empty, the Store Buffer was full and there was no outstanding load\000event=0xa6,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were executed on all ports and Reservation Station (RS) was not empty\000"
/* offset=849014 */ "exe_activity.exe_bound_0_ports\000cpu_core\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load. Unit: cpu_core \000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000"
/* offset=849387 */ "ext_snoop.all_agents.any\000\000other\000External snoops\000event=0x77,period=200000,umask=0x2b\000\00000\000\000"
/* offset=849476 */ "ext_snoop.all_agents.clean\000\000other\000External snoops\000event=0x77,period=200000,umask=0x21\000\00000\000\000"
/* offset=849567 */ "ext_snoop.all_agents.hit\000\000other\000External snoops\000event=0x77,period=200000,umask=0x22\000\00000\000\000"
/* offset=849656 */ "ext_snoop.all_agents.hitm\000\000other\000External snoops\000event=0x77,period=200000,umask=0x28\000\00000\000\000"
/* offset=849746 */ "ext_snoop.this_agent.any\000\000other\000External snoops\000event=0x77,period=200000,umask=0xb\000\00000\000\000"
/* offset=849834 */ "ext_snoop.this_agent.clean\000\000other\000External snoops\000event=0x77,period=200000,umask=0x1\000\00000\000\000"
/* offset=849924 */ "ext_snoop.this_agent.hit\000\000other\000External snoops\000event=0x77,period=200000,umask=0x2\000\00000\000\000"
/* offset=850012 */ "ext_snoop.this_agent.hitm\000\000other\000External snoops\000event=0x77,period=200000,umask=0x8\000\00000\000\000"
/* offset=850101 */ "fetch_stall.all\000\000other\000Cycles code-fetch stalled due to any reason\000event=0x86,period=200003,umask=0x3f\000\00000\000Counts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000"
/* offset=850438 */ "fetch_stall.all\000\000other\000Cycles code-fetch stalled due to any reason\000event=0x86,period=200003\000\00000\000Counts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000"
/* offset=850764 */ "fetch_stall.icache_fill_pending_cycles\000\000cache\000Counts the number of core cycles the fetch stalls because of an icache miss. This is a cumulative count of core cycles the fetch stalled for all icache misses\000event=0x86,period=200003,umask=0x4\000\00000\000This event counts the number of core cycles the fetch stalls because of an icache miss. This is a cumulative count of cycles the NIP stalled for all icache misses\000"
/* offset=851171 */ "fetch_stall.icache_fill_pending_cycles\000\000cache\000Cycles code-fetch stalled due to an outstanding ICache miss\000event=0x86,period=200003,umask=0x2\000\00000\000Counts cycles that fetch is stalled due to an outstanding ICache miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ICache miss.  Note: this event is not the same as the total number of cycles spent retrieving instruction cache lines from the memory hierarchy\000"
/* offset=851639 */ "fetch_stall.icache_fill_pending_cycles\000\000cache\000Cycles code-fetch stalled due to an outstanding ICache miss\000event=0x86,period=200003,umask=0x4\000\00000\000Counts cycles that fetch is stalled due to an outstanding ICache miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ICache miss.  Note: this event is not the same as the total number of cycles spent retrieving instruction cache lines from the memory hierarchy.\r\nCounts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000"
/* offset=852339 */ "fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles code-fetch stalled due to an outstanding ITLB miss\000event=0x86,period=200003,umask=0x1\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000"
/* offset=852761 */ "fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles code-fetch stalled due to an outstanding ITLB miss\000event=0x86,period=200003,umask=0x2\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000"
/* offset=853183 */ "fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles the code-fetch stalls and an ITLB miss is outstanding\000event=0x86,period=200003,umask=0x1\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000"
/* offset=853608 */ "fp_arith_dispatched.port_0\000\000floating point\000FP_ARITH_DISPATCHED.PORT_0\000event=0xb3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=853719 */ "fp_arith_dispatched.port_0\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_0. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=853855 */ "fp_arith_dispatched.port_1\000\000floating point\000FP_ARITH_DISPATCHED.PORT_1\000event=0xb3,period=2000003,umask=0x2\000\00000\000\000"
/* offset=853966 */ "fp_arith_dispatched.port_1\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_1. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x2\000\00000\000\000"
/* offset=854102 */ "fp_arith_dispatched.port_5\000\000floating point\000FP_ARITH_DISPATCHED.PORT_5\000event=0xb3,period=2000003,umask=0x4\000\00000\000\000"
/* offset=854213 */ "fp_arith_dispatched.port_5\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_5. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x4\000\00000\000\000"
/* offset=854349 */ "fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=855448 */ "fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x4\000\00000\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=856247 */ "fp_arith_inst_retired.128b_packed_double\000\000floating point\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=857340 */ "fp_arith_inst_retired.128b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=858464 */ "fp_arith_inst_retired.128b_packed_single\000\000floating point\000Counts once for most SIMD 128-bit packed computational single precision floating-point instruction retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x8\000\00000\000Counts once for most SIMD 128-bit packed computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=859272 */ "fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=860385 */ "fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=861484 */ "fp_arith_inst_retired.128b_packed_single\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=862608 */ "fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=863684 */ "fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x10\000\00000\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=864472 */ "fp_arith_inst_retired.256b_packed_double\000\000floating point\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=865542 */ "fp_arith_inst_retired.256b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=866643 */ "fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=867763 */ "fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x20\000\00000\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=868573 */ "fp_arith_inst_retired.256b_packed_single\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 8 calculations per element\000event=0xc7,period=2000003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=869687 */ "fp_arith_inst_retired.256b_packed_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=870832 */ "fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=872056 */ "fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=873279 */ "fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=874503 */ "fp_arith_inst_retired.4_flops\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=875751 */ "fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=876819 */ "fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=877888 */ "fp_arith_inst_retired.512b_packed_double\000\000floating point\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=878977 */ "fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=880047 */ "fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=881118 */ "fp_arith_inst_retired.512b_packed_single\000\000floating point\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=882208 */ "fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=883416 */ "fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=884623 */ "fp_arith_inst_retired.double\000\000floating point\000Number of SSE/AVX computational double precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000006,umask=0x15\000\00000\000\000"
/* offset=885097 */ "fp_arith_inst_retired.packed\000\000floating point\000Number of SSE/AVX computational packed floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* packed double and single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000004,umask=0x3c\000\00000\000\000"
/* offset=885571 */ "fp_arith_inst_retired.scalar\000\000floating point\000Counts once for most SIMD scalar computational floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x3\000\00000\000Counts once for most SIMD scalar computational single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=886310 */ "fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=887276 */ "fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=888236 */ "fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below. Each count represents 1 computation operation.   Applies to SSE* and AVX* scalar double and single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=889239 */ "fp_arith_inst_retired.scalar\000cpu_core\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element. Unit: cpu_core \000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=890230 */ "fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=891206 */ "fp_arith_inst_retired.scalar_double\000\000floating point\000Counts once for most SIMD scalar computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x1\000\00000\000Counts once for most SIMD scalar computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=891938 */ "fp_arith_inst_retired.scalar_double\000\000floating point\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=892915 */ "fp_arith_inst_retired.scalar_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=893916 */ "fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=894912 */ "fp_arith_inst_retired.scalar_single\000\000floating point\000Counts once for most SIMD scalar computational single precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x2\000\00000\000Counts once for most SIMD scalar computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=895654 */ "fp_arith_inst_retired.scalar_single\000\000floating point\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=896651 */ "fp_arith_inst_retired.scalar_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=897672 */ "fp_arith_inst_retired.single\000\000floating point\000Number of SSE/AVX computational single precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000005,umask=0x2a\000\00000\000\000"
/* offset=898161 */ "fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000Number of any Vector retired FP arithmetic instructions.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=898444 */ "fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000\000"
/* offset=898587 */ "fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000"
/* offset=898730 */ "fp_arith_inst_retired.vector\000cpu_core\000floating point\000Number of any Vector retired FP arithmetic instructions. Unit: cpu_core \000event=0xc7,period=1000003,umask=0xfc\000\00000\000Number of any Vector retired FP arithmetic instructions.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000"
/* offset=899038 */ "fp_arith_inst_retired2.128b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.128B_PACKED_HALF\000event=0xcf,period=100003,umask=0x4\000\00000\000\000"
/* offset=899174 */ "fp_arith_inst_retired2.128bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 512-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x20\000\00000\000Counts once for each Intel AVX-512 computational 512-bit packed BFloat16 floating-point instruction retired. Applies to the ZMM based VDPBF16PS instruction.  Each count represents 64 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000"
/* offset=899682 */ "fp_arith_inst_retired2.256b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.256B_PACKED_HALF\000event=0xcf,period=100003,umask=0x8\000\00000\000\000"
/* offset=899818 */ "fp_arith_inst_retired2.256bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 128-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x40\000\00000\000Counts once for each Intel AVX-512 computational 128-bit packed BFloat16 floating-point instruction retired. Applies to the XMM based VDPBF16PS instruction. Each count represents 16 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000"
/* offset=900325 */ "fp_arith_inst_retired2.512b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.512B_PACKED_HALF\000event=0xcf,period=100003,umask=0x10\000\00000\000\000"
/* offset=900462 */ "fp_arith_inst_retired2.512bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 256-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x80\000\00000\000Counts once for each Intel AVX-512 computational 256-bit packed BFloat16 floating-point instruction retired. Applies to the YMM based VDPBF16PS instruction.  Each count represents 32 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000"
/* offset=900970 */ "fp_arith_inst_retired2.complex_scalar_half\000\000floating point\000FP_ARITH_INST_RETIRED2.COMPLEX_SCALAR_HALF\000event=0xcf,period=100003,umask=0x2\000\00000\000\000"
/* offset=901112 */ "fp_arith_inst_retired2.scalar\000\000floating point\000Number of all Scalar Half-Precision FP arithmetic instructions(1) retired - regular and complex\000event=0xcf,period=100003,umask=0x3\000\00000\000FP_ARITH_INST_RETIRED2.SCALAR\000"
/* offset=901323 */ "fp_arith_inst_retired2.scalar_half\000\000floating point\000FP_ARITH_INST_RETIRED2.SCALAR_HALF\000event=0xcf,period=100003,umask=0x1\000\00000\000\000"
/* offset=901449 */ "fp_arith_inst_retired2.vector\000\000floating point\000Number of all Vector (also called packed) Half-Precision FP arithmetic instructions(1) retired\000event=0xcf,period=100003,umask=0x1c\000\00000\000FP_ARITH_INST_RETIRED2.VECTOR\000"
/* offset=901660 */ "fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000"
/* offset=901772 */ "fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000"
/* offset=902045 */ "fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Cycles with any input/output SSE* or FP assists\000"
/* offset=902217 */ "fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000This event counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000"
/* offset=902501 */ "fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000\000"
/* offset=902626 */ "fp_assist.ar\000\000floating point\000Floating point assists for retired operations\000event=0x11,period=10000,umask=0x81\000\00000\000\000"
/* offset=902741 */ "fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000"
/* offset=902880 */ "fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000"
/* offset=903020 */ "fp_assist.s\000\000floating point\000Floating point assists\000event=0x11,period=10000,umask=0x1\000\00000\000\000"
/* offset=903110 */ "fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000Number of SIMD FP assists due to input values\000"
/* offset=903279 */ "fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000This event counts any input SSE* FP assist - invalid operation, denormal operand, dividing by zero, SNaN operand. Counting includes only cases involving penalties that required micro-code assist intervention\000"
/* offset=903610 */ "fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000\000"
/* offset=903734 */ "fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000Number of SIMD FP assists due to output values\000"
/* offset=903905 */ "fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000This event counts the number of SSE* floating point (FP) micro-code assist (numeric overflow/underflow) when the output value (destination register) is invalid. Counting covers only cases involving penalties that require micro-code assist intervention\000"
/* offset=904281 */ "fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000\000"
/* offset=904406 */ "fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000Number of X87 FP assists due to input values\000"
/* offset=904567 */ "fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000This event counts x87 floating point (FP) micro-code assist (invalid operation, denormal operand, SNaN operand) when the input value (one of the source operands to an FP instruction) is invalid\000"
/* offset=904877 */ "fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000\000"
/* offset=904994 */ "fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000Number of X87 FP assists due to output values\000"
/* offset=905158 */ "fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000This event counts the number of x87 floating point (FP) micro-code assist (numeric overflow/underflow, inexact result) when the output value (destination register) is invalid\000"
/* offset=905451 */ "fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000\000"
/* offset=905570 */ "fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000"
/* offset=905656 */ "fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000"
/* offset=905760 */ "fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000"
/* offset=905885 */ "fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000"
/* offset=905986 */ "fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000"
/* offset=906093 */ "fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000"
/* offset=906200 */ "fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000"
/* offset=906471 */ "fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000\000"
/* offset=906653 */ "fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000"
/* offset=906924 */ "fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000\000"
/* offset=907106 */ "fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000Counts number of SSE* or AVX-128 double precision FP scalar uops executed\000"
/* offset=907361 */ "fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000\000"
/* offset=907543 */ "fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000"
/* offset=907814 */ "fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000\000"
/* offset=907996 */ "fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000"
/* offset=908121 */ "fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000"
/* offset=908247 */ "fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULs and IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000Counts number of X87 uops executed\000"
/* offset=908615 */ "fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULs and IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000\000"
/* offset=908949 */ "fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULsand IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000Counts number of X87 uops executed\000"
/* offset=909316 */ "fp_disp_faults.all\000\000floating point\000Floating-point dispatch faults of all types\000event=0xe,umask=0x0f\000\00000\000\000"
/* offset=909421 */ "fp_disp_faults.sse_avx_all\000\000floating point\000Floating-point dispatch faults of all types for SSE and AVX ops\000event=0xe,umask=0x0e\000\00000\000\000"
/* offset=909554 */ "fp_disp_faults.x87_fill_fault\000\000floating point\000Floating Point Dispatch Faults. x87 fill fault\000event=0xe,umask=0x01\000\00000\000\000"
/* offset=909673 */ "fp_disp_faults.x87_fill_fault\000\000floating point\000Floating-point dispatch faults for x87 fills\000event=0xe,umask=0x01\000\00000\000\000"
/* offset=909790 */ "fp_disp_faults.xmm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. XMM fill fault\000event=0xe,umask=0x02\000\00000\000\000"
/* offset=909909 */ "fp_disp_faults.xmm_fill_fault\000\000floating point\000Floating-point dispatch faults for XMM fills\000event=0xe,umask=0x02\000\00000\000\000"
/* offset=910026 */ "fp_disp_faults.ymm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM fill fault\000event=0xe,umask=0x04\000\00000\000\000"
/* offset=910145 */ "fp_disp_faults.ymm_fill_fault\000\000floating point\000Floating-point dispatch faults for YMM fills\000event=0xe,umask=0x04\000\00000\000\000"
/* offset=910262 */ "fp_disp_faults.ymm_spill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM spill fault\000event=0xe,umask=0x08\000\00000\000\000"
/* offset=910383 */ "fp_disp_faults.ymm_spill_fault\000\000floating point\000Floating-point dispatch faults for YMM spills\000event=0xe,umask=0x08\000\00000\000\000"
/* offset=910502 */ "fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000"
/* offset=910623 */ "fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000"
/* offset=910751 */ "fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000"
/* offset=910880 */ "fp_num_mov_elim_scal_op.opt_potential\000\000floating point\000Number of Ops that are candidates for optimization (have Z-bit either set or pass). This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x04\000\00000\000\000"
/* offset=911195 */ "fp_num_mov_elim_scal_op.opt_potential\000\000floating point\000Number of Ops that are candidates for optimization (have Z-bit either set or pass)\000event=0x4,umask=0x04\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of Ops that are candidates for optimization (have Z-bit either set or pass)\000"
/* offset=911592 */ "fp_num_mov_elim_scal_op.optimized\000\000floating point\000Number of Scalar Ops optimized. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x08\000\00000\000\000"
/* offset=911851 */ "fp_num_mov_elim_scal_op.optimized\000\000floating point\000Number of Scalar Ops optimized\000event=0x4,umask=0x08\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of Scalar Ops optimized\000"
/* offset=912140 */ "fp_num_mov_elim_scal_op.sse_mov_ops\000\000floating point\000Number of SSE Move Ops. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x01\000\00000\000\000"
/* offset=912393 */ "fp_num_mov_elim_scal_op.sse_mov_ops\000\000floating point\000Number of SSE Move Ops\000event=0x4,umask=0x01\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of SSE Move Ops\000"
/* offset=912668 */ "fp_num_mov_elim_scal_op.sse_mov_ops_elim\000\000floating point\000Number of SSE Move Ops eliminated. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x02\000\00000\000\000"
/* offset=912937 */ "fp_num_mov_elim_scal_op.sse_mov_ops_elim\000\000floating point\000Number of SSE Move Ops eliminated\000event=0x4,umask=0x02\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of SSE Move Ops eliminated\000"
/* offset=913239 */ "fp_ops_retired_by_type.all\000\000floating point\000Retired floating-point ops of all types\000event=0xa,umask=0xff\000\00000\000\000"
/* offset=913348 */ "fp_ops_retired_by_type.scalar_add\000\000floating point\000Retired scalar floating-point add ops\000event=0xa,umask=0x01\000\00000\000\000"
/* offset=913462 */ "fp_ops_retired_by_type.scalar_all\000\000floating point\000Retired scalar floating-point ops of all types\000event=0xa,umask=0x0f\000\00000\000\000"
/* offset=913585 */ "fp_ops_retired_by_type.scalar_blend\000\000floating point\000Retired scalar floating-point blend ops\000event=0xa,umask=0x09\000\00000\000\000"
/* offset=913703 */ "fp_ops_retired_by_type.scalar_cmp\000\000floating point\000Retired scalar floating-point compare ops\000event=0xa,umask=0x07\000\00000\000\000"
/* offset=913821 */ "fp_ops_retired_by_type.scalar_cvt\000\000floating point\000Retired scalar floating-point convert ops\000event=0xa,umask=0x08\000\00000\000\000"
/* offset=913939 */ "fp_ops_retired_by_type.scalar_div\000\000floating point\000Retired scalar floating-point divide ops\000event=0xa,umask=0x05\000\00000\000\000"
/* offset=914056 */ "fp_ops_retired_by_type.scalar_mac\000\000floating point\000Retired scalar floating-point multiply-accumulate ops\000event=0xa,umask=0x04\000\00000\000\000"
/* offset=914186 */ "fp_ops_retired_by_type.scalar_mul\000\000floating point\000Retired scalar floating-point multiply ops\000event=0xa,umask=0x03\000\00000\000\000"
/* offset=914305 */ "fp_ops_retired_by_type.scalar_other\000\000floating point\000Retired scalar floating-point ops of other types\000event=0xa,umask=0x0e\000\00000\000\000"
/* offset=914432 */ "fp_ops_retired_by_type.scalar_sqrt\000\000floating point\000Retired scalar floating-point square root ops\000event=0xa,umask=0x06\000\00000\000\000"
/* offset=914555 */ "fp_ops_retired_by_type.scalar_sub\000\000floating point\000Retired scalar floating-point subtract ops\000event=0xa,umask=0x02\000\00000\000\000"
/* offset=914674 */ "fp_ops_retired_by_type.vector_add\000\000floating point\000Retired vector floating-point add ops\000event=0xa,umask=0x10\000\00000\000\000"
/* offset=914788 */ "fp_ops_retired_by_type.vector_all\000\000floating point\000Retired vector floating-point ops of all types\000event=0xa,umask=0xf0\000\00000\000\000"
/* offset=914911 */ "fp_ops_retired_by_type.vector_blend\000\000floating point\000Retired vector floating-point blend ops\000event=0xa,umask=0x90\000\00000\000\000"
/* offset=915029 */ "fp_ops_retired_by_type.vector_cmp\000\000floating point\000Retired vector floating-point compare ops\000event=0xa,umask=0x70\000\00000\000\000"
/* offset=915147 */ "fp_ops_retired_by_type.vector_cvt\000\000floating point\000Retired vector floating-point convert ops\000event=0xa,umask=0x80\000\00000\000\000"
/* offset=915265 */ "fp_ops_retired_by_type.vector_div\000\000floating point\000Retired vector floating-point divide ops\000event=0xa,umask=0x50\000\00000\000\000"
/* offset=915382 */ "fp_ops_retired_by_type.vector_logical\000\000floating point\000Retired vector floating-point logical ops\000event=0xa,umask=0xd0\000\00000\000\000"
/* offset=915504 */ "fp_ops_retired_by_type.vector_mac\000\000floating point\000Retired vector floating-point multiply-accumulate ops\000event=0xa,umask=0x40\000\00000\000\000"
/* offset=915634 */ "fp_ops_retired_by_type.vector_mul\000\000floating point\000Retired vector floating-point multiply ops\000event=0xa,umask=0x30\000\00000\000\000"
/* offset=915753 */ "fp_ops_retired_by_type.vector_other\000\000floating point\000Retired vector floating-point ops of other types\000event=0xa,umask=0xe0\000\00000\000\000"
/* offset=915880 */ "fp_ops_retired_by_type.vector_shuffle\000\000floating point\000Retired vector floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xa,umask=0xb0\000\00000\000\000"
/* offset=916141 */ "fp_ops_retired_by_type.vector_sqrt\000\000floating point\000Retired vector floating-point square root ops\000event=0xa,umask=0x60\000\00000\000\000"
/* offset=916264 */ "fp_ops_retired_by_type.vector_sub\000\000floating point\000Retired vector floating-point subtract ops\000event=0xa,umask=0x20\000\00000\000\000"
/* offset=916383 */ "fp_ops_retired_by_width.all\000\000floating point\000Retired floating-point ops of all widths\000event=0x8,umask=0x3f\000\00000\000\000"
/* offset=916494 */ "fp_ops_retired_by_width.mmx_uops_retired\000\000floating point\000Retired MMX floating-point ops\000event=0x8,umask=0x02\000\00000\000\000"
/* offset=916608 */ "fp_ops_retired_by_width.pack_128_uops_retired\000\000floating point\000Retired packed 128-bit floating-point ops\000event=0x8,umask=0x08\000\00000\000\000"
/* offset=916738 */ "fp_ops_retired_by_width.pack_256_uops_retired\000\000floating point\000Retired packed 256-bit floating-point ops\000event=0x8,umask=0x10\000\00000\000\000"
/* offset=916868 */ "fp_ops_retired_by_width.pack_512_uops_retired\000\000floating point\000Retired packed 512-bit floating-point ops\000event=0x8,umask=0x20\000\00000\000\000"
/* offset=916998 */ "fp_ops_retired_by_width.scalar_uops_retired\000\000floating point\000Retired scalar floating-point ops\000event=0x8,umask=0x04\000\00000\000\000"
/* offset=917118 */ "fp_ops_retired_by_width.x87_uops_retired\000\000floating point\000Retired x87 floating-point ops\000event=0x8,umask=0x01\000\00000\000\000"
/* offset=917232 */ "fp_pack_ops_retired.all\000\000floating point\000Retired packed floating-point ops of all types\000event=0xc,umask=0xff\000\00000\000\000"
/* offset=917345 */ "fp_pack_ops_retired.fp128_add\000\000floating point\000Retired 128-bit packed floating-point add ops\000event=0xc,umask=0x01\000\00000\000\000"
/* offset=917463 */ "fp_pack_ops_retired.fp128_all\000\000floating point\000Retired 128-bit packed floating-point ops of all types\000event=0xc,umask=0x0f\000\00000\000\000"
/* offset=917590 */ "fp_pack_ops_retired.fp128_blend\000\000floating point\000Retired 128-bit packed floating-point blend ops\000event=0xc,umask=0x09\000\00000\000\000"
/* offset=917712 */ "fp_pack_ops_retired.fp128_cmp\000\000floating point\000Retired 128-bit packed floating-point compare ops\000event=0xc,umask=0x07\000\00000\000\000"
/* offset=917834 */ "fp_pack_ops_retired.fp128_cvt\000\000floating point\000Retired 128-bit packed floating-point convert ops\000event=0xc,umask=0x08\000\00000\000\000"
/* offset=917956 */ "fp_pack_ops_retired.fp128_div\000\000floating point\000Retired 128-bit packed floating-point divide ops\000event=0xc,umask=0x05\000\00000\000\000"
/* offset=918077 */ "fp_pack_ops_retired.fp128_logical\000\000floating point\000Retired 128-bit packed floating-point logical ops\000event=0xc,umask=0x0d\000\00000\000\000"
/* offset=918203 */ "fp_pack_ops_retired.fp128_mac\000\000floating point\000Retired 128-bit packed floating-point multiply-accumulate ops\000event=0xc,umask=0x04\000\00000\000\000"
/* offset=918337 */ "fp_pack_ops_retired.fp128_mul\000\000floating point\000Retired 128-bit packed floating-point multiply ops\000event=0xc,umask=0x03\000\00000\000\000"
/* offset=918460 */ "fp_pack_ops_retired.fp128_other\000\000floating point\000Retired 128-bit packed floating-point ops of other types\000event=0xc,umask=0x0e\000\00000\000\000"
/* offset=918591 */ "fp_pack_ops_retired.fp128_shuffle\000\000floating point\000Retired 128-bit packed floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xc,umask=0x0b\000\00000\000\000"
/* offset=918856 */ "fp_pack_ops_retired.fp128_sqrt\000\000floating point\000Retired 128-bit packed floating-point square root ops\000event=0xc,umask=0x06\000\00000\000\000"
/* offset=918983 */ "fp_pack_ops_retired.fp128_sub\000\000floating point\000Retired 128-bit packed floating-point subtract ops\000event=0xc,umask=0x02\000\00000\000\000"
/* offset=919106 */ "fp_pack_ops_retired.fp256_add\000\000floating point\000Retired 256-bit packed floating-point add ops\000event=0xc,umask=0x10\000\00000\000\000"
/* offset=919224 */ "fp_pack_ops_retired.fp256_all\000\000floating point\000Retired 256-bit packed floating-point ops of all types\000event=0xc,umask=0xf0\000\00000\000\000"
/* offset=919351 */ "fp_pack_ops_retired.fp256_blend\000\000floating point\000Retired 256-bit packed floating-point blend ops\000event=0xc,umask=0x90\000\00000\000\000"
/* offset=919473 */ "fp_pack_ops_retired.fp256_cmp\000\000floating point\000Retired 256-bit packed floating-point compare ops\000event=0xc,umask=0x70\000\00000\000\000"
/* offset=919595 */ "fp_pack_ops_retired.fp256_cvt\000\000floating point\000Retired 256-bit packed floating-point convert ops\000event=0xc,umask=0x80\000\00000\000\000"
/* offset=919717 */ "fp_pack_ops_retired.fp256_div\000\000floating point\000Retired 256-bit packed floating-point divide ops\000event=0xc,umask=0x50\000\00000\000\000"
/* offset=919838 */ "fp_pack_ops_retired.fp256_logical\000\000floating point\000Retired 256-bit packed floating-point logical ops\000event=0xc,umask=0xd0\000\00000\000\000"
/* offset=919964 */ "fp_pack_ops_retired.fp256_mac\000\000floating point\000Retired 256-bit packed floating-point multiply-accumulate ops\000event=0xc,umask=0x40\000\00000\000\000"
/* offset=920098 */ "fp_pack_ops_retired.fp256_mul\000\000floating point\000Retired 256-bit packed floating-point multiply ops\000event=0xc,umask=0x30\000\00000\000\000"
/* offset=920221 */ "fp_pack_ops_retired.fp256_other\000\000floating point\000Retired 256-bit packed floating-point ops of other types\000event=0xc,umask=0xe0\000\00000\000\000"
/* offset=920352 */ "fp_pack_ops_retired.fp256_shuffle\000\000floating point\000Retired 256-bit packed floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xc,umask=0xb0\000\00000\000\000"
/* offset=920617 */ "fp_pack_ops_retired.fp256_sqrt\000\000floating point\000Retired 256-bit packed floating-point square root ops\000event=0xc,umask=0x60\000\00000\000\000"
/* offset=920744 */ "fp_pack_ops_retired.fp256_sub\000\000floating point\000Retired 256-bit packed floating-point subtract ops\000event=0xc,umask=0x20\000\00000\000\000"
/* offset=920867 */ "fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Add/subtract FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x01\000\00000\000\000"
/* offset=921120 */ "fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Add/subtract FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x01\000\00000\000\000"
/* offset=921553 */ "fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Retired SSE and AVX floating-point add and subtract ops\000event=0x3,umask=0x01\000\00000\000\000"
/* offset=921684 */ "fp_ret_sse_avx_ops.all\000\000floating point\000All FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0xff\000\00000\000\000"
/* offset=921918 */ "fp_ret_sse_avx_ops.all\000\000floating point\000All FLOPS\000event=0x3,umask=0xff\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000"
/* offset=922150 */ "fp_ret_sse_avx_ops.all\000\000floating point\000Retired SSE and AVX floating-point ops of all types\000event=0x3,umask=0x1f\000\00000\000\000"
/* offset=922267 */ "fp_ret_sse_avx_ops.bfloat_mac_flops\000\000floating point\000Retired SSE and AVX floating-point bfloat multiply-accumulate ops (each operation is counted as 2 ops)\000event=0x3,umask=0x10\000\00000\000\000"
/* offset=922448 */ "fp_ret_sse_avx_ops.div_flops\000\000floating point\000Divide/square root FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x04\000\00000\000\000"
/* offset=922703 */ "fp_ret_sse_avx_ops.div_flops\000\000floating point\000Divide/square root FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x04\000\00000\000\000"
/* offset=923138 */ "fp_ret_sse_avx_ops.div_flops\000\000floating point\000Retired SSE and AVX floating-point divide and square root ops\000event=0x3,umask=0x04\000\00000\000\000"
/* offset=923271 */ "fp_ret_sse_avx_ops.dp_add_sub_flops\000\000floating point\000Double precision add/subtract FLOPS\000event=0x3,umask=0x10\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision add/subtract FLOPS\000"
/* offset=923579 */ "fp_ret_sse_avx_ops.dp_div_flops\000\000floating point\000Double precision divide/square root FLOPS\000event=0x3,umask=0x40\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision divide/square root FLOPS\000"
/* offset=923895 */ "fp_ret_sse_avx_ops.dp_mult_add_flops\000\000floating point\000Double precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000event=0x3,umask=0x80\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000"
/* offset=924268 */ "fp_ret_sse_avx_ops.dp_mult_flops\000\000floating point\000Double precision multiply FLOPS\000event=0x3,umask=0x20\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision multiply FLOPS\000"
/* offset=924565 */ "fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Multiply-Accumulate FLOPs. Each MAC operation is counted as 2 FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x08\000\00000\000\000"
/* offset=925043 */ "fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Multiply-add FLOPS. Multiply-add counts as 2 FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x08\000\00000\000\000"
/* offset=925324 */ "fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Retired SSE and AVX floating-point multiply-accumulate ops (each operation is counted as 2 ops)\000event=0x3,umask=0x08\000\00000\000\000"
/* offset=925491 */ "fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Multiply FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x02\000\00000\000\000"
/* offset=925737 */ "fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Multiply FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x02\000\00000\000\000"
/* offset=926163 */ "fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Retired SSE and AVX floating-point multiply ops\000event=0x3,umask=0x02\000\00000\000\000"
/* offset=926283 */ "fp_ret_sse_avx_ops.sp_add_sub_flops\000\000floating point\000Single-precision add/subtract FLOPS\000event=0x3,umask=0x01\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision add/subtract FLOPS\000"
/* offset=926591 */ "fp_ret_sse_avx_ops.sp_div_flops\000\000floating point\000Single-precision divide/square root FLOPS\000event=0x3,umask=0x04\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision divide/square root FLOPS\000"
/* offset=926907 */ "fp_ret_sse_avx_ops.sp_mult_add_flops\000\000floating point\000Single precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000event=0x3,umask=0x08\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000"
/* offset=927280 */ "fp_ret_sse_avx_ops.sp_mult_flops\000\000floating point\000Single-precision multiply FLOPS\000event=0x3,umask=0x02\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision multiply FLOPS\000"
/* offset=927577 */ "fp_ret_x87_fp_ops.add_sub_ops\000\000floating point\000Retired x87 floating-point add and subtract ops\000event=0x2,umask=0x01\000\00000\000\000"
/* offset=927697 */ "fp_ret_x87_fp_ops.all\000\000floating point\000Retired x87 floating-point ops of all types\000event=0x2,umask=0x07\000\00000\000\000"
/* offset=927805 */ "fp_ret_x87_fp_ops.div_sqrt_ops\000\000floating point\000Retired x87 floating-point divide and square root ops\000event=0x2,umask=0x04\000\00000\000\000"
/* offset=927932 */ "fp_ret_x87_fp_ops.mul_ops\000\000floating point\000Retired x87 floating-point multiply ops\000event=0x2,umask=0x02\000\00000\000\000"
/* offset=928040 */ "fp_retired_ser_ops.all\000\000floating point\000Retired SSE and AVX serializing ops of all types\000event=0x5,umask=0x0f\000\00000\000\000"
/* offset=928154 */ "fp_retired_ser_ops.sse_bot_ret\000\000floating point\000Retired SSE and AVX bottom-executing ops. Bottom-executing ops wait for all older ops to retire before executing\000event=0x5,umask=0x08\000\00000\000\000"
/* offset=928340 */ "fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE bottom-executing uOps retired. The number of serializing Ops retired\000event=0x5,umask=0x08\000\00000\000\000"
/* offset=928486 */ "fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE bottom-executing uOps retired\000event=0x5,umask=0x01\000\00000\000The number of serializing Ops retired. SSE bottom-executing uOps retired\000"
/* offset=928665 */ "fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE/AVX bottom-executing ops retired. The number of serializing Ops retired\000event=0x5,umask=0x08\000\00000\000\000"
/* offset=928814 */ "fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000Retired SSE and AVX control word mispredict traps\000event=0x5,umask=0x04\000\00000\000\000"
/* offset=928938 */ "fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000event=0x5,umask=0x02\000\00000\000The number of serializing Ops retired. SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000"
/* offset=929248 */ "fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000SSE/AVX control word mispredict traps. The number of serializing Ops retired\000event=0x5,umask=0x04\000\00000\000\000"
/* offset=929399 */ "fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000The number of serializing Ops retired. SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000event=0x5,umask=0x04\000\00000\000\000"
/* offset=929611 */ "fp_retired_ser_ops.x87_bot_ret\000\000floating point\000Retired x87 bottom-executing ops. Bottom-executing ops wait for all older ops to retire before executing\000event=0x5,umask=0x02\000\00000\000\000"
/* offset=929789 */ "fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing ops retired. The number of serializing Ops retired\000event=0x5,umask=0x02\000\00000\000\000"
/* offset=929934 */ "fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing uOps retired. The number of serializing Ops retired\000event=0x5,umask=0x02\000\00000\000\000"
/* offset=930080 */ "fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing uOps retired\000event=0x5,umask=0x04\000\00000\000The number of serializing Ops retired. x87 bottom-executing uOps retired\000"
/* offset=930259 */ "fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000Retired x87 control word mispredict traps due to mispredictions in RC or PC, or changes in exception mask bits\000event=0x5,umask=0x01\000\00000\000\000"
/* offset=930444 */ "fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits. The number of serializing Ops retired\000event=0x5,umask=0x01\000\00000\000\000"
/* offset=930650 */ "fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits\000event=0x5,umask=0x08\000\00000\000The number of serializing Ops retired. x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits\000"
/* offset=930948 */ "fp_retx87_fp_ops.add_sub_ops\000\000floating point\000Add/subtract Ops\000event=0x2,umask=0x01\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Add/subtract Ops\000"
/* offset=931168 */ "fp_retx87_fp_ops.all\000\000floating point\000All Ops\000event=0x2,umask=0x07\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8\000"
/* offset=931353 */ "fp_retx87_fp_ops.div_sqr_r_ops\000\000floating point\000Divide and square root Ops\000event=0x2,umask=0x04\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Divide and square root Ops\000"
/* offset=931595 */ "fp_retx87_fp_ops.mul_ops\000\000floating point\000Multiply Ops\000event=0x2,umask=0x02\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Multiply Ops\000"
/* offset=931803 */ "fp_sched_empty\000\000floating point\000This is a speculative event. The number of cycles in which the FPU scheduler is empty. Note that some Ops like FP loads bypass the scheduler\000event=0x1\000\00000\000\000"
/* offset=931990 */ "fpu_pipe_assignment.dual0\000\000floating point\000Total number multi-pipe uOps assigned to pipe 0\000event=0,umask=0x10\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 0\000"
/* offset=932624 */ "fpu_pipe_assignment.dual1\000\000floating point\000Total number multi-pipe uOps assigned to pipe 1\000event=0,umask=0x20\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 1\000"
/* offset=933258 */ "fpu_pipe_assignment.dual2\000\000floating point\000Total number multi-pipe uOps assigned to pipe 2\000event=0,umask=0x40\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 2\000"
/* offset=933892 */ "fpu_pipe_assignment.dual3\000\000floating point\000Total number multi-pipe uOps assigned to pipe 3\000event=0,umask=0x80\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 3\000"
/* offset=934526 */ "fpu_pipe_assignment.dual\000\000floating point\000Total number multi-pipe uOps assigned to all pipes\000event=0,umask=0xf0\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to all pipes\000"
/* offset=935165 */ "fpu_pipe_assignment.total0\000\000floating point\000Total number of fp uOps  on pipe 0\000event=0,umask=0x01\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 0\000"
/* offset=935757 */ "fpu_pipe_assignment.total1\000\000floating point\000Total number of fp uOps on pipe 1\000event=0,umask=0x02\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 1\000"
/* offset=936348 */ "fpu_pipe_assignment.total1\000\000floating point\000Total number uOps assigned to pipe 1\000event=0,umask=0x02\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 1\000"
/* offset=936942 */ "fpu_pipe_assignment.total2\000\000floating point\000Total number of fp uOps on pipe 2\000event=0,umask=0x04\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 2\000"
/* offset=937533 */ "fpu_pipe_assignment.total2\000\000floating point\000Total number uOps assigned to pipe 2\000event=0,umask=0x04\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 2\000"
/* offset=938127 */ "fpu_pipe_assignment.total3\000\000floating point\000Total number of fp uOps on pipe 3\000event=0,umask=0x08\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one-cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 3\000"
/* offset=938717 */ "fpu_pipe_assignment.total3\000\000floating point\000Total number uOps assigned to pipe 3\000event=0,umask=0x08\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one-cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 3\000"
/* offset=939310 */ "fpu_pipe_assignment.total\000\000floating point\000Total number of fp uOps\000event=0,umask=0x0f\000\00000\000Total number of fp uOps. The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS\000"
/* offset=939877 */ "fpu_pipe_assignment.total\000\000floating point\000Total number uOps assigned to all fpu pipes\000event=0,umask=0x0f\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to all pipes\000"
/* offset=940499 */ "frontend_retired.any_ant\000cpu_core\000frontend\000Retired ANT branches (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x9\000\00000\000Always Not Taken (ANT) conditional retired branches (no BTB entry and not mispredicted) (Precise event)\000"
/* offset=940752 */ "frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000"
/* offset=941034 */ "frontend_retired.any_dsb_miss\000cpu_core\000frontend\000Retired Instructions who experienced DSB miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000"
/* offset=941341 */ "frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000"
/* offset=941725 */ "frontend_retired.dsb_miss\000cpu_core\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000"
/* offset=942134 */ "frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000"
/* offset=942386 */ "frontend_retired.itlb_miss\000cpu_atom\000frontend\000Counts the number of instructions retired that were tagged because empty issue slots were seen before the uop due to ITLB miss (Precise event). Unit: cpu_atom \000event=0xc6,period=1000003,umask=0x10\000\00000\000\000"
/* offset=942633 */ "frontend_retired.itlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000"
/* offset=942910 */ "frontend_retired.itlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000"
/* offset=943187 */ "frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000"
/* offset=943451 */ "frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000\000"
/* offset=943625 */ "frontend_retired.l1i_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000"
/* offset=943914 */ "frontend_retired.l1i_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000"
/* offset=944203 */ "frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000"
/* offset=944466 */ "frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000\000"
/* offset=944639 */ "frontend_retired.l2_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000"
/* offset=944927 */ "frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x408006\000\00000\000\000"
/* offset=945210 */ "frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x508006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=945682 */ "frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=946154 */ "frontend_retired.latency_ge_128\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=946651 */ "frontend_retired.latency_ge_128\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=947148 */ "frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x401006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=947605 */ "frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x501006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=948062 */ "frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=948519 */ "frontend_retired.latency_ge_16\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=949001 */ "frontend_retired.latency_ge_16\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=949483 */ "frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Must be precise)\000event=0xc6,period=100007,umask=0x1,frontend=0x400106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Must be precise)\000"
/* offset=949857 */ "frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000"
/* offset=950227 */ "frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000"
/* offset=950597 */ "frontend_retired.latency_ge_1\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000"
/* offset=950992 */ "frontend_retired.latency_ge_1\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000"
/* offset=951387 */ "frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x410006\000\00000\000\000"
/* offset=951670 */ "frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x510006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=952142 */ "frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=952614 */ "frontend_retired.latency_ge_256\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=953111 */ "frontend_retired.latency_ge_256\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=953608 */ "frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=953980 */ "frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=954352 */ "frontend_retired.latency_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400206\000\00000\000\000"
/* offset=954631 */ "frontend_retired.latency_ge_2\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=955028 */ "frontend_retired.latency_ge_2\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=955425 */ "frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000"
/* offset=955952 */ "frontend_retired.latency_ge_2_bubbles_ge_1\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000"
/* offset=956504 */ "frontend_retired.latency_ge_2_bubbles_ge_1\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000"
/* offset=957056 */ "frontend_retired.latency_ge_2_bubbles_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 2 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x200206\000\00000\000\000"
/* offset=957358 */ "frontend_retired.latency_ge_2_bubbles_ge_3\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 3 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x300206\000\00000\000\000"
/* offset=957660 */ "frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x402006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=958117 */ "frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x502006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=958574 */ "frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=959031 */ "frontend_retired.latency_ge_32\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=959513 */ "frontend_retired.latency_ge_32\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=959995 */ "frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400406\000\00000\000\000"
/* offset=960274 */ "frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=960740 */ "frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=961206 */ "frontend_retired.latency_ge_4\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=961697 */ "frontend_retired.latency_ge_4\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=962188 */ "frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x420006\000\00000\000\000"
/* offset=962471 */ "frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x520006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=962943 */ "frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=963415 */ "frontend_retired.latency_ge_512\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=963912 */ "frontend_retired.latency_ge_512\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=964409 */ "frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x404006\000\00000\000\000"
/* offset=964690 */ "frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x504006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=965159 */ "frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=965628 */ "frontend_retired.latency_ge_64\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=966122 */ "frontend_retired.latency_ge_64\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000"
/* offset=966616 */ "frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=967070 */ "frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=967524 */ "frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=967978 */ "frontend_retired.latency_ge_8\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=968457 */ "frontend_retired.latency_ge_8\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000"
/* offset=968936 */ "frontend_retired.misp_ant\000cpu_core\000frontend\000Mispredicted Retired ANT branches (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x2,frontend=0x9\000\00000\000ANT retired branches that got just mispredicted (Precise event)\000"
/* offset=969163 */ "frontend_retired.ms_flows\000\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x8\000\00000\000\000"
/* offset=969294 */ "frontend_retired.ms_flows\000cpu_core\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x8\000\00000\000\000"
/* offset=969450 */ "frontend_retired.ms_flows\000cpu_core\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x8\000\00000\000\000"
/* offset=969606 */ "frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000"
/* offset=969872 */ "frontend_retired.stlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000"
/* offset=970163 */ "frontend_retired.unknown_branch\000\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x17\000\00000\000\000"
/* offset=970307 */ "frontend_retired.unknown_branch\000cpu_core\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x17\000\00000\000\000"
/* offset=970476 */ "frontend_retired.unknown_branch\000cpu_core\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x17\000\00000\000\000"
/* offset=970645 */ "hle_retired.aborted\000\000memory\000Number of times HLE abort was triggered (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000"
/* offset=970825 */ "hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000"
/* offset=971064 */ "hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000\000"
/* offset=971248 */ "hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one)\000event=0xc8,period=100003,umask=0x4\000\00000\000Counts the number of times HLE abort was triggered\000"
/* offset=971465 */ "hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=100003,umask=0x80\000\00000\000Counts the number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000"
/* offset=971725 */ "hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000\000"
/* offset=971889 */ "hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=100003,umask=0x8\000\00000\000Counts the number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000"
/* offset=972195 */ "hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000"
/* offset=972380 */ "hle_retired.aborted_memtype\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times an HLE execution aborted due to incompatible memory type\000"
/* offset=972603 */ "hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000Number of times an HLE abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000"
/* offset=972901 */ "hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000"
/* offset=973088 */ "hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an HLE abort\000"
/* offset=973286 */ "hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000"
/* offset=973430 */ "hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an HLE abort\000"
/* offset=973640 */ "hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000"
/* offset=973792 */ "hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc8,period=2000003,umask=0x40\000\00000\000\000"
/* offset=973961 */ "hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times HLE caused a fault\000"
/* offset=974144 */ "hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times HLE aborted and was not due to the abort conditions in subevents 3-6\000"
/* offset=974404 */ "hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000"
/* offset=974679 */ "hle_retired.aborted_timer\000\000memory\000Number of times an HLE execution aborted due to hardware timer expiration\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000"
/* offset=974829 */ "hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=100003,umask=0x20\000\00000\000Counts the number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000"
/* offset=975183 */ "hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000"
/* offset=975396 */ "hle_retired.commit\000\000memory\000Number of times HLE commit succeeded\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000"
/* offset=975537 */ "hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=100003,umask=0x2\000\00000\000Counts the number of times HLE commit succeeded\000"
/* offset=975707 */ "hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000"
/* offset=975867 */ "hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000\000"
/* offset=975991 */ "hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an HLE region. Does not count nested transactions\000"
/* offset=976185 */ "hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region. Does not count nested transactions\000"
/* offset=976369 */ "hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000\000"
/* offset=976477 */ "hle_retired.start\000\000memory\000Number of times we entered an HLE region; does not count nested transactions\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region\n does not count nested transactions\000"
/* offset=976697 */ "hw_int_rcv\000\000other\000Hardware interrupts received\000event=0xc8,period=200000\000\00000\000\000"
/* offset=976774 */ "hw_interrupts.masked\000\000other\000Counts the number of core cycles during which interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000"
/* offset=977105 */ "hw_interrupts.masked\000\000other\000Cycles hardware interrupts are masked\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000"
/* offset=977395 */ "hw_interrupts.pending_and_masked\000\000other\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled). Increments by 1 each core cycle that both EFLAGS.IF is 0 and an INTR is pending (which means the APIC is telling the ROB to cause an INTR). This event does not increment if EFLAGS.IF is 0 but all interrupt in the APICs Interrupt Request Register (IRR) are inhibited by the PPR (thus either by ISRV or TPR)  because in these cases the interrupts would be held up in the APIC and would not be pended to the ROB. This event does count when an interrupt is only inhibited by MOV/POP SS state machines or the STI state machine. These extra inhibits only last for a single instructions and would not be important\000"
/* offset=978310 */ "hw_interrupts.pending_and_masked\000\000other\000Cycles pending interrupts are masked\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts core cycles during which there are pending interrupts, but interrupts are masked (EFLAGS.IF = 0)\000"
/* offset=978530 */ "hw_interrupts.received\000\000other\000Counts the number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000\000"
/* offset=978664 */ "hw_interrupts.received\000\000other\000Hardware interrupts received\000event=0xcb,period=203,umask=0x1\000\00000\000Counts hardware interrupts received by the processor\000"
/* offset=978812 */ "hw_interrupts.received\000\000other\000Number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000Counts the number of hardware interruptions received by the processor\000"
/* offset=979004 */ "hw_pre_req.dl1_miss\000\000other\000Hardware Prefetch requests that miss the L1D cache. This accounts for both L1 streamer and IP-based (IPP) HW prefetchers. A request is being counted each time it access the cache & miss it, including if a block is applicable or if hit the Fill Buffer for \000event=0x4e,period=2000003,umask=0x2\000\00000\000\000"
/* offset=979328 */ "ic_cache_fill_l2\000\000cache\000Instruction Cache Refills from L2. The number of 64 byte instruction cache line was fulfilled from the L2 cache\000event=0x82\000\00000\000\000"
/* offset=979480 */ "ic_cache_fill_l2\000\000cache\000Instruction cache lines (64 bytes) fulfilled from the L2 cache\000event=0x82\000\00000\000\000"
/* offset=979583 */ "ic_cache_fill_l2\000\000cache\000The number of 64 byte instruction cache line was fulfilled from the L2 cache\000event=0x82\000\00000\000\000"
/* offset=979700 */ "ic_cache_fill_sys\000\000cache\000Instruction Cache Refills from System. The number of 64 byte instruction cache line fulfilled from system memory or another cache\000event=0x83\000\00000\000\000"
/* offset=979871 */ "ic_cache_fill_sys\000\000cache\000Instruction cache lines (64 bytes) fulfilled from system memory or another cache\000event=0x83\000\00000\000\000"
/* offset=979993 */ "ic_cache_fill_sys\000\000cache\000The number of 64 byte instruction cache line fulfilled from system memory or another cache\000event=0x83\000\00000\000\000"
/* offset=980125 */ "ic_cache_inval.fill_invalidated\000\000cache\000IC line invalidated due to overwriting fill response. The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x01\000\00000\000\000"
/* offset=980400 */ "ic_cache_inval.l2_invalidating_probe\000\000cache\000IC line invalidated due to L2 invalidating probe (external or LS). The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x02\000\00000\000\000"
/* offset=980693 */ "ic_fetch_stall.ic_stall_any\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle for any reason (nothing valid in pipe ICM1)\000event=0x87,umask=0x04\000\00000\000\000"
/* offset=980867 */ "ic_fetch_stall.ic_stall_back_pressure\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to back-pressure\000event=0x87,umask=0x01\000\00000\000\000"
/* offset=981057 */ "ic_fetch_stall.ic_stall_dq_empty\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to DQ empty\000event=0x87,umask=0x02\000\00000\000\000"
/* offset=981237 */ "ic_fw32\000\000cache\000The number of 32B fetch windows transferred from IC pipe to DE instruction decoder (includes non-cacheable and cacheable fill responses)\000event=0x80\000\00000\000\000"
/* offset=981405 */ "ic_fw32_miss\000\000cache\000The number of 32B fetch windows tried to read the L1 IC and missed in the full tag\000event=0x81\000\00000\000\000"
/* offset=981524 */ "ic_oc_mode_switch.ic_oc_mode_switch\000\000cache\000OC Mode Switch. IC to OC mode switch\000event=0x28a,umask=0x01\000\00000\000\000"
/* offset=981632 */ "ic_oc_mode_switch.ic_oc_mode_switch\000\000other\000OC Mode Switch. IC to OC mode switch\000event=0x28a,umask=0x01\000\00000\000\000"
/* offset=981740 */ "ic_oc_mode_switch.oc_ic_mode_switch\000\000cache\000OC Mode Switch. OC to IC mode switch\000event=0x28a,umask=0x02\000\00000\000\000"
/* offset=981848 */ "ic_oc_mode_switch.oc_ic_mode_switch\000\000other\000OC Mode Switch. OC to IC mode switch\000event=0x28a,umask=0x02\000\00000\000\000"
/* offset=981956 */ "ic_tag_hit_miss.all_instruction_cache_accesses\000\000cache\000All Instruction Cache Accesses. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x1f\000\00000\000\000"
/* offset=982120 */ "ic_tag_hit_miss.all_instruction_cache_accesses\000\000cache\000Instruction cache accesses of all types\000event=0x18e,umask=0x1f\000\00000\000\000"
/* offset=982242 */ "ic_tag_hit_miss.instruction_cache_hit\000\000cache\000Instruction Cache Hit. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x07\000\00000\000\000"
/* offset=982388 */ "ic_tag_hit_miss.instruction_cache_hit\000\000cache\000Instruction cache hits\000event=0x18e,umask=0x07\000\00000\000\000"
/* offset=982484 */ "ic_tag_hit_miss.instruction_cache_miss\000\000cache\000Instruction Cache Miss. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x18\000\00000\000\000"
/* offset=982632 */ "ic_tag_hit_miss.instruction_cache_miss\000\000cache\000Instruction cache misses\000event=0x18e,umask=0x18\000\00000\000\000"
/* offset=982731 */ "icache.accesses\000\000frontend\000Counts all instruction fetches, including uncacheable fetches\000event=0x80,period=200003,umask=0x3\000\00000\000\000"
/* offset=982859 */ "icache.accesses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump\000event=0x80,period=200003,umask=0x3\000\00000\000\000"
/* offset=983063 */ "icache.accesses\000\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line\000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000"
/* offset=983624 */ "icache.accesses\000\000frontend\000Instruction fetches\000event=0x80,period=200000,umask=0x3\000\00000\000\000"
/* offset=983710 */ "icache.accesses\000\000frontend\000Instruction fetches\000event=0x80,period=200003,umask=0x3\000\00000\000This event counts all instruction fetches, not including most uncacheable\r\nfetches\000"
/* offset=983878 */ "icache.accesses\000\000frontend\000References per ICache line. This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x3\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line.  The event strives to count on a cache line basis, so that multiple fetches to a single cache line count as one ICACHE.ACCESS.  Specifically, the event counts when accesses from straight line code crosses the cache line boundary, or when a branch target is to a new line.\r\nThis event counts differently than Intel processors based on Silvermont microarchitecture\000"
/* offset=984515 */ "icache.accesses\000cpu_atom\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump. Unit: cpu_atom \000event=0x80,period=200003,umask=0x3\000\00000\000\000"
/* offset=984744 */ "icache.accesses\000cpu_atom\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line. Unit: cpu_atom \000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000"
/* offset=985330 */ "icache.hit\000\000frontend\000Counts all instruction fetches that hit the instruction cache\000event=0x80,period=200003,umask=0x1\000\00000\000\000"
/* offset=985453 */ "icache.hit\000\000frontend\000Counts the number of instruction cache hits\000event=0x80,period=200003,umask=0x1\000\00000\000Counts the number of requests that hit in the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000"
/* offset=985964 */ "icache.hit\000\000frontend\000Icache hit\000event=0x80,period=200000,umask=0x1\000\00000\000\000"
/* offset=986036 */ "icache.hit\000\000frontend\000Instruction fetches from Icache\000event=0x80,period=200003,umask=0x1\000\00000\000This event counts all instruction fetches from the instruction cache\000"
/* offset=986197 */ "icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000"
/* offset=986506 */ "icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000This event counts the number of both cacheable and noncacheable Instruction Cache, Streaming Buffer and Victim Cache Reads including UC fetches\000"
/* offset=986835 */ "icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000\000"
/* offset=987021 */ "icache.hit\000\000frontend\000References per ICache line that are available in the ICache (hit). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x1\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line and that cache line is in the ICache (hit).  The event strives to count on a cache line basis, so that multiple accesses which hit in a single cache line count as one ICACHE.HIT.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000"
/* offset=987766 */ "icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000This event counts cycles during which the demand fetch waits for data (wfdM104H) from L2 or iSB (opportunistic hit)\000"
/* offset=988022 */ "icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000"
/* offset=988163 */ "icache.ifetch_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000"
/* offset=988304 */ "icache.ifetch_stall\000\000frontend\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000"
/* offset=988540 */ "icache.misses\000\000frontend\000Counts all instruction fetches that miss the instruction cache or produce memory requests. An instruction fetch miss is counted only once and not once for every cycle it is outstanding\000event=0x80,period=200003,umask=0x2\000\00000\000\000"
/* offset=988789 */ "icache.misses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump and the instruction cache registers bytes are not present. -\000event=0x80,period=200003,umask=0x2\000\00000\000\000"
/* offset=989052 */ "icache.misses\000\000frontend\000Counts the number of instruction cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000"
/* offset=989566 */ "icache.misses\000\000frontend\000Icache miss\000event=0x80,period=200000,umask=0x2\000\00000\000\000"
/* offset=989642 */ "icache.misses\000\000frontend\000Icache miss\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts all instruction fetches that miss the Instruction cache or produce memory requests. This includes uncacheable fetches. An instruction fetch miss is counted only once and not once for every cycle it is outstanding\000"
/* offset=989948 */ "icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes UC accesses\000"
/* offset=990163 */ "icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes unchacheable accesses\000"
/* offset=990419 */ "icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts Instruction Cache (ICACHE) misses\000"
/* offset=990635 */ "icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes UC accesses\000"
/* offset=990922 */ "icache.misses\000\000frontend\000References per ICache line that are not available in the ICache (miss). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x2\000\00000\000Counts requests to the Instruction Cache (ICache)  for one or more bytes in an ICache Line and that cache line is not in the ICache (miss).  The event strives to count on a cache line basis, so that multiple accesses which miss in a single cache line count as one ICACHE.MISS.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is not in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000"
/* offset=991687 */ "icache.misses\000cpu_atom\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump and the instruction cache registers bytes are not present. -. Unit: cpu_atom \000event=0x80,period=200003,umask=0x2\000\00000\000\000"
/* offset=991975 */ "icache.misses\000cpu_atom\000frontend\000Counts the number of instruction cache misses. Unit: cpu_atom \000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000"
/* offset=992514 */ "icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_DATA.STALLS]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_DATA.STALLS]\000"
/* offset=992891 */ "icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity\000"
/* offset=993172 */ "icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000"
/* offset=993527 */ "icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000\000"
/* offset=993710 */ "icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000Counts instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000"
/* offset=994068 */ "icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000\000"
/* offset=994253 */ "icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000"
/* offset=994568 */ "icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000\000"
/* offset=994759 */ "icache_data.stall_periods\000cpu_core\000frontend\000ICACHE_DATA.STALL_PERIODS. Unit: cpu_core \000event=0x80,cmask=1,edge=1,period=500009,umask=0x4\000\00000\000\000"
/* offset=994901 */ "icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_16B.IFDATA_STALL]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_16B.IFDATA_STALL]\000"
/* offset=995283 */ "icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The decode pipeline works at a 32 Byte granularity\000"
/* offset=995558 */ "icache_data.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. Unit: cpu_core \000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The decode pipeline works at a 32 Byte granularity\000"
/* offset=995858 */ "icache_tag.hit\000cpu_core\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Unit: cpu_core \000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000"
/* offset=996232 */ "icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000"
/* offset=996552 */ "icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000\000"
/* offset=996743 */ "icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss\000"
/* offset=996965 */ "icache_tag.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. Unit: cpu_core \000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss\000"
/* offset=997212 */ "idi_misc.wb_downgrade\000\000other\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000event=0xfe,period=100003,umask=0x4\000\00000\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000"
/* offset=997542 */ "idi_misc.wb_upgrade\000\000other\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000event=0xfe,period=100003,umask=0x2\000\00000\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000"
/* offset=997882 */ "idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.DSB_CYCLES_OK]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_OK]\000"
/* offset=998281 */ "idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered four uops. Set Cmask = 4\000"
/* offset=998477 */ "idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000"
/* offset=998803 */ "idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000\000"
/* offset=998944 */ "idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.DSB_CYCLES_ANY]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_ANY]\000"
/* offset=999346 */ "idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered at least one uops. Set Cmask = 1\000"
/* offset=999553 */ "idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000"
/* offset=999880 */ "idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000\000"
/* offset=1000024 */ "idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered four uops. Set Cmask = 4\000"
/* offset=1000200 */ "idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts the number of cycles 4 uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1000587 */ "idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1000957 */ "idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000\000"
/* offset=1001077 */ "idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uop. Set Cmask = 1\000"
/* offset=1001263 */ "idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uops. Set Cmask = 1\000"
/* offset=1001450 */ "idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1001838 */ "idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles  uops were delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1002208 */ "idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000\000"
/* offset=1002331 */ "idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1002689 */ "idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000"
/* offset=1002978 */ "idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000"
/* offset=1003345 */ "idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1003527 */ "idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000"
/* offset=1003938 */ "idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000"
/* offset=1004194 */ "idq.dsb_cycles_any\000cpu_core\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000"
/* offset=1004475 */ "idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1004838 */ "idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=6,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1005201 */ "idq.dsb_cycles_ok\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000"
/* offset=1005608 */ "idq.dsb_cycles_ok\000cpu_core\000frontend\000Cycles DSB is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1005996 */ "idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1006310 */ "idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000"
/* offset=1006574 */ "idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Increment each cycle. # of uops delivered to IDQ from DSB path. Set Cmask = 1 to count cycles\000"
/* offset=1006821 */ "idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000"
/* offset=1007144 */ "idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1007298 */ "idq.dsb_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000"
/* offset=1007587 */ "idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles  Spec update: HSD135\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty  Spec update: HSD135\000"
/* offset=1007764 */ "idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty\000"
/* offset=1007899 */ "idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000This counts the number of cycles that the instruction decoder queue is empty and can indicate that the application may be bound in the front end.  It does not determine whether there are uops being delivered to the Alloc stage since uops can be delivered by bypass skipping the Instruction Decode Queue (IDQ) when it is empty\000"
/* offset=1008329 */ "idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1008434 */ "idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000Number of uops delivered to IDQ from any path\000"
/* offset=1008613 */ "idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1008981 */ "idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000\000"
/* offset=1009115 */ "idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1009430 */ "idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000"
/* offset=1009676 */ "idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ\000"
/* offset=1010000 */ "idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1010161 */ "idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1010489 */ "idq.mite_cycles_any\000cpu_core\000frontend\000Cycles MITE is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1010842 */ "idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1011207 */ "idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=6,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1011572 */ "idq.mite_cycles_ok\000cpu_core\000frontend\000Cycles MITE is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1011962 */ "idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1012316 */ "idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1012620 */ "idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Increment each cycle # of uops delivered to IDQ from MITE path. Set Cmask = 1 to count cycles\000"
/* offset=1012842 */ "idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1013205 */ "idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1013334 */ "idq.mite_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000"
/* offset=1013663 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1014085 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000"
/* offset=1014378 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the Front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000"
/* offset=1014852 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance.  See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual for more information\000"
/* offset=1015423 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance.  See the Intel? 64 and IA-32 Architectures Optimization Reference Manual for more information\000"
/* offset=1015992 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1016423 */ "idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000"
/* offset=1016716 */ "idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x20\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1017043 */ "idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1017370 */ "idq.ms_cycles_any\000cpu_core\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x20\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1017722 */ "idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1018168 */ "idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000"
/* offset=1018545 */ "idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000This event counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000"
/* offset=1019000 */ "idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1019228 */ "idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000"
/* offset=1019605 */ "idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000"
/* offset=1019936 */ "idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000This event counts the number of deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000"
/* offset=1020351 */ "idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1020559 */ "idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequenser (MS) is busy\000"
/* offset=1020890 */ "idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000"
/* offset=1021234 */ "idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000This event counts the number of uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000"
/* offset=1021671 */ "idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1021882 */ "idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000"
/* offset=1022226 */ "idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1022589 */ "idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000"
/* offset=1022867 */ "idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000This event counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000"
/* offset=1023239 */ "idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000\000"
/* offset=1023418 */ "idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000"
/* offset=1023696 */ "idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000"
/* offset=1024000 */ "idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000"
/* offset=1024194 */ "idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x20\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000"
/* offset=1024432 */ "idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000"
/* offset=1024670 */ "idq.ms_switches\000cpu_core\000frontend\000Number of switches from DSB or MITE to the MS. Unit: cpu_core \000event=0x79,cmask=1,edge=1,period=100003,umask=0x20\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000"
/* offset=1024933 */ "idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS)\000"
/* offset=1025109 */ "idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=100003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000"
/* offset=1025427 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000"
/* offset=1025795 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Increment each cycle # of uops delivered to IDQ from MS by either DSB or MITE. Set Cmask = 1 to count cycles\000"
/* offset=1026055 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts the total number of uops delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000"
/* offset=1026444 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts uops delivered by the Front-end with the assistance of the microcode sequencer.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000"
/* offset=1026879 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000\000"
/* offset=1027031 */ "idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Increment each cycle # of uops delivered to IDQ from MS by either DSB or MITE. Set Cmask = 1 to count cycles\000"
/* offset=1027291 */ "idq.ms_uops\000cpu_core\000frontend\000Uops delivered to IDQ while MS is busy. Unit: cpu_core \000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS)\000"
/* offset=1027492 */ "idq.ms_uops\000cpu_core\000frontend\000Uops initiated by MITE or Decode Stream Buffer (DSB) and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy. Unit: cpu_core \000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE or Decode Stream Buffer (DSB) and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000"
/* offset=1027935 */ "idq_bubbles.core\000\000frontend\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations\000event=0x9c,period=1000003,umask=0x1\000\00000\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations.\nThe count may be distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Frontend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=1028916 */ "idq_bubbles.core\000cpu_core\000frontend\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations. Unit: cpu_core \000event=0x9c,period=1000003,umask=0x1\000\00000\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations.\nThe count may be distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Frontend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=1029922 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1030271 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event count the number of undelivered (unallocated) uops from the Front-end to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled. The Front-end can allocate up to 4 uops per cycle so this event can increment 0-4 times per cycle depending on the number of unallocated uops. This event is counted on a per-core basis  Spec update: HSD135\000"
/* offset=1030856 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled \000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to the back-end per cycle, per thread, when the back-end was not stalled.  In the ideal case 4 uops can be delivered each cycle.  The event counts the undelivered uops - so if 3 were delivered in one cycle, the counter would be incremented by 1 for that cycle (4 - 3). If the back-end is stalled, the count for this event is not incremented even when uops were not delivered, because the back-end would not have been able to accept them.  This event is used in determining the front-end bound category of the top-down pipeline slots characterization\000"
/* offset=1031644 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Count issue pipeline slots where no uop was delivered from the front end to the back end when there is no back-end stall\000"
/* offset=1031951 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when: a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread. b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions).  c. Instruction Decode Queue (IDQ) delivers four uops\000"
/* offset=1032672 */ "idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when:\n a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread;\n b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions); \n c. Instruction Decode Queue (IDQ) delivers four uops\000"
/* offset=1033407 */ "idq_uops_not_delivered.core\000cpu_core\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1033781 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts the number cycles during which the Front-end allocated exactly zero uops to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled.  This event is counted on a per-core basis  Spec update: HSD135\000"
/* offset=1034288 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000"
/* offset=1034662 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000"
/* offset=1035047 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1035288 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=5,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1035701 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=6,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1036114 */ "idq_uops_not_delivered.cycles_0_uops_deliv.core\000cpu_core\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,cmask=6,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1036552 */ "idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE  Spec update: HSD135\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1036763 */ "idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1036953 */ "idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1037389 */ "idq_uops_not_delivered.cycles_fe_was_ok\000cpu_core\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled. Unit: cpu_core \000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000"
/* offset=1037850 */ "idq_uops_not_delivered.cycles_ge_1_uop_deliv.core\000\000frontend\000Cycles when 1 or more uops were delivered to the by the front end\000event=0x9c,cmask=4,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1038031 */ "idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1038295 */ "idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when less than 1 uop is delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >= 3\000"
/* offset=1038680 */ "idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when less than 1 uop is  delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >=3\000"
/* offset=1039076 */ "idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1039319 */ "idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1039505 */ "idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles with less than 2 uops delivered by the front-end\000"
/* offset=1039725 */ "idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1039890 */ "idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1040076 */ "idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with less than 3 uops delivered by the front-end\000"
/* offset=1040296 */ "idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1040461 */ "ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000"
/* offset=1040570 */ "ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1040675 */ "ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000Stall cycles due to IQ is full\000"
/* offset=1040806 */ "ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1040907 */ "ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1041006 */ "ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000"
/* offset=1041607 */ "ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000"
/* offset=1042207 */ "ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts cycles where the decoder is stalled on an instruction with a length changing prefix (LCP)\000"
/* offset=1042438 */ "ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts stalls occurred due to changing prefix length (66, 67 or REX.W when they change the length of the decoded instruction). Occurrences counting is proportional to the number of prefixes in a 16B-line. This may result in the following penalties: three-cycle penalty for each LCP in a 16-byte chunk\000"
/* offset=1042873 */ "ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1042997 */ "ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1043097 */ "ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1043183 */ "inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1043299 */ "inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000"
/* offset=1043511 */ "inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x75,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000"
/* offset=1043723 */ "inst_decoded.decoders\000cpu_core\000pipeline\000Instruction decoders utilized in a cycle. Unit: cpu_core \000event=0x75,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000"
/* offset=1043960 */ "inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1044092 */ "inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1044203 */ "inst_retired.any\000\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000"
/* offset=1044654 */ "inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1044785 */ "inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire.  For instructions that consist of multiple micro-ops, this event counts exactly once, as the last micro-op of the instruction retires.  The event continues counting while instructions retire, including during interrupt service routines caused by hardware interrupts, faults or traps.  Background: Modern microprocessors employ extensive pipelining and speculative techniques.  Since sometimes an instruction is started but never completed, the notion of \"retirement\" is introduced.  A retired instruction is one that commits its states. Or stated differently, an instruction might be abandoned at some point. No instruction is truly finished until it retires.  This counter measures the number of completed instructions.  The fixed event is INST_RETIRED.ANY and the programmable event is INST_RETIRED.ANY_P\000"
/* offset=1045764 */ "inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire.  For instructions that consist of multiple micro-ops, this event counts exactly once, as the last micro-op of the instruction retires.  The event continues counting while instructions retire, including during interrupt service routines caused by hardware interrupts, faults or traps\000"
/* offset=1046219 */ "inst_retired.any\000\000pipeline\000Instructions retired (Fixed event) (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers.  This event uses fixed counter 0.  You cannot collect a PEBs record for this event (Must be precise)\000"
/* offset=1046701 */ "inst_retired.any\000\000pipeline\000Instructions retired (Fixed event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers.  This event uses fixed counter 0.  You cannot collect a PEBs record for this event\000"
/* offset=1047147 */ "inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1047242 */ "inst_retired.any\000\000pipeline\000Instructions retired from execution  Spec update: HSD140, HSD143\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. INST_RETIRED.ANY is counted by a designated fixed counter, leaving the programmable counters available for other events. Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions  Spec update: HSD140, HSD143\000"
/* offset=1047887 */ "inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, Counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. Counting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000"
/* offset=1048616 */ "inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. \nNotes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. \nCounting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000"
/* offset=1049369 */ "inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers\000"
/* offset=1049742 */ "inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1049836 */ "inst_retired.any\000\000pipeline\000Instructions retired\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1049915 */ "inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1050414 */ "inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1050909 */ "inst_retired.any\000cpu_atom\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000"
/* offset=1051385 */ "inst_retired.any\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1051541 */ "inst_retired.any\000cpu_core\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1052065 */ "inst_retired.any_p\000\000pipeline\000Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1052183 */ "inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000"
/* offset=1052656 */ "inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1052764 */ "inst_retired.any_p\000\000pipeline\000Instructions retired (Precise event capable) (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The event continues counting during hardware interrupts, traps, and inside interrupt handlers.  This is an architectural performance event.  This event uses a (_P)rogrammable general purpose performance counter. *This event is Precise Event capable:  The EventingRIP field in the PEBS record is precise to the address of the instruction which caused the event.  Note: Because PEBS records can be collected only on IA32_PMC0, only one event can use the PEBS facility at a time (Must be precise)\000"
/* offset=1053554 */ "inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1053692 */ "inst_retired.any_p\000\000pipeline\000Instructions retired (precise event) (Must be precise)\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1053807 */ "inst_retired.any_p\000\000pipeline\000Instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers\000"
/* offset=1054178 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: BDM61\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: BDM61\000"
/* offset=1054493 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: HSD11, HSD140\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement  Spec update: HSD11, HSD140\000"
/* offset=1054717 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement\000"
/* offset=1054885 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1055017 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event  Spec update: SKL091, SKL044\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: SKL091, SKL044\000"
/* offset=1055337 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1055840 */ "inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1056339 */ "inst_retired.any_p\000cpu_atom\000pipeline\000Counts the number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000\000"
/* offset=1056482 */ "inst_retired.any_p\000cpu_atom\000pipeline\000Counts the total number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000"
/* offset=1056980 */ "inst_retired.any_p\000cpu_core\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000"
/* offset=1057508 */ "inst_retired.macro_fused\000\000pipeline\000INST_RETIRED.MACRO_FUSED\000event=0xc0,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1057610 */ "inst_retired.macro_fused\000cpu_core\000pipeline\000INST_RETIRED.MACRO_FUSED. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1057737 */ "inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1057846 */ "inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions  Spec update: SKL091, SKL044 (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1057998 */ "inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1058121 */ "inst_retired.nop\000\000pipeline\000Retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions (Precise event)\000"
/* offset=1058295 */ "inst_retired.nop\000\000pipeline\000Retired NOP instructions\000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions\000"
/* offset=1058437 */ "inst_retired.nop\000cpu_core\000pipeline\000Retired NOP instructions. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions\000"
/* offset=1058604 */ "inst_retired.prec_dist\000\000pipeline\000Instructions retired - using Reduced Skid PEBS feature (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts INST_RETIRED.ANY using the Reduced Skid PEBS feature that reduces the shadow in which events aren't counted allowing for a more unbiased distribution of samples across instructions retired (Must be precise)\000"
/* offset=1058954 */ "inst_retired.prec_dist\000\000pipeline\000Instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1059091 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: BDM11, BDM55 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000This is a precise version (that is, uses PEBS) of the event that counts instructions retired  Spec update: BDM11, BDM55 (Must be precise)\000"
/* offset=1059440 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000"
/* offset=1059777 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled  Spec update: SKL091, SKL044 (Must be precise)\000"
/* offset=1060286 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000"
/* offset=1060581 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with a reduced effect of PEBS shadow in IP distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000"
/* offset=1061046 */ "inst_retired.prec_dist\000\000pipeline\000Precise instruction retired with PEBS precise-distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a precise distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR++) feature to fix bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000"
/* offset=1061466 */ "inst_retired.prec_dist\000cpu_core\000pipeline\000Precise instruction retired with PEBS precise-distribution (Precise event). Unit: cpu_core \000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a precise distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR++) feature to fix bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000"
/* offset=1061911 */ "inst_retired.rep_iteration\000\000pipeline\000Iterations of Repeat string retired instructions\000event=0xc0,period=2000003,umask=0x8\000\00000\000Number of iterations of Repeat (REP) string retired instructions such as MOVS, CMPS, and SCAS. Each has a byte, word, and doubleword version and string instructions can be repeated using a repetition prefix, REP, that allows their architectural execution to be repeated a number of times as specified by the RCX register. Note the number of iterations is implementation-dependent\000"
/* offset=1062417 */ "inst_retired.rep_iteration\000cpu_core\000pipeline\000Iterations of Repeat string retired instructions. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x8\000\00000\000Number of iterations of Repeat (REP) string retired instructions such as MOVS, CMPS, and SCAS. Each has a byte, word, and doubleword version and string instructions can be repeated using a repetition prefix, REP, that allows their architectural execution to be repeated a number of times as specified by the RCX register. Note the number of iterations is implementation-dependent\000"
/* offset=1062948 */ "inst_retired.stall_cycles\000\000pipeline\000Cycles without actually retired instructions\000event=0xc0,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000This event counts cycles without actually retired instructions\000"
/* offset=1063146 */ "inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1063267 */ "inst_retired.total_cycles_ps\000\000pipeline\000Number of cycles using always true condition applied to  PEBS instructions retired event  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using an always true condition applied to  PEBS instructions retired event. (inst_ret< 16)  Spec update: SKL091, SKL044 (Must be precise)\000"
/* offset=1063652 */ "inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1063776 */ "inst_retired.x87\000\000pipeline\000FP operations  retired. X87 FP operations that have no exceptions:\000event=0xc0,period=2000003,umask=0x2\000\00000\000This event counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000"
/* offset=1064102 */ "inst_retired.x87\000\000pipeline\000FP operations retired. X87 FP operations that have no exceptions: Counts also flows that have several X87 or flows that use X87 uops in the exception handling\000event=0xc0,period=2000003,umask=0x2\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000"
/* offset=1064586 */ "inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1064704 */ "insts_written_to_iq.insts\000\000other\000Valid instructions written to IQ per cycle\000event=0x17,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1064821 */ "int_misc.all_recovery_cycles\000\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000"
/* offset=1065136 */ "int_misc.all_recovery_cycles\000cpu_core\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall. Unit: cpu_core \000event=0xad,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000"
/* offset=1065477 */ "int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xad,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000"
/* offset=1065804 */ "int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xd,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000"
/* offset=1066130 */ "int_misc.clear_resteer_cycles\000\000pipeline\000Cycles the issue-stage is waiting for front-end to fetch from resteered path following branch misprediction or machine clear events\000event=0xd,period=2000003,umask=0x80\000\00000\000\000"
/* offset=1066343 */ "int_misc.clear_resteer_cycles\000cpu_core\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path. Unit: cpu_core \000event=0xad,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000"
/* offset=1066695 */ "int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xad,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000"
/* offset=1066904 */ "int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000"
/* offset=1067113 */ "int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000"
/* offset=1067321 */ "int_misc.clears_count\000cpu_core\000pipeline\000Clears speculative count. Unit: cpu_core \000event=0xad,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000"
/* offset=1067555 */ "int_misc.mba_stalls\000\000pipeline\000INT_MISC.MBA_STALLS\000event=0xad,period=1000003,umask=0x20\000\00000\000\000"
/* offset=1067647 */ "int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x40\000\00000\000\000"
/* offset=1067840 */ "int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x8\000\00000\000This event counts the number of cycles during which Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the current thread. This also includes the cycles during which the Allocator is serving another thread\000"
/* offset=1068279 */ "int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Cycles checkpoints in Resource Allocation Table (RAT) are recovering from JEClear or machine clear\000"
/* offset=1068591 */ "int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000This event counts the number of cycles spent waiting for a recovery after an event such as a processor nuke, JEClear, assist, hle/rtm abort etc\000"
/* offset=1068948 */ "int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,period=2000003,umask=0x1\000\00000\000Core cycles the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000"
/* offset=1069276 */ "int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xad,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000"
/* offset=1069580 */ "int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xd,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000"
/* offset=1069883 */ "int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000"
/* offset=1070200 */ "int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000"
/* offset=1070519 */ "int_misc.recovery_cycles\000cpu_core\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread. Unit: cpu_core \000event=0xad,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000"
/* offset=1070848 */ "int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000"
/* offset=1071258 */ "int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000"
/* offset=1071510 */ "int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1071754 */ "int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000"
/* offset=1072089 */ "int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000"
/* offset=1072426 */ "int_misc.unknown_branch_cycles\000\000pipeline\000INT_MISC.UNKNOWN_BRANCH_CYCLES\000event=0xad,period=1000003,umask=0x40,frontend=0x7\000\00000\000\000"
/* offset=1072553 */ "int_misc.unknown_branch_cycles\000cpu_core\000pipeline\000INT_MISC.UNKNOWN_BRANCH_CYCLES. Unit: cpu_core \000event=0xad,period=1000003,umask=0x40,frontend=0x7\000\00000\000\000"
/* offset=1072705 */ "int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xad,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000"
/* offset=1072919 */ "int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xd,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000"
/* offset=1073132 */ "int_misc.uop_dropping\000cpu_core\000pipeline\000TMA slots where uops got dropped. Unit: cpu_core \000event=0xad,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000"
/* offset=1073371 */ "int_vec_retired.128bit\000\000pipeline\000INT_VEC_RETIRED.128BIT\000event=0xe7,period=1000003,umask=0x13\000\00000\000\000"
/* offset=1073469 */ "int_vec_retired.128bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.128BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x13\000\00000\000\000"
/* offset=1073592 */ "int_vec_retired.256bit\000\000pipeline\000INT_VEC_RETIRED.256BIT\000event=0xe7,period=1000003,umask=0xac\000\00000\000\000"
/* offset=1073690 */ "int_vec_retired.256bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.256BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xac\000\00000\000\000"
/* offset=1073813 */ "int_vec_retired.add_128\000\000pipeline\000integer ADD, SUB, SAD 128-bit vector instructions\000event=0xe7,period=1000003,umask=0x3\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 128-bit vector instructions\000"
/* offset=1074028 */ "int_vec_retired.add_128\000cpu_core\000pipeline\000integer ADD, SUB, SAD 128-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x3\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 128-bit vector instructions\000"
/* offset=1074268 */ "int_vec_retired.add_256\000\000pipeline\000integer ADD, SUB, SAD 256-bit vector instructions\000event=0xe7,period=1000003,umask=0xc\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 256-bit vector instructions\000"
/* offset=1074483 */ "int_vec_retired.add_256\000cpu_core\000pipeline\000integer ADD, SUB, SAD 256-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xc\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 256-bit vector instructions\000"
/* offset=1074723 */ "int_vec_retired.mul_256\000\000pipeline\000INT_VEC_RETIRED.MUL_256\000event=0xe7,period=1000003,umask=0x80\000\00000\000\000"
/* offset=1074823 */ "int_vec_retired.mul_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.MUL_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x80\000\00000\000\000"
/* offset=1074948 */ "int_vec_retired.shuffles\000\000pipeline\000INT_VEC_RETIRED.SHUFFLES\000event=0xe7,period=1000003,umask=0x40\000\00000\000\000"
/* offset=1075050 */ "int_vec_retired.shuffles\000cpu_core\000pipeline\000INT_VEC_RETIRED.SHUFFLES. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x40\000\00000\000\000"
/* offset=1075177 */ "int_vec_retired.vnni_128\000\000pipeline\000INT_VEC_RETIRED.VNNI_128\000event=0xe7,period=1000003,umask=0x10\000\00000\000\000"
/* offset=1075279 */ "int_vec_retired.vnni_128\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_128. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x10\000\00000\000\000"
/* offset=1075406 */ "int_vec_retired.vnni_256\000\000pipeline\000INT_VEC_RETIRED.VNNI_256\000event=0xe7,period=1000003,umask=0x20\000\00000\000\000"
/* offset=1075508 */ "int_vec_retired.vnni_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x20\000\00000\000\000"
/* offset=1075635 */ "io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1075716 */ "issue_slots_not_consumed.any\000\000pipeline\000Unfilled issue slots per cycle\000event=0xca,period=200003\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend due to either a full resource  in the backend (RESOURCE_FULL) or due to the processor recovering from some event (RECOVERY)\000"
/* offset=1076025 */ "issue_slots_not_consumed.recovery\000\000pipeline\000Unfilled issue slots per cycle to recover\000event=0xca,period=200003,umask=0x2\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend because allocation is stalled waiting for a mispredicted jump to retire or other branch-like conditions (e.g. the event is relevant during certain microcode flows).   Counts all issue slots blocked while within this window including slots where uops were not available in the Instruction Queue\000"
/* offset=1076530 */ "issue_slots_not_consumed.resource_full\000\000pipeline\000Unfilled issue slots per cycle because of a full resource in the backend\000event=0xca,period=200003,umask=0x1\000\00000\000Counts the number of issue slots per core cycle that were not consumed because of a full resource in the backend.  Including but not limited to resources such as the Re-order Buffer (ROB), reservation stations (RS), load/store buffers, physical registers, or any other needed machine resource that is currently unavailable.   Note that uops must be available for consumption in order for this event to fire.  If a uop is not available (Instruction Queue is empty), this event will not count\000"
/* offset=1077182 */ "itlb.fills\000\000virtual memory\000Counts the number of times there was an ITLB miss and a new translation was filled into the ITLB\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) and a new translation was filled into the ITLB. The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000"
/* offset=1077697 */ "itlb.flush\000\000virtual memory\000ITLB flushes\000event=0x82,period=200000,umask=0x4\000\00000\000\000"
/* offset=1077777 */ "itlb.hit\000\000virtual memory\000ITLB hits\000event=0x82,period=200000,umask=0x1\000\00000\000\000"
/* offset=1077852 */ "itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100003,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000"
/* offset=1078052 */ "itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000"
/* offset=1078252 */ "itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000"
/* offset=1078539 */ "itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000This event counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000"
/* offset=1078837 */ "itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000\000"
/* offset=1078979 */ "itlb.miss\000\000virtual memory\000ITLB misses\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) for a linear address of an instruction fetch.  It counts when new translation are filled into the ITLB.  The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000"
/* offset=1079465 */ "itlb.misses\000\000virtual memory\000ITLB misses (Must be precise)\000event=0x82,period=200000,umask=0x2\000\00000\000\000"
/* offset=1079563 */ "itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1079644 */ "itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000"
/* offset=1079777 */ "itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000"
/* offset=1079859 */ "itlb_misses.large_page_walk_completed\000\000virtual memory\000Completed page walks in ITLB due to STLB load misses for large pages\000event=0x85,period=100003,umask=0x80\000\00000\000Completed page walks in ITLB due to STLB load misses for large pages\000"
/* offset=1080091 */ "itlb_misses.large_walk_completed\000\000virtual memory\000ITLB miss large page walks\000event=0x85,period=200000,umask=0x80\000\00000\000\000"
/* offset=1080208 */ "itlb_misses.miss_caused_walk\000\000virtual memory\000Counts the number of page walks initiated by a instruction fetch that missed the first and second level TLBs\000event=0x85,period=1000003,umask=0x1\000\00000\000\000"
/* offset=1080403 */ "itlb_misses.miss_caused_walk\000cpu_atom\000virtual memory\000Counts the number of page walks initiated by a instruction fetch that missed the first and second level TLBs. Unit: cpu_atom \000event=0x85,period=1000003,umask=0x1\000\00000\000\000"
/* offset=1080623 */ "itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000"
/* offset=1080900 */ "itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Counts page walks of any page size (4K/2M/4M/1G) caused by a code fetch. This implies it missed in the ITLB and further levels of TLB, but the walk need not have completed\000"
/* offset=1081206 */ "itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in ITLB that causes a page walk of any page size\000"
/* offset=1081396 */ "itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in all ITLB levels that cause page walks\000"
/* offset=1081578 */ "itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000\000"
/* offset=1081713 */ "itlb_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache\000event=0x85,period=2000003,umask=0x80\000\00000\000\000"
/* offset=1081905 */ "itlb_misses.pde_cache_miss\000cpu_atom\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x80\000\00000\000\000"
/* offset=1082122 */ "itlb_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to an instruction fetch that did not start a page walk. Account for all pages sizes. Will result in an ITLB write from STLB\000event=0x85,period=2000003,umask=0x20\000\00000\000\000"
/* offset=1082395 */ "itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x11,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000"
/* offset=1082642 */ "itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000"
/* offset=1082889 */ "itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000\000"
/* offset=1083030 */ "itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000Number of cache load STLB hits. No page walk\000"
/* offset=1083245 */ "itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000\000"
/* offset=1083416 */ "itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000ITLB misses that hit STLB. No page walk\000"
/* offset=1083626 */ "itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000\000"
/* offset=1083797 */ "itlb_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to an instruction fetch that did not start a page walk. Account for all pages sizes. Will result in an ITLB write from STLB. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x20\000\00000\000\000"
/* offset=1084095 */ "itlb_misses.stlb_hit\000cpu_core\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB. Unit: cpu_core \000event=0x11,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000"
/* offset=1084367 */ "itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000ITLB misses that hit STLB (2M)\000"
/* offset=1084532 */ "itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000\000"
/* offset=1084667 */ "itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000ITLB misses that hit STLB (4K)\000"
/* offset=1084832 */ "itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000\000"
/* offset=1084967 */ "itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake microarchitecture\000"
/* offset=1085351 */ "itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x11,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000"
/* offset=1085650 */ "itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000"
/* offset=1085949 */ "itlb_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. Unit: cpu_core \000event=0x11,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000"
/* offset=1086273 */ "itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1086630 */ "itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1086987 */ "itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000"
/* offset=1087383 */ "itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000"
/* offset=1087487 */ "itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0xe\000\00000\000\000"
/* offset=1087648 */ "itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000Misses in all ITLB levels that cause completed page walks\000"
/* offset=1087846 */ "itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000\000"
/* offset=1087987 */ "itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0xe\000\00000\000Completed page walks in ITLB of any page size\000"
/* offset=1088173 */ "itlb_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size. Unit: cpu_atom \000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000"
/* offset=1088594 */ "itlb_misses.walk_completed\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1088976 */ "itlb_misses.walk_completed_1g\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000Counts completed page walks (1G page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1089323 */ "itlb_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 1G page\000event=0x85,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000"
/* offset=1089713 */ "itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x85,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=1090053 */ "itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000\000"
/* offset=1090208 */ "itlb_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to an instruction fetch in a 1GB page\000event=0x85,period=2000003,umask=0x8\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 1GB pages.  The page walks can end with or without a page fault\000"
/* offset=1090540 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)  Spec update: BDM69\000event=0x85,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=1090892 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x11,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1091248 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Completed page walks due to misses in ITLB 2M/4M page entries\000"
/* offset=1091469 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1091825 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 2M or 4M page\000event=0x85,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000"
/* offset=1092231 */ "itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to an instruction fetch in a 2M or 4M page\000event=0x85,period=2000003,umask=0x4\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000"
/* offset=1092575 */ "itlb_misses.walk_completed_2m_4m\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 2M or 4M page. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000"
/* offset=1093006 */ "itlb_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M). Unit: cpu_core \000event=0x11,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1093387 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x85,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000"
/* offset=1093725 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x11,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1094072 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Completed page walks due to misses in ITLB 4K page entries\000"
/* offset=1094284 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1094631 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 4K page\000event=0x85,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000"
/* offset=1095022 */ "itlb_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to an instruction fetch in a 4K page\000event=0x85,period=2000003,umask=0x2\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000"
/* offset=1095351 */ "itlb_misses.walk_completed_4k\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K). Unit: cpu_core \000event=0x11,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000"
/* offset=1095723 */ "itlb_misses.walk_cycles\000\000virtual memory\000ITLB miss page walk cycles\000event=0x85,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1095831 */ "itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000"
/* offset=1096069 */ "itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by ITLB misses\000"
/* offset=1096296 */ "itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000Cycle PMH is busy with a walk\000"
/* offset=1096448 */ "itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000This event count cycles when Page Miss Handler (PMH) is servicing page walks caused by ITLB misses\000"
/* offset=1096669 */ "itlb_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake\000event=0x85,period=100003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH (Page Miss Handler) that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake michroarchitecture\000"
/* offset=1097075 */ "itlb_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle\000event=0x85,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk)\000"
/* offset=1097473 */ "itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x11,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000"
/* offset=1097779 */ "itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x85,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000"
/* offset=1098085 */ "itlb_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to an instruction fetch every cycle\000event=0x85,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to an instruction fetch. Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000"
/* offset=1098450 */ "itlb_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding for iside in PMH every cycle. Unit: cpu_atom \000event=0x85,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for iside in PMH every cycle.  A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals.  Walks could be counted by edge detecting on this event, but would count restarted suspended walks\000"
/* offset=1098940 */ "itlb_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle. Unit: cpu_core \000event=0x11,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000"
/* offset=1099271 */ "l1_data_cache_fills_all\000\000recommended\000L1 Data Cache Fills: All\000event=0x44,umask=0xff\000\00000\000\000"
/* offset=1099360 */ "l1_data_cache_fills_from_external_ccx_cache\000\000recommended\000L1 Data Cache Fills: From External CCX Cache\000event=0x44,umask=0x14\000\00000\000\000"
/* offset=1099489 */ "l1_data_cache_fills_from_memory\000\000recommended\000L1 Data Cache Fills: From Memory\000event=0x44,umask=0x48\000\00000\000\000"
/* offset=1099594 */ "l1_data_cache_fills_from_remote_node\000\000recommended\000L1 Data Cache Fills: From Remote Node\000event=0x44,umask=0x50\000\00000\000\000"
/* offset=1099709 */ "l1_data_cache_fills_from_within_same_ccx\000\000recommended\000L1 Data Cache Fills: From within same CCX\000event=0x44,umask=0x03\000\00000\000\000"
/* offset=1099832 */ "l1_dtlb_misses\000\000recommended\000L1 DTLB Misses\000event=0x45,umask=0xff\000\00000\000\000"
/* offset=1099902 */ "l1d.all_m_replacement\000\000cache\000Cache lines in M state evicted out of L1D due to Snoop HitM or dirty line replacement\000event=0x51,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1100058 */ "l1d.allocated_in_m\000\000cache\000Allocated L1D data cache lines in M state\000event=0x51,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1100167 */ "l1d.eviction\000\000cache\000L1D data cache lines in M state evicted due to replacement\000event=0x51,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1100287 */ "l1d.hwpf_miss\000\000cache\000L1D.HWPF_MISS\000event=0x51,period=1000003,umask=0x20\000\00000\000\000"
/* offset=1100364 */ "l1d.hwpf_miss\000cpu_core\000cache\000L1D.HWPF_MISS. Unit: cpu_core \000event=0x51,period=1000003,umask=0x20\000\00000\000\000"
/* offset=1100466 */ "l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1100562 */ "l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1100662 */ "l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1100773 */ "l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1100860 */ "l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000"
/* offset=1101122 */ "l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000"
/* offset=1101353 */ "l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts the number of lines brought into the L1 data cache\000"
/* offset=1101501 */ "l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000"
/* offset=1101743 */ "l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements.  Replacements occur when a new line is brought into the cache, causing eviction of a line loaded earlier\000"
/* offset=1101984 */ "l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts when new data lines are brought into the L1 Data cache, which cause other lines to be evicted from the cache\000"
/* offset=1102201 */ "l1d.replacement\000cpu_core\000cache\000Counts the number of cache lines replaced in L1 data cache. Unit: cpu_core \000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000"
/* offset=1102488 */ "l1d_all_ref.any\000\000cache\000All references to the L1 data cache\000event=0x43,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1102588 */ "l1d_all_ref.cacheable\000\000cache\000L1 data cacheable reads and writes\000event=0x43,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1102693 */ "l1d_blocks.bank_conflict_cycles\000\000cache\000Cycles when dispatched loads are cancelled due to L1D bank conflicts with other load ports\000event=0xbf,cmask=1,period=100003,umask=0x5\000\00000\000\000"
/* offset=1102871 */ "l1d_cache.all_cache_ref\000\000cache\000L1 Data Cacheable reads and writes\000event=0x40,period=2000000,umask=0xa3\000\00000\000\000"
/* offset=1102979 */ "l1d_cache.all_ref\000\000cache\000L1 Data reads and writes\000event=0x40,period=2000000,umask=0x83\000\00000\000\000"
/* offset=1103071 */ "l1d_cache.evict\000\000cache\000Modified cache lines evicted from the L1 data cache\000event=0x40,period=200000,umask=0x10\000\00000\000\000"
/* offset=1103187 */ "l1d_cache.ld\000\000cache\000L1 Cacheable Data Reads\000event=0x40,period=2000000,umask=0xa1\000\00000\000\000"
/* offset=1103273 */ "l1d_cache.repl\000\000cache\000L1 Data line replacements\000event=0x40,period=200000,umask=0x8\000\00000\000\000"
/* offset=1103361 */ "l1d_cache.replm\000\000cache\000Modified cache lines allocated in the L1 data cache\000event=0x40,period=200000,umask=0x48\000\00000\000\000"
/* offset=1103477 */ "l1d_cache.st\000\000cache\000L1 Cacheable Data Writes\000event=0x40,period=2000000,umask=0xa2\000\00000\000\000"
/* offset=1103564 */ "l1d_cache_ld.e_state\000\000cache\000L1 data cache read in E state\000event=0x40,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1103663 */ "l1d_cache_ld.i_state\000\000cache\000L1 data cache read in I state (misses)\000event=0x40,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1103771 */ "l1d_cache_ld.m_state\000\000cache\000L1 data cache read in M state\000event=0x40,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1103870 */ "l1d_cache_ld.mesi\000\000cache\000L1 data cache reads\000event=0x40,period=2000000,umask=0xf\000\00000\000\000"
/* offset=1103956 */ "l1d_cache_ld.s_state\000\000cache\000L1 data cache read in S state\000event=0x40,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1104055 */ "l1d_cache_lock.e_state\000\000cache\000L1 data cache load locks in E state\000event=0x42,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1104162 */ "l1d_cache_lock.hit\000\000cache\000L1 data cache load lock hits\000event=0x42,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1104258 */ "l1d_cache_lock.m_state\000\000cache\000L1 data cache load locks in M state\000event=0x42,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1104365 */ "l1d_cache_lock.s_state\000\000cache\000L1 data cache load locks in S state\000event=0x42,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1104472 */ "l1d_cache_lock_fb_hit\000\000cache\000L1D load lock accepted in fill buffer\000event=0x53,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1104580 */ "l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1104706 */ "l1d_cache_st.e_state\000\000cache\000L1 data cache stores in E state\000event=0x41,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1104807 */ "l1d_cache_st.m_state\000\000cache\000L1 data cache stores in M state\000event=0x41,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1104908 */ "l1d_cache_st.s_state\000\000cache\000L1 data cache stores in S state\000event=0x41,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1105009 */ "l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers inavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles a demand request was blocked due to Fill Buffers inavailability\000"
/* offset=1105228 */ "l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1105377 */ "l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1105725 */ "l1d_pend_miss.fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch\000event=0x48,period=2000003,umask=0x2\000\00000\000Number of times a request needed a FB (Fill Buffer) entry but there was no entry available for it. A request includes cacheable/uncacheable demands that are load, store or SW prefetch instructions\000"
/* offset=1106236 */ "l1d_pend_miss.fb_full\000cpu_core\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1106609 */ "l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1106980 */ "l1d_pend_miss.fb_full_periods\000cpu_core\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1107376 */ "l1d_pend_miss.l2_stall\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1107717 */ "l1d_pend_miss.l2_stall\000\000cache\000This event is deprecated. Refer to new event L1D_PEND_MISS.L2_STALLS\000event=0x48,period=1000003,umask=0x4\000\00010\000\000"
/* offset=1107857 */ "l1d_pend_miss.l2_stall\000cpu_core\000cache\000This event is deprecated. Refer to new event L1D_PEND_MISS.L2_STALLS. Unit: cpu_core \000event=0x48,period=1000003,umask=0x4\000\00010\000\000"
/* offset=1108022 */ "l1d_pend_miss.l2_stalls\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1108364 */ "l1d_pend_miss.l2_stalls\000cpu_core\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources. Unit: cpu_core \000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000"
/* offset=1108731 */ "l1d_pend_miss.pending\000\000cache\000L1D miss oustandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000"
/* offset=1108948 */ "l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000"
/* offset=1109165 */ "l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1109275 */ "l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch.Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000"
/* offset=1110022 */ "l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand; from the demand Hit FB, if it is allocated by hardware or software prefetch.\nNote: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000"
/* offset=1110782 */ "l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000"
/* offset=1111558 */ "l1d_pend_miss.pending\000cpu_core\000cache\000Number of L1D misses that are outstanding. Unit: cpu_core \000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000"
/* offset=1112359 */ "l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000"
/* offset=1112533 */ "l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000"
/* offset=1112707 */ "l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding in cycles\000"
/* offset=1112892 */ "l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1113017 */ "l1d_pend_miss.pending_cycles\000cpu_core\000cache\000Cycles with L1D load Misses outstanding. Unit: cpu_core \000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000"
/* offset=1113216 */ "l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with L1D load Misses outstanding from any thread on physical core\000"
/* offset=1113456 */ "l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1113624 */ "l1d_pend_miss.request_fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch. HWP are e\000event=0x48,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1113958 */ "l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000"
/* offset=1114052 */ "l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000"
/* offset=1114152 */ "l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000"
/* offset=1114262 */ "l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000"
/* offset=1114358 */ "l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000"
/* offset=1114463 */ "l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000"
/* offset=1114559 */ "l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000"
/* offset=1114645 */ "l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000"
/* offset=1114741 */ "l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1114843 */ "l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1114927 */ "l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1115015 */ "l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000"
/* offset=1115097 */ "l2_ads.self\000\000cache\000Cycles L2 address bus is in use\000event=0x21,period=200000,umask=0x40\000\00000\000\000"
/* offset=1115189 */ "l2_cache_accesses_from_dc_misses\000\000recommended\000L2 Cache Accesses from L1 Data Cache Misses (including prefetch)\000event=0x60,umask=0xc8\000\00000\000\000"
/* offset=1115327 */ "l2_cache_accesses_from_dc_misses\000\000recommended\000L2 Cache Accesses from L1 Data Cache Misses (including prefetch)\000event=0x60,umask=0xe8\000\00000\000\000"
/* offset=1115465 */ "l2_cache_accesses_from_ic_misses\000\000recommended\000L2 Cache Accesses from L1 Instruction Cache Misses (including prefetch)\000event=0x60,umask=0x10\000\00000\000\000"
/* offset=1115610 */ "l2_cache_hits_from_dc_misses\000\000recommended\000L2 Cache Hits from L1 Data Cache Misses\000event=0x64,umask=0x70\000\00000\000\000"
/* offset=1115719 */ "l2_cache_hits_from_dc_misses\000\000recommended\000L2 Cache Hits from L1 Data Cache Misses\000event=0x64,umask=0xf0\000\00000\000\000"
/* offset=1115828 */ "l2_cache_hits_from_ic_misses\000\000recommended\000L2 Cache Hits from L1 Instruction Cache Misses\000event=0x64,umask=0x06\000\00000\000\000"
/* offset=1115944 */ "l2_cache_hits_from_l2_hwpf\000\000recommended\000L2 Cache Hits from L2 Cache HWPF\000event=0x70,umask=0xff\000\00000\000\000"
/* offset=1116044 */ "l2_cache_hits_from_l2_hwpf\000\000recommended\000L2 Cache Hits from L2 HWPF\000event=0x70,umask=0xff\000\00000\000\000"
/* offset=1116138 */ "l2_cache_misses_from_dc_misses\000\000recommended\000L2 Cache Misses from L1 Data Cache Misses\000event=0x64,umask=0x08\000\00000\000\000"
/* offset=1116251 */ "l2_cache_misses_from_ic_miss\000\000recommended\000L2 Cache Misses from L1 Instruction Cache Misses\000event=0x64,umask=0x01\000\00000\000\000"
/* offset=1116369 */ "l2_cache_req_stat.all\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache access\000event=0x64,umask=0xff\000\00000\000\000"
/* offset=1116517 */ "l2_cache_req_stat.dc_access_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data cache access\000event=0x64,umask=0xf8\000\00000\000\000"
/* offset=1116661 */ "l2_cache_req_stat.dc_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data cache hits\000event=0x64,umask=0xf0\000\00000\000\000"
/* offset=1116800 */ "l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for instruction cache access\000event=0x64,umask=0x07\000\00000\000\000"
/* offset=1116951 */ "l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache requests in L2\000event=0x64,umask=0x07\000\00000\000\000"
/* offset=1117124 */ "l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache hits\000event=0x64,umask=0xf6\000\00000\000\000"
/* offset=1117282 */ "l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request hit in L2 and Data cache request hit in L2 (all types)\000event=0x64,umask=0xf6\000\00000\000\000"
/* offset=1117503 */ "l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache misses\000event=0x64,umask=0x09\000\00000\000\000"
/* offset=1117664 */ "l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2 and Data cache request miss in L2 (all types)\000event=0x64,umask=0x09\000\00000\000\000"
/* offset=1117888 */ "l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache hit non-modifiable line in L2\000event=0x64,umask=0x02\000\00000\000\000"
/* offset=1118069 */ "l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit clean line in L2\000event=0x64,umask=0x02\000\00000\000\000"
/* offset=1118246 */ "l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit non-modifiable line in L2\000event=0x64,umask=0x02\000\00000\000\000"
/* offset=1118432 */ "l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000"
/* offset=1118609 */ "l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000"
/* offset=1118791 */ "l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache request miss in L2\000event=0x64,umask=0x01\000\00000\000\000"
/* offset=1118960 */ "l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2. Use l2_cache_misses_from_ic_miss instead\000event=0x64,umask=0x01\000\00000\000\000"
/* offset=1119176 */ "l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2\000event=0x64,umask=0x01\000\00000\000\000"
/* offset=1119350 */ "l2_cache_req_stat.ic_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for instruction cache hits\000event=0x64,umask=0x06\000\00000\000\000"
/* offset=1119496 */ "l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache request miss in L2\000event=0x64,umask=0x08\000\00000\000\000"
/* offset=1119657 */ "l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache request miss in L2 (all types). Use l2_cache_misses_from_dc_misses instead\000event=0x64,umask=0x08\000\00000\000\000"
/* offset=1119879 */ "l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache request miss in L2 (all types)\000event=0x64,umask=0x08\000\00000\000\000"
/* offset=1120057 */ "l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000"
/* offset=1120222 */ "l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000"
/* offset=1120392 */ "l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache read hit non-modifiable line in L2\000event=0x64,umask=0x20\000\00000\000\000"
/* offset=1120575 */ "l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit non-modifiable line in L2\000event=0x64,umask=0x20\000\00000\000\000"
/* offset=1120763 */ "l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit on shared line in L2\000event=0x64,umask=0x20\000\00000\000\000"
/* offset=1120946 */ "l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache read hit modifiable line in L2\000event=0x64,umask=0x40\000\00000\000\000"
/* offset=1121125 */ "l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit in L2. Modifiable\000event=0x64,umask=0x40\000\00000\000\000"
/* offset=1121305 */ "l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit in L2\000event=0x64,umask=0x40\000\00000\000\000"
/* offset=1121473 */ "l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000"
/* offset=1121647 */ "l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000"
/* offset=1121826 */ "l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000"
/* offset=1121913 */ "l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000"
/* offset=1122021 */ "l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000"
/* offset=1122138 */ "l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000"
/* offset=1122246 */ "l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000"
/* offset=1122343 */ "l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000"
/* offset=1122451 */ "l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000"
/* offset=1122560 */ "l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000"
/* offset=1122682 */ "l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000"
/* offset=1122791 */ "l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000"
/* offset=1122890 */ "l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000"
/* offset=1123003 */ "l2_data_rqsts.self.e_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x44\000\00000\000\000"
/* offset=1123119 */ "l2_data_rqsts.self.i_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x41\000\00000\000\000"
/* offset=1123235 */ "l2_data_rqsts.self.m_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x48\000\00000\000\000"
/* offset=1123351 */ "l2_data_rqsts.self.mesi\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1123464 */ "l2_data_rqsts.self.s_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x42\000\00000\000\000"
/* offset=1123580 */ "l2_dbus_busy.self\000\000cache\000Cycles the L2 cache data bus is busy\000event=0x22,period=200000,umask=0x40\000\00000\000\000"
/* offset=1123683 */ "l2_dbus_busy_rd.self\000\000cache\000Cycles the L2 transfers data to the core\000event=0x23,period=200000,umask=0x40\000\00000\000\000"
/* offset=1123793 */ "l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000Not rejected writebacks that hit L2 cache\000"
/* offset=1123947 */ "l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000This event counts the number of WB requests that hit L2 cache\000"
/* offset=1124121 */ "l2_dtlb_misses\000\000recommended\000L2 DTLB Misses & Data page walks\000event=0x45,umask=0xf0\000\00000\000\000"
/* offset=1124209 */ "l2_fill_pending.l2_fill_busy\000\000cache\000Cycles with fill pending from L2. Total cycles spent with one or more fill requests in flight from L2\000event=0x6d,umask=0x01\000\00000\000\000"
/* offset=1124374 */ "l2_ifetch.self.e_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x44\000\00000\000\000"
/* offset=1124485 */ "l2_ifetch.self.i_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x41\000\00000\000\000"
/* offset=1124596 */ "l2_ifetch.self.m_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x48\000\00000\000\000"
/* offset=1124707 */ "l2_ifetch.self.mesi\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1124815 */ "l2_ifetch.self.s_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x42\000\00000\000\000"
/* offset=1124926 */ "l2_itlb_misses\000\000recommended\000L2 ITLB Misses & Instruction page walks\000event=0x85,umask=0x07\000\00000\000\000"
/* offset=1125021 */ "l2_l1d_wb_rqsts.all\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in any state\000event=0x28,period=200003,umask=0xf\000\00000\000\000"
/* offset=1125152 */ "l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000Not rejected writebacks from L1D to L2 cache lines in E state\000"
/* offset=1125344 */ "l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000\000"
/* offset=1125475 */ "l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000Not rejected writebacks from L1D to L2 cache lines in M state\000"
/* offset=1125667 */ "l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000\000"
/* offset=1125798 */ "l2_l1d_wb_rqsts.hit_s\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in S state\000event=0x28,period=200003,umask=0x2\000\00000\000\000"
/* offset=1125929 */ "l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000Not rejected writebacks that missed LLC\000"
/* offset=1126135 */ "l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000\000"
/* offset=1126302 */ "l2_latency.l2_cycles_waiting_on_fills\000\000cache\000Total cycles spent waiting for L2 fills to complete from L3 or memory, divided by four. Event counts are for both threads. To calculate average latency, the number of fills from both threads must be used\000event=0x62,umask=0x01\000\00000\000\000"
/* offset=1126578 */ "l2_ld.self.any.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x74\000\00000\000\000"
/* offset=1126664 */ "l2_ld.self.any.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x71\000\00000\000\000"
/* offset=1126750 */ "l2_ld.self.any.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x78\000\00000\000\000"
/* offset=1126836 */ "l2_ld.self.any.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x7f\000\00000\000\000"
/* offset=1126919 */ "l2_ld.self.any.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x72\000\00000\000\000"
/* offset=1127005 */ "l2_ld.self.demand.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x44\000\00000\000\000"
/* offset=1127094 */ "l2_ld.self.demand.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x41\000\00000\000\000"
/* offset=1127183 */ "l2_ld.self.demand.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x48\000\00000\000\000"
/* offset=1127272 */ "l2_ld.self.demand.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1127358 */ "l2_ld.self.demand.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x42\000\00000\000\000"
/* offset=1127447 */ "l2_ld.self.prefetch.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x54\000\00000\000\000"
/* offset=1127538 */ "l2_ld.self.prefetch.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x51\000\00000\000\000"
/* offset=1127629 */ "l2_ld.self.prefetch.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x58\000\00000\000\000"
/* offset=1127720 */ "l2_ld.self.prefetch.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x5f\000\00000\000\000"
/* offset=1127808 */ "l2_ld.self.prefetch.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x52\000\00000\000\000"
/* offset=1127899 */ "l2_ld_ifetch.self.e_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x44\000\00000\000\000"
/* offset=1128027 */ "l2_ld_ifetch.self.i_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x41\000\00000\000\000"
/* offset=1128155 */ "l2_ld_ifetch.self.m_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x48\000\00000\000\000"
/* offset=1128283 */ "l2_ld_ifetch.self.mesi\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1128408 */ "l2_ld_ifetch.self.s_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x42\000\00000\000\000"
/* offset=1128536 */ "l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0x25,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000"
/* offset=1128709 */ "l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000"
/* offset=1128882 */ "l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000L2 cache lines filling L2\000"
/* offset=1128996 */ "l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines brought into the L2 cache.  Lines are filled into the L2 cache when there was an L2 miss\000"
/* offset=1129220 */ "l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000"
/* offset=1129403 */ "l2_lines_in.all\000cpu_core\000cache\000L2 cache lines filling L2. Unit: cpu_core \000event=0x25,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000"
/* offset=1129601 */ "l2_lines_in.any\000\000cache\000L2 lines alloacated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000"
/* offset=1129684 */ "l2_lines_in.any\000\000cache\000L2 lines allocated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000"
/* offset=1129766 */ "l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000L2 cache lines in E state filling L2\000"
/* offset=1129900 */ "l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000This event counts the number of L2 cache lines in the Exclusive state filling the L2. Counting does not cover rejects\000"
/* offset=1130115 */ "l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000\000"
/* offset=1130213 */ "l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000"
/* offset=1130314 */ "l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000L2 cache lines in I state filling L2\000"
/* offset=1130448 */ "l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000This event counts the number of L2 cache lines in the Invalidate state filling the L2. Counting does not cover rejects\000"
/* offset=1130664 */ "l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000\000"
/* offset=1130762 */ "l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000L2 cache lines in S state filling L2\000"
/* offset=1130896 */ "l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000This event counts the number of L2 cache lines in the Shared state filling the L2. Counting does not cover rejects\000"
/* offset=1131108 */ "l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000\000"
/* offset=1131206 */ "l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000"
/* offset=1131307 */ "l2_lines_in.self.any\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x70\000\00000\000\000"
/* offset=1131392 */ "l2_lines_in.self.demand\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x40\000\00000\000\000"
/* offset=1131480 */ "l2_lines_in.self.prefetch\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x50\000\00000\000\000"
/* offset=1131570 */ "l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000"
/* offset=1131651 */ "l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000Clean L2 cache lines evicted by demand\000"
/* offset=1131801 */ "l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000\000"
/* offset=1131913 */ "l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000Clean L2 cache lines evicted by demand\000"
/* offset=1132063 */ "l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000\000"
/* offset=1132175 */ "l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000"
/* offset=1132285 */ "l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000Dirty L2 cache lines evicted by demand\000"
/* offset=1132435 */ "l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000\000"
/* offset=1132547 */ "l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x6\000\00000\000Dirty L2 cache lines evicted by demand\000"
/* offset=1132697 */ "l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000"
/* offset=1132816 */ "l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000Dirty L2 cache lines filling the L2\000"
/* offset=1132957 */ "l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000\000"
/* offset=1133063 */ "l2_lines_out.non_silent\000\000cache\000Cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by the L2 cache due to L2 cache fills.  Evicted lines are delivered to the L3, which may or may not cache them, according to system load and priorities\000"
/* offset=1133405 */ "l2_lines_out.non_silent\000\000cache\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000event=0xf2,period=200003,umask=0x2\000\00000\000\000"
/* offset=1133641 */ "l2_lines_out.non_silent\000\000cache\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000"
/* offset=1134329 */ "l2_lines_out.non_silent\000\000cache\000L2_LINES_OUT.NON_SILENT\000event=0x26,period=200003,umask=0x2\000\00000\000\000"
/* offset=1134424 */ "l2_lines_out.non_silent\000\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000"
/* offset=1134744 */ "l2_lines_out.non_silent\000cpu_core\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill. Unit: cpu_core \000event=0x26,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000"
/* offset=1135089 */ "l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000Clean L2 cache lines evicted by the MLC prefetcher\000"
/* offset=1135252 */ "l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000\000"
/* offset=1135365 */ "l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000Dirty L2 cache lines evicted by the MLC prefetcher\000"
/* offset=1135528 */ "l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000\000"
/* offset=1135641 */ "l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000"
/* offset=1135755 */ "l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000"
/* offset=1135878 */ "l2_lines_out.self.any\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x70\000\00000\000\000"
/* offset=1135971 */ "l2_lines_out.self.demand\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x40\000\00000\000\000"
/* offset=1136067 */ "l2_lines_out.self.prefetch\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x50\000\00000\000\000"
/* offset=1136165 */ "l2_lines_out.silent\000\000cache\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000event=0xf2,period=200003,umask=0x1\000\00000\000\000"
/* offset=1136410 */ "l2_lines_out.silent\000\000cache\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared state. A non-threaded event\000event=0xf2,period=200003,umask=0x1\000\00000\000\000"
/* offset=1136642 */ "l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0x26,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000"
/* offset=1136984 */ "l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000"
/* offset=1137326 */ "l2_lines_out.silent\000cpu_core\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill. Unit: cpu_core \000event=0x26,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000"
/* offset=1137693 */ "l2_lines_out.useless_hwpf\000\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses\000event=0x26,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000"
/* offset=1137997 */ "l2_lines_out.useless_hwpf\000\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses\000event=0xf2,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000"
/* offset=1138301 */ "l2_lines_out.useless_hwpf\000\000cache\000Counts the number of lines that have been hardware prefetched but not used and now evicted by L2 cache\000event=0xf2,period=200003,umask=0x4\000\00000\000\000"
/* offset=1138477 */ "l2_lines_out.useless_hwpf\000cpu_core\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses. Unit: cpu_core \000event=0x26,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000"
/* offset=1138806 */ "l2_lines_out.useless_pref\000\000cache\000This event is deprecated. Refer to new event L2_LINES_OUT.USELESS_HWPF\000event=0xf2,period=200003,umask=0x4\000\00010\000\000"
/* offset=1138950 */ "l2_lock.self.e_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x44\000\00000\000\000"
/* offset=1139038 */ "l2_lock.self.i_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x41\000\00000\000\000"
/* offset=1139126 */ "l2_lock.self.m_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x48\000\00000\000\000"
/* offset=1139214 */ "l2_lock.self.mesi\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1139299 */ "l2_lock.self.s_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x42\000\00000\000\000"
/* offset=1139387 */ "l2_m_lines_in.self\000\000cache\000L2 cache line modifications\000event=0x25,period=200000,umask=0x40\000\00000\000\000"
/* offset=1139482 */ "l2_m_lines_out.self.any\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x70\000\00000\000\000"
/* offset=1139595 */ "l2_m_lines_out.self.demand\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x40\000\00000\000\000"
/* offset=1139711 */ "l2_m_lines_out.self.prefetch\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x50\000\00000\000\000"
/* offset=1139829 */ "l2_no_req.self\000\000cache\000Cycles no L2 cache requests are pending\000event=0x32,period=200000,umask=0x40\000\00000\000\000"
/* offset=1139932 */ "l2_pf_hit_l2.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of all types\000event=0x70,umask=0xff\000\00000\000\000"
/* offset=1140064 */ "l2_pf_hit_l2.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x70,umask=0x80\000\00000\000\000"
/* offset=1140379 */ "l2_pf_hit_l2.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x70,umask=0x20\000\00000\000\000"
/* offset=1140571 */ "l2_pf_hit_l2.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x70,umask=0x40\000\00000\000\000"
/* offset=1140810 */ "l2_pf_hit_l2.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x70,umask=0x08\000\00000\000\000"
/* offset=1141013 */ "l2_pf_hit_l2.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2NextLine (fetch the next line into L2 cache)\000event=0x70,umask=0x02\000\00000\000\000"
/* offset=1141196 */ "l2_pf_hit_l2.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x70,umask=0x01\000\00000\000\000"
/* offset=1141388 */ "l2_pf_hit_l2.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Stride (fetch additional lines into L2 cache when each access is at a constant distance from the previous)\000event=0x70,umask=0x10\000\00000\000\000"
/* offset=1141630 */ "l2_pf_hit_l2.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x70,umask=0x04\000\00000\000\000"
/* offset=1141845 */ "l2_pf_hit_l2\000\000cache\000L2 prefetch hit in L2. Use l2_cache_hits_from_l2_hwpf instead\000event=0x70,umask=0xff\000\00000\000\000"
/* offset=1141954 */ "l2_pf_miss_l2_hit_l3.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache cache of all types\000event=0x71,umask=0xff\000\00000\000\000"
/* offset=1142122 */ "l2_pf_miss_l2_hit_l3.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x71,umask=0x80\000\00000\000\000"
/* offset=1142467 */ "l2_pf_miss_l2_hit_l3.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x71,umask=0x20\000\00000\000\000"
/* offset=1142689 */ "l2_pf_miss_l2_hit_l3.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x71,umask=0x40\000\00000\000\000"
/* offset=1142958 */ "l2_pf_miss_l2_hit_l3.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x71,umask=0x08\000\00000\000\000"
/* offset=1143191 */ "l2_pf_miss_l2_hit_l3.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2NextLine (fetch the next line into L2 cache)\000event=0x71,umask=0x02\000\00000\000\000"
/* offset=1143404 */ "l2_pf_miss_l2_hit_l3.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x71,umask=0x01\000\00000\000\000"
/* offset=1143626 */ "l2_pf_miss_l2_hit_l3.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Stride (fetch additional lines into L2 cache when each access is a constant distance from the previous)\000event=0x71,umask=0x10\000\00000\000\000"
/* offset=1143895 */ "l2_pf_miss_l2_hit_l3.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x71,umask=0x04\000\00000\000\000"
/* offset=1144140 */ "l2_pf_miss_l2_hit_l3\000\000cache\000L2 prefetcher hits in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit the L3\000event=0x71,umask=0xff\000\00000\000\000"
/* offset=1144313 */ "l2_pf_miss_l2_l3.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of all types\000event=0x72,umask=0xff\000\00000\000\000"
/* offset=1144459 */ "l2_pf_miss_l2_l3.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x72,umask=0x80\000\00000\000\000"
/* offset=1144788 */ "l2_pf_miss_l2_l3.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x72,umask=0x20\000\00000\000\000"
/* offset=1144994 */ "l2_pf_miss_l2_l3.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x72,umask=0x40\000\00000\000\000"
/* offset=1145247 */ "l2_pf_miss_l2_l3.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x72,umask=0x08\000\00000\000\000"
/* offset=1145464 */ "l2_pf_miss_l2_l3.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2NextLine (fetch the next line into L2 cache)\000event=0x72,umask=0x02\000\00000\000\000"
/* offset=1145661 */ "l2_pf_miss_l2_l3.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x72,umask=0x01\000\00000\000\000"
/* offset=1145867 */ "l2_pf_miss_l2_l3.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Stride (fetch additional lines into L2 cache when each access is a constant distance from the previous)\000event=0x72,umask=0x10\000\00000\000\000"
/* offset=1146120 */ "l2_pf_miss_l2_l3.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x72,umask=0x04\000\00000\000\000"
/* offset=1146349 */ "l2_pf_miss_l2_l3\000\000cache\000L2 prefetcher misses in L3. All L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches\000event=0x72,umask=0xff\000\00000\000\000"
/* offset=1146510 */ "l2_pf_miss_l2_l3\000\000cache\000L2 prefetcher misses in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches\000event=0x72,umask=0xff\000\00000\000\000"
/* offset=1146678 */ "l2_reject_busq.self.any.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x74\000\00000\000\000"
/* offset=1146785 */ "l2_reject_busq.self.any.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x71\000\00000\000\000"
/* offset=1146892 */ "l2_reject_busq.self.any.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x78\000\00000\000\000"
/* offset=1146999 */ "l2_reject_busq.self.any.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x7f\000\00000\000\000"
/* offset=1147103 */ "l2_reject_busq.self.any.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x72\000\00000\000\000"
/* offset=1147210 */ "l2_reject_busq.self.demand.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x44\000\00000\000\000"
/* offset=1147320 */ "l2_reject_busq.self.demand.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x41\000\00000\000\000"
/* offset=1147430 */ "l2_reject_busq.self.demand.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x48\000\00000\000\000"
/* offset=1147540 */ "l2_reject_busq.self.demand.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1147647 */ "l2_reject_busq.self.demand.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x42\000\00000\000\000"
/* offset=1147757 */ "l2_reject_busq.self.prefetch.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x54\000\00000\000\000"
/* offset=1147869 */ "l2_reject_busq.self.prefetch.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x51\000\00000\000\000"
/* offset=1147981 */ "l2_reject_busq.self.prefetch.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x58\000\00000\000\000"
/* offset=1148093 */ "l2_reject_busq.self.prefetch.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x5f\000\00000\000\000"
/* offset=1148202 */ "l2_reject_busq.self.prefetch.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x52\000\00000\000\000"
/* offset=1148314 */ "l2_reject_xq.all\000\000cache\000Counts the number of request from the L2 that were not accepted into the XQ\000event=0x30,period=200003\000\00000\000This event counts the number of demand and prefetch transactions that the L2 XQ rejects due to a full or near full condition which likely indicates back pressure from the IDI link. The XQ may reject transactions from the L2Q (non-cacheable requests), BBS (L2 misses) and WOB (L2 write-back victims)\000"
/* offset=1148742 */ "l2_reject_xq.all\000\000cache\000Requests rejected by the XQ\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the L2 XQ rejects due to a full or near full condition which likely indicates back pressure from the intra-die interconnect (IDI) fabric. The XQ may reject transactions from the L2Q (non-cacheable requests), L2 misses and L2 write-back victims\000"
/* offset=1149126 */ "l2_reject_xq.any\000\000cache\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition which likely indicates back pressure from the IDI link.  The XQ may reject transactions from the L2Q (non-cacheable requests), BBL (L2 misses) and WOB (L2 write-back victims)\000"
/* offset=1149610 */ "l2_request.all\000\000cache\000All accesses to L2 cache [This event is alias to L2_RQSTS.REFERENCES]\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.REFERENCES]\000"
/* offset=1149916 */ "l2_request.all\000\000cache\000Counts the total number of L2 Cache accesses. Counts on a per core basis\000event=0x24,period=200003\000\00000\000Counts the total number of L2 Cache Accesses, includes hits, misses, rejects  front door requests for CRd/DRd/RFO/ItoM/L2 Prefetches only.  Counts on a per core basis\000"
/* offset=1150207 */ "l2_request.all\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_RQSTS.REFERENCES]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.REFERENCES]\000"
/* offset=1150538 */ "l2_request.hit\000\000cache\000Counts the number of L2 Cache accesses that resulted in a hit. Counts on a per core basis\000event=0x24,period=200003,umask=0x2\000\00000\000Counts the number of L2 Cache accesses that resulted in a hit from a front door request only (does not include rejects or recycles), Counts on a per core basis\000"
/* offset=1150849 */ "l2_request.hit\000cpu_core\000cache\000All requests that hit L2 cache. [This event is alias to L2_RQSTS.HIT]. Unit: cpu_core \000event=0x24,period=200003,umask=0xdf\000\00000\000Counts all requests that hit L2 cache. [This event is alias to L2_RQSTS.HIT]\000"
/* offset=1151083 */ "l2_request.miss\000\000cache\000Counts the number of L2 Cache accesses that resulted in a miss. Counts on a per core basis\000event=0x24,period=200003,umask=0x1\000\00000\000Counts the number of L2 Cache accesses that resulted in a miss from a front door request only (does not include rejects or recycles). Counts on a per core basis\000"
/* offset=1151397 */ "l2_request.miss\000\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_RQSTS.MISS]\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000"
/* offset=1151715 */ "l2_request.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache [This event is alias to L2_RQSTS.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000"
/* offset=1152057 */ "l2_request.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_RQSTS.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000"
/* offset=1152400 */ "l2_request.rejects\000\000cache\000Counts the number of L2 Cache accesses that miss the L2 and get rejected. Counts on a per core basis\000event=0x24,period=200003,umask=0x4\000\00000\000Counts the number of L2 Cache accesses that miss the L2 and get BBL reject  short and long rejects (includes those counted in L2_reject_XQ.any). Counts on a per core basis\000"
/* offset=1152738 */ "l2_request_g1.all\000\000cache\000L2 cache requests of all types\000event=0x60,umask=0xff\000\00000\000\000"
/* offset=1152821 */ "l2_request_g1.all_dc\000\000cache\000L2 cache requests of common types from L1 data cache (including prefetches)\000event=0x60,umask=0xe8\000\00000\000\000"
/* offset=1152952 */ "l2_request_g1.all_no_prefetch\000\000cache\000L2 cache requests of common types not including prefetches\000event=0x60,umask=0xf9\000\00000\000\000"
/* offset=1153075 */ "l2_request_g1.all_no_prefetch\000\000cache\000\000event=0x60,umask=0xf9\000\00000\000\000"
/* offset=1153140 */ "l2_request_g1.cacheable_ic_read\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000"
/* offset=1153276 */ "l2_request_g1.cacheable_ic_read\000\000cache\000L2 cache requests: instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000"
/* offset=1153385 */ "l2_request_g1.change_to_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache state change requests. Request change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000"
/* offset=1153580 */ "l2_request_g1.change_to_x\000\000cache\000L2 cache requests: data cache state change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000"
/* offset=1153723 */ "l2_request_g1.group2\000\000cache\000L2 cache requests of non-cacheable type (non-cached data and instructions reads, self-modifying code checks)\000event=0x60,umask=0x01\000\00000\000\000"
/* offset=1153887 */ "l2_request_g1.group2\000\000cache\000Miscellaneous events covered in more detail by l2_request_g2 (PMCx061)\000event=0x60,umask=0x01\000\00000\000\000"
/* offset=1154013 */ "l2_request_g1.l2_hw_pf\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). L2 Prefetcher. All prefetches accepted by L2 pipeline, hit or miss. Types of PF and L2 hit/miss broken out in a separate perfmon event\000event=0x60,umask=0x02\000\00000\000\000"
/* offset=1154251 */ "l2_request_g1.l2_hw_pf\000\000cache\000L2 cache requests: from hardware prefetchers to prefetch directly into L2 (hit or miss)\000event=0x60,umask=0x02\000\00000\000\000"
/* offset=1154396 */ "l2_request_g1.ls_rd_blk_c_s\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000"
/* offset=1154528 */ "l2_request_g1.ls_rd_blk_c_s\000\000cache\000L2 cache requests: data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000"
/* offset=1154633 */ "l2_request_g1.prefetch_l2_cmd\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). PrefetchL2Cmd\000event=0x60,umask=0x04\000\00000\000\000"
/* offset=1154757 */ "l2_request_g1.prefetch_l2_cmd\000\000cache\000L2 cache requests: prefetch directly into L2\000event=0x60,umask=0x04\000\00000\000\000"
/* offset=1154866 */ "l2_request_g1.rd_blk_l\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache reads (including hardware and software prefetch)\000event=0x60,umask=0x80\000\00000\000\000"
/* offset=1155029 */ "l2_request_g1.rd_blk_l\000\000cache\000L2 cache requests: data cache reads including hardware and software prefetch\000event=0x60,umask=0x80\000\00000\000\000"
/* offset=1155163 */ "l2_request_g1.rd_blk_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache stores\000event=0x60,umask=0x40\000\00000\000\000"
/* offset=1155284 */ "l2_request_g1.rd_blk_x\000\000cache\000L2 cache requests: data cache stores\000event=0x60,umask=0x40\000\00000\000\000"
/* offset=1155378 */ "l2_request_g2.bus_locks_originator\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus locks\000event=0x61,umask=0x02\000\00000\000\000"
/* offset=1155501 */ "l2_request_g2.bus_locks_responses\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus lock response\000event=0x61,umask=0x01\000\00000\000\000"
/* offset=1155631 */ "l2_request_g2.group1\000\000cache\000Miscellaneous events covered in more detail by l2_request_g1 (PMCx060)\000event=0x61,umask=0x80\000\00000\000\000"
/* offset=1155757 */ "l2_request_g2.ic_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized\000event=0x61,umask=0x10\000\00000\000\000"
/* offset=1155890 */ "l2_request_g2.ic_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized non-cacheable\000event=0x61,umask=0x08\000\00000\000\000"
/* offset=1156040 */ "l2_request_g2.ls_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized\000event=0x61,umask=0x40\000\00000\000\000"
/* offset=1156166 */ "l2_request_g2.ls_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized non-cacheable\000event=0x61,umask=0x20\000\00000\000\000"
/* offset=1156309 */ "l2_request_g2.smc_inval\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Self-modifying code invalidates\000event=0x61,umask=0x04\000\00000\000\000"
/* offset=1156443 */ "l2_requests.miss\000\000cache\000Counts the number of L2 cache misses\000event=0x2e,period=200003,umask=0x41\000\00000\000\000"
/* offset=1156545 */ "l2_requests.reference\000\000cache\000Counts the total number of L2 cache references\000event=0x2e,period=200003,umask=0x4f\000\00000\000\000"
/* offset=1156662 */ "l2_requests_reject.all\000\000cache\000Counts the number of MEC requests from the L2Q that reference a cache line (cacheable requests) excluding SW prefetches filling only to L2 cache and L1 evictions (automatically exlcudes L2HWP, UC, WC) that were rejected - Multiple repeated rejects should be counted multiple times\000event=0x30,period=200003\000\00000\000\000"
/* offset=1157003 */ "l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 code requests\000"
/* offset=1157116 */ "l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000\000"
/* offset=1157202 */ "l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts all L2 code requests\000"
/* offset=1157315 */ "l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000"
/* offset=1157444 */ "l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000This event counts the total number of L2 code requests\000"
/* offset=1157584 */ "l2_rqsts.all_code_rd\000cpu_core\000cache\000L2 code requests. Unit: cpu_core \000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000"
/* offset=1157738 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read access L2 cache\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000"
/* offset=1158036 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2  Spec update: HSD78, HSM80\000"
/* offset=1158253 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2\000"
/* offset=1158415 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000\000"
/* offset=1158516 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000"
/* offset=1158790 */ "l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000This event counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000"
/* offset=1159075 */ "l2_rqsts.all_demand_data_rd\000cpu_core\000cache\000Demand Data Read access L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000"
/* offset=1159398 */ "l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000"
/* offset=1159594 */ "l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000"
/* offset=1159743 */ "l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache\000"
/* offset=1159885 */ "l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000\000"
/* offset=1159993 */ "l2_rqsts.all_demand_miss\000cpu_core\000cache\000Demand requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000"
/* offset=1160167 */ "l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000"
/* offset=1160355 */ "l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000"
/* offset=1160496 */ "l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache\000"
/* offset=1160630 */ "l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000\000"
/* offset=1160737 */ "l2_rqsts.all_demand_references\000cpu_core\000cache\000Demand requests to L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000"
/* offset=1160903 */ "l2_rqsts.all_hwpf\000\000cache\000L2_RQSTS.ALL_HWPF\000event=0x24,period=200003,umask=0xf0\000\00000\000\000"
/* offset=1160987 */ "l2_rqsts.all_hwpf\000cpu_core\000cache\000L2_RQSTS.ALL_HWPF. Unit: cpu_core \000event=0x24,period=200003,umask=0xf0\000\00000\000\000"
/* offset=1161096 */ "l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000Counts all L2 HW prefetcher requests\000"
/* offset=1161234 */ "l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000\000"
/* offset=1161336 */ "l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts all L2 HW prefetcher requests\000"
/* offset=1161474 */ "l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000This event counts the total number of requests from the L2 hardware prefetchers\000"
/* offset=1161655 */ "l2_rqsts.all_pf\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts the total number of requests from the L2 hardware prefetchers\000"
/* offset=1161863 */ "l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000Counts all L2 store RFO requests\000"
/* offset=1161984 */ "l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000\000"
/* offset=1162073 */ "l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts all L2 store RFO requests\000"
/* offset=1162195 */ "l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000"
/* offset=1162439 */ "l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000This event counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000"
/* offset=1162694 */ "l2_rqsts.all_rfo\000cpu_core\000cache\000RFO requests to L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000"
/* offset=1162963 */ "l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000Number of instruction fetches that hit the L2 cache\000"
/* offset=1163136 */ "l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000\000"
/* offset=1163258 */ "l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000"
/* offset=1163439 */ "l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Number of instruction fetches that hit the L2 cache\000"
/* offset=1163612 */ "l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000\000"
/* offset=1163734 */ "l2_rqsts.code_rd_hit\000cpu_core\000cache\000L2 cache hits when fetching instructions, code reads. Unit: cpu_core \000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000"
/* offset=1163940 */ "l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000Number of instruction fetches that missed the L2 cache\000"
/* offset=1164107 */ "l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000\000"
/* offset=1164220 */ "l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000"
/* offset=1164382 */ "l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Number of instruction fetches that missed the L2 cache\000"
/* offset=1164549 */ "l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000\000"
/* offset=1164662 */ "l2_rqsts.code_rd_miss\000cpu_core\000cache\000L2 cache misses when fetching instructions. Unit: cpu_core \000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000"
/* offset=1164849 */ "l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache  Spec update: HSD78, HSM80\000"
/* offset=1165120 */ "l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000Demand Data Read requests that hit L2 cache\000"
/* offset=1165282 */ "l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000\000"
/* offset=1165401 */ "l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000"
/* offset=1165616 */ "l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000"
/* offset=1165833 */ "l2_rqsts.demand_data_rd_hit\000cpu_core\000cache\000Demand Data Read requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000"
/* offset=1166073 */ "l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2 cache\000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000"
/* offset=1166338 */ "l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x21\000\00000\000Demand data read requests that missed L2, no rejects  Spec update: HSD78, HSM80\000"
/* offset=1166558 */ "l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000"
/* offset=1166774 */ "l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000This event counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000"
/* offset=1167001 */ "l2_rqsts.demand_data_rd_miss\000cpu_core\000cache\000Demand Data Read miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000"
/* offset=1167291 */ "l2_rqsts.hit\000cpu_core\000cache\000All requests that hit L2 cache. [This event is alias to L2_REQUEST.HIT]. Unit: cpu_core \000event=0x24,period=200003,umask=0xdf\000\00000\000Counts all requests that hit L2 cache. [This event is alias to L2_REQUEST.HIT]\000"
/* offset=1167527 */ "l2_rqsts.hwpf_miss\000\000cache\000L2_RQSTS.HWPF_MISS\000event=0x24,period=200003,umask=0x30\000\00000\000\000"
/* offset=1167613 */ "l2_rqsts.hwpf_miss\000cpu_core\000cache\000L2_RQSTS.HWPF_MISS. Unit: cpu_core \000event=0x24,period=200003,umask=0x30\000\00000\000\000"
/* offset=1167724 */ "l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000"
/* offset=1167818 */ "l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000"
/* offset=1167915 */ "l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000"
/* offset=1168004 */ "l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000"
/* offset=1168158 */ "l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that hit L2 cache. L3 prefetch new types\000"
/* offset=1168378 */ "l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000"
/* offset=1168537 */ "l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that miss L2 cache\000"
/* offset=1168737 */ "l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000"
/* offset=1168813 */ "l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000"
/* offset=1168892 */ "l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000"
/* offset=1168966 */ "l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000"
/* offset=1169042 */ "l2_rqsts.miss\000\000cache\000All requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that missed L2  Spec update: HSD78, HSM80\000"
/* offset=1169217 */ "l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that miss L2 cache\000"
/* offset=1169342 */ "l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts all requests that miss L2 cache\000"
/* offset=1169474 */ "l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000\000"
/* offset=1169568 */ "l2_rqsts.miss\000\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_REQUEST.MISS]\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000"
/* offset=1169888 */ "l2_rqsts.miss\000\000cache\000Read requests with true-miss in L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses\000"
/* offset=1170124 */ "l2_rqsts.miss\000\000cache\000This event is deprecated\000event=0x24,period=200003,umask=0x3f\000\00010\000\000"
/* offset=1170211 */ "l2_rqsts.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache [This event is alias to L2_REQUEST.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000"
/* offset=1170555 */ "l2_rqsts.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_REQUEST.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000"
/* offset=1170900 */ "l2_rqsts.pf_hit\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000event=0x24,period=200003,umask=0xd8\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000"
/* offset=1171158 */ "l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000"
/* offset=1171330 */ "l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000\000"
/* offset=1171454 */ "l2_rqsts.pf_miss\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000event=0x24,period=200003,umask=0x38\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000"
/* offset=1171715 */ "l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000"
/* offset=1171892 */ "l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000\000"
/* offset=1172018 */ "l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000"
/* offset=1172105 */ "l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000"
/* offset=1172195 */ "l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000"
/* offset=1172281 */ "l2_rqsts.references\000\000cache\000All L2 requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xff\000\00000\000All requests to L2 cache  Spec update: HSD78, HSM80\000"
/* offset=1172443 */ "l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000"
/* offset=1172527 */ "l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000All L2 requests\000"
/* offset=1172626 */ "l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all L2 requests\000"
/* offset=1172732 */ "l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000\000"
/* offset=1172816 */ "l2_rqsts.references\000\000cache\000All accesses to L2 cache [This event is alias to L2_REQUEST.ALL]\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.ALL]\000"
/* offset=1173117 */ "l2_rqsts.references\000\000cache\000All accesses to L2 cache\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses\000"
/* offset=1173337 */ "l2_rqsts.references\000\000cache\000This event is deprecated\000event=0x24,period=200003,umask=0xff\000\00010\000\000"
/* offset=1173430 */ "l2_rqsts.references\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_REQUEST.ALL]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.ALL]\000"
/* offset=1173756 */ "l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000"
/* offset=1173832 */ "l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000RFO requests that hit L2 cache\000"
/* offset=1173957 */ "l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000\000"
/* offset=1174052 */ "l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000"
/* offset=1174210 */ "l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the number of store RFO requests that hit the L2 cache\000"
/* offset=1174367 */ "l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000\000"
/* offset=1174463 */ "l2_rqsts.rfo_hit\000cpu_core\000cache\000RFO requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000"
/* offset=1174646 */ "l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000"
/* offset=1174725 */ "l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000"
/* offset=1174886 */ "l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000"
/* offset=1175046 */ "l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000\000"
/* offset=1175144 */ "l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000"
/* offset=1175303 */ "l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000\000"
/* offset=1175400 */ "l2_rqsts.rfo_miss\000cpu_core\000cache\000RFO requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000"
/* offset=1175586 */ "l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000"
/* offset=1175663 */ "l2_rqsts.self.any.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x74\000\00000\000\000"
/* offset=1175755 */ "l2_rqsts.self.any.i_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x71\000\00000\000\000"
/* offset=1175847 */ "l2_rqsts.self.any.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x78\000\00000\000\000"
/* offset=1175939 */ "l2_rqsts.self.any.mesi\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x7f\000\00000\000\000"
/* offset=1176028 */ "l2_rqsts.self.any.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x72\000\00000\000\000"
/* offset=1176120 */ "l2_rqsts.self.demand.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x44\000\00000\000\000"
/* offset=1176215 */ "l2_rqsts.self.demand.i_state\000\000cache\000L2 cache demand requests from this core that missed the L2\000event=0x2e,period=200000,umask=0x41\000\00000\000\000"
/* offset=1176351 */ "l2_rqsts.self.demand.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x48\000\00000\000\000"
/* offset=1176446 */ "l2_rqsts.self.demand.mesi\000\000cache\000L2 cache demand requests from this core\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1176560 */ "l2_rqsts.self.demand.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x42\000\00000\000\000"
/* offset=1176655 */ "l2_rqsts.self.prefetch.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x54\000\00000\000\000"
/* offset=1176752 */ "l2_rqsts.self.prefetch.i_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x51\000\00000\000\000"
/* offset=1176849 */ "l2_rqsts.self.prefetch.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x58\000\00000\000\000"
/* offset=1176946 */ "l2_rqsts.self.prefetch.mesi\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x5f\000\00000\000\000"
/* offset=1177040 */ "l2_rqsts.self.prefetch.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x52\000\00000\000\000"
/* offset=1177137 */ "l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000"
/* offset=1177375 */ "l2_rqsts.swpf_hit\000cpu_core\000cache\000SW prefetch requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000"
/* offset=1177638 */ "l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000"
/* offset=1177879 */ "l2_rqsts.swpf_miss\000cpu_core\000cache\000SW prefetch requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000"
/* offset=1178145 */ "l2_st.self.e_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x44\000\00000\000\000"
/* offset=1178230 */ "l2_st.self.i_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x41\000\00000\000\000"
/* offset=1178315 */ "l2_st.self.m_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x48\000\00000\000\000"
/* offset=1178400 */ "l2_st.self.mesi\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1178482 */ "l2_st.self.s_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x42\000\00000\000\000"
/* offset=1178567 */ "l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000RFOs that access cache lines in any state\000"
/* offset=1178721 */ "l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000\000"
/* offset=1178834 */ "l2_store_lock_rqsts.hit_e\000\000cache\000RFOs that hit cache lines in E state\000event=0x27,period=200003,umask=0x4\000\00000\000\000"
/* offset=1178944 */ "l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000RFOs that hit cache lines in M state\000"
/* offset=1179090 */ "l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000\000"
/* offset=1179200 */ "l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000RFOs that miss cache lines\000"
/* offset=1179325 */ "l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000\000"
/* offset=1179424 */ "l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or L3 HW prefetch accessing L2, including rejects\000"
/* offset=1179588 */ "l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000This event counts L2 or L3 HW prefetches that access L2 cache including rejects\000"
/* offset=1179774 */ "l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or LLC HW prefetch accessing L2, including rejects\000"
/* offset=1179940 */ "l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000\000"
/* offset=1180048 */ "l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000This event counts transactions that access the L2 pipe including snoops, pagewalks, and so on\000"
/* offset=1180242 */ "l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000Transactions accessing L2 pipe\000"
/* offset=1180373 */ "l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000\000"
/* offset=1180474 */ "l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000L2 cache accesses when fetching instructions\000"
/* offset=1180627 */ "l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000This event counts the number of L2 cache accesses when fetching instructions\000"
/* offset=1180812 */ "l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000\000"
/* offset=1180921 */ "l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand Data Read requests that access L2 cache\000"
/* offset=1181085 */ "l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand data read requests that access L2 cache\000"
/* offset=1181249 */ "l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000This event counts Demand Data Read requests that access L2 cache, including rejects\000"
/* offset=1181450 */ "l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000\000"
/* offset=1181568 */ "l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000L1D writebacks that access L2 cache\000"
/* offset=1181703 */ "l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000This event counts L1D writebacks that access L2 cache\000"
/* offset=1181856 */ "l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000\000"
/* offset=1181956 */ "l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000L2 fill requests that access L2 cache\000"
/* offset=1182096 */ "l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000This event counts L2 fill requests that access L2 cache\000"
/* offset=1182254 */ "l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000\000"
/* offset=1182357 */ "l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000"
/* offset=1182496 */ "l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000L2 writebacks that access L2 cache\000"
/* offset=1182628 */ "l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000This event counts L2 writebacks that access L2 cache\000"
/* offset=1182778 */ "l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000\000"
/* offset=1182876 */ "l2_trans.l2_wb\000cpu_core\000cache\000L2 writebacks that access L2 cache. Unit: cpu_core \000event=0x23,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000"
/* offset=1183040 */ "l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000RFO requests that access L2 cache\000"
/* offset=1183167 */ "l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000This event counts Read for Ownership (RFO) requests that access L2 cache\000"
/* offset=1183333 */ "l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000\000"
/* offset=1183427 */ "l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000"
/* offset=1183515 */ "l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000"
/* offset=1183605 */ "l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000"
/* offset=1183709 */ "l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000"
/* offset=1183813 */ "l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000"
/* offset=1183902 */ "l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000"
/* offset=1183999 */ "l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000"
/* offset=1184086 */ "l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000"
/* offset=1184186 */ "l2_wcb_req.cl_zero\000\000cache\000LS to L2 WCB cache line zeroing requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) cache line zeroing requests\000event=0x63,umask=0x01\000\00000\000\000"
/* offset=1184365 */ "l2_wcb_req.wcb_close\000\000cache\000LS to L2 WCB close requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) close requests\000event=0x63,umask=0x20\000\00000\000\000"
/* offset=1184520 */ "l2_wcb_req.wcb_write\000\000cache\000LS to L2 WCB write requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) write requests\000event=0x63,umask=0x40\000\00000\000\000"
/* offset=1184675 */ "l2_wcb_req.zero_byte_store\000\000cache\000LS to L2 WCB zero byte store requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) zero byte store requests\000event=0x63,umask=0x04\000\00000\000\000"
/* offset=1184856 */ "l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000"
/* offset=1184957 */ "l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000"
/* offset=1185066 */ "l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000"
/* offset=1185176 */ "l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000"
/* offset=1185277 */ "l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000"
/* offset=1185368 */ "l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000"
/* offset=1185469 */ "l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000"
/* offset=1185577 */ "l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000"
/* offset=1185686 */ "l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000"
/* offset=1185786 */ "l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000"
/* offset=1185876 */ "l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000"
/* offset=1185976 */ "l3_accesses\000amd_l3\000recommended\000L3 Accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000"
/* offset=1186060 */ "l3_cache_accesses\000amd_l3\000recommended\000L3 Cache Accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000"
/* offset=1186156 */ "l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000"
/* offset=1186252 */ "l3_comb_clstr_state.other_l3_miss_typs\000amd_l3\000cache\000Other L3 Miss Request Types. Unit: amd_l3 \000event=0x6,umask=0xfe\000\00000\000\000"
/* offset=1186373 */ "l3_comb_clstr_state.request_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x6,umask=0x01\000\00000\000\000"
/* offset=1186476 */ "l3_lookup_state.all_coherent_accesses_to_l3\000amd_l3\000cache\000L3 cache requests for all coherent accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000"
/* offset=1186618 */ "l3_lookup_state.all_l3_req_typs\000amd_l3\000cache\000All L3 Request Types. All L3 cache Requests. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000"
/* offset=1186748 */ "l3_lookup_state.all_l3_req_typs\000amd_l3\000cache\000All L3 Request Types. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000"
/* offset=1186855 */ "l3_lookup_state.l3_hit\000amd_l3\000cache\000L3 cache hits. Unit: amd_l3 \000event=0x4,umask=0xfe\000\00000\000\000"
/* offset=1186946 */ "l3_lookup_state.l3_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000"
/* offset=1187040 */ "l3_misses\000amd_l3\000recommended\000L3 Misses (includes Chg2X). Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000"
/* offset=1187137 */ "l3_misses\000amd_l3\000recommended\000L3 Misses (includes cacheline state change requests). Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000"
/* offset=1187260 */ "l3_request_g1.caching_l3_cache_accesses\000amd_l3\000cache\000Caching: L3 cache accesses. Unit: amd_l3 \000event=0x1,umask=0x80\000\00000\000\000"
/* offset=1187381 */ "l3_xi_sampled_latency.all\000amd_l3\000cache\000Average sampled latency from all data sources. Unit: amd_l3 \000event=0xac,umask=0x3f\000\00000\000\000"
/* offset=1187508 */ "l3_xi_sampled_latency.dram_far\000amd_l3\000cache\000Average sampled latency when data is sourced from DRAM in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x02\000\00000\000\000"
/* offset=1187674 */ "l3_xi_sampled_latency.dram_near\000amd_l3\000cache\000Average sampled latency when data is sourced from DRAM in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x01\000\00000\000\000"
/* offset=1187838 */ "l3_xi_sampled_latency.ext_far\000amd_l3\000cache\000Average sampled latency when data is sourced from extension memory (CXL) in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x20\000\00000\000\000"
/* offset=1188021 */ "l3_xi_sampled_latency.ext_near\000amd_l3\000cache\000Average sampled latency when data is sourced from extension memory (CXL) in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x10\000\00000\000\000"
/* offset=1188202 */ "l3_xi_sampled_latency.far_cache\000amd_l3\000cache\000Average sampled latency when data is sourced from another CCX's cache when the address was in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x08\000\00000\000\000"
/* offset=1188405 */ "l3_xi_sampled_latency.near_cache\000amd_l3\000cache\000Average sampled latency when data is sourced from another CCX's cache when the address was in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x04\000\00000\000\000"
/* offset=1188606 */ "l3_xi_sampled_latency_requests.all\000amd_l3\000cache\000L3 cache fill requests sourced from all data sources. Unit: amd_l3 \000event=0xad,umask=0x3f\000\00000\000\000"
/* offset=1188749 */ "l3_xi_sampled_latency_requests.dram_far\000amd_l3\000cache\000L3 cache fill requests sourced from DRAM in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x02\000\00000\000\000"
/* offset=1188910 */ "l3_xi_sampled_latency_requests.dram_near\000amd_l3\000cache\000L3 cache fill requests sourced from DRAM in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x01\000\00000\000\000"
/* offset=1189069 */ "l3_xi_sampled_latency_requests.ext_far\000amd_l3\000cache\000L3 cache fill requests sourced from extension memory (CXL) in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x20\000\00000\000\000"
/* offset=1189247 */ "l3_xi_sampled_latency_requests.ext_near\000amd_l3\000cache\000L3 cache fill requests sourced from extension memory (CXL) in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x10\000\00000\000\000"
/* offset=1189423 */ "l3_xi_sampled_latency_requests.far_cache\000amd_l3\000cache\000L3 cache fill requests sourced from another CCX's cache when the address was in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x08\000\00000\000\000"
/* offset=1189621 */ "l3_xi_sampled_latency_requests.near_cache\000amd_l3\000cache\000L3 cache fill requests sourced from another CCX's cache when the address was in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x04\000\00000\000\000"
/* offset=1189817 */ "large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000"
/* offset=1189894 */ "ld_blocks.4k_alias\000\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1190157 */ "ld_blocks.4k_alias\000\000pipeline\000Loads blocked because address has 4k partial address false dependence (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x4\000\00000\000Counts loads that block because their address modulo 4K matches a pending store (Must be precise)\000"
/* offset=1190434 */ "ld_blocks.4k_alias\000\000pipeline\000This event is deprecated. Refer to new event LD_BLOCKS.ADDRESS_ALIAS (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00010\000\000"
/* offset=1190588 */ "ld_blocks.4k_alias\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event LD_BLOCKS.ADDRESS_ALIAS (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x4\000\00010\000\000"
/* offset=1190767 */ "ld_blocks.address_alias\000\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1191035 */ "ld_blocks.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x3,period=100003,umask=0x4\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000"
/* offset=1191280 */ "ld_blocks.address_alias\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1191573 */ "ld_blocks.address_alias\000cpu_core\000pipeline\000False dependencies in MOB due to partial compare on address. Unit: cpu_core \000event=0x3,period=100003,umask=0x4\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000"
/* offset=1191843 */ "ld_blocks.all\000\000pipeline\000Counts the number of retired loads that are blocked for any of the following reasons:  DTLB miss, address alias, store forward or data unknown (includes memory disambiguation blocks and ESP consuming load blocks) (Precise event)\000event=0x3,period=1000003,umask=0x10\000\00000\000\000"
/* offset=1192137 */ "ld_blocks.all_block\000\000pipeline\000Loads blocked (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x10\000\00000\000Counts anytime a load that retires is blocked for any reason (Must be precise)\000"
/* offset=1192341 */ "ld_blocks.all_block\000\000pipeline\000Number of cases where any load ends up with a valid block-code written to the load buffer (including blocks due to Memory Order Buffer (MOB), Data Cache Unit (DCU), TLB, but load has no DCU miss)\000event=0x3,period=100003,umask=0x10\000\00000\000\000"
/* offset=1192607 */ "ld_blocks.data_unknown\000\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event)\000event=0x3,period=1000003,umask=0x1\000\00000\000\000"
/* offset=1192823 */ "ld_blocks.data_unknown\000\000pipeline\000Loads blocked due to store data not ready (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x1\000\00000\000Counts a load blocked from using a store forward, but did not occur because the store data was not available at the right time.  The forward might occur subsequently when the data is available (Must be precise)\000"
/* offset=1193189 */ "ld_blocks.data_unknown\000\000pipeline\000Loads delayed due to SB blocks, preceding store operations with known addresses but unknown data\000event=0x3,period=100003,umask=0x1\000\00000\000\000"
/* offset=1193358 */ "ld_blocks.data_unknown\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x1\000\00000\000\000"
/* offset=1193599 */ "ld_blocks.dtlb_miss\000\000virtual memory\000Counts the number of retired loads that are blocked due to a first level TLB miss (Precise event)\000event=0x3,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1193773 */ "ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x88\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000"
/* offset=1194117 */ "ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000"
/* offset=1194460 */ "ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000"
/* offset=1194796 */ "ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000"
/* offset=1195150 */ "ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000"
/* offset=1195369 */ "ld_blocks.no_sr\000cpu_core\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use. Unit: cpu_core \000event=0x3,period=100003,umask=0x88\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000"
/* offset=1195738 */ "ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000Loads blocked by overlapping with store buffer that cannot be forwarded\000"
/* offset=1195965 */ "ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts how many times the load operation got the true Block-on-Store blocking code preventing store forwarding. This includes cases when:\n - preceding store conflicts with the load (incomplete overlap);\n - store forwarding is impossible due to u-arch limitations;\n - preceding lock RMW operations are not forwarded;\n - store has the no-forward bit set (uncacheable/page-split/masked stores);\n - all-blocking stores are used (mostly, fences and port I/O);\nand others.\nThe most common case is a load blocked due to its address range overlapping with a preceding smaller uncompleted store. Note: This event does not take into account cases of out-of-SW-control (for example, SbTailHit), unknown physical STA, and cases of blocking loads on store due to being non-WB memory type or a lock. These cases are covered by other events.\nSee the table of not supported store forwards in the Optimization Guide\000"
/* offset=1197030 */ "ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store.  See the table of not supported store forwards in the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual.  The penalty for blocked store forwarding is that the load must wait for the store to complete before it can be issued\000"
/* offset=1197724 */ "ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store.  See the table of not supported store forwards in the Intel? 64 and IA-32 Architectures Optimization Reference Manual.  The penalty for blocked store forwarding is that the load must wait for the store to complete before it can be issued\000"
/* offset=1198416 */ "ld_blocks.store_forward\000\000pipeline\000Counts the number of retired loads that are blocked because its address partially overlapped with an older store (Precise event)\000event=0x3,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1198619 */ "ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000"
/* offset=1199071 */ "ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x82\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000"
/* offset=1199524 */ "ld_blocks.store_forward\000\000pipeline\000Loads blocked due to store forward restriction (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x2\000\00000\000Counts a load blocked from using a store forward because of an address/size mismatch, only one of the loads blocked from each store will be counted (Must be precise)\000"
/* offset=1199851 */ "ld_blocks.store_forward\000\000pipeline\000loads blocked by overlapping with store buffer that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store. The penalty for blocked store forwarding is that the load must wait for the store to write its value to the cache before it can be issued\000"
/* offset=1200432 */ "ld_blocks.store_forward\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because its address partially overlapped with an older store (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1200660 */ "ld_blocks.store_forward\000cpu_core\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded. Unit: cpu_core \000event=0x3,period=100003,umask=0x82\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000"
/* offset=1201138 */ "ld_blocks.utlb_miss\000\000pipeline\000Loads blocked because address in not in the UTLB (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x8\000\00000\000Counts loads blocked because they are unable to find their physical address in the micro TLB (UTLB) (Must be precise)\000"
/* offset=1201415 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies due to partial compare on address\000"
/* offset=1201654 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline which can have a performance impact\000"
/* offset=1202058 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000"
/* offset=1202459 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000"
/* offset=1202712 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000False dependencies in MOB due to partial compare on address\000"
/* offset=1202912 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline.  The enhanced address check typically has a performance penalty of 5 cycles\000"
/* offset=1203346 */ "ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000This event counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000"
/* offset=1203747 */ "ld_blocks_partial.all_sta_block\000\000pipeline\000This event counts the number of times that load operations are temporarily blocked because of older stores, with addresses that are not yet known. A load operation may incur more than one block of this type\000event=0x7,period=100003,umask=0x8\000\00000\000\000"
/* offset=1204035 */ "ld_head.any_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to any number of reasons, including an L1 miss, WCB full, pagewalk, store address block or store data block, on a load that retires\000event=0x5,period=1000003,umask=0xff\000\00000\000\000"
/* offset=1204325 */ "ld_head.any_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to any number of reasons, including an L1 miss, WCB full, pagewalk, store address block or store data block, on a load that retires. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xff\000\00000\000\000"
/* offset=1204640 */ "ld_head.dtlb_miss_at_ret\000\000virtual memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DTLB miss\000event=0x5,period=1000003,umask=0x90\000\00000\000\000"
/* offset=1204848 */ "ld_head.dtlb_miss_at_ret\000cpu_atom\000virtual memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DTLB miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x90\000\00000\000\000"
/* offset=1205081 */ "ld_head.l1_bound_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to a core bound stall including a store address match, a DTLB miss or a page walk that detains the load from retiring\000event=0x5,period=1000003,umask=0xf4\000\00000\000\000"
/* offset=1205362 */ "ld_head.l1_bound_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to a core bound stall including a store address match, a DTLB miss or a page walk that detains the load from retiring. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xf4\000\00000\000\000"
/* offset=1205668 */ "ld_head.l1_miss_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DL1 miss\000event=0x5,period=1000003,umask=0x81\000\00000\000\000"
/* offset=1205865 */ "ld_head.l1_miss_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DL1 miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x81\000\00000\000\000"
/* offset=1206087 */ "ld_head.other_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases\000event=0x5,period=1000003,umask=0xc0\000\00000\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases such as pipeline conflicts, fences, etc\000"
/* offset=1206460 */ "ld_head.other_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xc0\000\00000\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases such as pipeline conflicts, fences, etc\000"
/* offset=1206858 */ "ld_head.pgwalk_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a pagewalk\000event=0x5,period=1000003,umask=0xa0\000\00000\000\000"
/* offset=1207054 */ "ld_head.pgwalk_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a pagewalk. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xa0\000\00000\000\000"
/* offset=1207275 */ "ld_head.st_addr_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a store address match\000event=0x5,period=1000003,umask=0x84\000\00000\000\000"
/* offset=1207483 */ "ld_head.st_addr_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a store address match. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x84\000\00000\000\000"
/* offset=1207716 */ "llc_misses.code_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for code reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x191\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1208449 */ "llc_misses.data_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for data reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x192\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1209182 */ "llc_misses.data_read\000uncore_cbox\000uncore cache\000LLC misses - demand and prefetch data reads - excludes LLC prefetches. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x182\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1209942 */ "llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000"
/* offset=1210502 */ "llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000"
/* offset=1210794 */ "llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0xf\000\0000164Bytes\000Counts the total number of DRAM Read CAS commands, w/ and w/o auto-pre, issued on this channel.  This includes underfills\000"
/* offset=1211079 */ "llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0x30\000\0000164Bytes\000Counts the total number of DRAM Write CAS commands issued, w/ and w/o auto-pre, on this channel\000"
/* offset=1211341 */ "llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000"
/* offset=1211826 */ "llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000"
/* offset=1212098 */ "llc_misses.mmio_read\000uncore_cbox\000uncore cache\000MMIO reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1212811 */ "llc_misses.mmio_read\000uncore_cha\000uncore cache\000MMIO reads. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40040e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1213222 */ "llc_misses.mmio_read\000uncore_cha\000uncore cache\000MMIO reads. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40040e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1213639 */ "llc_misses.mmio_write\000uncore_cbox\000uncore cache\000MMIO writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x18f,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1214354 */ "llc_misses.mmio_write\000uncore_cha\000uncore cache\000MMIO writes. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40041e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1214767 */ "llc_misses.mmio_write\000uncore_cha\000uncore cache\000MMIO writes. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40041e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1215186 */ "llc_misses.pcie_non_snoop_write\000uncore_cbox\000uncore cache\000PCIe write misses (full cache line). Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1215939 */ "llc_misses.pcie_read\000uncore_cbox\000uncore cache\000LLC misses for PCIe read current. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1216662 */ "llc_misses.pcie_read\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4,ch_mask=0x1f\000\000014Bytes\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=1217336 */ "llc_misses.pcie_read\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4,ch_mask=0x1f\000\000014Bytes\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=1217854 */ "llc_misses.pcie_write\000uncore_cbox\000uncore cache\000ItoM write misses (as part of fast string memcpy stores) + PCIe full line writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1218626 */ "llc_misses.pcie_write\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1,ch_mask=0x1f\000\000014Bytes\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=1219302 */ "llc_misses.pcie_write\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1,ch_mask=0x1f\000\000014Bytes\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=1219820 */ "llc_misses.rfo_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for RFO. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x190\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1220545 */ "llc_misses.uncacheable\000uncore_cbox\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=1221280 */ "llc_misses.uncacheable\000uncore_cha\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1221722 */ "llc_misses.uncacheable\000uncore_cha\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1222170 */ "llc_references.code_llc_prefetch\000uncore_cbox\000uncore cache\000L2 demand and L2 prefetch code references to LLC. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x181\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1222951 */ "llc_references.pcie_ns_partial_write\000uncore_cbox\000uncore cache\000PCIe writes (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x180,filter_tid=0x3e\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1223729 */ "llc_references.pcie_read\000uncore_cbox\000uncore cache\000PCIe read current. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1224471 */ "llc_references.pcie_write\000uncore_cbox\000uncore cache\000PCIe write references (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1225252 */ "llc_references.streaming_full\000uncore_cbox\000uncore cache\000Streaming stores (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18c\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1226016 */ "llc_references.streaming_full\000uncore_cha\000uncore cache\000Streaming stores (full cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x41833\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1226464 */ "llc_references.streaming_full\000uncore_cha\000uncore cache\000Streaming stores (full cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x41833\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1226918 */ "llc_references.streaming_partial\000uncore_cbox\000uncore cache\000Streaming stores (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18d\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=1227688 */ "llc_references.streaming_partial\000uncore_cha\000uncore cache\000Streaming stores (partial cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x41a33\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1228142 */ "llc_references.streaming_partial\000uncore_cha\000uncore cache\000Streaming stores (partial cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x41a33\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=1228602 */ "load_block.overlap_store\000\000other\000Loads that partially overlap an earlier store\000event=0x3,period=200000,umask=0x2\000\00000\000\000"
/* offset=1228719 */ "load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000"
/* offset=1228806 */ "load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1228902 */ "load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1229004 */ "load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1229109 */ "load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for H/W prefetch\000"
/* offset=1229339 */ "load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the hardware prefetch\000"
/* offset=1229615 */ "load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000\000"
/* offset=1229766 */ "load_hit_pre.sw_pf\000\000pipeline\000Demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000"
/* offset=1230225 */ "load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for S/W prefetch\000"
/* offset=1230455 */ "load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by asm inspection of the nearby instructions\000"
/* offset=1230906 */ "load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000\000"
/* offset=1231057 */ "load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000"
/* offset=1231173 */ "load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000"
/* offset=1231657 */ "load_hit_prefetch.swpf\000cpu_core\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch. Unit: cpu_core \000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000"
/* offset=1232166 */ "local_processor_read_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 0\000"
/* offset=1232336 */ "local_processor_read_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 10\000"
/* offset=1232509 */ "local_processor_read_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 11\000"
/* offset=1232682 */ "local_processor_read_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 1\000"
/* offset=1232852 */ "local_processor_read_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 2\000"
/* offset=1233022 */ "local_processor_read_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 3\000"
/* offset=1233192 */ "local_processor_read_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 4\000"
/* offset=1233363 */ "local_processor_read_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 5\000"
/* offset=1233534 */ "local_processor_read_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 6\000"
/* offset=1233705 */ "local_processor_read_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 7\000"
/* offset=1233876 */ "local_processor_read_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 8\000"
/* offset=1234047 */ "local_processor_read_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 9\000"
/* offset=1234218 */ "local_processor_write_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 0\000"
/* offset=1234390 */ "local_processor_write_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 10\000"
/* offset=1234565 */ "local_processor_write_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 11\000"
/* offset=1234740 */ "local_processor_write_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 1\000"
/* offset=1234912 */ "local_processor_write_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 2\000"
/* offset=1235084 */ "local_processor_write_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 3\000"
/* offset=1235256 */ "local_processor_write_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 4\000"
/* offset=1235429 */ "local_processor_write_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 5\000"
/* offset=1235602 */ "local_processor_write_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 6\000"
/* offset=1235775 */ "local_processor_write_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 7\000"
/* offset=1235948 */ "local_processor_write_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 8\000"
/* offset=1236121 */ "local_processor_write_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 9\000"
/* offset=1236294 */ "local_socket_inf0_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 0\000"
/* offset=1236489 */ "local_socket_inf0_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 1\000"
/* offset=1236684 */ "local_socket_inf0_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 2\000"
/* offset=1236879 */ "local_socket_inf0_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 3\000"
/* offset=1237074 */ "local_socket_inf0_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 4\000"
/* offset=1237269 */ "local_socket_inf0_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 5\000"
/* offset=1237464 */ "local_socket_inf0_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 6\000"
/* offset=1237659 */ "local_socket_inf0_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 7\000"
/* offset=1237854 */ "local_socket_inf0_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 0\000"
/* offset=1238053 */ "local_socket_inf0_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 1\000"
/* offset=1238252 */ "local_socket_inf0_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 2\000"
/* offset=1238451 */ "local_socket_inf0_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 3\000"
/* offset=1238650 */ "local_socket_inf0_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 4\000"
/* offset=1238849 */ "local_socket_inf0_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 5\000"
/* offset=1239048 */ "local_socket_inf0_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 6\000"
/* offset=1239247 */ "local_socket_inf0_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 7\000"
/* offset=1239446 */ "local_socket_inf1_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 0\000"
/* offset=1239641 */ "local_socket_inf1_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 1\000"
/* offset=1239836 */ "local_socket_inf1_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 2\000"
/* offset=1240031 */ "local_socket_inf1_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 3\000"
/* offset=1240226 */ "local_socket_inf1_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 4\000"
/* offset=1240421 */ "local_socket_inf1_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 5\000"
/* offset=1240616 */ "local_socket_inf1_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 6\000"
/* offset=1240811 */ "local_socket_inf1_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 7\000"
/* offset=1241006 */ "local_socket_inf1_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 0\000"
/* offset=1241205 */ "local_socket_inf1_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 1\000"
/* offset=1241404 */ "local_socket_inf1_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 2\000"
/* offset=1241603 */ "local_socket_inf1_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 3\000"
/* offset=1241802 */ "local_socket_inf1_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 4\000"
/* offset=1242001 */ "local_socket_inf1_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 5\000"
/* offset=1242200 */ "local_socket_inf1_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 6\000"
/* offset=1242399 */ "local_socket_inf1_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 7\000"
/* offset=1242598 */ "local_socket_outbound_data_beats_link0\000amd_df\000data fabric\000Unit: amd_df \000event=0xb5f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 0\000"
/* offset=1242781 */ "local_socket_outbound_data_beats_link1\000amd_df\000data fabric\000Unit: amd_df \000event=0xb9f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 1\000"
/* offset=1242964 */ "local_socket_outbound_data_beats_link2\000amd_df\000data fabric\000Unit: amd_df \000event=0xbdf,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 2\000"
/* offset=1243147 */ "local_socket_outbound_data_beats_link3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc1f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 3\000"
/* offset=1243330 */ "local_socket_outbound_data_beats_link4\000amd_df\000data fabric\000Unit: amd_df \000event=0xc5f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 4\000"
/* offset=1243513 */ "local_socket_outbound_data_beats_link5\000amd_df\000data fabric\000Unit: amd_df \000event=0xc9f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 5\000"
/* offset=1243696 */ "local_socket_outbound_data_beats_link6\000amd_df\000data fabric\000Unit: amd_df \000event=0xcdf,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 6\000"
/* offset=1243879 */ "local_socket_outbound_data_beats_link7\000amd_df\000data fabric\000Unit: amd_df \000event=0xd1f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 7\000"
/* offset=1244062 */ "local_socket_upstream_read_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 0\000"
/* offset=1244242 */ "local_socket_upstream_read_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 1\000"
/* offset=1244422 */ "local_socket_upstream_read_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 2\000"
/* offset=1244602 */ "local_socket_upstream_read_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 3\000"
/* offset=1244782 */ "local_socket_upstream_write_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 0\000"
/* offset=1244964 */ "local_socket_upstream_write_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 1\000"
/* offset=1245146 */ "local_socket_upstream_write_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 2\000"
/* offset=1245328 */ "local_socket_upstream_write_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 3\000"
/* offset=1245510 */ "lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000Cycles in which the L1D is locked\000"
/* offset=1245649 */ "lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000This event counts the number of cycles when the L1D is locked. It is a superset of the 0x1 mask (BUS_LOCK_CLOCKS.BUS_LOCK_DURATION)\000"
/* offset=1245886 */ "lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1245992 */ "lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000Cycles in which the L1D and L2 are locked, due to a UC lock or split lock\000"
/* offset=1246210 */ "lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000This event counts cycles in which the L1 and L2 are locked due to a UC lock or split lock. A lock is asserted in case of locked memory access, due to noncacheable memory, locked operation that spans two cache lines, or a page walk from the noncacheable page table. L1D and L2 locks have a very high performance penalty and it is highly recommended to avoid such access\000"
/* offset=1246723 */ "lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1246868 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2. It does not include all misses to the L3  Spec update: SKL057\000"
/* offset=1247290 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts core-originated cacheable demand requests that miss the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000"
/* offset=1247614 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000"
/* offset=1247819 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000"
/* offset=1248025 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000\000"
/* offset=1248149 */ "longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000"
/* offset=1248632 */ "longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000"
/* offset=1249101 */ "longest_lat_cache.miss\000\000cache\000L2 cache request misses\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts memory requests originating from the core that miss in the L2 cache\000"
/* offset=1249270 */ "longest_lat_cache.miss\000\000cache\000L2 cache request misses\000event=0x2e,period=200003,umask=0x41\000\00000\000This event counts the total number of L2 cache references and the number of L2 cache misses respectively\000"
/* offset=1249469 */ "longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000"
/* offset=1249567 */ "longest_lat_cache.miss\000cpu_atom\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000"
/* offset=1250061 */ "longest_lat_cache.miss\000cpu_core\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000"
/* offset=1250569 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the  L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2.  It does not include all accesses to the L3  Spec update: SKL057\000"
/* offset=1251000 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts core-originated cacheable demand requests that refer to the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000"
/* offset=1251340 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000"
/* offset=1251579 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000"
/* offset=1251819 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000\000"
/* offset=1251955 */ "longest_lat_cache.reference\000\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000"
/* offset=1252437 */ "longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000"
/* offset=1252909 */ "longest_lat_cache.reference\000\000cache\000L2 cache requests from this core\000event=0x2e,period=200003,umask=0x4f\000\00000\000This event counts requests originating from the core that references a cache line in the L2 cache\000"
/* offset=1253115 */ "longest_lat_cache.reference\000\000cache\000L2 cache requests\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts memory requests originating from the core that reference a cache line in the L2 cache\000"
/* offset=1253301 */ "longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000"
/* offset=1253409 */ "longest_lat_cache.reference\000cpu_atom\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000"
/* offset=1253906 */ "longest_lat_cache.reference\000cpu_core\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000"
/* offset=1254413 */ "ls_alloc_mab_count\000\000cache\000In-flight L1 data cache misses i.e. Miss Address Buffer (MAB) allocations each cycle\000event=0x5f\000\00000\000\000"
/* offset=1254540 */ "ls_alloc_mab_count\000\000memory\000Count of Allocated Mabs\000event=0x5f\000\00000\000This event counts the in-flight L1 data cache misses (allocated Miss Address Buffers) divided by 4 and rounded down each cycle unless used with the MergeEvent functionality. If the MergeEvent is used, it counts the exact number of outstanding L1 data cache misses. See 2.1.17.3 [Large Increment per Cycle Events]\000"
/* offset=1254919 */ "ls_any_fills_from_sys.all\000\000cache\000Any data cache fills from all types of data sources\000event=0x44,umask=0xff\000\00000\000\000"
/* offset=1255031 */ "ls_any_fills_from_sys.all_dram_io\000\000cache\000Any data cache fills from either DRAM or MMIO in any NUMA node (same or different socket)\000event=0x44,umask=0x48\000\00000\000\000"
/* offset=1255189 */ "ls_any_fills_from_sys.alternate_memories\000\000cache\000Any data cache fills from extension memory\000event=0x44,umask=0x80\000\00000\000\000"
/* offset=1255307 */ "ls_any_fills_from_sys.dram_io_all\000\000cache\000Any data cache fills from either DRAM or MMIO in any NUMA node (same or different socket)\000event=0x44,umask=0x48\000\00000\000\000"
/* offset=1255465 */ "ls_any_fills_from_sys.dram_io_far\000\000cache\000Any data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x44,umask=0x40\000\00000\000\000"
/* offset=1255631 */ "ls_any_fills_from_sys.dram_io_near\000\000cache\000Any data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x44,umask=0x08\000\00000\000\000"
/* offset=1255768 */ "ls_any_fills_from_sys.ext_cache_local\000\000memory\000Any Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x44,umask=0x04\000\00000\000\000"
/* offset=1255919 */ "ls_any_fills_from_sys.ext_cache_remote\000\000memory\000Any Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x44,umask=0x10\000\00000\000\000"
/* offset=1256063 */ "ls_any_fills_from_sys.far_all\000\000cache\000Any data cache fills from either cache of another CCX, DRAM or MMIO when the address was in a different NUMA node (same or different socket)\000event=0x44,umask=0x50\000\00000\000\000"
/* offset=1256268 */ "ls_any_fills_from_sys.far_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x44,umask=0x10\000\00000\000\000"
/* offset=1256427 */ "ls_any_fills_from_sys.int_cache\000\000memory\000Any Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x44,umask=0x02\000\00000\000\000"
/* offset=1256567 */ "ls_any_fills_from_sys.lcl_l2\000\000memory\000Any Data Cache Fills by Data Source. From Local L2 to the core\000event=0x44,umask=0x01\000\00000\000\000"
/* offset=1256694 */ "ls_any_fills_from_sys.local_all\000\000cache\000Any data cache fills from local L2 cache or L3 cache or different L2 cache in the same CCX\000event=0x44,umask=0x03\000\00000\000\000"
/* offset=1256851 */ "ls_any_fills_from_sys.local_ccx\000\000cache\000Any data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x44,umask=0x02\000\00000\000\000"
/* offset=1256990 */ "ls_any_fills_from_sys.local_l2\000\000cache\000Any data cache fills from local L2 cache\000event=0x44,umask=0x01\000\00000\000\000"
/* offset=1257096 */ "ls_any_fills_from_sys.mem_io_local\000\000memory\000Any Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x44,umask=0x08\000\00000\000\000"
/* offset=1257242 */ "ls_any_fills_from_sys.mem_io_remote\000\000memory\000Any Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x44,umask=0x40\000\00000\000\000"
/* offset=1257394 */ "ls_any_fills_from_sys.near_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x44,umask=0x04\000\00000\000\000"
/* offset=1257551 */ "ls_any_fills_from_sys.remote_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in the same or a different NUMA node\000event=0x44,umask=0x14\000\00000\000\000"
/* offset=1257725 */ "ls_bad_status2.stli_other\000\000memory\000Non-forwardable conflict; used to reduce STLI's via software. All reasons. Store To Load Interlock (STLI) are loads that were unable to complete because of a possible match with an older store, and the older store could not do STLF for some reason\000event=0x24,umask=0x02\000\00000\000Store-to-load conflicts: A load was unable to complete due to a non-forwardable conflict with an older store. Most commonly, a load's address range partially but not completely overlaps with an uncompleted older store. Software can avoid this problem by using same-size and same-alignment loads and stores when accessing the same data. Vector/SIMD code is particularly susceptible to this problem; software should construct wide vector stores by manipulating vector elements in registers using shuffle/blend/swap instructions prior to storing to memory, instead of using narrow element-by-element stores\000"
/* offset=1258637 */ "ls_bad_status2.stli_other\000\000memory\000Store-to-load conflicts (load unable to complete due to a non-forwardable conflict with an older store)\000event=0x24,umask=0x02\000\00000\000\000"
/* offset=1258802 */ "ls_dc_accesses\000\000memory\000Number of accesses to the dcache for load/store references\000event=0x40\000\00000\000The number of accesses to the data cache for load and store references. This may include certain microcode scratchpad accesses, although these are generally rare. Each increment represents an eight-byte access, although the instruction may only be accessing a portion of that. This event is a speculative event\000"
/* offset=1259210 */ "ls_dc_accesses\000\000memory\000The number of accesses to the data cache for load and store references. This may include certain microcode scratchpad accesses, although these are generally rare. Each increment represents an eight-byte access, although the instruction may only be accessing a portion of that. This event is a speculative event\000event=0x40\000\00000\000\000"
/* offset=1259560 */ "ls_dispatch.ld_dispatch\000\000memory\000Counts the number of loads dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000"
/* offset=1259690 */ "ls_dispatch.ld_dispatch\000\000memory\000Dispatch of a single op that performs a memory load. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000"
/* offset=1259878 */ "ls_dispatch.ld_dispatch\000\000memory\000Number of loads dispatched. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000"
/* offset=1260041 */ "ls_dispatch.ld_dispatch\000\000memory\000Number of memory load operations dispatched to the load-store unit\000event=0x29,umask=0x01\000\00000\000\000"
/* offset=1260167 */ "ls_dispatch.ld_st_dispatch\000\000memory\000Counts the number of operations dispatched to the LS unit. Unit Masks ADDed. Load-op-Stores\000event=0x29,umask=0x04\000\00000\000\000"
/* offset=1260321 */ "ls_dispatch.ld_st_dispatch\000\000memory\000Dispatch of a single op that performs a load from and store to the same memory address. Number of single ops that do load/store to an address\000event=0x29,umask=0x04\000\00000\000\000"
/* offset=1260525 */ "ls_dispatch.ld_st_dispatch\000\000memory\000Load-op-Store Dispatch. Dispatch of a single op that performs a load from and store to the same memory address. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x04\000\00000\000\000"
/* offset=1260775 */ "ls_dispatch.ld_st_dispatch\000\000memory\000Number of memory load-store operations dispatched to the load-store unit\000event=0x29,umask=0x04\000\00000\000\000"
/* offset=1260910 */ "ls_dispatch.store_dispatch\000\000memory\000Counts the number of stores dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000"
/* offset=1261044 */ "ls_dispatch.store_dispatch\000\000memory\000Dispatch of a single op that performs a memory store. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000"
/* offset=1261236 */ "ls_dispatch.store_dispatch\000\000memory\000Number of memory store operations dispatched to the load-store unit\000event=0x29,umask=0x02\000\00000\000\000"
/* offset=1261366 */ "ls_dispatch.store_dispatch\000\000memory\000Number of stores dispatched. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000"
/* offset=1261533 */ "ls_dmnd_fills_from_sys.all\000\000cache\000Demand data cache fills from all types of data sources\000event=0x43,umask=0xff\000\00000\000\000"
/* offset=1261649 */ "ls_dmnd_fills_from_sys.alternate_memories\000\000cache\000Demand data cache fills from extension memory\000event=0x43,umask=0x80\000\00000\000\000"
/* offset=1261771 */ "ls_dmnd_fills_from_sys.dram_io_far\000\000cache\000Demand data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x43,umask=0x40\000\00000\000\000"
/* offset=1261941 */ "ls_dmnd_fills_from_sys.dram_io_near\000\000cache\000Demand data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x43,umask=0x08\000\00000\000\000"
/* offset=1262082 */ "ls_dmnd_fills_from_sys.ext_cache_local\000\000memory\000Demand Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x43,umask=0x04\000\00000\000\000"
/* offset=1262237 */ "ls_dmnd_fills_from_sys.ext_cache_remote\000\000memory\000Demand Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x43,umask=0x10\000\00000\000\000"
/* offset=1262385 */ "ls_dmnd_fills_from_sys.far_cache\000\000cache\000Demand data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x43,umask=0x10\000\00000\000\000"
/* offset=1262548 */ "ls_dmnd_fills_from_sys.int_cache\000\000memory\000Demand Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x43,umask=0x02\000\00000\000\000"
/* offset=1262692 */ "ls_dmnd_fills_from_sys.lcl_l2\000\000memory\000Demand Data Cache Fills by Data Source. From Local L2 to the core\000event=0x43,umask=0x01\000\00000\000\000"
/* offset=1262823 */ "ls_dmnd_fills_from_sys.local_ccx\000\000cache\000Demand data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x43,umask=0x02\000\00000\000\000"
/* offset=1262966 */ "ls_dmnd_fills_from_sys.local_l2\000\000cache\000Demand data cache fills from local L2 cache\000event=0x43,umask=0x01\000\00000\000\000"
/* offset=1263076 */ "ls_dmnd_fills_from_sys.mem_io_local\000\000memory\000Demand Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x43,umask=0x08\000\00000\000\000"
/* offset=1263226 */ "ls_dmnd_fills_from_sys.mem_io_remote\000\000memory\000Demand Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x43,umask=0x40\000\00000\000\000"
/* offset=1263382 */ "ls_dmnd_fills_from_sys.near_cache\000\000cache\000Demand data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x43,umask=0x04\000\00000\000\000"
/* offset=1263543 */ "ls_hw_pf_dc_fill.ls_mabresp_lcl_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From another cache (home node local)\000event=0x5a,umask=0x02\000\00000\000\000"
/* offset=1263704 */ "ls_hw_pf_dc_fill.ls_mabresp_lcl_dram\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM (home node local)\000event=0x5a,umask=0x08\000\00000\000\000"
/* offset=1263855 */ "ls_hw_pf_dc_fill.ls_mabresp_lcl_l2\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. Local L2 hit\000event=0x5a,umask=0x01\000\00000\000\000"
/* offset=1263989 */ "ls_hw_pf_dc_fill.ls_mabresp_rmt_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From another cache (home node remote)\000event=0x5a,umask=0x10\000\00000\000\000"
/* offset=1264151 */ "ls_hw_pf_dc_fill.ls_mabresp_rmt_dram\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM (home node remote)\000event=0x5a,umask=0x40\000\00000\000\000"
/* offset=1264303 */ "ls_hw_pf_dc_fills.all\000\000cache\000Hardware prefetch data cache fills from all types of data sources\000event=0x5a,umask=0xdf\000\00000\000\000"
/* offset=1264425 */ "ls_hw_pf_dc_fills.alternate_memories\000\000cache\000Hardware prefetch data cache fills from extension memory\000event=0x5a,umask=0x80\000\00000\000\000"
/* offset=1264553 */ "ls_hw_pf_dc_fills.dram_io_far\000\000cache\000Hardware prefetch data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x5a,umask=0x40\000\00000\000\000"
/* offset=1264729 */ "ls_hw_pf_dc_fills.dram_io_near\000\000cache\000Hardware prefetch data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x5a,umask=0x08\000\00000\000\000"
/* offset=1264876 */ "ls_hw_pf_dc_fills.ext_cache_local\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x5a,umask=0x04\000\00000\000\000"
/* offset=1265037 */ "ls_hw_pf_dc_fills.ext_cache_remote\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x5a,umask=0x10\000\00000\000\000"
/* offset=1265191 */ "ls_hw_pf_dc_fills.far_cache\000\000cache\000Hardware prefetch data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x5a,umask=0x10\000\00000\000\000"
/* offset=1265360 */ "ls_hw_pf_dc_fills.int_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x5a,umask=0x02\000\00000\000\000"
/* offset=1265510 */ "ls_hw_pf_dc_fills.lcl_l2\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From Local L2 to the core\000event=0x5a,umask=0x01\000\00000\000\000"
/* offset=1265647 */ "ls_hw_pf_dc_fills.local_ccx\000\000cache\000Hardware prefetch data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x5a,umask=0x02\000\00000\000\000"
/* offset=1265796 */ "ls_hw_pf_dc_fills.local_l2\000\000cache\000Hardware prefetch data cache fills from local L2 cache\000event=0x5a,umask=0x01\000\00000\000\000"
/* offset=1265912 */ "ls_hw_pf_dc_fills.mem_io_local\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x5a,umask=0x08\000\00000\000\000"
/* offset=1266068 */ "ls_hw_pf_dc_fills.mem_io_remote\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x5a,umask=0x40\000\00000\000\000"
/* offset=1266230 */ "ls_hw_pf_dc_fills.near_cache\000\000cache\000Hardware prefetch data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x5a,umask=0x04\000\00000\000\000"
/* offset=1266397 */ "ls_inef_sw_pref.all\000\000cache\000\000event=0x52,umask=0x03\000\00000\000\000"
/* offset=1266452 */ "ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000cache\000Software prefetches that did not fetch data outside of the processor core as the PREFETCH instruction saw a data cache hit\000event=0x52,umask=0x01\000\00000\000\000"
/* offset=1266648 */ "ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a DC hit\000event=0x52,umask=0x01\000\00000\000\000"
/* offset=1266854 */ "ls_inef_sw_pref.mab_mch_cnt\000\000cache\000Software prefetches that did not fetch data outside of the processor core as the PREFETCH instruction saw a match on an already allocated Miss Address Buffer (MAB)\000event=0x52,umask=0x02\000\00000\000\000"
/* offset=1267080 */ "ls_inef_sw_pref.mab_mch_cnt\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a match on an already-allocated miss request buffer\000event=0x52,umask=0x02\000\00000\000\000"
/* offset=1267318 */ "ls_int_taken\000\000core\000Interrupts taken\000event=0x2c\000\00000\000\000"
/* offset=1267370 */ "ls_int_taken\000\000memory\000Counts the number of interrupts taken\000event=0x2c\000\00000\000\000"
/* offset=1267445 */ "ls_int_taken\000\000memory\000Number of interrupts taken\000event=0x2c\000\00000\000\000"
/* offset=1267509 */ "ls_l1_d_tlb_miss.all\000\000memory\000All L1 DTLB Misses or Reloads. Use l1_dtlb_misses instead\000event=0x45,umask=0xff\000\00000\000\000"
/* offset=1267623 */ "ls_l1_d_tlb_miss.all\000\000memory\000All L1 DTLB Misses or Reloads\000event=0x45,umask=0xff\000\00000\000\000"
/* offset=1267709 */ "ls_l1_d_tlb_miss.all\000\000memory\000L1 DTLB Miss or Reload off all sizes\000event=0x45,umask=0xff\000\00000\000\000"
/* offset=1267802 */ "ls_l1_d_tlb_miss.all\000\000memory\000L1 DTLB misses for all page sizes\000event=0x45,umask=0xff\000\00000\000\000"
/* offset=1267892 */ "ls_l1_d_tlb_miss.all_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for all page sizes\000event=0x45,umask=0xf0\000\00000\000\000"
/* offset=1268043 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that hit in the L2 TLB\000event=0x45,umask=0x08\000\00000\000\000"
/* offset=1268178 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB Reload of a page of 1G size\000event=0x45,umask=0x08\000\00000\000\000"
/* offset=1268287 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 1G pages\000event=0x45,umask=0x08\000\00000\000\000"
/* offset=1268406 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss of a page of 1G size\000event=0x45,umask=0x80\000\00000\000\000"
/* offset=1268514 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that also missed in the L2 TLB\000event=0x45,umask=0x80\000\00000\000\000"
/* offset=1268658 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that miss in the L2 TLB\000event=0x45,umask=0x80\000\00000\000\000"
/* offset=1268795 */ "ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 1G pages\000event=0x45,umask=0x80\000\00000\000\000"
/* offset=1268950 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that hit in the L2 TLB\000event=0x45,umask=0x04\000\00000\000\000"
/* offset=1269085 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB Reload of a page of 2M size\000event=0x45,umask=0x04\000\00000\000\000"
/* offset=1269194 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 2M pages\000event=0x45,umask=0x04\000\00000\000\000"
/* offset=1269313 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss of a page of 2M size\000event=0x45,umask=0x40\000\00000\000\000"
/* offset=1269421 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that also missed in the L2 TLB\000event=0x45,umask=0x40\000\00000\000\000"
/* offset=1269565 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that miss in the L2 TLB\000event=0x45,umask=0x40\000\00000\000\000"
/* offset=1269702 */ "ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 2M pages\000event=0x45,umask=0x40\000\00000\000\000"
/* offset=1269857 */ "ls_l1_d_tlb_miss.tlb_reload_32k_l2_hit\000\000memory\000L1 DTLB Reload of a page of 32K size\000event=0x45,umask=0x02\000\00000\000\000"
/* offset=1269968 */ "ls_l1_d_tlb_miss.tlb_reload_32k_l2_miss\000\000memory\000L1 DTLB Miss of a page of 32K size\000event=0x45,umask=0x20\000\00000\000\000"
/* offset=1270078 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that hit in the L2 TLB\000event=0x45,umask=0x01\000\00000\000\000"
/* offset=1270213 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB Reload of a page of 4K size\000event=0x45,umask=0x01\000\00000\000\000"
/* offset=1270322 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 4k pages\000event=0x45,umask=0x01\000\00000\000\000"
/* offset=1270441 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss of a page of 4K size\000event=0x45,umask=0x10\000\00000\000\000"
/* offset=1270549 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that miss the L2 TLB\000event=0x45,umask=0x10\000\00000\000\000"
/* offset=1270683 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that missed the L2 TLB\000event=0x45,umask=0x10\000\00000\000\000"
/* offset=1270819 */ "ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 4k pages\000event=0x45,umask=0x10\000\00000\000\000"
/* offset=1270974 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB Miss. DTLB reload hit a coalesced page\000event=0x45,umask=0x02\000\00000\000\000"
/* offset=1271103 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a coalesced page that hit in the L2 TLB\000event=0x45,umask=0x02\000\00000\000\000"
/* offset=1271254 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x45,umask=0x02\000\00000\000\000"
/* offset=1271457 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB Miss. DTLB reload coalesced page miss\000event=0x45,umask=0x20\000\00000\000\000"
/* offset=1271586 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB Miss. DTLB reload coalesced page that also missed in the L2 TLB\000event=0x45,umask=0x20\000\00000\000\000"
/* offset=1271741 */ "ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x45,umask=0x20\000\00000\000\000"
/* offset=1271980 */ "ls_locks.bus_lock\000\000core\000Retired Lock instructions which caused a bus lock\000event=0x25,umask=0x01\000\00000\000\000"
/* offset=1272081 */ "ls_locks.bus_lock\000\000memory\000Bus lock when a locked operations crosses a cache boundary or is done on an uncacheable memory type\000event=0x25,umask=0x01\000\00000\000\000"
/* offset=1272234 */ "ls_locks.bus_lock\000\000memory\000Retired lock instructions. Bus lock when a locked operations crosses a cache boundary or is done on an uncacheable memory type. Comparable to legacy bus lock\000event=0x25,umask=0x01\000\00000\000\000"
/* offset=1272445 */ "ls_locks.bus_lock\000\000memory\000Retired lock instructions. Comparable to legacy bus lock\000event=0x25,umask=0x01\000\00000\000\000"
/* offset=1272555 */ "ls_locks.non_spec_lock\000\000memory\000Retired lock instructions. Non-speculative lock succeeded\000event=0x25,umask=0x02\000\00000\000\000"
/* offset=1272671 */ "ls_locks.spec_lock_hi_spec\000\000memory\000Retired lock instructions. High speculative cacheable lock speculation succeeded\000event=0x25,umask=0x08\000\00000\000\000"
/* offset=1272814 */ "ls_locks.spec_lock_lo_spec\000\000memory\000Retired lock instructions. Low speculative cacheable lock speculation succeeded\000event=0x25,umask=0x04\000\00000\000\000"
/* offset=1272956 */ "ls_mab_alloc.all_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for all types of allocations\000event=0x41,umask=0x7f\000\00000\000\000"
/* offset=1273118 */ "ls_mab_alloc.all_allocations\000\000memory\000All Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x7f\000\00000\000\000"
/* offset=1273243 */ "ls_mab_alloc.dc_prefetcher\000\000memory\000LS MAB Allocates by Type. DC prefetcher\000event=0x41,umask=0x08\000\00000\000\000"
/* offset=1273345 */ "ls_mab_alloc.dc_prefetcher\000\000memory\000LS MAB allocates by type - DC prefetcher\000event=0x41,umask=0x08\000\00000\000\000"
/* offset=1273448 */ "ls_mab_alloc.hardware_prefetcher_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for hardware prefetcher allocations\000event=0x41,umask=0x40\000\00000\000\000"
/* offset=1273633 */ "ls_mab_alloc.hardware_prefetcher_allocations\000\000memory\000Hardware Prefetcher Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x40\000\00000\000\000"
/* offset=1273790 */ "ls_mab_alloc.load_store_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for load-store allocations\000event=0x41,umask=0x3f\000\00000\000\000"
/* offset=1273957 */ "ls_mab_alloc.load_store_allocations\000\000memory\000Load Store Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x3f\000\00000\000\000"
/* offset=1274096 */ "ls_mab_alloc.loads\000\000memory\000LS MAB Allocates by Type. Loads\000event=0x41,umask=0x01\000\00000\000\000"
/* offset=1274182 */ "ls_mab_alloc.loads\000\000memory\000LS MAB allocates by type - loads\000event=0x41,umask=0x01\000\00000\000\000"
/* offset=1274269 */ "ls_mab_alloc.stores\000\000memory\000LS MAB Allocates by Type. Stores\000event=0x41,umask=0x02\000\00000\000\000"
/* offset=1274357 */ "ls_mab_alloc.stores\000\000memory\000LS MAB allocates by type - stores\000event=0x41,umask=0x02\000\00000\000\000"
/* offset=1274446 */ "ls_misal_accesses\000\000memory\000Misaligned loads\000event=0x47\000\00000\000\000"
/* offset=1274505 */ "ls_misal_loads.ma4k\000\000memory\0004kB misaligned (page crossing) loads\000event=0x47,umask=0x02\000\00000\000\000"
/* offset=1274597 */ "ls_misal_loads.ma4k\000\000memory\000The number of 4KB misaligned (i.e., page crossing) loads\000event=0x47,umask=0x02\000\00000\000\000"
/* offset=1274709 */ "ls_misal_loads.ma64\000\000memory\00064B misaligned (cacheline crossing) loads\000event=0x47,umask=0x01\000\00000\000\000"
/* offset=1274806 */ "ls_misal_loads.ma64\000\000memory\000The number of 64B misaligned (i.e., cacheline crossing) loads\000event=0x47,umask=0x01\000\00000\000\000"
/* offset=1274923 */ "ls_not_halted_cyc\000\000core\000Core cycles not in halt\000event=0x76\000\00000\000\000"
/* offset=1274987 */ "ls_not_halted_cyc\000\000memory\000Cycles not in Halt\000event=0x76\000\00000\000\000"
/* offset=1275048 */ "ls_not_halted_p0_cyc.p0_freq_cyc\000\000core\000Reference cycles (P0 frequency) not in halt \000event=0x120,umask=0x1\000\00000\000\000"
/* offset=1275159 */ "ls_pref_instr_disp.all\000\000cache\000Software prefetch instructions dispatched (speculative) of all types\000event=0x4b,umask=0x07\000\00000\000\000"
/* offset=1275285 */ "ls_pref_instr_disp.load_prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched. Prefetch, Prefetch_T0_T1_T2\000event=0x4b,umask=0x01\000\00000\000\000"
/* offset=1275426 */ "ls_pref_instr_disp.prefetch\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchT0 (move data to all cache levels), T1 (move data to all cache levels except L1) and T2 (move data to all cache levels except L1 and L2)\000event=0x4b,umask=0x01\000\00000\000\000"
/* offset=1275697 */ "ls_pref_instr_disp.prefetch\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchT0, T1 and T2 instructions. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x01\000\00000\000\000"
/* offset=1275879 */ "ls_pref_instr_disp.prefetch\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). Prefetch_T0_T1_T2. PrefetchT0, T1 and T2 instructions. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x01\000\00000\000\000"
/* offset=1276080 */ "ls_pref_instr_disp.prefetch_nta\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchNTA (move data with minimum cache pollution i.e. non-temporal access)\000event=0x4b,umask=0x04\000\00000\000\000"
/* offset=1276288 */ "ls_pref_instr_disp.prefetch_nta\000\000memory\000Software Prefetch Instructions (PREFETCHNTA instruction) Dispatched\000event=0x4b,umask=0x04\000\00000\000\000"
/* offset=1276423 */ "ls_pref_instr_disp.prefetch_nta\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchNTA instruction. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x04\000\00000\000\000"
/* offset=1276598 */ "ls_pref_instr_disp.prefetch_w\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchW (move data to L1 cache and mark it modifiable)\000event=0x4b,umask=0x02\000\00000\000\000"
/* offset=1276783 */ "ls_pref_instr_disp.prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchW instruction. See docAPM3 PREFETCHW\000event=0x4b,umask=0x02\000\00000\000\000"
/* offset=1276950 */ "ls_pref_instr_disp.prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). See docAPM3 PREFETCHW\000event=0x4b,umask=0x02\000\00000\000\000"
/* offset=1277094 */ "ls_pref_instr_disp.store_prefetch_w\000\000memory\000Software Prefetch Instructions (3DNow PREFETCHW instruction) Dispatched\000event=0x4b,umask=0x02\000\00000\000\000"
/* offset=1277237 */ "ls_pref_instr_disp\000\000memory\000Software Prefetch Instructions Dispatched (Speculative)\000event=0x4b,umask=0xff\000\00000\000\000"
/* offset=1277347 */ "ls_rdtsc\000\000memory\000Number of reads of the TSC (RDTSC instructions). The count is speculative\000event=0x2d\000\00000\000\000"
/* offset=1277454 */ "ls_refills_from_sys.ls_mabresp_lcl_cache\000\000memory\000Demand Data Cache Fills by Data Source. Hit in cache; local CCX (not Local L2), or Remote CCX and the address's Home Node is on this thread's die\000event=0x43,umask=0x02\000\00000\000\000"
/* offset=1277676 */ "ls_refills_from_sys.ls_mabresp_lcl_dram\000\000memory\000Demand Data Cache Fills by Data Source. DRAM or IO from this thread's die\000event=0x43,umask=0x08\000\00000\000\000"
/* offset=1277825 */ "ls_refills_from_sys.ls_mabresp_lcl_l2\000\000memory\000Demand Data Cache Fills by Data Source. Local L2 hit\000event=0x43,umask=0x01\000\00000\000\000"
/* offset=1277951 */ "ls_refills_from_sys.ls_mabresp_rmt_cache\000\000memory\000Demand Data Cache Fills by Data Source. Hit in cache; Remote CCX and the address's Home Node is on a different die\000event=0x43,umask=0x10\000\00000\000\000"
/* offset=1278142 */ "ls_refills_from_sys.ls_mabresp_rmt_dram\000\000memory\000Demand Data Cache Fills by Data Source. DRAM or IO from different die\000event=0x43,umask=0x40\000\00000\000\000"
/* offset=1278287 */ "ls_ret_cl_flush\000\000core\000Retired CLFLUSH instructions\000event=0x26\000\00000\000\000"
/* offset=1278354 */ "ls_ret_cl_flush\000\000memory\000Number of retired CLFLUSH instructions\000event=0x26\000\00000\000\000"
/* offset=1278433 */ "ls_ret_cl_flush\000\000memory\000The number of retired CLFLUSH instructions. This is a non-speculative event\000event=0x26\000\00000\000\000"
/* offset=1278549 */ "ls_ret_cpuid\000\000core\000Retired CPUID instructions\000event=0x27\000\00000\000\000"
/* offset=1278611 */ "ls_ret_cpuid\000\000memory\000Number of retired CPUID instructions\000event=0x27\000\00000\000\000"
/* offset=1278685 */ "ls_ret_cpuid\000\000memory\000The number of CPUID instructions retired\000event=0x27\000\00000\000\000"
/* offset=1278763 */ "ls_smi_rx\000\000core\000SMIs received\000event=0x2b\000\00000\000\000"
/* offset=1278809 */ "ls_smi_rx\000\000memory\000Counts the number of SMIs received\000event=0x2b\000\00000\000\000"
/* offset=1278878 */ "ls_smi_rx\000\000memory\000Number of SMIs received\000event=0x2b\000\00000\000\000"
/* offset=1278936 */ "ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000A non-cacheable store and the non-cacheable commit buffer is full\000event=0x37,umask=0x01\000\00000\000\000"
/* offset=1279084 */ "ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000A non-cacheable store and the non-cacheable commit buffer is full\000event=0x37\000\00000\000\000"
/* offset=1279221 */ "ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000Non-cacheable store commits cancelled due to the non-cacheable commit buffer being full\000event=0x37,umask=0x01\000\00000\000\000"
/* offset=1279391 */ "ls_stlf\000\000memory\000Number of STLF hits\000event=0x35\000\00000\000\000"
/* offset=1279443 */ "ls_stlf\000\000memory\000Store-to-load-forward (STLF) hits\000event=0x35\000\00000\000\000"
/* offset=1279509 */ "ls_sw_pf_dc_fill.ls_mabresp_lcl_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From another cache (home node local)\000event=0x59,umask=0x02\000\00000\000\000"
/* offset=1279670 */ "ls_sw_pf_dc_fill.ls_mabresp_lcl_dram\000\000memory\000Software Prefetch Data Cache Fills by Data Source. DRAM or IO from this thread's die.  From DRAM (home node local)\000event=0x59,umask=0x08\000\00000\000\000"
/* offset=1279857 */ "ls_sw_pf_dc_fill.ls_mabresp_lcl_l2\000\000memory\000Software Prefetch Data Cache Fills by Data Source. Local L2 hit\000event=0x59,umask=0x01\000\00000\000\000"
/* offset=1279991 */ "ls_sw_pf_dc_fill.ls_mabresp_rmt_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From another cache (home node remote)\000event=0x59,umask=0x10\000\00000\000\000"
/* offset=1280153 */ "ls_sw_pf_dc_fill.ls_mabresp_rmt_dram\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM (home node remote)\000event=0x59,umask=0x40\000\00000\000\000"
/* offset=1280305 */ "ls_sw_pf_dc_fills.all\000\000cache\000Software prefetch data cache fills from all types of data sources\000event=0x59,umask=0xdf\000\00000\000\000"
/* offset=1280427 */ "ls_sw_pf_dc_fills.alternate_memories\000\000cache\000Software prefetch data cache fills from extension memory\000event=0x59,umask=0x80\000\00000\000\000"
/* offset=1280555 */ "ls_sw_pf_dc_fills.dram_io_far\000\000cache\000Software prefetch data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x59,umask=0x40\000\00000\000\000"
/* offset=1280731 */ "ls_sw_pf_dc_fills.dram_io_near\000\000cache\000Software prefetch data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x59,umask=0x08\000\00000\000\000"
/* offset=1280878 */ "ls_sw_pf_dc_fills.ext_cache_local\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x59,umask=0x04\000\00000\000\000"
/* offset=1281039 */ "ls_sw_pf_dc_fills.ext_cache_remote\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x59,umask=0x10\000\00000\000\000"
/* offset=1281193 */ "ls_sw_pf_dc_fills.far_cache\000\000cache\000Software prefetch data cache fills from cache of another CCX in a different NUMA node\000event=0x59,umask=0x10\000\00000\000\000"
/* offset=1281341 */ "ls_sw_pf_dc_fills.int_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x59,umask=0x02\000\00000\000\000"
/* offset=1281491 */ "ls_sw_pf_dc_fills.lcl_l2\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From Local L2 to the core\000event=0x59,umask=0x01\000\00000\000\000"
/* offset=1281628 */ "ls_sw_pf_dc_fills.local_ccx\000\000cache\000Software prefetch data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x59,umask=0x02\000\00000\000\000"
/* offset=1281777 */ "ls_sw_pf_dc_fills.local_l2\000\000cache\000Software prefetch data cache fills from local L2 cache\000event=0x59,umask=0x01\000\00000\000\000"
/* offset=1281893 */ "ls_sw_pf_dc_fills.mem_io_local\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x59,umask=0x08\000\00000\000\000"
/* offset=1282049 */ "ls_sw_pf_dc_fills.mem_io_remote\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x59,umask=0x40\000\00000\000\000"
/* offset=1282211 */ "ls_sw_pf_dc_fills.near_cache\000\000cache\000Software prefetch data cache fills from cache of another CCX in the same NUMA node\000event=0x59,umask=0x04\000\00000\000\000"
/* offset=1282357 */ "ls_tablewalker.dc_type0\000\000memory\000Total Page Table Walks DC Type 0\000event=0x46,umask=0x01\000\00000\000\000"
/* offset=1282449 */ "ls_tablewalker.dc_type1\000\000memory\000Total Page Table Walks DC Type 1\000event=0x46,umask=0x02\000\00000\000\000"
/* offset=1282541 */ "ls_tablewalker.dside\000\000memory\000Total Page Table Walks on D-side\000event=0x46,umask=0x03\000\00000\000\000"
/* offset=1282630 */ "ls_tablewalker.ic_type0\000\000memory\000Total Page Table Walks IC Type 0\000event=0x46,umask=0x04\000\00000\000\000"
/* offset=1282722 */ "ls_tablewalker.ic_type1\000\000memory\000Total Page Table Walks IC Type 1\000event=0x46,umask=0x08\000\00000\000\000"
/* offset=1282814 */ "ls_tablewalker.iside\000\000memory\000Total Page Table Walks on I-side\000event=0x46,umask=0x0c\000\00000\000\000"
/* offset=1282903 */ "ls_tlb_flush.all\000\000memory\000All TLB Flushes\000event=0x78,umask=0xff\000\00000\000\000"
/* offset=1282971 */ "ls_tlb_flush.all_tlb_flushes\000\000memory\000All TLB Flushes. Requires unit mask 0xFF to engage event for counting. Use all_tlbs_flushed instead\000event=0x78,umask=0xff\000\00000\000\000"
/* offset=1283135 */ "ls_tlb_flush\000\000memory\000All TLB Flushes\000event=0x78\000\00000\000\000"
/* offset=1283188 */ "lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1283301 */ "lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_OK]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_OK]\000"
/* offset=1283604 */ "lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000"
/* offset=1283818 */ "lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1283964 */ "lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000"
/* offset=1284194 */ "lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000"
/* offset=1284404 */ "lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1284548 */ "lsd.cycles_active\000cpu_core\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder. Unit: cpu_core \000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000"
/* offset=1284803 */ "lsd.cycles_ok\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_4_UOPS]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_4_UOPS]\000"
/* offset=1285110 */ "lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=5,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000"
/* offset=1285361 */ "lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=6,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000"
/* offset=1285612 */ "lsd.cycles_ok\000cpu_core\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder. Unit: cpu_core \000event=0xa8,cmask=6,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000"
/* offset=1285888 */ "lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1286007 */ "lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000"
/* offset=1286187 */ "lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered by the LSD\000" /* also: LSD\000 */
/* offset=1286318 */ "lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000"
/* offset=1286487 */ "lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1286583 */ "lsd.uops\000cpu_core\000pipeline\000Number of Uops delivered by the LSD. Unit: cpu_core \000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000"
/* offset=1286788 */ "lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1286903 */ "machine_clears.all\000\000pipeline\000All machine clears\000event=0xc3,period=200003\000\00000\000Counts machine clears for any reason\000"
/* offset=1287017 */ "machine_clears.all\000\000pipeline\000All machine clears\000event=0xc3,period=20003\000\00000\000Counts machine clears for any reason\000"
/* offset=1287130 */ "machine_clears.all\000\000pipeline\000Counts all machine clears\000event=0xc3,period=200003,umask=0x8\000\00000\000Machine clears happen when something happens in the machine that causes the hardware to need to take special care to get the right answer. When such a condition is signaled on an instruction, the front end of the machine is notified that it must restart, so no more instructions will be decoded from the current path.  All instructions \"older\" than this one will be allowed to finish.  This instruction and all \"younger\" instructions must be cleared, since they must not be allowed to complete.  Essentially, the hardware waits until the problematic instruction is the oldest instruction in the machine.  This means all older instructions are retired, and all pending stores (from older instructions) are completed.  Then the new path of instructions from the front end are allowed to start into the machine.  There are many conditions that might cause a machine clear (including the receipt of an interrupt, or a trap or a fault).  All those conditions (including but not limited to MACHINE_CLEARS.MEMORY_ORDERING, MACHINE_CLEARS.SMC, and MACHINE_CLEARS.FP_ASSIST) are captured in the ANY event. In addition, some conditions can be specifically counted (i.e. SMC, MEMORY_ORDERING, FP_ASSIST).  However, the sum of SMC, MEMORY_ORDERING, and FP_ASSIST machine clears will not necessarily equal the number of ANY\000"
/* offset=1288535 */ "machine_clears.all\000\000pipeline\000Counts all nukes\000event=0xc3,period=200003,umask=0x8\000\00000\000\000"
/* offset=1288621 */ "machine_clears.any\000\000pipeline\000Counts the total number of machine clears for any reason including, but not limited to, memory ordering, memory disambiguation, SMC, and FP assist\000event=0xc3,period=20003\000\00000\000\000"
/* offset=1288826 */ "machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000"
/* offset=1289012 */ "machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000"
/* offset=1289143 */ "machine_clears.count\000cpu_core\000pipeline\000Number of machine clears (nukes) of any type. Unit: cpu_core \000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000"
/* offset=1289354 */ "machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000"
/* offset=1289455 */ "machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000This event counts both thread-specific (TS) and all-thread (AT) nukes\000"
/* offset=1289676 */ "machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1289828 */ "machine_clears.disambiguation\000\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU\000event=0xc3,period=20003,umask=0x8\000\00000\000\000"
/* offset=1290034 */ "machine_clears.disambiguation\000\000pipeline\000Machine clears due to memory disambiguation\000event=0xc3,period=200003,umask=0x8\000\00000\000Counts machine clears due to memory disambiguation.  Memory disambiguation happens when a load which has been issued conflicts with a previous unretired store in the pipeline whose address was not known at issue time, but is later resolved to be the same as the load address\000"
/* offset=1290432 */ "machine_clears.disambiguation\000\000pipeline\000Machine clears due to memory disambiguation\000event=0xc3,period=20003,umask=0x8\000\00000\000Counts machine clears due to memory disambiguation.  Memory disambiguation happens when a load which has been issued conflicts with a previous unretired store in the pipeline whose address was not known at issue time, but is later resolved to be the same as the load address\000"
/* offset=1290829 */ "machine_clears.disambiguation\000cpu_atom\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x8\000\00000\000\000"
/* offset=1291060 */ "machine_clears.fp_assist\000\000floating point\000Counts the number of floating operations retired that required microcode assists\000event=0xc3,period=200003,umask=0x4\000\00000\000This event counts the number of times that the pipeline stalled due to FP operations needing assists\000"
/* offset=1291322 */ "machine_clears.fp_assist\000\000floating point\000Counts the number of floating point operations retired that required microcode assist\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000"
/* offset=1291653 */ "machine_clears.fp_assist\000\000floating point\000Machine clears due to FP assists\000event=0xc3,period=200003,umask=0x4\000\00000\000Counts machine clears due to floating point (FP) operations needing assists.  For instance, if the result was a floating point denormal, the hardware clears the pipeline and reissues uops to produce the correct IEEE compliant denormal result\000"
/* offset=1292008 */ "machine_clears.fp_assist\000\000floating point\000Machine clears due to FP assists\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts machine clears due to floating point (FP) operations needing assists.  For instance, if the result was a floating point denormal, the hardware clears the pipeline and reissues uops to produce the correct IEEE compliant denormal result\000"
/* offset=1292362 */ "machine_clears.fp_assist\000\000floating point\000Stalls due to FP assists\000event=0xc3,period=200003,umask=0x4\000\00000\000This event counts the number of times that pipeline stalled due to FP operations needing assists\000"
/* offset=1292564 */ "machine_clears.fp_assist\000cpu_atom\000floating point\000Counts the number of floating point operations retired that required microcode assist. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000"
/* offset=1292920 */ "machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Counts the number of executed AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000"
/* offset=1293258 */ "machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000"
/* offset=1293637 */ "machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000\000"
/* offset=1293852 */ "machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000"
/* offset=1293986 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts  Spec update: SKL089\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:a. memory disambiguation,b. external snoop, orc. cross SMT-HW-thread snoop (stores) hitting load buffer  Spec update: SKL089\000"
/* offset=1294406 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from memory disambiguation, external snoops, or cross SMT-HW-thread snoop (stores) hitting load buffers.  Machine clears can have a significant performance impact if they are happening frequently\000"
/* offset=1294861 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:\n1. memory disambiguation,\n2. external snoop, or\n3. cross SMT-HW-thread snoop (stores) hitting load buffer\000"
/* offset=1295253 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering machine clears detected. Memory ordering machine clears can result from memory address aliasing or snoops from another hardware thread or core to data inflight in the pipeline.  Machine clears can have a significant performance impact if they are happening frequently\000"
/* offset=1295713 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000\000"
/* offset=1295858 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation\000event=0xc3,period=20003,umask=0x2\000\00000\000\000"
/* offset=1296131 */ "machine_clears.memory_ordering\000\000memory\000Counts the number of times the machine clears due to memory ordering hazards\000event=0xc3,period=200003,umask=0x2\000\00000\000\000"
/* offset=1296287 */ "machine_clears.memory_ordering\000\000memory\000Machine clears due to memory ordering issue\000event=0xc3,period=200003,umask=0x2\000\00000\000Counts machine clears due to memory ordering issues.  This occurs when a snoop request happens and the machine is uncertain if memory ordering will be preserved as another core is in the process of modifying the data\000"
/* offset=1296626 */ "machine_clears.memory_ordering\000\000memory\000Machine clears due to memory ordering issue\000event=0xc3,period=20003,umask=0x2\000\00000\000Counts machine clears due to memory ordering issues.  This occurs when a snoop request happens and the machine is uncertain if memory ordering will be preserved - as another core is in the process of modifying the data\000"
/* offset=1296966 */ "machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000"
/* offset=1297300 */ "machine_clears.memory_ordering\000\000memory\000Stalls due to Memory ordering\000event=0xc3,period=200003,umask=0x2\000\00000\000This event counts the number of times that pipeline was cleared due to memory ordering issues\000"
/* offset=1297502 */ "machine_clears.memory_ordering\000cpu_atom\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x2\000\00000\000\000"
/* offset=1297800 */ "machine_clears.memory_ordering\000cpu_core\000memory\000Number of machine clears due to memory ordering conflicts. Unit: cpu_core \000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000"
/* offset=1298159 */ "machine_clears.mrn_nuke\000\000pipeline\000Counts the number of machines clears due to memory renaming\000event=0xc3,period=1000003,umask=0x80\000\00000\000\000"
/* offset=1298295 */ "machine_clears.mrn_nuke\000cpu_atom\000pipeline\000Counts the number of machines clears due to memory renaming. Unit: cpu_atom \000event=0xc3,period=1000003,umask=0x80\000\00000\000\000"
/* offset=1298456 */ "machine_clears.page_fault\000\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs\000event=0xc3,period=20003,umask=0x20\000\00000\000\000"
/* offset=1298736 */ "machine_clears.page_fault\000\000pipeline\000Machines clear due to a page fault\000event=0xc3,period=20003,umask=0x20\000\00000\000Counts the number of times that the machines clears due to a page fault. Covers both I-side and D-side(Loads/Stores) page faults. A page fault occurs when either page is not present, or an access violation\000"
/* offset=1299052 */ "machine_clears.page_fault\000cpu_atom\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x20\000\00000\000\000"
/* offset=1299357 */ "machine_clears.slow\000\000pipeline\000Counts the number of machine clears that flush the pipeline and restart the machine with the use of microcode due to SMC, MEMORY_ORDERING, FP_ASSISTS, PAGE_FAULT, DISAMBIGUATION, and FPC_VIRTUAL_TRAP\000event=0xc3,period=20003,umask=0x6f\000\00000\000\000"
/* offset=1299627 */ "machine_clears.slow\000cpu_atom\000pipeline\000Counts the number of machine clears that flush the pipeline and restart the machine with the use of microcode due to SMC, MEMORY_ORDERING, FP_ASSISTS, PAGE_FAULT, DISAMBIGUATION, and FPC_VIRTUAL_TRAP. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x6f\000\00000\000\000"
/* offset=1299922 */ "machine_clears.smc\000\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page\000event=0xc3,period=20003,umask=0x1\000\00000\000\000"
/* offset=1300120 */ "machine_clears.smc\000\000pipeline\000Counts the number of times that the machine clears due to program modifying data within 1K of a recently fetched code page\000event=0xc3,period=200003,umask=0x1\000\00000\000\000"
/* offset=1300312 */ "machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000"
/* offset=1300409 */ "machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200000,umask=0x1\000\00000\000\000"
/* offset=1300507 */ "machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200003,umask=0x1\000\00000\000Counts the number of times that the processor detects that a program is writing to a code section and has to perform a machine clear because of that modification.  Self-modifying code (SMC) causes a severe penalty in all Intel(R) architecture processors\000"
/* offset=1300858 */ "machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200003,umask=0x1\000\00000\000This event counts the number of times that a program writes to a code section. Self-modifying code causes a severe penalty in all Intel? architecture processors\000"
/* offset=1301116 */ "machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20003,umask=0x1\000\00000\000Counts the number of times that the processor detects that a program is writing to a code section and has to perform a machine clear because of that modification.  Self-modifying code (SMC) causes a severe penalty in all Intel(R) architecture processors\000"
/* offset=1301466 */ "machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000"
/* offset=1301641 */ "machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Number of self-modifying-code machine clears detected\000"
/* offset=1301798 */ "machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event counts self-modifying code (SMC) detected, which causes a machine clear\000"
/* offset=1301984 */ "machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event is incremented when self-modifying code (SMC) is detected, which causes a machine clear.  Machine clears can have a significant performance impact if they are happening frequently\000"
/* offset=1302278 */ "machine_clears.smc\000cpu_atom\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x1\000\00000\000\000"
/* offset=1302501 */ "machine_clears.smc\000cpu_core\000pipeline\000Self-modifying code (SMC) detected. Unit: cpu_core \000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000"
/* offset=1302701 */ "macro_insts.all_decoded\000\000frontend\000All Instructions decoded\000event=0xaa,period=2000000,umask=0x3\000\00000\000\000"
/* offset=1302801 */ "macro_insts.cisc_decoded\000\000frontend\000CISC macro instructions decoded\000event=0xaa,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1302909 */ "macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1303001 */ "macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1303113 */ "macro_insts.non_cisc_decoded\000\000frontend\000Non-CISC nacro instructions decoded\000event=0xaa,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1303229 */ "macro_ops_retired\000\000recommended\000Macro-ops Retired\000event=0xc1\000\00000\000\000"
/* offset=1303294 */ "mem_bound_stalls.ifetch\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000"
/* offset=1303672 */ "mem_bound_stalls.ifetch\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000"
/* offset=1304075 */ "mem_bound_stalls.ifetch_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000"
/* offset=1304436 */ "mem_bound_stalls.ifetch_dram_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000"
/* offset=1304822 */ "mem_bound_stalls.ifetch_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache\000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000"
/* offset=1305158 */ "mem_bound_stalls.ifetch_l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000"
/* offset=1305519 */ "mem_bound_stalls.ifetch_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000"
/* offset=1305922 */ "mem_bound_stalls.ifetch_llc_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M. Unit: cpu_atom \000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000"
/* offset=1306350 */ "mem_bound_stalls.load\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x7\000\00000\000\000"
/* offset=1306543 */ "mem_bound_stalls.load\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x7\000\00000\000\000"
/* offset=1306761 */ "mem_bound_stalls.load_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x4\000\00000\000\000"
/* offset=1306950 */ "mem_bound_stalls.load_dram_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x4\000\00000\000\000"
/* offset=1307164 */ "mem_bound_stalls.load_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache\000event=0x34,period=200003,umask=0x1\000\00000\000\000"
/* offset=1307335 */ "mem_bound_stalls.load_l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=200003,umask=0x1\000\00000\000\000"
/* offset=1307531 */ "mem_bound_stalls.load_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000"
/* offset=1307862 */ "mem_bound_stalls.load_llc_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M. Unit: cpu_atom \000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000"
/* offset=1308218 */ "mem_bound_stalls.store_buffer_full\000\000cache\000Counts the number of cycles the core is stalled due to a store buffer being full\000event=0x34,period=200003,umask=0x40\000\00000\000\000"
/* offset=1308382 */ "mem_bound_stalls_ifetch.all\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an instruction cache or TLB miss. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x6f\000\00000\000\000"
/* offset=1308586 */ "mem_bound_stalls_ifetch.l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x1\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000"
/* offset=1308948 */ "mem_bound_stalls_ifetch.llc_hit\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an icache or itlb miss which hit in the LLC. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x6\000\00000\000\000"
/* offset=1309166 */ "mem_bound_stalls_ifetch.llc_miss\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an icache or itlb miss which missed all the caches. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x68\000\00000\000\000"
/* offset=1309393 */ "mem_bound_stalls_load.all\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an L1 demand load miss. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x6f\000\00000\000\000"
/* offset=1309585 */ "mem_bound_stalls_load.l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x1\000\00000\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 cache\000"
/* offset=1309874 */ "mem_bound_stalls_load.llc_hit\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to a demand load miss which hit in the LLC. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x6\000\00000\000\000"
/* offset=1310086 */ "mem_bound_stalls_load.llc_miss\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to a demand load miss which missed all the local caches. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x68\000\00000\000\000"
/* offset=1310313 */ "mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000"
/* offset=1310641 */ "mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000"
/* offset=1310969 */ "mem_inst_retired.all_loads\000cpu_core\000cache\000Retired load instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000"
/* offset=1311322 */ "mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000"
/* offset=1311557 */ "mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000"
/* offset=1311792 */ "mem_inst_retired.all_stores\000cpu_core\000cache\000Retired store instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000"
/* offset=1312052 */ "mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000"
/* offset=1312305 */ "mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000"
/* offset=1312558 */ "mem_inst_retired.any\000cpu_core\000cache\000All retired memory instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000"
/* offset=1312836 */ "mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000"
/* offset=1312997 */ "mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000"
/* offset=1313161 */ "mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000"
/* offset=1313323 */ "mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000"
/* offset=1313488 */ "mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000"
/* offset=1313649 */ "mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000"
/* offset=1313812 */ "mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000"
/* offset=1313974 */ "mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000"
/* offset=1314139 */ "mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000"
/* offset=1314299 */ "mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000"
/* offset=1314463 */ "mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000"
/* offset=1314621 */ "mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000"
/* offset=1314783 */ "mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000"
/* offset=1314943 */ "mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000"
/* offset=1315107 */ "mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000"
/* offset=1315265 */ "mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1315394 */ "mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000"
/* offset=1315660 */ "mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000"
/* offset=1315828 */ "mem_inst_retired.lock_loads\000cpu_core\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000"
/* offset=1316119 */ "mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000"
/* offset=1316426 */ "mem_inst_retired.split_loads\000cpu_core\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000"
/* offset=1316758 */ "mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000"
/* offset=1317068 */ "mem_inst_retired.split_stores\000cpu_core\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000"
/* offset=1317403 */ "mem_inst_retired.stlb_hit_loads\000cpu_core\000cache\000Retired load instructions that hit the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x9\000\00000\000Number of retired load instructions with a clean hit in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1317725 */ "mem_inst_retired.stlb_hit_stores\000cpu_core\000cache\000Retired store instructions that hit the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0xa\000\00000\000Number of retired store instructions that hit in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1318042 */ "mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1318345 */ "mem_inst_retired.stlb_miss_loads\000cpu_core\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1318673 */ "mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1318979 */ "mem_inst_retired.stlb_miss_stores\000cpu_core\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000"
/* offset=1319310 */ "mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1319441 */ "mem_load_completed.l1_miss_any\000\000cache\000Completed demand load uops that miss the L1 d-cache\000event=0x43,period=1000003,umask=0xfd\000\00000\000Number of completed demand load requests that missed the L1 data cache including shadow misses (FB hits, merge to an ongoing L1D miss)\000"
/* offset=1319707 */ "mem_load_completed.l1_miss_any\000cpu_core\000cache\000Completed demand load uops that miss the L1 d-cache. Unit: cpu_core \000event=0x43,period=1000003,umask=0xfd\000\00000\000Number of completed demand load requests that missed the L1 data cache including shadow misses (FB hits, merge to an ongoing L1D miss)\000"
/* offset=1319998 */ "mem_load_l3_hit_retired.xsnp_fwd\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000"
/* offset=1320337 */ "mem_load_l3_hit_retired.xsnp_fwd\000\000cache\000Snoop hit a modified(HITM) or clean line(HIT_W_FWD) in another on-pkg core which forwarded the data back due to a retired load instruction  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions where a cross-core snoop hit in another cores caches on this socket, the data was forwarded back to the requesting core as the data was modified (SNOOP_HITM) or the L3 did not have the data(SNOOP_HIT_WITH_FWD)  Supports address when precise (Precise event)\000"
/* offset=1320891 */ "mem_load_l3_hit_retired.xsnp_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000"
/* offset=1321255 */ "mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1321627 */ "mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1322006 */ "mem_load_l3_hit_retired.xsnp_hit\000\000cache\000This event is deprecated. Refer to new event MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00010\000\000"
/* offset=1322213 */ "mem_load_l3_hit_retired.xsnp_hit\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1322617 */ "mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000"
/* offset=1322950 */ "mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000"
/* offset=1323290 */ "mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000This event is deprecated. Refer to new event MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00010\000\000"
/* offset=1323495 */ "mem_load_l3_hit_retired.xsnp_hitm\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000"
/* offset=1323860 */ "mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000"
/* offset=1324093 */ "mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1324489 */ "mem_load_l3_hit_retired.xsnp_miss\000cpu_core\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1324910 */ "mem_load_l3_hit_retired.xsnp_no_fwd\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1325292 */ "mem_load_l3_hit_retired.xsnp_no_fwd\000\000cache\000Snoop hit without forwarding in another on-pkg core due to a retired load instruction, data was supplied by the L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions in which the L3 supplied the data and a cross-core snoop hit in another cores caches on this socket but that other core did not forward the data back (SNOOP_HIT_NO_FWD)  Supports address when precise (Precise event)\000"
/* offset=1325784 */ "mem_load_l3_hit_retired.xsnp_no_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000"
/* offset=1326191 */ "mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000"
/* offset=1326535 */ "mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000"
/* offset=1326886 */ "mem_load_l3_hit_retired.xsnp_none\000cpu_core\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000"
/* offset=1327262 */ "mem_load_l3_miss_retired.local_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000"
/* offset=1327606 */ "mem_load_l3_miss_retired.local_dram\000cpu_core\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000"
/* offset=1327975 */ "mem_load_l3_miss_retired.remote_dram\000\000cache\000MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM  Supports address when precise (Precise event)\000event=0xd3,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1328144 */ "mem_load_l3_miss_retired.remote_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from remote dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x2\000\00000\000\000"
/* offset=1328360 */ "mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000"
/* offset=1328694 */ "mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise\000"
/* offset=1328996 */ "mem_load_l3_miss_retired.remote_hitm\000\000cache\000MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM  Supports address when precise (Precise event)\000event=0xd3,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1329165 */ "mem_load_l3_miss_retired.remote_hitm\000\000cache\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000"
/* offset=1329464 */ "mem_load_l3_miss_retired.remote_pmm\000\000cache\000Retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000Counts retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000"
/* offset=1329971 */ "mem_load_l3_miss_retired.remote_pmm\000\000cache\000Retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches\000event=0xd3,period=100007,umask=0x10\000\00000\000Counts retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3\000"
/* offset=1330329 */ "mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or Bus Lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000"
/* offset=1330690 */ "mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access  Supports address when precise (Precise event)\000"
/* offset=1331036 */ "mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000"
/* offset=1331393 */ "mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000\000"
/* offset=1331574 */ "mem_load_misc_retired.uc\000cpu_core\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000"
/* offset=1331956 */ "mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000"
/* offset=1332089 */ "mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (precise event) (Precise event)\000event=0xcb,period=200000,umask=0x4\000\00000\000\000"
/* offset=1332237 */ "mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000"
/* offset=1332781 */ "mem_load_retired.fb_hit\000\000cache\000Retired load instructions which data sources were load missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000"
/* offset=1333255 */ "mem_load_retired.fb_hit\000cpu_core\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000"
/* offset=1333824 */ "mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000"
/* offset=1333977 */ "mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000"
/* offset=1334379 */ "mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000"
/* offset=1334781 */ "mem_load_retired.l1_hit\000cpu_core\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000"
/* offset=1335208 */ "mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000"
/* offset=1335514 */ "mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000"
/* offset=1335820 */ "mem_load_retired.l1_miss\000cpu_core\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000"
/* offset=1336151 */ "mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1336281 */ "mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000"
/* offset=1336567 */ "mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000"
/* offset=1336860 */ "mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000"
/* offset=1336983 */ "mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (precise event)\000event=0xcb,period=200000,umask=0x1\000\00000\000\000"
/* offset=1337106 */ "mem_load_retired.l2_hit\000cpu_core\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000"
/* offset=1337424 */ "mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000"
/* offset=1337713 */ "mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000"
/* offset=1337994 */ "mem_load_retired.l2_miss\000\000cache\000Retired loads that miss the L2 cache\000event=0xcb,period=10000,umask=0x2\000\00000\000\000"
/* offset=1338102 */ "mem_load_retired.l2_miss\000cpu_core\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000"
/* offset=1338416 */ "mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1338721 */ "mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1339025 */ "mem_load_retired.l3_hit\000cpu_core\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1339355 */ "mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1339662 */ "mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1339968 */ "mem_load_retired.l3_miss\000cpu_core\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000"
/* offset=1340299 */ "mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000"
/* offset=1340426 */ "mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000"
/* offset=1340577 */ "mem_load_retired.local_pmm\000\000cache\000Retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x80\000\00000\000Counts retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3  Supports address when precise (Precise event)\000"
/* offset=1341019 */ "mem_load_retired.local_pmm\000\000cache\000Retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x80\000\00000\000Counts retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000"
/* offset=1341515 */ "mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000"
/* offset=1341691 */ "mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops which data sources were L3 hit and a cross-core snoop hit in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000"
/* offset=1342123 */ "mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000"
/* offset=1342388 */ "mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops which data sources were HitM responses from a core on same socket (shared L3)  Supports address when precise.  Spec update: BDM100 (Precise event)\000"
/* offset=1342796 */ "mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000"
/* offset=1343042 */ "mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000This event counts retired load uops which data sources were L3 Hit and a cross-core snoop missed in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000"
/* offset=1343484 */ "mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000"
/* offset=1343756 */ "mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000"
/* offset=1344174 */ "mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000"
/* offset=1344433 */ "mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uop whose Data Source was: local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000"
/* offset=1344834 */ "mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x1\000\00000\000This event counts retired load uops where the data came from local DRAM. This does not include hardware prefetches  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000"
/* offset=1345280 */ "mem_load_uops_l3_miss_retired.remote_dram\000\000cache\000Retired load uop whose Data Source was: remote DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000\000"
/* offset=1345534 */ "mem_load_uops_l3_miss_retired.remote_dram\000\000cache\000Retired load uop whose Data Source was: remote DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x4\000\00000\000\000"
/* offset=1345795 */ "mem_load_uops_l3_miss_retired.remote_fwd\000\000cache\000Retired load uop whose Data Source was: forwarded from remote cache  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x20\000\00000\000\000"
/* offset=1346020 */ "mem_load_uops_l3_miss_retired.remote_fwd\000\000cache\000Retired load uop whose Data Source was: forwarded from remote cache  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x20\000\00000\000\000"
/* offset=1346245 */ "mem_load_uops_l3_miss_retired.remote_hitm\000\000cache\000Retired load uop whose Data Source was: Remote cache HITM  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000\000"
/* offset=1346461 */ "mem_load_uops_l3_miss_retired.remote_hitm\000\000cache\000Retired load uop whose Data Source was: Remote cache HITM  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x10\000\00000\000\000"
/* offset=1346677 */ "mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000"
/* offset=1346871 */ "mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a non-modified state. (Precise Event - PEBS) (Precise event)\000"
/* offset=1347536 */ "mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a non-modified state\000"
/* offset=1348121 */ "mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000"
/* offset=1348296 */ "mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a modified state, so the line had to be invalidated in that L2 cache and transferred to the requesting L2. (Precise Event - PEBS) (Precise event)\000"
/* offset=1349027 */ "mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a modified state, so the line had to be invalidated in that L2 cache and transferred to the requesting L2\000"
/* offset=1349678 */ "mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000"
/* offset=1349879 */ "mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000"
/* offset=1350104 */ "mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache\000event=0xd2,period=20011,umask=0x1\000\00000\000\000"
/* offset=1350289 */ "mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000"
/* offset=1350470 */ "mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000"
/* offset=1350675 */ "mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required\000event=0xd2,period=100003,umask=0x8\000\00000\000\000"
/* offset=1350840 */ "mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)\000event=0xd3,period=100007,umask=0x1\000\00000\000\000"
/* offset=1350995 */ "mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Retired load uops which data sources missed LLC but serviced from local dram\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uops whose data source was local memory (cross-socket snoop not needed or missed)\000"
/* offset=1351255 */ "mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Retired load uops whose data source was local DRAM (Snoop not needed, Snoop Miss, or Snoop Hit data not forwarded)\000event=0xd3,period=100007,umask=0x3\000\00000\000\000"
/* offset=1351459 */ "mem_load_uops_llc_miss_retired.remote_dram\000\000cache\000Data from remote DRAM either Snoop not needed or Snoop Miss (RspI)\000event=0xd3,period=100007,umask=0x4\000\00000\000\000"
/* offset=1351616 */ "mem_load_uops_llc_miss_retired.remote_dram\000\000cache\000Retired load uops whose data source was remote DRAM (Snoop not needed, Snoop Miss, or Snoop Hit data not forwarded)\000event=0xd3,period=100007,umask=0xc\000\00000\000\000"
/* offset=1351822 */ "mem_load_uops_llc_miss_retired.remote_fwd\000\000cache\000Data forwarded from remote cache\000event=0xd3,period=100007,umask=0x20\000\00000\000\000"
/* offset=1351945 */ "mem_load_uops_llc_miss_retired.remote_hitm\000\000cache\000Remote cache HITM\000event=0xd3,period=100007,umask=0x10\000\00000\000\000"
/* offset=1352054 */ "mem_load_uops_misc_retired.llc_miss\000\000cache\000Retired load uops with unknown information as data source in cache serviced the load. (Precise Event - PEBS) (Precise event)\000event=0xd4,period=100007,umask=0x2\000\00000\000This event counts retired demand loads that missed the  last-level (L3) cache. This means that the load is usually satisfied from memory in a client system or possibly from the remote socket in a server. Demand loads are non speculative load uops. (Precise Event - PEBS) (Precise event)\000"
/* offset=1352548 */ "mem_load_uops_misc_retired.local_dram\000cpu_atom\000cache\000Counts the number of load ops retired that miss the L3 cache and hit in DRAM (Precise event). Unit: cpu_atom \000event=0xd4,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1352752 */ "mem_load_uops_retired.dram_hit\000\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x80\000\00000\000\000"
/* offset=1352934 */ "mem_load_uops_retired.dram_hit\000\000cache\000Loads retired that came from DRAM (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x80\000\00000\000Counts memory load uops retired where the data is retrieved from DRAM.  Event is counted at retirement, so the speculative loads are ignored.  A memory load can hit (or miss) the L1 cache, hit (or miss) the L2 cache, hit DRAM, hit in the WCB or receive a HITM response  Supports address when precise (Must be precise)\000"
/* offset=1353437 */ "mem_load_uops_retired.dram_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x80\000\00000\000\000"
/* offset=1353644 */ "mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000This event counts retired load uops which data sources were load uops missed L1 but hit a fill buffer due to a preceding miss to the same cache line with the data not ready.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load  Supports address when precise (Precise event)\000"
/* offset=1354341 */ "mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000"
/* offset=1354625 */ "mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000"
/* offset=1354857 */ "mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000"
/* offset=1355113 */ "mem_load_uops_retired.hitm\000\000cache\000Counts the number of load uops retired that hit in the L3 cache, in which a snoop was required and modified data was forwarded from another core or module  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x20\000\00000\000\000"
/* offset=1355390 */ "mem_load_uops_retired.hitm\000\000cache\000Memory uop retired where cross core or cross module HITM occurred (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x20\000\00000\000Counts load uops retired where the cache line containing the data was in the modified state of another core or modules cache (HITM).  More specifically, this means that when the load address was checked by other caching agents (typically another processor) in the system, one of those caching agents indicated that they had a dirty copy of the data.  Loads that obtain a HITM response incur greater latency than most is typical for a load.  In addition, since HITM indicates that some other processor had this data in its cache, it implies that the data was shared between processors, or potentially was a lock or semaphore value.  This event is useful for locating sharing, false sharing, and contended locks  Supports address when precise (Must be precise)\000"
/* offset=1356362 */ "mem_load_uops_retired.l1_hit\000\000cache\000Counts the number of load uops retired that hit in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x1\000\00000\000\000"
/* offset=1356554 */ "mem_load_uops_retired.l1_hit\000\000cache\000Load uops retired that hit L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x1\000\00000\000Counts load uops retired that hit the L1 data cache  Supports address when precise (Must be precise)\000"
/* offset=1356844 */ "mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000This event counts retired load uops which data sources were hits in the nearest-level (L1) cache.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load. This event also counts SW prefetches independent of the actual data source  Supports address when precise (Precise event)\000"
/* offset=1357455 */ "mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1357660 */ "mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1357806 */ "mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1357976 */ "mem_load_uops_retired.l1_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit the L1 data cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x1\000\00000\000\000"
/* offset=1358158 */ "mem_load_uops_retired.l1_miss\000\000cache\000Counts the number of load uops retired that miss in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000\000"
/* offset=1358352 */ "mem_load_uops_retired.l1_miss\000\000cache\000Load uops retired that missed L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts load uops retired that miss the L1 data cache  Supports address when precise (Must be precise)\000"
/* offset=1358647 */ "mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were misses in the nearest-level (L1) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000"
/* offset=1359015 */ "mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Retired load uops missed L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000"
/* offset=1359330 */ "mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops which data sources following L1 data-cache miss (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000\000"
/* offset=1359489 */ "mem_load_uops_retired.l1_miss\000cpu_atom\000cache\000Counts the number of load ops retired that miss in the L1 data cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x40\000\00000\000\000"
/* offset=1359677 */ "mem_load_uops_retired.l2_hit\000\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000\000"
/* offset=1359864 */ "mem_load_uops_retired.l2_hit\000\000cache\000Load uops retired that hit L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts load uops retired that hit in the L2 cache  Supports address when precise (Must be precise)\000"
/* offset=1360141 */ "mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000This event counts retired load uops which data sources were hits in the mid-level (L2) cache  Supports address when precise.  Spec update: BDM35 (Precise event)\000"
/* offset=1360498 */ "mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000"
/* offset=1360709 */ "mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000"
/* offset=1360854 */ "mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000"
/* offset=1361023 */ "mem_load_uops_retired.l2_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit in the L2 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x2\000\00000\000\000"
/* offset=1361203 */ "mem_load_uops_retired.l2_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x2\000\00000\000\000"
/* offset=1361415 */ "mem_load_uops_retired.l2_miss\000\000cache\000Counts the number of load uops retired that miss in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x10\000\00000\000\000"
/* offset=1361605 */ "mem_load_uops_retired.l2_miss\000\000cache\000Load uops retired that missed L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x10\000\00000\000Counts load uops retired that miss in the L2 cache  Supports address when precise (Must be precise)\000"
/* offset=1361888 */ "mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000This event counts retired load uops which data sources were misses in the mid-level (L2) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000"
/* offset=1362258 */ "mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load uops missed L2. Unknown data source excluded  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000"
/* offset=1362601 */ "mem_load_uops_retired.l2_miss\000\000cache\000Retired load uops with L2 cache misses as data sources (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000\000"
/* offset=1362749 */ "mem_load_uops_retired.l2_miss\000cpu_atom\000cache\000Counts the number of load ops retired that miss in the L2 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x80\000\00000\000\000"
/* offset=1362932 */ "mem_load_uops_retired.l3_hit\000\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x4\000\00000\000\000"
/* offset=1363119 */ "mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops which data sources were data hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000"
/* offset=1363536 */ "mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Retired load uops with L3 cache hits as data sources  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000"
/* offset=1363937 */ "mem_load_uops_retired.l3_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit in the L3 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x1c\000\00000\000\000"
/* offset=1364118 */ "mem_load_uops_retired.l3_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x4\000\00000\000\000"
/* offset=1364330 */ "mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: BDM100, BDE70 (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000"
/* offset=1364544 */ "mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x20\000\00000\000Retired load uops missed L3. Excludes unknown data source   Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000"
/* offset=1364932 */ "mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000\000"
/* offset=1365107 */ "mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level (L3) cache without snoops required. (Precise Event - PEBS) (Precise event)\000"
/* offset=1365443 */ "mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level (L3) cache without snoops required\000"
/* offset=1365699 */ "mem_load_uops_retired.llc_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000"
/* offset=1365854 */ "mem_load_uops_retired.llc_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source\000event=0xd1,period=100007,umask=0x20\000\00000\000\000"
/* offset=1365993 */ "mem_load_uops_retired.wcb_hit\000\000cache\000Loads retired that hit WCB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x40\000\00000\000Counts memory load uops retired where the data is retrieved from the WCB (or fill buffer), indicating that the load found its data while that data was in the process of being brought into the L1 cache.  Typically a load will receive this indication when some other load or prefetch missed the L1 cache and was in the process of retrieving the cache line containing the data, but that process had not yet finished (and written the data back to the cache). For example, consider load X and Y, both referencing the same cache line that is not in the L1 cache.  If load X misses cache first, it obtains and WCB (or fill buffer) and begins the process of requesting the data.  When load Y requests the data, it will either hit the WCB, or the L1 cache, depending on exactly what time the request to Y occurs  Supports address when precise (Must be precise)\000"
/* offset=1367022 */ "mem_load_uops_retired.wcb_hit\000cpu_atom\000cache\000Counts the number of loads that hit in a write combining buffer (WCB), excluding the first load that caused the WCB to allocate (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x20\000\00000\000\000"
/* offset=1367269 */ "mem_scheduler_block.all\000\000cache\000Counts the number of cycles that uops are blocked for any of the following reasons:  load buffer, store buffer or RSV full\000event=0x4,period=20003,umask=0x7\000\00000\000\000"
/* offset=1367461 */ "mem_scheduler_block.all\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked for any of the following reasons:  load buffer, store buffer or RSV full. Unit: cpu_atom \000event=0x4,period=20003,umask=0x7\000\00000\000\000"
/* offset=1367678 */ "mem_scheduler_block.ld_buf\000\000cache\000Counts the number of cycles that uops are blocked due to a load buffer full condition\000event=0x4,period=20003,umask=0x2\000\00000\000\000"
/* offset=1367836 */ "mem_scheduler_block.ld_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a load buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x2\000\00000\000\000"
/* offset=1368019 */ "mem_scheduler_block.rsv\000\000cache\000Counts the number of cycles that uops are blocked due to an RSV full condition\000event=0x4,period=20003,umask=0x4\000\00000\000\000"
/* offset=1368167 */ "mem_scheduler_block.rsv\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to an RSV full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x4\000\00000\000\000"
/* offset=1368340 */ "mem_scheduler_block.st_buf\000\000cache\000Counts the number of cycles that uops are blocked due to a store buffer full condition\000event=0x4,period=20003,umask=0x1\000\00000\000\000"
/* offset=1368499 */ "mem_scheduler_block.st_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a store buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x1\000\00000\000\000"
/* offset=1368683 */ "mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000"
/* offset=1368816 */ "mem_store_retired.l2_hit\000\000cache\000MEM_STORE_RETIRED.L2_HIT\000event=0x44,period=200003,umask=0x1\000\00000\000\000"
/* offset=1368913 */ "mem_store_retired.l2_hit\000cpu_core\000cache\000MEM_STORE_RETIRED.L2_HIT. Unit: cpu_core \000event=0x44,period=200003,umask=0x1\000\00000\000\000"
/* offset=1369035 */ "mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1369507 */ "mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Loads with latency value being above 128 (Must be precise)\000"
/* offset=1369719 */ "mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000"
/* offset=1369873 */ "mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1370248 */ "mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000"
/* offset=1370486 */ "mem_trans_retired.load_latency_gt_128\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1370983 */ "mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1371453 */ "mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Loads with latency value being above 16 (Must be precise)\000"
/* offset=1371663 */ "mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000"
/* offset=1371816 */ "mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1372189 */ "mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000"
/* offset=1372426 */ "mem_trans_retired.load_latency_gt_16\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1372921 */ "mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1373393 */ "mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Loads with latency value being above 256 (Must be precise)\000"
/* offset=1373605 */ "mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000"
/* offset=1373759 */ "mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1374134 */ "mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000"
/* offset=1374372 */ "mem_trans_retired.load_latency_gt_256\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1374869 */ "mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1375340 */ "mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Loads with latency value being above 32 (Must be precise)\000"
/* offset=1375551 */ "mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000\000"
/* offset=1375705 */ "mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1376079 */ "mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x20\000\00000\000\000"
/* offset=1376317 */ "mem_trans_retired.load_latency_gt_32\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1376813 */ "mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1377280 */ "mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4  (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000"
/* offset=1377432 */ "mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Loads with latency value being above 4 (Must be precise)\000"
/* offset=1377639 */ "mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads with latency value being above four  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1378012 */ "mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000"
/* offset=1378247 */ "mem_trans_retired.load_latency_gt_4\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1378739 */ "mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1379211 */ "mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Loads with latency value being above 512 (Must be precise)\000"
/* offset=1379423 */ "mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000"
/* offset=1379577 */ "mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1379952 */ "mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000"
/* offset=1380190 */ "mem_trans_retired.load_latency_gt_512\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1380687 */ "mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1381156 */ "mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Loads with latency value being above 64 (Must be precise)\000"
/* offset=1381365 */ "mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000"
/* offset=1381517 */ "mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1381889 */ "mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000"
/* offset=1382125 */ "mem_trans_retired.load_latency_gt_64\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1382619 */ "mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1383085 */ "mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Loads with latency value being above 8 (Must be precise)\000"
/* offset=1383291 */ "mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000"
/* offset=1383441 */ "mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads with latency value being above eight  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000"
/* offset=1383814 */ "mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000"
/* offset=1384048 */ "mem_trans_retired.load_latency_gt_8\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000"
/* offset=1384539 */ "mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1384715 */ "mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only. (Precise Event - PEBS) (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1384915 */ "mem_trans_retired.store_sample\000\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise)\000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000"
/* offset=1385440 */ "mem_trans_retired.store_sample\000cpu_core\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000"
/* offset=1385990 */ "mem_uncore_retired.local_dram\000\000cache\000Load instructions retired with a data source of local DRAM or locally homed remote hitm (Precise Event)\000event=0xf,period=10000,umask=0x10\000\00000\000\000"
/* offset=1386170 */ "mem_uncore_retired.local_dram\000\000cache\000Load instructions retired with a data source of local DRAM or locally homed remote hitm (Precise Event)\000event=0xf,period=10000,umask=0x20\000\00000\000\000"
/* offset=1386350 */ "mem_uncore_retired.local_dram_and_remote_cache_hit\000\000cache\000Load instructions retired local dram and remote cache HIT data sources (Precise Event)\000event=0xf,period=20000,umask=0x8\000\00000\000\000"
/* offset=1386533 */ "mem_uncore_retired.local_hitm\000\000cache\000Load instructions retired that HIT modified data in sibling core (Precise Event)\000event=0xf,period=40000,umask=0x2\000\00000\000\000"
/* offset=1386689 */ "mem_uncore_retired.other_core_l2_hitm\000\000cache\000Load instructions retired that HIT modified data in sibling core (Precise Event)\000event=0xf,period=40000,umask=0x2\000\00000\000\000"
/* offset=1386853 */ "mem_uncore_retired.remote_cache_local_home_hit\000\000cache\000Load instructions retired remote cache HIT data source (Precise Event)\000event=0xf,period=20000,umask=0x8\000\00000\000\000"
/* offset=1387016 */ "mem_uncore_retired.remote_dram\000\000cache\000Load instructions retired remote DRAM and remote home-remote cache HITM (Precise Event)\000event=0xf,period=10000,umask=0x10\000\00000\000\000"
/* offset=1387181 */ "mem_uncore_retired.remote_dram\000\000cache\000Load instructions retired remote DRAM and remote home-remote cache HITM (Precise Event)\000event=0xf,period=10000,umask=0x20\000\00000\000\000"
/* offset=1387346 */ "mem_uncore_retired.remote_hitm\000\000cache\000Retired loads that hit remote socket in modified state (Precise Event)\000event=0xf,period=40000,umask=0x4\000\00000\000\000"
/* offset=1387493 */ "mem_uncore_retired.uncacheable\000\000cache\000Load instructions retired IO (Precise Event)\000event=0xf,period=4000,umask=0x80\000\00000\000\000"
/* offset=1387614 */ "mem_uop_retired.any\000\000cache\000Retired memory uops for any access\000event=0xe5,period=1000003,umask=0x3\000\00000\000Number of retired micro-operations (uops) for load or store memory accesses\000"
/* offset=1387792 */ "mem_uop_retired.any\000cpu_core\000cache\000Retired memory uops for any access. Unit: cpu_core \000event=0xe5,period=1000003,umask=0x3\000\00000\000Number of retired micro-operations (uops) for load or store memory accesses\000"
/* offset=1387995 */ "mem_uops_retired.all\000\000cache\000Counts the number of memory uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired.  A single uop that performs both a load AND a store will be counted as 1, not 2 (e.g. ADD [mem], CONST)  Supports address when precise (Precise event)\000"
/* offset=1388344 */ "mem_uops_retired.all\000\000cache\000Memory uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired that is either a loads or a store or both  Supports address when precise (Must be precise)\000"
/* offset=1388637 */ "mem_uops_retired.all_loads\000\000cache\000All Loads\000event=0x4,period=200003,umask=0x40\000\00000\000This event counts the number of load ops retired\000"
/* offset=1388769 */ "mem_uops_retired.all_loads\000\000cache\000All retired load uops (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000This event counts the number of load uops retired (Precise event)\000"
/* offset=1388948 */ "mem_uops_retired.all_loads\000\000cache\000All retired load uops. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000This event counts the number of load uops retired (Precise Event) (Precise event)\000"
/* offset=1389167 */ "mem_uops_retired.all_loads\000\000cache\000All retired load uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000\000"
/* offset=1389282 */ "mem_uops_retired.all_loads\000\000cache\000Counts all the load micro-ops retired\000event=0x4,period=200003,umask=0x40\000\00000\000This event counts the number of load micro-ops retired\000"
/* offset=1389448 */ "mem_uops_retired.all_loads\000\000cache\000Counts the number of load ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000\000"
/* offset=1389608 */ "mem_uops_retired.all_loads\000\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000"
/* offset=1389860 */ "mem_uops_retired.all_loads\000\000cache\000Load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the number of load uops retired  Supports address when precise (Must be precise)\000"
/* offset=1390113 */ "mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000"
/* offset=1390417 */ "mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000"
/* offset=1390777 */ "mem_uops_retired.all_loads\000cpu_atom\000cache\000Counts the number of load ops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x81\000\00000\000\000"
/* offset=1390962 */ "mem_uops_retired.all_loads\000cpu_atom\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000"
/* offset=1391239 */ "mem_uops_retired.all_stores\000\000cache\000All Stores\000event=0x4,period=200003,umask=0x80\000\00000\000This event counts the number of store ops retired\000"
/* offset=1391374 */ "mem_uops_retired.all_stores\000\000cache\000All retired store uops (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000This event counts the number of store uops retired (Precise event)\000"
/* offset=1391556 */ "mem_uops_retired.all_stores\000\000cache\000All retired store uops. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000This event counts the number of store uops retired. (Precise Event - PEBS) (Precise event)\000"
/* offset=1391786 */ "mem_uops_retired.all_stores\000\000cache\000All retired store uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000\000"
/* offset=1391903 */ "mem_uops_retired.all_stores\000\000cache\000Counts all the store micro-ops retired\000event=0x4,period=200003,umask=0x80\000\00000\000This event counts the number of store micro-ops retired\000"
/* offset=1392072 */ "mem_uops_retired.all_stores\000\000cache\000Counts the number of store ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000\000"
/* offset=1392234 */ "mem_uops_retired.all_stores\000\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000"
/* offset=1392489 */ "mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise (Precise event)\000"
/* offset=1392708 */ "mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000"
/* offset=1392983 */ "mem_uops_retired.all_stores\000\000cache\000Store uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the number of store uops retired  Supports address when precise (Must be precise)\000"
/* offset=1393239 */ "mem_uops_retired.all_stores\000cpu_atom\000cache\000Counts the number of store ops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x82\000\00000\000\000"
/* offset=1393426 */ "mem_uops_retired.all_stores\000cpu_atom\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000"
/* offset=1393706 */ "mem_uops_retired.dtlb_miss\000\000virtual memory\000Counts the number of memory uops retired that missed in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x13\000\00000\000\000"
/* offset=1393914 */ "mem_uops_retired.dtlb_miss\000\000virtual memory\000Memory uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x13\000\00000\000Counts uops retired that had a DTLB miss on load, store or either.  Note that when two distinct memory operations to the same page miss the DTLB, only one of them will be recorded as a DTLB miss  Supports address when precise (Must be precise)\000"
/* offset=1394355 */ "mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Counts the number of load micro-ops retired that cause a DTLB miss  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x8\000\00000\000\000"
/* offset=1394557 */ "mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Counts the number of load uops retired that miss in the second Level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x11\000\00000\000\000"
/* offset=1394767 */ "mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Load uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x11\000\00000\000Counts load uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000"
/* offset=1395066 */ "mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Loads missed DTLB (Precise event)\000event=0x4,period=200003,umask=0x8\000\00000\000This event counts the number of load ops retired that had DTLB miss (Precise event)\000"
/* offset=1395271 */ "mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Counts the number of store uops retired that miss in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x12\000\00000\000\000"
/* offset=1395483 */ "mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Store uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x12\000\00000\000Counts store uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000"
/* offset=1395785 */ "mem_uops_retired.hitm\000\000cache\000Counts the loads retired that get the data from the other core in the same tile in M state  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x20\000\00000\000\000"
/* offset=1395992 */ "mem_uops_retired.hitm\000\000cache\000Cross core or cross module hitm (Precise event)\000event=0x4,period=200003,umask=0x20\000\00000\000This event counts the number of load ops retired that got data from the other core or from the other module (Precise event)\000"
/* offset=1396232 */ "mem_uops_retired.l1_miss_loads\000\000cache\000Counts the number of load micro-ops retired that miss in L1 D cache\000event=0x4,period=200003,umask=0x1\000\00000\000This event counts the number of load micro-ops retired that miss in L1 Data cache. Note that prefetch misses will not be counted\000"
/* offset=1396505 */ "mem_uops_retired.l1_miss_loads\000\000cache\000Loads missed L1\000event=0x4,period=200003,umask=0x1\000\00000\000This event counts the number of load ops retired that miss in L1 Data cache. Note that prefetch misses will not be counted\000"
/* offset=1396720 */ "mem_uops_retired.l2_hit_loads\000\000cache\000Counts the number of load micro-ops retired that hit in the L2  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x2\000\00000\000\000"
/* offset=1396906 */ "mem_uops_retired.l2_hit_loads\000\000cache\000Loads hit L2 (Precise event)\000event=0x4,period=200003,umask=0x2\000\00000\000This event counts the number of load ops retired that hit in the L2 (Precise event)\000"
/* offset=1397094 */ "mem_uops_retired.l2_miss_loads\000\000cache\000Counts the number of load micro-ops retired that miss in the L2  Supports address when precise (Precise event)\000event=0x4,period=100007,umask=0x4\000\00000\000\000"
/* offset=1397282 */ "mem_uops_retired.l2_miss_loads\000\000cache\000Loads missed L2 (Precise event)\000event=0x4,period=100007,umask=0x4\000\00000\000This event counts the number of load ops retired that miss in the L2 (Precise event)\000"
/* offset=1397475 */ "mem_uops_retired.load_latency_gt_1024\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x400\000\00000\000\000"
/* offset=1397774 */ "mem_uops_retired.load_latency_gt_1024\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x400\000\00000\000\000"
/* offset=1398098 */ "mem_uops_retired.load_latency_gt_128\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000\000"
/* offset=1398395 */ "mem_uops_retired.load_latency_gt_128\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1399079 */ "mem_uops_retired.load_latency_gt_128\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000\000"
/* offset=1399401 */ "mem_uops_retired.load_latency_gt_128\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1400110 */ "mem_uops_retired.load_latency_gt_16\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000\000"
/* offset=1400406 */ "mem_uops_retired.load_latency_gt_16\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1401087 */ "mem_uops_retired.load_latency_gt_16\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000\000"
/* offset=1401408 */ "mem_uops_retired.load_latency_gt_16\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1402114 */ "mem_uops_retired.load_latency_gt_2048\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x800\000\00000\000\000"
/* offset=1402413 */ "mem_uops_retired.load_latency_gt_2048\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x800\000\00000\000\000"
/* offset=1402737 */ "mem_uops_retired.load_latency_gt_256\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000\000"
/* offset=1403035 */ "mem_uops_retired.load_latency_gt_256\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1403720 */ "mem_uops_retired.load_latency_gt_256\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000\000"
/* offset=1404043 */ "mem_uops_retired.load_latency_gt_256\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1404753 */ "mem_uops_retired.load_latency_gt_32\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000\000"
/* offset=1405049 */ "mem_uops_retired.load_latency_gt_32\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1405730 */ "mem_uops_retired.load_latency_gt_32\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000\000"
/* offset=1406051 */ "mem_uops_retired.load_latency_gt_32\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1406757 */ "mem_uops_retired.load_latency_gt_4\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000\000"
/* offset=1407051 */ "mem_uops_retired.load_latency_gt_4\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1407728 */ "mem_uops_retired.load_latency_gt_4\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000\000"
/* offset=1408047 */ "mem_uops_retired.load_latency_gt_4\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1408749 */ "mem_uops_retired.load_latency_gt_512\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000\000"
/* offset=1409047 */ "mem_uops_retired.load_latency_gt_512\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1409732 */ "mem_uops_retired.load_latency_gt_512\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000\000"
/* offset=1410055 */ "mem_uops_retired.load_latency_gt_512\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1410765 */ "mem_uops_retired.load_latency_gt_64\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000\000"
/* offset=1411061 */ "mem_uops_retired.load_latency_gt_64\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1411742 */ "mem_uops_retired.load_latency_gt_64\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000\000"
/* offset=1412063 */ "mem_uops_retired.load_latency_gt_64\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1412769 */ "mem_uops_retired.load_latency_gt_8\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000\000"
/* offset=1413063 */ "mem_uops_retired.load_latency_gt_8\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1413740 */ "mem_uops_retired.load_latency_gt_8\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000\000"
/* offset=1414059 */ "mem_uops_retired.load_latency_gt_8\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1414761 */ "mem_uops_retired.lock_loads\000\000cache\000Counts the number of load uops retired that performed one or more locks  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x21\000\00000\000\000"
/* offset=1414956 */ "mem_uops_retired.lock_loads\000\000cache\000Locked load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x21\000\00000\000Counts locked memory uops retired.  This includes regular locks and bus locks. (To specifically count bus locks only, see the Offcore response event.)  A locked access is one with a lock prefix, or an exchange to memory.  See the SDM for a complete description of which memory load accesses are locks  Supports address when precise (Must be precise)\000"
/* offset=1415479 */ "mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000This event counts load uops with locked access retired to the architected path  Supports address when precise.  Spec update: BDM35 (Precise event)\000"
/* offset=1415806 */ "mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x21\000\00000\000\000"
/* offset=1416001 */ "mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000"
/* offset=1416130 */ "mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000"
/* offset=1416283 */ "mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access. (Precise Event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000"
/* offset=1416413 */ "mem_uops_retired.lock_loads\000cpu_atom\000cache\000Counts the number of load uops retired that performed one or more locks  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x21\000\00000\000\000"
/* offset=1416633 */ "mem_uops_retired.split\000\000cache\000Counts the number of memory uops retired that were splits  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x43\000\00000\000\000"
/* offset=1416809 */ "mem_uops_retired.split\000\000cache\000Memory uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x43\000\00000\000Counts memory uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000"
/* offset=1417133 */ "mem_uops_retired.split\000cpu_atom\000cache\000Counts the number of memory uops retired that were splits  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x43\000\00000\000\000"
/* offset=1417334 */ "mem_uops_retired.split_loads\000\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x41\000\00000\000\000"
/* offset=1417503 */ "mem_uops_retired.split_loads\000\000cache\000Load uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x41\000\00000\000Counts load uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000"
/* offset=1417829 */ "mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000"
/* offset=1418202 */ "mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000"
/* offset=1418411 */ "mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K) (Precise event)\000"
/* offset=1418722 */ "mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K). (Precise Event - PEBS) (Precise event)\000"
/* offset=1419081 */ "mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000"
/* offset=1419232 */ "mem_uops_retired.split_loads\000cpu_atom\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x41\000\00000\000\000"
/* offset=1419426 */ "mem_uops_retired.split_stores\000\000cache\000Counts the number of retired split store uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x42\000\00000\000\000"
/* offset=1419597 */ "mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000"
/* offset=1419973 */ "mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000"
/* offset=1420184 */ "mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K) (Precise event)\000"
/* offset=1420498 */ "mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K). (Precise Event - PEBS) (Precise event)\000"
/* offset=1420860 */ "mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000"
/* offset=1421013 */ "mem_uops_retired.split_stores\000\000cache\000Stores uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x42\000\00000\000Counts store uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000"
/* offset=1421343 */ "mem_uops_retired.split_stores\000cpu_atom\000cache\000Counts the number of retired split store uops  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x42\000\00000\000\000"
/* offset=1421539 */ "mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000This event counts load uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000"
/* offset=1421987 */ "mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000"
/* offset=1422180 */ "mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000"
/* offset=1422314 */ "mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000"
/* offset=1422472 */ "mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000"
/* offset=1422607 */ "mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000This event counts store uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000"
/* offset=1423058 */ "mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000"
/* offset=1423253 */ "mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000"
/* offset=1423389 */ "mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000"
/* offset=1423549 */ "mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000"
/* offset=1423686 */ "mem_uops_retired.store_latency\000\000cache\000Counts the number of  stores uops retired same as MEM_UOPS_RETIRED.ALL_STORES  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x6\000\00000\000\000"
/* offset=1423892 */ "mem_uops_retired.store_latency\000\000cache\000Counts the number of stores uops retired. Counts with or without PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x6\000\00000\000Counts the number of stores uops retired. Counts with or without PEBS enabled. If PEBS is enabled and a PEBS record is generated, will populate PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1424343 */ "mem_uops_retired.store_latency\000cpu_atom\000cache\000Counts the number of  stores uops retired same as MEM_UOPS_RETIRED.ALL_STORES  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x6\000\00000\000\000"
/* offset=1424574 */ "mem_uops_retired.store_latency\000cpu_atom\000cache\000Counts the number of stores uops retired. Counts with or without PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x6\000\00000\000Counts the number of stores uops retired. Counts with or without PEBS enabled. If PEBS is enabled and a PEBS record is generated, will populate PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000"
/* offset=1425050 */ "mem_uops_retired.utlb_miss\000\000cache\000Loads missed UTLB\000event=0x4,period=200003,umask=0x10\000\00000\000This event counts the number of load ops retired that had UTLB miss\000"
/* offset=1425209 */ "mem_uops_retired.utlb_miss_loads\000\000cache\000Counts the number of load micro-ops retired that caused micro TLB miss\000event=0x4,period=200003,umask=0x10\000\00000\000\000"
/* offset=1425360 */ "memory_activity.cycles_l1d_miss\000\000memory\000Cycles while L1 cache miss demand load is outstanding\000event=0x47,cmask=2,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1425503 */ "memory_activity.cycles_l1d_miss\000cpu_core\000memory\000Cycles while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0x47,cmask=2,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1425671 */ "memory_activity.stalls_l1d_miss\000\000memory\000Execution stalls while L1 cache miss demand load is outstanding\000event=0x47,cmask=3,period=1000003,umask=0x3\000\00000\000\000"
/* offset=1425824 */ "memory_activity.stalls_l1d_miss\000cpu_core\000memory\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0x47,cmask=3,period=1000003,umask=0x3\000\00000\000\000"
/* offset=1426002 */ "memory_activity.stalls_l2_miss\000\000memory\000Execution stalls while L2 cache miss demand cacheable load request is outstanding\000event=0x47,cmask=5,period=1000003,umask=0x5\000\00000\000Execution stalls while L2 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000"
/* offset=1426316 */ "memory_activity.stalls_l2_miss\000cpu_core\000memory\000Execution stalls while L2 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=5,period=1000003,umask=0x5\000\00000\000Execution stalls while L2 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000"
/* offset=1426655 */ "memory_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand cacheable load request is outstanding\000event=0x47,cmask=9,period=1000003,umask=0x9\000\00000\000Execution stalls while L3 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000"
/* offset=1426969 */ "memory_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=9,period=1000003,umask=0x9\000\00000\000Execution stalls while L3 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000"
/* offset=1427308 */ "memory_disambiguation.history_reset\000\000other\000MEMORY_DISAMBIGUATION.HISTORY_RESET\000event=0x9,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1427427 */ "misalign_mem_ref.bubble\000\000memory\000Nonzero segbase 1 bubble\000event=0x5,period=200000,umask=0x97\000\00000\000\000"
/* offset=1427524 */ "misalign_mem_ref.ld_bubble\000\000memory\000Nonzero segbase load 1 bubble\000event=0x5,period=200000,umask=0x91\000\00000\000\000"
/* offset=1427629 */ "misalign_mem_ref.ld_split.ar\000\000memory\000Load splits (At Retirement)\000event=0x5,period=200000,umask=0x89\000\00000\000\000"
/* offset=1427734 */ "misalign_mem_ref.ld_split\000\000memory\000Load splits\000event=0x5,period=200000,umask=0x9\000\00000\000\000"
/* offset=1427819 */ "misalign_mem_ref.load_page_split\000\000memory\000Counts the number of misaligned load uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x2\000\00000\000\000"
/* offset=1427982 */ "misalign_mem_ref.load_page_split\000\000memory\000Load uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x2\000\00000\000Counts when a memory load of a uop spans a page boundary (a split) is retired (Must be precise)\000"
/* offset=1428228 */ "misalign_mem_ref.load_page_split\000cpu_atom\000memory\000Counts misaligned loads that are 4K page splits (Precise event). Unit: cpu_atom \000event=0x13,period=200003,umask=0x2\000\00000\000\000"
/* offset=1428398 */ "misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000Speculative cache-line split load uops dispatched to L1D\000"
/* offset=1428587 */ "misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000This event counts speculative cache-line split load uops dispatched to the L1 cache\000"
/* offset=1428803 */ "misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1428936 */ "misalign_mem_ref.rmw_bubble\000\000memory\000Nonzero segbase ld-op-st 1 bubble\000event=0x5,period=200000,umask=0x94\000\00000\000\000"
/* offset=1429046 */ "misalign_mem_ref.rmw_split\000\000memory\000ld-op-st splits\000event=0x5,period=200000,umask=0x8c\000\00000\000\000"
/* offset=1429137 */ "misalign_mem_ref.split.ar\000\000memory\000Memory references that cross an 8-byte boundary (At Retirement)\000event=0x5,period=200000,umask=0x8f\000\00000\000\000"
/* offset=1429275 */ "misalign_mem_ref.split\000\000memory\000Memory references that cross an 8-byte boundary\000event=0x5,period=200000,umask=0xf\000\00000\000\000"
/* offset=1429393 */ "misalign_mem_ref.st_bubble\000\000memory\000Nonzero segbase store 1 bubble\000event=0x5,period=200000,umask=0x92\000\00000\000\000"
/* offset=1429499 */ "misalign_mem_ref.st_split.ar\000\000memory\000Store splits (Ar Retirement)\000event=0x5,period=200000,umask=0x8a\000\00000\000\000"
/* offset=1429605 */ "misalign_mem_ref.st_split\000\000memory\000Store splits\000event=0x5,period=200000,umask=0xa\000\00000\000\000"
/* offset=1429691 */ "misalign_mem_ref.store\000\000memory\000Misaligned store references\000event=0x5,period=200000,umask=0x2\000\00000\000\000"
/* offset=1429789 */ "misalign_mem_ref.store_page_split\000\000memory\000Counts the number of misaligned store uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x4\000\00000\000\000"
/* offset=1429954 */ "misalign_mem_ref.store_page_split\000\000memory\000Store uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x4\000\00000\000Counts when a memory store of a uop spans a page boundary (a split) is retired (Must be precise)\000"
/* offset=1430203 */ "misalign_mem_ref.store_page_split\000cpu_atom\000memory\000Counts misaligned stores that are 4K page splits (Precise event). Unit: cpu_atom \000event=0x13,period=200003,umask=0x4\000\00000\000\000"
/* offset=1430375 */ "misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split Store-address uops dispatched to L1D\000"
/* offset=1430573 */ "misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split store-address uops dispatched to L1D\000"
/* offset=1430771 */ "misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000This event counts speculative cache line split store-address (STA) uops dispatched to the L1 cache\000"
/* offset=1431002 */ "misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000\000"
/* offset=1431135 */ "misc2_retired.lfence\000\000pipeline\000LFENCE instructions retired\000event=0xe0,period=400009,umask=0x20\000\00000\000number of LFENCE retired instructions\000"
/* offset=1431272 */ "misc2_retired.lfence\000cpu_core\000pipeline\000LFENCE instructions retired. Unit: cpu_core \000event=0xe0,period=400009,umask=0x20\000\00000\000number of LFENCE retired instructions\000"
/* offset=1431434 */ "misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000"
/* offset=1431801 */ "misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR to be enabled properly\000"
/* offset=1432117 */ "misc_retired.lbr_inserts\000cpu_core\000pipeline\000Increments whenever there is an update to the LBR array. Unit: cpu_core \000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000"
/* offset=1432509 */ "misc_retired.pause_inst\000\000pipeline\000Number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000event=0xcc,period=100003,umask=0x40\000\00000\000Counts number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000"
/* offset=1432782 */ "move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000Number of integer move elimination candidate uops that were eliminated\000"
/* offset=1433006 */ "move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000"
/* offset=1433160 */ "move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000Number of integer move elimination candidate uops that were not eliminated\000"
/* offset=1433396 */ "move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1433558 */ "move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000Number of SIMD move elimination candidate uops that were eliminated\000"
/* offset=1433783 */ "move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000"
/* offset=1433941 */ "move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000Number of SIMD move elimination candidate uops that were not eliminated\000"
/* offset=1434178 */ "move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1434344 */ "ms_decoded.ms_entry\000\000frontend\000Counts the number of times entered into a ucode flow in the FEC.  Includes inserted flows due to front-end detected faults or assists.  Speculative count\000event=0xe7,period=200003,umask=0x1\000\00000\000Counts the number of times the MSROM starts a flow of UOPS. It does not count every time a UOP is read from the microcode ROM.  The most common case that this counts is when a micro-coded instruction is encountered by the front end of the machine.  Other cases include when an instruction encounters a fault, trap, or microcode assist of any sort.  The event will count MSROM startups for UOPS that are speculative, and subsequently cleared by branch mispredict or machine clear.  Background: UOPS are produced by two mechanisms.  Either they are generated by hardware that decodes instructions into UOPS, or they are delivered by a ROM (called the MSROM) that holds UOPS associated with a specific instruction.  MSROM UOPS might also be delivered in response to some condition such as a fault or other exceptional condition.  This event is an excellent mechanism for detecting instructions that require the use of MSROM instructions\000"
/* offset=1435501 */ "ms_decoded.ms_entry\000\000frontend\000Counts the number of times the MSROM starts a flow of uops\000event=0xe7,period=200003,umask=0x1\000\00000\000\000"
/* offset=1435630 */ "ms_decoded.ms_entry\000\000frontend\000MS decode starts\000event=0xe7,period=200003,umask=0x1\000\00000\000Counts the number of times the Microcode Sequencer (MS) starts a flow of uops from the MSROM. It does not count every time a uop is read from the MSROM.  The most common case that this counts is when a micro-coded instruction is encountered by the front end of the machine.  Other cases include when an instruction encounters a fault, trap, or microcode assist of any sort that initiates a flow of uops.  The event will count MS startups for uops that are speculative, and subsequently cleared by branch mispredict or a machine clear\000"
/* offset=1436250 */ "mul.ar\000\000pipeline\000Multiply operations retired\000event=0x12,period=2000000,umask=0x81\000\00000\000\000"
/* offset=1436337 */ "mul.s\000\000pipeline\000Multiply operations executed\000event=0x12,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1436423 */ "no_alloc_cycles.all\000\000pipeline\000Counts the number of cycles when no uops are allocated for any reason\000event=0xca,period=200003,umask=0x3f\000\00000\000The NO_ALLOC_CYCLES.ALL event counts the number of cycles when the front-end does not provide any instructions to be allocated for any reason. This event indicates the cycles where an allocation stalls occurs, and no UOPS are allocated in that cycle\000"
/* offset=1436813 */ "no_alloc_cycles.all\000\000pipeline\000Counts the total number of core cycles when no micro-ops are allocated for any reason\000event=0xca,period=200003,umask=0x7f\000\00000\000\000"
/* offset=1436970 */ "no_alloc_cycles.mispredicts\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and the alloc pipe is stalled waiting for a mispredicted branch to retire\000event=0xca,period=200003,umask=0x4\000\00000\000This event counts the number of core cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted branch to retire\000"
/* offset=1437331 */ "no_alloc_cycles.mispredicts\000\000pipeline\000Counts the number of cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted jump to retire.  After the misprediction is detected, the front end will start immediately but the allocate pipe stalls until the mispredicted\000event=0xca,period=200003,umask=0x4\000\00000\000Counts the number of cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted jump to retire.  After the misprediction is detected, the front end will start immediately but the allocate pipe stalls until the mispredicted\000"
/* offset=1437918 */ "no_alloc_cycles.not_delivered\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated, the IQ is empty, and no other condition is blocking allocation\000event=0xca,period=200003,umask=0x90\000\00000\000This event counts the number of core cycles when no uops are allocated, the instruction queue is empty and the alloc pipe is stalled waiting for instructions to be fetched\000"
/* offset=1438299 */ "no_alloc_cycles.not_delivered\000\000pipeline\000Counts the number of cycles when no uops are allocated, the IQ is empty, and no other condition is blocking allocation\000event=0xca,period=200003,umask=0x50\000\00000\000The NO_ALLOC_CYCLES.NOT_DELIVERED event is used to measure front-end inefficiencies, i.e. when front-end of the machine is not delivering micro-ops to the back-end and the back-end is not stalled. This event can be used to identify if the machine is truly front-end bound.  When this event occurs, it is an indication that the front-end of the machine is operating at less than its theoretical peak performance.  Background: We can think of the processor pipeline as being divided into 2 broader parts: Front-end and Back-end. Front-end is responsible for fetching the instruction, decoding into micro-ops (uops) in machine understandable format and putting them into a micro-op queue to be consumed by back end. The back-end then takes these micro-ops, allocates the required resources.  When all resources are ready, micro-ops are executed. If the back-end is not ready to accept micro-ops from the front-end, then we do not want to count these as front-end bottlenecks.  However, whenever we have bottlenecks in the back-end, we will have allocation unit stalls and eventually forcing the front-end to wait until the back-end is ready to receive more UOPS. This event counts the cycles only when back-end is requesting more uops and front-end is not able to provide them. Some examples of conditions that cause front-end efficiencies are: Icache misses, ITLB misses, and decoder restrictions that limit the front-end bandwidth\000"
/* offset=1439928 */ "no_alloc_cycles.rat_stall\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and a RATstall (caused by reservation station full) is asserted\000event=0xca,period=200003,umask=0x20\000\00000\000\000"
/* offset=1440134 */ "no_alloc_cycles.rat_stall\000\000pipeline\000Counts the number of cycles when no uops are allocated and a RATstall is asserted\000event=0xca,period=200003,umask=0x20\000\00000\000\000"
/* offset=1440293 */ "no_alloc_cycles.rob_full\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and the ROB is full\000event=0xca,period=200003,umask=0x1\000\00000\000\000"
/* offset=1440453 */ "no_alloc_cycles.rob_full\000\000pipeline\000Counts the number of cycles when no uops are allocated and the ROB is full (less than 2 entries available)\000event=0xca,period=200003,umask=0x1\000\00000\000Counts the number of cycles when no uops are allocated and the ROB is full (less than 2 entries available)\000"
/* offset=1440741 */ "ocr.all_code_rd.any_response\000\000other\000Counts all code reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10044\000\00000\000\000"
/* offset=1440890 */ "ocr.all_code_rd.dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000"
/* offset=1441031 */ "ocr.all_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0044\000\00000\000\000"
/* offset=1441264 */ "ocr.all_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0044\000\00000\000\000"
/* offset=1441509 */ "ocr.all_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0044\000\00000\000\000"
/* offset=1441743 */ "ocr.all_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0044\000\00000\000\000"
/* offset=1441949 */ "ocr.all_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all code reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0044\000\00000\000\000"
/* offset=1442166 */ "ocr.all_code_rd.l3_hit\000\000cache\000Counts all code reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0044\000\00000\000\000"
/* offset=1442318 */ "ocr.all_code_rd.l3_miss\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000"
/* offset=1442476 */ "ocr.all_code_rd.l3_miss_local\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000"
/* offset=1442640 */ "ocr.all_code_rd.local_dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000"
/* offset=1442787 */ "ocr.all_code_rd.outstanding\000\000other\000Counts all code reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000044\000\00000\000\000"
/* offset=1443033 */ "ocr.all_data_rd.any_response\000\000other\000OCR.ALL_DATA_RD.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00000\000\000"
/* offset=1443181 */ "ocr.all_data_rd.l3_hit.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00000\000\000"
/* offset=1443385 */ "ocr.all_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00000\000\000"
/* offset=1443624 */ "ocr.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00000\000\000"
/* offset=1443875 */ "ocr.all_data_rd.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00000\000\000"
/* offset=1444103 */ "ocr.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00000\000\000"
/* offset=1444330 */ "ocr.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0491\000\00000\000\000"
/* offset=1444485 */ "ocr.all_data_rd.l3_hit.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0491\000\00000\000\000"
/* offset=1444658 */ "ocr.all_data_rd.l3_hit.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0491\000\00000\000\000"
/* offset=1444830 */ "ocr.all_data_rd.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080491\000\00000\000\000"
/* offset=1445008 */ "ocr.all_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080491\000\00000\000\000"
/* offset=1445212 */ "ocr.all_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080491\000\00000\000\000"
/* offset=1445425 */ "ocr.all_data_rd.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080491\000\00000\000\000"
/* offset=1445621 */ "ocr.all_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080491\000\00000\000\000"
/* offset=1445816 */ "ocr.all_data_rd.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080491\000\00000\000\000"
/* offset=1445959 */ "ocr.all_data_rd.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080491\000\00000\000\000"
/* offset=1446101 */ "ocr.all_data_rd.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200491\000\00000\000\000"
/* offset=1446279 */ "ocr.all_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200491\000\00000\000\000"
/* offset=1446483 */ "ocr.all_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200491\000\00000\000\000"
/* offset=1446696 */ "ocr.all_data_rd.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200491\000\00000\000\000"
/* offset=1446892 */ "ocr.all_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200491\000\00000\000\000"
/* offset=1447087 */ "ocr.all_data_rd.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200491\000\00000\000\000"
/* offset=1447230 */ "ocr.all_data_rd.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200491\000\00000\000\000"
/* offset=1447372 */ "ocr.all_data_rd.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040491\000\00000\000\000"
/* offset=1447550 */ "ocr.all_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040491\000\00000\000\000"
/* offset=1447754 */ "ocr.all_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040491\000\00000\000\000"
/* offset=1447967 */ "ocr.all_data_rd.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040491\000\00000\000\000"
/* offset=1448163 */ "ocr.all_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040491\000\00000\000\000"
/* offset=1448358 */ "ocr.all_data_rd.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040491\000\00000\000\000"
/* offset=1448501 */ "ocr.all_data_rd.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040491\000\00000\000\000"
/* offset=1448643 */ "ocr.all_data_rd.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100491\000\00000\000\000"
/* offset=1448821 */ "ocr.all_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100491\000\00000\000\000"
/* offset=1449025 */ "ocr.all_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100491\000\00000\000\000"
/* offset=1449238 */ "ocr.all_data_rd.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100491\000\00000\000\000"
/* offset=1449434 */ "ocr.all_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100491\000\00000\000\000"
/* offset=1449629 */ "ocr.all_data_rd.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100491\000\00000\000\000"
/* offset=1449772 */ "ocr.all_data_rd.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100491\000\00000\000\000"
/* offset=1449914 */ "ocr.all_data_rd.l3_miss.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00000\000\000"
/* offset=1450123 */ "ocr.all_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000491\000\00000\000\000"
/* offset=1450367 */ "ocr.all_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000491\000\00000\000\000"
/* offset=1450623 */ "ocr.all_data_rd.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000491\000\00000\000\000"
/* offset=1450856 */ "ocr.all_data_rd.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000491\000\00000\000\000"
/* offset=1451088 */ "ocr.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00000\000\000"
/* offset=1451289 */ "ocr.all_data_rd.l3_miss.remote_hitm\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00000\000\000"
/* offset=1451470 */ "ocr.all_data_rd.l3_miss.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000491\000\00000\000\000"
/* offset=1451647 */ "ocr.all_data_rd.l3_miss.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000491\000\00000\000\000"
/* offset=1451823 */ "ocr.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000491\000\00000\000\000"
/* offset=1452032 */ "ocr.all_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000491\000\00000\000\000"
/* offset=1452267 */ "ocr.all_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000491\000\00000\000\000"
/* offset=1452511 */ "ocr.all_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000491\000\00000\000\000"
/* offset=1452738 */ "ocr.all_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000491\000\00000\000\000"
/* offset=1452964 */ "ocr.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000491\000\00000\000\000"
/* offset=1453128 */ "ocr.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00000\000\000"
/* offset=1453368 */ "ocr.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000491\000\00000\000\000"
/* offset=1453531 */ "ocr.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00000\000\000"
/* offset=1453774 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000491\000\00000\000\000"
/* offset=1454001 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000491\000\00000\000\000"
/* offset=1454254 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000491\000\00000\000\000"
/* offset=1454516 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000491\000\00000\000\000"
/* offset=1454761 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000491\000\00000\000\000"
/* offset=1455005 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000491\000\00000\000\000"
/* offset=1455181 */ "ocr.all_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000491\000\00000\000\000"
/* offset=1455356 */ "ocr.all_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400491\000\00000\000\000"
/* offset=1455560 */ "ocr.all_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400491\000\00000\000\000"
/* offset=1455765 */ "ocr.all_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400491\000\00000\000\000"
/* offset=1455989 */ "ocr.all_data_rd.supplier_none.any_snoop\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020491\000\00000\000\000"
/* offset=1456182 */ "ocr.all_data_rd.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020491\000\00000\000\000"
/* offset=1456401 */ "ocr.all_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020491\000\00000\000\000"
/* offset=1456629 */ "ocr.all_data_rd.supplier_none.hitm_other_core\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020491\000\00000\000\000"
/* offset=1456840 */ "ocr.all_data_rd.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020491\000\00000\000\000"
/* offset=1457050 */ "ocr.all_data_rd.supplier_none.snoop_miss\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020491\000\00000\000\000"
/* offset=1457203 */ "ocr.all_data_rd.supplier_none.snoop_none\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020491\000\00000\000\000"
/* offset=1457355 */ "ocr.all_pf_data_rd.any_response\000\000other\000OCR.ALL_PF_DATA_RD.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00000\000\000"
/* offset=1457509 */ "ocr.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00000\000\000"
/* offset=1457725 */ "ocr.all_pf_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00000\000\000"
/* offset=1457976 */ "ocr.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00000\000\000"
/* offset=1458239 */ "ocr.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00000\000\000"
/* offset=1458479 */ "ocr.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00000\000\000"
/* offset=1458718 */ "ocr.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0490\000\00000\000\000"
/* offset=1458879 */ "ocr.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0490\000\00000\000\000"
/* offset=1459061 */ "ocr.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0490\000\00000\000\000"
/* offset=1459242 */ "ocr.all_pf_data_rd.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080490\000\00000\000\000"
/* offset=1459429 */ "ocr.all_pf_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080490\000\00000\000\000"
/* offset=1459642 */ "ocr.all_pf_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080490\000\00000\000\000"
/* offset=1459864 */ "ocr.all_pf_data_rd.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080490\000\00000\000\000"
/* offset=1460069 */ "ocr.all_pf_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080490\000\00000\000\000"
/* offset=1460273 */ "ocr.all_pf_data_rd.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080490\000\00000\000\000"
/* offset=1460422 */ "ocr.all_pf_data_rd.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080490\000\00000\000\000"
/* offset=1460570 */ "ocr.all_pf_data_rd.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200490\000\00000\000\000"
/* offset=1460757 */ "ocr.all_pf_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200490\000\00000\000\000"
/* offset=1460970 */ "ocr.all_pf_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200490\000\00000\000\000"
/* offset=1461192 */ "ocr.all_pf_data_rd.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200490\000\00000\000\000"
/* offset=1461397 */ "ocr.all_pf_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200490\000\00000\000\000"
/* offset=1461601 */ "ocr.all_pf_data_rd.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200490\000\00000\000\000"
/* offset=1461750 */ "ocr.all_pf_data_rd.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200490\000\00000\000\000"
/* offset=1461898 */ "ocr.all_pf_data_rd.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040490\000\00000\000\000"
/* offset=1462085 */ "ocr.all_pf_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040490\000\00000\000\000"
/* offset=1462298 */ "ocr.all_pf_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040490\000\00000\000\000"
/* offset=1462520 */ "ocr.all_pf_data_rd.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040490\000\00000\000\000"
/* offset=1462725 */ "ocr.all_pf_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040490\000\00000\000\000"
/* offset=1462929 */ "ocr.all_pf_data_rd.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040490\000\00000\000\000"
/* offset=1463078 */ "ocr.all_pf_data_rd.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040490\000\00000\000\000"
/* offset=1463226 */ "ocr.all_pf_data_rd.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100490\000\00000\000\000"
/* offset=1463413 */ "ocr.all_pf_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100490\000\00000\000\000"
/* offset=1463626 */ "ocr.all_pf_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100490\000\00000\000\000"
/* offset=1463848 */ "ocr.all_pf_data_rd.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100490\000\00000\000\000"
/* offset=1464053 */ "ocr.all_pf_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100490\000\00000\000\000"
/* offset=1464257 */ "ocr.all_pf_data_rd.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100490\000\00000\000\000"
/* offset=1464406 */ "ocr.all_pf_data_rd.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100490\000\00000\000\000"
/* offset=1464554 */ "ocr.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00000\000\000"
/* offset=1464775 */ "ocr.all_pf_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000490\000\00000\000\000"
/* offset=1465031 */ "ocr.all_pf_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000490\000\00000\000\000"
/* offset=1465299 */ "ocr.all_pf_data_rd.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000490\000\00000\000\000"
/* offset=1465544 */ "ocr.all_pf_data_rd.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000490\000\00000\000\000"
/* offset=1465788 */ "ocr.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00000\000\000"
/* offset=1465998 */ "ocr.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00000\000\000"
/* offset=1466188 */ "ocr.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000490\000\00000\000\000"
/* offset=1466374 */ "ocr.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000490\000\00000\000\000"
/* offset=1466559 */ "ocr.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000490\000\00000\000\000"
/* offset=1466777 */ "ocr.all_pf_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000490\000\00000\000\000"
/* offset=1467021 */ "ocr.all_pf_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000490\000\00000\000\000"
/* offset=1467274 */ "ocr.all_pf_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000490\000\00000\000\000"
/* offset=1467510 */ "ocr.all_pf_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000490\000\00000\000\000"
/* offset=1467745 */ "ocr.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000490\000\00000\000\000"
/* offset=1467915 */ "ocr.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00000\000\000"
/* offset=1468164 */ "ocr.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000490\000\00000\000\000"
/* offset=1468333 */ "ocr.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00000\000\000"
/* offset=1468585 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000490\000\00000\000\000"
/* offset=1468821 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000490\000\00000\000\000"
/* offset=1469083 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000490\000\00000\000\000"
/* offset=1469354 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000490\000\00000\000\000"
/* offset=1469608 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000490\000\00000\000\000"
/* offset=1469861 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000490\000\00000\000\000"
/* offset=1470043 */ "ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000490\000\00000\000\000"
/* offset=1470224 */ "ocr.all_pf_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400490\000\00000\000\000"
/* offset=1470437 */ "ocr.all_pf_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400490\000\00000\000\000"
/* offset=1470651 */ "ocr.all_pf_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400490\000\00000\000\000"
/* offset=1470884 */ "ocr.all_pf_data_rd.supplier_none.any_snoop\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020490\000\00000\000\000"
/* offset=1471086 */ "ocr.all_pf_data_rd.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020490\000\00000\000\000"
/* offset=1471314 */ "ocr.all_pf_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020490\000\00000\000\000"
/* offset=1471551 */ "ocr.all_pf_data_rd.supplier_none.hitm_other_core\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020490\000\00000\000\000"
/* offset=1471771 */ "ocr.all_pf_data_rd.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020490\000\00000\000\000"
/* offset=1471990 */ "ocr.all_pf_data_rd.supplier_none.snoop_miss\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020490\000\00000\000\000"
/* offset=1472149 */ "ocr.all_pf_data_rd.supplier_none.snoop_none\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020490\000\00000\000\000"
/* offset=1472307 */ "ocr.all_pf_rfo.any_response\000\000other\000OCR.ALL_PF_RFO.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000"
/* offset=1472453 */ "ocr.all_pf_rfo.l3_hit.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000"
/* offset=1472653 */ "ocr.all_pf_rfo.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00000\000\000"
/* offset=1472888 */ "ocr.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000"
/* offset=1473135 */ "ocr.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000"
/* offset=1473359 */ "ocr.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000"
/* offset=1473582 */ "ocr.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0120\000\00000\000\000"
/* offset=1473735 */ "ocr.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00000\000\000"
/* offset=1473905 */ "ocr.all_pf_rfo.l3_hit.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00000\000\000"
/* offset=1474074 */ "ocr.all_pf_rfo.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080120\000\00000\000\000"
/* offset=1474249 */ "ocr.all_pf_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080120\000\00000\000\000"
/* offset=1474450 */ "ocr.all_pf_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080120\000\00000\000\000"
/* offset=1474660 */ "ocr.all_pf_rfo.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080120\000\00000\000\000"
/* offset=1474853 */ "ocr.all_pf_rfo.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080120\000\00000\000\000"
/* offset=1475045 */ "ocr.all_pf_rfo.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080120\000\00000\000\000"
/* offset=1475186 */ "ocr.all_pf_rfo.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080120\000\00000\000\000"
/* offset=1475326 */ "ocr.all_pf_rfo.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200120\000\00000\000\000"
/* offset=1475501 */ "ocr.all_pf_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200120\000\00000\000\000"
/* offset=1475702 */ "ocr.all_pf_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200120\000\00000\000\000"
/* offset=1475912 */ "ocr.all_pf_rfo.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200120\000\00000\000\000"
/* offset=1476105 */ "ocr.all_pf_rfo.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200120\000\00000\000\000"
/* offset=1476297 */ "ocr.all_pf_rfo.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200120\000\00000\000\000"
/* offset=1476438 */ "ocr.all_pf_rfo.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200120\000\00000\000\000"
/* offset=1476578 */ "ocr.all_pf_rfo.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040120\000\00000\000\000"
/* offset=1476753 */ "ocr.all_pf_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040120\000\00000\000\000"
/* offset=1476954 */ "ocr.all_pf_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040120\000\00000\000\000"
/* offset=1477164 */ "ocr.all_pf_rfo.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040120\000\00000\000\000"
/* offset=1477357 */ "ocr.all_pf_rfo.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040120\000\00000\000\000"
/* offset=1477549 */ "ocr.all_pf_rfo.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040120\000\00000\000\000"
/* offset=1477690 */ "ocr.all_pf_rfo.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040120\000\00000\000\000"
/* offset=1477830 */ "ocr.all_pf_rfo.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100120\000\00000\000\000"
/* offset=1478005 */ "ocr.all_pf_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100120\000\00000\000\000"
/* offset=1478206 */ "ocr.all_pf_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100120\000\00000\000\000"
/* offset=1478416 */ "ocr.all_pf_rfo.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100120\000\00000\000\000"
/* offset=1478609 */ "ocr.all_pf_rfo.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100120\000\00000\000\000"
/* offset=1478801 */ "ocr.all_pf_rfo.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100120\000\00000\000\000"
/* offset=1478942 */ "ocr.all_pf_rfo.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100120\000\00000\000\000"
/* offset=1479082 */ "ocr.all_pf_rfo.l3_miss.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00000\000\000"
/* offset=1479287 */ "ocr.all_pf_rfo.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000120\000\00000\000\000"
/* offset=1479527 */ "ocr.all_pf_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00000\000\000"
/* offset=1479779 */ "ocr.all_pf_rfo.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000120\000\00000\000\000"
/* offset=1480008 */ "ocr.all_pf_rfo.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00000\000\000"
/* offset=1480236 */ "ocr.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00000\000\000"
/* offset=1480434 */ "ocr.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00000\000\000"
/* offset=1480612 */ "ocr.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00000\000\000"
/* offset=1480786 */ "ocr.all_pf_rfo.l3_miss.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00000\000\000"
/* offset=1480959 */ "ocr.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00000\000\000"
/* offset=1481165 */ "ocr.all_pf_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000120\000\00000\000\000"
/* offset=1481397 */ "ocr.all_pf_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00000\000\000"
/* offset=1481638 */ "ocr.all_pf_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00000\000\000"
/* offset=1481862 */ "ocr.all_pf_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00000\000\000"
/* offset=1482085 */ "ocr.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00000\000\000"
/* offset=1482247 */ "ocr.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00000\000\000"
/* offset=1482484 */ "ocr.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00000\000\000"
/* offset=1482645 */ "ocr.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00000\000\000"
/* offset=1482885 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000120\000\00000\000\000"
/* offset=1483109 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000120\000\00000\000\000"
/* offset=1483359 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000120\000\00000\000\000"
/* offset=1483618 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000120\000\00000\000\000"
/* offset=1483860 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000120\000\00000\000\000"
/* offset=1484101 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000120\000\00000\000\000"
/* offset=1484275 */ "ocr.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000120\000\00000\000\000"
/* offset=1484448 */ "ocr.all_pf_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400120\000\00000\000\000"
/* offset=1484649 */ "ocr.all_pf_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400120\000\00000\000\000"
/* offset=1484851 */ "ocr.all_pf_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400120\000\00000\000\000"
/* offset=1485072 */ "ocr.all_pf_rfo.supplier_none.any_snoop\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00000\000\000"
/* offset=1485262 */ "ocr.all_pf_rfo.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020120\000\00000\000\000"
/* offset=1485478 */ "ocr.all_pf_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00000\000\000"
/* offset=1485703 */ "ocr.all_pf_rfo.supplier_none.hitm_other_core\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00000\000\000"
/* offset=1485911 */ "ocr.all_pf_rfo.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00000\000\000"
/* offset=1486118 */ "ocr.all_pf_rfo.supplier_none.snoop_miss\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00000\000\000"
/* offset=1486269 */ "ocr.all_pf_rfo.supplier_none.snoop_none\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00000\000\000"
/* offset=1486419 */ "ocr.all_reads.any_response\000\000other\000OCR.ALL_READS.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107F7\000\00000\000\000"
/* offset=1486563 */ "ocr.all_reads.l3_hit.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT.ANY_SNOOP OCR.ALL_READS.L3_HIT.ANY_SNOOP OCR.ALL_READS.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C07F7\000\00000\000\000"
/* offset=1486759 */ "ocr.all_reads.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C07F7\000\00000\000\000"
/* offset=1486990 */ "ocr.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000"
/* offset=1487233 */ "ocr.all_reads.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000"
/* offset=1487453 */ "ocr.all_reads.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C07F7\000\00000\000\000"
/* offset=1487672 */ "ocr.all_reads.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C07F7\000\00000\000\000"
/* offset=1487823 */ "ocr.all_reads.l3_hit.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_MISS OCR.ALL_READS.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C07F7\000\00000\000\000"
/* offset=1487990 */ "ocr.all_reads.l3_hit.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_NONE OCR.ALL_READS.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C07F7\000\00000\000\000"
/* offset=1488156 */ "ocr.all_reads.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_E.ANY_SNOOP  OCR.ALL_READS.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800807F7\000\00000\000\000"
/* offset=1488328 */ "ocr.all_reads.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000807F7\000\00000\000\000"
/* offset=1488526 */ "ocr.all_reads.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000807F7\000\00000\000\000"
/* offset=1488733 */ "ocr.all_reads.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000807F7\000\00000\000\000"
/* offset=1488923 */ "ocr.all_reads.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000807F7\000\00000\000\000"
/* offset=1489112 */ "ocr.all_reads.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000807F7\000\00000\000\000"
/* offset=1489251 */ "ocr.all_reads.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800807F7\000\00000\000\000"
/* offset=1489389 */ "ocr.all_reads.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_F.ANY_SNOOP  OCR.ALL_READS.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F802007F7\000\00000\000\000"
/* offset=1489561 */ "ocr.all_reads.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8002007F7\000\00000\000\000"
/* offset=1489759 */ "ocr.all_reads.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4002007F7\000\00000\000\000"
/* offset=1489966 */ "ocr.all_reads.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002007F7\000\00000\000\000"
/* offset=1490156 */ "ocr.all_reads.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002007F7\000\00000\000\000"
/* offset=1490345 */ "ocr.all_reads.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002007F7\000\00000\000\000"
/* offset=1490484 */ "ocr.all_reads.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802007F7\000\00000\000\000"
/* offset=1490622 */ "ocr.all_reads.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_M.ANY_SNOOP  OCR.ALL_READS.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800407F7\000\00000\000\000"
/* offset=1490794 */ "ocr.all_reads.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000407F7\000\00000\000\000"
/* offset=1490992 */ "ocr.all_reads.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000407F7\000\00000\000\000"
/* offset=1491199 */ "ocr.all_reads.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000407F7\000\00000\000\000"
/* offset=1491389 */ "ocr.all_reads.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000407F7\000\00000\000\000"
/* offset=1491578 */ "ocr.all_reads.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000407F7\000\00000\000\000"
/* offset=1491717 */ "ocr.all_reads.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800407F7\000\00000\000\000"
/* offset=1491855 */ "ocr.all_reads.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_S.ANY_SNOOP  OCR.ALL_READS.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F801007F7\000\00000\000\000"
/* offset=1492027 */ "ocr.all_reads.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8001007F7\000\00000\000\000"
/* offset=1492225 */ "ocr.all_reads.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001007F7\000\00000\000\000"
/* offset=1492432 */ "ocr.all_reads.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001007F7\000\00000\000\000"
/* offset=1492622 */ "ocr.all_reads.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001007F7\000\00000\000\000"
/* offset=1492811 */ "ocr.all_reads.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001007F7\000\00000\000\000"
/* offset=1492950 */ "ocr.all_reads.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801007F7\000\00000\000\000"
/* offset=1493088 */ "ocr.all_reads.l3_miss.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS.ANY_SNOOP OCR.ALL_READS.L3_MISS.ANY_SNOOP OCR.ALL_READS.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC0007F7\000\00000\000\000"
/* offset=1493289 */ "ocr.all_reads.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C0007F7\000\00000\000\000"
/* offset=1493525 */ "ocr.all_reads.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C0007F7\000\00000\000\000"
/* offset=1493773 */ "ocr.all_reads.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C0007F7\000\00000\000\000"
/* offset=1493998 */ "ocr.all_reads.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C0007F7\000\00000\000\000"
/* offset=1494222 */ "ocr.all_reads.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00000\000\000"
/* offset=1494417 */ "ocr.all_reads.l3_miss.remote_hitm\000\000memory\000OCR.ALL_READS.L3_MISS.REMOTE_HITM OCR.ALL_READS.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00000\000\000"
/* offset=1494592 */ "ocr.all_reads.l3_miss.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS.SNOOP_MISS OCR.ALL_READS.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C0007F7\000\00000\000\000"
/* offset=1494763 */ "ocr.all_reads.l3_miss.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS.SNOOP_NONE OCR.ALL_READS.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC0007F7\000\00000\000\000"
/* offset=1494933 */ "ocr.all_reads.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F840007F7\000\00000\000\000"
/* offset=1495136 */ "ocr.all_reads.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8040007F7\000\00000\000\000"
/* offset=1495365 */ "ocr.all_reads.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4040007F7\000\00000\000\000"
/* offset=1495603 */ "ocr.all_reads.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040007F7\000\00000\000\000"
/* offset=1495824 */ "ocr.all_reads.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1040007F7\000\00000\000\000"
/* offset=1496044 */ "ocr.all_reads.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2040007F7\000\00000\000\000"
/* offset=1496204 */ "ocr.all_reads.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00000\000\000"
/* offset=1496438 */ "ocr.all_reads.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x840007F7\000\00000\000\000"
/* offset=1496597 */ "ocr.all_reads.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B8007F7\000\00000\000\000"
/* offset=1496834 */ "ocr.all_reads.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F900007F7\000\00000\000\000"
/* offset=1497055 */ "ocr.all_reads.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8100007F7\000\00000\000\000"
/* offset=1497302 */ "ocr.all_reads.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4100007F7\000\00000\000\000"
/* offset=1497558 */ "ocr.all_reads.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100007F7\000\00000\000\000"
/* offset=1497797 */ "ocr.all_reads.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1100007F7\000\00000\000\000"
/* offset=1498035 */ "ocr.all_reads.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2100007F7\000\00000\000\000"
/* offset=1498207 */ "ocr.all_reads.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x900007F7\000\00000\000\000"
/* offset=1498378 */ "ocr.all_reads.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F804007F7\000\00000\000\000"
/* offset=1498576 */ "ocr.all_reads.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804007F7\000\00000\000\000"
/* offset=1498775 */ "ocr.all_reads.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00000\000\000"
/* offset=1498993 */ "ocr.all_reads.supplier_none.any_snoop\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800207F7\000\00000\000\000"
/* offset=1499180 */ "ocr.all_reads.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000207F7\000\00000\000\000"
/* offset=1499393 */ "ocr.all_reads.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000207F7\000\00000\000\000"
/* offset=1499615 */ "ocr.all_reads.supplier_none.hitm_other_core\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000207F7\000\00000\000\000"
/* offset=1499820 */ "ocr.all_reads.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000207F7\000\00000\000\000"
/* offset=1500024 */ "ocr.all_reads.supplier_none.snoop_miss\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000207F7\000\00000\000\000"
/* offset=1500173 */ "ocr.all_reads.supplier_none.snoop_none\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800207F7\000\00000\000\000"
/* offset=1500321 */ "ocr.all_rfo.any_response\000\000other\000OCR.ALL_RFO.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000"
/* offset=1500461 */ "ocr.all_rfo.l3_hit.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT.ANY_SNOOP OCR.ALL_RFO.L3_HIT.ANY_SNOOP OCR.ALL_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000"
/* offset=1500649 */ "ocr.all_rfo.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00000\000\000"
/* offset=1500872 */ "ocr.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000"
/* offset=1501107 */ "ocr.all_rfo.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000"
/* offset=1501319 */ "ocr.all_rfo.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000"
/* offset=1501530 */ "ocr.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0122\000\00000\000\000"
/* offset=1501677 */ "ocr.all_rfo.l3_hit.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_MISS OCR.ALL_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00000\000\000"
/* offset=1501838 */ "ocr.all_rfo.l3_hit.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_NONE OCR.ALL_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00000\000\000"
/* offset=1501998 */ "ocr.all_rfo.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080122\000\00000\000\000"
/* offset=1502164 */ "ocr.all_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080122\000\00000\000\000"
/* offset=1502356 */ "ocr.all_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080122\000\00000\000\000"
/* offset=1502557 */ "ocr.all_rfo.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080122\000\00000\000\000"
/* offset=1502741 */ "ocr.all_rfo.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080122\000\00000\000\000"
/* offset=1502924 */ "ocr.all_rfo.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080122\000\00000\000\000"
/* offset=1503059 */ "ocr.all_rfo.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080122\000\00000\000\000"
/* offset=1503193 */ "ocr.all_rfo.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200122\000\00000\000\000"
/* offset=1503359 */ "ocr.all_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200122\000\00000\000\000"
/* offset=1503551 */ "ocr.all_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200122\000\00000\000\000"
/* offset=1503752 */ "ocr.all_rfo.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200122\000\00000\000\000"
/* offset=1503936 */ "ocr.all_rfo.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200122\000\00000\000\000"
/* offset=1504119 */ "ocr.all_rfo.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200122\000\00000\000\000"
/* offset=1504254 */ "ocr.all_rfo.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200122\000\00000\000\000"
/* offset=1504388 */ "ocr.all_rfo.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040122\000\00000\000\000"
/* offset=1504554 */ "ocr.all_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040122\000\00000\000\000"
/* offset=1504746 */ "ocr.all_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040122\000\00000\000\000"
/* offset=1504947 */ "ocr.all_rfo.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040122\000\00000\000\000"
/* offset=1505131 */ "ocr.all_rfo.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040122\000\00000\000\000"
/* offset=1505314 */ "ocr.all_rfo.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040122\000\00000\000\000"
/* offset=1505449 */ "ocr.all_rfo.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040122\000\00000\000\000"
/* offset=1505583 */ "ocr.all_rfo.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100122\000\00000\000\000"
/* offset=1505749 */ "ocr.all_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100122\000\00000\000\000"
/* offset=1505941 */ "ocr.all_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100122\000\00000\000\000"
/* offset=1506142 */ "ocr.all_rfo.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100122\000\00000\000\000"
/* offset=1506326 */ "ocr.all_rfo.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100122\000\00000\000\000"
/* offset=1506509 */ "ocr.all_rfo.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100122\000\00000\000\000"
/* offset=1506644 */ "ocr.all_rfo.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100122\000\00000\000\000"
/* offset=1506778 */ "ocr.all_rfo.l3_miss.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS.ANY_SNOOP OCR.ALL_RFO.L3_MISS.ANY_SNOOP OCR.ALL_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00000\000\000"
/* offset=1506971 */ "ocr.all_rfo.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000122\000\00000\000\000"
/* offset=1507199 */ "ocr.all_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00000\000\000"
/* offset=1507439 */ "ocr.all_rfo.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000122\000\00000\000\000"
/* offset=1507656 */ "ocr.all_rfo.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00000\000\000"
/* offset=1507872 */ "ocr.all_rfo.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00000\000\000"
/* offset=1508061 */ "ocr.all_rfo.l3_miss.remote_hitm\000\000memory\000OCR.ALL_RFO.L3_MISS.REMOTE_HITM OCR.ALL_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00000\000\000"
/* offset=1508230 */ "ocr.all_rfo.l3_miss.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS.SNOOP_MISS OCR.ALL_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00000\000\000"
/* offset=1508395 */ "ocr.all_rfo.l3_miss.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS.SNOOP_NONE OCR.ALL_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00000\000\000"
/* offset=1508559 */ "ocr.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00000\000\000"
/* offset=1508756 */ "ocr.all_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000122\000\00000\000\000"
/* offset=1508979 */ "ocr.all_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00000\000\000"
/* offset=1509211 */ "ocr.all_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00000\000\000"
/* offset=1509426 */ "ocr.all_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00000\000\000"
/* offset=1509640 */ "ocr.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00000\000\000"
/* offset=1509796 */ "ocr.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000"
/* offset=1510024 */ "ocr.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00000\000\000"
/* offset=1510179 */ "ocr.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00000\000\000"
/* offset=1510410 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000122\000\00000\000\000"
/* offset=1510625 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000122\000\00000\000\000"
/* offset=1510866 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000122\000\00000\000\000"
/* offset=1511116 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000122\000\00000\000\000"
/* offset=1511349 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000122\000\00000\000\000"
/* offset=1511581 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000122\000\00000\000\000"
/* offset=1511749 */ "ocr.all_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000122\000\00000\000\000"
/* offset=1511916 */ "ocr.all_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400122\000\00000\000\000"
/* offset=1512108 */ "ocr.all_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400122\000\00000\000\000"
/* offset=1512301 */ "ocr.all_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00000\000\000"
/* offset=1512513 */ "ocr.all_rfo.supplier_none.any_snoop\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00000\000\000"
/* offset=1512694 */ "ocr.all_rfo.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020122\000\00000\000\000"
/* offset=1512901 */ "ocr.all_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00000\000\000"
/* offset=1513117 */ "ocr.all_rfo.supplier_none.hitm_other_core\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00000\000\000"
/* offset=1513316 */ "ocr.all_rfo.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00000\000\000"
/* offset=1513514 */ "ocr.all_rfo.supplier_none.snoop_miss\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00000\000\000"
/* offset=1513659 */ "ocr.all_rfo.supplier_none.snoop_none\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00000\000\000"
/* offset=1513803 */ "ocr.corewb_m.any_response\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000"
/* offset=1513981 */ "ocr.corewb_m.any_response\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3000000010000\000\00000\000\000"
/* offset=1514167 */ "ocr.corewb_m.any_response\000cpu_atom\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000"
/* offset=1514370 */ "ocr.corewb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache and L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3001F803C0000\000\00000\000\000"
/* offset=1514554 */ "ocr.corewb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000"
/* offset=1514744 */ "ocr.corewb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000"
/* offset=1514940 */ "ocr.corewb_m.outstanding\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003000000000000\000\00000\000\000"
/* offset=1515215 */ "ocr.demand_code_rd.any_response\000\000other\000Counts all demand code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000"
/* offset=1515366 */ "ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000"
/* offset=1515566 */ "ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000"
/* offset=1515766 */ "ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000"
/* offset=1515962 */ "ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000004\000\00000\000\000"
/* offset=1516154 */ "ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000"
/* offset=1516346 */ "ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000004\000\00000\000\000"
/* offset=1516538 */ "ocr.demand_code_rd.l3_hit.any\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0004\000\00000\000\000"
/* offset=1516771 */ "ocr.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000"
/* offset=1516980 */ "ocr.demand_code_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000"
/* offset=1517215 */ "ocr.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=1517459 */ "ocr.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=1517686 */ "ocr.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000"
/* offset=1517912 */ "ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=1518194 */ "ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=1518478 */ "ocr.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0004\000\00000\000\000"
/* offset=1518623 */ "ocr.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000"
/* offset=1518919 */ "ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=1519224 */ "ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=1519498 */ "ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=1519772 */ "ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=1520057 */ "ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000"
/* offset=1520231 */ "ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000"
/* offset=1520495 */ "ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000"
/* offset=1520752 */ "ocr.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00000\000\000"
/* offset=1520925 */ "ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000"
/* offset=1521192 */ "ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000"
/* offset=1521460 */ "ocr.demand_code_rd.l3_hit.snoop_sent\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0004\000\00000\000\000"
/* offset=1521693 */ "ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000"
/* offset=1521942 */ "ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000"
/* offset=1522191 */ "ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0004\000\00000\000\000"
/* offset=1522394 */ "ocr.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080004\000\00000\000\000"
/* offset=1522572 */ "ocr.demand_code_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080004\000\00000\000\000"
/* offset=1522767 */ "ocr.demand_code_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00000\000\000"
/* offset=1522968 */ "ocr.demand_code_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000"
/* offset=1523158 */ "ocr.demand_code_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00000\000\000"
/* offset=1523347 */ "ocr.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00000\000\000"
/* offset=1523486 */ "ocr.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00000\000\000"
/* offset=1523624 */ "ocr.demand_code_rd.l3_hit_f.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200004\000\00000\000\000"
/* offset=1523802 */ "ocr.demand_code_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200004\000\00000\000\000"
/* offset=1523997 */ "ocr.demand_code_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200004\000\00000\000\000"
/* offset=1524198 */ "ocr.demand_code_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200004\000\00000\000\000"
/* offset=1524388 */ "ocr.demand_code_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200004\000\00000\000\000"
/* offset=1524577 */ "ocr.demand_code_rd.l3_hit_f.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200004\000\00000\000\000"
/* offset=1524716 */ "ocr.demand_code_rd.l3_hit_f.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200004\000\00000\000\000"
/* offset=1524854 */ "ocr.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040004\000\00000\000\000"
/* offset=1525032 */ "ocr.demand_code_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040004\000\00000\000\000"
/* offset=1525227 */ "ocr.demand_code_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00000\000\000"
/* offset=1525428 */ "ocr.demand_code_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00000\000\000"
/* offset=1525618 */ "ocr.demand_code_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00000\000\000"
/* offset=1525807 */ "ocr.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00000\000\000"
/* offset=1525946 */ "ocr.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00000\000\000"
/* offset=1526084 */ "ocr.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100004\000\00000\000\000"
/* offset=1526262 */ "ocr.demand_code_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100004\000\00000\000\000"
/* offset=1526457 */ "ocr.demand_code_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00000\000\000"
/* offset=1526658 */ "ocr.demand_code_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00000\000\000"
/* offset=1526848 */ "ocr.demand_code_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00000\000\000"
/* offset=1527037 */ "ocr.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00000\000\000"
/* offset=1527176 */ "ocr.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00000\000\000"
/* offset=1527314 */ "ocr.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00000\000\000"
/* offset=1527527 */ "ocr.demand_code_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000004\000\00000\000\000"
/* offset=1527766 */ "ocr.demand_code_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00000\000\000"
/* offset=1528014 */ "ocr.demand_code_rd.l3_miss.hitm_other_core\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000004\000\00000\000\000"
/* offset=1528245 */ "ocr.demand_code_rd.l3_miss.no_snoop_needed\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00000\000\000"
/* offset=1528475 */ "ocr.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00000\000\000"
/* offset=1528668 */ "ocr.demand_code_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00000\000\000"
/* offset=1528848 */ "ocr.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00000\000\000"
/* offset=1529025 */ "ocr.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00000\000\000"
/* offset=1529201 */ "ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00004\000\00000\000\000"
/* offset=1529409 */ "ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000"
/* offset=1529618 */ "ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000"
/* offset=1529854 */ "ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000"
/* offset=1530090 */ "ocr.demand_code_rd.l3_miss_local\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000"
/* offset=1530305 */ "ocr.demand_code_rd.l3_miss_local\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400004\000\00000\000\000"
/* offset=1530582 */ "ocr.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00000\000\000"
/* offset=1530781 */ "ocr.demand_code_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000004\000\00000\000\000"
/* offset=1530997 */ "ocr.demand_code_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00000\000\000"
/* offset=1531219 */ "ocr.demand_code_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00000\000\000"
/* offset=1531430 */ "ocr.demand_code_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000"
/* offset=1531640 */ "ocr.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00000\000\000"
/* offset=1531790 */ "ocr.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00000\000\000"
/* offset=1532009 */ "ocr.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00000\000\000"
/* offset=1532158 */ "ocr.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00000\000\000"
/* offset=1532379 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000004\000\00000\000\000"
/* offset=1532590 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000004\000\00000\000\000"
/* offset=1532818 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000004\000\00000\000\000"
/* offset=1533052 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000004\000\00000\000\000"
/* offset=1533275 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000004\000\00000\000\000"
/* offset=1533497 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000004\000\00000\000\000"
/* offset=1533653 */ "ocr.demand_code_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000004\000\00000\000\000"
/* offset=1533808 */ "ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000"
/* offset=1534010 */ "ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000"
/* offset=1534361 */ "ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000"
/* offset=1534712 */ "ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000"
/* offset=1534910 */ "ocr.demand_code_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400004\000\00000\000\000"
/* offset=1535105 */ "ocr.demand_code_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00000\000\000"
/* offset=1535300 */ "ocr.demand_code_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000"
/* offset=1535508 */ "ocr.demand_code_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000004\000\00000\000\000"
/* offset=1535865 */ "ocr.demand_code_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000004\000\00000\000\000"
/* offset=1536222 */ "ocr.demand_code_rd.snc_cache.hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000004\000\00000\000\000"
/* offset=1536561 */ "ocr.demand_code_rd.snc_cache.hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000004\000\00000\000\000"
/* offset=1536900 */ "ocr.demand_code_rd.snc_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000004\000\00000\000\000"
/* offset=1537192 */ "ocr.demand_code_rd.snc_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000004\000\00000\000\000"
/* offset=1537484 */ "ocr.demand_code_rd.supplier_none.any_snoop\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00000\000\000"
/* offset=1537672 */ "ocr.demand_code_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020004\000\00000\000\000"
/* offset=1537877 */ "ocr.demand_code_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00000\000\000"
/* offset=1538088 */ "ocr.demand_code_rd.supplier_none.hitm_other_core\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00000\000\000"
/* offset=1538288 */ "ocr.demand_code_rd.supplier_none.no_snoop_needed\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00000\000\000"
/* offset=1538487 */ "ocr.demand_code_rd.supplier_none.snoop_miss\000\000other\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00000\000\000"
/* offset=1538631 */ "ocr.demand_code_rd.supplier_none.snoop_none\000\000other\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00000\000\000"
/* offset=1538774 */ "ocr.demand_data_and_l1pf_rd.any_response\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1539026 */ "ocr.demand_data_and_l1pf_rd.dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000"
/* offset=1539270 */ "ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1539606 */ "ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1539954 */ "ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hitm\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1540291 */ "ocr.demand_data_and_l1pf_rd.l3_hit.snoop_miss\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000"
/* offset=1540600 */ "ocr.demand_data_and_l1pf_rd.l3_hit.snoop_not_needed\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000"
/* offset=1540920 */ "ocr.demand_data_and_l1pf_rd.l3_hit\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00000\000\000"
/* offset=1541175 */ "ocr.demand_data_and_l1pf_rd.l3_miss\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000"
/* offset=1541436 */ "ocr.demand_data_and_l1pf_rd.l3_miss_local\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000"
/* offset=1541703 */ "ocr.demand_data_and_l1pf_rd.local_dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000"
/* offset=1541953 */ "ocr.demand_data_and_l1pf_rd.outstanding\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00000\000\000"
/* offset=1542302 */ "ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1542449 */ "ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1542604 */ "ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1542759 */ "ocr.demand_data_rd.any_response\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00010\000\000"
/* offset=1542944 */ "ocr.demand_data_rd.any_response\000cpu_atom\000other\000Counts demand data reads that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1543124 */ "ocr.demand_data_rd.any_response\000cpu_core\000other\000Counts demand data reads that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=1543304 */ "ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000"
/* offset=1543455 */ "ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000001\000\00000\000\000"
/* offset=1543602 */ "ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000001\000\00000\000\000"
/* offset=1543749 */ "ocr.demand_data_rd.dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000"
/* offset=1543922 */ "ocr.demand_data_rd.dram\000cpu_core\000other\000Counts demand data reads that were supplied by DRAM. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000"
/* offset=1544094 */ "ocr.demand_data_rd.l3_hit.any\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0001\000\00000\000\000"
/* offset=1544282 */ "ocr.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=1544487 */ "ocr.demand_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1544718 */ "ocr.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1544958 */ "ocr.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1545181 */ "ocr.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000"
/* offset=1545403 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1545640 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that resulted in a snoop that hit in another core, which did not forward the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1545861 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that resulted in a snoop that hit in another core, which did not forward the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1546082 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1546321 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00010\000\000"
/* offset=1546532 */ "ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=1546796 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1547050 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1547304 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1547555 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0001\000\00000\000\000"
/* offset=1547696 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1547857 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00010\000\000"
/* offset=1548072 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1548348 */ "ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches which forwarded the unmodified data to the requesting core. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=1548626 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1548886 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1549115 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1549344 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1549584 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00010\000\000"
/* offset=1549784 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1550049 */ "ocr.demand_data_rd.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=1550314 */ "ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000"
/* offset=1550484 */ "ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000"
/* offset=1550703 */ "ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00010\000\000"
/* offset=1550902 */ "ocr.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00000\000\000"
/* offset=1551071 */ "ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000"
/* offset=1551293 */ "ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00010\000\000"
/* offset=1551504 */ "ocr.demand_data_rd.l3_hit.snoop_sent\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0001\000\00000\000\000"
/* offset=1551692 */ "ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=1551896 */ "ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=1552100 */ "ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=1552258 */ "ocr.demand_data_rd.l3_hit\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00010\000\000"
/* offset=1552436 */ "ocr.demand_data_rd.l3_hit\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=1552619 */ "ocr.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080001\000\00000\000\000"
/* offset=1552793 */ "ocr.demand_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080001\000\00000\000\000"
/* offset=1552984 */ "ocr.demand_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00000\000\000"
/* offset=1553181 */ "ocr.demand_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000"
/* offset=1553367 */ "ocr.demand_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00000\000\000"
/* offset=1553552 */ "ocr.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00000\000\000"
/* offset=1553687 */ "ocr.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00000\000\000"
/* offset=1553821 */ "ocr.demand_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200001\000\00000\000\000"
/* offset=1553995 */ "ocr.demand_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200001\000\00000\000\000"
/* offset=1554186 */ "ocr.demand_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200001\000\00000\000\000"
/* offset=1554383 */ "ocr.demand_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200001\000\00000\000\000"
/* offset=1554569 */ "ocr.demand_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200001\000\00000\000\000"
/* offset=1554754 */ "ocr.demand_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200001\000\00000\000\000"
/* offset=1554889 */ "ocr.demand_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200001\000\00000\000\000"
/* offset=1555023 */ "ocr.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040001\000\00000\000\000"
/* offset=1555197 */ "ocr.demand_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040001\000\00000\000\000"
/* offset=1555388 */ "ocr.demand_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00000\000\000"
/* offset=1555585 */ "ocr.demand_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00000\000\000"
/* offset=1555771 */ "ocr.demand_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00000\000\000"
/* offset=1555956 */ "ocr.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00000\000\000"
/* offset=1556091 */ "ocr.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00000\000\000"
/* offset=1556225 */ "ocr.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100001\000\00000\000\000"
/* offset=1556399 */ "ocr.demand_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100001\000\00000\000\000"
/* offset=1556590 */ "ocr.demand_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00000\000\000"
/* offset=1556787 */ "ocr.demand_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00000\000\000"
/* offset=1556973 */ "ocr.demand_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00000\000\000"
/* offset=1557158 */ "ocr.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00000\000\000"
/* offset=1557293 */ "ocr.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00000\000\000"
/* offset=1557427 */ "ocr.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00000\000\000"
/* offset=1557636 */ "ocr.demand_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000001\000\00000\000\000"
/* offset=1557871 */ "ocr.demand_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00000\000\000"
/* offset=1558115 */ "ocr.demand_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000001\000\00000\000\000"
/* offset=1558342 */ "ocr.demand_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00000\000\000"
/* offset=1558568 */ "ocr.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00000\000\000"
/* offset=1558757 */ "ocr.demand_data_rd.l3_miss.remote_hitm\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00000\000\000"
/* offset=1558933 */ "ocr.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00000\000\000"
/* offset=1559106 */ "ocr.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00000\000\000"
/* offset=1559278 */ "ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00001\000\00000\000\000"
/* offset=1559441 */ "ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000"
/* offset=1559605 */ "ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000"
/* offset=1559769 */ "ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000"
/* offset=1559960 */ "ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000"
/* offset=1560151 */ "ocr.demand_data_rd.l3_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000"
/* offset=1560332 */ "ocr.demand_data_rd.l3_miss\000cpu_atom\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000"
/* offset=1560521 */ "ocr.demand_data_rd.l3_miss\000cpu_core\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000"
/* offset=1560710 */ "ocr.demand_data_rd.l3_miss_local\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000"
/* offset=1560880 */ "ocr.demand_data_rd.l3_miss_local\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000"
/* offset=1561112 */ "ocr.demand_data_rd.l3_miss_local\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS_LOCAL\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000"
/* offset=1561305 */ "ocr.demand_data_rd.l3_miss_local\000cpu_atom\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000"
/* offset=1561500 */ "ocr.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00000\000\000"
/* offset=1561695 */ "ocr.demand_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000001\000\00000\000\000"
/* offset=1561907 */ "ocr.demand_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00000\000\000"
/* offset=1562125 */ "ocr.demand_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00000\000\000"
/* offset=1562332 */ "ocr.demand_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000"
/* offset=1562538 */ "ocr.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00000\000\000"
/* offset=1562684 */ "ocr.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00000\000\000"
/* offset=1562899 */ "ocr.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00000\000\000"
/* offset=1563044 */ "ocr.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00000\000\000"
/* offset=1563261 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000001\000\00000\000\000"
/* offset=1563468 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000001\000\00000\000\000"
/* offset=1563692 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000001\000\00000\000\000"
/* offset=1563922 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000001\000\00000\000\000"
/* offset=1564141 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000001\000\00000\000\000"
/* offset=1564359 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000001\000\00000\000\000"
/* offset=1564511 */ "ocr.demand_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000001\000\00000\000\000"
/* offset=1564662 */ "ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000"
/* offset=1564819 */ "ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000"
/* offset=1565125 */ "ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000"
/* offset=1565431 */ "ocr.demand_data_rd.local_dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.LOCAL_DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000"
/* offset=1565616 */ "ocr.demand_data_rd.local_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000"
/* offset=1565919 */ "ocr.demand_data_rd.outstanding\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.OUTSTANDING\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00010\000\000"
/* offset=1566113 */ "ocr.demand_data_rd.pmm\000\000other\000Counts demand data reads that were supplied by PMM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703C00001\000\00000\000\000"
/* offset=1566258 */ "ocr.demand_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400001\000\00000\000\000"
/* offset=1566449 */ "ocr.demand_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00000\000\000"
/* offset=1566640 */ "ocr.demand_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000"
/* offset=1566844 */ "ocr.demand_data_rd.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x830000001\000\00000\000\000"
/* offset=1567142 */ "ocr.demand_data_rd.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x830000001\000\00000\000\000"
/* offset=1567440 */ "ocr.demand_data_rd.remote_cache.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1030000001\000\00000\000\000"
/* offset=1567713 */ "ocr.demand_data_rd.remote_cache.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1030000001\000\00000\000\000"
/* offset=1567986 */ "ocr.demand_data_rd.remote_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x730000001\000\00000\000\000"
/* offset=1568167 */ "ocr.demand_data_rd.remote_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x730000001\000\00000\000\000"
/* offset=1568348 */ "ocr.demand_data_rd.remote_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x703000001\000\00000\000\000"
/* offset=1568527 */ "ocr.demand_data_rd.remote_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000001\000\00000\000\000"
/* offset=1568706 */ "ocr.demand_data_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand data reads that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000001\000\00000\000\000"
/* offset=1569018 */ "ocr.demand_data_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand data reads that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000001\000\00000\000\000"
/* offset=1569330 */ "ocr.demand_data_rd.snc_cache.hitm\000\000cache\000Counts demand data reads that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000001\000\00000\000\000"
/* offset=1569624 */ "ocr.demand_data_rd.snc_cache.hitm\000\000cache\000Counts demand data reads that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000001\000\00000\000\000"
/* offset=1569918 */ "ocr.demand_data_rd.snc_dram\000\000other\000Counts demand data reads that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000001\000\00000\000\000"
/* offset=1570165 */ "ocr.demand_data_rd.snc_dram\000\000other\000Counts demand data reads that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000001\000\00000\000\000"
/* offset=1570412 */ "ocr.demand_data_rd.snc_pmm\000\000other\000Counts demand data reads that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800001\000\00000\000\000"
/* offset=1570657 */ "ocr.demand_data_rd.supplier_none.any_snoop\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00000\000\000"
/* offset=1570841 */ "ocr.demand_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020001\000\00000\000\000"
/* offset=1571042 */ "ocr.demand_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00000\000\000"
/* offset=1571249 */ "ocr.demand_data_rd.supplier_none.hitm_other_core\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00000\000\000"
/* offset=1571445 */ "ocr.demand_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00000\000\000"
/* offset=1571640 */ "ocr.demand_data_rd.supplier_none.snoop_miss\000\000other\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00000\000\000"
/* offset=1571780 */ "ocr.demand_data_rd.supplier_none.snoop_none\000\000other\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00000\000\000"
/* offset=1571919 */ "ocr.demand_rfo.any_response\000\000other\000Counts all demand data writes (RFOs) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=1572074 */ "ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=1572300 */ "ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0002\000\00000\000\000"
/* offset=1572540 */ "ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=1572775 */ "ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0002\000\00000\000\000"
/* offset=1573015 */ "ocr.demand_rfo.any_response\000cpu_atom\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=1573266 */ "ocr.demand_rfo.any_response\000cpu_core\000other\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=1573525 */ "ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000"
/* offset=1573743 */ "ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000"
/* offset=1573974 */ "ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000002\000\00000\000\000"
/* offset=1574201 */ "ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000002\000\00000\000\000"
/* offset=1574428 */ "ocr.demand_rfo.l3_hit.any\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0002\000\00000\000\000"
/* offset=1574696 */ "ocr.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=1574901 */ "ocr.demand_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000"
/* offset=1575132 */ "ocr.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=1575372 */ "ocr.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1575595 */ "ocr.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000"
/* offset=1575817 */ "ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=1576127 */ "ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=1576444 */ "ocr.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0002\000\00000\000\000"
/* offset=1576593 */ "ocr.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000"
/* offset=1576915 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1577226 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1577566 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1577875 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1578184 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000cpu_atom\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1578520 */ "ocr.demand_rfo.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=1578864 */ "ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000"
/* offset=1579038 */ "ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000"
/* offset=1579321 */ "ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000"
/* offset=1579620 */ "ocr.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00000\000\000"
/* offset=1579793 */ "ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000"
/* offset=1580087 */ "ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000"
/* offset=1580389 */ "ocr.demand_rfo.l3_hit.snoop_sent\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0002\000\00000\000\000"
/* offset=1580657 */ "ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0002\000\00000\000\000"
/* offset=1580886 */ "ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=1581115 */ "ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=1581399 */ "ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=1581683 */ "ocr.demand_rfo.l3_hit\000cpu_atom\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=1581937 */ "ocr.demand_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080002\000\00000\000\000"
/* offset=1582115 */ "ocr.demand_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080002\000\00000\000\000"
/* offset=1582310 */ "ocr.demand_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00000\000\000"
/* offset=1582511 */ "ocr.demand_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000"
/* offset=1582701 */ "ocr.demand_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00000\000\000"
/* offset=1582890 */ "ocr.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00000\000\000"
/* offset=1583033 */ "ocr.demand_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00000\000\000"
/* offset=1583175 */ "ocr.demand_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200002\000\00000\000\000"
/* offset=1583353 */ "ocr.demand_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200002\000\00000\000\000"
/* offset=1583548 */ "ocr.demand_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200002\000\00000\000\000"
/* offset=1583749 */ "ocr.demand_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200002\000\00000\000\000"
/* offset=1583939 */ "ocr.demand_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200002\000\00000\000\000"
/* offset=1584128 */ "ocr.demand_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200002\000\00000\000\000"
/* offset=1584271 */ "ocr.demand_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200002\000\00000\000\000"
/* offset=1584413 */ "ocr.demand_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040002\000\00000\000\000"
/* offset=1584591 */ "ocr.demand_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040002\000\00000\000\000"
/* offset=1584786 */ "ocr.demand_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00000\000\000"
/* offset=1584987 */ "ocr.demand_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000"
/* offset=1585177 */ "ocr.demand_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00000\000\000"
/* offset=1585366 */ "ocr.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00000\000\000"
/* offset=1585509 */ "ocr.demand_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00000\000\000"
/* offset=1585651 */ "ocr.demand_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100002\000\00000\000\000"
/* offset=1585829 */ "ocr.demand_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100002\000\00000\000\000"
/* offset=1586024 */ "ocr.demand_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00000\000\000"
/* offset=1586225 */ "ocr.demand_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00000\000\000"
/* offset=1586415 */ "ocr.demand_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00000\000\000"
/* offset=1586604 */ "ocr.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00000\000\000"
/* offset=1586747 */ "ocr.demand_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00000\000\000"
/* offset=1586889 */ "ocr.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00000\000\000"
/* offset=1587098 */ "ocr.demand_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000002\000\00000\000\000"
/* offset=1587333 */ "ocr.demand_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00000\000\000"
/* offset=1587577 */ "ocr.demand_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000002\000\00000\000\000"
/* offset=1587804 */ "ocr.demand_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00000\000\000"
/* offset=1588030 */ "ocr.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00000\000\000"
/* offset=1588223 */ "ocr.demand_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000"
/* offset=1588403 */ "ocr.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00000\000\000"
/* offset=1588580 */ "ocr.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00000\000\000"
/* offset=1588756 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000"
/* offset=1588991 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000"
/* offset=1589226 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000"
/* offset=1589461 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00002\000\00000\000\000"
/* offset=1589704 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FC00002\000\00000\000\000"
/* offset=1589975 */ "ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FC00002\000\00000\000\000"
/* offset=1590246 */ "ocr.demand_rfo.l3_miss\000cpu_atom\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000"
/* offset=1590506 */ "ocr.demand_rfo.l3_miss\000cpu_core\000memory\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000"
/* offset=1590774 */ "ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000"
/* offset=1591015 */ "ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000"
/* offset=1591256 */ "ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by the local socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F04400002\000\00000\000\000"
/* offset=1591571 */ "ocr.demand_rfo.l3_miss_local\000cpu_atom\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000"
/* offset=1591837 */ "ocr.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00000\000\000"
/* offset=1592036 */ "ocr.demand_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000002\000\00000\000\000"
/* offset=1592252 */ "ocr.demand_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00000\000\000"
/* offset=1592474 */ "ocr.demand_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00000\000\000"
/* offset=1592685 */ "ocr.demand_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000"
/* offset=1592895 */ "ocr.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00000\000\000"
/* offset=1593049 */ "ocr.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00000\000\000"
/* offset=1593268 */ "ocr.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000"
/* offset=1593421 */ "ocr.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00000\000\000"
/* offset=1593642 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000002\000\00000\000\000"
/* offset=1593853 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000002\000\00000\000\000"
/* offset=1594081 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000002\000\00000\000\000"
/* offset=1594315 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000002\000\00000\000\000"
/* offset=1594538 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000002\000\00000\000\000"
/* offset=1594760 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000002\000\00000\000\000"
/* offset=1594920 */ "ocr.demand_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00000\000\000"
/* offset=1595079 */ "ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000"
/* offset=1595303 */ "ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000"
/* offset=1595540 */ "ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000"
/* offset=1595926 */ "ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000"
/* offset=1596312 */ "ocr.demand_rfo.local_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000"
/* offset=1596695 */ "ocr.demand_rfo.outstanding\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000002\000\00000\000\000"
/* offset=1597018 */ "ocr.demand_rfo.pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703C00002\000\00000\000\000"
/* offset=1597243 */ "ocr.demand_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400002\000\00000\000\000"
/* offset=1597438 */ "ocr.demand_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00000\000\000"
/* offset=1597633 */ "ocr.demand_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000"
/* offset=1597841 */ "ocr.demand_rfo.remote_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000002\000\00000\000\000"
/* offset=1598100 */ "ocr.demand_rfo.snc_cache.hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000002\000\00000\000\000"
/* offset=1598492 */ "ocr.demand_rfo.snc_cache.hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000002\000\00000\000\000"
/* offset=1598884 */ "ocr.demand_rfo.snc_cache.hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000002\000\00000\000\000"
/* offset=1599258 */ "ocr.demand_rfo.snc_cache.hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000002\000\00000\000\000"
/* offset=1599632 */ "ocr.demand_rfo.snc_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000002\000\00000\000\000"
/* offset=1599959 */ "ocr.demand_rfo.snc_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000002\000\00000\000\000"
/* offset=1600286 */ "ocr.demand_rfo.snc_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800002\000\00000\000\000"
/* offset=1600611 */ "ocr.demand_rfo.supplier_none.any_snoop\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020002\000\00000\000\000"
/* offset=1600799 */ "ocr.demand_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020002\000\00000\000\000"
/* offset=1601004 */ "ocr.demand_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00000\000\000"
/* offset=1601215 */ "ocr.demand_rfo.supplier_none.hitm_other_core\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00000\000\000"
/* offset=1601415 */ "ocr.demand_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00000\000\000"
/* offset=1601614 */ "ocr.demand_rfo.supplier_none.snoop_miss\000\000other\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00000\000\000"
/* offset=1601762 */ "ocr.demand_rfo.supplier_none.snoop_none\000\000other\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00000\000\000"
/* offset=1601909 */ "ocr.full_streaming_wr.any_response\000\000other\000Counts streaming stores which modify a full 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800000010000\000\00000\000\000"
/* offset=1602111 */ "ocr.full_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify a full 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801F803C0000\000\00000\000\000"
/* offset=1602311 */ "ocr.full_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000"
/* offset=1602517 */ "ocr.full_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000"
/* offset=1602729 */ "ocr.hwpf_l1d.any_response\000\000other\000Counts data load hardware prefetch requests to the L1 data cache that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=1602918 */ "ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=1603145 */ "ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=1603360 */ "ocr.hwpf_l1d_and_swpf.dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000"
/* offset=1603571 */ "ocr.hwpf_l1d_and_swpf.dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000400\000\00000\000\000"
/* offset=1603778 */ "ocr.hwpf_l1d_and_swpf.l3_hit.any\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0400\000\00000\000\000"
/* offset=1604026 */ "ocr.hwpf_l1d_and_swpf.l3_hit.snoop_hitm\000\000cache\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000"
/* offset=1604338 */ "ocr.hwpf_l1d_and_swpf.l3_hit.snoop_miss\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00000\000\000"
/* offset=1604617 */ "ocr.hwpf_l1d_and_swpf.l3_hit.snoop_not_needed\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000"
/* offset=1604899 */ "ocr.hwpf_l1d_and_swpf.l3_hit\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000"
/* offset=1605163 */ "ocr.hwpf_l1d_and_swpf.l3_miss\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00400\000\00000\000\000"
/* offset=1605386 */ "ocr.hwpf_l1d_and_swpf.l3_miss\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00400\000\00000\000\000"
/* offset=1605637 */ "ocr.hwpf_l1d_and_swpf.l3_miss_local\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400400\000\00000\000\000"
/* offset=1605929 */ "ocr.hwpf_l1d_and_swpf.local_dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000"
/* offset=1606146 */ "ocr.hwpf_l1d_and_swpf.local_dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00000\000\000"
/* offset=1606512 */ "ocr.hwpf_l2.any_response\000\000other\000Counts hardware prefetch (which bring data to L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10070\000\00000\000\000"
/* offset=1606685 */ "ocr.hwpf_l2.any_response\000\000other\000Counts hardware prefetches (which bring data to L2) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10070\000\00000\000\000"
/* offset=1606860 */ "ocr.hwpf_l2_code_rd.any_response\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000"
/* offset=1607067 */ "ocr.hwpf_l2_code_rd.dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000"
/* offset=1607266 */ "ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0040\000\00000\000\000"
/* offset=1607557 */ "ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0040\000\00000\000\000"
/* offset=1607860 */ "ocr.hwpf_l2_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0040\000\00000\000\000"
/* offset=1608152 */ "ocr.hwpf_l2_code_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0040\000\00000\000\000"
/* offset=1608416 */ "ocr.hwpf_l2_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0040\000\00000\000\000"
/* offset=1608691 */ "ocr.hwpf_l2_code_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0040\000\00000\000\000"
/* offset=1608901 */ "ocr.hwpf_l2_code_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000"
/* offset=1609117 */ "ocr.hwpf_l2_code_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000"
/* offset=1609339 */ "ocr.hwpf_l2_code_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000"
/* offset=1609544 */ "ocr.hwpf_l2_code_rd.outstanding\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000040\000\00000\000\000"
/* offset=1609848 */ "ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000"
/* offset=1610055 */ "ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000"
/* offset=1610248 */ "ocr.hwpf_l2_data_rd.dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000"
/* offset=1610447 */ "ocr.hwpf_l2_data_rd.dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000"
/* offset=1610636 */ "ocr.hwpf_l2_data_rd.l3_hit.any\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0010\000\00000\000\000"
/* offset=1610862 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000"
/* offset=1611153 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000"
/* offset=1611428 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000"
/* offset=1611731 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000"
/* offset=1612023 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000"
/* offset=1612321 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000"
/* offset=1612585 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000"
/* offset=1612842 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000"
/* offset=1613117 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000"
/* offset=1613377 */ "ocr.hwpf_l2_data_rd.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0010\000\00000\000\000"
/* offset=1613603 */ "ocr.hwpf_l2_data_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0010\000\00000\000\000"
/* offset=1613813 */ "ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000"
/* offset=1614029 */ "ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts hardware prefetch data reads (which bring data to L2)  that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00010\000\00000\000\000"
/* offset=1614230 */ "ocr.hwpf_l2_data_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000"
/* offset=1614452 */ "ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000"
/* offset=1614657 */ "ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000"
/* offset=1614852 */ "ocr.hwpf_l2_rfo.any_response\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000"
/* offset=1615049 */ "ocr.hwpf_l2_rfo.any_response\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000"
/* offset=1615231 */ "ocr.hwpf_l2_rfo.dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000"
/* offset=1615420 */ "ocr.hwpf_l2_rfo.dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000"
/* offset=1615598 */ "ocr.hwpf_l2_rfo.l3_hit.any\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0020\000\00000\000\000"
/* offset=1615813 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000"
/* offset=1616094 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000"
/* offset=1616358 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000"
/* offset=1616651 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000"
/* offset=1616933 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000"
/* offset=1617220 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000"
/* offset=1617474 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000"
/* offset=1617720 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000"
/* offset=1617985 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000"
/* offset=1618234 */ "ocr.hwpf_l2_rfo.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0020\000\00000\000\000"
/* offset=1618449 */ "ocr.hwpf_l2_rfo.l3_hit\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0020\000\00000\000\000"
/* offset=1618649 */ "ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000"
/* offset=1618855 */ "ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts hardware prefetch RFOs (which bring data to L2) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00020\000\00000\000\000"
/* offset=1619045 */ "ocr.hwpf_l2_rfo.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000"
/* offset=1619257 */ "ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000"
/* offset=1619452 */ "ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000"
/* offset=1619636 */ "ocr.hwpf_l2_rfo.outstanding\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000020\000\00000\000\000"
/* offset=1619930 */ "ocr.hwpf_l3.any_response\000\000other\000Counts hardware prefetches to the L3 only that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x12380\000\00000\000\000"
/* offset=1620095 */ "ocr.hwpf_l3.any_response\000\000other\000Counts hardware prefetches to the L3 only that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x12380\000\00000\000\000"
/* offset=1620260 */ "ocr.hwpf_l3.l3_hit.any\000\000cache\000Counts hardware prefetches to the L3 only that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C2380\000\00000\000\000"
/* offset=1620458 */ "ocr.hwpf_l3.l3_hit\000\000cache\000Counts hardware prefetches to the L3 only that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x80082380\000\00000\000\000"
/* offset=1620670 */ "ocr.hwpf_l3.l3_hit\000\000cache\000Counts hardware prefetches to the L3 only that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80082380\000\00000\000\000"
/* offset=1620882 */ "ocr.hwpf_l3.l3_miss\000\000memory\000Counts hardware prefetches to the L3 only that missed the local socket's L1, L2, and L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x94002380\000\00000\000\000"
/* offset=1621068 */ "ocr.hwpf_l3.l3_miss\000\000memory\000Counts hardware prefetches to the L3 only that missed the local socket's L1, L2, and L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x94002380\000\00000\000\000"
/* offset=1621254 */ "ocr.hwpf_l3.l3_miss_local\000\000memory\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x84002380\000\00000\000\000"
/* offset=1621494 */ "ocr.hwpf_l3.l3_miss_local\000\000memory\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84002380\000\00000\000\000"
/* offset=1621734 */ "ocr.hwpf_l3.remote\000\000other\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x90002380\000\00000\000\000"
/* offset=1621978 */ "ocr.hwpf_l3.remote\000\000other\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90002380\000\00000\000\000"
/* offset=1622222 */ "ocr.itom.l3_miss_local\000\000memory\000Counts full cacheline writes (ItoM) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000"
/* offset=1622453 */ "ocr.itom.remote\000\000other\000Counts full cacheline writes (ItoM) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00000\000\000"
/* offset=1622688 */ "ocr.l1wb_m.any_response\000\000other\000Counts modified writebacks from L1 cache that miss the L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000000010000\000\00000\000\000"
/* offset=1622882 */ "ocr.l1wb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache that miss the L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001F803C0000\000\00000\000\000"
/* offset=1623074 */ "ocr.l1wb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000"
/* offset=1623272 */ "ocr.l1wb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000"
/* offset=1623476 */ "ocr.l2wb_m.any_response\000\000other\000Counts modified writeBacks from L2 cache that miss the L3 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000000010000\000\00000\000\000"
/* offset=1623670 */ "ocr.l2wb_m.l3_hit\000\000cache\000Counts modified writeBacks from L2 cache that miss the L3 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001F803C0000\000\00000\000\000"
/* offset=1623862 */ "ocr.l2wb_m.l3_miss\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000"
/* offset=1624060 */ "ocr.l2wb_m.l3_miss_local\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000"
/* offset=1624264 */ "ocr.modified_write.any_response\000\000other\000Counts writebacks of modified cachelines and streaming stores that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10808\000\00000\000\000"
/* offset=1624456 */ "ocr.other.any_response\000\000other\000Counts any other requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000"
/* offset=1624595 */ "ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O accesses, that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000"
/* offset=1624769 */ "ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000"
/* offset=1624959 */ "ocr.other.dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000"
/* offset=1625145 */ "ocr.other.l3_hit.any_snoop\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.ANY_SNOOP OCR.OTHER.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00000\000\000"
/* offset=1625324 */ "ocr.other.l3_hit.hit_other_core_fwd\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C8000\000\00000\000\000"
/* offset=1625529 */ "ocr.other.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000"
/* offset=1625743 */ "ocr.other.l3_hit.hitm_other_core\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HITM_OTHER_CORE OCR.OTHER.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00000\000\000"
/* offset=1625940 */ "ocr.other.l3_hit.no_snoop_needed\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000"
/* offset=1626136 */ "ocr.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000"
/* offset=1626408 */ "ocr.other.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C8000\000\00000\000\000"
/* offset=1626541 */ "ocr.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000"
/* offset=1626694 */ "ocr.other.l3_hit.snoop_miss\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000"
/* offset=1626948 */ "ocr.other.l3_hit.snoop_none\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00000\000\000"
/* offset=1627100 */ "ocr.other.l3_hit.snoop_not_needed\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000"
/* offset=1627357 */ "ocr.other.l3_hit.snoop_sent\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C8000\000\00000\000\000"
/* offset=1627580 */ "ocr.other.l3_hit_e.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80088000\000\00000\000\000"
/* offset=1627737 */ "ocr.other.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800088000\000\00000\000\000"
/* offset=1627911 */ "ocr.other.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00000\000\000"
/* offset=1628091 */ "ocr.other.l3_hit_e.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000"
/* offset=1628260 */ "ocr.other.l3_hit_e.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00000\000\000"
/* offset=1628428 */ "ocr.other.l3_hit_e.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00000\000\000"
/* offset=1628555 */ "ocr.other.l3_hit_e.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00000\000\000"
/* offset=1628681 */ "ocr.other.l3_hit_f.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80208000\000\00000\000\000"
/* offset=1628838 */ "ocr.other.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800208000\000\00000\000\000"
/* offset=1629012 */ "ocr.other.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400208000\000\00000\000\000"
/* offset=1629192 */ "ocr.other.l3_hit_f.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000208000\000\00000\000\000"
/* offset=1629361 */ "ocr.other.l3_hit_f.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100208000\000\00000\000\000"
/* offset=1629529 */ "ocr.other.l3_hit_f.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200208000\000\00000\000\000"
/* offset=1629656 */ "ocr.other.l3_hit_f.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80208000\000\00000\000\000"
/* offset=1629782 */ "ocr.other.l3_hit_m.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80048000\000\00000\000\000"
/* offset=1629939 */ "ocr.other.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800048000\000\00000\000\000"
/* offset=1630113 */ "ocr.other.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00000\000\000"
/* offset=1630293 */ "ocr.other.l3_hit_m.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00000\000\000"
/* offset=1630462 */ "ocr.other.l3_hit_m.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00000\000\000"
/* offset=1630630 */ "ocr.other.l3_hit_m.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00000\000\000"
/* offset=1630757 */ "ocr.other.l3_hit_m.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00000\000\000"
/* offset=1630883 */ "ocr.other.l3_hit_s.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80108000\000\00000\000\000"
/* offset=1631040 */ "ocr.other.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800108000\000\00000\000\000"
/* offset=1631214 */ "ocr.other.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00000\000\000"
/* offset=1631394 */ "ocr.other.l3_hit_s.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00000\000\000"
/* offset=1631563 */ "ocr.other.l3_hit_s.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00000\000\000"
/* offset=1631731 */ "ocr.other.l3_hit_s.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00000\000\000"
/* offset=1631858 */ "ocr.other.l3_hit_s.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00000\000\000"
/* offset=1631984 */ "ocr.other.l3_miss.any_snoop\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.ANY_SNOOP OCR.OTHER.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC008000\000\00000\000\000"
/* offset=1632167 */ "ocr.other.l3_miss.hit_other_core_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C008000\000\00000\000\000"
/* offset=1632376 */ "ocr.other.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00000\000\000"
/* offset=1632594 */ "ocr.other.l3_miss.hitm_other_core\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HITM_OTHER_CORE OCR.OTHER.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C008000\000\00000\000\000"
/* offset=1632795 */ "ocr.other.l3_miss.no_snoop_needed\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00000\000\000"
/* offset=1632995 */ "ocr.other.l3_miss.remote_hit_forward\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC08000\000\00000\000\000"
/* offset=1633167 */ "ocr.other.l3_miss.remote_hitm\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC08000\000\00000\000\000"
/* offset=1633326 */ "ocr.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00000\000\000"
/* offset=1633482 */ "ocr.other.l3_miss.snoop_none\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00000\000\000"
/* offset=1633637 */ "ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000"
/* offset=1633820 */ "ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC08000\000\00000\000\000"
/* offset=1634018 */ "ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC08000\000\00000\000\000"
/* offset=1634244 */ "ocr.other.l3_miss_local\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000"
/* offset=1634433 */ "ocr.other.l3_miss_local\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84408000\000\00000\000\000"
/* offset=1634700 */ "ocr.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00000\000\000"
/* offset=1634878 */ "ocr.other.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804008000\000\00000\000\000"
/* offset=1635073 */ "ocr.other.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00000\000\000"
/* offset=1635274 */ "ocr.other.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00000\000\000"
/* offset=1635464 */ "ocr.other.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00000\000\000"
/* offset=1635653 */ "ocr.other.l3_miss_local_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00000\000\000"
/* offset=1635791 */ "ocr.other.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604008000\000\00000\000\000"
/* offset=1635989 */ "ocr.other.l3_miss_local_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00000\000\000"
/* offset=1636126 */ "ocr.other.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B808000\000\00000\000\000"
/* offset=1636326 */ "ocr.other.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90008000\000\00000\000\000"
/* offset=1636516 */ "ocr.other.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810008000\000\00000\000\000"
/* offset=1636723 */ "ocr.other.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410008000\000\00000\000\000"
/* offset=1636936 */ "ocr.other.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010008000\000\00000\000\000"
/* offset=1637138 */ "ocr.other.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110008000\000\00000\000\000"
/* offset=1637339 */ "ocr.other.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210008000\000\00000\000\000"
/* offset=1637483 */ "ocr.other.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90008000\000\00000\000\000"
/* offset=1637626 */ "ocr.other.local_dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000"
/* offset=1637818 */ "ocr.other.pmm_hit_local_pmm.any_snoop\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80408000\000\00000\000\000"
/* offset=1637992 */ "ocr.other.pmm_hit_local_pmm.snoop_none\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00000\000\000"
/* offset=1638166 */ "ocr.other.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00000\000\000"
/* offset=1638353 */ "ocr.other.supplier_none.any_snoop\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00000\000\000"
/* offset=1638520 */ "ocr.other.supplier_none.hit_other_core_fwd\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800028000\000\00000\000\000"
/* offset=1638704 */ "ocr.other.supplier_none.hit_other_core_no_fwd\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00000\000\000"
/* offset=1638894 */ "ocr.other.supplier_none.hitm_other_core\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00000\000\000"
/* offset=1639073 */ "ocr.other.supplier_none.no_snoop_needed\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00000\000\000"
/* offset=1639251 */ "ocr.other.supplier_none.snoop_miss\000\000other\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00000\000\000"
/* offset=1639383 */ "ocr.other.supplier_none.snoop_none\000\000other\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00000\000\000"
/* offset=1639514 */ "ocr.partial_streaming_wr.any_response\000\000other\000Counts streaming stores which modify only part of a 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400000010000\000\00000\000\000"
/* offset=1639727 */ "ocr.partial_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify only part of a 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401F803C0000\000\00000\000\000"
/* offset=1639938 */ "ocr.partial_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000"
/* offset=1640155 */ "ocr.partial_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000"
/* offset=1640378 */ "ocr.pf_l1d_and_sw.any_response\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=1640578 */ "ocr.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000"
/* offset=1640834 */ "ocr.pf_l1d_and_sw.l3_hit.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00000\000\000"
/* offset=1641116 */ "ocr.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00000\000\000"
/* offset=1641407 */ "ocr.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000"
/* offset=1641681 */ "ocr.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000"
/* offset=1641954 */ "ocr.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0400\000\00000\000\000"
/* offset=1642148 */ "ocr.pf_l1d_and_sw.l3_hit.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00000\000\000"
/* offset=1642370 */ "ocr.pf_l1d_and_sw.l3_hit.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0400\000\00000\000\000"
/* offset=1642591 */ "ocr.pf_l1d_and_sw.l3_hit_e.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080400\000\00000\000\000"
/* offset=1642817 */ "ocr.pf_l1d_and_sw.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080400\000\00000\000\000"
/* offset=1643060 */ "ocr.pf_l1d_and_sw.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080400\000\00000\000\000"
/* offset=1643309 */ "ocr.pf_l1d_and_sw.l3_hit_e.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080400\000\00000\000\000"
/* offset=1643547 */ "ocr.pf_l1d_and_sw.l3_hit_e.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080400\000\00000\000\000"
/* offset=1643784 */ "ocr.pf_l1d_and_sw.l3_hit_e.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080400\000\00000\000\000"
/* offset=1643972 */ "ocr.pf_l1d_and_sw.l3_hit_e.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080400\000\00000\000\000"
/* offset=1644159 */ "ocr.pf_l1d_and_sw.l3_hit_f.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200400\000\00000\000\000"
/* offset=1644385 */ "ocr.pf_l1d_and_sw.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200400\000\00000\000\000"
/* offset=1644628 */ "ocr.pf_l1d_and_sw.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200400\000\00000\000\000"
/* offset=1644877 */ "ocr.pf_l1d_and_sw.l3_hit_f.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200400\000\00000\000\000"
/* offset=1645115 */ "ocr.pf_l1d_and_sw.l3_hit_f.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200400\000\00000\000\000"
/* offset=1645352 */ "ocr.pf_l1d_and_sw.l3_hit_f.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200400\000\00000\000\000"
/* offset=1645540 */ "ocr.pf_l1d_and_sw.l3_hit_f.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200400\000\00000\000\000"
/* offset=1645727 */ "ocr.pf_l1d_and_sw.l3_hit_m.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040400\000\00000\000\000"
/* offset=1645953 */ "ocr.pf_l1d_and_sw.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040400\000\00000\000\000"
/* offset=1646196 */ "ocr.pf_l1d_and_sw.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040400\000\00000\000\000"
/* offset=1646445 */ "ocr.pf_l1d_and_sw.l3_hit_m.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040400\000\00000\000\000"
/* offset=1646683 */ "ocr.pf_l1d_and_sw.l3_hit_m.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040400\000\00000\000\000"
/* offset=1646920 */ "ocr.pf_l1d_and_sw.l3_hit_m.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040400\000\00000\000\000"
/* offset=1647108 */ "ocr.pf_l1d_and_sw.l3_hit_m.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040400\000\00000\000\000"
/* offset=1647295 */ "ocr.pf_l1d_and_sw.l3_hit_s.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100400\000\00000\000\000"
/* offset=1647521 */ "ocr.pf_l1d_and_sw.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100400\000\00000\000\000"
/* offset=1647764 */ "ocr.pf_l1d_and_sw.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100400\000\00000\000\000"
/* offset=1648013 */ "ocr.pf_l1d_and_sw.l3_hit_s.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100400\000\00000\000\000"
/* offset=1648251 */ "ocr.pf_l1d_and_sw.l3_hit_s.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100400\000\00000\000\000"
/* offset=1648488 */ "ocr.pf_l1d_and_sw.l3_hit_s.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100400\000\00000\000\000"
/* offset=1648676 */ "ocr.pf_l1d_and_sw.l3_hit_s.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100400\000\00000\000\000"
/* offset=1648863 */ "ocr.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00000\000\000"
/* offset=1649123 */ "ocr.pf_l1d_and_sw.l3_miss.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000400\000\00000\000\000"
/* offset=1649409 */ "ocr.pf_l1d_and_sw.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000400\000\00000\000\000"
/* offset=1649704 */ "ocr.pf_l1d_and_sw.l3_miss.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000400\000\00000\000\000"
/* offset=1649982 */ "ocr.pf_l1d_and_sw.l3_miss.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000400\000\00000\000\000"
/* offset=1650259 */ "ocr.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00000\000\000"
/* offset=1650500 */ "ocr.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00000\000\000"
/* offset=1650728 */ "ocr.pf_l1d_and_sw.l3_miss.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000400\000\00000\000\000"
/* offset=1650953 */ "ocr.pf_l1d_and_sw.l3_miss.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000400\000\00000\000\000"
/* offset=1651177 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000400\000\00000\000\000"
/* offset=1651424 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000400\000\00000\000\000"
/* offset=1651688 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000400\000\00000\000\000"
/* offset=1651958 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000400\000\00000\000\000"
/* offset=1652217 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00000\000\000"
/* offset=1652475 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000400\000\00000\000\000"
/* offset=1652674 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00000\000\000"
/* offset=1652941 */ "ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000400\000\00000\000\000"
/* offset=1653139 */ "ocr.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00000\000\000"
/* offset=1653408 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000400\000\00000\000\000"
/* offset=1653667 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000400\000\00000\000\000"
/* offset=1653943 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000400\000\00000\000\000"
/* offset=1654225 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000400\000\00000\000\000"
/* offset=1654496 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000400\000\00000\000\000"
/* offset=1654766 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000400\000\00000\000\000"
/* offset=1654971 */ "ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000400\000\00000\000\000"
/* offset=1655175 */ "ocr.pf_l1d_and_sw.pmm_hit_local_pmm.any_snoop\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400400\000\00000\000\000"
/* offset=1655418 */ "ocr.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_none\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400400\000\00000\000\000"
/* offset=1655661 */ "ocr.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400400\000\00000\000\000"
/* offset=1655917 */ "ocr.pf_l1d_and_sw.supplier_none.any_snoop\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020400\000\00000\000\000"
/* offset=1656153 */ "ocr.pf_l1d_and_sw.supplier_none.hit_other_core_fwd\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020400\000\00000\000\000"
/* offset=1656406 */ "ocr.pf_l1d_and_sw.supplier_none.hit_other_core_no_fwd\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020400\000\00000\000\000"
/* offset=1656665 */ "ocr.pf_l1d_and_sw.supplier_none.hitm_other_core\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020400\000\00000\000\000"
/* offset=1656913 */ "ocr.pf_l1d_and_sw.supplier_none.no_snoop_needed\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020400\000\00000\000\000"
/* offset=1657160 */ "ocr.pf_l1d_and_sw.supplier_none.snoop_miss\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020400\000\00000\000\000"
/* offset=1657353 */ "ocr.pf_l1d_and_sw.supplier_none.snoop_none\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020400\000\00000\000\000"
/* offset=1657545 */ "ocr.pf_l2_data_rd.any_response\000\000other\000Counts prefetch (that bring data to L2) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000"
/* offset=1657717 */ "ocr.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000"
/* offset=1657945 */ "ocr.pf_l2_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000"
/* offset=1658199 */ "ocr.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000"
/* offset=1658462 */ "ocr.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000"
/* offset=1658708 */ "ocr.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000"
/* offset=1658953 */ "ocr.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0010\000\00000\000\000"
/* offset=1659119 */ "ocr.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000"
/* offset=1659313 */ "ocr.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00000\000\000"
/* offset=1659506 */ "ocr.pf_l2_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080010\000\00000\000\000"
/* offset=1659704 */ "ocr.pf_l2_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080010\000\00000\000\000"
/* offset=1659919 */ "ocr.pf_l2_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080010\000\00000\000\000"
/* offset=1660140 */ "ocr.pf_l2_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080010\000\00000\000\000"
/* offset=1660350 */ "ocr.pf_l2_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080010\000\00000\000\000"
/* offset=1660559 */ "ocr.pf_l2_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080010\000\00000\000\000"
/* offset=1660719 */ "ocr.pf_l2_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080010\000\00000\000\000"
/* offset=1660878 */ "ocr.pf_l2_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200010\000\00000\000\000"
/* offset=1661076 */ "ocr.pf_l2_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200010\000\00000\000\000"
/* offset=1661291 */ "ocr.pf_l2_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200010\000\00000\000\000"
/* offset=1661512 */ "ocr.pf_l2_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200010\000\00000\000\000"
/* offset=1661722 */ "ocr.pf_l2_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200010\000\00000\000\000"
/* offset=1661931 */ "ocr.pf_l2_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200010\000\00000\000\000"
/* offset=1662091 */ "ocr.pf_l2_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200010\000\00000\000\000"
/* offset=1662250 */ "ocr.pf_l2_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040010\000\00000\000\000"
/* offset=1662448 */ "ocr.pf_l2_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040010\000\00000\000\000"
/* offset=1662663 */ "ocr.pf_l2_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040010\000\00000\000\000"
/* offset=1662884 */ "ocr.pf_l2_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040010\000\00000\000\000"
/* offset=1663094 */ "ocr.pf_l2_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040010\000\00000\000\000"
/* offset=1663303 */ "ocr.pf_l2_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040010\000\00000\000\000"
/* offset=1663463 */ "ocr.pf_l2_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040010\000\00000\000\000"
/* offset=1663622 */ "ocr.pf_l2_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100010\000\00000\000\000"
/* offset=1663820 */ "ocr.pf_l2_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100010\000\00000\000\000"
/* offset=1664035 */ "ocr.pf_l2_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100010\000\00000\000\000"
/* offset=1664256 */ "ocr.pf_l2_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100010\000\00000\000\000"
/* offset=1664466 */ "ocr.pf_l2_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100010\000\00000\000\000"
/* offset=1664675 */ "ocr.pf_l2_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100010\000\00000\000\000"
/* offset=1664835 */ "ocr.pf_l2_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100010\000\00000\000\000"
/* offset=1664994 */ "ocr.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00000\000\000"
/* offset=1665226 */ "ocr.pf_l2_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000010\000\00000\000\000"
/* offset=1665484 */ "ocr.pf_l2_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00000\000\000"
/* offset=1665751 */ "ocr.pf_l2_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000010\000\00000\000\000"
/* offset=1666001 */ "ocr.pf_l2_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00000\000\000"
/* offset=1666250 */ "ocr.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00000\000\000"
/* offset=1666463 */ "ocr.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00000\000\000"
/* offset=1666663 */ "ocr.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00000\000\000"
/* offset=1666860 */ "ocr.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00000\000\000"
/* offset=1667056 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00000\000\000"
/* offset=1667275 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000010\000\00000\000\000"
/* offset=1667511 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00000\000\000"
/* offset=1667753 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00000\000\000"
/* offset=1667984 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00000\000\000"
/* offset=1668214 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00000\000\000"
/* offset=1668385 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00000\000\000"
/* offset=1668624 */ "ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00000\000\000"
/* offset=1668794 */ "ocr.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00000\000\000"
/* offset=1669035 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000010\000\00000\000\000"
/* offset=1669266 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000010\000\00000\000\000"
/* offset=1669514 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000010\000\00000\000\000"
/* offset=1669768 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000010\000\00000\000\000"
/* offset=1670011 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000010\000\00000\000\000"
/* offset=1670253 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000010\000\00000\000\000"
/* offset=1670430 */ "ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000010\000\00000\000\000"
/* offset=1670606 */ "ocr.pf_l2_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400010\000\00000\000\000"
/* offset=1670821 */ "ocr.pf_l2_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400010\000\00000\000\000"
/* offset=1671036 */ "ocr.pf_l2_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400010\000\00000\000\000"
/* offset=1671264 */ "ocr.pf_l2_data_rd.supplier_none.any_snoop\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00000\000\000"
/* offset=1671472 */ "ocr.pf_l2_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020010\000\00000\000\000"
/* offset=1671697 */ "ocr.pf_l2_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00000\000\000"
/* offset=1671928 */ "ocr.pf_l2_data_rd.supplier_none.hitm_other_core\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00000\000\000"
/* offset=1672148 */ "ocr.pf_l2_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00000\000\000"
/* offset=1672367 */ "ocr.pf_l2_data_rd.supplier_none.snoop_miss\000\000other\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00000\000\000"
/* offset=1672532 */ "ocr.pf_l2_data_rd.supplier_none.snoop_none\000\000other\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00000\000\000"
/* offset=1672696 */ "ocr.pf_l2_rfo.any_response\000\000other\000Counts all prefetch (that bring data to L2) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000"
/* offset=1672862 */ "ocr.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000"
/* offset=1673076 */ "ocr.pf_l2_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000"
/* offset=1673316 */ "ocr.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000"
/* offset=1673565 */ "ocr.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000"
/* offset=1673797 */ "ocr.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000"
/* offset=1674028 */ "ocr.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0020\000\00000\000\000"
/* offset=1674188 */ "ocr.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000"
/* offset=1674372 */ "ocr.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00000\000\000"
/* offset=1674555 */ "ocr.pf_l2_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080020\000\00000\000\000"
/* offset=1674743 */ "ocr.pf_l2_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080020\000\00000\000\000"
/* offset=1674948 */ "ocr.pf_l2_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080020\000\00000\000\000"
/* offset=1675159 */ "ocr.pf_l2_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080020\000\00000\000\000"
/* offset=1675359 */ "ocr.pf_l2_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080020\000\00000\000\000"
/* offset=1675558 */ "ocr.pf_l2_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080020\000\00000\000\000"
/* offset=1675712 */ "ocr.pf_l2_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080020\000\00000\000\000"
/* offset=1675865 */ "ocr.pf_l2_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200020\000\00000\000\000"
/* offset=1676053 */ "ocr.pf_l2_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200020\000\00000\000\000"
/* offset=1676258 */ "ocr.pf_l2_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200020\000\00000\000\000"
/* offset=1676469 */ "ocr.pf_l2_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200020\000\00000\000\000"
/* offset=1676669 */ "ocr.pf_l2_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200020\000\00000\000\000"
/* offset=1676868 */ "ocr.pf_l2_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200020\000\00000\000\000"
/* offset=1677022 */ "ocr.pf_l2_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200020\000\00000\000\000"
/* offset=1677175 */ "ocr.pf_l2_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040020\000\00000\000\000"
/* offset=1677363 */ "ocr.pf_l2_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040020\000\00000\000\000"
/* offset=1677568 */ "ocr.pf_l2_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040020\000\00000\000\000"
/* offset=1677779 */ "ocr.pf_l2_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040020\000\00000\000\000"
/* offset=1677979 */ "ocr.pf_l2_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040020\000\00000\000\000"
/* offset=1678178 */ "ocr.pf_l2_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040020\000\00000\000\000"
/* offset=1678332 */ "ocr.pf_l2_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040020\000\00000\000\000"
/* offset=1678485 */ "ocr.pf_l2_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100020\000\00000\000\000"
/* offset=1678673 */ "ocr.pf_l2_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100020\000\00000\000\000"
/* offset=1678878 */ "ocr.pf_l2_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100020\000\00000\000\000"
/* offset=1679089 */ "ocr.pf_l2_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100020\000\00000\000\000"
/* offset=1679289 */ "ocr.pf_l2_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100020\000\00000\000\000"
/* offset=1679488 */ "ocr.pf_l2_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100020\000\00000\000\000"
/* offset=1679642 */ "ocr.pf_l2_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100020\000\00000\000\000"
/* offset=1679795 */ "ocr.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00000\000\000"
/* offset=1680013 */ "ocr.pf_l2_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000020\000\00000\000\000"
/* offset=1680257 */ "ocr.pf_l2_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00000\000\000"
/* offset=1680510 */ "ocr.pf_l2_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000020\000\00000\000\000"
/* offset=1680746 */ "ocr.pf_l2_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00000\000\000"
/* offset=1680981 */ "ocr.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00000\000\000"
/* offset=1681184 */ "ocr.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00000\000\000"
/* offset=1681374 */ "ocr.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00000\000\000"
/* offset=1681561 */ "ocr.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00000\000\000"
/* offset=1681747 */ "ocr.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00000\000\000"
/* offset=1681956 */ "ocr.pf_l2_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000020\000\00000\000\000"
/* offset=1682182 */ "ocr.pf_l2_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00000\000\000"
/* offset=1682414 */ "ocr.pf_l2_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00000\000\000"
/* offset=1682635 */ "ocr.pf_l2_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00000\000\000"
/* offset=1682855 */ "ocr.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00000\000\000"
/* offset=1683020 */ "ocr.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00000\000\000"
/* offset=1683249 */ "ocr.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00000\000\000"
/* offset=1683413 */ "ocr.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00000\000\000"
/* offset=1683644 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000020\000\00000\000\000"
/* offset=1683865 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000020\000\00000\000\000"
/* offset=1684103 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000020\000\00000\000\000"
/* offset=1684347 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000020\000\00000\000\000"
/* offset=1684580 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000020\000\00000\000\000"
/* offset=1684812 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000020\000\00000\000\000"
/* offset=1684983 */ "ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000020\000\00000\000\000"
/* offset=1685153 */ "ocr.pf_l2_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400020\000\00000\000\000"
/* offset=1685358 */ "ocr.pf_l2_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400020\000\00000\000\000"
/* offset=1685563 */ "ocr.pf_l2_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400020\000\00000\000\000"
/* offset=1685781 */ "ocr.pf_l2_rfo.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00000\000\000"
/* offset=1685979 */ "ocr.pf_l2_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020020\000\00000\000\000"
/* offset=1686194 */ "ocr.pf_l2_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00000\000\000"
/* offset=1686415 */ "ocr.pf_l2_rfo.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00000\000\000"
/* offset=1686625 */ "ocr.pf_l2_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00000\000\000"
/* offset=1686834 */ "ocr.pf_l2_rfo.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00000\000\000"
/* offset=1686993 */ "ocr.pf_l2_rfo.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00000\000\000"
/* offset=1687151 */ "ocr.pf_l3_data_rd.any_response\000\000other\000Counts all prefetch (that bring data to LLC only) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000"
/* offset=1687333 */ "ocr.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000"
/* offset=1687571 */ "ocr.pf_l3_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00000\000\000"
/* offset=1687835 */ "ocr.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000"
/* offset=1688108 */ "ocr.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000"
/* offset=1688364 */ "ocr.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000"
/* offset=1688619 */ "ocr.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0080\000\00000\000\000"
/* offset=1688795 */ "ocr.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00000\000\000"
/* offset=1688999 */ "ocr.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00000\000\000"
/* offset=1689202 */ "ocr.pf_l3_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080080\000\00000\000\000"
/* offset=1689410 */ "ocr.pf_l3_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080080\000\00000\000\000"
/* offset=1689635 */ "ocr.pf_l3_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080080\000\00000\000\000"
/* offset=1689866 */ "ocr.pf_l3_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080080\000\00000\000\000"
/* offset=1690086 */ "ocr.pf_l3_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080080\000\00000\000\000"
/* offset=1690305 */ "ocr.pf_l3_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080080\000\00000\000\000"
/* offset=1690475 */ "ocr.pf_l3_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080080\000\00000\000\000"
/* offset=1690644 */ "ocr.pf_l3_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200080\000\00000\000\000"
/* offset=1690852 */ "ocr.pf_l3_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200080\000\00000\000\000"
/* offset=1691077 */ "ocr.pf_l3_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200080\000\00000\000\000"
/* offset=1691308 */ "ocr.pf_l3_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200080\000\00000\000\000"
/* offset=1691528 */ "ocr.pf_l3_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200080\000\00000\000\000"
/* offset=1691747 */ "ocr.pf_l3_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200080\000\00000\000\000"
/* offset=1691917 */ "ocr.pf_l3_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200080\000\00000\000\000"
/* offset=1692086 */ "ocr.pf_l3_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040080\000\00000\000\000"
/* offset=1692294 */ "ocr.pf_l3_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040080\000\00000\000\000"
/* offset=1692519 */ "ocr.pf_l3_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040080\000\00000\000\000"
/* offset=1692750 */ "ocr.pf_l3_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040080\000\00000\000\000"
/* offset=1692970 */ "ocr.pf_l3_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040080\000\00000\000\000"
/* offset=1693189 */ "ocr.pf_l3_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040080\000\00000\000\000"
/* offset=1693359 */ "ocr.pf_l3_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040080\000\00000\000\000"
/* offset=1693528 */ "ocr.pf_l3_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100080\000\00000\000\000"
/* offset=1693736 */ "ocr.pf_l3_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100080\000\00000\000\000"
/* offset=1693961 */ "ocr.pf_l3_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100080\000\00000\000\000"
/* offset=1694192 */ "ocr.pf_l3_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100080\000\00000\000\000"
/* offset=1694412 */ "ocr.pf_l3_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100080\000\00000\000\000"
/* offset=1694631 */ "ocr.pf_l3_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100080\000\00000\000\000"
/* offset=1694801 */ "ocr.pf_l3_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100080\000\00000\000\000"
/* offset=1694970 */ "ocr.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00000\000\000"
/* offset=1695212 */ "ocr.pf_l3_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000080\000\00000\000\000"
/* offset=1695480 */ "ocr.pf_l3_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00000\000\000"
/* offset=1695757 */ "ocr.pf_l3_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000080\000\00000\000\000"
/* offset=1696017 */ "ocr.pf_l3_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00000\000\000"
/* offset=1696276 */ "ocr.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00000\000\000"
/* offset=1696499 */ "ocr.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00000\000\000"
/* offset=1696709 */ "ocr.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00000\000\000"
/* offset=1696916 */ "ocr.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00000\000\000"
/* offset=1697122 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00000\000\000"
/* offset=1697351 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000080\000\00000\000\000"
/* offset=1697597 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00000\000\000"
/* offset=1697849 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00000\000\000"
/* offset=1698090 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00000\000\000"
/* offset=1698330 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00000\000\000"
/* offset=1698511 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00000\000\000"
/* offset=1698760 */ "ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00000\000\000"
/* offset=1698940 */ "ocr.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00000\000\000"
/* offset=1699191 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000080\000\00000\000\000"
/* offset=1699432 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000080\000\00000\000\000"
/* offset=1699690 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000080\000\00000\000\000"
/* offset=1699954 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000080\000\00000\000\000"
/* offset=1700207 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000080\000\00000\000\000"
/* offset=1700459 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000080\000\00000\000\000"
/* offset=1700646 */ "ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000080\000\00000\000\000"
/* offset=1700832 */ "ocr.pf_l3_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400080\000\00000\000\000"
/* offset=1701057 */ "ocr.pf_l3_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400080\000\00000\000\000"
/* offset=1701282 */ "ocr.pf_l3_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400080\000\00000\000\000"
/* offset=1701520 */ "ocr.pf_l3_data_rd.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00000\000\000"
/* offset=1701738 */ "ocr.pf_l3_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020080\000\00000\000\000"
/* offset=1701973 */ "ocr.pf_l3_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00000\000\000"
/* offset=1702214 */ "ocr.pf_l3_data_rd.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00000\000\000"
/* offset=1702444 */ "ocr.pf_l3_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00000\000\000"
/* offset=1702673 */ "ocr.pf_l3_data_rd.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00000\000\000"
/* offset=1702848 */ "ocr.pf_l3_data_rd.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00000\000\000"
/* offset=1703022 */ "ocr.pf_l3_rfo.any_response\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000"
/* offset=1703194 */ "ocr.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000"
/* offset=1703414 */ "ocr.pf_l3_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00000\000\000"
/* offset=1703660 */ "ocr.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000"
/* offset=1703915 */ "ocr.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000"
/* offset=1704153 */ "ocr.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000"
/* offset=1704390 */ "ocr.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0100\000\00000\000\000"
/* offset=1704556 */ "ocr.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00000\000\000"
/* offset=1704746 */ "ocr.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00000\000\000"
/* offset=1704935 */ "ocr.pf_l3_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080100\000\00000\000\000"
/* offset=1705129 */ "ocr.pf_l3_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080100\000\00000\000\000"
/* offset=1705340 */ "ocr.pf_l3_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080100\000\00000\000\000"
/* offset=1705557 */ "ocr.pf_l3_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080100\000\00000\000\000"
/* offset=1705763 */ "ocr.pf_l3_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080100\000\00000\000\000"
/* offset=1705968 */ "ocr.pf_l3_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080100\000\00000\000\000"
/* offset=1706128 */ "ocr.pf_l3_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080100\000\00000\000\000"
/* offset=1706287 */ "ocr.pf_l3_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200100\000\00000\000\000"
/* offset=1706481 */ "ocr.pf_l3_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200100\000\00000\000\000"
/* offset=1706692 */ "ocr.pf_l3_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200100\000\00000\000\000"
/* offset=1706909 */ "ocr.pf_l3_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200100\000\00000\000\000"
/* offset=1707115 */ "ocr.pf_l3_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200100\000\00000\000\000"
/* offset=1707320 */ "ocr.pf_l3_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200100\000\00000\000\000"
/* offset=1707480 */ "ocr.pf_l3_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200100\000\00000\000\000"
/* offset=1707639 */ "ocr.pf_l3_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040100\000\00000\000\000"
/* offset=1707833 */ "ocr.pf_l3_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040100\000\00000\000\000"
/* offset=1708044 */ "ocr.pf_l3_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040100\000\00000\000\000"
/* offset=1708261 */ "ocr.pf_l3_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040100\000\00000\000\000"
/* offset=1708467 */ "ocr.pf_l3_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040100\000\00000\000\000"
/* offset=1708672 */ "ocr.pf_l3_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040100\000\00000\000\000"
/* offset=1708832 */ "ocr.pf_l3_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040100\000\00000\000\000"
/* offset=1708991 */ "ocr.pf_l3_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100100\000\00000\000\000"
/* offset=1709185 */ "ocr.pf_l3_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100100\000\00000\000\000"
/* offset=1709396 */ "ocr.pf_l3_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100100\000\00000\000\000"
/* offset=1709613 */ "ocr.pf_l3_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100100\000\00000\000\000"
/* offset=1709819 */ "ocr.pf_l3_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100100\000\00000\000\000"
/* offset=1710024 */ "ocr.pf_l3_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100100\000\00000\000\000"
/* offset=1710184 */ "ocr.pf_l3_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100100\000\00000\000\000"
/* offset=1710343 */ "ocr.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00000\000\000"
/* offset=1710567 */ "ocr.pf_l3_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000100\000\00000\000\000"
/* offset=1710817 */ "ocr.pf_l3_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00000\000\000"
/* offset=1711076 */ "ocr.pf_l3_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000100\000\00000\000\000"
/* offset=1711318 */ "ocr.pf_l3_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00000\000\000"
/* offset=1711559 */ "ocr.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00000\000\000"
/* offset=1711768 */ "ocr.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00000\000\000"
/* offset=1711964 */ "ocr.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00000\000\000"
/* offset=1712157 */ "ocr.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00000\000\000"
/* offset=1712349 */ "ocr.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00000\000\000"
/* offset=1712564 */ "ocr.pf_l3_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000100\000\00000\000\000"
/* offset=1712796 */ "ocr.pf_l3_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00000\000\000"
/* offset=1713034 */ "ocr.pf_l3_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00000\000\000"
/* offset=1713261 */ "ocr.pf_l3_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00000\000\000"
/* offset=1713487 */ "ocr.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00000\000\000"
/* offset=1713658 */ "ocr.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00000\000\000"
/* offset=1713893 */ "ocr.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00000\000\000"
/* offset=1714063 */ "ocr.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00000\000\000"
/* offset=1714300 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000100\000\00000\000\000"
/* offset=1714527 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000100\000\00000\000\000"
/* offset=1714771 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000100\000\00000\000\000"
/* offset=1715021 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000100\000\00000\000\000"
/* offset=1715260 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000100\000\00000\000\000"
/* offset=1715498 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000100\000\00000\000\000"
/* offset=1715675 */ "ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000100\000\00000\000\000"
/* offset=1715851 */ "ocr.pf_l3_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400100\000\00000\000\000"
/* offset=1716062 */ "ocr.pf_l3_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400100\000\00000\000\000"
/* offset=1716273 */ "ocr.pf_l3_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400100\000\00000\000\000"
/* offset=1716497 */ "ocr.pf_l3_rfo.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00000\000\000"
/* offset=1716701 */ "ocr.pf_l3_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020100\000\00000\000\000"
/* offset=1716922 */ "ocr.pf_l3_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00000\000\000"
/* offset=1717149 */ "ocr.pf_l3_rfo.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00000\000\000"
/* offset=1717365 */ "ocr.pf_l3_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00000\000\000"
/* offset=1717580 */ "ocr.pf_l3_rfo.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00000\000\000"
/* offset=1717745 */ "ocr.pf_l3_rfo.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00000\000\000"
/* offset=1717909 */ "ocr.prefetches.any_response\000\000other\000Counts all hardware and software prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10470\000\00000\000\000"
/* offset=1718079 */ "ocr.prefetches.l3_hit\000\000cache\000Counts hardware and software prefetches to all cache levels that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C27F0\000\00000\000\000"
/* offset=1718314 */ "ocr.prefetches.l3_miss\000\000memory\000Counts all hardware and software prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000470\000\00000\000\000"
/* offset=1718493 */ "ocr.prefetches.l3_miss_local\000\000memory\000Counts hardware and software prefetches to all cache levels that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F844027F0\000\00000\000\000"
/* offset=1718756 */ "ocr.reads_to_core.any_response\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FFC4477\000\00000\000\000"
/* offset=1719014 */ "ocr.reads_to_core.any_response\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0477\000\00000\000\000"
/* offset=1719272 */ "ocr.reads_to_core.any_response\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10477\000\00000\000\000"
/* offset=1719513 */ "ocr.reads_to_core.dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C004477\000\00000\000\000"
/* offset=1719758 */ "ocr.reads_to_core.dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000477\000\00000\000\000"
/* offset=1720003 */ "ocr.reads_to_core.dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000"
/* offset=1720236 */ "ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop that hit in another core, which did not forward the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x4003C4477\000\00000\000\000"
/* offset=1720555 */ "ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop that hit in another core, which did not forward the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0477\000\00000\000\000"
/* offset=1720874 */ "ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0477\000\00000\000\000"
/* offset=1721199 */ "ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C4477\000\00000\000\000"
/* offset=1721551 */ "ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0477\000\00000\000\000"
/* offset=1721903 */ "ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0477\000\00000\000\000"
/* offset=1722240 */ "ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C4477\000\00000\000\000"
/* offset=1722567 */ "ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0477\000\00000\000\000"
/* offset=1722894 */ "ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0477\000\00000\000\000"
/* offset=1723220 */ "ocr.reads_to_core.l3_hit.snoop_miss\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0477\000\00000\000\000"
/* offset=1723518 */ "ocr.reads_to_core.l3_hit.snoop_not_needed\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0477\000\00000\000\000"
/* offset=1723827 */ "ocr.reads_to_core.l3_hit\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F003C4477\000\00000\000\000"
/* offset=1724129 */ "ocr.reads_to_core.l3_hit\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F003C0477\000\00000\000\000"
/* offset=1724431 */ "ocr.reads_to_core.l3_hit\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0477\000\00000\000\000"
/* offset=1724675 */ "ocr.reads_to_core.l3_miss\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FC04477\000\00000\000\000"
/* offset=1724964 */ "ocr.reads_to_core.l3_miss\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FC00477\000\00000\000\000"
/* offset=1725253 */ "ocr.reads_to_core.l3_miss\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000"
/* offset=1725503 */ "ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F04C04477\000\00000\000\000"
/* offset=1725833 */ "ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by the local socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F04400477\000\00000\000\000"
/* offset=1726166 */ "ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000"
/* offset=1726422 */ "ocr.reads_to_core.l3_miss_local_socket\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that missed the L3 Cache and were supplied by the local socket (DRAM or PMM), whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM or DRAM accesses that are controlled by the close or distant SNC Cluster.  It does not count misses to the L3 which go to Local CXL Type 2 Memory or Local Non DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x70CC04477\000\00000\000\000"
/* offset=1726969 */ "ocr.reads_to_core.l3_miss_local_socket\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that missed the L3 Cache and were supplied by the local socket (DRAM or PMM), whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM or DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x70CC00477\000\00000\000\000"
/* offset=1727425 */ "ocr.reads_to_core.local_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104004477\000\00000\000\000"
/* offset=1727829 */ "ocr.reads_to_core.local_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000477\000\00000\000\000"
/* offset=1728233 */ "ocr.reads_to_core.local_dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000"
/* offset=1728472 */ "ocr.reads_to_core.local_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400477\000\00000\000\000"
/* offset=1728873 */ "ocr.reads_to_core.local_socket_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x70C004477\000\00000\000\000"
/* offset=1729292 */ "ocr.reads_to_core.local_socket_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x70C000477\000\00000\000\000"
/* offset=1729711 */ "ocr.reads_to_core.local_socket_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM accesses that are controlled by the close or distant SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x700C04477\000\00000\000\000"
/* offset=1730127 */ "ocr.reads_to_core.local_socket_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700C00477\000\00000\000\000"
/* offset=1730543 */ "ocr.reads_to_core.outstanding\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000477\000\00000\000\000"
/* offset=1730881 */ "ocr.reads_to_core.remote\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by a remote socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F33004477\000\00000\000\000"
/* offset=1731205 */ "ocr.reads_to_core.remote\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F33000477\000\00000\000\000"
/* offset=1731529 */ "ocr.reads_to_core.remote_cache.snoop_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop was sent and data was returned (Modified or Not Modified)\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1830004477\000\00000\000\000"
/* offset=1731887 */ "ocr.reads_to_core.remote_cache.snoop_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop was sent and data was returned (Modified or Not Modified)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1830000477\000\00000\000\000"
/* offset=1732245 */ "ocr.reads_to_core.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x830004477\000\00000\000\000"
/* offset=1732641 */ "ocr.reads_to_core.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x830000477\000\00000\000\000"
/* offset=1733037 */ "ocr.reads_to_core.remote_cache.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1030004477\000\00000\000\000"
/* offset=1733408 */ "ocr.reads_to_core.remote_cache.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1030000477\000\00000\000\000"
/* offset=1733779 */ "ocr.reads_to_core.remote_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x730004477\000\00000\000\000"
/* offset=1734058 */ "ocr.reads_to_core.remote_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x730000477\000\00000\000\000"
/* offset=1734337 */ "ocr.reads_to_core.remote_memory\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM or PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x733004477\000\00000\000\000"
/* offset=1734625 */ "ocr.reads_to_core.remote_memory\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM or PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x731800477\000\00000\000\000"
/* offset=1734913 */ "ocr.reads_to_core.remote_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x703004477\000\00000\000\000"
/* offset=1735190 */ "ocr.reads_to_core.remote_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000477\000\00000\000\000"
/* offset=1735467 */ "ocr.reads_to_core.snc_cache.hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808004477\000\00000\000\000"
/* offset=1735877 */ "ocr.reads_to_core.snc_cache.hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000477\000\00000\000\000"
/* offset=1736287 */ "ocr.reads_to_core.snc_cache.hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008004477\000\00000\000\000"
/* offset=1736679 */ "ocr.reads_to_core.snc_cache.hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000477\000\00000\000\000"
/* offset=1737071 */ "ocr.reads_to_core.snc_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708004477\000\00000\000\000"
/* offset=1737416 */ "ocr.reads_to_core.snc_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000477\000\00000\000\000"
/* offset=1737761 */ "ocr.reads_to_core.snc_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800477\000\00000\000\000"
/* offset=1738104 */ "ocr.rfo_to_core.l3_hit_m\000\000cache\000Counts demand reads for ownership (RFO), hardware prefetch RFOs (which bring data to L2), and software prefetches for exclusive ownership (PREFETCHW) that hit to a (M)odified cacheline in the L3 or snoop filter\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1F80040022\000\00000\000\000"
/* offset=1738412 */ "ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000"
/* offset=1738564 */ "ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000"
/* offset=1738716 */ "ocr.streaming_wr.any_response\000cpu_atom\000other\000Counts streaming stores that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000"
/* offset=1738893 */ "ocr.streaming_wr.any_response\000cpu_core\000other\000Counts streaming stores that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000"
/* offset=1739070 */ "ocr.streaming_wr.dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000"
/* offset=1739218 */ "ocr.streaming_wr.l3_hit.any\000\000cache\000Counts streaming stores that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0800\000\00000\000\000"
/* offset=1739403 */ "ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x80080800\000\00000\000\000"
/* offset=1739602 */ "ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080800\000\00000\000\000"
/* offset=1739801 */ "ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0800\000\00000\000\000"
/* offset=1739956 */ "ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that missed the local socket's L1, L2, and L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x94000800\000\00000\000\000"
/* offset=1740129 */ "ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that missed the local socket's L1, L2, and L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x94000800\000\00000\000\000"
/* offset=1740302 */ "ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00800\000\00000\000\000"
/* offset=1740462 */ "ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000"
/* offset=1740623 */ "ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000"
/* offset=1740790 */ "ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x84000800\000\00000\000\000"
/* offset=1741017 */ "ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000800\000\00000\000\000"
/* offset=1741244 */ "ocr.streaming_wr.local_dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000"
/* offset=1741398 */ "ocr.uc_rd.any_response\000\000other\000Counts uncached memory reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100000010000\000\00000\000\000"
/* offset=1741555 */ "ocr.uc_rd.dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000"
/* offset=1741700 */ "ocr.uc_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004003C0000\000\00000\000\000"
/* offset=1741937 */ "ocr.uc_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008003C0000\000\00000\000\000"
/* offset=1742186 */ "ocr.uc_rd.l3_hit.snoop_hitm\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010003C0000\000\00000\000\000"
/* offset=1742423 */ "ocr.uc_rd.l3_hit.snoop_miss\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002003C0000\000\00000\000\000"
/* offset=1742633 */ "ocr.uc_rd.l3_hit.snoop_not_needed\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001003C0000\000\00000\000\000"
/* offset=1742854 */ "ocr.uc_rd.l3_hit\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x101F803C0000\000\00000\000\000"
/* offset=1743009 */ "ocr.uc_rd.l3_miss\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000"
/* offset=1743170 */ "ocr.uc_rd.l3_miss_local\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000"
/* offset=1743337 */ "ocr.uc_rd.local_dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000"
/* offset=1743488 */ "ocr.uc_rd.outstanding\000\000other\000Counts uncached memory reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000100000000000\000\00000\000\000"
/* offset=1743735 */ "ocr.uc_wr.any_response\000\000other\000Counts uncached memory writes that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200000010000\000\00000\000\000"
/* offset=1743893 */ "ocr.uc_wr.l3_hit\000\000cache\000Counts uncached memory writes that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x201F803C0000\000\00000\000\000"
/* offset=1744049 */ "ocr.uc_wr.l3_miss\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000"
/* offset=1744211 */ "ocr.uc_wr.l3_miss_local\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000"
/* offset=1744379 */ "ocr.write_estimate.memory\000\000other\000Counts Demand RFOs, ItoM's, PREFECTHW's, Hardware RFO Prefetches to the L1/L2 and Streaming stores that likely resulted in a store to Memory (DRAM or PMM)\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0xFBFF80822\000\00000\000\000"
/* offset=1744631 */ "ocr.write_estimate.memory\000\000other\000Counts Demand RFOs, ItoM's, PREFECTHW's, Hardware RFO Prefetches to the L1/L2 and Streaming stores that likely resulted in a store to Memory (DRAM or PMM)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xFBFF80822\000\00000\000\000"
/* offset=1744883 */ "offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000"
/* offset=1745197 */ "offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Data read requests sent to uncore (demand and prefetch)\000"
/* offset=1745359 */ "offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000This event counts the demand and prefetch data reads. All Core Data Reads include cacheable Demands and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000"
/* offset=1745682 */ "offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000\000"
/* offset=1745789 */ "offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000"
/* offset=1746038 */ "offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000This event counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, and so on\000"
/* offset=1746303 */ "offcore_requests.all_requests\000\000cache\000Counts memory transactions sent to the uncore\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions sent to the uncore including requests initiated by the core, all L3 prefetches, reads resulting from page walks, and snoop responses\000"
/* offset=1746586 */ "offcore_requests.all_requests\000\000cache\000OFFCORE_REQUESTS.ALL_REQUESTS\000event=0x21,period=100003,umask=0x80\000\00000\000\000"
/* offset=1746694 */ "offcore_requests.all_requests\000cpu_core\000cache\000Any memory transaction that reached the SQ. Unit: cpu_core \000event=0x21,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000"
/* offset=1746968 */ "offcore_requests.all_requests\000cpu_core\000cache\000OFFCORE_REQUESTS.ALL_REQUESTS. Unit: cpu_core \000event=0x21,period=100003,umask=0x80\000\00000\000\000"
/* offset=1747101 */ "offcore_requests.any.read\000\000cache\000Offcore read requests\000event=0xb0,period=100000,umask=0x8\000\00000\000\000"
/* offset=1747196 */ "offcore_requests.any.rfo\000\000cache\000Offcore RFO requests\000event=0xb0,period=100000,umask=0x10\000\00000\000\000"
/* offset=1747290 */ "offcore_requests.any\000\000cache\000All offcore requests\000event=0xb0,period=100000,umask=0x80\000\00000\000\000"
/* offset=1747380 */ "offcore_requests.data_rd\000\000cache\000Demand and prefetch data reads\000event=0x21,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000"
/* offset=1747690 */ "offcore_requests.data_rd\000cpu_core\000cache\000Demand and prefetch data reads. Unit: cpu_core \000event=0x21,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000"
/* offset=1748025 */ "offcore_requests.demand.read_code\000\000cache\000Offcore demand code read requests\000event=0xb0,period=100000,umask=0x2\000\00000\000\000"
/* offset=1748140 */ "offcore_requests.demand.read_data\000\000cache\000Offcore demand data read requests\000event=0xb0,period=100000,umask=0x1\000\00000\000\000"
/* offset=1748255 */ "offcore_requests.demand.rfo\000\000cache\000Offcore demand RFO requests\000event=0xb0,period=100000,umask=0x4\000\00000\000\000"
/* offset=1748358 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code read requests\000"
/* offset=1748542 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000This event counts both cacheable and non-cacheable code read requests\000"
/* offset=1748737 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000\000"
/* offset=1748863 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncachaeble code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000"
/* offset=1749028 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000"
/* offset=1749193 */ "offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000\000"
/* offset=1749318 */ "offcore_requests.demand_code_rd\000\000cache\000Counts cacheable and non-cacheable code reads to the core\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code reads to the core\000"
/* offset=1749517 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore  Spec update: HSD78, HSM80\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore  Spec update: HSD78, HSM80\000"
/* offset=1749731 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0x21,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000"
/* offset=1750002 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000"
/* offset=1750273 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore\000"
/* offset=1750433 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000This event counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000"
/* offset=1750715 */ "offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000\000"
/* offset=1750835 */ "offcore_requests.demand_data_rd\000cpu_core\000cache\000Demand Data Read requests sent to uncore. Unit: cpu_core \000event=0x21,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000"
/* offset=1751131 */ "offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000"
/* offset=1751349 */ "offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Demand RFO read requests sent to uncore, including regular RFOs, locks, ItoM\000"
/* offset=1751556 */ "offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000This event counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000"
/* offset=1751785 */ "offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000\000"
/* offset=1751916 */ "offcore_requests.demand_rfo\000cpu_core\000cache\000Demand RFO requests including regular RFOs, locks, ItoM. Unit: cpu_core \000event=0x21,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000"
/* offset=1752159 */ "offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000"
/* offset=1752271 */ "offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0x21,period=100003,umask=0x10\000\00000\000\000"
/* offset=1752416 */ "offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000\000"
/* offset=1752561 */ "offcore_requests.l3_miss_demand_data_rd\000\000memory\000Demand Data Read requests who miss L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000Demand Data Read requests who miss L3 cache\000"
/* offset=1752737 */ "offcore_requests.l3_miss_demand_data_rd\000cpu_core\000memory\000Counts demand data read requests that miss the L3 cache. Unit: cpu_core \000event=0x21,period=100003,umask=0x10\000\00000\000\000"
/* offset=1752907 */ "offcore_requests.uncached_mem\000\000cache\000Offcore uncached memory accesses\000event=0xb0,period=100000,umask=0x20\000\00000\000\000"
/* offset=1753018 */ "offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Cases when offcore requests buffer cannot take more entries for core\000"
/* offset=1753235 */ "offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1753384 */ "offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.Note: Writeback pending FIFO has six entries\000"
/* offset=1753800 */ "offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000This event counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.\nNote: Writeback pending FIFO has six entries\000"
/* offset=1754228 */ "offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1754378 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000For every cycle, increments by the number of outstanding data read requests pending\000event=0x60,period=1000003,umask=0x8\000\00000\000For every cycle, increments by the number of outstanding data read requests pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1754992 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x8\000\00000\000This event counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000"
/* offset=1755531 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000"
/* offset=1755879 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=1000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1756367 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1756855 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles\000"
/* offset=1757135 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1757318 */ "offcore_requests_outstanding.all_data_rd\000\000cache\000This event is deprecated. Refer to new event OFFCORE_REQUESTS_OUTSTANDING.DATA_RD\000event=0x20,period=1000003,umask=0x8\000\00010\000\000"
/* offset=1757489 */ "offcore_requests_outstanding.all_data_rd\000cpu_core\000cache\000This event is deprecated. Refer to new event OFFCORE_REQUESTS_OUTSTANDING.DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,period=1000003,umask=0x8\000\00010\000\000"
/* offset=1757706 */ "offcore_requests_outstanding.any.read\000\000cache\000Outstanding offcore reads\000event=0x60,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1757818 */ "offcore_requests_outstanding.any.read_not_empty\000\000cache\000Cycles offcore reads busy\000event=0x60,cmask=1,period=2000000,umask=0x8\000\00000\000\000"
/* offset=1757948 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000"
/* offset=1758525 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1758782 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1759308 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1759834 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000"
/* offset=1760174 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000"
/* offset=1760397 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles where at least 1 outstanding data read request is pending\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Cycles where at least 1 outstanding data read request is pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1760989 */ "offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000event=0x20,cmask=1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1761143 */ "offcore_requests_outstanding.cycles_with_data_rd\000cpu_core\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,cmask=1,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1761343 */ "offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1761845 */ "offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with outstanding code read requests pending\000event=0x60,cmask=1,period=1000003,umask=0x2\000\00000\000Cycles with outstanding code read requests pending.  Code Read requests include both cacheable and non-cacheable Code Reads.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1762279 */ "offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000"
/* offset=1762576 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)  Spec update: BDM76\000"
/* offset=1763101 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1763371 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)\000"
/* offset=1763845 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000"
/* offset=1764176 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1764398 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles where at least 1 outstanding demand data read request is pending\000event=0x20,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1764582 */ "offcore_requests_outstanding.cycles_with_demand_data_rd\000cpu_core\000cache\000Cycles where at least 1 outstanding demand data read request is pending. Unit: cpu_core \000event=0x20,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1764791 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles where at least 1 outstanding Demand RFO request is pending\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Cycles where at least 1 outstanding Demand RFO request is pending.   RFOs are initiated by a core as part of a data store operation.  Demand RFO requests include RFOs, locks, and ItoM transactions.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1765309 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1765815 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1766321 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO\000event=0x20,cmask=1,period=1000003,umask=0x4\000\00000\000\000"
/* offset=1766481 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000"
/* offset=1767037 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1767278 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000"
/* offset=1767583 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1767790 */ "offcore_requests_outstanding.cycles_with_demand_rfo\000cpu_core\000cache\000For every cycle where the core is waiting on at least 1 outstanding Demand RFO request, increments by 1. Unit: cpu_core \000event=0x20,cmask=1,period=1000003,umask=0x4\000\00000\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO\000"
/* offset=1768078 */ "offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles where at least one demand data read request known to have missed the L3 cache is pending\000event=0x60,cmask=1,period=1000003,umask=0x10\000\00000\000Cycles where at least one demand data read request known to have missed the L3 cache is pending.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000"
/* offset=1768551 */ "offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles with at least 1 Demand Data Read requests who miss L3 cache in the superQ\000event=0x60,cmask=1,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1768754 */ "offcore_requests_outstanding.data_rd\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.DATA_RD\000event=0x20,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1768876 */ "offcore_requests_outstanding.data_rd\000cpu_core\000cache\000OFFCORE_REQUESTS_OUTSTANDING.DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,period=1000003,umask=0x8\000\00000\000\000"
/* offset=1769044 */ "offcore_requests_outstanding.demand.read_code\000\000cache\000Outstanding offcore demand code reads\000event=0x60,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1769176 */ "offcore_requests_outstanding.demand.read_code_not_empty\000\000cache\000Cycles offcore demand code read busy\000event=0x60,cmask=1,period=2000000,umask=0x2\000\00000\000\000"
/* offset=1769325 */ "offcore_requests_outstanding.demand.read_data\000\000cache\000Outstanding offcore demand data reads\000event=0x60,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1769457 */ "offcore_requests_outstanding.demand.read_data_not_empty\000\000cache\000Cycles offcore demand data read busy\000event=0x60,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=1769606 */ "offcore_requests_outstanding.demand.rfo\000\000cache\000Outstanding offcore demand RFOs\000event=0x60,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1769726 */ "offcore_requests_outstanding.demand.rfo_not_empty\000\000cache\000Cycles offcore demand RFOs busy\000event=0x60,cmask=1,period=2000000,umask=0x4\000\00000\000\000"
/* offset=1769864 */ "offcore_requests_outstanding.demand_code_rd\000\000cache\000For every cycle, increments by the number of outstanding code read requests pending\000event=0x60,period=1000003,umask=0x2\000\00000\000For every cycle, increments by the number of outstanding code read requests pending.  Code Read requests include both cacheable and non-cacheable Code Reads.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1770345 */ "offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1770828 */ "offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,period=2000003,umask=0x2\000\00000\000This event counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000"
/* offset=1771356 */ "offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand code Read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000"
/* offset=1771703 */ "offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand Code Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000"
/* offset=1771982 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Demand Data Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x1\000\00000\000Counts the number of off-core outstanding Demand Data Read transactions every cycle. A transaction is considered to be in the Off-core outstanding state between L2 cache miss and data-return to the core\000"
/* offset=1772346 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x20,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1772768 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x60,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1773190 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,period=2000003,umask=0x1\000\00000\000This event counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.\nNote: A prefetch promoted to Demand is counted from the promotion point  Spec update: BDM76\000"
/* offset=1773759 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding demand data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000"
/* offset=1774107 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.Note: A prefetch promoted to Demand is counted from the promotion point\000"
/* offset=1774624 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding Demand Data Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000"
/* offset=1774876 */ "offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1775034 */ "offcore_requests_outstanding.demand_data_rd\000cpu_core\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending. Unit: cpu_core \000event=0x20,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000"
/* offset=1775481 */ "offcore_requests_outstanding.demand_data_rd_c6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1775673 */ "offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1775887 */ "offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1776129 */ "offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000"
/* offset=1776411 */ "offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000"
/* offset=1776605 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000"
/* offset=1777120 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000"
/* offset=1777442 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles\000"
/* offset=1777696 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000\000"
/* offset=1777863 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000"
/* offset=1778347 */ "offcore_requests_outstanding.demand_rfo\000\000cache\000Store Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x4\000\00000\000Counts the number of off-core outstanding read-for-ownership (RFO) store transactions every cycle. An RFO transaction is considered to be in the Off-core outstanding state between L2 cache miss and transaction completion\000"
/* offset=1778719 */ "offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000Counts number of Offcore outstanding Demand Data Read requests that miss L3 cache in the superQ every cycle\000event=0x60,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1778929 */ "offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache\000event=0x20,period=2000003,umask=0x10\000\00000\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known by the requesting core to have missed the L3 cache\000"
/* offset=1779457 */ "offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000This event is deprecated\000event=0x60,period=2000003,umask=0x10\000\00010\000\000"
/* offset=1779584 */ "offcore_requests_outstanding.l3_miss_demand_data_rd\000cpu_core\000memory\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache. Unit: cpu_core \000event=0x20,period=2000003,umask=0x10\000\00000\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known by the requesting core to have missed the L3 cache\000"
/* offset=1780137 */ "offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles where the core is waiting on at least 6 outstanding demand data read requests known to have missed the L3 cache\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000Cycles where the core is waiting on at least 6 outstanding demand data read requests known to have missed the L3 cache.  Note that this event does not capture all elapsed cycles while the requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000"
/* offset=1780659 */ "offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles with at least 6 Demand Data Read requests that miss L3 cache in the superQ\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000\000"
/* offset=1780856 */ "offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000"
/* offset=1780977 */ "offcore_response.all_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0244\000\00000\000\000"
/* offset=1781246 */ "offcore_response.all_code_rd.l3_miss.any_response\000\000memory\000Counts all demand & prefetch code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00244\000\00000\000\000"
/* offset=1781424 */ "offcore_response.all_code_rd.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400244\000\00000\000\000"
/* offset=1781637 */ "offcore_response.all_code_rd.llc_hit.any_response\000\000cache\000Counts all demand & prefetch code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0244\000\00000\000\000"
/* offset=1781819 */ "offcore_response.all_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0244\000\00000\000\000"
/* offset=1782089 */ "offcore_response.all_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0244\000\00000\000\000"
/* offset=1782363 */ "offcore_response.all_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0244\000\00000\000\000"
/* offset=1782670 */ "offcore_response.all_code_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0244\000\00000\000\000"
/* offset=1782904 */ "offcore_response.all_code_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00244\000\00000\000\000"
/* offset=1783083 */ "offcore_response.all_code_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch code reads that miss the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc00244\000\00000\000\000"
/* offset=1783265 */ "offcore_response.all_code_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400244\000\00000\000\000"
/* offset=1783471 */ "offcore_response.all_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400244\000\00000\000\000"
/* offset=1783685 */ "offcore_response.all_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000244\000\00000\000\000"
/* offset=1783899 */ "offcore_response.all_code_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800244\000\00000\000\000"
/* offset=1784119 */ "offcore_response.all_code_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f800244\000\00000\000\000"
/* offset=1784348 */ "offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10091\000\00000\000\000"
/* offset=1784520 */ "offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00000\000\000"
/* offset=1784697 */ "offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000105B3\000\00000\000\000"
/* offset=1784849 */ "offcore_response.all_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00010\000\000"
/* offset=1785032 */ "offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00000\000\000"
/* offset=1785209 */ "offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0091\000\00000\000\000"
/* offset=1785367 */ "offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00010\000\000"
/* offset=1785563 */ "offcore_response.all_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00010\000\000"
/* offset=1785776 */ "offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000"
/* offset=1786045 */ "offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00000\000\000"
/* offset=1786326 */ "offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00010\000\000"
/* offset=1786545 */ "offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000"
/* offset=1786816 */ "offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00000\000\000"
/* offset=1787092 */ "offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00010\000\000"
/* offset=1787300 */ "offcore_response.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00000\000\000"
/* offset=1787609 */ "offcore_response.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00010\000\000"
/* offset=1787816 */ "offcore_response.all_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000"
/* offset=1787980 */ "offcore_response.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00000\000\000"
/* offset=1788161 */ "offcore_response.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0491\000\00010\000\000"
/* offset=1788374 */ "offcore_response.all_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000"
/* offset=1788533 */ "offcore_response.all_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0091\000\00000\000\000"
/* offset=1788691 */ "offcore_response.all_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0491\000\00010\000\000"
/* offset=1788888 */ "offcore_response.all_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0091\000\00000\000\000"
/* offset=1789052 */ "offcore_response.all_data_rd.l3_hit.snoop_none\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0091\000\00000\000\000"
/* offset=1789209 */ "offcore_response.all_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0491\000\00010\000\000"
/* offset=1789405 */ "offcore_response.all_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0091\000\00000\000\000"
/* offset=1789569 */ "offcore_response.all_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080491\000\00010\000\000"
/* offset=1789769 */ "offcore_response.all_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080491\000\00010\000\000"
/* offset=1789986 */ "offcore_response.all_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080491\000\00010\000\000"
/* offset=1790209 */ "offcore_response.all_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080491\000\00010\000\000"
/* offset=1790421 */ "offcore_response.all_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080491\000\00010\000\000"
/* offset=1790632 */ "offcore_response.all_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080491\000\00010\000\000"
/* offset=1790833 */ "offcore_response.all_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080491\000\00010\000\000"
/* offset=1791033 */ "offcore_response.all_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200491\000\00010\000\000"
/* offset=1791233 */ "offcore_response.all_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200491\000\00010\000\000"
/* offset=1791450 */ "offcore_response.all_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200491\000\00010\000\000"
/* offset=1791673 */ "offcore_response.all_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200491\000\00010\000\000"
/* offset=1791885 */ "offcore_response.all_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200491\000\00010\000\000"
/* offset=1792096 */ "offcore_response.all_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200491\000\00010\000\000"
/* offset=1792297 */ "offcore_response.all_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200491\000\00010\000\000"
/* offset=1792497 */ "offcore_response.all_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040491\000\00010\000\000"
/* offset=1792697 */ "offcore_response.all_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040491\000\00010\000\000"
/* offset=1792914 */ "offcore_response.all_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040491\000\00010\000\000"
/* offset=1793137 */ "offcore_response.all_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040491\000\00010\000\000"
/* offset=1793349 */ "offcore_response.all_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040491\000\00010\000\000"
/* offset=1793560 */ "offcore_response.all_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040491\000\00010\000\000"
/* offset=1793761 */ "offcore_response.all_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040491\000\00010\000\000"
/* offset=1793961 */ "offcore_response.all_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100491\000\00010\000\000"
/* offset=1794161 */ "offcore_response.all_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100491\000\00010\000\000"
/* offset=1794378 */ "offcore_response.all_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100491\000\00010\000\000"
/* offset=1794601 */ "offcore_response.all_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100491\000\00010\000\000"
/* offset=1794813 */ "offcore_response.all_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100491\000\00010\000\000"
/* offset=1795024 */ "offcore_response.all_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100491\000\00010\000\000"
/* offset=1795225 */ "offcore_response.all_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100491\000\00010\000\000"
/* offset=1795425 */ "offcore_response.all_data_rd.l3_miss.any_response\000\000memory\000Counts all demand & prefetch data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00091\000\00000\000\000"
/* offset=1795603 */ "offcore_response.all_data_rd.l3_miss.any_snoop\000\000memory\000Counts all demand & prefetch data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00000\000\000"
/* offset=1795783 */ "offcore_response.all_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00010\000\000"
/* offset=1795982 */ "offcore_response.all_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000491\000\00010\000\000"
/* offset=1796198 */ "offcore_response.all_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000491\000\00010\000\000"
/* offset=1796420 */ "offcore_response.all_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000491\000\00010\000\000"
/* offset=1796631 */ "offcore_response.all_data_rd.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400091\000\00000\000\000"
/* offset=1796844 */ "offcore_response.all_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000491\000\00010\000\000"
/* offset=1797054 */ "offcore_response.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00000\000\000"
/* offset=1797297 */ "offcore_response.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00010\000\000"
/* offset=1797513 */ "offcore_response.all_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00000\000\000"
/* offset=1797747 */ "offcore_response.all_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00010\000\000"
/* offset=1797950 */ "offcore_response.all_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000091\000\00000\000\000"
/* offset=1798116 */ "offcore_response.all_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000091\000\00000\000\000"
/* offset=1798276 */ "offcore_response.all_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000491\000\00010\000\000"
/* offset=1798476 */ "offcore_response.all_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00491\000\00000\000\000"
/* offset=1798714 */ "offcore_response.all_data_rd.l3_miss.snoop_none\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000091\000\00000\000\000"
/* offset=1798873 */ "offcore_response.all_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000491\000\00010\000\000"
/* offset=1799072 */ "offcore_response.all_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000091\000\00000\000\000"
/* offset=1799238 */ "offcore_response.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000091\000\00000\000\000"
/* offset=1799409 */ "offcore_response.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000491\000\00010\000\000"
/* offset=1799630 */ "offcore_response.all_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000491\000\00010\000\000"
/* offset=1799868 */ "offcore_response.all_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000491\000\00010\000\000"
/* offset=1800112 */ "offcore_response.all_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000491\000\00010\000\000"
/* offset=1800345 */ "offcore_response.all_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000491\000\00010\000\000"
/* offset=1800577 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000091\000\00000\000\000"
/* offset=1800754 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000091\000\00000\000\000"
/* offset=1800926 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000091\000\00000\000\000"
/* offset=1801097 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000491\000\00010\000\000"
/* offset=1801319 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00000\000\000"
/* offset=1801558 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00010\000\000"
/* offset=1801800 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000091\000\00000\000\000"
/* offset=1801976 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000091\000\00000\000\000"
/* offset=1802146 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000491\000\00010\000\000"
/* offset=1802367 */ "offcore_response.all_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000091\000\00000\000\000"
/* offset=1802544 */ "offcore_response.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00000\000\000"
/* offset=1802785 */ "offcore_response.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00010\000\000"
/* offset=1803029 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000491\000\00010\000\000"
/* offset=1803262 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000491\000\00010\000\000"
/* offset=1803512 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000491\000\00010\000\000"
/* offset=1803768 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000491\000\00010\000\000"
/* offset=1804013 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000491\000\00010\000\000"
/* offset=1804257 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000491\000\00010\000\000"
/* offset=1804491 */ "offcore_response.all_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000491\000\00010\000\000"
/* offset=1804724 */ "offcore_response.all_data_rd.llc_hit.any_response\000\000cache\000Counts all demand & prefetch data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0091\000\00000\000\000"
/* offset=1804906 */ "offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000"
/* offset=1805176 */ "offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0091\000\00000\000\000"
/* offset=1805448 */ "offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000"
/* offset=1805720 */ "offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0091\000\00000\000\000"
/* offset=1805994 */ "offcore_response.all_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0091\000\00000\000\000"
/* offset=1806301 */ "offcore_response.all_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0091\000\00000\000\000"
/* offset=1806525 */ "offcore_response.all_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0091\000\00000\000\000"
/* offset=1806759 */ "offcore_response.all_data_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00091\000\00000\000\000"
/* offset=1806938 */ "offcore_response.all_data_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch data reads that hits the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20091\000\00000\000\000"
/* offset=1807120 */ "offcore_response.all_data_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400091\000\00000\000\000"
/* offset=1807326 */ "offcore_response.all_data_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400091\000\00000\000\000"
/* offset=1807540 */ "offcore_response.all_data_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000091\000\00000\000\000"
/* offset=1807754 */ "offcore_response.all_data_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63BC00091\000\00000\000\000"
/* offset=1807970 */ "offcore_response.all_data_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63F800091\000\00000\000\000"
/* offset=1808186 */ "offcore_response.all_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00091\000\00000\000\000"
/* offset=1808425 */ "offcore_response.all_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87FC00091\000\00000\000\000"
/* offset=1808664 */ "offcore_response.all_data_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00091\000\00000\000\000"
/* offset=1808894 */ "offcore_response.all_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400491\000\00010\000\000"
/* offset=1809112 */ "offcore_response.all_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400491\000\00010\000\000"
/* offset=1809330 */ "offcore_response.all_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400491\000\00010\000\000"
/* offset=1809561 */ "offcore_response.all_data_rd.supplier_none.any_snoop\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020091\000\00000\000\000"
/* offset=1809726 */ "offcore_response.all_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020491\000\00010\000\000"
/* offset=1809936 */ "offcore_response.all_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020491\000\00010\000\000"
/* offset=1810163 */ "offcore_response.all_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020491\000\00010\000\000"
/* offset=1810396 */ "offcore_response.all_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020491\000\00010\000\000"
/* offset=1810618 */ "offcore_response.all_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020491\000\00010\000\000"
/* offset=1810839 */ "offcore_response.all_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020091\000\00000\000\000"
/* offset=1811010 */ "offcore_response.all_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020091\000\00000\000\000"
/* offset=1811176 */ "offcore_response.all_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020091\000\00000\000\000"
/* offset=1811341 */ "offcore_response.all_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020491\000\00010\000\000"
/* offset=1811552 */ "offcore_response.all_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020091\000\00000\000\000"
/* offset=1811723 */ "offcore_response.all_data_rd.supplier_none.snoop_none\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020091\000\00000\000\000"
/* offset=1811887 */ "offcore_response.all_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020491\000\00010\000\000"
/* offset=1812097 */ "offcore_response.all_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020091\000\00000\000\000"
/* offset=1812268 */ "offcore_response.all_demand_mlc_pref_reads.llc_miss.any_response\000\000memory\000This event counts all LLC misses for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC20077\000\00000\000\000"
/* offset=1812501 */ "offcore_response.all_demand_mlc_pref_reads.llc_miss.local_dram\000\000memory\000Counts all local dram accesses for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400077\000\00000\000\000"
/* offset=1812729 */ "offcore_response.all_demand_mlc_pref_reads.llc_miss.remote_hitm_hit_forward\000\000memory\000This event counts all remote cache-to-cache transfers (includes HITM and HIT-Forward) for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x187FC20077\000\00000\000\000"
/* offset=1813026 */ "offcore_response.all_pf_code_rd.any_response\000\000cache\000Counts all prefetch code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10240\000\00000\000\000"
/* offset=1813192 */ "offcore_response.all_pf_code_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0240\000\00000\000\000"
/* offset=1813344 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0240\000\00000\000\000"
/* offset=1813502 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0240\000\00000\000\000"
/* offset=1813655 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0240\000\00000\000\000"
/* offset=1813807 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0240\000\00000\000\000"
/* offset=1813965 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0240\000\00000\000\000"
/* offset=1814116 */ "offcore_response.all_pf_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0240\000\00000\000\000"
/* offset=1814274 */ "offcore_response.all_pf_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000240\000\00000\000\000"
/* offset=1814434 */ "offcore_response.all_pf_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000240\000\00000\000\000"
/* offset=1814588 */ "offcore_response.all_pf_code_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000240\000\00000\000\000"
/* offset=1814741 */ "offcore_response.all_pf_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000240\000\00000\000\000"
/* offset=1814901 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000240\000\00000\000\000"
/* offset=1815066 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000240\000\00000\000\000"
/* offset=1815237 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000240\000\00000\000\000"
/* offset=1815403 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000240\000\00000\000\000"
/* offset=1815568 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000240\000\00000\000\000"
/* offset=1815738 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000240\000\00000\000\000"
/* offset=1815902 */ "offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000240\000\00000\000\000"
/* offset=1816073 */ "offcore_response.all_pf_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0240\000\00000\000\000"
/* offset=1816249 */ "offcore_response.all_pf_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0240\000\00000\000\000"
/* offset=1816515 */ "offcore_response.all_pf_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0240\000\00000\000\000"
/* offset=1816783 */ "offcore_response.all_pf_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0240\000\00000\000\000"
/* offset=1817084 */ "offcore_response.all_pf_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0240\000\00000\000\000"
/* offset=1817312 */ "offcore_response.all_pf_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400240\000\00000\000\000"
/* offset=1817512 */ "offcore_response.all_pf_code_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020240\000\00000\000\000"
/* offset=1817671 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020240\000\00000\000\000"
/* offset=1817836 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020240\000\00000\000\000"
/* offset=1817996 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020240\000\00000\000\000"
/* offset=1818155 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020240\000\00000\000\000"
/* offset=1818320 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020240\000\00000\000\000"
/* offset=1818478 */ "offcore_response.all_pf_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020240\000\00000\000\000"
/* offset=1818643 */ "offcore_response.all_pf_data_rd.any_response\000\000cache\000Counts all prefetch data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10090\000\00000\000\000"
/* offset=1818809 */ "offcore_response.all_pf_data_rd.any_response\000\000cache\000Counts all prefetch data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00000\000\000"
/* offset=1818980 */ "offcore_response.all_pf_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00010\000\000"
/* offset=1819169 */ "offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00000\000\000"
/* offset=1819340 */ "offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0090\000\00000\000\000"
/* offset=1819492 */ "offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00010\000\000"
/* offset=1819694 */ "offcore_response.all_pf_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00010\000\000"
/* offset=1819913 */ "offcore_response.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00000\000\000"
/* offset=1820188 */ "offcore_response.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00010\000\000"
/* offset=1820413 */ "offcore_response.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00000\000\000"
/* offset=1820683 */ "offcore_response.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00010\000\000"
/* offset=1820897 */ "offcore_response.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00000\000\000"
/* offset=1821200 */ "offcore_response.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00010\000\000"
/* offset=1821413 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0090\000\00000\000\000"
/* offset=1821571 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00000\000\000"
/* offset=1821758 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0490\000\00010\000\000"
/* offset=1821977 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0090\000\00000\000\000"
/* offset=1822130 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0090\000\00000\000\000"
/* offset=1822282 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0490\000\00010\000\000"
/* offset=1822485 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0090\000\00000\000\000"
/* offset=1822643 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0090\000\00000\000\000"
/* offset=1822794 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0490\000\00010\000\000"
/* offset=1822996 */ "offcore_response.all_pf_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0090\000\00000\000\000"
/* offset=1823154 */ "offcore_response.all_pf_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080490\000\00010\000\000"
/* offset=1823360 */ "offcore_response.all_pf_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080490\000\00010\000\000"
/* offset=1823583 */ "offcore_response.all_pf_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080490\000\00010\000\000"
/* offset=1823812 */ "offcore_response.all_pf_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080490\000\00010\000\000"
/* offset=1824030 */ "offcore_response.all_pf_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080490\000\00010\000\000"
/* offset=1824247 */ "offcore_response.all_pf_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080490\000\00010\000\000"
/* offset=1824454 */ "offcore_response.all_pf_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080490\000\00010\000\000"
/* offset=1824660 */ "offcore_response.all_pf_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200490\000\00010\000\000"
/* offset=1824866 */ "offcore_response.all_pf_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200490\000\00010\000\000"
/* offset=1825089 */ "offcore_response.all_pf_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200490\000\00010\000\000"
/* offset=1825318 */ "offcore_response.all_pf_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200490\000\00010\000\000"
/* offset=1825536 */ "offcore_response.all_pf_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200490\000\00010\000\000"
/* offset=1825753 */ "offcore_response.all_pf_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200490\000\00010\000\000"
/* offset=1825960 */ "offcore_response.all_pf_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200490\000\00010\000\000"
/* offset=1826166 */ "offcore_response.all_pf_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040490\000\00010\000\000"
/* offset=1826372 */ "offcore_response.all_pf_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040490\000\00010\000\000"
/* offset=1826595 */ "offcore_response.all_pf_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040490\000\00010\000\000"
/* offset=1826824 */ "offcore_response.all_pf_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040490\000\00010\000\000"
/* offset=1827042 */ "offcore_response.all_pf_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040490\000\00010\000\000"
/* offset=1827259 */ "offcore_response.all_pf_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040490\000\00010\000\000"
/* offset=1827466 */ "offcore_response.all_pf_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040490\000\00010\000\000"
/* offset=1827672 */ "offcore_response.all_pf_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100490\000\00010\000\000"
/* offset=1827878 */ "offcore_response.all_pf_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100490\000\00010\000\000"
/* offset=1828101 */ "offcore_response.all_pf_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100490\000\00010\000\000"
/* offset=1828330 */ "offcore_response.all_pf_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100490\000\00010\000\000"
/* offset=1828548 */ "offcore_response.all_pf_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100490\000\00010\000\000"
/* offset=1828765 */ "offcore_response.all_pf_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100490\000\00010\000\000"
/* offset=1828972 */ "offcore_response.all_pf_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100490\000\00010\000\000"
/* offset=1829178 */ "offcore_response.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00000\000\000"
/* offset=1829352 */ "offcore_response.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00010\000\000"
/* offset=1829557 */ "offcore_response.all_pf_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000490\000\00010\000\000"
/* offset=1829779 */ "offcore_response.all_pf_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000490\000\00010\000\000"
/* offset=1830007 */ "offcore_response.all_pf_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000490\000\00010\000\000"
/* offset=1830224 */ "offcore_response.all_pf_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000490\000\00010\000\000"
/* offset=1830440 */ "offcore_response.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00000\000\000"
/* offset=1830677 */ "offcore_response.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00010\000\000"
/* offset=1830899 */ "offcore_response.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00000\000\000"
/* offset=1831127 */ "offcore_response.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00010\000\000"
/* offset=1831336 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000090\000\00000\000\000"
/* offset=1831496 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000090\000\00000\000\000"
/* offset=1831650 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000490\000\00010\000\000"
/* offset=1831856 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00490\000\00000\000\000"
/* offset=1832088 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000090\000\00000\000\000"
/* offset=1832241 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000490\000\00010\000\000"
/* offset=1832446 */ "offcore_response.all_pf_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000090\000\00000\000\000"
/* offset=1832606 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000090\000\00000\000\000"
/* offset=1832771 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000490\000\00010\000\000"
/* offset=1832998 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000490\000\00010\000\000"
/* offset=1833242 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000490\000\00010\000\000"
/* offset=1833492 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000490\000\00010\000\000"
/* offset=1833731 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000490\000\00010\000\000"
/* offset=1833969 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000090\000\00000\000\000"
/* offset=1834140 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000090\000\00000\000\000"
/* offset=1834306 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000090\000\00000\000\000"
/* offset=1834471 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000490\000\00010\000\000"
/* offset=1834699 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00000\000\000"
/* offset=1834932 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00010\000\000"
/* offset=1835180 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000090\000\00000\000\000"
/* offset=1835350 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000090\000\00000\000\000"
/* offset=1835514 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000490\000\00010\000\000"
/* offset=1835741 */ "offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000090\000\00000\000\000"
/* offset=1835912 */ "offcore_response.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00000\000\000"
/* offset=1836147 */ "offcore_response.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00010\000\000"
/* offset=1836397 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000490\000\00010\000\000"
/* offset=1836636 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000490\000\00010\000\000"
/* offset=1836892 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000490\000\00010\000\000"
/* offset=1837154 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000490\000\00010\000\000"
/* offset=1837405 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000490\000\00010\000\000"
/* offset=1837655 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000490\000\00010\000\000"
/* offset=1837895 */ "offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000490\000\00010\000\000"
/* offset=1838134 */ "offcore_response.all_pf_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0090\000\00000\000\000"
/* offset=1838310 */ "offcore_response.all_pf_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch data reads that hit the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0090\000\00000\000\000"
/* offset=1838483 */ "offcore_response.all_pf_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0090\000\00000\000\000"
/* offset=1838749 */ "offcore_response.all_pf_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0090\000\00000\000\000"
/* offset=1839017 */ "offcore_response.all_pf_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0090\000\00000\000\000"
/* offset=1839318 */ "offcore_response.all_pf_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0090\000\00000\000\000"
/* offset=1839536 */ "offcore_response.all_pf_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0090\000\00000\000\000"
/* offset=1839764 */ "offcore_response.all_pf_data_rd.llc_miss.dram\000\000memory\000Counts all prefetch data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400090\000\00000\000\000"
/* offset=1839964 */ "offcore_response.all_pf_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400490\000\00010\000\000"
/* offset=1840188 */ "offcore_response.all_pf_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400490\000\00010\000\000"
/* offset=1840412 */ "offcore_response.all_pf_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400490\000\00010\000\000"
/* offset=1840649 */ "offcore_response.all_pf_data_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020090\000\00000\000\000"
/* offset=1840808 */ "offcore_response.all_pf_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020490\000\00010\000\000"
/* offset=1841024 */ "offcore_response.all_pf_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020490\000\00010\000\000"
/* offset=1841257 */ "offcore_response.all_pf_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020490\000\00010\000\000"
/* offset=1841496 */ "offcore_response.all_pf_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020490\000\00010\000\000"
/* offset=1841724 */ "offcore_response.all_pf_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020490\000\00010\000\000"
/* offset=1841951 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020090\000\00000\000\000"
/* offset=1842116 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020090\000\00000\000\000"
/* offset=1842276 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020090\000\00000\000\000"
/* offset=1842435 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020490\000\00010\000\000"
/* offset=1842652 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020090\000\00000\000\000"
/* offset=1842817 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020090\000\00000\000\000"
/* offset=1842975 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020490\000\00010\000\000"
/* offset=1843191 */ "offcore_response.all_pf_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020090\000\00000\000\000"
/* offset=1843356 */ "offcore_response.all_pf_rfo.any_response\000\000cache\000Counts prefetch RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000"
/* offset=1843508 */ "offcore_response.all_pf_rfo.any_response\000\000cache\000Counts prefetch RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000"
/* offset=1843665 */ "offcore_response.all_pf_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00010\000\000"
/* offset=1843846 */ "offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000Counts prefetch RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000"
/* offset=1844003 */ "offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000"
/* offset=1844141 */ "offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00010\000\000"
/* offset=1844335 */ "offcore_response.all_pf_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00010\000\000"
/* offset=1844546 */ "offcore_response.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000"
/* offset=1844807 */ "offcore_response.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00010\000\000"
/* offset=1845024 */ "offcore_response.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000Counts prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000"
/* offset=1845280 */ "offcore_response.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00010\000\000"
/* offset=1845486 */ "offcore_response.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000"
/* offset=1845775 */ "offcore_response.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00010\000\000"
/* offset=1845980 */ "offcore_response.all_pf_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000"
/* offset=1846124 */ "offcore_response.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00000\000\000"
/* offset=1846303 */ "offcore_response.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0120\000\00010\000\000"
/* offset=1846514 */ "offcore_response.all_pf_rfo.l3_hit.snoop_hitm\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000"
/* offset=1846653 */ "offcore_response.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00000\000\000"
/* offset=1846791 */ "offcore_response.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00010\000\000"
/* offset=1846986 */ "offcore_response.all_pf_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0120\000\00000\000\000"
/* offset=1847130 */ "offcore_response.all_pf_rfo.l3_hit.snoop_none\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00000\000\000"
/* offset=1847267 */ "offcore_response.all_pf_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00010\000\000"
/* offset=1847461 */ "offcore_response.all_pf_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000"
/* offset=1847605 */ "offcore_response.all_pf_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080120\000\00010\000\000"
/* offset=1847803 */ "offcore_response.all_pf_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080120\000\00010\000\000"
/* offset=1848018 */ "offcore_response.all_pf_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080120\000\00010\000\000"
/* offset=1848239 */ "offcore_response.all_pf_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080120\000\00010\000\000"
/* offset=1848449 */ "offcore_response.all_pf_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080120\000\00010\000\000"
/* offset=1848658 */ "offcore_response.all_pf_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080120\000\00010\000\000"
/* offset=1848857 */ "offcore_response.all_pf_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080120\000\00010\000\000"
/* offset=1849055 */ "offcore_response.all_pf_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200120\000\00010\000\000"
/* offset=1849253 */ "offcore_response.all_pf_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200120\000\00010\000\000"
/* offset=1849468 */ "offcore_response.all_pf_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200120\000\00010\000\000"
/* offset=1849689 */ "offcore_response.all_pf_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200120\000\00010\000\000"
/* offset=1849899 */ "offcore_response.all_pf_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200120\000\00010\000\000"
/* offset=1850108 */ "offcore_response.all_pf_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200120\000\00010\000\000"
/* offset=1850307 */ "offcore_response.all_pf_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200120\000\00010\000\000"
/* offset=1850505 */ "offcore_response.all_pf_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040120\000\00010\000\000"
/* offset=1850703 */ "offcore_response.all_pf_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040120\000\00010\000\000"
/* offset=1850918 */ "offcore_response.all_pf_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040120\000\00010\000\000"
/* offset=1851139 */ "offcore_response.all_pf_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040120\000\00010\000\000"
/* offset=1851349 */ "offcore_response.all_pf_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040120\000\00010\000\000"
/* offset=1851558 */ "offcore_response.all_pf_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040120\000\00010\000\000"
/* offset=1851757 */ "offcore_response.all_pf_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040120\000\00010\000\000"
/* offset=1851955 */ "offcore_response.all_pf_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100120\000\00010\000\000"
/* offset=1852153 */ "offcore_response.all_pf_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100120\000\00010\000\000"
/* offset=1852368 */ "offcore_response.all_pf_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100120\000\00010\000\000"
/* offset=1852589 */ "offcore_response.all_pf_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100120\000\00010\000\000"
/* offset=1852799 */ "offcore_response.all_pf_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100120\000\00010\000\000"
/* offset=1853008 */ "offcore_response.all_pf_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100120\000\00010\000\000"
/* offset=1853207 */ "offcore_response.all_pf_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100120\000\00010\000\000"
/* offset=1853405 */ "offcore_response.all_pf_rfo.l3_miss.any_snoop\000\000memory\000Counts prefetch RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00000\000\000"
/* offset=1853565 */ "offcore_response.all_pf_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00010\000\000"
/* offset=1853762 */ "offcore_response.all_pf_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000120\000\00010\000\000"
/* offset=1853976 */ "offcore_response.all_pf_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00010\000\000"
/* offset=1854196 */ "offcore_response.all_pf_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000120\000\00010\000\000"
/* offset=1854405 */ "offcore_response.all_pf_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00010\000\000"
/* offset=1854613 */ "offcore_response.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00000\000\000"
/* offset=1854836 */ "offcore_response.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00010\000\000"
/* offset=1855050 */ "offcore_response.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000Counts prefetch RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00000\000\000"
/* offset=1855264 */ "offcore_response.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00010\000\000"
/* offset=1855465 */ "offcore_response.all_pf_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00000\000\000"
/* offset=1855611 */ "offcore_response.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00000\000\000"
/* offset=1855751 */ "offcore_response.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00010\000\000"
/* offset=1855949 */ "offcore_response.all_pf_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00120\000\00000\000\000"
/* offset=1856167 */ "offcore_response.all_pf_rfo.l3_miss.snoop_none\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00000\000\000"
/* offset=1856306 */ "offcore_response.all_pf_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00010\000\000"
/* offset=1856503 */ "offcore_response.all_pf_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00000\000\000"
/* offset=1856649 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00000\000\000"
/* offset=1856800 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00010\000\000"
/* offset=1857019 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000120\000\00010\000\000"
/* offset=1857255 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00010\000\000"
/* offset=1857497 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00010\000\000"
/* offset=1857728 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00010\000\000"
/* offset=1857958 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00000\000\000"
/* offset=1858115 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00000\000\000"
/* offset=1858267 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00000\000\000"
/* offset=1858418 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00010\000\000"
/* offset=1858638 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00000\000\000"
/* offset=1858857 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00010\000\000"
/* offset=1859097 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000120\000\00000\000\000"
/* offset=1859253 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00000\000\000"
/* offset=1859403 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00010\000\000"
/* offset=1859622 */ "offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00000\000\000"
/* offset=1859779 */ "offcore_response.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00000\000\000"
/* offset=1860000 */ "offcore_response.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00010\000\000"
/* offset=1860242 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000120\000\00010\000\000"
/* offset=1860473 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000120\000\00010\000\000"
/* offset=1860721 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000120\000\00010\000\000"
/* offset=1860975 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000120\000\00010\000\000"
/* offset=1861218 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000120\000\00010\000\000"
/* offset=1861460 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000120\000\00010\000\000"
/* offset=1861692 */ "offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000120\000\00010\000\000"
/* offset=1861923 */ "offcore_response.all_pf_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0120\000\00000\000\000"
/* offset=1862089 */ "offcore_response.all_pf_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0120\000\00000\000\000"
/* offset=1862345 */ "offcore_response.all_pf_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0120\000\00000\000\000"
/* offset=1862603 */ "offcore_response.all_pf_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0120\000\00000\000\000"
/* offset=1862894 */ "offcore_response.all_pf_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0120\000\00000\000\000"
/* offset=1863112 */ "offcore_response.all_pf_rfo.llc_miss.dram\000\000memory\000Counts all prefetch RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400120\000\00000\000\000"
/* offset=1863302 */ "offcore_response.all_pf_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400120\000\00010\000\000"
/* offset=1863518 */ "offcore_response.all_pf_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400120\000\00010\000\000"
/* offset=1863734 */ "offcore_response.all_pf_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400120\000\00010\000\000"
/* offset=1863963 */ "offcore_response.all_pf_rfo.supplier_none.any_snoop\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00000\000\000"
/* offset=1864108 */ "offcore_response.all_pf_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00010\000\000"
/* offset=1864316 */ "offcore_response.all_pf_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020120\000\00010\000\000"
/* offset=1864541 */ "offcore_response.all_pf_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00010\000\000"
/* offset=1864772 */ "offcore_response.all_pf_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00010\000\000"
/* offset=1864992 */ "offcore_response.all_pf_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00010\000\000"
/* offset=1865211 */ "offcore_response.all_pf_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00000\000\000"
/* offset=1865362 */ "offcore_response.all_pf_rfo.supplier_none.snoop_hitm\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00000\000\000"
/* offset=1865508 */ "offcore_response.all_pf_rfo.supplier_none.snoop_miss\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00000\000\000"
/* offset=1865653 */ "offcore_response.all_pf_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00010\000\000"
/* offset=1865862 */ "offcore_response.all_pf_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020120\000\00000\000\000"
/* offset=1866013 */ "offcore_response.all_pf_rfo.supplier_none.snoop_none\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00000\000\000"
/* offset=1866157 */ "offcore_response.all_pf_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00010\000\000"
/* offset=1866365 */ "offcore_response.all_pf_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00000\000\000"
/* offset=1866516 */ "offcore_response.all_reads.any_response\000\000cache\000Counts all data/code/rfo references (demand & prefetch) \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000107F7\000\00000\000\000"
/* offset=1866683 */ "offcore_response.all_reads.any_response\000\000cache\000Counts all data/code/rfo references (demand & prefetch)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000107F7\000\00000\000\000"
/* offset=1866849 */ "offcore_response.all_reads.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107F7\000\00010\000\000"
/* offset=1867028 */ "offcore_response.all_reads.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C07F7\000\00010\000\000"
/* offset=1867220 */ "offcore_response.all_reads.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C07F7\000\00010\000\000"
/* offset=1867429 */ "offcore_response.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00010\000\000"
/* offset=1867644 */ "offcore_response.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000"
/* offset=1867871 */ "offcore_response.all_reads.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00010\000\000"
/* offset=1868075 */ "offcore_response.all_reads.l3_hit.hitm_other_core\000\000cache\000hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000"
/* offset=1868304 */ "offcore_response.all_reads.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C07F7\000\00010\000\000"
/* offset=1868507 */ "offcore_response.all_reads.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C07F7\000\00010\000\000"
/* offset=1868716 */ "offcore_response.all_reads.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C07F7\000\00010\000\000"
/* offset=1868909 */ "offcore_response.all_reads.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C07F7\000\00010\000\000"
/* offset=1869101 */ "offcore_response.all_reads.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800807F7\000\00010\000\000"
/* offset=1869297 */ "offcore_response.all_reads.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000807F7\000\00010\000\000"
/* offset=1869510 */ "offcore_response.all_reads.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000807F7\000\00010\000\000"
/* offset=1869729 */ "offcore_response.all_reads.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000807F7\000\00010\000\000"
/* offset=1869937 */ "offcore_response.all_reads.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000807F7\000\00010\000\000"
/* offset=1870144 */ "offcore_response.all_reads.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000807F7\000\00010\000\000"
/* offset=1870341 */ "offcore_response.all_reads.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800807F7\000\00010\000\000"
/* offset=1870537 */ "offcore_response.all_reads.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F802007F7\000\00010\000\000"
/* offset=1870733 */ "offcore_response.all_reads.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8002007F7\000\00010\000\000"
/* offset=1870946 */ "offcore_response.all_reads.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4002007F7\000\00010\000\000"
/* offset=1871165 */ "offcore_response.all_reads.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002007F7\000\00010\000\000"
/* offset=1871373 */ "offcore_response.all_reads.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002007F7\000\00010\000\000"
/* offset=1871580 */ "offcore_response.all_reads.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002007F7\000\00010\000\000"
/* offset=1871777 */ "offcore_response.all_reads.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802007F7\000\00010\000\000"
/* offset=1871973 */ "offcore_response.all_reads.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800407F7\000\00010\000\000"
/* offset=1872169 */ "offcore_response.all_reads.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000407F7\000\00010\000\000"
/* offset=1872382 */ "offcore_response.all_reads.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000407F7\000\00010\000\000"
/* offset=1872601 */ "offcore_response.all_reads.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000407F7\000\00010\000\000"
/* offset=1872809 */ "offcore_response.all_reads.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000407F7\000\00010\000\000"
/* offset=1873016 */ "offcore_response.all_reads.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000407F7\000\00010\000\000"
/* offset=1873213 */ "offcore_response.all_reads.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800407F7\000\00010\000\000"
/* offset=1873409 */ "offcore_response.all_reads.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F801007F7\000\00010\000\000"
/* offset=1873605 */ "offcore_response.all_reads.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8001007F7\000\00010\000\000"
/* offset=1873818 */ "offcore_response.all_reads.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001007F7\000\00010\000\000"
/* offset=1874037 */ "offcore_response.all_reads.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001007F7\000\00010\000\000"
/* offset=1874245 */ "offcore_response.all_reads.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001007F7\000\00010\000\000"
/* offset=1874452 */ "offcore_response.all_reads.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001007F7\000\00010\000\000"
/* offset=1874649 */ "offcore_response.all_reads.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801007F7\000\00010\000\000"
/* offset=1874845 */ "offcore_response.all_reads.l3_miss.any_response\000\000memory\000miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC007F7\000\00000\000\000"
/* offset=1874981 */ "offcore_response.all_reads.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC0007F7\000\00010\000\000"
/* offset=1875176 */ "offcore_response.all_reads.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C0007F7\000\00010\000\000"
/* offset=1875388 */ "offcore_response.all_reads.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C0007F7\000\00010\000\000"
/* offset=1875606 */ "offcore_response.all_reads.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C0007F7\000\00010\000\000"
/* offset=1875813 */ "offcore_response.all_reads.l3_miss.local_dram\000\000memory\000miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00000\000\000"
/* offset=1875984 */ "offcore_response.all_reads.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C0007F7\000\00010\000\000"
/* offset=1876190 */ "offcore_response.all_reads.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00010\000\000"
/* offset=1876402 */ "offcore_response.all_reads.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00010\000\000"
/* offset=1876601 */ "offcore_response.all_reads.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C0007F7\000\00010\000\000"
/* offset=1876797 */ "offcore_response.all_reads.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC0007F7\000\00010\000\000"
/* offset=1876992 */ "offcore_response.all_reads.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F840007F7\000\00010\000\000"
/* offset=1877209 */ "offcore_response.all_reads.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8040007F7\000\00010\000\000"
/* offset=1877443 */ "offcore_response.all_reads.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4040007F7\000\00010\000\000"
/* offset=1877683 */ "offcore_response.all_reads.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040007F7\000\00010\000\000"
/* offset=1877912 */ "offcore_response.all_reads.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1040007F7\000\00010\000\000"
/* offset=1878140 */ "offcore_response.all_reads.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2040007F7\000\00010\000\000"
/* offset=1878358 */ "offcore_response.all_reads.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00010\000\000"
/* offset=1878596 */ "offcore_response.all_reads.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x840007F7\000\00010\000\000"
/* offset=1878813 */ "offcore_response.all_reads.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B8007F7\000\00010\000\000"
/* offset=1879053 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F900007F7\000\00010\000\000"
/* offset=1879282 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8100007F7\000\00010\000\000"
/* offset=1879528 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4100007F7\000\00010\000\000"
/* offset=1879780 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100007F7\000\00010\000\000"
/* offset=1880021 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1100007F7\000\00010\000\000"
/* offset=1880261 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2100007F7\000\00010\000\000"
/* offset=1880491 */ "offcore_response.all_reads.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x900007F7\000\00010\000\000"
/* offset=1880720 */ "offcore_response.all_reads.llc_hit.any_response\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c03f7\000\00000\000\000"
/* offset=1880911 */ "offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000"
/* offset=1881190 */ "offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c03f7\000\00000\000\000"
/* offset=1881475 */ "offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c03f7\000\00000\000\000"
/* offset=1881756 */ "offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000"
/* offset=1882037 */ "offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c03f7\000\00000\000\000"
/* offset=1882324 */ "offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c03f7\000\00000\000\000"
/* offset=1882607 */ "offcore_response.all_reads.llc_hit.no_snoop_needed\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c03f7\000\00000\000\000"
/* offset=1882927 */ "offcore_response.all_reads.llc_hit.no_snoop_needed\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c03f7\000\00000\000\000"
/* offset=1883243 */ "offcore_response.all_reads.llc_hit.snoop_miss\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c03f7\000\00000\000\000"
/* offset=1883480 */ "offcore_response.all_reads.llc_hit.snoop_miss\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c03f7\000\00000\000\000"
/* offset=1883723 */ "offcore_response.all_reads.llc_miss.any_response\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC007F7\000\00000\000\000"
/* offset=1883911 */ "offcore_response.all_reads.llc_miss.any_response\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that hit the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc203f7\000\00000\000\000"
/* offset=1884101 */ "offcore_response.all_reads.llc_miss.dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3004003f7\000\00000\000\000"
/* offset=1884316 */ "offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004007F7\000\00000\000\000"
/* offset=1884539 */ "offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00000\000\000"
/* offset=1884762 */ "offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004003f7\000\00000\000\000"
/* offset=1884989 */ "offcore_response.all_reads.llc_miss.remote_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63BC007F7\000\00000\000\000"
/* offset=1885214 */ "offcore_response.all_reads.llc_miss.remote_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63F8007F7\000\00000\000\000"
/* offset=1885439 */ "offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00000\000\000"
/* offset=1885687 */ "offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87FC007F7\000\00000\000\000"
/* offset=1885935 */ "offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f8203f7\000\00000\000\000"
/* offset=1886173 */ "offcore_response.all_reads.llc_miss.remote_hitm\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00000\000\000"
/* offset=1886412 */ "offcore_response.all_reads.llc_miss.remote_hitm\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc003f7\000\00000\000\000"
/* offset=1886673 */ "offcore_response.all_reads.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F804007F7\000\00010\000\000"
/* offset=1886887 */ "offcore_response.all_reads.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804007F7\000\00010\000\000"
/* offset=1887101 */ "offcore_response.all_reads.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00010\000\000"
/* offset=1887328 */ "offcore_response.all_reads.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800207F7\000\00010\000\000"
/* offset=1887534 */ "offcore_response.all_reads.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000207F7\000\00010\000\000"
/* offset=1887757 */ "offcore_response.all_reads.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000207F7\000\00010\000\000"
/* offset=1887986 */ "offcore_response.all_reads.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000207F7\000\00010\000\000"
/* offset=1888204 */ "offcore_response.all_reads.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000207F7\000\00010\000\000"
/* offset=1888421 */ "offcore_response.all_reads.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000207F7\000\00010\000\000"
/* offset=1888628 */ "offcore_response.all_reads.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800207F7\000\00010\000\000"
/* offset=1888834 */ "offcore_response.all_requests.l3_hit.any_response\000\000cache\000Counts all requests hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8FFF\000\00000\000\000"
/* offset=1888990 */ "offcore_response.all_requests.l3_miss.any_response\000\000memory\000Counts all requests miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC08FFF\000\00000\000\000"
/* offset=1889149 */ "offcore_response.all_requests.llc_hit.any_response\000\000cache\000Counts all requests hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8FFF\000\00000\000\000"
/* offset=1889306 */ "offcore_response.all_requests.llc_miss.any_response\000\000memory\000Counts all requests miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC08FFF\000\00000\000\000"
/* offset=1889466 */ "offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000"
/* offset=1889628 */ "offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000"
/* offset=1889795 */ "offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch prefetch RFOs \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010122\000\00000\000\000"
/* offset=1889947 */ "offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010122\000\00000\000\000"
/* offset=1890098 */ "offcore_response.all_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00010\000\000"
/* offset=1890273 */ "offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000"
/* offset=1890440 */ "offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000"
/* offset=1890588 */ "offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00010\000\000"
/* offset=1890776 */ "offcore_response.all_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00010\000\000"
/* offset=1890981 */ "offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000"
/* offset=1891240 */ "offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000"
/* offset=1891511 */ "offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00010\000\000"
/* offset=1891722 */ "offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000"
/* offset=1891983 */ "offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000"
/* offset=1892249 */ "offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00010\000\000"
/* offset=1892449 */ "offcore_response.all_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000"
/* offset=1892748 */ "offcore_response.all_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00010\000\000"
/* offset=1892947 */ "offcore_response.all_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000"
/* offset=1893101 */ "offcore_response.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00000\000\000"
/* offset=1893274 */ "offcore_response.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0122\000\00010\000\000"
/* offset=1893479 */ "offcore_response.all_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000"
/* offset=1893628 */ "offcore_response.all_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00000\000\000"
/* offset=1893776 */ "offcore_response.all_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00010\000\000"
/* offset=1893965 */ "offcore_response.all_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0122\000\00000\000\000"
/* offset=1894119 */ "offcore_response.all_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00000\000\000"
/* offset=1894266 */ "offcore_response.all_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00010\000\000"
/* offset=1894454 */ "offcore_response.all_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000"
/* offset=1894608 */ "offcore_response.all_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080122\000\00010\000\000"
/* offset=1894800 */ "offcore_response.all_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080122\000\00010\000\000"
/* offset=1895009 */ "offcore_response.all_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080122\000\00010\000\000"
/* offset=1895224 */ "offcore_response.all_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080122\000\00010\000\000"
/* offset=1895428 */ "offcore_response.all_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080122\000\00010\000\000"
/* offset=1895631 */ "offcore_response.all_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080122\000\00010\000\000"
/* offset=1895824 */ "offcore_response.all_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080122\000\00010\000\000"
/* offset=1896016 */ "offcore_response.all_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200122\000\00010\000\000"
/* offset=1896208 */ "offcore_response.all_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200122\000\00010\000\000"
/* offset=1896417 */ "offcore_response.all_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200122\000\00010\000\000"
/* offset=1896632 */ "offcore_response.all_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200122\000\00010\000\000"
/* offset=1896836 */ "offcore_response.all_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200122\000\00010\000\000"
/* offset=1897039 */ "offcore_response.all_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200122\000\00010\000\000"
/* offset=1897232 */ "offcore_response.all_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200122\000\00010\000\000"
/* offset=1897424 */ "offcore_response.all_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040122\000\00010\000\000"
/* offset=1897616 */ "offcore_response.all_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040122\000\00010\000\000"
/* offset=1897825 */ "offcore_response.all_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040122\000\00010\000\000"
/* offset=1898040 */ "offcore_response.all_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040122\000\00010\000\000"
/* offset=1898244 */ "offcore_response.all_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040122\000\00010\000\000"
/* offset=1898447 */ "offcore_response.all_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040122\000\00010\000\000"
/* offset=1898640 */ "offcore_response.all_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040122\000\00010\000\000"
/* offset=1898832 */ "offcore_response.all_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100122\000\00010\000\000"
/* offset=1899024 */ "offcore_response.all_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100122\000\00010\000\000"
/* offset=1899233 */ "offcore_response.all_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100122\000\00010\000\000"
/* offset=1899448 */ "offcore_response.all_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100122\000\00010\000\000"
/* offset=1899652 */ "offcore_response.all_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100122\000\00010\000\000"
/* offset=1899855 */ "offcore_response.all_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100122\000\00010\000\000"
/* offset=1900048 */ "offcore_response.all_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100122\000\00010\000\000"
/* offset=1900240 */ "offcore_response.all_rfo.l3_miss.any_response\000\000memory\000Counts all demand & prefetch RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00122\000\00000\000\000"
/* offset=1900408 */ "offcore_response.all_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand & prefetch RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00000\000\000"
/* offset=1900578 */ "offcore_response.all_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00010\000\000"
/* offset=1900769 */ "offcore_response.all_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000122\000\00010\000\000"
/* offset=1900977 */ "offcore_response.all_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00010\000\000"
/* offset=1901191 */ "offcore_response.all_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000122\000\00010\000\000"
/* offset=1901394 */ "offcore_response.all_rfo.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00000\000\000"
/* offset=1901597 */ "offcore_response.all_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00010\000\000"
/* offset=1901799 */ "offcore_response.all_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00000\000\000"
/* offset=1902032 */ "offcore_response.all_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00010\000\000"
/* offset=1902240 */ "offcore_response.all_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00000\000\000"
/* offset=1902464 */ "offcore_response.all_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00010\000\000"
/* offset=1902659 */ "offcore_response.all_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00000\000\000"
/* offset=1902815 */ "offcore_response.all_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00000\000\000"
/* offset=1902965 */ "offcore_response.all_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00010\000\000"
/* offset=1903157 */ "offcore_response.all_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00122\000\00000\000\000"
/* offset=1903385 */ "offcore_response.all_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00000\000\000"
/* offset=1903534 */ "offcore_response.all_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00010\000\000"
/* offset=1903725 */ "offcore_response.all_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00000\000\000"
/* offset=1903881 */ "offcore_response.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00000\000\000"
/* offset=1904042 */ "offcore_response.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00010\000\000"
/* offset=1904255 */ "offcore_response.all_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000122\000\00010\000\000"
/* offset=1904485 */ "offcore_response.all_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00010\000\000"
/* offset=1904721 */ "offcore_response.all_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00010\000\000"
/* offset=1904946 */ "offcore_response.all_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00010\000\000"
/* offset=1905170 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00000\000\000"
/* offset=1905337 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00000\000\000"
/* offset=1905499 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00000\000\000"
/* offset=1905660 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00010\000\000"
/* offset=1905874 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000"
/* offset=1906103 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00010\000\000"
/* offset=1906337 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000122\000\00000\000\000"
/* offset=1906503 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00000\000\000"
/* offset=1906663 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00010\000\000"
/* offset=1906876 */ "offcore_response.all_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00000\000\000"
/* offset=1907043 */ "offcore_response.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00000\000\000"
/* offset=1907274 */ "offcore_response.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00010\000\000"
/* offset=1907510 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000122\000\00010\000\000"
/* offset=1907735 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000122\000\00010\000\000"
/* offset=1907977 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000122\000\00010\000\000"
/* offset=1908225 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000122\000\00010\000\000"
/* offset=1908462 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000122\000\00010\000\000"
/* offset=1908698 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000122\000\00010\000\000"
/* offset=1908924 */ "offcore_response.all_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000122\000\00010\000\000"
/* offset=1909149 */ "offcore_response.all_rfo.llc_hit.any_response\000\000cache\000Counts all demand & prefetch RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0122\000\00000\000\000"
/* offset=1909321 */ "offcore_response.all_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000"
/* offset=1909581 */ "offcore_response.all_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0122\000\00000\000\000"
/* offset=1909843 */ "offcore_response.all_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000"
/* offset=1910105 */ "offcore_response.all_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0122\000\00000\000\000"
/* offset=1910369 */ "offcore_response.all_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0122\000\00000\000\000"
/* offset=1910666 */ "offcore_response.all_rfo.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0122\000\00000\000\000"
/* offset=1910890 */ "offcore_response.all_rfo.llc_miss.any_response\000\000memory\000Counts all demand & prefetch RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00122\000\00000\000\000"
/* offset=1911059 */ "offcore_response.all_rfo.llc_miss.dram\000\000memory\000Counts all demand & prefetch RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400122\000\00000\000\000"
/* offset=1911255 */ "offcore_response.all_rfo.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400122\000\00000\000\000"
/* offset=1911459 */ "offcore_response.all_rfo.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000"
/* offset=1911663 */ "offcore_response.all_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400122\000\00010\000\000"
/* offset=1911873 */ "offcore_response.all_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400122\000\00010\000\000"
/* offset=1912083 */ "offcore_response.all_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00010\000\000"
/* offset=1912306 */ "offcore_response.all_rfo.supplier_none.any_snoop\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00000\000\000"
/* offset=1912461 */ "offcore_response.all_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00010\000\000"
/* offset=1912663 */ "offcore_response.all_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020122\000\00010\000\000"
/* offset=1912882 */ "offcore_response.all_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00010\000\000"
/* offset=1913107 */ "offcore_response.all_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00010\000\000"
/* offset=1913321 */ "offcore_response.all_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00010\000\000"
/* offset=1913534 */ "offcore_response.all_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00000\000\000"
/* offset=1913695 */ "offcore_response.all_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00000\000\000"
/* offset=1913851 */ "offcore_response.all_rfo.supplier_none.snoop_miss\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00000\000\000"
/* offset=1914006 */ "offcore_response.all_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00010\000\000"
/* offset=1914209 */ "offcore_response.all_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020122\000\00000\000\000"
/* offset=1914370 */ "offcore_response.all_rfo.supplier_none.snoop_none\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00000\000\000"
/* offset=1914524 */ "offcore_response.all_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00010\000\000"
/* offset=1914726 */ "offcore_response.all_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00000\000\000"
/* offset=1914887 */ "offcore_response.any_code_rd.any_response\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010044\000\00000\000\000"
/* offset=1915090 */ "offcore_response.any_code_rd.any_response\000\000cache\000Counts any code reads (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010044\000\00000\000\000"
/* offset=1915274 */ "offcore_response.any_code_rd.ddr\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800044\000\00000\000\000"
/* offset=1915491 */ "offcore_response.any_code_rd.ddr_far\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000044\000\00000\000\000"
/* offset=1915706 */ "offcore_response.any_code_rd.ddr_near\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800044\000\00000\000\000"
/* offset=1915924 */ "offcore_response.any_code_rd.l2_hit_far_tile\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400044\000\00000\000\000"
/* offset=1916285 */ "offcore_response.any_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400044\000\00000\000\000"
/* offset=1916654 */ "offcore_response.any_code_rd.l2_hit_far_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400044\000\00000\000\000"
/* offset=1916985 */ "offcore_response.any_code_rd.l2_hit_near_tile\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180044\000\00000\000\000"
/* offset=1917275 */ "offcore_response.any_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080044\000\00000\000\000"
/* offset=1917571 */ "offcore_response.any_code_rd.l2_hit_near_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080044\000\00000\000\000"
/* offset=1917863 */ "offcore_response.any_code_rd.l2_hit_this_tile_e\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000044\000\00000\000\000"
/* offset=1918118 */ "offcore_response.any_code_rd.l2_hit_this_tile_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000044\000\00000\000\000"
/* offset=1918373 */ "offcore_response.any_code_rd.l2_hit_this_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000044\000\00000\000\000"
/* offset=1918628 */ "offcore_response.any_code_rd.l2_hit_this_tile_s\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000044\000\00000\000\000"
/* offset=1918883 */ "offcore_response.any_code_rd.l2_miss.any\000\000cache\000Counts any code reads (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000044\000\00000\000\000"
/* offset=1919051 */ "offcore_response.any_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any code reads (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000044\000\00000\000\000"
/* offset=1919323 */ "offcore_response.any_code_rd.l2_miss.hitm_other_core\000\000cache\000Counts any code reads (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000044\000\00000\000\000"
/* offset=1919577 */ "offcore_response.any_code_rd.l2_miss.snoop_miss\000\000cache\000Counts any code reads (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000044\000\00000\000\000"
/* offset=1919779 */ "offcore_response.any_code_rd.mcdram\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600044\000\00000\000\000"
/* offset=1920002 */ "offcore_response.any_code_rd.mcdram_far\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400044\000\00000\000\000"
/* offset=1920247 */ "offcore_response.any_code_rd.mcdram_near\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200044\000\00000\000\000"
/* offset=1920470 */ "offcore_response.any_code_rd.outstanding\000\000cache\000Counts Demand code reads and prefetch code read requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000044\000\00000\000\000"
/* offset=1920805 */ "offcore_response.any_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5011\000\00000\000\000"
/* offset=1921008 */ "offcore_response.any_data.any_cache_dram\000\000cache\000Offcore data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F11\000\00000\000\000"
/* offset=1921165 */ "offcore_response.any_data.any_cache_dram\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f11\000\00000\000\000"
/* offset=1921326 */ "offcore_response.any_data.any_dram\000\000memory\000Offcore data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6011\000\00000\000\000"
/* offset=1921469 */ "offcore_response.any_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3011\000\00000\000\000"
/* offset=1921649 */ "offcore_response.any_data.any_llc_miss\000\000memory\000Offcore data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF811\000\00000\000\000"
/* offset=1921794 */ "offcore_response.any_data.any_llc_miss\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf811\000\00000\000\000"
/* offset=1921952 */ "offcore_response.any_data.any_location\000\000cache\000All offcore data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF11\000\00000\000\000"
/* offset=1922080 */ "offcore_response.any_data.any_location\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff11\000\00000\000\000"
/* offset=1922237 */ "offcore_response.any_data.io_csr_mmio\000\000cache\000Offcore data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000"
/* offset=1922396 */ "offcore_response.any_data.io_csr_mmio\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000"
/* offset=1922551 */ "offcore_response.any_data.llc_hit_no_other_core\000\000cache\000Offcore data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000"
/* offset=1922736 */ "offcore_response.any_data.llc_hit_no_other_core\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000"
/* offset=1922910 */ "offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000Offcore data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000"
/* offset=1923090 */ "offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000"
/* offset=1923266 */ "offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000Offcore data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000"
/* offset=1923449 */ "offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000"
/* offset=1923627 */ "offcore_response.any_data.local_cache\000\000cache\000Offcore data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000"
/* offset=1923770 */ "offcore_response.any_data.local_cache\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000"
/* offset=1923924 */ "offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2711\000\00000\000\000"
/* offset=1924087 */ "offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4711\000\00000\000\000"
/* offset=1924250 */ "offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000"
/* offset=1924401 */ "offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000"
/* offset=1924552 */ "offcore_response.any_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000"
/* offset=1924747 */ "offcore_response.any_data.other_local_dram\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000"
/* offset=1924913 */ "offcore_response.any_data.remote_cache\000\000cache\000Offcore data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1811\000\00000\000\000"
/* offset=1925065 */ "offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3811\000\00000\000\000"
/* offset=1925237 */ "offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5811\000\00000\000\000"
/* offset=1925409 */ "offcore_response.any_data.remote_cache_hit\000\000cache\000Offcore data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000"
/* offset=1925564 */ "offcore_response.any_data.remote_cache_hitm\000\000cache\000Offcore data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000"
/* offset=1925720 */ "offcore_response.any_data.remote_cache_hitm\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000"
/* offset=1925886 */ "offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000"
/* offset=1926037 */ "offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000"
/* offset=1926188 */ "offcore_response.any_data.remote_dram\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000"
/* offset=1926344 */ "offcore_response.any_data_rd.any_response\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000\000"
/* offset=1926554 */ "offcore_response.any_data_rd.any_response\000\000cache\000Counts any data read (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000\000"
/* offset=1926737 */ "offcore_response.any_data_rd.any_response\000\000cache\000Counts data reads (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000Counts data reads (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1927137 */ "offcore_response.any_data_rd.ddr\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181803091\000\00000\000\000"
/* offset=1927361 */ "offcore_response.any_data_rd.ddr_far\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101003091\000\00000\000\000"
/* offset=1927583 */ "offcore_response.any_data_rd.ddr_near\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080803091\000\00000\000\000"
/* offset=1927808 */ "offcore_response.any_data_rd.l2_hit\000\000cache\000Counts data reads (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043091\000\00000\000Counts data reads (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1928122 */ "offcore_response.any_data_rd.l2_hit\000\000cache\000Counts data reads (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043091\000\00000\000Counts data reads (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1928446 */ "offcore_response.any_data_rd.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800403091\000\00000\000\000"
/* offset=1928814 */ "offcore_response.any_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800403091\000\00000\000\000"
/* offset=1929190 */ "offcore_response.any_data_rd.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000403091\000\00000\000\000"
/* offset=1929528 */ "offcore_response.any_data_rd.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800183091\000\00000\000\000"
/* offset=1929825 */ "offcore_response.any_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800083091\000\00000\000\000"
/* offset=1930128 */ "offcore_response.any_data_rd.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000083091\000\00000\000\000"
/* offset=1930427 */ "offcore_response.any_data_rd.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004003091\000\00000\000\000"
/* offset=1930689 */ "offcore_response.any_data_rd.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010003091\000\00000\000\000"
/* offset=1930951 */ "offcore_response.any_data_rd.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002003091\000\00000\000\000"
/* offset=1931213 */ "offcore_response.any_data_rd.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008003091\000\00000\000\000"
/* offset=1931475 */ "offcore_response.any_data_rd.l2_miss.any\000\000cache\000Counts any data read (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680003091\000\00000\000\000"
/* offset=1931642 */ "offcore_response.any_data_rd.l2_miss.any\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1931973 */ "offcore_response.any_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any data read (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003091\000\00000\000\000"
/* offset=1932244 */ "offcore_response.any_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1932751 */ "offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts any data read (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000\000"
/* offset=1933004 */ "offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000Counts data reads (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1933489 */ "offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1933984 */ "offcore_response.any_data_rd.l2_miss.snoop_miss\000\000cache\000Counts any data read (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000\000"
/* offset=1934185 */ "offcore_response.any_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000Counts data reads (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1934657 */ "offcore_response.any_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000Counts data reads (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1935119 */ "offcore_response.any_data_rd.mcdram\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180603091\000\00000\000\000"
/* offset=1935349 */ "offcore_response.any_data_rd.mcdram_far\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100403091\000\00000\000\000"
/* offset=1935601 */ "offcore_response.any_data_rd.mcdram_near\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080203091\000\00000\000\000"
/* offset=1935831 */ "offcore_response.any_data_rd.outstanding\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003091\000\00000\000\000"
/* offset=1936173 */ "offcore_response.any_data_rd.outstanding\000\000cache\000Counts data reads (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003091\000\00000\000Counts data reads (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1936630 */ "offcore_response.any_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5044\000\00000\000\000"
/* offset=1936832 */ "offcore_response.any_ifetch.any_cache_dram\000\000cache\000Offcore code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F44\000\00000\000\000"
/* offset=1936991 */ "offcore_response.any_ifetch.any_cache_dram\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f44\000\00000\000\000"
/* offset=1937151 */ "offcore_response.any_ifetch.any_dram\000\000memory\000Offcore code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6044\000\00000\000\000"
/* offset=1937296 */ "offcore_response.any_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3044\000\00000\000\000"
/* offset=1937475 */ "offcore_response.any_ifetch.any_llc_miss\000\000memory\000Offcore code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF844\000\00000\000\000"
/* offset=1937622 */ "offcore_response.any_ifetch.any_llc_miss\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf844\000\00000\000\000"
/* offset=1937779 */ "offcore_response.any_ifetch.any_location\000\000cache\000All offcore code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF44\000\00000\000\000"
/* offset=1937909 */ "offcore_response.any_ifetch.any_location\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff44\000\00000\000\000"
/* offset=1938065 */ "offcore_response.any_ifetch.io_csr_mmio\000\000cache\000Offcore code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000"
/* offset=1938226 */ "offcore_response.any_ifetch.io_csr_mmio\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000"
/* offset=1938380 */ "offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000"
/* offset=1938567 */ "offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000"
/* offset=1938740 */ "offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000"
/* offset=1938922 */ "offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000"
/* offset=1939097 */ "offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000"
/* offset=1939282 */ "offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000"
/* offset=1939459 */ "offcore_response.any_ifetch.local_cache\000\000cache\000Offcore code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000"
/* offset=1939604 */ "offcore_response.any_ifetch.local_cache\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000"
/* offset=1939757 */ "offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2744\000\00000\000\000"
/* offset=1939922 */ "offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4744\000\00000\000\000"
/* offset=1940087 */ "offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000"
/* offset=1940240 */ "offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000"
/* offset=1940393 */ "offcore_response.any_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000"
/* offset=1940587 */ "offcore_response.any_ifetch.other_local_dram\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000"
/* offset=1940752 */ "offcore_response.any_ifetch.remote_cache\000\000cache\000Offcore code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1844\000\00000\000\000"
/* offset=1940906 */ "offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3844\000\00000\000\000"
/* offset=1941080 */ "offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5844\000\00000\000\000"
/* offset=1941254 */ "offcore_response.any_ifetch.remote_cache_hit\000\000cache\000Offcore code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000"
/* offset=1941411 */ "offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000Offcore code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000"
/* offset=1941569 */ "offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000"
/* offset=1941734 */ "offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000"
/* offset=1941887 */ "offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000"
/* offset=1942040 */ "offcore_response.any_ifetch.remote_dram\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000"
/* offset=1942195 */ "offcore_response.any_pf_data_rd.any_response\000\000cache\000Counts data reads generated by L1 or L2 prefetchers have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013010\000\00000\000Counts data reads generated by L1 or L2 prefetchers have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1942626 */ "offcore_response.any_pf_data_rd.l2_hit\000\000cache\000Counts data reads generated by L1 or L2 prefetchers hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043010\000\00000\000Counts data reads generated by L1 or L2 prefetchers hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1942971 */ "offcore_response.any_pf_data_rd.l2_hit\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1943326 */ "offcore_response.any_pf_data_rd.l2_miss.any\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1943688 */ "offcore_response.any_pf_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1944226 */ "offcore_response.any_pf_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads generated by L1 or L2 prefetchers miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1944742 */ "offcore_response.any_pf_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1945268 */ "offcore_response.any_pf_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1945771 */ "offcore_response.any_pf_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads generated by L1 or L2 prefetchers true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1946264 */ "offcore_response.any_pf_data_rd.outstanding\000\000cache\000Counts data reads generated by L1 or L2 prefetchers outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1946752 */ "offcore_response.any_pf_l2.any_response\000\000cache\000Counts any Prefetch requests that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010070\000\00000\000\000"
/* offset=1946924 */ "offcore_response.any_pf_l2.ddr_far\000\000memory\000Counts any Prefetch requests that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000070\000\00000\000\000"
/* offset=1947108 */ "offcore_response.any_pf_l2.ddr_near\000\000memory\000Counts any Prefetch requests that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800070\000\00000\000\000"
/* offset=1947295 */ "offcore_response.any_pf_l2.l2_hit_far_tile\000\000cache\000Counts any Prefetch requests that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400070\000\00000\000\000"
/* offset=1947625 */ "offcore_response.any_pf_l2.l2_hit_far_tile_e_f\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400070\000\00000\000\000"
/* offset=1947963 */ "offcore_response.any_pf_l2.l2_hit_far_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400070\000\00000\000\000"
/* offset=1948263 */ "offcore_response.any_pf_l2.l2_hit_near_tile\000\000cache\000Counts any Prefetch requests that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180070\000\00000\000\000"
/* offset=1948522 */ "offcore_response.any_pf_l2.l2_hit_near_tile_e_f\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080070\000\00000\000\000"
/* offset=1948787 */ "offcore_response.any_pf_l2.l2_hit_near_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080070\000\00000\000\000"
/* offset=1949048 */ "offcore_response.any_pf_l2.l2_hit_this_tile_e\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000070\000\00000\000\000"
/* offset=1949272 */ "offcore_response.any_pf_l2.l2_hit_this_tile_f\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000070\000\00000\000\000"
/* offset=1949496 */ "offcore_response.any_pf_l2.l2_hit_this_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000070\000\00000\000\000"
/* offset=1949720 */ "offcore_response.any_pf_l2.mcdram\000\000memory\000Counts any Prefetch requests that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600070\000\00000\000\000"
/* offset=1949912 */ "offcore_response.any_pf_l2.mcdram_far\000\000memory\000Counts any Prefetch requests that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400070\000\00000\000\000"
/* offset=1950126 */ "offcore_response.any_pf_l2.mcdram_near\000\000memory\000Counts any Prefetch requests that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200070\000\00000\000\000"
/* offset=1950318 */ "offcore_response.any_pf_l2.outstanding\000\000cache\000Counts any Prefetch requests that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000070\000\00000\000\000"
/* offset=1950622 */ "offcore_response.any_read.any_response\000\000cache\000Counts any Read request  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000132f7\000\00000\000\000"
/* offset=1950789 */ "offcore_response.any_read.any_response\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000132b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1951284 */ "offcore_response.any_read.ddr\000\000memory\000Counts any Read request  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01818032f7\000\00000\000\000"
/* offset=1951465 */ "offcore_response.any_read.ddr_far\000\000memory\000Counts any Read request  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01010032f7\000\00000\000\000"
/* offset=1951644 */ "offcore_response.any_read.ddr_near\000\000memory\000Counts any Read request  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00808032f7\000\00000\000\000"
/* offset=1951826 */ "offcore_response.any_read.l2_hit\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000432b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1952235 */ "offcore_response.any_read.l2_hit\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000432b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1952654 */ "offcore_response.any_read.l2_hit_far_tile\000\000cache\000Counts any Read request  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x18004032f7\000\00000\000\000"
/* offset=1952979 */ "offcore_response.any_read.l2_hit_far_tile_e_f\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x08004032f7\000\00000\000\000"
/* offset=1953312 */ "offcore_response.any_read.l2_hit_far_tile_m\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10004032f7\000\00000\000\000"
/* offset=1953607 */ "offcore_response.any_read.l2_hit_near_tile\000\000cache\000Counts any Read request  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x18001832f7\000\00000\000\000"
/* offset=1953861 */ "offcore_response.any_read.l2_hit_near_tile_e_f\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x08000832f7\000\00000\000\000"
/* offset=1954121 */ "offcore_response.any_read.l2_hit_near_tile_m\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000832f7\000\00000\000\000"
/* offset=1954377 */ "offcore_response.any_read.l2_hit_this_tile_e\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00040032f7\000\00000\000\000"
/* offset=1954596 */ "offcore_response.any_read.l2_hit_this_tile_f\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00100032f7\000\00000\000\000"
/* offset=1954815 */ "offcore_response.any_read.l2_hit_this_tile_m\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00020032f7\000\00000\000\000"
/* offset=1955034 */ "offcore_response.any_read.l2_hit_this_tile_s\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00080032f7\000\00000\000\000"
/* offset=1955253 */ "offcore_response.any_read.l2_miss.any\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x36000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1955679 */ "offcore_response.any_read.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x04000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1956281 */ "offcore_response.any_read.l2_miss.hitm_other_core\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1956861 */ "offcore_response.any_read.l2_miss.hitm_other_core\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1957451 */ "offcore_response.any_read.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x02000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1958018 */ "offcore_response.any_read.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x02000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1958575 */ "offcore_response.any_read.mcdram\000\000memory\000Counts any Read request  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01806032f7\000\00000\000\000"
/* offset=1958762 */ "offcore_response.any_read.mcdram_far\000\000memory\000Counts any Read request  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01004032f7\000\00000\000\000"
/* offset=1958971 */ "offcore_response.any_read.mcdram_near\000\000memory\000Counts any Read request  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00802032f7\000\00000\000\000"
/* offset=1959158 */ "offcore_response.any_read.outstanding\000\000cache\000Counts any Read request  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x40000032f7\000\00000\000\000"
/* offset=1959457 */ "offcore_response.any_read.outstanding\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x40000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1960009 */ "offcore_response.any_request.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x50ff\000\00000\000\000"
/* offset=1960213 */ "offcore_response.any_request.any_cache_dram\000\000cache\000Offcore requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FFF\000\00000\000\000"
/* offset=1960371 */ "offcore_response.any_request.any_cache_dram\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7fff\000\00000\000\000"
/* offset=1960533 */ "offcore_response.any_request.any_dram\000\000memory\000Offcore requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x60FF\000\00000\000\000"
/* offset=1960677 */ "offcore_response.any_request.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x30ff\000\00000\000\000"
/* offset=1960858 */ "offcore_response.any_request.any_llc_miss\000\000memory\000Offcore requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF8FF\000\00000\000\000"
/* offset=1961004 */ "offcore_response.any_request.any_llc_miss\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf8ff\000\00000\000\000"
/* offset=1961163 */ "offcore_response.any_request.any_location\000\000cache\000All offcore requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFFFF\000\00000\000\000"
/* offset=1961292 */ "offcore_response.any_request.any_location\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xffff\000\00000\000\000"
/* offset=1961450 */ "offcore_response.any_request.any_response\000\000cache\000Counts any request that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000\000"
/* offset=1961614 */ "offcore_response.any_request.any_response\000\000cache\000Counts any request that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018008\000\00000\000\000"
/* offset=1961775 */ "offcore_response.any_request.any_response\000\000cache\000Counts requests to the uncore subsystem have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000Counts requests to the uncore subsystem have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1962179 */ "offcore_response.any_request.any_response\000\000cache\000Counts requests to the uncore subsystem that have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000Counts requests to the uncore subsystem that have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1962593 */ "offcore_response.any_request.ddr\000\000memory\000Counts any request that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181808000\000\00000\000\000"
/* offset=1962771 */ "offcore_response.any_request.ddr_far\000\000memory\000Counts any request that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101008000\000\00000\000\000"
/* offset=1962947 */ "offcore_response.any_request.ddr_near\000\000memory\000Counts any request that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080808000\000\00000\000\000"
/* offset=1963126 */ "offcore_response.any_request.io_csr_mmio\000\000cache\000Offcore requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80FF\000\00000\000\000"
/* offset=1963286 */ "offcore_response.any_request.io_csr_mmio\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80ff\000\00000\000\000"
/* offset=1963442 */ "offcore_response.any_request.l2_hit\000\000cache\000Counts requests to the uncore subsystem hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000048000\000\00000\000Counts requests to the uncore subsystem hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1963760 */ "offcore_response.any_request.l2_hit\000\000cache\000Counts requests to the uncore subsystem that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000048000\000\00000\000Counts requests to the uncore subsystem that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1964088 */ "offcore_response.any_request.l2_hit_far_tile\000\000cache\000Counts any request that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800408000\000\00000\000\000"
/* offset=1964410 */ "offcore_response.any_request.l2_hit_far_tile_e_f\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800408000\000\00000\000\000"
/* offset=1964740 */ "offcore_response.any_request.l2_hit_far_tile_m\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000408000\000\00000\000\000"
/* offset=1965032 */ "offcore_response.any_request.l2_hit_near_tile\000\000cache\000Counts any request that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800188000\000\00000\000\000"
/* offset=1965283 */ "offcore_response.any_request.l2_hit_near_tile_e_f\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800088000\000\00000\000\000"
/* offset=1965540 */ "offcore_response.any_request.l2_hit_near_tile_m\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000"
/* offset=1965793 */ "offcore_response.any_request.l2_hit_this_tile_e\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004008000\000\00000\000\000"
/* offset=1966009 */ "offcore_response.any_request.l2_hit_this_tile_f\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010008000\000\00000\000\000"
/* offset=1966225 */ "offcore_response.any_request.l2_hit_this_tile_m\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002008000\000\00000\000\000"
/* offset=1966441 */ "offcore_response.any_request.l2_hit_this_tile_s\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008008000\000\00000\000\000"
/* offset=1966657 */ "offcore_response.any_request.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any request that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400008008\000\00000\000\000"
/* offset=1966906 */ "offcore_response.any_request.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400008000\000\00000\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1967417 */ "offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts any request that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008008\000\00000\000\000"
/* offset=1967648 */ "offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts requests to the uncore subsystem miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008000\000\00000\000Counts requests to the uncore subsystem miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1968137 */ "offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008000\000\00000\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1968636 */ "offcore_response.any_request.l2_miss.snoop_miss\000\000cache\000Counts any request that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008008\000\00000\000\000"
/* offset=1968815 */ "offcore_response.any_request.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts requests to the uncore subsystem that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008000\000\00000\000Counts requests to the uncore subsystem that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1969291 */ "offcore_response.any_request.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts requests to the uncore subsystem true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008000\000\00000\000Counts requests to the uncore subsystem true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1969757 */ "offcore_response.any_request.llc_hit_no_other_core\000\000cache\000Offcore requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1FF\000\00000\000\000"
/* offset=1969943 */ "offcore_response.any_request.llc_hit_no_other_core\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1ff\000\00000\000\000"
/* offset=1970118 */ "offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000Offcore requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2FF\000\00000\000\000"
/* offset=1970299 */ "offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2ff\000\00000\000\000"
/* offset=1970476 */ "offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000Offcore requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4FF\000\00000\000\000"
/* offset=1970660 */ "offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4ff\000\00000\000\000"
/* offset=1970839 */ "offcore_response.any_request.llc_miss_local.dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80408fff\000\00000\000This event counts any requests that miss the LLC where the data was returned from local DRAM\000"
/* offset=1971122 */ "offcore_response.any_request.local_cache\000\000cache\000Offcore requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FF\000\00000\000\000"
/* offset=1971266 */ "offcore_response.any_request.local_cache\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7ff\000\00000\000\000"
/* offset=1971421 */ "offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x27FF\000\00000\000\000"
/* offset=1971585 */ "offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x47FF\000\00000\000\000"
/* offset=1971749 */ "offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000"
/* offset=1971901 */ "offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000"
/* offset=1972053 */ "offcore_response.any_request.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10ff\000\00000\000\000"
/* offset=1972249 */ "offcore_response.any_request.mcdram\000\000memory\000Counts any request that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180608000\000\00000\000\000"
/* offset=1972433 */ "offcore_response.any_request.mcdram_far\000\000memory\000Counts any request that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100408000\000\00000\000\000"
/* offset=1972639 */ "offcore_response.any_request.mcdram_near\000\000memory\000Counts any request that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080208000\000\00000\000\000"
/* offset=1972823 */ "offcore_response.any_request.other_local_dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40ff\000\00000\000\000"
/* offset=1972990 */ "offcore_response.any_request.outstanding\000\000cache\000Counts any request that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000008000\000\00000\000\000"
/* offset=1973286 */ "offcore_response.any_request.outstanding\000\000cache\000Counts requests to the uncore subsystem outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000008000\000\00000\000Counts requests to the uncore subsystem outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1973747 */ "offcore_response.any_request.remote_cache\000\000cache\000Offcore requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x18FF\000\00000\000\000"
/* offset=1973900 */ "offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x38FF\000\00000\000\000"
/* offset=1974073 */ "offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x58FF\000\00000\000\000"
/* offset=1974246 */ "offcore_response.any_request.remote_cache_hit\000\000cache\000Offcore requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10FF\000\00000\000\000"
/* offset=1974402 */ "offcore_response.any_request.remote_cache_hitm\000\000cache\000Offcore requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8FF\000\00000\000\000"
/* offset=1974559 */ "offcore_response.any_request.remote_cache_hitm\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8ff\000\00000\000\000"
/* offset=1974726 */ "offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000"
/* offset=1974878 */ "offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000"
/* offset=1975030 */ "offcore_response.any_request.remote_dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20ff\000\00000\000\000"
/* offset=1975187 */ "offcore_response.any_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5022\000\00000\000\000"
/* offset=1975383 */ "offcore_response.any_rfo.any_cache_dram\000\000cache\000Offcore RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F22\000\00000\000\000"
/* offset=1975541 */ "offcore_response.any_rfo.any_cache_dram\000\000cache\000REQUEST = ANY RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f22\000\00000\000\000"
/* offset=1975695 */ "offcore_response.any_rfo.any_dram\000\000memory\000Offcore RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6022\000\00000\000\000"
/* offset=1975839 */ "offcore_response.any_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3022\000\00000\000\000"
/* offset=1976012 */ "offcore_response.any_rfo.any_llc_miss\000\000memory\000Offcore RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF822\000\00000\000\000"
/* offset=1976158 */ "offcore_response.any_rfo.any_llc_miss\000\000memory\000REQUEST = ANY RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf822\000\00000\000\000"
/* offset=1976309 */ "offcore_response.any_rfo.any_location\000\000cache\000All offcore RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF22\000\00000\000\000"
/* offset=1976438 */ "offcore_response.any_rfo.any_location\000\000cache\000REQUEST = ANY RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff22\000\00000\000\000"
/* offset=1976588 */ "offcore_response.any_rfo.any_response\000\000cache\000Counts Demand cacheable data write requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000\000"
/* offset=1976774 */ "offcore_response.any_rfo.any_response\000\000cache\000Counts any rfo reads (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000\000"
/* offset=1976953 */ "offcore_response.any_rfo.any_response\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1977397 */ "offcore_response.any_rfo.ddr\000\000memory\000Counts Demand cacheable data write requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800022\000\00000\000\000"
/* offset=1977597 */ "offcore_response.any_rfo.ddr_far\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000022\000\00000\000\000"
/* offset=1977795 */ "offcore_response.any_rfo.ddr_near\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800022\000\00000\000\000"
/* offset=1977996 */ "offcore_response.any_rfo.io_csr_mmio\000\000cache\000Offcore RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000"
/* offset=1978156 */ "offcore_response.any_rfo.io_csr_mmio\000\000cache\000REQUEST = ANY RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000"
/* offset=1978304 */ "offcore_response.any_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1978662 */ "offcore_response.any_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1979030 */ "offcore_response.any_rfo.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400022\000\00000\000\000"
/* offset=1979374 */ "offcore_response.any_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400022\000\00000\000\000"
/* offset=1979726 */ "offcore_response.any_rfo.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400022\000\00000\000\000"
/* offset=1980040 */ "offcore_response.any_rfo.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180022\000\00000\000\000"
/* offset=1980313 */ "offcore_response.any_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080022\000\00000\000\000"
/* offset=1980592 */ "offcore_response.any_rfo.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080022\000\00000\000\000"
/* offset=1980867 */ "offcore_response.any_rfo.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000022\000\00000\000\000"
/* offset=1981105 */ "offcore_response.any_rfo.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000022\000\00000\000\000"
/* offset=1981343 */ "offcore_response.any_rfo.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000022\000\00000\000\000"
/* offset=1981581 */ "offcore_response.any_rfo.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000022\000\00000\000\000"
/* offset=1981819 */ "offcore_response.any_rfo.l2_miss.any\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000022\000\00000\000\000"
/* offset=1981982 */ "offcore_response.any_rfo.l2_miss.any\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1982357 */ "offcore_response.any_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000022\000\00000\000\000"
/* offset=1982624 */ "offcore_response.any_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1983175 */ "offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts any rfo reads (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000\000"
/* offset=1983424 */ "offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1983953 */ "offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1984492 */ "offcore_response.any_rfo.l2_miss.snoop_miss\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000\000"
/* offset=1984689 */ "offcore_response.any_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1985205 */ "offcore_response.any_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1985711 */ "offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000Offcore RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000"
/* offset=1985897 */ "offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000"
/* offset=1986064 */ "offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000Offcore RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000"
/* offset=1986245 */ "offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000"
/* offset=1986414 */ "offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000"
/* offset=1986598 */ "offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000"
/* offset=1986769 */ "offcore_response.any_rfo.local_cache\000\000cache\000Offcore RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000"
/* offset=1986913 */ "offcore_response.any_rfo.local_cache\000\000cache\000REQUEST = ANY RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000"
/* offset=1987060 */ "offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2722\000\00000\000\000"
/* offset=1987224 */ "offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4722\000\00000\000\000"
/* offset=1987388 */ "offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000"
/* offset=1987540 */ "offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000"
/* offset=1987692 */ "offcore_response.any_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000"
/* offset=1987880 */ "offcore_response.any_rfo.mcdram\000\000memory\000Counts Demand cacheable data write requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600022\000\00000\000\000"
/* offset=1988086 */ "offcore_response.any_rfo.mcdram_far\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400022\000\00000\000\000"
/* offset=1988314 */ "offcore_response.any_rfo.mcdram_near\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200022\000\00000\000\000"
/* offset=1988520 */ "offcore_response.any_rfo.other_local_dram\000\000memory\000REQUEST = ANY RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000"
/* offset=1988679 */ "offcore_response.any_rfo.outstanding\000\000cache\000Counts Demand cacheable data write requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000022\000\00000\000\000"
/* offset=1988997 */ "offcore_response.any_rfo.outstanding\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1989498 */ "offcore_response.any_rfo.remote_cache\000\000cache\000Offcore RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1822\000\00000\000\000"
/* offset=1989651 */ "offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3822\000\00000\000\000"
/* offset=1989824 */ "offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5822\000\00000\000\000"
/* offset=1989997 */ "offcore_response.any_rfo.remote_cache_hit\000\000cache\000Offcore RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000"
/* offset=1990153 */ "offcore_response.any_rfo.remote_cache_hitm\000\000cache\000Offcore RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000"
/* offset=1990310 */ "offcore_response.any_rfo.remote_cache_hitm\000\000cache\000REQUEST = ANY RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000"
/* offset=1990469 */ "offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000"
/* offset=1990621 */ "offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000"
/* offset=1990773 */ "offcore_response.any_rfo.remote_dram\000\000memory\000REQUEST = ANY RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000"
/* offset=1990922 */ "offcore_response.bus_locks.any_response\000\000cache\000Counts Bus locks and split lock requests that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000\000"
/* offset=1991106 */ "offcore_response.bus_locks.any_response\000\000cache\000Counts bus lock and split lock requests have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000Counts bus lock and split lock requests have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1991508 */ "offcore_response.bus_locks.any_response\000\000cache\000Counts bus lock and split lock requests that have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000Counts bus lock and split lock requests that have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1991920 */ "offcore_response.bus_locks.ddr\000\000memory\000Counts Bus locks and split lock requests that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800400\000\00000\000\000"
/* offset=1992118 */ "offcore_response.bus_locks.ddr_far\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000400\000\00000\000\000"
/* offset=1992314 */ "offcore_response.bus_locks.ddr_near\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800400\000\00000\000\000"
/* offset=1992513 */ "offcore_response.bus_locks.l2_hit\000\000cache\000Counts bus lock and split lock requests hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040400\000\00000\000Counts bus lock and split lock requests hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1992829 */ "offcore_response.bus_locks.l2_hit_far_tile\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400400\000\00000\000\000"
/* offset=1993171 */ "offcore_response.bus_locks.l2_hit_far_tile_e_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400400\000\00000\000\000"
/* offset=1993521 */ "offcore_response.bus_locks.l2_hit_far_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400400\000\00000\000\000"
/* offset=1993833 */ "offcore_response.bus_locks.l2_hit_near_tile\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180400\000\00000\000\000"
/* offset=1994104 */ "offcore_response.bus_locks.l2_hit_near_tile_e_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080400\000\00000\000\000"
/* offset=1994381 */ "offcore_response.bus_locks.l2_hit_near_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080400\000\00000\000\000"
/* offset=1994654 */ "offcore_response.bus_locks.l2_hit_this_tile_e\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000400\000\00000\000\000"
/* offset=1994890 */ "offcore_response.bus_locks.l2_hit_this_tile_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000400\000\00000\000\000"
/* offset=1995126 */ "offcore_response.bus_locks.l2_hit_this_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000400\000\00000\000\000"
/* offset=1995362 */ "offcore_response.bus_locks.l2_hit_this_tile_s\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000400\000\00000\000\000"
/* offset=1995598 */ "offcore_response.bus_locks.l2_miss.hitm_other_core\000\000cache\000Counts bus lock and split lock requests miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000400\000\00000\000Counts bus lock and split lock requests miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1996085 */ "offcore_response.bus_locks.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts bus lock and split lock requests true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000400\000\00000\000Counts bus lock and split lock requests true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1996549 */ "offcore_response.bus_locks.mcdram\000\000memory\000Counts Bus locks and split lock requests that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600400\000\00000\000\000"
/* offset=1996753 */ "offcore_response.bus_locks.mcdram_far\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400400\000\00000\000\000"
/* offset=1996979 */ "offcore_response.bus_locks.mcdram_near\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200400\000\00000\000\000"
/* offset=1997183 */ "offcore_response.bus_locks.outstanding\000\000cache\000Counts Bus locks and split lock requests that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000400\000\00000\000\000"
/* offset=1997499 */ "offcore_response.bus_locks.outstanding\000\000cache\000Counts bus lock and split lock requests outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000400\000\00000\000Counts bus lock and split lock requests outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1997958 */ "offcore_response.corewb.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5008\000\00000\000\000"
/* offset=1998153 */ "offcore_response.corewb.any_cache_dram\000\000cache\000Offcore writebacks to any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F08\000\00000\000\000"
/* offset=1998298 */ "offcore_response.corewb.any_cache_dram\000\000cache\000REQUEST = CORE_WB and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f08\000\00000\000\000"
/* offset=1998451 */ "offcore_response.corewb.any_dram\000\000memory\000Offcore writebacks to any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6008\000\00000\000\000"
/* offset=1998582 */ "offcore_response.corewb.any_dram_and_remote_fwd\000\000memory\000REQUEST = CORE_WB and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3008\000\00000\000\000"
/* offset=1998754 */ "offcore_response.corewb.any_llc_miss\000\000memory\000Offcore writebacks that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF808\000\00000\000\000"
/* offset=1998897 */ "offcore_response.corewb.any_llc_miss\000\000memory\000REQUEST = CORE_WB and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf808\000\00000\000\000"
/* offset=1999047 */ "offcore_response.corewb.any_location\000\000cache\000All offcore writebacks\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF08\000\00000\000\000"
/* offset=1999173 */ "offcore_response.corewb.any_location\000\000cache\000REQUEST = CORE_WB and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff08\000\00000\000\000"
/* offset=1999322 */ "offcore_response.corewb.any_response\000\000cache\000Counts all writebacks from the core to the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000"
/* offset=1999473 */ "offcore_response.corewb.any_response\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=1999950 */ "offcore_response.corewb.any_response\000\000cache\000Counts writebacks (modified to exclusive) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000"
/* offset=2000119 */ "offcore_response.corewb.any_response\000\000cache\000OFFCORE_RESPONSE.COREWB.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000"
/* offset=2000260 */ "offcore_response.corewb.io_csr_mmio\000\000cache\000Offcore writebacks to the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000"
/* offset=2000407 */ "offcore_response.corewb.io_csr_mmio\000\000cache\000REQUEST = CORE_WB and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000"
/* offset=2000554 */ "offcore_response.corewb.l2_hit\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2000945 */ "offcore_response.corewb.l2_hit\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2001346 */ "offcore_response.corewb.l2_miss.any\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2001754 */ "offcore_response.corewb.l2_miss.any\000\000cache\000Counts writeback (modified to exclusive) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000008\000\00000\000\000"
/* offset=2001916 */ "offcore_response.corewb.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2002500 */ "offcore_response.corewb.l2_miss.hitm_other_core\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2003062 */ "offcore_response.corewb.l2_miss.hitm_other_core\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2003634 */ "offcore_response.corewb.l2_miss.no_snoop_needed\000\000cache\000Counts writeback (modified to exclusive) that miss L2 with no details on snoop-related information\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080000008\000\00000\000\000"
/* offset=2003853 */ "offcore_response.corewb.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2004402 */ "offcore_response.corewb.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2004941 */ "offcore_response.corewb.l3_hit.any_snoop\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0008\000\00000\000\000"
/* offset=2005096 */ "offcore_response.corewb.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0008\000\00000\000\000"
/* offset=2005257 */ "offcore_response.corewb.l3_hit.snoop_hitm\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0008\000\00000\000\000"
/* offset=2005413 */ "offcore_response.corewb.l3_hit.snoop_miss\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0008\000\00000\000\000"
/* offset=2005568 */ "offcore_response.corewb.l3_hit.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0008\000\00000\000\000"
/* offset=2005729 */ "offcore_response.corewb.l3_hit.snoop_none\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0008\000\00000\000\000"
/* offset=2005883 */ "offcore_response.corewb.l3_hit.snoop_not_needed\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0008\000\00000\000\000"
/* offset=2006044 */ "offcore_response.corewb.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000008\000\00000\000\000"
/* offset=2006207 */ "offcore_response.corewb.l3_miss.snoop_miss\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000008\000\00000\000\000"
/* offset=2006364 */ "offcore_response.corewb.l3_miss.snoop_none\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000008\000\00000\000\000"
/* offset=2006520 */ "offcore_response.corewb.l3_miss.snoop_not_needed\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000008\000\00000\000\000"
/* offset=2006683 */ "offcore_response.corewb.l3_miss_local_dram.any_snoop\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000008\000\00000\000\000"
/* offset=2006851 */ "offcore_response.corewb.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000008\000\00000\000\000"
/* offset=2007025 */ "offcore_response.corewb.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000008\000\00000\000\000"
/* offset=2007194 */ "offcore_response.corewb.l3_miss_local_dram.snoop_miss\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000008\000\00000\000\000"
/* offset=2007362 */ "offcore_response.corewb.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000008\000\00000\000\000"
/* offset=2007535 */ "offcore_response.corewb.l3_miss_local_dram.snoop_none\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000008\000\00000\000\000"
/* offset=2007702 */ "offcore_response.corewb.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000008\000\00000\000\000"
/* offset=2007876 */ "offcore_response.corewb.llc_hit_no_other_core\000\000cache\000Offcore writebacks to the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000"
/* offset=2008049 */ "offcore_response.corewb.llc_hit_no_other_core\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000"
/* offset=2008215 */ "offcore_response.corewb.llc_hit_other_core_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x208\000\00000\000\000"
/* offset=2008383 */ "offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000Offcore writebacks to the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000"
/* offset=2008554 */ "offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000"
/* offset=2008724 */ "offcore_response.corewb.local_cache\000\000cache\000Offcore writebacks to the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000"
/* offset=2008855 */ "offcore_response.corewb.local_cache\000\000cache\000REQUEST = CORE_WB and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000"
/* offset=2009001 */ "offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2708\000\00000\000\000"
/* offset=2009152 */ "offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4708\000\00000\000\000"
/* offset=2009303 */ "offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000"
/* offset=2009442 */ "offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000"
/* offset=2009581 */ "offcore_response.corewb.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000"
/* offset=2009768 */ "offcore_response.corewb.other_local_dram\000\000memory\000REQUEST = CORE_WB and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000"
/* offset=2009926 */ "offcore_response.corewb.outstanding\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2010460 */ "offcore_response.corewb.remote_cache\000\000cache\000Offcore writebacks to a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1808\000\00000\000\000"
/* offset=2010600 */ "offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3808\000\00000\000\000"
/* offset=2010760 */ "offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5808\000\00000\000\000"
/* offset=2010920 */ "offcore_response.corewb.remote_cache_hit\000\000cache\000Offcore writebacks that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000"
/* offset=2011073 */ "offcore_response.corewb.remote_cache_hitm\000\000cache\000Offcore writebacks that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000"
/* offset=2011227 */ "offcore_response.corewb.remote_cache_hitm\000\000cache\000REQUEST = CORE_WB and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000"
/* offset=2011385 */ "offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000"
/* offset=2011524 */ "offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000"
/* offset=2011663 */ "offcore_response.corewb.remote_dram\000\000memory\000REQUEST = CORE_WB and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000"
/* offset=2011811 */ "offcore_response.corewb.supplier_none.any_snoop\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020008\000\00000\000\000"
/* offset=2011973 */ "offcore_response.corewb.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020008\000\00000\000\000"
/* offset=2012141 */ "offcore_response.corewb.supplier_none.snoop_hitm\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020008\000\00000\000\000"
/* offset=2012304 */ "offcore_response.corewb.supplier_none.snoop_miss\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020008\000\00000\000\000"
/* offset=2012466 */ "offcore_response.corewb.supplier_none.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020008\000\00000\000\000"
/* offset=2012634 */ "offcore_response.corewb.supplier_none.snoop_none\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020008\000\00000\000\000"
/* offset=2012795 */ "offcore_response.corewb.supplier_none.snoop_not_needed\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020008\000\00000\000\000"
/* offset=2012963 */ "offcore_response.data_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5077\000\00000\000\000"
/* offset=2013167 */ "offcore_response.data_ifetch.any_cache_dram\000\000cache\000Offcore code or data read requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F77\000\00000\000\000"
/* offset=2013343 */ "offcore_response.data_ifetch.any_cache_dram\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f77\000\00000\000\000"
/* offset=2013505 */ "offcore_response.data_ifetch.any_dram\000\000memory\000Offcore code or data read requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6077\000\00000\000\000"
/* offset=2013667 */ "offcore_response.data_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3077\000\00000\000\000"
/* offset=2013848 */ "offcore_response.data_ifetch.any_llc_miss\000\000memory\000Offcore code or data read requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF877\000\00000\000\000"
/* offset=2014012 */ "offcore_response.data_ifetch.any_llc_miss\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf877\000\00000\000\000"
/* offset=2014171 */ "offcore_response.data_ifetch.any_location\000\000cache\000All offcore code or data read requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF77\000\00000\000\000"
/* offset=2014318 */ "offcore_response.data_ifetch.any_location\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff77\000\00000\000\000"
/* offset=2014476 */ "offcore_response.data_ifetch.io_csr_mmio\000\000cache\000Offcore code or data read requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000"
/* offset=2014654 */ "offcore_response.data_ifetch.io_csr_mmio\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000"
/* offset=2014810 */ "offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code or data read requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000"
/* offset=2015014 */ "offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000"
/* offset=2015189 */ "offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code or data read requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000"
/* offset=2015388 */ "offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000"
/* offset=2015565 */ "offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code or data read requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000"
/* offset=2015767 */ "offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000"
/* offset=2015946 */ "offcore_response.data_ifetch.local_cache\000\000cache\000Offcore code or data read requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000"
/* offset=2016108 */ "offcore_response.data_ifetch.local_cache\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000"
/* offset=2016263 */ "offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2777\000\00000\000\000"
/* offset=2016445 */ "offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4777\000\00000\000\000"
/* offset=2016627 */ "offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000"
/* offset=2016797 */ "offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000"
/* offset=2016967 */ "offcore_response.data_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000"
/* offset=2017163 */ "offcore_response.data_ifetch.other_local_dram\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000"
/* offset=2017330 */ "offcore_response.data_ifetch.remote_cache\000\000cache\000Offcore code or data read requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1877\000\00000\000\000"
/* offset=2017501 */ "offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3877\000\00000\000\000"
/* offset=2017692 */ "offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5877\000\00000\000\000"
/* offset=2017883 */ "offcore_response.data_ifetch.remote_cache_hit\000\000cache\000Offcore code or data read requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000"
/* offset=2018057 */ "offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000Offcore code or data read requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000"
/* offset=2018232 */ "offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000"
/* offset=2018399 */ "offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000"
/* offset=2018569 */ "offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000"
/* offset=2018739 */ "offcore_response.data_ifetch.remote_dram\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000"
/* offset=2018896 */ "offcore_response.data_in.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5033\000\00000\000\000"
/* offset=2019092 */ "offcore_response.data_in.any_cache_dram\000\000cache\000Offcore request = all data, response = any cache_dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F33\000\00000\000\000"
/* offset=2019252 */ "offcore_response.data_in.any_cache_dram\000\000cache\000REQUEST = DATA_IN and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f33\000\00000\000\000"
/* offset=2019406 */ "offcore_response.data_in.any_dram\000\000memory\000Offcore request = all data, response = any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6033\000\00000\000\000"
/* offset=2019555 */ "offcore_response.data_in.any_dram_and_remote_fwd\000\000memory\000REQUEST = DATA_IN and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3033\000\00000\000\000"
/* offset=2019728 */ "offcore_response.data_in.any_llc_miss\000\000memory\000Offcore request = all data, response = any LLC miss\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF833\000\00000\000\000"
/* offset=2019885 */ "offcore_response.data_in.any_llc_miss\000\000memory\000REQUEST = DATA_IN and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf833\000\00000\000\000"
/* offset=2020036 */ "offcore_response.data_in.any_location\000\000cache\000Offcore request = all data, response = any location\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF33\000\00000\000\000"
/* offset=2020192 */ "offcore_response.data_in.any_location\000\000cache\000REQUEST = DATA_IN and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff33\000\00000\000\000"
/* offset=2020342 */ "offcore_response.data_in.any_response\000\000cache\000REQUEST = DATA_INTO_CORE and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10433\000\00000\000\000"
/* offset=2020500 */ "offcore_response.data_in.io_csr_mmio\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000"
/* offset=2020680 */ "offcore_response.data_in.io_csr_mmio\000\000cache\000REQUEST = DATA_IN and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000"
/* offset=2020828 */ "offcore_response.data_in.llc_hit_no_other_core\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000"
/* offset=2021034 */ "offcore_response.data_in.llc_hit_no_other_core\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000"
/* offset=2021201 */ "offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000"
/* offset=2021402 */ "offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000"
/* offset=2021571 */ "offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000"
/* offset=2021775 */ "offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000"
/* offset=2021946 */ "offcore_response.data_in.local_cache\000\000cache\000Offcore request = all data, response = local cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000"
/* offset=2022099 */ "offcore_response.data_in.local_cache\000\000cache\000REQUEST = DATA_IN and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000"
/* offset=2022246 */ "offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2733\000\00000\000\000"
/* offset=2022413 */ "offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4733\000\00000\000\000"
/* offset=2022580 */ "offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000"
/* offset=2022752 */ "offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000"
/* offset=2022924 */ "offcore_response.data_in.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000"
/* offset=2023112 */ "offcore_response.data_in.other_local_dram\000\000memory\000REQUEST = DATA_IN and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000"
/* offset=2023271 */ "offcore_response.data_in.remote_cache\000\000cache\000Offcore request = all data, response = remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1833\000\00000\000\000"
/* offset=2023427 */ "offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3833\000\00000\000\000"
/* offset=2023596 */ "offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5833\000\00000\000\000"
/* offset=2023765 */ "offcore_response.data_in.remote_cache_hit\000\000cache\000Offcore data reads, RFOs, and prefetches that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000"
/* offset=2023941 */ "offcore_response.data_in.remote_cache_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000"
/* offset=2024118 */ "offcore_response.data_in.remote_cache_hitm\000\000cache\000REQUEST = DATA_IN and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000"
/* offset=2024277 */ "offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000"
/* offset=2024451 */ "offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000"
/* offset=2024625 */ "offcore_response.data_in.remote_dram\000\000memory\000REQUEST = DATA_IN and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000"
/* offset=2024774 */ "offcore_response.data_in_socket.llc_miss.local_dram\000\000memory\000Counts LLC replacements\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004001b3\000\00000\000This event counts all data requests (demand/prefetch data reads and demand data writes (RFOs) that miss the LLC  where the data is returned from local DRAM\000"
/* offset=2025077 */ "offcore_response.data_in_socket.llc_miss.local_dram\000\000memory\000Counts LLC replacements\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004001b3\000\00000\000\000"
/* offset=2025225 */ "offcore_response.data_in_socket.llc_miss_local.any_llc_hit\000\000memory\000REQUEST = DATA_IN_SOCKET and RESPONSE = LLC_MISS_LOCAL and SNOOP = ANY_LLC_HIT\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x17004001b3\000\00000\000\000"
/* offset=2025436 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000"
/* offset=2025600 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000"
/* offset=2025769 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010004\000\00000\000\000"
/* offset=2025913 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand and DCU prefetch instruction cacheline that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000\000"
/* offset=2026111 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand code reads and prefetch code reads that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000\000"
/* offset=2026308 */ "offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2026829 */ "offcore_response.demand_code_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00010\000\000"
/* offset=2027018 */ "offcore_response.demand_code_rd.ddr\000\000memory\000Counts demand code reads and prefetch code reads that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800004\000\00000\000\000"
/* offset=2027229 */ "offcore_response.demand_code_rd.ddr_far\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000004\000\00000\000\000"
/* offset=2027438 */ "offcore_response.demand_code_rd.ddr_near\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800004\000\00000\000\000"
/* offset=2027650 */ "offcore_response.demand_code_rd.l2_hit\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2028085 */ "offcore_response.demand_code_rd.l2_hit\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2028530 */ "offcore_response.demand_code_rd.l2_hit_far_tile\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400004\000\00000\000\000"
/* offset=2028885 */ "offcore_response.demand_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400004\000\00000\000\000"
/* offset=2029248 */ "offcore_response.demand_code_rd.l2_hit_far_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400004\000\00000\000\000"
/* offset=2029573 */ "offcore_response.demand_code_rd.l2_hit_near_tile\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180004\000\00000\000\000"
/* offset=2029857 */ "offcore_response.demand_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080004\000\00000\000\000"
/* offset=2030147 */ "offcore_response.demand_code_rd.l2_hit_near_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000"
/* offset=2030433 */ "offcore_response.demand_code_rd.l2_hit_this_tile_e\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000004\000\00000\000\000"
/* offset=2030682 */ "offcore_response.demand_code_rd.l2_hit_this_tile_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000004\000\00000\000\000"
/* offset=2030931 */ "offcore_response.demand_code_rd.l2_hit_this_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000004\000\00000\000\000"
/* offset=2031180 */ "offcore_response.demand_code_rd.l2_hit_this_tile_s\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000004\000\00000\000\000"
/* offset=2031429 */ "offcore_response.demand_code_rd.l2_miss.any\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000004\000\00000\000\000"
/* offset=2031611 */ "offcore_response.demand_code_rd.l2_miss.any\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2032063 */ "offcore_response.demand_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000004\000\00000\000\000"
/* offset=2032349 */ "offcore_response.demand_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2032977 */ "offcore_response.demand_code_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2033583 */ "offcore_response.demand_code_rd.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000\000"
/* offset=2033799 */ "offcore_response.demand_code_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2034392 */ "offcore_response.demand_code_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2034975 */ "offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000"
/* offset=2035144 */ "offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000"
/* offset=2035294 */ "offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0004\000\00000\000\000"
/* offset=2035444 */ "offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00010\000\000"
/* offset=2035646 */ "offcore_response.demand_code_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00010\000\000"
/* offset=2035865 */ "offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=2036126 */ "offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=2036399 */ "offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00010\000\000"
/* offset=2036624 */ "offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=2036887 */ "offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=2037155 */ "offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00010\000\000"
/* offset=2037369 */ "offcore_response.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand code reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000"
/* offset=2037670 */ "offcore_response.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00010\000\000"
/* offset=2037883 */ "offcore_response.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0004\000\00000\000\000"
/* offset=2038039 */ "offcore_response.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=2038195 */ "offcore_response.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_CODE_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000"
/* offset=2038382 */ "offcore_response.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0004\000\00010\000\000"
/* offset=2038601 */ "offcore_response.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0004\000\00000\000\000"
/* offset=2038752 */ "offcore_response.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=2038903 */ "offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0004\000\00000\000\000"
/* offset=2039053 */ "offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000"
/* offset=2039203 */ "offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00010\000\000"
/* offset=2039406 */ "offcore_response.demand_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0004\000\00000\000\000"
/* offset=2039562 */ "offcore_response.demand_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0004\000\00000\000\000"
/* offset=2039718 */ "offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0004\000\00000\000\000"
/* offset=2039867 */ "offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00000\000\000"
/* offset=2040016 */ "offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00010\000\000"
/* offset=2040218 */ "offcore_response.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0004\000\00000\000\000"
/* offset=2040374 */ "offcore_response.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000"
/* offset=2040530 */ "offcore_response.demand_code_rd.l3_hit.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0004\000\00000\000\000"
/* offset=2040676 */ "offcore_response.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080004\000\00000\000\000"
/* offset=2040828 */ "offcore_response.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080004\000\00010\000\000"
/* offset=2041034 */ "offcore_response.demand_code_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080004\000\00010\000\000"
/* offset=2041257 */ "offcore_response.demand_code_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00010\000\000"
/* offset=2041486 */ "offcore_response.demand_code_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00010\000\000"
/* offset=2041704 */ "offcore_response.demand_code_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00010\000\000"
/* offset=2041921 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00000\000\000"
/* offset=2042079 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000"
/* offset=2042232 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00000\000\000"
/* offset=2042384 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00010\000\000"
/* offset=2042591 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080004\000\00000\000\000"
/* offset=2042749 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00000\000\000"
/* offset=2042900 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00010\000\000"
/* offset=2043106 */ "offcore_response.demand_code_rd.l3_hit_e.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00000\000\000"
/* offset=2043264 */ "offcore_response.demand_code_rd.l3_hit_e.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080004\000\00000\000\000"
/* offset=2043412 */ "offcore_response.demand_code_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200004\000\00010\000\000"
/* offset=2043618 */ "offcore_response.demand_code_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200004\000\00010\000\000"
/* offset=2043841 */ "offcore_response.demand_code_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200004\000\00010\000\000"
/* offset=2044070 */ "offcore_response.demand_code_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200004\000\00010\000\000"
/* offset=2044288 */ "offcore_response.demand_code_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200004\000\00010\000\000"
/* offset=2044505 */ "offcore_response.demand_code_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200004\000\00010\000\000"
/* offset=2044712 */ "offcore_response.demand_code_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200004\000\00010\000\000"
/* offset=2044918 */ "offcore_response.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040004\000\00000\000\000"
/* offset=2045070 */ "offcore_response.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040004\000\00010\000\000"
/* offset=2045276 */ "offcore_response.demand_code_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040004\000\00010\000\000"
/* offset=2045499 */ "offcore_response.demand_code_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00010\000\000"
/* offset=2045728 */ "offcore_response.demand_code_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00010\000\000"
/* offset=2045946 */ "offcore_response.demand_code_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00010\000\000"
/* offset=2046163 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00000\000\000"
/* offset=2046321 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00000\000\000"
/* offset=2046474 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00000\000\000"
/* offset=2046626 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00010\000\000"
/* offset=2046833 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040004\000\00000\000\000"
/* offset=2046991 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00000\000\000"
/* offset=2047142 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00010\000\000"
/* offset=2047348 */ "offcore_response.demand_code_rd.l3_hit_m.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00000\000\000"
/* offset=2047506 */ "offcore_response.demand_code_rd.l3_hit_m.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040004\000\00000\000\000"
/* offset=2047654 */ "offcore_response.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100004\000\00000\000\000"
/* offset=2047806 */ "offcore_response.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100004\000\00010\000\000"
/* offset=2048012 */ "offcore_response.demand_code_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100004\000\00010\000\000"
/* offset=2048235 */ "offcore_response.demand_code_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00010\000\000"
/* offset=2048464 */ "offcore_response.demand_code_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00010\000\000"
/* offset=2048682 */ "offcore_response.demand_code_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00010\000\000"
/* offset=2048899 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00000\000\000"
/* offset=2049057 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00000\000\000"
/* offset=2049210 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00000\000\000"
/* offset=2049362 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00010\000\000"
/* offset=2049569 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100004\000\00000\000\000"
/* offset=2049727 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00000\000\000"
/* offset=2049878 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00010\000\000"
/* offset=2050084 */ "offcore_response.demand_code_rd.l3_hit_s.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00000\000\000"
/* offset=2050242 */ "offcore_response.demand_code_rd.l3_hit_s.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100004\000\00000\000\000"
/* offset=2050390 */ "offcore_response.demand_code_rd.l3_miss.any_response\000\000memory\000Counts all demand code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00004\000\00000\000\000"
/* offset=2050560 */ "offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00000\000\000"
/* offset=2050732 */ "offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400004\000\00000\000\000"
/* offset=2050884 */ "offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00010\000\000"
/* offset=2051089 */ "offcore_response.demand_code_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000004\000\00010\000\000"
/* offset=2051311 */ "offcore_response.demand_code_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00010\000\000"
/* offset=2051539 */ "offcore_response.demand_code_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000004\000\00010\000\000"
/* offset=2051756 */ "offcore_response.demand_code_rd.l3_miss.local_dram\000\000memory\000Counts all demand code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000"
/* offset=2051961 */ "offcore_response.demand_code_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00010\000\000"
/* offset=2052177 */ "offcore_response.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand code reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00000\000\000"
/* offset=2052412 */ "offcore_response.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00010\000\000"
/* offset=2052634 */ "offcore_response.demand_code_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand code reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00000\000\000"
/* offset=2052860 */ "offcore_response.demand_code_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00010\000\000"
/* offset=2053069 */ "offcore_response.demand_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00000\000\000"
/* offset=2053227 */ "offcore_response.demand_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400004\000\00000\000\000"
/* offset=2053385 */ "offcore_response.demand_code_rd.l3_miss.snoop_hitm\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400004\000\00000\000\000"
/* offset=2053538 */ "offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00000\000\000"
/* offset=2053690 */ "offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400004\000\00000\000\000"
/* offset=2053842 */ "offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00010\000\000"
/* offset=2054048 */ "offcore_response.demand_code_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00004\000\00000\000\000"
/* offset=2054278 */ "offcore_response.demand_code_rd.l3_miss.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400004\000\00000\000\000"
/* offset=2054435 */ "offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00000\000\000"
/* offset=2054586 */ "offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400004\000\00000\000\000"
/* offset=2054737 */ "offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00010\000\000"
/* offset=2054942 */ "offcore_response.demand_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00000\000\000"
/* offset=2055100 */ "offcore_response.demand_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400004\000\00000\000\000"
/* offset=2055258 */ "offcore_response.demand_code_rd.l3_miss.spl_hit\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400004\000\00000\000\000"
/* offset=2055406 */ "offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00000\000\000"
/* offset=2055569 */ "offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000004\000\00000\000\000"
/* offset=2055732 */ "offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00010\000\000"
/* offset=2055959 */ "offcore_response.demand_code_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000004\000\00010\000\000"
/* offset=2056203 */ "offcore_response.demand_code_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00010\000\000"
/* offset=2056453 */ "offcore_response.demand_code_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00010\000\000"
/* offset=2056692 */ "offcore_response.demand_code_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00010\000\000"
/* offset=2056930 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00000\000\000"
/* offset=2057099 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00000\000\000"
/* offset=2057263 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00000\000\000"
/* offset=2057426 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00010\000\000"
/* offset=2057654 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00000\000\000"
/* offset=2057885 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00010\000\000"
/* offset=2058133 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000004\000\00000\000\000"
/* offset=2058301 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00000\000\000"
/* offset=2058463 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00010\000\000"
/* offset=2058690 */ "offcore_response.demand_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000"
/* offset=2058859 */ "offcore_response.demand_code_rd.l3_miss_local_dram.spl_hit\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000004\000\00000\000\000"
/* offset=2059018 */ "offcore_response.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00000\000\000"
/* offset=2059251 */ "offcore_response.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00010\000\000"
/* offset=2059501 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000004\000\00010\000\000"
/* offset=2059740 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000004\000\00010\000\000"
/* offset=2059996 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000004\000\00010\000\000"
/* offset=2060258 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000004\000\00010\000\000"
/* offset=2060509 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000004\000\00010\000\000"
/* offset=2060759 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000004\000\00010\000\000"
/* offset=2060999 */ "offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000004\000\00010\000\000"
/* offset=2061238 */ "offcore_response.demand_code_rd.l4_hit_local_l4.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400004\000\00000\000\000"
/* offset=2061397 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400004\000\00000\000\000"
/* offset=2061562 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400004\000\00000\000\000"
/* offset=2061722 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400004\000\00000\000\000"
/* offset=2061881 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400004\000\00000\000\000"
/* offset=2062046 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00000\000\000"
/* offset=2062204 */ "offcore_response.demand_code_rd.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000"
/* offset=2062369 */ "offcore_response.demand_code_rd.l4_hit_local_l4.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400004\000\00000\000\000"
/* offset=2062524 */ "offcore_response.demand_code_rd.llc_hit.any_response\000\000cache\000Counts all demand code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0004\000\00000\000\000"
/* offset=2062698 */ "offcore_response.demand_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000"
/* offset=2062960 */ "offcore_response.demand_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0004\000\00000\000\000"
/* offset=2063224 */ "offcore_response.demand_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts all demand code reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000"
/* offset=2063488 */ "offcore_response.demand_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0004\000\00000\000\000"
/* offset=2063754 */ "offcore_response.demand_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0004\000\00000\000\000"
/* offset=2064053 */ "offcore_response.demand_code_rd.llc_hit.snoop_miss\000\000cache\000Counts demand code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0004\000\00000\000\000"
/* offset=2064279 */ "offcore_response.demand_code_rd.llc_miss.any_response\000\000memory\000Counts all demand code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000"
/* offset=2064450 */ "offcore_response.demand_code_rd.llc_miss.any_response\000\000memory\000Counts all demand code reads that miss the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20004\000\00000\000\000"
/* offset=2064624 */ "offcore_response.demand_code_rd.llc_miss.dram\000\000memory\000Counts demand code reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400004\000\00000\000\000"
/* offset=2064817 */ "offcore_response.demand_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400004\000\00000\000\000"
/* offset=2065023 */ "offcore_response.demand_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400004\000\00000\000\000"
/* offset=2065233 */ "offcore_response.demand_code_rd.llc_miss.remote_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800004\000\00000\000\000"
/* offset=2065445 */ "offcore_response.demand_code_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand code reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820004\000\00000\000\000"
/* offset=2065666 */ "offcore_response.demand_code_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand code reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00004\000\00000\000\000"
/* offset=2065910 */ "offcore_response.demand_code_rd.mcdram\000\000memory\000Counts demand code reads and prefetch code reads that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600004\000\00000\000\000"
/* offset=2066127 */ "offcore_response.demand_code_rd.mcdram_far\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400004\000\00000\000\000"
/* offset=2066366 */ "offcore_response.demand_code_rd.mcdram_near\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200004\000\00000\000\000"
/* offset=2066583 */ "offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand and DCU prefetch instruction cacheline that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000\000"
/* offset=2066851 */ "offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand code reads and prefetch code reads that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000\000"
/* offset=2067180 */ "offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2067758 */ "offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2068354 */ "offcore_response.demand_code_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400004\000\00010\000\000"
/* offset=2068578 */ "offcore_response.demand_code_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00010\000\000"
/* offset=2068802 */ "offcore_response.demand_code_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00010\000\000"
/* offset=2069039 */ "offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00000\000\000"
/* offset=2069196 */ "offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020004\000\00000\000\000"
/* offset=2069353 */ "offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00010\000\000"
/* offset=2069569 */ "offcore_response.demand_code_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020004\000\00010\000\000"
/* offset=2069802 */ "offcore_response.demand_code_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00010\000\000"
/* offset=2070041 */ "offcore_response.demand_code_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00010\000\000"
/* offset=2070269 */ "offcore_response.demand_code_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00010\000\000"
/* offset=2070496 */ "offcore_response.demand_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00000\000\000"
/* offset=2070659 */ "offcore_response.demand_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00000\000\000"
/* offset=2070817 */ "offcore_response.demand_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00000\000\000"
/* offset=2070974 */ "offcore_response.demand_code_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00010\000\000"
/* offset=2071191 */ "offcore_response.demand_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020004\000\00000\000\000"
/* offset=2071354 */ "offcore_response.demand_code_rd.supplier_none.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00000\000\000"
/* offset=2071510 */ "offcore_response.demand_code_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00010\000\000"
/* offset=2071726 */ "offcore_response.demand_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00000\000\000"
/* offset=2071889 */ "offcore_response.demand_code_rd.supplier_none.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020004\000\00000\000\000"
/* offset=2072042 */ "offcore_response.demand_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5003\000\00000\000\000"
/* offset=2072246 */ "offcore_response.demand_data.any_cache_dram\000\000cache\000Offcore demand data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F03\000\00000\000\000"
/* offset=2072416 */ "offcore_response.demand_data.any_cache_dram\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f03\000\00000\000\000"
/* offset=2072578 */ "offcore_response.demand_data.any_dram\000\000memory\000Offcore demand data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6003\000\00000\000\000"
/* offset=2072734 */ "offcore_response.demand_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3003\000\00000\000\000"
/* offset=2072915 */ "offcore_response.demand_data.any_llc_miss\000\000memory\000Offcore demand data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF803\000\00000\000\000"
/* offset=2073073 */ "offcore_response.demand_data.any_llc_miss\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf803\000\00000\000\000"
/* offset=2073232 */ "offcore_response.demand_data.any_location\000\000cache\000All offcore demand data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF03\000\00000\000\000"
/* offset=2073373 */ "offcore_response.demand_data.any_location\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff03\000\00000\000\000"
/* offset=2073531 */ "offcore_response.demand_data.io_csr_mmio\000\000cache\000Offcore demand data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000"
/* offset=2073703 */ "offcore_response.demand_data.io_csr_mmio\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000"
/* offset=2073859 */ "offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000Offcore demand data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000"
/* offset=2074057 */ "offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000"
/* offset=2074232 */ "offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000Offcore demand data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000"
/* offset=2074425 */ "offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000"
/* offset=2074602 */ "offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000Offcore demand data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000"
/* offset=2074798 */ "offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000"
/* offset=2074977 */ "offcore_response.demand_data.local_cache\000\000cache\000Offcore demand data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000"
/* offset=2075133 */ "offcore_response.demand_data.local_cache\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000"
/* offset=2075288 */ "offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2703\000\00000\000\000"
/* offset=2075464 */ "offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4703\000\00000\000\000"
/* offset=2075640 */ "offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000"
/* offset=2075804 */ "offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000"
/* offset=2075968 */ "offcore_response.demand_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000"
/* offset=2076164 */ "offcore_response.demand_data.other_local_dram\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000"
/* offset=2076331 */ "offcore_response.demand_data.remote_cache\000\000cache\000Offcore demand data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1803\000\00000\000\000"
/* offset=2076496 */ "offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3803\000\00000\000\000"
/* offset=2076681 */ "offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5803\000\00000\000\000"
/* offset=2076866 */ "offcore_response.demand_data.remote_cache_hit\000\000cache\000Offcore demand data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000"
/* offset=2077034 */ "offcore_response.demand_data.remote_cache_hitm\000\000cache\000Offcore demand data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000"
/* offset=2077203 */ "offcore_response.demand_data.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000"
/* offset=2077370 */ "offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000"
/* offset=2077534 */ "offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000"
/* offset=2077698 */ "offcore_response.demand_data.remote_dram\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000"
/* offset=2077855 */ "offcore_response.demand_data_rd.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5001\000\00000\000\000"
/* offset=2078065 */ "offcore_response.demand_data_rd.any_cache_dram\000\000cache\000Offcore demand data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F01\000\00000\000\000"
/* offset=2078235 */ "offcore_response.demand_data_rd.any_cache_dram\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f01\000\00000\000\000"
/* offset=2078403 */ "offcore_response.demand_data_rd.any_dram\000\000memory\000Offcore demand data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6001\000\00000\000\000"
/* offset=2078559 */ "offcore_response.demand_data_rd.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3001\000\00000\000\000"
/* offset=2078746 */ "offcore_response.demand_data_rd.any_llc_miss\000\000memory\000Offcore demand data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF801\000\00000\000\000"
/* offset=2078904 */ "offcore_response.demand_data_rd.any_llc_miss\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf801\000\00000\000\000"
/* offset=2079069 */ "offcore_response.demand_data_rd.any_location\000\000cache\000All offcore demand data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF01\000\00000\000\000"
/* offset=2079210 */ "offcore_response.demand_data_rd.any_location\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff01\000\00000\000\000"
/* offset=2079374 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts all demand data reads \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010001\000\00000\000\000"
/* offset=2079519 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts all demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010001\000\00000\000\000"
/* offset=2079663 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand and DCU prefetch data read that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000\000"
/* offset=2079849 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000\000"
/* offset=2080053 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand cacheable data reads of full cache lines have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000Counts demand cacheable data reads of full cache lines have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2080490 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=2080650 */ "offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000"
/* offset=2080815 */ "offcore_response.demand_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00010\000\000"
/* offset=2081004 */ "offcore_response.demand_data_rd.ddr\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800001\000\00000\000\000"
/* offset=2081222 */ "offcore_response.demand_data_rd.ddr_far\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000001\000\00000\000\000"
/* offset=2081438 */ "offcore_response.demand_data_rd.ddr_near\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800001\000\00000\000\000"
/* offset=2081657 */ "offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000Offcore demand data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000"
/* offset=2081829 */ "offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000"
/* offset=2081991 */ "offcore_response.demand_data_rd.l2_hit\000\000cache\000Counts demand cacheable data reads of full cache lines hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040001\000\00000\000Counts demand cacheable data reads of full cache lines hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2082342 */ "offcore_response.demand_data_rd.l2_hit\000\000cache\000Counts demand cacheable data reads of full cache lines that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040001\000\00000\000Counts demand cacheable data reads of full cache lines that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2082703 */ "offcore_response.demand_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400001\000\00000\000\000"
/* offset=2083073 */ "offcore_response.demand_data_rd.l2_hit_far_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400001\000\00000\000\000"
/* offset=2083405 */ "offcore_response.demand_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080001\000\00000\000\000"
/* offset=2083702 */ "offcore_response.demand_data_rd.l2_hit_near_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000"
/* offset=2083995 */ "offcore_response.demand_data_rd.l2_hit_this_tile_e\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000001\000\00000\000\000"
/* offset=2084251 */ "offcore_response.demand_data_rd.l2_hit_this_tile_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000001\000\00000\000\000"
/* offset=2084507 */ "offcore_response.demand_data_rd.l2_hit_this_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000001\000\00000\000\000"
/* offset=2084763 */ "offcore_response.demand_data_rd.l2_hit_this_tile_s\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000001\000\00000\000\000"
/* offset=2085019 */ "offcore_response.demand_data_rd.l2_miss.any\000\000cache\000Counts demand and DCU prefetch data read that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000001\000\00000\000\000"
/* offset=2085189 */ "offcore_response.demand_data_rd.l2_miss.any\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2085557 */ "offcore_response.demand_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch data read that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000001\000\00000\000\000"
/* offset=2085831 */ "offcore_response.demand_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2086375 */ "offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand and DCU prefetch data read that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000\000"
/* offset=2086631 */ "offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand cacheable data reads of full cache lines miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000Counts demand cacheable data reads of full cache lines miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2087153 */ "offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2087685 */ "offcore_response.demand_data_rd.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch data read that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000\000"
/* offset=2087889 */ "offcore_response.demand_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand cacheable data reads of full cache lines that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000Counts demand cacheable data reads of full cache lines that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2088398 */ "offcore_response.demand_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand cacheable data reads of full cache lines true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000Counts demand cacheable data reads of full cache lines true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2088897 */ "offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=2089062 */ "offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000"
/* offset=2089208 */ "offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0001\000\00000\000\000"
/* offset=2089354 */ "offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00010\000\000"
/* offset=2089556 */ "offcore_response.demand_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00010\000\000"
/* offset=2089775 */ "offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=2090032 */ "offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=2090301 */ "offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00010\000\000"
/* offset=2090526 */ "offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=2090785 */ "offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=2091049 */ "offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00010\000\000"
/* offset=2091263 */ "offcore_response.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000"
/* offset=2091560 */ "offcore_response.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00010\000\000"
/* offset=2091773 */ "offcore_response.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0001\000\00000\000\000"
/* offset=2091925 */ "offcore_response.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=2092077 */ "offcore_response.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000"
/* offset=2092264 */ "offcore_response.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0001\000\00010\000\000"
/* offset=2092483 */ "offcore_response.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0001\000\00000\000\000"
/* offset=2092630 */ "offcore_response.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=2092777 */ "offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0001\000\00000\000\000"
/* offset=2092923 */ "offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000"
/* offset=2093069 */ "offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00010\000\000"
/* offset=2093272 */ "offcore_response.demand_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0001\000\00000\000\000"
/* offset=2093424 */ "offcore_response.demand_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0001\000\00000\000\000"
/* offset=2093576 */ "offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0001\000\00000\000\000"
/* offset=2093721 */ "offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00000\000\000"
/* offset=2093866 */ "offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00010\000\000"
/* offset=2094068 */ "offcore_response.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0001\000\00000\000\000"
/* offset=2094220 */ "offcore_response.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000"
/* offset=2094372 */ "offcore_response.demand_data_rd.l3_hit.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0001\000\00000\000\000"
/* offset=2094514 */ "offcore_response.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080001\000\00000\000\000"
/* offset=2094662 */ "offcore_response.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080001\000\00010\000\000"
/* offset=2094868 */ "offcore_response.demand_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080001\000\00010\000\000"
/* offset=2095091 */ "offcore_response.demand_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00010\000\000"
/* offset=2095320 */ "offcore_response.demand_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00010\000\000"
/* offset=2095538 */ "offcore_response.demand_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00010\000\000"
/* offset=2095755 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00000\000\000"
/* offset=2095909 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000"
/* offset=2096058 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00000\000\000"
/* offset=2096206 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00010\000\000"
/* offset=2096413 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080001\000\00000\000\000"
/* offset=2096567 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00000\000\000"
/* offset=2096714 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00010\000\000"
/* offset=2096920 */ "offcore_response.demand_data_rd.l3_hit_e.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00000\000\000"
/* offset=2097074 */ "offcore_response.demand_data_rd.l3_hit_e.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080001\000\00000\000\000"
/* offset=2097218 */ "offcore_response.demand_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200001\000\00010\000\000"
/* offset=2097424 */ "offcore_response.demand_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200001\000\00010\000\000"
/* offset=2097647 */ "offcore_response.demand_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200001\000\00010\000\000"
/* offset=2097876 */ "offcore_response.demand_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200001\000\00010\000\000"
/* offset=2098094 */ "offcore_response.demand_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200001\000\00010\000\000"
/* offset=2098311 */ "offcore_response.demand_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200001\000\00010\000\000"
/* offset=2098518 */ "offcore_response.demand_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200001\000\00010\000\000"
/* offset=2098724 */ "offcore_response.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040001\000\00000\000\000"
/* offset=2098872 */ "offcore_response.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040001\000\00010\000\000"
/* offset=2099078 */ "offcore_response.demand_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040001\000\00010\000\000"
/* offset=2099301 */ "offcore_response.demand_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00010\000\000"
/* offset=2099530 */ "offcore_response.demand_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00010\000\000"
/* offset=2099748 */ "offcore_response.demand_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00010\000\000"
/* offset=2099965 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00000\000\000"
/* offset=2100119 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00000\000\000"
/* offset=2100268 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00000\000\000"
/* offset=2100416 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00010\000\000"
/* offset=2100623 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040001\000\00000\000\000"
/* offset=2100777 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00000\000\000"
/* offset=2100924 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00010\000\000"
/* offset=2101130 */ "offcore_response.demand_data_rd.l3_hit_m.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00000\000\000"
/* offset=2101284 */ "offcore_response.demand_data_rd.l3_hit_m.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040001\000\00000\000\000"
/* offset=2101428 */ "offcore_response.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100001\000\00000\000\000"
/* offset=2101576 */ "offcore_response.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100001\000\00010\000\000"
/* offset=2101782 */ "offcore_response.demand_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100001\000\00010\000\000"
/* offset=2102005 */ "offcore_response.demand_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00010\000\000"
/* offset=2102234 */ "offcore_response.demand_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00010\000\000"
/* offset=2102452 */ "offcore_response.demand_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00010\000\000"
/* offset=2102669 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00000\000\000"
/* offset=2102823 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00000\000\000"
/* offset=2102972 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00000\000\000"
/* offset=2103120 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00010\000\000"
/* offset=2103327 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100001\000\00000\000\000"
/* offset=2103481 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00000\000\000"
/* offset=2103628 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00010\000\000"
/* offset=2103834 */ "offcore_response.demand_data_rd.l3_hit_s.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00000\000\000"
/* offset=2103988 */ "offcore_response.demand_data_rd.l3_hit_s.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100001\000\00000\000\000"
/* offset=2104132 */ "offcore_response.demand_data_rd.l3_miss.any_response\000\000memory\000Counts demand data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00001\000\00000\000\000"
/* offset=2104298 */ "offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00000\000\000"
/* offset=2104466 */ "offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400001\000\00000\000\000"
/* offset=2104614 */ "offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00010\000\000"
/* offset=2104819 */ "offcore_response.demand_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000001\000\00010\000\000"
/* offset=2105041 */ "offcore_response.demand_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00010\000\000"
/* offset=2105269 */ "offcore_response.demand_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000001\000\00010\000\000"
/* offset=2105486 */ "offcore_response.demand_data_rd.l3_miss.local_dram\000\000memory\000Counts demand data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000"
/* offset=2105687 */ "offcore_response.demand_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00010\000\000"
/* offset=2105903 */ "offcore_response.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts demand data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00000\000\000"
/* offset=2106134 */ "offcore_response.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00010\000\000"
/* offset=2106356 */ "offcore_response.demand_data_rd.l3_miss.remote_hitm\000\000memory\000Counts demand data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00000\000\000"
/* offset=2106578 */ "offcore_response.demand_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00010\000\000"
/* offset=2106787 */ "offcore_response.demand_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00000\000\000"
/* offset=2106941 */ "offcore_response.demand_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400001\000\00000\000\000"
/* offset=2107095 */ "offcore_response.demand_data_rd.l3_miss.snoop_hitm\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400001\000\00000\000\000"
/* offset=2107244 */ "offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00000\000\000"
/* offset=2107392 */ "offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400001\000\00000\000\000"
/* offset=2107540 */ "offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00010\000\000"
/* offset=2107746 */ "offcore_response.demand_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00001\000\00000\000\000"
/* offset=2107972 */ "offcore_response.demand_data_rd.l3_miss.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400001\000\00000\000\000"
/* offset=2108125 */ "offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00000\000\000"
/* offset=2108272 */ "offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400001\000\00000\000\000"
/* offset=2108419 */ "offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00010\000\000"
/* offset=2108624 */ "offcore_response.demand_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00000\000\000"
/* offset=2108778 */ "offcore_response.demand_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400001\000\00000\000\000"
/* offset=2108932 */ "offcore_response.demand_data_rd.l3_miss.spl_hit\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400001\000\00000\000\000"
/* offset=2109076 */ "offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00000\000\000"
/* offset=2109235 */ "offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000001\000\00000\000\000"
/* offset=2109394 */ "offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00010\000\000"
/* offset=2109621 */ "offcore_response.demand_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000001\000\00010\000\000"
/* offset=2109865 */ "offcore_response.demand_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00010\000\000"
/* offset=2110115 */ "offcore_response.demand_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00010\000\000"
/* offset=2110354 */ "offcore_response.demand_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00010\000\000"
/* offset=2110592 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00000\000\000"
/* offset=2110757 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00000\000\000"
/* offset=2110917 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00000\000\000"
/* offset=2111076 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00010\000\000"
/* offset=2111304 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00000\000\000"
/* offset=2111531 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00010\000\000"
/* offset=2111779 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000001\000\00000\000\000"
/* offset=2111943 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00000\000\000"
/* offset=2112101 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00010\000\000"
/* offset=2112328 */ "offcore_response.demand_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000"
/* offset=2112493 */ "offcore_response.demand_data_rd.l3_miss_local_dram.spl_hit\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000001\000\00000\000\000"
/* offset=2112648 */ "offcore_response.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00000\000\000"
/* offset=2112877 */ "offcore_response.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00010\000\000"
/* offset=2113127 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000001\000\00010\000\000"
/* offset=2113366 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000001\000\00010\000\000"
/* offset=2113622 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000001\000\00010\000\000"
/* offset=2113884 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000001\000\00010\000\000"
/* offset=2114135 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000001\000\00010\000\000"
/* offset=2114385 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000001\000\00010\000\000"
/* offset=2114625 */ "offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000001\000\00010\000\000"
/* offset=2114864 */ "offcore_response.demand_data_rd.l4_hit_local_l4.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400001\000\00000\000\000"
/* offset=2115019 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400001\000\00000\000\000"
/* offset=2115180 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400001\000\00000\000\000"
/* offset=2115336 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400001\000\00000\000\000"
/* offset=2115491 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400001\000\00000\000\000"
/* offset=2115652 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00000\000\000"
/* offset=2115806 */ "offcore_response.demand_data_rd.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000"
/* offset=2115967 */ "offcore_response.demand_data_rd.l4_hit_local_l4.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400001\000\00000\000\000"
/* offset=2116118 */ "offcore_response.demand_data_rd.llc_hit.any_response\000\000cache\000Counts all demand data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0001\000\00000\000\000"
/* offset=2116292 */ "offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000"
/* offset=2116550 */ "offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0001\000\00000\000\000"
/* offset=2116814 */ "offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000"
/* offset=2117074 */ "offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0001\000\00000\000\000"
/* offset=2117340 */ "offcore_response.demand_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0001\000\00000\000\000"
/* offset=2117639 */ "offcore_response.demand_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0001\000\00000\000\000"
/* offset=2117855 */ "offcore_response.demand_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0001\000\00000\000\000"
/* offset=2118081 */ "offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000Offcore demand data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000"
/* offset=2118279 */ "offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000"
/* offset=2118460 */ "offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore demand data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000"
/* offset=2118653 */ "offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000"
/* offset=2118836 */ "offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore demand data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000"
/* offset=2119032 */ "offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000"
/* offset=2119217 */ "offcore_response.demand_data_rd.llc_miss.any_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00001\000\00000\000\000"
/* offset=2119430 */ "offcore_response.demand_data_rd.llc_miss.any_response\000\000memory\000Counts demand data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000"
/* offset=2119597 */ "offcore_response.demand_data_rd.llc_miss.any_response\000\000memory\000Counts demand data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20001\000\00000\000\000"
/* offset=2119770 */ "offcore_response.demand_data_rd.llc_miss.dram\000\000memory\000Counts demand data reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400001\000\00000\000\000"
/* offset=2119963 */ "offcore_response.demand_data_rd.llc_miss.local_dram\000\000memory\000Counts demand data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400001\000\00000\000\000"
/* offset=2120165 */ "offcore_response.demand_data_rd.llc_miss.local_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400001\000\00000\000\000"
/* offset=2120371 */ "offcore_response.demand_data_rd.llc_miss.remote_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800001\000\00000\000\000"
/* offset=2120579 */ "offcore_response.demand_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts demand data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820001\000\00000\000\000"
/* offset=2120796 */ "offcore_response.demand_data_rd.llc_miss.remote_hitm\000\000memory\000Counts demand data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00001\000\00000\000\000"
/* offset=2121036 */ "offcore_response.demand_data_rd.local_cache\000\000cache\000Offcore demand data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000"
/* offset=2121192 */ "offcore_response.demand_data_rd.local_cache\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000"
/* offset=2121353 */ "offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2701\000\00000\000\000"
/* offset=2121529 */ "offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4701\000\00000\000\000"
/* offset=2121705 */ "offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000"
/* offset=2121869 */ "offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000"
/* offset=2122033 */ "offcore_response.demand_data_rd.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000"
/* offset=2122235 */ "offcore_response.demand_data_rd.mcdram\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600001\000\00000\000\000"
/* offset=2122459 */ "offcore_response.demand_data_rd.mcdram_far\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400001\000\00000\000\000"
/* offset=2122705 */ "offcore_response.demand_data_rd.mcdram_near\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200001\000\00000\000\000"
/* offset=2122929 */ "offcore_response.demand_data_rd.other_local_dram\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000"
/* offset=2123102 */ "offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand and DCU prefetch data read that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000\000"
/* offset=2123358 */ "offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000\000"
/* offset=2123694 */ "offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data reads of full cache lines outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000Counts demand cacheable data reads of full cache lines outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2124188 */ "offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data reads of full cache lines that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000Counts demand cacheable data reads of full cache lines that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2124700 */ "offcore_response.demand_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400001\000\00010\000\000"
/* offset=2124924 */ "offcore_response.demand_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00010\000\000"
/* offset=2125148 */ "offcore_response.demand_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00010\000\000"
/* offset=2125385 */ "offcore_response.demand_data_rd.remote_cache\000\000cache\000Offcore demand data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1801\000\00000\000\000"
/* offset=2125550 */ "offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3801\000\00000\000\000"
/* offset=2125735 */ "offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5801\000\00000\000\000"
/* offset=2125920 */ "offcore_response.demand_data_rd.remote_cache_hit\000\000cache\000Offcore demand data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000"
/* offset=2126088 */ "offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000Offcore demand data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000"
/* offset=2126257 */ "offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000"
/* offset=2126430 */ "offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000"
/* offset=2126594 */ "offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000"
/* offset=2126758 */ "offcore_response.demand_data_rd.remote_dram\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000"
/* offset=2126921 */ "offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00000\000\000"
/* offset=2127074 */ "offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020001\000\00000\000\000"
/* offset=2127227 */ "offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00010\000\000"
/* offset=2127443 */ "offcore_response.demand_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020001\000\00010\000\000"
/* offset=2127676 */ "offcore_response.demand_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00010\000\000"
/* offset=2127915 */ "offcore_response.demand_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00010\000\000"
/* offset=2128143 */ "offcore_response.demand_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00010\000\000"
/* offset=2128370 */ "offcore_response.demand_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00000\000\000"
/* offset=2128529 */ "offcore_response.demand_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00000\000\000"
/* offset=2128683 */ "offcore_response.demand_data_rd.supplier_none.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00000\000\000"
/* offset=2128836 */ "offcore_response.demand_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00010\000\000"
/* offset=2129053 */ "offcore_response.demand_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020001\000\00000\000\000"
/* offset=2129212 */ "offcore_response.demand_data_rd.supplier_none.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00000\000\000"
/* offset=2129364 */ "offcore_response.demand_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00010\000\000"
/* offset=2129580 */ "offcore_response.demand_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00000\000\000"
/* offset=2129739 */ "offcore_response.demand_data_rd.supplier_none.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020001\000\00000\000\000"
/* offset=2129888 */ "offcore_response.demand_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5004\000\00000\000\000"
/* offset=2130096 */ "offcore_response.demand_ifetch.any_cache_dram\000\000cache\000Offcore demand code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F04\000\00000\000\000"
/* offset=2130265 */ "offcore_response.demand_ifetch.any_cache_dram\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f04\000\00000\000\000"
/* offset=2130431 */ "offcore_response.demand_ifetch.any_dram\000\000memory\000Offcore demand code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6004\000\00000\000\000"
/* offset=2130586 */ "offcore_response.demand_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3004\000\00000\000\000"
/* offset=2130771 */ "offcore_response.demand_ifetch.any_llc_miss\000\000memory\000Offcore demand code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF804\000\00000\000\000"
/* offset=2130928 */ "offcore_response.demand_ifetch.any_llc_miss\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf804\000\00000\000\000"
/* offset=2131091 */ "offcore_response.demand_ifetch.any_location\000\000cache\000All offcore demand code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF04\000\00000\000\000"
/* offset=2131231 */ "offcore_response.demand_ifetch.any_location\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff04\000\00000\000\000"
/* offset=2131393 */ "offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000Offcore demand code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000"
/* offset=2131564 */ "offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000"
/* offset=2131724 */ "offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000Offcore demand code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000"
/* offset=2131921 */ "offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000"
/* offset=2132100 */ "offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore demand code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000"
/* offset=2132292 */ "offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000"
/* offset=2132473 */ "offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore demand code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000"
/* offset=2132668 */ "offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000"
/* offset=2132851 */ "offcore_response.demand_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400004\000\00000\000\000"
/* offset=2133046 */ "offcore_response.demand_ifetch.local_cache\000\000cache\000Offcore demand code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000"
/* offset=2133201 */ "offcore_response.demand_ifetch.local_cache\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000"
/* offset=2133360 */ "offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2704\000\00000\000\000"
/* offset=2133535 */ "offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4704\000\00000\000\000"
/* offset=2133710 */ "offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000"
/* offset=2133873 */ "offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000"
/* offset=2134036 */ "offcore_response.demand_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000"
/* offset=2134236 */ "offcore_response.demand_ifetch.other_local_dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000"
/* offset=2134407 */ "offcore_response.demand_ifetch.remote_cache\000\000cache\000Offcore demand code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1804\000\00000\000\000"
/* offset=2134571 */ "offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3804\000\00000\000\000"
/* offset=2134755 */ "offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5804\000\00000\000\000"
/* offset=2134939 */ "offcore_response.demand_ifetch.remote_cache_hit\000\000cache\000Offcore demand code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000"
/* offset=2135106 */ "offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000Offcore demand code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000"
/* offset=2135274 */ "offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000"
/* offset=2135445 */ "offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000"
/* offset=2135608 */ "offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000"
/* offset=2135771 */ "offcore_response.demand_ifetch.remote_dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000"
/* offset=2135932 */ "offcore_response.demand_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5002\000\00000\000\000"
/* offset=2136134 */ "offcore_response.demand_rfo.any_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F02\000\00000\000\000"
/* offset=2136302 */ "offcore_response.demand_rfo.any_cache_dram\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f02\000\00000\000\000"
/* offset=2136462 */ "offcore_response.demand_rfo.any_dram\000\000memory\000Offcore demand RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6002\000\00000\000\000"
/* offset=2136616 */ "offcore_response.demand_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3002\000\00000\000\000"
/* offset=2136795 */ "offcore_response.demand_rfo.any_llc_miss\000\000memory\000Offcore demand RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF802\000\00000\000\000"
/* offset=2136951 */ "offcore_response.demand_rfo.any_llc_miss\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf802\000\00000\000\000"
/* offset=2137108 */ "offcore_response.demand_rfo.any_location\000\000cache\000All offcore demand RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF02\000\00000\000\000"
/* offset=2137247 */ "offcore_response.demand_rfo.any_location\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff02\000\00000\000\000"
/* offset=2137403 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts Demand cacheable data writes that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010002\000\00000\000\000"
/* offset=2137583 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand data writes (RFOs) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=2137751 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand data writes (RFOs) that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000"
/* offset=2137924 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand rfo's \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010002\000\00000\000\000"
/* offset=2138060 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand rfo's\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010002\000\00000\000\000"
/* offset=2138195 */ "offcore_response.demand_rfo.any_response\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2138706 */ "offcore_response.demand_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00010\000\000"
/* offset=2138887 */ "offcore_response.demand_rfo.ddr\000\000memory\000Counts Demand cacheable data writes that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800002\000\00000\000\000"
/* offset=2139081 */ "offcore_response.demand_rfo.ddr_far\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000002\000\00000\000\000"
/* offset=2139273 */ "offcore_response.demand_rfo.ddr_near\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800002\000\00000\000\000"
/* offset=2139468 */ "offcore_response.demand_rfo.io_csr_mmio\000\000cache\000Offcore demand RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000"
/* offset=2139638 */ "offcore_response.demand_rfo.io_csr_mmio\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000"
/* offset=2139792 */ "offcore_response.demand_rfo.l2_hit\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2140217 */ "offcore_response.demand_rfo.l2_hit\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2140652 */ "offcore_response.demand_rfo.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data writes that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400002\000\00000\000\000"
/* offset=2140990 */ "offcore_response.demand_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400002\000\00000\000\000"
/* offset=2141336 */ "offcore_response.demand_rfo.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400002\000\00000\000\000"
/* offset=2141644 */ "offcore_response.demand_rfo.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data writes that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180002\000\00000\000\000"
/* offset=2141911 */ "offcore_response.demand_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080002\000\00000\000\000"
/* offset=2142184 */ "offcore_response.demand_rfo.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000"
/* offset=2142453 */ "offcore_response.demand_rfo.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000002\000\00000\000\000"
/* offset=2142685 */ "offcore_response.demand_rfo.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000002\000\00000\000\000"
/* offset=2142917 */ "offcore_response.demand_rfo.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000002\000\00000\000\000"
/* offset=2143149 */ "offcore_response.demand_rfo.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000002\000\00000\000\000"
/* offset=2143381 */ "offcore_response.demand_rfo.l2_miss.any\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000002\000\00000\000\000"
/* offset=2143542 */ "offcore_response.demand_rfo.l2_miss.any\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2143984 */ "offcore_response.demand_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000002\000\00000\000\000"
/* offset=2144249 */ "offcore_response.demand_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2144867 */ "offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand and DCU prefetch RFOs that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000\000"
/* offset=2145114 */ "offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2145710 */ "offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2146316 */ "offcore_response.demand_rfo.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000\000"
/* offset=2146511 */ "offcore_response.demand_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2147094 */ "offcore_response.demand_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2147667 */ "offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=2147840 */ "offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=2147994 */ "offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0002\000\00000\000\000"
/* offset=2148148 */ "offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00010\000\000"
/* offset=2148342 */ "offcore_response.demand_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00010\000\000"
/* offset=2148553 */ "offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=2148818 */ "offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=2149095 */ "offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00010\000\000"
/* offset=2149312 */ "offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=2149579 */ "offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=2149851 */ "offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00010\000\000"
/* offset=2150057 */ "offcore_response.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000"
/* offset=2150362 */ "offcore_response.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00010\000\000"
/* offset=2150567 */ "offcore_response.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0002\000\00000\000\000"
/* offset=2150727 */ "offcore_response.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=2150887 */ "offcore_response.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000"
/* offset=2151066 */ "offcore_response.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0002\000\00010\000\000"
/* offset=2151277 */ "offcore_response.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0002\000\00000\000\000"
/* offset=2151432 */ "offcore_response.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=2151587 */ "offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0002\000\00000\000\000"
/* offset=2151741 */ "offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000"
/* offset=2151895 */ "offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00010\000\000"
/* offset=2152090 */ "offcore_response.demand_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0002\000\00000\000\000"
/* offset=2152250 */ "offcore_response.demand_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0002\000\00000\000\000"
/* offset=2152410 */ "offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0002\000\00000\000\000"
/* offset=2152563 */ "offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00000\000\000"
/* offset=2152716 */ "offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00010\000\000"
/* offset=2152910 */ "offcore_response.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0002\000\00000\000\000"
/* offset=2153070 */ "offcore_response.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000"
/* offset=2153230 */ "offcore_response.demand_rfo.l3_hit.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0002\000\00000\000\000"
/* offset=2153380 */ "offcore_response.demand_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080002\000\00000\000\000"
/* offset=2153536 */ "offcore_response.demand_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080002\000\00010\000\000"
/* offset=2153734 */ "offcore_response.demand_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080002\000\00010\000\000"
/* offset=2153949 */ "offcore_response.demand_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00010\000\000"
/* offset=2154170 */ "offcore_response.demand_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00010\000\000"
/* offset=2154380 */ "offcore_response.demand_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00010\000\000"
/* offset=2154589 */ "offcore_response.demand_rfo.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00000\000\000"
/* offset=2154751 */ "offcore_response.demand_rfo.l3_hit_e.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000"
/* offset=2154908 */ "offcore_response.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00000\000\000"
/* offset=2155064 */ "offcore_response.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00010\000\000"
/* offset=2155263 */ "offcore_response.demand_rfo.l3_hit_e.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080002\000\00000\000\000"
/* offset=2155425 */ "offcore_response.demand_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00000\000\000"
/* offset=2155580 */ "offcore_response.demand_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00010\000\000"
/* offset=2155778 */ "offcore_response.demand_rfo.l3_hit_e.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00000\000\000"
/* offset=2155940 */ "offcore_response.demand_rfo.l3_hit_e.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080002\000\00000\000\000"
/* offset=2156092 */ "offcore_response.demand_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200002\000\00010\000\000"
/* offset=2156290 */ "offcore_response.demand_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200002\000\00010\000\000"
/* offset=2156505 */ "offcore_response.demand_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200002\000\00010\000\000"
/* offset=2156726 */ "offcore_response.demand_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200002\000\00010\000\000"
/* offset=2156936 */ "offcore_response.demand_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200002\000\00010\000\000"
/* offset=2157145 */ "offcore_response.demand_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200002\000\00010\000\000"
/* offset=2157344 */ "offcore_response.demand_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200002\000\00010\000\000"
/* offset=2157542 */ "offcore_response.demand_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040002\000\00000\000\000"
/* offset=2157698 */ "offcore_response.demand_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040002\000\00010\000\000"
/* offset=2157896 */ "offcore_response.demand_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040002\000\00010\000\000"
/* offset=2158111 */ "offcore_response.demand_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00010\000\000"
/* offset=2158332 */ "offcore_response.demand_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00010\000\000"
/* offset=2158542 */ "offcore_response.demand_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00010\000\000"
/* offset=2158751 */ "offcore_response.demand_rfo.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00000\000\000"
/* offset=2158913 */ "offcore_response.demand_rfo.l3_hit_m.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000"
/* offset=2159070 */ "offcore_response.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00000\000\000"
/* offset=2159226 */ "offcore_response.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00010\000\000"
/* offset=2159425 */ "offcore_response.demand_rfo.l3_hit_m.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040002\000\00000\000\000"
/* offset=2159587 */ "offcore_response.demand_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00000\000\000"
/* offset=2159742 */ "offcore_response.demand_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00010\000\000"
/* offset=2159940 */ "offcore_response.demand_rfo.l3_hit_m.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00000\000\000"
/* offset=2160102 */ "offcore_response.demand_rfo.l3_hit_m.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040002\000\00000\000\000"
/* offset=2160254 */ "offcore_response.demand_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100002\000\00000\000\000"
/* offset=2160410 */ "offcore_response.demand_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100002\000\00010\000\000"
/* offset=2160608 */ "offcore_response.demand_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100002\000\00010\000\000"
/* offset=2160823 */ "offcore_response.demand_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00010\000\000"
/* offset=2161044 */ "offcore_response.demand_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00010\000\000"
/* offset=2161254 */ "offcore_response.demand_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00010\000\000"
/* offset=2161463 */ "offcore_response.demand_rfo.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00000\000\000"
/* offset=2161625 */ "offcore_response.demand_rfo.l3_hit_s.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00000\000\000"
/* offset=2161782 */ "offcore_response.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00000\000\000"
/* offset=2161938 */ "offcore_response.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00010\000\000"
/* offset=2162137 */ "offcore_response.demand_rfo.l3_hit_s.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100002\000\00000\000\000"
/* offset=2162299 */ "offcore_response.demand_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00000\000\000"
/* offset=2162454 */ "offcore_response.demand_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00010\000\000"
/* offset=2162652 */ "offcore_response.demand_rfo.l3_hit_s.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00000\000\000"
/* offset=2162814 */ "offcore_response.demand_rfo.l3_hit_s.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100002\000\00000\000\000"
/* offset=2162966 */ "offcore_response.demand_rfo.l3_miss.any_response\000\000memory\000Counts all demand data writes (RFOs) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00002\000\00000\000\000"
/* offset=2163140 */ "offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs) that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00000\000\000"
/* offset=2163316 */ "offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400002\000\00000\000\000"
/* offset=2163472 */ "offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00010\000\000"
/* offset=2163669 */ "offcore_response.demand_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000002\000\00010\000\000"
/* offset=2163883 */ "offcore_response.demand_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00010\000\000"
/* offset=2164103 */ "offcore_response.demand_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000002\000\00010\000\000"
/* offset=2164312 */ "offcore_response.demand_rfo.l3_miss.local_dram\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000"
/* offset=2164521 */ "offcore_response.demand_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00010\000\000"
/* offset=2164729 */ "offcore_response.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00000\000\000"
/* offset=2164968 */ "offcore_response.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00010\000\000"
/* offset=2165182 */ "offcore_response.demand_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000"
/* offset=2165412 */ "offcore_response.demand_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00010\000\000"
/* offset=2165613 */ "offcore_response.demand_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00000\000\000"
/* offset=2165775 */ "offcore_response.demand_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400002\000\00000\000\000"
/* offset=2165937 */ "offcore_response.demand_rfo.l3_miss.snoop_hitm\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400002\000\00000\000\000"
/* offset=2166094 */ "offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00000\000\000"
/* offset=2166250 */ "offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400002\000\00000\000\000"
/* offset=2166406 */ "offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00010\000\000"
/* offset=2166604 */ "offcore_response.demand_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00002\000\00000\000\000"
/* offset=2166838 */ "offcore_response.demand_rfo.l3_miss.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400002\000\00000\000\000"
/* offset=2166999 */ "offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00000\000\000"
/* offset=2167154 */ "offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400002\000\00000\000\000"
/* offset=2167309 */ "offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00010\000\000"
/* offset=2167506 */ "offcore_response.demand_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00000\000\000"
/* offset=2167668 */ "offcore_response.demand_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400002\000\00000\000\000"
/* offset=2167830 */ "offcore_response.demand_rfo.l3_miss.spl_hit\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400002\000\00000\000\000"
/* offset=2167982 */ "offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00000\000\000"
/* offset=2168149 */ "offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000002\000\00000\000\000"
/* offset=2168316 */ "offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00010\000\000"
/* offset=2168535 */ "offcore_response.demand_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000002\000\00010\000\000"
/* offset=2168771 */ "offcore_response.demand_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00010\000\000"
/* offset=2169013 */ "offcore_response.demand_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00010\000\000"
/* offset=2169244 */ "offcore_response.demand_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00010\000\000"
/* offset=2169474 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00000\000\000"
/* offset=2169647 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00000\000\000"
/* offset=2169815 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00000\000\000"
/* offset=2169982 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00010\000\000"
/* offset=2170202 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00000\000\000"
/* offset=2170437 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00010\000\000"
/* offset=2170677 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000002\000\00000\000\000"
/* offset=2170849 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000"
/* offset=2171015 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00010\000\000"
/* offset=2171234 */ "offcore_response.demand_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000"
/* offset=2171407 */ "offcore_response.demand_rfo.l3_miss_local_dram.spl_hit\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000002\000\00000\000\000"
/* offset=2171570 */ "offcore_response.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00000\000\000"
/* offset=2171807 */ "offcore_response.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00010\000\000"
/* offset=2172049 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000002\000\00010\000\000"
/* offset=2172280 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000002\000\00010\000\000"
/* offset=2172528 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000002\000\00010\000\000"
/* offset=2172782 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000002\000\00010\000\000"
/* offset=2173025 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000002\000\00010\000\000"
/* offset=2173267 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000002\000\00010\000\000"
/* offset=2173499 */ "offcore_response.demand_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00010\000\000"
/* offset=2173730 */ "offcore_response.demand_rfo.l4_hit_local_l4.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400002\000\00000\000\000"
/* offset=2173893 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400002\000\00000\000\000"
/* offset=2174062 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400002\000\00000\000\000"
/* offset=2174226 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400002\000\00000\000\000"
/* offset=2174389 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400002\000\00000\000\000"
/* offset=2174558 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00000\000\000"
/* offset=2174720 */ "offcore_response.demand_rfo.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000"
/* offset=2174889 */ "offcore_response.demand_rfo.l4_hit_local_l4.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400002\000\00000\000\000"
/* offset=2175048 */ "offcore_response.demand_rfo.llc_hit.any_response\000\000cache\000Counts all demand data writes (RFOs) hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000"
/* offset=2175220 */ "offcore_response.demand_rfo.llc_hit.any_response\000\000cache\000Counts all demand data writes (RFOs) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0002\000\00000\000\000"
/* offset=2175398 */ "offcore_response.demand_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000"
/* offset=2175664 */ "offcore_response.demand_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0002\000\00000\000\000"
/* offset=2175932 */ "offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000"
/* offset=2176200 */ "offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0002\000\00000\000\000"
/* offset=2176470 */ "offcore_response.demand_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0002\000\00000\000\000"
/* offset=2176773 */ "offcore_response.demand_rfo.llc_hit.snoop_miss\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0002\000\00000\000\000"
/* offset=2177003 */ "offcore_response.demand_rfo.llc_hit_m.hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_M and SNOOP = HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000"
/* offset=2177181 */ "offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000Offcore demand RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000"
/* offset=2177377 */ "offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000"
/* offset=2177550 */ "offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000Offcore demand RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000"
/* offset=2177741 */ "offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000"
/* offset=2177916 */ "offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore demand RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000"
/* offset=2178110 */ "offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000"
/* offset=2178287 */ "offcore_response.demand_rfo.llc_miss.any_response\000\000memory\000Counts all demand data writes (RFOs) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000"
/* offset=2178462 */ "offcore_response.demand_rfo.llc_miss.dram\000\000memory\000Counts demand data writes (RFOs) that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400002\000\00000\000\000"
/* offset=2178659 */ "offcore_response.demand_rfo.llc_miss.local_dram\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400002\000\00000\000\000"
/* offset=2178869 */ "offcore_response.demand_rfo.llc_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000"
/* offset=2179095 */ "offcore_response.demand_rfo.llc_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) that miss the LLC and the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc20002\000\00000\000\000"
/* offset=2179346 */ "offcore_response.demand_rfo.local_cache\000\000cache\000Offcore demand RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000"
/* offset=2179500 */ "offcore_response.demand_rfo.local_cache\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000"
/* offset=2179653 */ "offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2702\000\00000\000\000"
/* offset=2179827 */ "offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4702\000\00000\000\000"
/* offset=2180001 */ "offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000"
/* offset=2180163 */ "offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000"
/* offset=2180325 */ "offcore_response.demand_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000"
/* offset=2180519 */ "offcore_response.demand_rfo.mcdram\000\000memory\000Counts Demand cacheable data writes that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600002\000\00000\000\000"
/* offset=2180719 */ "offcore_response.demand_rfo.mcdram_far\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400002\000\00000\000\000"
/* offset=2180941 */ "offcore_response.demand_rfo.mcdram_near\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200002\000\00000\000\000"
/* offset=2181141 */ "offcore_response.demand_rfo.other_local_dram\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000"
/* offset=2181306 */ "offcore_response.demand_rfo.outstanding\000\000cache\000Counts Demand cacheable data writes that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000\000"
/* offset=2181618 */ "offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand and DCU prefetch RFOs that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000\000"
/* offset=2181865 */ "offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2182433 */ "offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2183019 */ "offcore_response.demand_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400002\000\00010\000\000"
/* offset=2183235 */ "offcore_response.demand_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00010\000\000"
/* offset=2183451 */ "offcore_response.demand_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00010\000\000"
/* offset=2183680 */ "offcore_response.demand_rfo.remote_cache\000\000cache\000Offcore demand RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1802\000\00000\000\000"
/* offset=2183843 */ "offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3802\000\00000\000\000"
/* offset=2184026 */ "offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5802\000\00000\000\000"
/* offset=2184209 */ "offcore_response.demand_rfo.remote_cache_hit\000\000cache\000Offcore demand RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000"
/* offset=2184375 */ "offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000Offcore demand RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000"
/* offset=2184542 */ "offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000"
/* offset=2184707 */ "offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000"
/* offset=2184869 */ "offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000"
/* offset=2185031 */ "offcore_response.demand_rfo.remote_dram\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000"
/* offset=2185186 */ "offcore_response.demand_rfo.supplier_none.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020002\000\00000\000\000"
/* offset=2185347 */ "offcore_response.demand_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020002\000\00010\000\000"
/* offset=2185555 */ "offcore_response.demand_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020002\000\00010\000\000"
/* offset=2185780 */ "offcore_response.demand_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00010\000\000"
/* offset=2186011 */ "offcore_response.demand_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00010\000\000"
/* offset=2186231 */ "offcore_response.demand_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00010\000\000"
/* offset=2186450 */ "offcore_response.demand_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00000\000\000"
/* offset=2186617 */ "offcore_response.demand_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00000\000\000"
/* offset=2186779 */ "offcore_response.demand_rfo.supplier_none.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00000\000\000"
/* offset=2186940 */ "offcore_response.demand_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00010\000\000"
/* offset=2187149 */ "offcore_response.demand_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020002\000\00000\000\000"
/* offset=2187316 */ "offcore_response.demand_rfo.supplier_none.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00000\000\000"
/* offset=2187476 */ "offcore_response.demand_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00010\000\000"
/* offset=2187684 */ "offcore_response.demand_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00000\000\000"
/* offset=2187851 */ "offcore_response.demand_rfo.supplier_none.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020002\000\00000\000\000"
/* offset=2188008 */ "offcore_response.full_streaming_stores.any_response\000\000cache\000Counts Full streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010800\000\00000\000\000"
/* offset=2188230 */ "offcore_response.full_streaming_stores.any_response\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2188818 */ "offcore_response.full_streaming_stores.l2_hit\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2189320 */ "offcore_response.full_streaming_stores.l2_hit\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2189832 */ "offcore_response.full_streaming_stores.l2_miss.any\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2190351 */ "offcore_response.full_streaming_stores.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2191046 */ "offcore_response.full_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2191719 */ "offcore_response.full_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2192402 */ "offcore_response.full_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2193062 */ "offcore_response.full_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2193712 */ "offcore_response.full_streaming_stores.outstanding\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2194357 */ "offcore_response.other.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = OTHER and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5080\000\00000\000\000"
/* offset=2194549 */ "offcore_response.other.any_cache_dram\000\000cache\000Offcore other requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F80\000\00000\000\000"
/* offset=2194707 */ "offcore_response.other.any_cache_dram\000\000cache\000REQUEST = OTHER and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f80\000\00000\000\000"
/* offset=2194857 */ "offcore_response.other.any_dram\000\000memory\000Offcore other requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6080\000\00000\000\000"
/* offset=2195001 */ "offcore_response.other.any_dram_and_remote_fwd\000\000memory\000REQUEST = OTHER and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3080\000\00000\000\000"
/* offset=2195170 */ "offcore_response.other.any_llc_miss\000\000memory\000Offcore other requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF880\000\00000\000\000"
/* offset=2195316 */ "offcore_response.other.any_llc_miss\000\000memory\000REQUEST = OTHER and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf880\000\00000\000\000"
/* offset=2195463 */ "offcore_response.other.any_location\000\000cache\000All offcore other requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF80\000\00000\000\000"
/* offset=2195592 */ "offcore_response.other.any_location\000\000cache\000REQUEST = OTHER and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff80\000\00000\000\000"
/* offset=2195738 */ "offcore_response.other.any_response\000\000cache\000Counts any other requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000"
/* offset=2195890 */ "offcore_response.other.any_response\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses. It also includes L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000"
/* offset=2196179 */ "offcore_response.other.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00010\000\000"
/* offset=2196350 */ "offcore_response.other.io_csr_mmio\000\000cache\000Offcore other requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000"
/* offset=2196510 */ "offcore_response.other.io_csr_mmio\000\000cache\000REQUEST = OTHER and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000"
/* offset=2196654 */ "offcore_response.other.l3_hit.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00000\000\000"
/* offset=2196792 */ "offcore_response.other.l3_hit.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C8000\000\00000\000\000"
/* offset=2196930 */ "offcore_response.other.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00010\000\000"
/* offset=2197114 */ "offcore_response.other.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C8000\000\00010\000\000"
/* offset=2197315 */ "offcore_response.other.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00010\000\000"
/* offset=2197522 */ "offcore_response.other.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00010\000\000"
/* offset=2197718 */ "offcore_response.other.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00010\000\000"
/* offset=2197913 */ "offcore_response.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C8000\000\00000\000\000"
/* offset=2198057 */ "offcore_response.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000"
/* offset=2198201 */ "offcore_response.other.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C8000\000\00010\000\000"
/* offset=2198402 */ "offcore_response.other.l3_hit.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C8000\000\00000\000\000"
/* offset=2198541 */ "offcore_response.other.l3_hit.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00000\000\000"
/* offset=2198680 */ "offcore_response.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C8000\000\00000\000\000"
/* offset=2198818 */ "offcore_response.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000"
/* offset=2198956 */ "offcore_response.other.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00010\000\000"
/* offset=2199141 */ "offcore_response.other.l3_hit.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C8000\000\00000\000\000"
/* offset=2199285 */ "offcore_response.other.l3_hit.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C8000\000\00000\000\000"
/* offset=2199429 */ "offcore_response.other.l3_hit.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C8000\000\00000\000\000"
/* offset=2199566 */ "offcore_response.other.l3_hit.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00000\000\000"
/* offset=2199703 */ "offcore_response.other.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00010\000\000"
/* offset=2199887 */ "offcore_response.other.l3_hit.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C8000\000\00000\000\000"
/* offset=2200031 */ "offcore_response.other.l3_hit.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000"
/* offset=2200175 */ "offcore_response.other.l3_hit.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C8000\000\00000\000\000"
/* offset=2200309 */ "offcore_response.other.l3_hit_e.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0088000\000\00000\000\000"
/* offset=2200449 */ "offcore_response.other.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80088000\000\00010\000\000"
/* offset=2200637 */ "offcore_response.other.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800088000\000\00010\000\000"
/* offset=2200842 */ "offcore_response.other.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00010\000\000"
/* offset=2201053 */ "offcore_response.other.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00010\000\000"
/* offset=2201253 */ "offcore_response.other.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00010\000\000"
/* offset=2201452 */ "offcore_response.other.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00000\000\000"
/* offset=2201598 */ "offcore_response.other.l3_hit_e.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000"
/* offset=2201739 */ "offcore_response.other.l3_hit_e.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00000\000\000"
/* offset=2201879 */ "offcore_response.other.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00010\000\000"
/* offset=2202068 */ "offcore_response.other.l3_hit_e.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000088000\000\00000\000\000"
/* offset=2202214 */ "offcore_response.other.l3_hit_e.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00000\000\000"
/* offset=2202353 */ "offcore_response.other.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00010\000\000"
/* offset=2202541 */ "offcore_response.other.l3_hit_e.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00000\000\000"
/* offset=2202687 */ "offcore_response.other.l3_hit_e.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40088000\000\00000\000\000"
/* offset=2202823 */ "offcore_response.other.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80208000\000\00010\000\000"
/* offset=2203011 */ "offcore_response.other.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800208000\000\00010\000\000"
/* offset=2203216 */ "offcore_response.other.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400208000\000\00010\000\000"
/* offset=2203427 */ "offcore_response.other.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000208000\000\00010\000\000"
/* offset=2203627 */ "offcore_response.other.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100208000\000\00010\000\000"
/* offset=2203826 */ "offcore_response.other.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200208000\000\00010\000\000"
/* offset=2204015 */ "offcore_response.other.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80208000\000\00010\000\000"
/* offset=2204203 */ "offcore_response.other.l3_hit_m.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0048000\000\00000\000\000"
/* offset=2204343 */ "offcore_response.other.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80048000\000\00010\000\000"
/* offset=2204531 */ "offcore_response.other.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800048000\000\00010\000\000"
/* offset=2204736 */ "offcore_response.other.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00010\000\000"
/* offset=2204947 */ "offcore_response.other.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00010\000\000"
/* offset=2205147 */ "offcore_response.other.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00010\000\000"
/* offset=2205346 */ "offcore_response.other.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00000\000\000"
/* offset=2205492 */ "offcore_response.other.l3_hit_m.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00000\000\000"
/* offset=2205633 */ "offcore_response.other.l3_hit_m.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00000\000\000"
/* offset=2205773 */ "offcore_response.other.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00010\000\000"
/* offset=2205962 */ "offcore_response.other.l3_hit_m.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000048000\000\00000\000\000"
/* offset=2206108 */ "offcore_response.other.l3_hit_m.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00000\000\000"
/* offset=2206247 */ "offcore_response.other.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00010\000\000"
/* offset=2206435 */ "offcore_response.other.l3_hit_m.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00000\000\000"
/* offset=2206581 */ "offcore_response.other.l3_hit_m.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40048000\000\00000\000\000"
/* offset=2206717 */ "offcore_response.other.l3_hit_s.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0108000\000\00000\000\000"
/* offset=2206857 */ "offcore_response.other.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80108000\000\00010\000\000"
/* offset=2207045 */ "offcore_response.other.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800108000\000\00010\000\000"
/* offset=2207250 */ "offcore_response.other.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00010\000\000"
/* offset=2207461 */ "offcore_response.other.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00010\000\000"
/* offset=2207661 */ "offcore_response.other.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00010\000\000"
/* offset=2207860 */ "offcore_response.other.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00000\000\000"
/* offset=2208006 */ "offcore_response.other.l3_hit_s.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00000\000\000"
/* offset=2208147 */ "offcore_response.other.l3_hit_s.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00000\000\000"
/* offset=2208287 */ "offcore_response.other.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00010\000\000"
/* offset=2208476 */ "offcore_response.other.l3_hit_s.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000108000\000\00000\000\000"
/* offset=2208622 */ "offcore_response.other.l3_hit_s.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00000\000\000"
/* offset=2208761 */ "offcore_response.other.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00010\000\000"
/* offset=2208949 */ "offcore_response.other.l3_hit_s.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00000\000\000"
/* offset=2209095 */ "offcore_response.other.l3_hit_s.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40108000\000\00000\000\000"
/* offset=2209231 */ "offcore_response.other.l3_miss.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC408000\000\00000\000\000"
/* offset=2209371 */ "offcore_response.other.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC008000\000\00010\000\000"
/* offset=2209558 */ "offcore_response.other.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C008000\000\00010\000\000"
/* offset=2209762 */ "offcore_response.other.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00010\000\000"
/* offset=2209972 */ "offcore_response.other.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C008000\000\00010\000\000"
/* offset=2210171 */ "offcore_response.other.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00010\000\000"
/* offset=2210369 */ "offcore_response.other.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC08000\000\00010\000\000"
/* offset=2210573 */ "offcore_response.other.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC08000\000\00010\000\000"
/* offset=2210764 */ "offcore_response.other.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00000\000\000"
/* offset=2210910 */ "offcore_response.other.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C408000\000\00000\000\000"
/* offset=2211056 */ "offcore_response.other.l3_miss.snoop_hitm\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C408000\000\00000\000\000"
/* offset=2211197 */ "offcore_response.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00000\000\000"
/* offset=2211337 */ "offcore_response.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C408000\000\00000\000\000"
/* offset=2211477 */ "offcore_response.other.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00010\000\000"
/* offset=2211665 */ "offcore_response.other.l3_miss.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C408000\000\00000\000\000"
/* offset=2211810 */ "offcore_response.other.l3_miss.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00000\000\000"
/* offset=2211949 */ "offcore_response.other.l3_miss.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC408000\000\00000\000\000"
/* offset=2212088 */ "offcore_response.other.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00010\000\000"
/* offset=2212275 */ "offcore_response.other.l3_miss.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00000\000\000"
/* offset=2212421 */ "offcore_response.other.l3_miss.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C408000\000\00000\000\000"
/* offset=2212567 */ "offcore_response.other.l3_miss.spl_hit\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C408000\000\00000\000\000"
/* offset=2212703 */ "offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00000\000\000"
/* offset=2212854 */ "offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4008000\000\00000\000\000"
/* offset=2213005 */ "offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00010\000\000"
/* offset=2213214 */ "offcore_response.other.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804008000\000\00010\000\000"
/* offset=2213440 */ "offcore_response.other.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00010\000\000"
/* offset=2213672 */ "offcore_response.other.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00010\000\000"
/* offset=2213893 */ "offcore_response.other.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00010\000\000"
/* offset=2214113 */ "offcore_response.other.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00000\000\000"
/* offset=2214270 */ "offcore_response.other.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00000\000\000"
/* offset=2214422 */ "offcore_response.other.l3_miss_local_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00000\000\000"
/* offset=2214573 */ "offcore_response.other.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00010\000\000"
/* offset=2214783 */ "offcore_response.other.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604008000\000\00010\000\000"
/* offset=2215013 */ "offcore_response.other.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004008000\000\00000\000\000"
/* offset=2215169 */ "offcore_response.other.l3_miss_local_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00000\000\000"
/* offset=2215319 */ "offcore_response.other.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00010\000\000"
/* offset=2215528 */ "offcore_response.other.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00000\000\000"
/* offset=2215685 */ "offcore_response.other.l3_miss_local_dram.spl_hit\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44008000\000\00000\000\000"
/* offset=2215832 */ "offcore_response.other.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B808000\000\00010\000\000"
/* offset=2216064 */ "offcore_response.other.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90008000\000\00010\000\000"
/* offset=2216285 */ "offcore_response.other.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810008000\000\00010\000\000"
/* offset=2216523 */ "offcore_response.other.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410008000\000\00010\000\000"
/* offset=2216767 */ "offcore_response.other.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010008000\000\00010\000\000"
/* offset=2217000 */ "offcore_response.other.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110008000\000\00010\000\000"
/* offset=2217232 */ "offcore_response.other.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210008000\000\00010\000\000"
/* offset=2217454 */ "offcore_response.other.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90008000\000\00010\000\000"
/* offset=2217675 */ "offcore_response.other.l4_hit_local_l4.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0408000\000\00000\000\000"
/* offset=2217822 */ "offcore_response.other.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400408000\000\00000\000\000"
/* offset=2217975 */ "offcore_response.other.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000408000\000\00000\000\000"
/* offset=2218123 */ "offcore_response.other.l4_hit_local_l4.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200408000\000\00000\000\000"
/* offset=2218270 */ "offcore_response.other.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000408000\000\00000\000\000"
/* offset=2218423 */ "offcore_response.other.l4_hit_local_l4.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00000\000\000"
/* offset=2218569 */ "offcore_response.other.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00000\000\000"
/* offset=2218722 */ "offcore_response.other.l4_hit_local_l4.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40408000\000\00000\000\000"
/* offset=2218865 */ "offcore_response.other.llc_hit_no_other_core\000\000cache\000Offcore other requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000"
/* offset=2219051 */ "offcore_response.other.llc_hit_no_other_core\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000"
/* offset=2219214 */ "offcore_response.other.llc_hit_other_core_hit\000\000cache\000Offcore other requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000"
/* offset=2219395 */ "offcore_response.other.llc_hit_other_core_hit\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000"
/* offset=2219560 */ "offcore_response.other.llc_hit_other_core_hitm\000\000cache\000Offcore other requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000"
/* offset=2219744 */ "offcore_response.other.llc_hit_other_core_hitm\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000"
/* offset=2219911 */ "offcore_response.other.local_cache\000\000cache\000Offcore other requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000"
/* offset=2220055 */ "offcore_response.other.local_cache\000\000cache\000REQUEST = OTHER and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000"
/* offset=2220198 */ "offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2780\000\00000\000\000"
/* offset=2220362 */ "offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4780\000\00000\000\000"
/* offset=2220526 */ "offcore_response.other.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = OTHER and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000"
/* offset=2220710 */ "offcore_response.other.lru_hints\000\000cache\000Counts L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803c8000\000\00000\000\000"
/* offset=2220898 */ "offcore_response.other.other_local_dram\000\000memory\000REQUEST = OTHER and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4080\000\00000\000\000"
/* offset=2221053 */ "offcore_response.other.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80408000\000\00010\000\000"
/* offset=2221259 */ "offcore_response.other.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00010\000\000"
/* offset=2221465 */ "offcore_response.other.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00010\000\000"
/* offset=2221684 */ "offcore_response.other.portio_mmio_uc\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2380408000\000\00000\000\000"
/* offset=2221884 */ "offcore_response.other.portio_mmio_uc\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23ffc08000\000\00000\000\000"
/* offset=2222084 */ "offcore_response.other.remote_cache\000\000cache\000Offcore other requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1880\000\00000\000\000"
/* offset=2222237 */ "offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3880\000\00000\000\000"
/* offset=2222410 */ "offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5880\000\00000\000\000"
/* offset=2222583 */ "offcore_response.other.remote_cache_hit\000\000cache\000Offcore other requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000"
/* offset=2222739 */ "offcore_response.other.remote_cache_hitm\000\000cache\000Offcore other requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000"
/* offset=2222896 */ "offcore_response.other.remote_cache_hitm\000\000cache\000REQUEST = OTHER and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000"
/* offset=2223051 */ "offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000"
/* offset=2223203 */ "offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4080\000\00000\000\000"
/* offset=2223355 */ "offcore_response.other.remote_dram\000\000memory\000REQUEST = OTHER and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000"
/* offset=2223500 */ "offcore_response.other.supplier_none.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00000\000\000"
/* offset=2223645 */ "offcore_response.other.supplier_none.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0028000\000\00000\000\000"
/* offset=2223790 */ "offcore_response.other.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00010\000\000"
/* offset=2223988 */ "offcore_response.other.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800028000\000\00010\000\000"
/* offset=2224203 */ "offcore_response.other.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00010\000\000"
/* offset=2224424 */ "offcore_response.other.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00010\000\000"
/* offset=2224634 */ "offcore_response.other.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00010\000\000"
/* offset=2224843 */ "offcore_response.other.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00000\000\000"
/* offset=2224994 */ "offcore_response.other.supplier_none.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00000\000\000"
/* offset=2225140 */ "offcore_response.other.supplier_none.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00000\000\000"
/* offset=2225285 */ "offcore_response.other.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00010\000\000"
/* offset=2225484 */ "offcore_response.other.supplier_none.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000028000\000\00000\000\000"
/* offset=2225635 */ "offcore_response.other.supplier_none.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00000\000\000"
/* offset=2225779 */ "offcore_response.other.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00010\000\000"
/* offset=2225977 */ "offcore_response.other.supplier_none.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00000\000\000"
/* offset=2226128 */ "offcore_response.other.supplier_none.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40028000\000\00000\000\000"
/* offset=2226269 */ "offcore_response.partial_reads.any_response\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010080\000\00000\000\000"
/* offset=2226498 */ "offcore_response.partial_reads.ddr\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800080\000\00000\000\000"
/* offset=2226741 */ "offcore_response.partial_reads.ddr_far\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000080\000\00000\000\000"
/* offset=2226982 */ "offcore_response.partial_reads.ddr_near\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800080\000\00000\000\000"
/* offset=2227226 */ "offcore_response.partial_reads.l2_hit_far_tile\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400080\000\00000\000\000"
/* offset=2227613 */ "offcore_response.partial_reads.l2_hit_far_tile_e_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400080\000\00000\000\000"
/* offset=2228008 */ "offcore_response.partial_reads.l2_hit_far_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400080\000\00000\000\000"
/* offset=2228365 */ "offcore_response.partial_reads.l2_hit_near_tile\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180080\000\00000\000\000"
/* offset=2228681 */ "offcore_response.partial_reads.l2_hit_near_tile_e_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080080\000\00000\000\000"
/* offset=2229003 */ "offcore_response.partial_reads.l2_hit_near_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080080\000\00000\000\000"
/* offset=2229321 */ "offcore_response.partial_reads.l2_hit_this_tile_e\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000080\000\00000\000\000"
/* offset=2229602 */ "offcore_response.partial_reads.l2_hit_this_tile_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000080\000\00000\000\000"
/* offset=2229883 */ "offcore_response.partial_reads.l2_hit_this_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000080\000\00000\000\000"
/* offset=2230164 */ "offcore_response.partial_reads.l2_hit_this_tile_s\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000080\000\00000\000\000"
/* offset=2230445 */ "offcore_response.partial_reads.l2_miss.any\000\000cache\000Counts demand data partial reads, including data in uncacheable (UC) or uncacheable write combining (USWC) memory types that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000080\000\00000\000Counts demand data partial reads, including data in uncacheable (UC) or uncacheable write combining (USWC) memory types that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2230942 */ "offcore_response.partial_reads.l2_miss.any\000\000cache\000Counts demand reads of partial cache lines (including UC and WC) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000080\000\00000\000\000"
/* offset=2231135 */ "offcore_response.partial_reads.mcdram\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600080\000\00000\000\000"
/* offset=2231384 */ "offcore_response.partial_reads.mcdram_far\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400080\000\00000\000\000"
/* offset=2231655 */ "offcore_response.partial_reads.mcdram_near\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200080\000\00000\000\000"
/* offset=2231904 */ "offcore_response.partial_reads.non_dram\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from any NON_DRAM system address. This includes MMIO transactions\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x2000020080\000\00000\000\000"
/* offset=2232193 */ "offcore_response.partial_reads.outstanding\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000080\000\00000\000\000"
/* offset=2232554 */ "offcore_response.partial_streaming_stores.any_response\000\000cache\000Counts Partial streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014000\000\00000\000\000"
/* offset=2232782 */ "offcore_response.partial_streaming_stores.l2_hit\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2233225 */ "offcore_response.partial_streaming_stores.l2_miss.any\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2233675 */ "offcore_response.partial_streaming_stores.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2234301 */ "offcore_response.partial_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2234915 */ "offcore_response.partial_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2235506 */ "offcore_response.partial_writes.any_response\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010100\000\00000\000\000"
/* offset=2235726 */ "offcore_response.partial_writes.ddr_far\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000100\000\00000\000\000"
/* offset=2235958 */ "offcore_response.partial_writes.ddr_near\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800100\000\00000\000\000"
/* offset=2236193 */ "offcore_response.partial_writes.l2_hit_far_tile\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400100\000\00000\000\000"
/* offset=2236571 */ "offcore_response.partial_writes.l2_hit_far_tile_e_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400100\000\00000\000\000"
/* offset=2236957 */ "offcore_response.partial_writes.l2_hit_far_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400100\000\00000\000\000"
/* offset=2237305 */ "offcore_response.partial_writes.l2_hit_near_tile\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180100\000\00000\000\000"
/* offset=2237612 */ "offcore_response.partial_writes.l2_hit_near_tile_e_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080100\000\00000\000\000"
/* offset=2237925 */ "offcore_response.partial_writes.l2_hit_near_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080100\000\00000\000\000"
/* offset=2238234 */ "offcore_response.partial_writes.l2_hit_this_tile_e\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000100\000\00000\000\000"
/* offset=2238506 */ "offcore_response.partial_writes.l2_hit_this_tile_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000100\000\00000\000\000"
/* offset=2238778 */ "offcore_response.partial_writes.l2_hit_this_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000100\000\00000\000\000"
/* offset=2239050 */ "offcore_response.partial_writes.l2_hit_this_tile_s\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000100\000\00000\000\000"
/* offset=2239322 */ "offcore_response.partial_writes.l2_miss.any\000\000cache\000Counts the number of demand write requests (RFO) generated by a write to partial data cache line, including the writes to uncacheable (UC) and write through (WT), and write protected (WP) types of memory that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000100\000\00000\000Counts the number of demand write requests (RFO) generated by a write to partial data cache line, including the writes to uncacheable (UC) and write through (WT), and write protected (WP) types of memory that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2239988 */ "offcore_response.partial_writes.l2_miss.any\000\000cache\000Countsof demand RFO requests to write to partial cache lines that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000100\000\00000\000\000"
/* offset=2240178 */ "offcore_response.partial_writes.mcdram\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600100\000\00000\000\000"
/* offset=2240418 */ "offcore_response.partial_writes.mcdram_far\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400100\000\00000\000\000"
/* offset=2240680 */ "offcore_response.partial_writes.mcdram_near\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200100\000\00000\000\000"
/* offset=2240920 */ "offcore_response.pf_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5050\000\00000\000\000"
/* offset=2241116 */ "offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F30\000\00000\000\000"
/* offset=2241284 */ "offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F50\000\00000\000\000"
/* offset=2241452 */ "offcore_response.pf_data.any_cache_dram\000\000cache\000REQUEST = PF_DATA and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f50\000\00000\000\000"
/* offset=2241606 */ "offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6030\000\00000\000\000"
/* offset=2241760 */ "offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6050\000\00000\000\000"
/* offset=2241914 */ "offcore_response.pf_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_DATA and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3050\000\00000\000\000"
/* offset=2242087 */ "offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF830\000\00000\000\000"
/* offset=2242243 */ "offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF850\000\00000\000\000"
/* offset=2242399 */ "offcore_response.pf_data.any_llc_miss\000\000memory\000REQUEST = PF_DATA and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf850\000\00000\000\000"
/* offset=2242550 */ "offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF30\000\00000\000\000"
/* offset=2242689 */ "offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF50\000\00000\000\000"
/* offset=2242828 */ "offcore_response.pf_data.any_location\000\000cache\000REQUEST = PF_DATA and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff50\000\00000\000\000"
/* offset=2242978 */ "offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8030\000\00000\000\000"
/* offset=2243148 */ "offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8050\000\00000\000\000"
/* offset=2243318 */ "offcore_response.pf_data.io_csr_mmio\000\000cache\000REQUEST = PF_DATA and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8050\000\00000\000\000"
/* offset=2243466 */ "offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x130\000\00000\000\000"
/* offset=2243662 */ "offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x150\000\00000\000\000"
/* offset=2243858 */ "offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x150\000\00000\000\000"
/* offset=2244025 */ "offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x230\000\00000\000\000"
/* offset=2244216 */ "offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x250\000\00000\000\000"
/* offset=2244407 */ "offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x250\000\00000\000\000"
/* offset=2244576 */ "offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x430\000\00000\000\000"
/* offset=2244770 */ "offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x450\000\00000\000\000"
/* offset=2244964 */ "offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x450\000\00000\000\000"
/* offset=2245135 */ "offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x730\000\00000\000\000"
/* offset=2245289 */ "offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x750\000\00000\000\000"
/* offset=2245443 */ "offcore_response.pf_data.local_cache\000\000cache\000REQUEST = PF_DATA and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x750\000\00000\000\000"
/* offset=2245590 */ "offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2750\000\00000\000\000"
/* offset=2245764 */ "offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4730\000\00000\000\000"
/* offset=2245938 */ "offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2050\000\00000\000\000"
/* offset=2246100 */ "offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4030\000\00000\000\000"
/* offset=2246262 */ "offcore_response.pf_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1050\000\00000\000\000"
/* offset=2246450 */ "offcore_response.pf_data.other_local_dram\000\000memory\000REQUEST = PF_DATA and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4050\000\00000\000\000"
/* offset=2246609 */ "offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1830\000\00000\000\000"
/* offset=2246772 */ "offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1850\000\00000\000\000"
/* offset=2246935 */ "offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3830\000\00000\000\000"
/* offset=2247118 */ "offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5850\000\00000\000\000"
/* offset=2247301 */ "offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1030\000\00000\000\000"
/* offset=2247467 */ "offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1050\000\00000\000\000"
/* offset=2247633 */ "offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x830\000\00000\000\000"
/* offset=2247800 */ "offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x850\000\00000\000\000"
/* offset=2247967 */ "offcore_response.pf_data.remote_cache_hitm\000\000cache\000REQUEST = PF_DATA and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x850\000\00000\000\000"
/* offset=2248126 */ "offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2030\000\00000\000\000"
/* offset=2248288 */ "offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4050\000\00000\000\000"
/* offset=2248450 */ "offcore_response.pf_data.remote_dram\000\000memory\000REQUEST = PF_DATA and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2050\000\00000\000\000"
/* offset=2248599 */ "offcore_response.pf_data_rd.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5010\000\00000\000\000"
/* offset=2248801 */ "offcore_response.pf_data_rd.any_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F10\000\00000\000\000"
/* offset=2248969 */ "offcore_response.pf_data_rd.any_cache_dram\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f10\000\00000\000\000"
/* offset=2249129 */ "offcore_response.pf_data_rd.any_dram\000\000memory\000Offcore prefetch data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6010\000\00000\000\000"
/* offset=2249283 */ "offcore_response.pf_data_rd.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3010\000\00000\000\000"
/* offset=2249462 */ "offcore_response.pf_data_rd.any_llc_miss\000\000memory\000Offcore prefetch data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF810\000\00000\000\000"
/* offset=2249618 */ "offcore_response.pf_data_rd.any_llc_miss\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf810\000\00000\000\000"
/* offset=2249775 */ "offcore_response.pf_data_rd.any_location\000\000cache\000All offcore prefetch data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF10\000\00000\000\000"
/* offset=2249914 */ "offcore_response.pf_data_rd.any_location\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff10\000\00000\000\000"
/* offset=2250070 */ "offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000Offcore prefetch data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000"
/* offset=2250240 */ "offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000"
/* offset=2250394 */ "offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000Offcore prefetch data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000"
/* offset=2250590 */ "offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000"
/* offset=2250763 */ "offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000"
/* offset=2250954 */ "offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000"
/* offset=2251129 */ "offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000"
/* offset=2251323 */ "offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000"
/* offset=2251500 */ "offcore_response.pf_data_rd.llc_miss_local.dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400010\000\00000\000\000"
/* offset=2251689 */ "offcore_response.pf_data_rd.local_cache\000\000cache\000Offcore prefetch data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000"
/* offset=2251843 */ "offcore_response.pf_data_rd.local_cache\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000"
/* offset=2251996 */ "offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2710\000\00000\000\000"
/* offset=2252170 */ "offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4710\000\00000\000\000"
/* offset=2252344 */ "offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000"
/* offset=2252506 */ "offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000"
/* offset=2252668 */ "offcore_response.pf_data_rd.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000"
/* offset=2252862 */ "offcore_response.pf_data_rd.other_local_dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000"
/* offset=2253027 */ "offcore_response.pf_data_rd.remote_cache\000\000cache\000Offcore prefetch data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1810\000\00000\000\000"
/* offset=2253190 */ "offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3810\000\00000\000\000"
/* offset=2253373 */ "offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5810\000\00000\000\000"
/* offset=2253556 */ "offcore_response.pf_data_rd.remote_cache_hit\000\000cache\000Offcore prefetch data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000"
/* offset=2253722 */ "offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000Offcore prefetch data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000"
/* offset=2253889 */ "offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000"
/* offset=2254054 */ "offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000"
/* offset=2254216 */ "offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000"
/* offset=2254378 */ "offcore_response.pf_data_rd.remote_dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000"
/* offset=2254533 */ "offcore_response.pf_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5040\000\00000\000\000"
/* offset=2254730 */ "offcore_response.pf_ifetch.any_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F40\000\00000\000\000"
/* offset=2254897 */ "offcore_response.pf_ifetch.any_cache_dram\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f40\000\00000\000\000"
/* offset=2255052 */ "offcore_response.pf_ifetch.any_dram\000\000memory\000Offcore prefetch code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6040\000\00000\000\000"
/* offset=2255205 */ "offcore_response.pf_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3040\000\00000\000\000"
/* offset=2255379 */ "offcore_response.pf_ifetch.any_llc_miss\000\000memory\000Offcore prefetch code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF840\000\00000\000\000"
/* offset=2255534 */ "offcore_response.pf_ifetch.any_llc_miss\000\000memory\000REQUEST = PF_RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf840\000\00000\000\000"
/* offset=2255686 */ "offcore_response.pf_ifetch.any_location\000\000cache\000All offcore prefetch code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF40\000\00000\000\000"
/* offset=2255824 */ "offcore_response.pf_ifetch.any_location\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff40\000\00000\000\000"
/* offset=2255975 */ "offcore_response.pf_ifetch.any_response\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000"
/* offset=2256127 */ "offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000Offcore prefetch code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000"
/* offset=2256296 */ "offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000REQUEST = PF_RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000"
/* offset=2256445 */ "offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000"
/* offset=2256640 */ "offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000"
/* offset=2256808 */ "offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000"
/* offset=2256998 */ "offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000"
/* offset=2257168 */ "offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000"
/* offset=2257361 */ "offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000"
/* offset=2257533 */ "offcore_response.pf_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400040\000\00000\000\000"
/* offset=2257717 */ "offcore_response.pf_ifetch.local_cache\000\000cache\000Offcore prefetch code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000"
/* offset=2257870 */ "offcore_response.pf_ifetch.local_cache\000\000cache\000REQUEST = PF_RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000"
/* offset=2258018 */ "offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2740\000\00000\000\000"
/* offset=2258191 */ "offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4740\000\00000\000\000"
/* offset=2258364 */ "offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000"
/* offset=2258525 */ "offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000"
/* offset=2258686 */ "offcore_response.pf_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000"
/* offset=2258875 */ "offcore_response.pf_ifetch.other_local_dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000"
/* offset=2259035 */ "offcore_response.pf_ifetch.remote_cache\000\000cache\000Offcore prefetch code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1840\000\00000\000\000"
/* offset=2259197 */ "offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3840\000\00000\000\000"
/* offset=2259379 */ "offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5840\000\00000\000\000"
/* offset=2259561 */ "offcore_response.pf_ifetch.remote_cache_hit\000\000cache\000Offcore prefetch code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000"
/* offset=2259726 */ "offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000Offcore prefetch code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000"
/* offset=2259892 */ "offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000REQUEST = PF_RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000"
/* offset=2260052 */ "offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000"
/* offset=2260213 */ "offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000"
/* offset=2260374 */ "offcore_response.pf_ifetch.remote_dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000"
/* offset=2260524 */ "offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts DCU hardware prefetcher data read that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000\000"
/* offset=2260709 */ "offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts L1 data HW prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000\000"
/* offset=2260885 */ "offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2261363 */ "offcore_response.pf_l1_data_rd.ddr\000\000memory\000Counts L1 data HW prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181802000\000\00000\000\000"
/* offset=2261553 */ "offcore_response.pf_l1_data_rd.ddr_far\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101002000\000\00000\000\000"
/* offset=2261741 */ "offcore_response.pf_l1_data_rd.ddr_near\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080802000\000\00000\000\000"
/* offset=2261932 */ "offcore_response.pf_l1_data_rd.l2_hit\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000042000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2262324 */ "offcore_response.pf_l1_data_rd.l2_hit\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000042000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2262726 */ "offcore_response.pf_l1_data_rd.l2_hit_far_tile\000\000cache\000Counts L1 data HW prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800402000\000\00000\000\000"
/* offset=2263060 */ "offcore_response.pf_l1_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800402000\000\00000\000\000"
/* offset=2263402 */ "offcore_response.pf_l1_data_rd.l2_hit_far_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000402000\000\00000\000\000"
/* offset=2263706 */ "offcore_response.pf_l1_data_rd.l2_hit_near_tile\000\000cache\000Counts L1 data HW prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800182000\000\00000\000\000"
/* offset=2263969 */ "offcore_response.pf_l1_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800082000\000\00000\000\000"
/* offset=2264238 */ "offcore_response.pf_l1_data_rd.l2_hit_near_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000082000\000\00000\000\000"
/* offset=2264503 */ "offcore_response.pf_l1_data_rd.l2_hit_this_tile_e\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004002000\000\00000\000\000"
/* offset=2264731 */ "offcore_response.pf_l1_data_rd.l2_hit_this_tile_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010002000\000\00000\000\000"
/* offset=2264959 */ "offcore_response.pf_l1_data_rd.l2_hit_this_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002002000\000\00000\000\000"
/* offset=2265187 */ "offcore_response.pf_l1_data_rd.l2_hit_this_tile_s\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008002000\000\00000\000\000"
/* offset=2265415 */ "offcore_response.pf_l1_data_rd.l2_miss.any\000\000cache\000Counts DCU hardware prefetcher data read that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680002000\000\00000\000\000"
/* offset=2265584 */ "offcore_response.pf_l1_data_rd.l2_miss.any\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2265993 */ "offcore_response.pf_l1_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts DCU hardware prefetcher data read that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400002000\000\00000\000\000"
/* offset=2266266 */ "offcore_response.pf_l1_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2266851 */ "offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts DCU hardware prefetcher data read that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000\000"
/* offset=2267106 */ "offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2267669 */ "offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2268242 */ "offcore_response.pf_l1_data_rd.l2_miss.snoop_miss\000\000cache\000Counts DCU hardware prefetcher data read that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000\000"
/* offset=2268445 */ "offcore_response.pf_l1_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2268995 */ "offcore_response.pf_l1_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2269535 */ "offcore_response.pf_l1_data_rd.mcdram_far\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100402000\000\00000\000\000"
/* offset=2269753 */ "offcore_response.pf_l1_data_rd.mcdram_near\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080202000\000\00000\000\000"
/* offset=2269949 */ "offcore_response.pf_l1_data_rd.outstanding\000\000cache\000Counts L1 data HW prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000002000\000\00000\000\000"
/* offset=2270257 */ "offcore_response.pf_l1_data_rd.outstanding\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2270792 */ "offcore_response.pf_l1d_and_sw.any_response\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=2271010 */ "offcore_response.pf_l1d_and_sw.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00010\000\000"
/* offset=2271197 */ "offcore_response.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000"
/* offset=2271415 */ "offcore_response.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00010\000\000"
/* offset=2271615 */ "offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00010\000\000"
/* offset=2271832 */ "offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00000\000\000"
/* offset=2272154 */ "offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00010\000\000"
/* offset=2272377 */ "offcore_response.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000"
/* offset=2272694 */ "offcore_response.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00010\000\000"
/* offset=2272906 */ "offcore_response.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000"
/* offset=2273256 */ "offcore_response.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00010\000\000"
/* offset=2273467 */ "offcore_response.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L1D_AND_SW.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00000\000\000"
/* offset=2273652 */ "offcore_response.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0400\000\00010\000\000"
/* offset=2273869 */ "offcore_response.pf_l1d_and_sw.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00010\000\000"
/* offset=2274070 */ "offcore_response.pf_l1d_and_sw.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0400\000\00010\000\000"
/* offset=2274270 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080400\000\00010\000\000"
/* offset=2274474 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080400\000\00010\000\000"
/* offset=2274695 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080400\000\00010\000\000"
/* offset=2274922 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080400\000\00010\000\000"
/* offset=2275138 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080400\000\00010\000\000"
/* offset=2275353 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080400\000\00010\000\000"
/* offset=2275558 */ "offcore_response.pf_l1d_and_sw.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080400\000\00010\000\000"
/* offset=2275762 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200400\000\00010\000\000"
/* offset=2275966 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200400\000\00010\000\000"
/* offset=2276187 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200400\000\00010\000\000"
/* offset=2276414 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200400\000\00010\000\000"
/* offset=2276630 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200400\000\00010\000\000"
/* offset=2276845 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200400\000\00010\000\000"
/* offset=2277050 */ "offcore_response.pf_l1d_and_sw.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200400\000\00010\000\000"
/* offset=2277254 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040400\000\00010\000\000"
/* offset=2277458 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040400\000\00010\000\000"
/* offset=2277679 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040400\000\00010\000\000"
/* offset=2277906 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040400\000\00010\000\000"
/* offset=2278122 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040400\000\00010\000\000"
/* offset=2278337 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040400\000\00010\000\000"
/* offset=2278542 */ "offcore_response.pf_l1d_and_sw.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040400\000\00010\000\000"
/* offset=2278746 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100400\000\00010\000\000"
/* offset=2278950 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100400\000\00010\000\000"
/* offset=2279171 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100400\000\00010\000\000"
/* offset=2279398 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100400\000\00010\000\000"
/* offset=2279614 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100400\000\00010\000\000"
/* offset=2279829 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100400\000\00010\000\000"
/* offset=2280034 */ "offcore_response.pf_l1d_and_sw.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100400\000\00010\000\000"
/* offset=2280238 */ "offcore_response.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00000\000\000"
/* offset=2280459 */ "offcore_response.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00010\000\000"
/* offset=2280662 */ "offcore_response.pf_l1d_and_sw.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000400\000\00010\000\000"
/* offset=2280882 */ "offcore_response.pf_l1d_and_sw.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000400\000\00010\000\000"
/* offset=2281108 */ "offcore_response.pf_l1d_and_sw.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000400\000\00010\000\000"
/* offset=2281323 */ "offcore_response.pf_l1d_and_sw.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000400\000\00010\000\000"
/* offset=2281537 */ "offcore_response.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00000\000\000"
/* offset=2281821 */ "offcore_response.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00010\000\000"
/* offset=2282041 */ "offcore_response.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00000\000\000"
/* offset=2282316 */ "offcore_response.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00010\000\000"
/* offset=2282523 */ "offcore_response.pf_l1d_and_sw.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000400\000\00010\000\000"
/* offset=2282727 */ "offcore_response.pf_l1d_and_sw.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00400\000\00000\000\000"
/* offset=2283006 */ "offcore_response.pf_l1d_and_sw.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000400\000\00010\000\000"
/* offset=2283209 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000400\000\00010\000\000"
/* offset=2283434 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000400\000\00010\000\000"
/* offset=2283676 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000400\000\00010\000\000"
/* offset=2283924 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000400\000\00010\000\000"
/* offset=2284161 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00010\000\000"
/* offset=2284397 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000400\000\00010\000\000"
/* offset=2284623 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00000\000\000"
/* offset=2284903 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00010\000\000"
/* offset=2285149 */ "offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000400\000\00010\000\000"
/* offset=2285374 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00000\000\000"
/* offset=2285656 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00010\000\000"
/* offset=2285904 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000400\000\00010\000\000"
/* offset=2286141 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000400\000\00010\000\000"
/* offset=2286395 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000400\000\00010\000\000"
/* offset=2286655 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000400\000\00010\000\000"
/* offset=2286904 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000400\000\00010\000\000"
/* offset=2287152 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000400\000\00010\000\000"
/* offset=2287390 */ "offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000400\000\00010\000\000"
/* offset=2287627 */ "offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400400\000\00010\000\000"
/* offset=2287849 */ "offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400400\000\00010\000\000"
/* offset=2288071 */ "offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400400\000\00010\000\000"
/* offset=2288306 */ "offcore_response.pf_l1d_and_sw.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020400\000\00010\000\000"
/* offset=2288520 */ "offcore_response.pf_l1d_and_sw.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020400\000\00010\000\000"
/* offset=2288751 */ "offcore_response.pf_l1d_and_sw.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020400\000\00010\000\000"
/* offset=2288988 */ "offcore_response.pf_l1d_and_sw.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020400\000\00010\000\000"
/* offset=2289214 */ "offcore_response.pf_l1d_and_sw.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020400\000\00010\000\000"
/* offset=2289439 */ "offcore_response.pf_l1d_and_sw.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020400\000\00010\000\000"
/* offset=2289654 */ "offcore_response.pf_l1d_and_sw.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020400\000\00010\000\000"
/* offset=2289868 */ "offcore_response.pf_l2_code_rd.any_response\000\000cache\000Counts L2 code HW prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010040\000\00000\000\000"
/* offset=2290044 */ "offcore_response.pf_l2_code_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000"
/* offset=2290239 */ "offcore_response.pf_l2_code_rd.ddr\000\000memory\000Counts L2 code HW prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800040\000\00000\000\000"
/* offset=2290429 */ "offcore_response.pf_l2_code_rd.ddr_far\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000040\000\00000\000\000"
/* offset=2290617 */ "offcore_response.pf_l2_code_rd.ddr_near\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800040\000\00000\000\000"
/* offset=2290808 */ "offcore_response.pf_l2_code_rd.l2_hit_far_tile\000\000cache\000Counts L2 code HW prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400040\000\00000\000\000"
/* offset=2291142 */ "offcore_response.pf_l2_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400040\000\00000\000\000"
/* offset=2291484 */ "offcore_response.pf_l2_code_rd.l2_hit_far_tile_m\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400040\000\00000\000\000"
/* offset=2291788 */ "offcore_response.pf_l2_code_rd.l2_hit_near_tile\000\000cache\000Counts L2 code HW prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180040\000\00000\000\000"
/* offset=2292051 */ "offcore_response.pf_l2_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080040\000\00000\000\000"
/* offset=2292320 */ "offcore_response.pf_l2_code_rd.l2_hit_near_tile_m\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080040\000\00000\000\000"
/* offset=2292585 */ "offcore_response.pf_l2_code_rd.l2_hit_this_tile_e\000\000cache\000Counts L2 code HW prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000040\000\00000\000\000"
/* offset=2292813 */ "offcore_response.pf_l2_code_rd.l2_hit_this_tile_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000040\000\00000\000\000"
/* offset=2293041 */ "offcore_response.pf_l2_code_rd.l2_miss.any\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000040\000\00000\000\000"
/* offset=2293215 */ "offcore_response.pf_l2_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000040\000\00000\000\000"
/* offset=2293493 */ "offcore_response.pf_l2_code_rd.l2_miss.snoop_miss\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000040\000\00000\000\000"
/* offset=2293701 */ "offcore_response.pf_l2_code_rd.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000"
/* offset=2293899 */ "offcore_response.pf_l2_code_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000"
/* offset=2294080 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0040\000\00000\000\000"
/* offset=2294267 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0040\000\00000\000\000"
/* offset=2294449 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0040\000\00000\000\000"
/* offset=2294630 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0040\000\00000\000\000"
/* offset=2294817 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0040\000\00000\000\000"
/* offset=2294997 */ "offcore_response.pf_l2_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0040\000\00000\000\000"
/* offset=2295184 */ "offcore_response.pf_l2_code_rd.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00040\000\00000\000\000"
/* offset=2295385 */ "offcore_response.pf_l2_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000040\000\00000\000\000"
/* offset=2295574 */ "offcore_response.pf_l2_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000040\000\00000\000\000"
/* offset=2295757 */ "offcore_response.pf_l2_code_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000040\000\00000\000\000"
/* offset=2295939 */ "offcore_response.pf_l2_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000040\000\00000\000\000"
/* offset=2296128 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000040\000\00000\000\000"
/* offset=2296322 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000040\000\00000\000\000"
/* offset=2296522 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000040\000\00000\000\000"
/* offset=2296717 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000040\000\00000\000\000"
/* offset=2296911 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000040\000\00000\000\000"
/* offset=2297110 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000040\000\00000\000\000"
/* offset=2297303 */ "offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000040\000\00000\000\000"
/* offset=2297503 */ "offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0040\000\00000\000\000"
/* offset=2297702 */ "offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000"
/* offset=2297901 */ "offcore_response.pf_l2_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0040\000\00000\000\000"
/* offset=2298190 */ "offcore_response.pf_l2_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0040\000\00000\000\000"
/* offset=2298481 */ "offcore_response.pf_l2_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0040\000\00000\000\000"
/* offset=2298805 */ "offcore_response.pf_l2_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0040\000\00000\000\000"
/* offset=2299056 */ "offcore_response.pf_l2_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) code reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20040\000\00000\000\000"
/* offset=2299303 */ "offcore_response.pf_l2_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00040\000\00000\000\000"
/* offset=2299505 */ "offcore_response.pf_l2_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to L2) code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400040\000\00000\000\000"
/* offset=2299728 */ "offcore_response.pf_l2_code_rd.mcdram_far\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400040\000\00000\000\000"
/* offset=2299946 */ "offcore_response.pf_l2_code_rd.mcdram_near\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200040\000\00000\000\000"
/* offset=2300142 */ "offcore_response.pf_l2_code_rd.outstanding\000\000cache\000Counts L2 code HW prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000040\000\00000\000\000"
/* offset=2300450 */ "offcore_response.pf_l2_code_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020040\000\00000\000\000"
/* offset=2300638 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020040\000\00000\000\000"
/* offset=2300832 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020040\000\00000\000\000"
/* offset=2301021 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020040\000\00000\000\000"
/* offset=2301209 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020040\000\00000\000\000"
/* offset=2301403 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020040\000\00000\000\000"
/* offset=2301590 */ "offcore_response.pf_l2_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020040\000\00000\000\000"
/* offset=2301784 */ "offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2302250 */ "offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000"
/* offset=2302435 */ "offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000"
/* offset=2302625 */ "offcore_response.pf_l2_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00010\000\000"
/* offset=2302812 */ "offcore_response.pf_l2_data_rd.l2_hit\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2303192 */ "offcore_response.pf_l2_data_rd.l2_hit\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2303582 */ "offcore_response.pf_l2_data_rd.l2_miss.any\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000010\000\00000\000\000"
/* offset=2303766 */ "offcore_response.pf_l2_data_rd.l2_miss.any\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2304163 */ "offcore_response.pf_l2_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000010\000\00000\000\000"
/* offset=2304451 */ "offcore_response.pf_l2_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2305024 */ "offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000\000"
/* offset=2305294 */ "offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2305845 */ "offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2306406 */ "offcore_response.pf_l2_data_rd.l2_miss.snoop_miss\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000\000"
/* offset=2306624 */ "offcore_response.pf_l2_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2307162 */ "offcore_response.pf_l2_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2307690 */ "offcore_response.pf_l2_data_rd.l3_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000"
/* offset=2307878 */ "offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000"
/* offset=2308068 */ "offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000"
/* offset=2308239 */ "offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00010\000\000"
/* offset=2308439 */ "offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00010\000\000"
/* offset=2308656 */ "offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000"
/* offset=2308950 */ "offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00010\000\000"
/* offset=2309173 */ "offcore_response.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000"
/* offset=2309462 */ "offcore_response.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00010\000\000"
/* offset=2309674 */ "offcore_response.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000"
/* offset=2309996 */ "offcore_response.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00010\000\000"
/* offset=2310207 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000"
/* offset=2310384 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L2_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000"
/* offset=2310569 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0010\000\00010\000\000"
/* offset=2310786 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000"
/* offset=2310958 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000"
/* offset=2311129 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00010\000\000"
/* offset=2311330 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0010\000\00000\000\000"
/* offset=2311507 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00000\000\000"
/* offset=2311677 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00010\000\000"
/* offset=2311877 */ "offcore_response.pf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000"
/* offset=2312054 */ "offcore_response.pf_l2_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080010\000\00010\000\000"
/* offset=2312258 */ "offcore_response.pf_l2_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080010\000\00010\000\000"
/* offset=2312479 */ "offcore_response.pf_l2_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080010\000\00010\000\000"
/* offset=2312706 */ "offcore_response.pf_l2_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080010\000\00010\000\000"
/* offset=2312922 */ "offcore_response.pf_l2_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080010\000\00010\000\000"
/* offset=2313137 */ "offcore_response.pf_l2_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080010\000\00010\000\000"
/* offset=2313342 */ "offcore_response.pf_l2_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080010\000\00010\000\000"
/* offset=2313546 */ "offcore_response.pf_l2_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200010\000\00010\000\000"
/* offset=2313750 */ "offcore_response.pf_l2_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200010\000\00010\000\000"
/* offset=2313971 */ "offcore_response.pf_l2_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200010\000\00010\000\000"
/* offset=2314198 */ "offcore_response.pf_l2_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200010\000\00010\000\000"
/* offset=2314414 */ "offcore_response.pf_l2_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200010\000\00010\000\000"
/* offset=2314629 */ "offcore_response.pf_l2_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200010\000\00010\000\000"
/* offset=2314834 */ "offcore_response.pf_l2_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200010\000\00010\000\000"
/* offset=2315038 */ "offcore_response.pf_l2_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040010\000\00010\000\000"
/* offset=2315242 */ "offcore_response.pf_l2_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040010\000\00010\000\000"
/* offset=2315463 */ "offcore_response.pf_l2_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040010\000\00010\000\000"
/* offset=2315690 */ "offcore_response.pf_l2_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040010\000\00010\000\000"
/* offset=2315906 */ "offcore_response.pf_l2_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040010\000\00010\000\000"
/* offset=2316121 */ "offcore_response.pf_l2_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040010\000\00010\000\000"
/* offset=2316326 */ "offcore_response.pf_l2_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040010\000\00010\000\000"
/* offset=2316530 */ "offcore_response.pf_l2_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100010\000\00010\000\000"
/* offset=2316734 */ "offcore_response.pf_l2_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100010\000\00010\000\000"
/* offset=2316955 */ "offcore_response.pf_l2_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100010\000\00010\000\000"
/* offset=2317182 */ "offcore_response.pf_l2_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100010\000\00010\000\000"
/* offset=2317398 */ "offcore_response.pf_l2_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100010\000\00010\000\000"
/* offset=2317613 */ "offcore_response.pf_l2_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100010\000\00010\000\000"
/* offset=2317818 */ "offcore_response.pf_l2_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100010\000\00010\000\000"
/* offset=2318022 */ "offcore_response.pf_l2_data_rd.l3_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00010\000\00000\000\000"
/* offset=2318213 */ "offcore_response.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00000\000\000"
/* offset=2318406 */ "offcore_response.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00010\000\000"
/* offset=2318609 */ "offcore_response.pf_l2_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000010\000\00010\000\000"
/* offset=2318829 */ "offcore_response.pf_l2_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00010\000\000"
/* offset=2319055 */ "offcore_response.pf_l2_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000010\000\00010\000\000"
/* offset=2319270 */ "offcore_response.pf_l2_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00010\000\000"
/* offset=2319484 */ "offcore_response.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00000\000\000"
/* offset=2319740 */ "offcore_response.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00010\000\000"
/* offset=2319960 */ "offcore_response.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00000\000\000"
/* offset=2320207 */ "offcore_response.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00010\000\000"
/* offset=2320414 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00000\000\000"
/* offset=2320593 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00000\000\000"
/* offset=2320766 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00010\000\000"
/* offset=2320970 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00010\000\00000\000\000"
/* offset=2321221 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00000\000\000"
/* offset=2321393 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00010\000\000"
/* offset=2321596 */ "offcore_response.pf_l2_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00000\000\000"
/* offset=2321775 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00000\000\000"
/* offset=2321959 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00010\000\000"
/* offset=2322184 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000010\000\00010\000\000"
/* offset=2322426 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00010\000\000"
/* offset=2322674 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00010\000\000"
/* offset=2322911 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00010\000\000"
/* offset=2323147 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00000\000\000"
/* offset=2323337 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00000\000\000"
/* offset=2323522 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00000\000\000"
/* offset=2323706 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00010\000\000"
/* offset=2323932 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00000\000\000"
/* offset=2324184 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00010\000\000"
/* offset=2324430 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000010\000\00000\000\000"
/* offset=2324619 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00000\000\000"
/* offset=2324802 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00010\000\000"
/* offset=2325027 */ "offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00000\000\000"
/* offset=2325217 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00000\000\000"
/* offset=2325471 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00010\000\000"
/* offset=2325719 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000010\000\00010\000\000"
/* offset=2325956 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000010\000\00010\000\000"
/* offset=2326210 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000010\000\00010\000\000"
/* offset=2326470 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000010\000\00010\000\000"
/* offset=2326719 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000010\000\00010\000\000"
/* offset=2326967 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000010\000\00010\000\000"
/* offset=2327205 */ "offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000010\000\00010\000\000"
/* offset=2327442 */ "offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0010\000\00000\000\000"
/* offset=2327641 */ "offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000"
/* offset=2327830 */ "offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0010\000\00000\000\000"
/* offset=2328025 */ "offcore_response.pf_l2_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0010\000\00000\000\000"
/* offset=2328314 */ "offcore_response.pf_l2_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0010\000\00000\000\000"
/* offset=2328605 */ "offcore_response.pf_l2_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0010\000\00000\000\000"
/* offset=2328929 */ "offcore_response.pf_l2_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0010\000\00000\000\000"
/* offset=2329180 */ "offcore_response.pf_l2_data_rd.llc_miss.any_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00010\000\00000\000\000"
/* offset=2329418 */ "offcore_response.pf_l2_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00010\000\00000\000\000"
/* offset=2329610 */ "offcore_response.pf_l2_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20010\000\00000\000\000"
/* offset=2329808 */ "offcore_response.pf_l2_data_rd.llc_miss.dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400010\000\00000\000\000"
/* offset=2330026 */ "offcore_response.pf_l2_data_rd.llc_miss.local_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400010\000\00000\000\000"
/* offset=2330257 */ "offcore_response.pf_l2_data_rd.llc_miss.remote_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads  that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800010\000\00000\000\000"
/* offset=2330491 */ "offcore_response.pf_l2_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820010\000\00000\000\000"
/* offset=2330733 */ "offcore_response.pf_l2_data_rd.llc_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00010\000\00000\000\000"
/* offset=2330998 */ "offcore_response.pf_l2_data_rd.outstanding\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2331521 */ "offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400010\000\00010\000\000"
/* offset=2331743 */ "offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400010\000\00010\000\000"
/* offset=2331965 */ "offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400010\000\00010\000\000"
/* offset=2332200 */ "offcore_response.pf_l2_data_rd.supplier_none.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00000\000\000"
/* offset=2332378 */ "offcore_response.pf_l2_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00010\000\000"
/* offset=2332592 */ "offcore_response.pf_l2_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020010\000\00010\000\000"
/* offset=2332823 */ "offcore_response.pf_l2_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00010\000\000"
/* offset=2333060 */ "offcore_response.pf_l2_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00010\000\000"
/* offset=2333286 */ "offcore_response.pf_l2_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00010\000\000"
/* offset=2333511 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00000\000\000"
/* offset=2333695 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00000\000\000"
/* offset=2333874 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00000\000\000"
/* offset=2334052 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00010\000\000"
/* offset=2334267 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020010\000\00000\000\000"
/* offset=2334451 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00000\000\000"
/* offset=2334628 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00010\000\000"
/* offset=2334842 */ "offcore_response.pf_l2_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00000\000\000"
/* offset=2335026 */ "offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010020\000\00000\000\000"
/* offset=2335232 */ "offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000"
/* offset=2335411 */ "offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000"
/* offset=2335595 */ "offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2336055 */ "offcore_response.pf_l2_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00010\000\000"
/* offset=2336234 */ "offcore_response.pf_l2_rfo.ddr\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800020\000\00000\000\000"
/* offset=2336454 */ "offcore_response.pf_l2_rfo.ddr_far\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000020\000\00000\000\000"
/* offset=2336672 */ "offcore_response.pf_l2_rfo.ddr_near\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800020\000\00000\000\000"
/* offset=2336893 */ "offcore_response.pf_l2_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2337267 */ "offcore_response.pf_l2_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2337651 */ "offcore_response.pf_l2_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400020\000\00000\000\000"
/* offset=2338023 */ "offcore_response.pf_l2_rfo.l2_hit_far_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400020\000\00000\000\000"
/* offset=2338357 */ "offcore_response.pf_l2_rfo.l2_hit_near_tile\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180020\000\00000\000\000"
/* offset=2338650 */ "offcore_response.pf_l2_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080020\000\00000\000\000"
/* offset=2338949 */ "offcore_response.pf_l2_rfo.l2_hit_near_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080020\000\00000\000\000"
/* offset=2339244 */ "offcore_response.pf_l2_rfo.l2_hit_this_tile_e\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000020\000\00000\000\000"
/* offset=2339502 */ "offcore_response.pf_l2_rfo.l2_hit_this_tile_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000020\000\00000\000\000"
/* offset=2339760 */ "offcore_response.pf_l2_rfo.l2_hit_this_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000020\000\00000\000\000"
/* offset=2340018 */ "offcore_response.pf_l2_rfo.l2_hit_this_tile_s\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000020\000\00000\000\000"
/* offset=2340276 */ "offcore_response.pf_l2_rfo.l2_miss.any\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000020\000\00000\000\000"
/* offset=2340448 */ "offcore_response.pf_l2_rfo.l2_miss.any\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2340839 */ "offcore_response.pf_l2_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000020\000\00000\000\000"
/* offset=2341115 */ "offcore_response.pf_l2_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2341682 */ "offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts RFO requests generated by L2 prefetchers that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000\000"
/* offset=2341940 */ "offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2342485 */ "offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2343040 */ "offcore_response.pf_l2_rfo.l2_miss.snoop_miss\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000\000"
/* offset=2343246 */ "offcore_response.pf_l2_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2343778 */ "offcore_response.pf_l2_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2344300 */ "offcore_response.pf_l2_rfo.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000"
/* offset=2344482 */ "offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000"
/* offset=2344666 */ "offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000"
/* offset=2344831 */ "offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00010\000\000"
/* offset=2345023 */ "offcore_response.pf_l2_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00010\000\000"
/* offset=2345232 */ "offcore_response.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000"
/* offset=2345520 */ "offcore_response.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00010\000\000"
/* offset=2345735 */ "offcore_response.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000"
/* offset=2346018 */ "offcore_response.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00010\000\000"
/* offset=2346222 */ "offcore_response.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000"
/* offset=2346538 */ "offcore_response.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00010\000\000"
/* offset=2346741 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000"
/* offset=2346912 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L2_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000"
/* offset=2347089 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0020\000\00010\000\000"
/* offset=2347298 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000"
/* offset=2347464 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000"
/* offset=2347629 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00010\000\000"
/* offset=2347822 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0020\000\00000\000\000"
/* offset=2347993 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00000\000\000"
/* offset=2348157 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00010\000\000"
/* offset=2348349 */ "offcore_response.pf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000"
/* offset=2348520 */ "offcore_response.pf_l2_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080020\000\00010\000\000"
/* offset=2348716 */ "offcore_response.pf_l2_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080020\000\00010\000\000"
/* offset=2348929 */ "offcore_response.pf_l2_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080020\000\00010\000\000"
/* offset=2349148 */ "offcore_response.pf_l2_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080020\000\00010\000\000"
/* offset=2349356 */ "offcore_response.pf_l2_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080020\000\00010\000\000"
/* offset=2349563 */ "offcore_response.pf_l2_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080020\000\00010\000\000"
/* offset=2349760 */ "offcore_response.pf_l2_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080020\000\00010\000\000"
/* offset=2349956 */ "offcore_response.pf_l2_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200020\000\00010\000\000"
/* offset=2350152 */ "offcore_response.pf_l2_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200020\000\00010\000\000"
/* offset=2350365 */ "offcore_response.pf_l2_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200020\000\00010\000\000"
/* offset=2350584 */ "offcore_response.pf_l2_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200020\000\00010\000\000"
/* offset=2350792 */ "offcore_response.pf_l2_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200020\000\00010\000\000"
/* offset=2350999 */ "offcore_response.pf_l2_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200020\000\00010\000\000"
/* offset=2351196 */ "offcore_response.pf_l2_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200020\000\00010\000\000"
/* offset=2351392 */ "offcore_response.pf_l2_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040020\000\00010\000\000"
/* offset=2351588 */ "offcore_response.pf_l2_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040020\000\00010\000\000"
/* offset=2351801 */ "offcore_response.pf_l2_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040020\000\00010\000\000"
/* offset=2352020 */ "offcore_response.pf_l2_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040020\000\00010\000\000"
/* offset=2352228 */ "offcore_response.pf_l2_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040020\000\00010\000\000"
/* offset=2352435 */ "offcore_response.pf_l2_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040020\000\00010\000\000"
/* offset=2352632 */ "offcore_response.pf_l2_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040020\000\00010\000\000"
/* offset=2352828 */ "offcore_response.pf_l2_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100020\000\00010\000\000"
/* offset=2353024 */ "offcore_response.pf_l2_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100020\000\00010\000\000"
/* offset=2353237 */ "offcore_response.pf_l2_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100020\000\00010\000\000"
/* offset=2353456 */ "offcore_response.pf_l2_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100020\000\00010\000\000"
/* offset=2353664 */ "offcore_response.pf_l2_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100020\000\00010\000\000"
/* offset=2353871 */ "offcore_response.pf_l2_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100020\000\00010\000\000"
/* offset=2354068 */ "offcore_response.pf_l2_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100020\000\00010\000\000"
/* offset=2354264 */ "offcore_response.pf_l2_rfo.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00020\000\00000\000\000"
/* offset=2354449 */ "offcore_response.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00000\000\000"
/* offset=2354636 */ "offcore_response.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00010\000\000"
/* offset=2354831 */ "offcore_response.pf_l2_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000020\000\00010\000\000"
/* offset=2355043 */ "offcore_response.pf_l2_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00010\000\000"
/* offset=2355261 */ "offcore_response.pf_l2_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000020\000\00010\000\000"
/* offset=2355468 */ "offcore_response.pf_l2_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00010\000\000"
/* offset=2355674 */ "offcore_response.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00000\000\000"
/* offset=2355924 */ "offcore_response.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00010\000\000"
/* offset=2356136 */ "offcore_response.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00000\000\000"
/* offset=2356377 */ "offcore_response.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00010\000\000"
/* offset=2356576 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00000\000\000"
/* offset=2356749 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00000\000\000"
/* offset=2356916 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00010\000\000"
/* offset=2357112 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00020\000\00000\000\000"
/* offset=2357357 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00000\000\000"
/* offset=2357523 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00010\000\000"
/* offset=2357718 */ "offcore_response.pf_l2_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00000\000\000"
/* offset=2357891 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00000\000\000"
/* offset=2358069 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00010\000\000"
/* offset=2358286 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000020\000\00010\000\000"
/* offset=2358520 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00010\000\000"
/* offset=2358760 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00010\000\000"
/* offset=2358989 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00010\000\000"
/* offset=2359217 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00000\000\000"
/* offset=2359401 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00000\000\000"
/* offset=2359580 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00000\000\000"
/* offset=2359758 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00010\000\000"
/* offset=2359976 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00000\000\000"
/* offset=2360222 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00010\000\000"
/* offset=2360460 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000020\000\00000\000\000"
/* offset=2360643 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00000\000\000"
/* offset=2360820 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00010\000\000"
/* offset=2361037 */ "offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00000\000\000"
/* offset=2361221 */ "offcore_response.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00000\000\000"
/* offset=2361469 */ "offcore_response.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00010\000\000"
/* offset=2361709 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000020\000\00010\000\000"
/* offset=2361938 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000020\000\00010\000\000"
/* offset=2362184 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000020\000\00010\000\000"
/* offset=2362436 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000020\000\00010\000\000"
/* offset=2362677 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000020\000\00010\000\000"
/* offset=2362917 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000020\000\00010\000\000"
/* offset=2363147 */ "offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000020\000\00010\000\000"
/* offset=2363376 */ "offcore_response.pf_l2_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000"
/* offset=2363559 */ "offcore_response.pf_l2_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0020\000\00000\000\000"
/* offset=2363748 */ "offcore_response.pf_l2_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0020\000\00000\000\000"
/* offset=2364027 */ "offcore_response.pf_l2_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0020\000\00000\000\000"
/* offset=2364308 */ "offcore_response.pf_l2_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0020\000\00000\000\000"
/* offset=2364622 */ "offcore_response.pf_l2_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0020\000\00000\000\000"
/* offset=2364863 */ "offcore_response.pf_l2_rfo.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00020\000\00000\000\000"
/* offset=2365049 */ "offcore_response.pf_l2_rfo.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400020\000\00000\000\000"
/* offset=2365262 */ "offcore_response.pf_l2_rfo.mcdram\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600020\000\00000\000\000"
/* offset=2365488 */ "offcore_response.pf_l2_rfo.mcdram_far\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400020\000\00000\000\000"
/* offset=2365736 */ "offcore_response.pf_l2_rfo.mcdram_near\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200020\000\00000\000\000"
/* offset=2365962 */ "offcore_response.pf_l2_rfo.non_dram\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from any NON_DRAM system address. This includes MMIO transactions\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x2000020020\000\00000\000\000"
/* offset=2366228 */ "offcore_response.pf_l2_rfo.outstanding\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2366745 */ "offcore_response.pf_l2_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400020\000\00010\000\000"
/* offset=2366959 */ "offcore_response.pf_l2_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400020\000\00010\000\000"
/* offset=2367173 */ "offcore_response.pf_l2_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400020\000\00010\000\000"
/* offset=2367400 */ "offcore_response.pf_l2_rfo.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00000\000\000"
/* offset=2367572 */ "offcore_response.pf_l2_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00010\000\000"
/* offset=2367778 */ "offcore_response.pf_l2_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020020\000\00010\000\000"
/* offset=2368001 */ "offcore_response.pf_l2_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00010\000\000"
/* offset=2368230 */ "offcore_response.pf_l2_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00010\000\000"
/* offset=2368448 */ "offcore_response.pf_l2_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00010\000\000"
/* offset=2368665 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00000\000\000"
/* offset=2368843 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00000\000\000"
/* offset=2369016 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00000\000\000"
/* offset=2369188 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00010\000\000"
/* offset=2369395 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020020\000\00000\000\000"
/* offset=2369573 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00000\000\000"
/* offset=2369744 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00010\000\000"
/* offset=2369950 */ "offcore_response.pf_l2_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00000\000\000"
/* offset=2370128 */ "offcore_response.pf_l2_rfo.supplier_none\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that provides no supplier details\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000020020\000\00000\000\000"
/* offset=2370338 */ "offcore_response.pf_l3_code_rd.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10200\000\00000\000\000"
/* offset=2370529 */ "offcore_response.pf_l3_code_rd.l3_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000"
/* offset=2370723 */ "offcore_response.pf_l3_code_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000"
/* offset=2370900 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0200\000\00000\000\000"
/* offset=2371083 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0200\000\00000\000\000"
/* offset=2371261 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0200\000\00000\000\000"
/* offset=2371438 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0200\000\00000\000\000"
/* offset=2371621 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0200\000\00000\000\000"
/* offset=2371797 */ "offcore_response.pf_l3_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0200\000\00000\000\000"
/* offset=2371980 */ "offcore_response.pf_l3_code_rd.l3_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00200\000\00000\000\000"
/* offset=2372177 */ "offcore_response.pf_l3_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000200\000\00000\000\000"
/* offset=2372362 */ "offcore_response.pf_l3_code_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000200\000\00000\000\000"
/* offset=2372541 */ "offcore_response.pf_l3_code_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000200\000\00000\000\000"
/* offset=2372719 */ "offcore_response.pf_l3_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000200\000\00000\000\000"
/* offset=2372904 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000200\000\00000\000\000"
/* offset=2373094 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000200\000\00000\000\000"
/* offset=2373290 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000200\000\00000\000\000"
/* offset=2373481 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000200\000\00000\000\000"
/* offset=2373671 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000200\000\00000\000\000"
/* offset=2373866 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000200\000\00000\000\000"
/* offset=2374055 */ "offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000200\000\00000\000\000"
/* offset=2374251 */ "offcore_response.pf_l3_code_rd.supplier_none.any_snoop\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020200\000\00000\000\000"
/* offset=2374435 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020200\000\00000\000\000"
/* offset=2374625 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020200\000\00000\000\000"
/* offset=2374810 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020200\000\00000\000\000"
/* offset=2374994 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020200\000\00000\000\000"
/* offset=2375184 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_none\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020200\000\00000\000\000"
/* offset=2375367 */ "offcore_response.pf_l3_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020200\000\00000\000\000"
/* offset=2375557 */ "offcore_response.pf_l3_data_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000"
/* offset=2375752 */ "offcore_response.pf_l3_data_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000"
/* offset=2375952 */ "offcore_response.pf_l3_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00010\000\000"
/* offset=2376139 */ "offcore_response.pf_l3_data_rd.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000"
/* offset=2376337 */ "offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000"
/* offset=2376537 */ "offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000"
/* offset=2376718 */ "offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00010\000\000"
/* offset=2376918 */ "offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00010\000\000"
/* offset=2377135 */ "offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000"
/* offset=2377439 */ "offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00010\000\000"
/* offset=2377662 */ "offcore_response.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000"
/* offset=2377961 */ "offcore_response.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00010\000\000"
/* offset=2378173 */ "offcore_response.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000"
/* offset=2378505 */ "offcore_response.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00010\000\000"
/* offset=2378716 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000"
/* offset=2378903 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L3_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00000\000\000"
/* offset=2379088 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0080\000\00010\000\000"
/* offset=2379305 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000"
/* offset=2379487 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00000\000\000"
/* offset=2379668 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00010\000\000"
/* offset=2379869 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0080\000\00000\000\000"
/* offset=2380056 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00000\000\000"
/* offset=2380236 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00010\000\000"
/* offset=2380436 */ "offcore_response.pf_l3_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000"
/* offset=2380623 */ "offcore_response.pf_l3_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080080\000\00010\000\000"
/* offset=2380827 */ "offcore_response.pf_l3_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080080\000\00010\000\000"
/* offset=2381048 */ "offcore_response.pf_l3_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080080\000\00010\000\000"
/* offset=2381275 */ "offcore_response.pf_l3_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080080\000\00010\000\000"
/* offset=2381491 */ "offcore_response.pf_l3_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080080\000\00010\000\000"
/* offset=2381706 */ "offcore_response.pf_l3_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080080\000\00010\000\000"
/* offset=2381911 */ "offcore_response.pf_l3_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080080\000\00010\000\000"
/* offset=2382115 */ "offcore_response.pf_l3_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200080\000\00010\000\000"
/* offset=2382319 */ "offcore_response.pf_l3_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200080\000\00010\000\000"
/* offset=2382540 */ "offcore_response.pf_l3_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200080\000\00010\000\000"
/* offset=2382767 */ "offcore_response.pf_l3_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200080\000\00010\000\000"
/* offset=2382983 */ "offcore_response.pf_l3_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200080\000\00010\000\000"
/* offset=2383198 */ "offcore_response.pf_l3_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200080\000\00010\000\000"
/* offset=2383403 */ "offcore_response.pf_l3_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200080\000\00010\000\000"
/* offset=2383607 */ "offcore_response.pf_l3_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040080\000\00010\000\000"
/* offset=2383811 */ "offcore_response.pf_l3_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040080\000\00010\000\000"
/* offset=2384032 */ "offcore_response.pf_l3_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040080\000\00010\000\000"
/* offset=2384259 */ "offcore_response.pf_l3_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040080\000\00010\000\000"
/* offset=2384475 */ "offcore_response.pf_l3_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040080\000\00010\000\000"
/* offset=2384690 */ "offcore_response.pf_l3_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040080\000\00010\000\000"
/* offset=2384895 */ "offcore_response.pf_l3_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040080\000\00010\000\000"
/* offset=2385099 */ "offcore_response.pf_l3_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100080\000\00010\000\000"
/* offset=2385303 */ "offcore_response.pf_l3_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100080\000\00010\000\000"
/* offset=2385524 */ "offcore_response.pf_l3_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100080\000\00010\000\000"
/* offset=2385751 */ "offcore_response.pf_l3_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100080\000\00010\000\000"
/* offset=2385967 */ "offcore_response.pf_l3_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100080\000\00010\000\000"
/* offset=2386182 */ "offcore_response.pf_l3_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100080\000\00010\000\000"
/* offset=2386387 */ "offcore_response.pf_l3_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100080\000\00010\000\000"
/* offset=2386591 */ "offcore_response.pf_l3_data_rd.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00080\000\00000\000\000"
/* offset=2386792 */ "offcore_response.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00000\000\000"
/* offset=2386995 */ "offcore_response.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00010\000\000"
/* offset=2387198 */ "offcore_response.pf_l3_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000080\000\00010\000\000"
/* offset=2387418 */ "offcore_response.pf_l3_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00010\000\000"
/* offset=2387644 */ "offcore_response.pf_l3_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000080\000\00010\000\000"
/* offset=2387859 */ "offcore_response.pf_l3_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00010\000\000"
/* offset=2388073 */ "offcore_response.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00000\000\000"
/* offset=2388339 */ "offcore_response.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00010\000\000"
/* offset=2388559 */ "offcore_response.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00000\000\000"
/* offset=2388816 */ "offcore_response.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00010\000\000"
/* offset=2389023 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00000\000\000"
/* offset=2389212 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00000\000\000"
/* offset=2389395 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00010\000\000"
/* offset=2389599 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00080\000\00000\000\000"
/* offset=2389860 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00000\000\000"
/* offset=2390042 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00010\000\000"
/* offset=2390245 */ "offcore_response.pf_l3_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00000\000\000"
/* offset=2390434 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00000\000\000"
/* offset=2390628 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00010\000\000"
/* offset=2390853 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000080\000\00010\000\000"
/* offset=2391095 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00010\000\000"
/* offset=2391343 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00010\000\000"
/* offset=2391580 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00010\000\000"
/* offset=2391816 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00000\000\000"
/* offset=2392016 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00000\000\000"
/* offset=2392211 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00000\000\000"
/* offset=2392405 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00010\000\000"
/* offset=2392631 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00000\000\000"
/* offset=2392893 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00010\000\000"
/* offset=2393139 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000080\000\00000\000\000"
/* offset=2393338 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00000\000\000"
/* offset=2393531 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00010\000\000"
/* offset=2393756 */ "offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00000\000\000"
/* offset=2393956 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00000\000\000"
/* offset=2394220 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00010\000\000"
/* offset=2394468 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000080\000\00010\000\000"
/* offset=2394705 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000080\000\00010\000\000"
/* offset=2394959 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000080\000\00010\000\000"
/* offset=2395219 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000080\000\00010\000\000"
/* offset=2395468 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000080\000\00010\000\000"
/* offset=2395716 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000080\000\00010\000\000"
/* offset=2395954 */ "offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000080\000\00010\000\000"
/* offset=2396191 */ "offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400080\000\00010\000\000"
/* offset=2396413 */ "offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400080\000\00010\000\000"
/* offset=2396635 */ "offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400080\000\00010\000\000"
/* offset=2396870 */ "offcore_response.pf_l3_data_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00000\000\000"
/* offset=2397058 */ "offcore_response.pf_l3_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00010\000\000"
/* offset=2397272 */ "offcore_response.pf_l3_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020080\000\00010\000\000"
/* offset=2397503 */ "offcore_response.pf_l3_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00010\000\000"
/* offset=2397740 */ "offcore_response.pf_l3_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00010\000\000"
/* offset=2397966 */ "offcore_response.pf_l3_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00010\000\000"
/* offset=2398191 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00000\000\000"
/* offset=2398385 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00000\000\000"
/* offset=2398574 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00000\000\000"
/* offset=2398762 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00010\000\000"
/* offset=2398977 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020080\000\00000\000\000"
/* offset=2399171 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00000\000\000"
/* offset=2399358 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00010\000\000"
/* offset=2399572 */ "offcore_response.pf_l3_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00000\000\000"
/* offset=2399766 */ "offcore_response.pf_l3_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000"
/* offset=2399951 */ "offcore_response.pf_l3_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000"
/* offset=2400141 */ "offcore_response.pf_l3_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00010\000\000"
/* offset=2400320 */ "offcore_response.pf_l3_rfo.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000"
/* offset=2400508 */ "offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000"
/* offset=2400698 */ "offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000"
/* offset=2400869 */ "offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00010\000\000"
/* offset=2401061 */ "offcore_response.pf_l3_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00010\000\000"
/* offset=2401270 */ "offcore_response.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000"
/* offset=2401564 */ "offcore_response.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00010\000\000"
/* offset=2401779 */ "offcore_response.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000"
/* offset=2402068 */ "offcore_response.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00010\000\000"
/* offset=2402272 */ "offcore_response.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000"
/* offset=2402594 */ "offcore_response.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00010\000\000"
/* offset=2402797 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000"
/* offset=2402974 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L3_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00000\000\000"
/* offset=2403151 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0100\000\00010\000\000"
/* offset=2403360 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000"
/* offset=2403532 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00000\000\000"
/* offset=2403703 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00010\000\000"
/* offset=2403896 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0100\000\00000\000\000"
/* offset=2404073 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00000\000\000"
/* offset=2404243 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00010\000\000"
/* offset=2404435 */ "offcore_response.pf_l3_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000"
/* offset=2404612 */ "offcore_response.pf_l3_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080100\000\00010\000\000"
/* offset=2404808 */ "offcore_response.pf_l3_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080100\000\00010\000\000"
/* offset=2405021 */ "offcore_response.pf_l3_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080100\000\00010\000\000"
/* offset=2405240 */ "offcore_response.pf_l3_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080100\000\00010\000\000"
/* offset=2405448 */ "offcore_response.pf_l3_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080100\000\00010\000\000"
/* offset=2405655 */ "offcore_response.pf_l3_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080100\000\00010\000\000"
/* offset=2405852 */ "offcore_response.pf_l3_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080100\000\00010\000\000"
/* offset=2406048 */ "offcore_response.pf_l3_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200100\000\00010\000\000"
/* offset=2406244 */ "offcore_response.pf_l3_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200100\000\00010\000\000"
/* offset=2406457 */ "offcore_response.pf_l3_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200100\000\00010\000\000"
/* offset=2406676 */ "offcore_response.pf_l3_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200100\000\00010\000\000"
/* offset=2406884 */ "offcore_response.pf_l3_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200100\000\00010\000\000"
/* offset=2407091 */ "offcore_response.pf_l3_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200100\000\00010\000\000"
/* offset=2407288 */ "offcore_response.pf_l3_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200100\000\00010\000\000"
/* offset=2407484 */ "offcore_response.pf_l3_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040100\000\00010\000\000"
/* offset=2407680 */ "offcore_response.pf_l3_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040100\000\00010\000\000"
/* offset=2407893 */ "offcore_response.pf_l3_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040100\000\00010\000\000"
/* offset=2408112 */ "offcore_response.pf_l3_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040100\000\00010\000\000"
/* offset=2408320 */ "offcore_response.pf_l3_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040100\000\00010\000\000"
/* offset=2408527 */ "offcore_response.pf_l3_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040100\000\00010\000\000"
/* offset=2408724 */ "offcore_response.pf_l3_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040100\000\00010\000\000"
/* offset=2408920 */ "offcore_response.pf_l3_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100100\000\00010\000\000"
/* offset=2409116 */ "offcore_response.pf_l3_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100100\000\00010\000\000"
/* offset=2409329 */ "offcore_response.pf_l3_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100100\000\00010\000\000"
/* offset=2409548 */ "offcore_response.pf_l3_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100100\000\00010\000\000"
/* offset=2409756 */ "offcore_response.pf_l3_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100100\000\00010\000\000"
/* offset=2409963 */ "offcore_response.pf_l3_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100100\000\00010\000\000"
/* offset=2410160 */ "offcore_response.pf_l3_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100100\000\00010\000\000"
/* offset=2410356 */ "offcore_response.pf_l3_rfo.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00100\000\00000\000\000"
/* offset=2410547 */ "offcore_response.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00000\000\000"
/* offset=2410740 */ "offcore_response.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00010\000\000"
/* offset=2410935 */ "offcore_response.pf_l3_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000100\000\00010\000\000"
/* offset=2411147 */ "offcore_response.pf_l3_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00010\000\000"
/* offset=2411365 */ "offcore_response.pf_l3_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000100\000\00010\000\000"
/* offset=2411572 */ "offcore_response.pf_l3_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00010\000\000"
/* offset=2411778 */ "offcore_response.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00000\000\000"
/* offset=2412034 */ "offcore_response.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00010\000\000"
/* offset=2412246 */ "offcore_response.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00000\000\000"
/* offset=2412493 */ "offcore_response.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00010\000\000"
/* offset=2412692 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00000\000\000"
/* offset=2412871 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00000\000\000"
/* offset=2413044 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00010\000\000"
/* offset=2413240 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00100\000\00000\000\000"
/* offset=2413491 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00000\000\000"
/* offset=2413663 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00010\000\000"
/* offset=2413858 */ "offcore_response.pf_l3_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00000\000\000"
/* offset=2414037 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00000\000\000"
/* offset=2414221 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00010\000\000"
/* offset=2414438 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000100\000\00010\000\000"
/* offset=2414672 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00010\000\000"
/* offset=2414912 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00010\000\000"
/* offset=2415141 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00010\000\000"
/* offset=2415369 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00000\000\000"
/* offset=2415559 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00000\000\000"
/* offset=2415744 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00000\000\000"
/* offset=2415928 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00010\000\000"
/* offset=2416146 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00000\000\000"
/* offset=2416398 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00010\000\000"
/* offset=2416636 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000100\000\00000\000\000"
/* offset=2416825 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00000\000\000"
/* offset=2417008 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00010\000\000"
/* offset=2417225 */ "offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00000\000\000"
/* offset=2417415 */ "offcore_response.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00000\000\000"
/* offset=2417669 */ "offcore_response.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00010\000\000"
/* offset=2417909 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000100\000\00010\000\000"
/* offset=2418138 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000100\000\00010\000\000"
/* offset=2418384 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000100\000\00010\000\000"
/* offset=2418636 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000100\000\00010\000\000"
/* offset=2418877 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000100\000\00010\000\000"
/* offset=2419117 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000100\000\00010\000\000"
/* offset=2419347 */ "offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000100\000\00010\000\000"
/* offset=2419576 */ "offcore_response.pf_l3_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400100\000\00010\000\000"
/* offset=2419790 */ "offcore_response.pf_l3_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400100\000\00010\000\000"
/* offset=2420004 */ "offcore_response.pf_l3_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400100\000\00010\000\000"
/* offset=2420231 */ "offcore_response.pf_l3_rfo.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00000\000\000"
/* offset=2420409 */ "offcore_response.pf_l3_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00010\000\000"
/* offset=2420615 */ "offcore_response.pf_l3_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020100\000\00010\000\000"
/* offset=2420838 */ "offcore_response.pf_l3_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00010\000\000"
/* offset=2421067 */ "offcore_response.pf_l3_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00010\000\000"
/* offset=2421285 */ "offcore_response.pf_l3_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00010\000\000"
/* offset=2421502 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00000\000\000"
/* offset=2421686 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00000\000\000"
/* offset=2421865 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00000\000\000"
/* offset=2422043 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00010\000\000"
/* offset=2422250 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020100\000\00000\000\000"
/* offset=2422434 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00000\000\000"
/* offset=2422611 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00010\000\000"
/* offset=2422817 */ "offcore_response.pf_l3_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00000\000\000"
/* offset=2423001 */ "offcore_response.pf_l_data_rd.any_response\000\000cache\000REQUEST = PF_LLC_DATA_RD and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000"
/* offset=2423164 */ "offcore_response.pf_l_data_rd.llc_miss_local.dram\000\000memory\000REQUEST = PF_LLC_DATA_RD and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400080\000\00000\000\000"
/* offset=2423359 */ "offcore_response.pf_l_ifetch.any_response\000\000cache\000REQUEST = PF_LLC_IFETCH and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10200\000\00000\000\000"
/* offset=2423520 */ "offcore_response.pf_l_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = PF_LLC_IFETCH and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400200\000\00000\000\000"
/* offset=2423713 */ "offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0200\000\00000\000\000"
/* offset=2423919 */ "offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000"
/* offset=2424115 */ "offcore_response.pf_llc_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0200\000\00000\000\000"
/* offset=2424411 */ "offcore_response.pf_llc_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0200\000\00000\000\000"
/* offset=2424709 */ "offcore_response.pf_llc_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0200\000\00000\000\000"
/* offset=2425040 */ "offcore_response.pf_llc_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0200\000\00000\000\000"
/* offset=2425298 */ "offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20200\000\00000\000\000"
/* offset=2425507 */ "offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00200\000\00000\000\000"
/* offset=2425706 */ "offcore_response.pf_llc_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400200\000\00000\000\000"
/* offset=2425936 */ "offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000"
/* offset=2426136 */ "offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0080\000\00000\000\000"
/* offset=2426342 */ "offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0080\000\00000\000\000"
/* offset=2426544 */ "offcore_response.pf_llc_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0080\000\00000\000\000"
/* offset=2426840 */ "offcore_response.pf_llc_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0080\000\00000\000\000"
/* offset=2427138 */ "offcore_response.pf_llc_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0080\000\00000\000\000"
/* offset=2427469 */ "offcore_response.pf_llc_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0080\000\00000\000\000"
/* offset=2427727 */ "offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00080\000\00000\000\000"
/* offset=2427930 */ "offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20080\000\00000\000\000"
/* offset=2428193 */ "offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20080\000\00000\000\000"
/* offset=2428398 */ "offcore_response.pf_llc_data_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400080\000\00000\000\000"
/* offset=2428628 */ "offcore_response.pf_llc_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000"
/* offset=2428818 */ "offcore_response.pf_llc_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0100\000\00000\000\000"
/* offset=2429014 */ "offcore_response.pf_llc_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0100\000\00000\000\000"
/* offset=2429300 */ "offcore_response.pf_llc_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0100\000\00000\000\000"
/* offset=2429588 */ "offcore_response.pf_llc_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0100\000\00000\000\000"
/* offset=2429909 */ "offcore_response.pf_llc_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0100\000\00000\000\000"
/* offset=2430157 */ "offcore_response.pf_llc_rfo.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00100\000\00000\000\000"
/* offset=2430350 */ "offcore_response.pf_llc_rfo.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400100\000\00000\000\000"
/* offset=2430570 */ "offcore_response.pf_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5020\000\00000\000\000"
/* offset=2430767 */ "offcore_response.pf_rfo.any_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F20\000\00000\000\000"
/* offset=2430933 */ "offcore_response.pf_rfo.any_cache_dram\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f20\000\00000\000\000"
/* offset=2431088 */ "offcore_response.pf_rfo.any_dram\000\000memory\000Offcore prefetch RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6020\000\00000\000\000"
/* offset=2431240 */ "offcore_response.pf_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3020\000\00000\000\000"
/* offset=2431414 */ "offcore_response.pf_rfo.any_llc_miss\000\000memory\000Offcore prefetch RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF820\000\00000\000\000"
/* offset=2431568 */ "offcore_response.pf_rfo.any_llc_miss\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf820\000\00000\000\000"
/* offset=2431720 */ "offcore_response.pf_rfo.any_location\000\000cache\000All offcore prefetch RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF20\000\00000\000\000"
/* offset=2431857 */ "offcore_response.pf_rfo.any_location\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff20\000\00000\000\000"
/* offset=2432008 */ "offcore_response.pf_rfo.io_csr_mmio\000\000cache\000Offcore prefetch RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000"
/* offset=2432176 */ "offcore_response.pf_rfo.io_csr_mmio\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000"
/* offset=2432325 */ "offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000"
/* offset=2432519 */ "offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000"
/* offset=2432687 */ "offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000"
/* offset=2432876 */ "offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000"
/* offset=2433046 */ "offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000"
/* offset=2433238 */ "offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000"
/* offset=2433410 */ "offcore_response.pf_rfo.local_cache\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000"
/* offset=2433562 */ "offcore_response.pf_rfo.local_cache\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000"
/* offset=2433710 */ "offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2720\000\00000\000\000"
/* offset=2433882 */ "offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4720\000\00000\000\000"
/* offset=2434054 */ "offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000"
/* offset=2434214 */ "offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000"
/* offset=2434374 */ "offcore_response.pf_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000"
/* offset=2434563 */ "offcore_response.pf_rfo.other_local_dram\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000"
/* offset=2434723 */ "offcore_response.pf_rfo.remote_cache\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1820\000\00000\000\000"
/* offset=2434884 */ "offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3820\000\00000\000\000"
/* offset=2435065 */ "offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5820\000\00000\000\000"
/* offset=2435246 */ "offcore_response.pf_rfo.remote_cache_hit\000\000cache\000Offcore prefetch RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000"
/* offset=2435410 */ "offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000Offcore prefetch RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000"
/* offset=2435575 */ "offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000"
/* offset=2435735 */ "offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000"
/* offset=2435895 */ "offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000"
/* offset=2436055 */ "offcore_response.pf_rfo.remote_dram\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000"
/* offset=2436205 */ "offcore_response.pf_software.any_response\000\000cache\000Counts Software Prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000011000\000\00000\000\000"
/* offset=2436377 */ "offcore_response.pf_software.ddr\000\000memory\000Counts Software Prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181801000\000\00000\000\000"
/* offset=2436563 */ "offcore_response.pf_software.ddr_far\000\000memory\000Counts Software Prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101001000\000\00000\000\000"
/* offset=2436747 */ "offcore_response.pf_software.ddr_near\000\000memory\000Counts Software Prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080801000\000\00000\000\000"
/* offset=2436934 */ "offcore_response.pf_software.l2_hit_far_tile\000\000cache\000Counts Software Prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800401000\000\00000\000\000"
/* offset=2437264 */ "offcore_response.pf_software.l2_hit_far_tile_e_f\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800401000\000\00000\000\000"
/* offset=2437602 */ "offcore_response.pf_software.l2_hit_far_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000401000\000\00000\000\000"
/* offset=2437902 */ "offcore_response.pf_software.l2_hit_near_tile\000\000cache\000Counts Software Prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800181000\000\00000\000\000"
/* offset=2438161 */ "offcore_response.pf_software.l2_hit_near_tile_e_f\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800081000\000\00000\000\000"
/* offset=2438426 */ "offcore_response.pf_software.l2_hit_near_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000081000\000\00000\000\000"
/* offset=2438687 */ "offcore_response.pf_software.l2_hit_this_tile_e\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004001000\000\00000\000\000"
/* offset=2438911 */ "offcore_response.pf_software.l2_hit_this_tile_f\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010001000\000\00000\000\000"
/* offset=2439135 */ "offcore_response.pf_software.l2_hit_this_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002001000\000\00000\000\000"
/* offset=2439359 */ "offcore_response.pf_software.l2_hit_this_tile_s\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008001000\000\00000\000\000"
/* offset=2439583 */ "offcore_response.pf_software.mcdram\000\000memory\000Counts Software Prefetches that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180601000\000\00000\000\000"
/* offset=2439775 */ "offcore_response.pf_software.mcdram_far\000\000memory\000Counts Software Prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100401000\000\00000\000\000"
/* offset=2439989 */ "offcore_response.pf_software.mcdram_near\000\000memory\000Counts Software Prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080201000\000\00000\000\000"
/* offset=2440181 */ "offcore_response.pf_software.outstanding\000\000cache\000Counts Software Prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000001000\000\00000\000\000"
/* offset=2440485 */ "offcore_response.prefetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5070\000\00000\000\000"
/* offset=2440683 */ "offcore_response.prefetch.any_cache_dram\000\000cache\000Offcore prefetch requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F70\000\00000\000\000"
/* offset=2440847 */ "offcore_response.prefetch.any_cache_dram\000\000cache\000REQUEST = PREFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f70\000\00000\000\000"
/* offset=2441003 */ "offcore_response.prefetch.any_dram\000\000memory\000Offcore prefetch requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6070\000\00000\000\000"
/* offset=2441153 */ "offcore_response.prefetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = PREFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3070\000\00000\000\000"
/* offset=2441328 */ "offcore_response.prefetch.any_llc_miss\000\000memory\000Offcore prefetch requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF870\000\00000\000\000"
/* offset=2441480 */ "offcore_response.prefetch.any_llc_miss\000\000memory\000REQUEST = PREFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf870\000\00000\000\000"
/* offset=2441633 */ "offcore_response.prefetch.any_location\000\000cache\000All offcore prefetch requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF70\000\00000\000\000"
/* offset=2441768 */ "offcore_response.prefetch.any_location\000\000cache\000REQUEST = PREFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff70\000\00000\000\000"
/* offset=2441920 */ "offcore_response.prefetch.io_csr_mmio\000\000cache\000Offcore prefetch requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000"
/* offset=2442086 */ "offcore_response.prefetch.io_csr_mmio\000\000cache\000REQUEST = PREFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000"
/* offset=2442236 */ "offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000"
/* offset=2442428 */ "offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000"
/* offset=2442597 */ "offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000"
/* offset=2442784 */ "offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000"
/* offset=2442955 */ "offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000"
/* offset=2443145 */ "offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000"
/* offset=2443318 */ "offcore_response.prefetch.local_cache\000\000cache\000Offcore prefetch requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000"
/* offset=2443468 */ "offcore_response.prefetch.local_cache\000\000cache\000REQUEST = PREFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000"
/* offset=2443617 */ "offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2770\000\00000\000\000"
/* offset=2443787 */ "offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4770\000\00000\000\000"
/* offset=2443957 */ "offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000"
/* offset=2444115 */ "offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000"
/* offset=2444273 */ "offcore_response.prefetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000"
/* offset=2444463 */ "offcore_response.prefetch.other_local_dram\000\000memory\000REQUEST = PREFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000"
/* offset=2444624 */ "offcore_response.prefetch.remote_cache\000\000cache\000Offcore prefetch requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1870\000\00000\000\000"
/* offset=2444783 */ "offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3870\000\00000\000\000"
/* offset=2444962 */ "offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5870\000\00000\000\000"
/* offset=2445141 */ "offcore_response.prefetch.remote_cache_hit\000\000cache\000Offcore prefetch requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000"
/* offset=2445303 */ "offcore_response.prefetch.remote_cache_hitm\000\000cache\000Offcore prefetch requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000"
/* offset=2445466 */ "offcore_response.prefetch.remote_cache_hitm\000\000cache\000REQUEST = PREFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000"
/* offset=2445627 */ "offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000"
/* offset=2445785 */ "offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000"
/* offset=2445943 */ "offcore_response.prefetch.remote_dram\000\000memory\000REQUEST = PREFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000"
/* offset=2446094 */ "offcore_response.split_lock_uc_lock.any_response\000\000cache\000Counts requests where the address of an atomic lock instruction spans a cache line boundary or the lock instruction is executed on uncacheable address\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000"
/* offset=2446361 */ "offcore_response.streaming_stores.any_response\000\000cache\000Counts all streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014800\000\00000\000\000"
/* offset=2446577 */ "offcore_response.streaming_stores.any_response\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2447058 */ "offcore_response.streaming_stores.any_response\000\000cache\000Counts non-temporal stores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000"
/* offset=2447199 */ "offcore_response.streaming_stores.l2_hit\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2447594 */ "offcore_response.streaming_stores.l2_hit\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2447999 */ "offcore_response.streaming_stores.l2_miss.any\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2448411 */ "offcore_response.streaming_stores.l2_miss.any\000\000cache\000Counts streaming store that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680004800\000\00000\000\000"
/* offset=2448565 */ "offcore_response.streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2449131 */ "offcore_response.streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2449674 */ "offcore_response.streaming_stores.outstanding\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2450212 */ "offcore_response.sw_prefetch.any_response\000\000cache\000Counts data cache lines requests by software prefetch instructions have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000011000\000\00000\000Counts data cache lines requests by software prefetch instructions have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2450670 */ "offcore_response.sw_prefetch.l2_hit\000\000cache\000Counts data cache lines requests by software prefetch instructions hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000041000\000\00000\000Counts data cache lines requests by software prefetch instructions hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2451042 */ "offcore_response.sw_prefetch.l2_hit\000\000cache\000Counts data cache lines requests by software prefetch instructions that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000041000\000\00000\000Counts data cache lines requests by software prefetch instructions that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2451424 */ "offcore_response.sw_prefetch.l2_miss.any\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2451813 */ "offcore_response.sw_prefetch.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2452378 */ "offcore_response.sw_prefetch.l2_miss.hitm_other_core\000\000cache\000Counts data cache lines requests by software prefetch instructions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000001000\000\00000\000Counts data cache lines requests by software prefetch instructions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2452921 */ "offcore_response.sw_prefetch.l2_miss.hitm_other_core\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2453474 */ "offcore_response.sw_prefetch.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache lines requests by software prefetch instructions that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200001000\000\00000\000Counts data cache lines requests by software prefetch instructions that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2454004 */ "offcore_response.sw_prefetch.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache lines requests by software prefetch instructions true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200001000\000\00000\000Counts data cache lines requests by software prefetch instructions true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2454524 */ "offcore_response.sw_prefetch.outstanding\000\000cache\000Counts data cache lines requests by software prefetch instructions outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000001000\000\00000\000Counts data cache lines requests by software prefetch instructions outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000"
/* offset=2455039 */ "offcore_response.uc_code_reads.any_response\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010200\000\00000\000\000"
/* offset=2455251 */ "offcore_response.uc_code_reads.ddr\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800200\000\00000\000\000"
/* offset=2455477 */ "offcore_response.uc_code_reads.ddr_far\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000200\000\00000\000\000"
/* offset=2455701 */ "offcore_response.uc_code_reads.ddr_near\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800200\000\00000\000\000"
/* offset=2455928 */ "offcore_response.uc_code_reads.l2_hit_far_tile_e_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400200\000\00000\000\000"
/* offset=2456306 */ "offcore_response.uc_code_reads.l2_hit_far_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400200\000\00000\000\000"
/* offset=2456646 */ "offcore_response.uc_code_reads.l2_hit_near_tile\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180200\000\00000\000\000"
/* offset=2456945 */ "offcore_response.uc_code_reads.l2_hit_near_tile_e_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080200\000\00000\000\000"
/* offset=2457250 */ "offcore_response.uc_code_reads.l2_hit_near_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080200\000\00000\000\000"
/* offset=2457551 */ "offcore_response.uc_code_reads.l2_hit_this_tile_e\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000200\000\00000\000\000"
/* offset=2457815 */ "offcore_response.uc_code_reads.l2_hit_this_tile_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000200\000\00000\000\000"
/* offset=2458079 */ "offcore_response.uc_code_reads.l2_hit_this_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000200\000\00000\000\000"
/* offset=2458343 */ "offcore_response.uc_code_reads.l2_hit_this_tile_s\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000200\000\00000\000\000"
/* offset=2458607 */ "offcore_response.uc_code_reads.mcdram\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600200\000\00000\000\000"
/* offset=2458839 */ "offcore_response.uc_code_reads.mcdram_far\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400200\000\00000\000\000"
/* offset=2459093 */ "offcore_response.uc_code_reads.mcdram_near\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200200\000\00000\000\000"
/* offset=2459325 */ "offcore_response.uc_code_reads.outstanding\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000200\000\00000\000\000"
/* offset=2459669 */ "offcore_response\000\000cache\000Counts the matrix events specified by MSR_OFFCORE_RESPx\000event=0xb7,period=100007,umask=0x1\000\00000\000\000"
/* offset=2459789 */ "offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000"
/* offset=2460294 */ "offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000"
/* offset=2460579 */ "offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100007,umask=0x1\000\00000\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000"
/* offset=2461084 */ "offcore_response\000\000cache\000Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000event=0xb7,period=100007,umask=0x1\000\00000\000\000"
/* offset=2461244 */ "op_cache_hit_miss.all_op_cache_accesses\000\000cache\000All Op Cache accesses. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x07\000\00000\000\000"
/* offset=2461384 */ "op_cache_hit_miss.all_op_cache_accesses\000\000cache\000Op cache accesses of all types\000event=0x28f,umask=0x07\000\00000\000\000"
/* offset=2461490 */ "op_cache_hit_miss.op_cache_hit\000\000cache\000Op Cache Hit. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x03\000\00000\000\000"
/* offset=2461612 */ "op_cache_hit_miss.op_cache_hit\000\000cache\000Op cache hits\000event=0x28f,umask=0x03\000\00000\000\000"
/* offset=2461692 */ "op_cache_hit_miss.op_cache_miss\000\000cache\000Op Cache Miss. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x04\000\00000\000\000"
/* offset=2461816 */ "op_cache_hit_miss.op_cache_miss\000\000cache\000Op cache misses\000event=0x28f,umask=0x04\000\00000\000\000"
/* offset=2461899 */ "other_assists.any\000\000pipeline\000Number of times a microcode assist is invoked by HW other than FP-assist. Examples include AD (page Access Dirty) and AVX* related assists\000event=0xc1,period=100003,umask=0x3f\000\00000\000\000"
/* offset=2462107 */ "other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000Number of microcode assists invoked by HW upon uop writeback\000"
/* offset=2462319 */ "other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000\000"
/* offset=2462471 */ "other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x80\000\00000\000\000"
/* offset=2462623 */ "other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000Number of assists associated with 256-bit AVX store operations\000"
/* offset=2462917 */ "other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000\000"
/* offset=2463149 */ "other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x8\000\00000\000This event counts the number of transitions from AVX-256 to legacy SSE when penalty is applicable  Spec update: BDM30\000"
/* offset=2463440 */ "other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x8\000\00000\000\000"
/* offset=2463621 */ "other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable\000event=0xc1,period=100003,umask=0x10\000\00000\000\000"
/* offset=2463776 */ "other_assists.itlb_miss_retired\000\000pipeline\000Retired instructions experiencing ITLB misses\000event=0xc1,period=100003,umask=0x2\000\00000\000\000"
/* offset=2463904 */ "other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x10\000\00000\000This event counts the number of transitions from legacy SSE to AVX-256 when penalty is applicable  Spec update: BDM30\000"
/* offset=2464189 */ "other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x10\000\00000\000\000"
/* offset=2464364 */ "other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable\000event=0xc1,period=100003,umask=0x20\000\00000\000\000"
/* offset=2464512 */ "packed_int_op_type.all\000\000floating point\000Retired packed integer ops of all types\000event=0xd,umask=0xff\000\00000\000\000"
/* offset=2464617 */ "packed_int_op_type.int128_add\000\000floating point\000Retired 128-bit packed integer add ops\000event=0xd,umask=0x01\000\00000\000\000"
/* offset=2464728 */ "packed_int_op_type.int128_aes\000\000floating point\000Retired 128-bit packed integer AES ops\000event=0xd,umask=0x05\000\00000\000\000"
/* offset=2464839 */ "packed_int_op_type.int128_all\000\000floating point\000Retired 128-bit packed integer ops of all types\000event=0xd,umask=0x0f\000\00000\000\000"
/* offset=2464959 */ "packed_int_op_type.int128_clm\000\000floating point\000Retired 128-bit packed integer CLM ops\000event=0xd,umask=0x08\000\00000\000\000"
/* offset=2465070 */ "packed_int_op_type.int128_cmp\000\000floating point\000Retired 128-bit packed integer compare ops\000event=0xd,umask=0x07\000\00000\000\000"
/* offset=2465185 */ "packed_int_op_type.int128_logical\000\000floating point\000Retired 128-bit packed integer logical ops\000event=0xd,umask=0x0d\000\00000\000\000"
/* offset=2465304 */ "packed_int_op_type.int128_mac\000\000floating point\000Retired 128-bit packed integer multiply-accumulate ops\000event=0xd,umask=0x04\000\00000\000\000"
/* offset=2465431 */ "packed_int_op_type.int128_mov\000\000floating point\000Retired 128-bit packed integer MOV ops\000event=0xd,umask=0x0a\000\00000\000\000"
/* offset=2465542 */ "packed_int_op_type.int128_mul\000\000floating point\000Retired 128-bit packed integer multiply ops\000event=0xd,umask=0x03\000\00000\000\000"
/* offset=2465658 */ "packed_int_op_type.int128_other\000\000floating point\000Retired 128-bit packed integer ops of other types\000event=0xd,umask=0x0e\000\00000\000\000"
/* offset=2465782 */ "packed_int_op_type.int128_pack\000\000floating point\000Retired 128-bit packed integer pack ops\000event=0xd,umask=0x0c\000\00000\000\000"
/* offset=2465895 */ "packed_int_op_type.int128_sha\000\000floating point\000Retired 128-bit packed integer SHA ops\000event=0xd,umask=0x06\000\00000\000\000"
/* offset=2466006 */ "packed_int_op_type.int128_shift\000\000floating point\000Retired 128-bit packed integer shift ops\000event=0xd,umask=0x09\000\00000\000\000"
/* offset=2466121 */ "packed_int_op_type.int128_shuffle\000\000floating point\000Retired 128-bit packed integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xd,umask=0x0b\000\00000\000\000"
/* offset=2466379 */ "packed_int_op_type.int128_sub\000\000floating point\000Retired 128-bit packed integer subtract ops\000event=0xd,umask=0x02\000\00000\000\000"
/* offset=2466495 */ "packed_int_op_type.int256_add\000\000floating point\000Retired 256-bit packed integer add ops\000event=0xd,umask=0x10\000\00000\000\000"
/* offset=2466606 */ "packed_int_op_type.int256_all\000\000floating point\000Retired 256-bit packed integer ops of all types\000event=0xd,umask=0xf0\000\00000\000\000"
/* offset=2466726 */ "packed_int_op_type.int256_cmp\000\000floating point\000Retired 256-bit packed integer compare ops\000event=0xd,umask=0x70\000\00000\000\000"
/* offset=2466841 */ "packed_int_op_type.int256_logical\000\000floating point\000Retired 256-bit packed integer logical ops\000event=0xd,umask=0xd0\000\00000\000\000"
/* offset=2466960 */ "packed_int_op_type.int256_mac\000\000floating point\000Retired 256-bit packed integer multiply-accumulate ops\000event=0xd,umask=0x40\000\00000\000\000"
/* offset=2467087 */ "packed_int_op_type.int256_mov\000\000floating point\000Retired 256-bit packed integer MOV ops\000event=0xd,umask=0xa0\000\00000\000\000"
/* offset=2467198 */ "packed_int_op_type.int256_mul\000\000floating point\000Retired 256-bit packed integer multiply ops\000event=0xd,umask=0x30\000\00000\000\000"
/* offset=2467314 */ "packed_int_op_type.int256_other\000\000floating point\000Retired 256-bit packed integer ops of other types\000event=0xd,umask=0xe0\000\00000\000\000"
/* offset=2467438 */ "packed_int_op_type.int256_pack\000\000floating point\000Retired 256-bit packed integer pack ops\000event=0xd,umask=0xc0\000\00000\000\000"
/* offset=2467551 */ "packed_int_op_type.int256_shift\000\000floating point\000Retired 256-bit packed integer shift ops\000event=0xd,umask=0x90\000\00000\000\000"
/* offset=2467666 */ "packed_int_op_type.int256_shuffle\000\000floating point\000Retired 256-bit packed integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xd,umask=0xb0\000\00000\000\000"
/* offset=2467924 */ "packed_int_op_type.int256_sub\000\000floating point\000Retired 256-bit packed integer subtract ops\000event=0xd,umask=0x20\000\00000\000\000"
/* offset=2468040 */ "page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x11\000\00000\000\000"
/* offset=2468196 */ "page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x11\000\00000\000Number of DTLB page walker loads that hit in the L1+FB\000"
/* offset=2468379 */ "page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x12\000\00000\000\000"
/* offset=2468532 */ "page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x12\000\00000\000Number of DTLB page walker loads that hit in the L2\000"
/* offset=2468709 */ "page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x14\000\00000\000\000"
/* offset=2468869 */ "page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x14\000\00000\000Number of DTLB page walker loads that hit in the L3  Spec update: HSD25\000"
/* offset=2469093 */ "page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x18\000\00000\000\000"
/* offset=2469250 */ "page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x18\000\00000\000Number of DTLB page walker loads from memory  Spec update: HSD25\000"
/* offset=2469464 */ "page_walker_loads.ept_dtlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x41\000\00000\000\000"
/* offset=2469639 */ "page_walker_loads.ept_dtlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L2\000event=0xbc,period=2000003,umask=0x42\000\00000\000\000"
/* offset=2469807 */ "page_walker_loads.ept_dtlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L3\000event=0xbc,period=2000003,umask=0x44\000\00000\000\000"
/* offset=2469975 */ "page_walker_loads.ept_dtlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in memory\000event=0xbc,period=2000003,umask=0x48\000\00000\000\000"
/* offset=2470147 */ "page_walker_loads.ept_itlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x81\000\00000\000\000"
/* offset=2470322 */ "page_walker_loads.ept_itlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x82\000\00000\000\000"
/* offset=2470490 */ "page_walker_loads.ept_itlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x84\000\00000\000\000"
/* offset=2470658 */ "page_walker_loads.ept_itlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in memory\000event=0xbc,period=2000003,umask=0x88\000\00000\000\000"
/* offset=2470830 */ "page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x21\000\00000\000\000"
/* offset=2470986 */ "page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x21\000\00000\000Number of ITLB page walker loads that hit in the L1+FB\000"
/* offset=2471169 */ "page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x22\000\00000\000\000"
/* offset=2471322 */ "page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x22\000\00000\000Number of ITLB page walker loads that hit in the L2\000"
/* offset=2471499 */ "page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x24\000\00000\000\000"
/* offset=2471659 */ "page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x24\000\00000\000Number of ITLB page walker loads that hit in the L3  Spec update: HSD25\000"
/* offset=2471883 */ "page_walker_loads.itlb_memory\000\000virtual memory\000Number of ITLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x28\000\00000\000Number of ITLB page walker loads from memory  Spec update: HSD25\000"
/* offset=2472097 */ "page_walks.cycles\000\000virtual memory\000Counts the total number of core cycles for all the page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x3\000\00000\000This event counts every cycle when a data (D) page walk or instruction (I) page walk is in progress\000"
/* offset=2472408 */ "page_walks.cycles\000\000virtual memory\000Duration of page-walks in core cycles\000event=0xc,period=2000000,umask=0x3\000\00000\000\000"
/* offset=2472520 */ "page_walks.cycles\000\000virtual memory\000Duration of page-walks in cycles\000event=0x5,period=200003,umask=0x3\000\00000\000Counts every core cycle a page-walk is in progress due to either a data memory operation or an instruction fetch\000"
/* offset=2472738 */ "page_walks.cycles\000\000virtual memory\000Total cycles for all the page walks. (I-side and D-side)\000event=0x5,period=200003,umask=0x3\000\00000\000This event counts every cycle when a data (D) page walk or instruction (I) page walk is in progress.  Since a pagewalk implies a TLB miss, the approximate cost of a TLB miss can be determined from this event\000"
/* offset=2473075 */ "page_walks.d_side_cycles\000\000virtual memory\000Counts the total number of core cycles for all the D-side page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x1\000\00000\000\000"
/* offset=2473301 */ "page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side only page walks\000event=0xc,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2473417 */ "page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side page-walks in core cycles\000event=0x5,period=200003,umask=0x1\000\00000\000This event counts every cycle when a D-side (walks due to a load) page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks\000"
/* offset=2473722 */ "page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side page-walks in cycles\000event=0x5,period=200003,umask=0x1\000\00000\000Counts every core cycle when a Data-side (walks due to a data operation) page walk is in progress\000"
/* offset=2473939 */ "page_walks.d_side_walks\000\000virtual memory\000Counts the total D-side page walks that are completed or started. The page walks started in the speculative path will also be counted\000event=0x5,edge=1,period=100003,umask=0x1\000\00000\000\000"
/* offset=2474159 */ "page_walks.d_side_walks\000\000virtual memory\000D-side page-walks\000event=0x5,edge=1,period=100003,umask=0x1\000\00000\000This event counts when a data (D) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000"
/* offset=2474446 */ "page_walks.d_side_walks\000\000virtual memory\000Number of D-side only page walks\000event=0xc,period=200000,umask=0x1\000\00000\000\000"
/* offset=2474558 */ "page_walks.i_side_cycles\000\000virtual memory\000Counts the total number of core cycles for all the I-side page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x2\000\00000\000This event counts every cycle when an I-side (walks due to an instruction fetch) page walk is in progress\000"
/* offset=2474889 */ "page_walks.i_side_cycles\000\000virtual memory\000Duration of I-Side page walks\000event=0xc,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2475000 */ "page_walks.i_side_cycles\000\000virtual memory\000Duration of I-side page-walks in core cycles\000event=0x5,period=200003,umask=0x2\000\00000\000This event counts every cycle when a I-side (walks due to an instruction fetch) page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks\000"
/* offset=2475319 */ "page_walks.i_side_cycles\000\000virtual memory\000Duration of I-side pagewalks in cycles\000event=0x5,period=200003,umask=0x2\000\00000\000Counts every core cycle when a Instruction-side (walks due to an instruction fetch) page walk is in progress\000"
/* offset=2475546 */ "page_walks.i_side_walks\000\000virtual memory\000Counts the total I-side page walks that are completed\000event=0x5,edge=1,period=100003,umask=0x2\000\00000\000\000"
/* offset=2475686 */ "page_walks.i_side_walks\000\000virtual memory\000I-side page-walks\000event=0x5,edge=1,period=100003,umask=0x2\000\00000\000This event counts when an instruction (I) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000"
/* offset=2475981 */ "page_walks.i_side_walks\000\000virtual memory\000Number of I-Side page walks\000event=0xc,period=200000,umask=0x2\000\00000\000\000"
/* offset=2476088 */ "page_walks.llc_miss\000\000memory\000Number of any page walk that had a miss in LLC. Does not necessary cause a SUSPEND\000event=0xbe,period=100003,umask=0x1\000\00000\000\000"
/* offset=2476239 */ "page_walks.llc_miss\000\000memory\000Number of any page walk that had a miss in LLC\000event=0xbe,period=100003,umask=0x1\000\00000\000\000"
/* offset=2476354 */ "page_walks.walks\000\000virtual memory\000Counts the total page walks that are completed (I-side and D-side)\000event=0x5,edge=1,period=100003,umask=0x3\000\00000\000\000"
/* offset=2476500 */ "page_walks.walks\000\000virtual memory\000Number of page-walks executed\000event=0xc,period=200000,umask=0x3\000\00000\000\000"
/* offset=2476602 */ "page_walks.walks\000\000virtual memory\000Total page walks that are completed (I-side and D-side)\000event=0x5,edge=1,period=100003,umask=0x3\000\00000\000This event counts when a data (D) page walk or an instruction (I) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000"
/* offset=2476952 */ "partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000"
/* offset=2477071 */ "partial_rat_stalls.flags_merge_uop\000\000pipeline\000Increments the number of flags-merge uops in flight each cycle\000event=0x59,period=2000003,umask=0x20\000\00000\000\000"
/* offset=2477221 */ "partial_rat_stalls.flags_merge_uop_cycles\000\000pipeline\000Performance sensitive flags-merging uops added by Sandy Bridge u-arch\000event=0x59,cmask=1,period=2000003,umask=0x20\000\00000\000This event counts the number of cycles spent executing performance-sensitive flags-merging uops. For example, shift CL (merge_arith_flags). For more details, See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual\000"
/* offset=2477624 */ "partial_rat_stalls.flags_merge_uop_cycles\000\000pipeline\000Performance sensitive flags-merging uops added by Sandy Bridge u-arch\000event=0x59,cmask=1,period=2000003,umask=0x20\000\00000\000This event counts the number of cycles spent executing performance-sensitive flags-merging uops. For example, shift CL (merge_arith_flags). For more details, See the Intel? 64 and IA-32 Architectures Optimization Reference Manual\000"
/* offset=2478025 */ "partial_rat_stalls.mul_single_uop\000\000pipeline\000Multiply packed/scalar single precision uops allocated\000event=0x59,period=2000003,umask=0x80\000\00000\000\000"
/* offset=2478166 */ "partial_rat_stalls.scoreboard\000\000pipeline\000Cycles where the pipeline is stalled due to serializing operations\000event=0x59,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the microcode scoreboard stalls happen\000"
/* offset=2478390 */ "partial_rat_stalls.slow_lea_window\000\000pipeline\000Cycles with at least one slow LEA uop being allocated\000event=0x59,period=2000003,umask=0x40\000\00000\000This event counts the number of cycles with at least one slow LEA uop being allocated. A uop is generally considered as slow LEA if it has three sources (for example, two sources and immediate) regardless of whether it is a result of LEA instruction or not. Examples of the slow LEA uop are or uops with base, index, and offset source operands using base and index reqisters, where base is EBR/RBP/R13, using RIP relative or 16-bit addressing modes. See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual for more details about slow LEA instructions\000"
/* offset=2479099 */ "partial_rat_stalls.slow_lea_window\000\000pipeline\000Cycles with at least one slow LEA uop being allocated\000event=0x59,period=2000003,umask=0x40\000\00000\000This event counts the number of cycles with at least one slow LEA uop being allocated. A uop is generally considered as slow LEA if it has three sources (for example, two sources and immediate) regardless of whether it is a result of LEA instruction or not. Examples of the slow LEA uop are or uops with base, index, and offset source operands using base and index reqisters, where base is EBR/RBP/R13, using RIP relative or 16-bit addressing modes. See the Intel? 64 and IA-32 Architectures Optimization Reference Manual for more details about slow LEA instructions\000"
/* offset=2479806 */ "prefetch.hw_prefetch\000\000memory\000L1 hardware prefetch request\000event=0x7,period=2000000,umask=0x10\000\00000\000\000"
/* offset=2479905 */ "prefetch.prefetchnta\000\000memory\000Streaming SIMD Extensions (SSE) Prefetch NTA instructions executed\000event=0x7,period=200000,umask=0x88\000\00000\000\000"
/* offset=2480041 */ "prefetch.prefetcht0\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT0 instructions executed\000event=0x7,period=200000,umask=0x81\000\00000\000\000"
/* offset=2480174 */ "prefetch.prefetcht1\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT1 instructions executed\000event=0x7,period=200000,umask=0x82\000\00000\000\000"
/* offset=2480307 */ "prefetch.prefetcht2\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT2 instructions executed\000event=0x7,period=200000,umask=0x84\000\00000\000\000"
/* offset=2480440 */ "prefetch.software_prefetch.ar\000\000memory\000Any Software prefetch\000event=0x7,period=200000,umask=0x8f\000\00000\000\000"
/* offset=2480540 */ "prefetch.software_prefetch\000\000memory\000Any Software prefetch\000event=0x7,period=200000,umask=0xf\000\00000\000\000"
/* offset=2480636 */ "prefetch.sw_l2\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT1 and PrefetchT2 instructions executed\000event=0x7,period=200000,umask=0x86\000\00000\000\000"
/* offset=2480779 */ "qpi_ctl_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of non data (control) flits transmitted . Derived from unc_q_txl_flits_g0.non_data. Unit: uncore_qpi \000event=0,umask=0x4\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000"
/* offset=2482340 */ "qpi_data_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of data flits transmitted . Derived from unc_q_txl_flits_g0.data. Unit: uncore_qpi \000event=0,umask=0x2\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000"
/* offset=2483994 */ "rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000"
/* offset=2484081 */ "rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2484167 */ "rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2484269 */ "rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2484373 */ "rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000"
/* offset=2484470 */ "recycleq.any_ld\000\000pipeline\000Counts any retired load that was pushed into the recycle queue for any reason\000event=0x3,period=200003,umask=0x40\000\00000\000\000"
/* offset=2484614 */ "recycleq.any_st\000\000pipeline\000Counts any retired store that was pushed into the recycle queue for any reason\000event=0x3,period=200003,umask=0x80\000\00000\000\000"
/* offset=2484759 */ "recycleq.ld_block_st_forward\000\000pipeline\000Counts the number of occurrences a retired load gets blocked because its address partially overlaps with a store  Supports address when precise (Precise event)\000event=0x3,period=200003,umask=0x1\000\00000\000\000"
/* offset=2484997 */ "recycleq.ld_block_std_notready\000\000pipeline\000Counts the number of occurrences a retired load gets blocked because its address overlaps with a store whose data is not ready\000event=0x3,period=200003,umask=0x2\000\00000\000\000"
/* offset=2485204 */ "recycleq.ld_splits\000\000pipeline\000Counts the number of occurrences a retired load that is a cache line split. Each split should be counted only once  Supports address when precise (Precise event)\000event=0x3,period=200003,umask=0x8\000\00000\000\000"
/* offset=2485434 */ "recycleq.lock\000\000pipeline\000Counts all the retired locked loads. It does not include stores because we would double count if we count stores\000event=0x3,period=200003,umask=0x10\000\00000\000\000"
/* offset=2485611 */ "recycleq.st_splits\000\000pipeline\000Counts the number of occurrences a retired store that is a cache line split. Each split should be counted only once\000event=0x3,period=200003,umask=0x4\000\00000\000This event counts the number of retired store that experienced a cache line boundary split(Precise Event). Note that each spilt should be counted only once\000"
/* offset=2485950 */ "recycleq.sta_full\000\000pipeline\000Counts the store micro-ops retired that were pushed in the rehad queue because the store address buffer is full\000event=0x3,period=200003,umask=0x20\000\00000\000\000"
/* offset=2486130 */ "rehabq.any_ld\000\000cache\000Any reissued load uops\000event=0x3,period=200003,umask=0x40\000\00000\000This event counts the number of load uops reissued from Rehabq\000"
/* offset=2486276 */ "rehabq.any_st\000\000cache\000Any reissued store uops\000event=0x3,period=200003,umask=0x80\000\00000\000This event counts the number of store uops reissued from Rehabq\000"
/* offset=2486424 */ "rehabq.ld_block_st_forward\000\000cache\000Loads blocked due to store forward restriction (Precise event)\000event=0x3,period=200003,umask=0x1\000\00000\000This event counts the number of retired loads that were prohibited from receiving forwarded data from the store because of address mismatch (Precise event)\000"
/* offset=2486715 */ "rehabq.ld_block_std_notready\000\000cache\000Loads blocked due to store data not ready\000event=0x3,period=200003,umask=0x2\000\00000\000This event counts the cases where a forward was technically possible, but did not occur because the store data was not available at the right time\000"
/* offset=2486978 */ "rehabq.ld_splits\000\000cache\000Load uops that split cache line boundary (Precise event)\000event=0x3,period=200003,umask=0x8\000\00000\000This event counts the number of retire loads that experienced cache line boundary splits (Precise event)\000"
/* offset=2487202 */ "rehabq.lock\000\000cache\000Uops with lock semantics\000event=0x3,period=200003,umask=0x10\000\00000\000This event counts the number of retired memory operations with lock semantics. These are either implicit locked instructions such as the XCHG instruction or instructions with an explicit LOCK prefix (0xF0)\000"
/* offset=2487491 */ "rehabq.st_splits\000\000cache\000Store uops that split cache line boundary\000event=0x3,period=200003,umask=0x4\000\00000\000This event counts the number of retire stores that experienced cache line boundary splits\000"
/* offset=2487685 */ "rehabq.sta_full\000\000cache\000Store address buffer full\000event=0x3,period=200003,umask=0x20\000\00000\000This event counts the number of retired stores that are delayed because there is not a store address buffer available\000"
/* offset=2487891 */ "reissue.any.ar\000\000pipeline\000Micro-op reissues for any cause (At Retirement)\000event=0x3,period=200000,umask=0xff\000\00000\000\000"
/* offset=2488004 */ "reissue.any\000\000pipeline\000Micro-op reissues for any cause\000event=0x3,period=200000,umask=0x7f\000\00000\000\000"
/* offset=2488098 */ "reissue.overlap_store.ar\000\000pipeline\000Micro-op reissues on a store-load collision (At Retirement)\000event=0x3,period=200000,umask=0x81\000\00000\000\000"
/* offset=2488233 */ "reissue.overlap_store\000\000pipeline\000Micro-op reissues on a store-load collision\000event=0x3,period=200000,umask=0x1\000\00000\000\000"
/* offset=2488348 */ "remote_outbound_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7c7,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 0\000"
/* offset=2488525 */ "remote_outbound_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x807,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 1\000"
/* offset=2488702 */ "remote_outbound_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x847,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 2\000"
/* offset=2488879 */ "remote_outbound_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0x887,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 3\000"
/* offset=2489056 */ "remote_processor_read_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 0\000"
/* offset=2489228 */ "remote_processor_read_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 10\000"
/* offset=2489403 */ "remote_processor_read_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 11\000"
/* offset=2489578 */ "remote_processor_read_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 1\000"
/* offset=2489750 */ "remote_processor_read_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 2\000"
/* offset=2489922 */ "remote_processor_read_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 3\000"
/* offset=2490094 */ "remote_processor_read_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 4\000"
/* offset=2490267 */ "remote_processor_read_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 5\000"
/* offset=2490440 */ "remote_processor_read_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 6\000"
/* offset=2490613 */ "remote_processor_read_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 7\000"
/* offset=2490786 */ "remote_processor_read_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 8\000"
/* offset=2490959 */ "remote_processor_read_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 9\000"
/* offset=2491132 */ "remote_processor_write_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 0\000"
/* offset=2491306 */ "remote_processor_write_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 10\000"
/* offset=2491483 */ "remote_processor_write_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 11\000"
/* offset=2491660 */ "remote_processor_write_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 1\000"
/* offset=2491834 */ "remote_processor_write_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 2\000"
/* offset=2492008 */ "remote_processor_write_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 3\000"
/* offset=2492182 */ "remote_processor_write_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 4\000"
/* offset=2492357 */ "remote_processor_write_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 5\000"
/* offset=2492532 */ "remote_processor_write_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 6\000"
/* offset=2492707 */ "remote_processor_write_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 7\000"
/* offset=2492882 */ "remote_processor_write_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 8\000"
/* offset=2493057 */ "remote_processor_write_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 9\000"
/* offset=2493232 */ "remote_socket_inf0_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 0\000"
/* offset=2493429 */ "remote_socket_inf0_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 1\000"
/* offset=2493626 */ "remote_socket_inf0_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 2\000"
/* offset=2493823 */ "remote_socket_inf0_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 3\000"
/* offset=2494020 */ "remote_socket_inf0_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 4\000"
/* offset=2494217 */ "remote_socket_inf0_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 5\000"
/* offset=2494414 */ "remote_socket_inf0_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 6\000"
/* offset=2494611 */ "remote_socket_inf0_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 7\000"
/* offset=2494808 */ "remote_socket_inf0_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 0\000"
/* offset=2495009 */ "remote_socket_inf0_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 1\000"
/* offset=2495210 */ "remote_socket_inf0_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 2\000"
/* offset=2495411 */ "remote_socket_inf0_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 3\000"
/* offset=2495612 */ "remote_socket_inf0_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 4\000"
/* offset=2495813 */ "remote_socket_inf0_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 5\000"
/* offset=2496014 */ "remote_socket_inf0_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 6\000"
/* offset=2496215 */ "remote_socket_inf0_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 7\000"
/* offset=2496416 */ "remote_socket_inf1_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 0\000"
/* offset=2496613 */ "remote_socket_inf1_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 1\000"
/* offset=2496810 */ "remote_socket_inf1_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 2\000"
/* offset=2497007 */ "remote_socket_inf1_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 3\000"
/* offset=2497204 */ "remote_socket_inf1_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 4\000"
/* offset=2497401 */ "remote_socket_inf1_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 5\000"
/* offset=2497598 */ "remote_socket_inf1_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 6\000"
/* offset=2497795 */ "remote_socket_inf1_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 7\000"
/* offset=2497992 */ "remote_socket_inf1_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 0\000"
/* offset=2498193 */ "remote_socket_inf1_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 1\000"
/* offset=2498394 */ "remote_socket_inf1_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 2\000"
/* offset=2498595 */ "remote_socket_inf1_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 3\000"
/* offset=2498796 */ "remote_socket_inf1_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 4\000"
/* offset=2498997 */ "remote_socket_inf1_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 5\000"
/* offset=2499198 */ "remote_socket_inf1_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 6\000"
/* offset=2499399 */ "remote_socket_inf1_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 7\000"
/* offset=2499600 */ "remote_socket_upstream_read_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 0\000"
/* offset=2499782 */ "remote_socket_upstream_read_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 1\000"
/* offset=2499964 */ "remote_socket_upstream_read_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 2\000"
/* offset=2500146 */ "remote_socket_upstream_read_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 3\000"
/* offset=2500328 */ "remote_socket_upstream_write_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 0\000"
/* offset=2500512 */ "remote_socket_upstream_write_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 1\000"
/* offset=2500696 */ "remote_socket_upstream_write_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 2\000"
/* offset=2500880 */ "remote_socket_upstream_write_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 3\000"
/* offset=2501064 */ "resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2501165 */ "resource_stalls.any\000\000pipeline\000Resource-related stall cycles  Spec update: HSD135\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles allocation is stalled due to resource related reason  Spec update: HSD135\000"
/* offset=2501367 */ "resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Counts resource-related stall cycles\000"
/* offset=2501504 */ "resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles Allocation is stalled due to Resource Related reason\000"
/* offset=2501664 */ "resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000This event counts resource-related stall cycles\000"
/* offset=2501812 */ "resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2501913 */ "resource_stalls.div_busy\000\000pipeline\000Cycles issue is stalled due to div busy\000event=0xdc,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2502029 */ "resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000"
/* offset=2502138 */ "resource_stalls.lb\000\000pipeline\000Counts the cycles of stall due to lack of load buffers\000event=0xa2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2502263 */ "resource_stalls.lb_sb\000\000pipeline\000Resource stalls due to load or store buffers all being in use\000event=0xa2,period=2000003,umask=0xa\000\00000\000\000"
/* offset=2502398 */ "resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2502495 */ "resource_stalls.mem_rs\000\000pipeline\000Resource stalls due to memory buffers or Reservation Station (RS) being fully utilized\000event=0xa2,period=2000003,umask=0xe\000\00000\000\000"
/* offset=2502656 */ "resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000"
/* offset=2502756 */ "resource_stalls.ooo_rsrc\000\000pipeline\000Resource stalls due to Rob being full, FCSW, MXCSR and OTHER\000event=0xa2,period=2000003,umask=0xf0\000\00000\000\000"
/* offset=2502894 */ "resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000"
/* offset=2503004 */ "resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000This event counts ROB full stall cycles. This counts cycles that the pipeline backend blocked uop delivery from the front end\000"
/* offset=2503244 */ "resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000"
/* offset=2503359 */ "resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000"
/* offset=2503458 */ "resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000This event counts stall cycles caused by absence of eligible entries in the reservation station (RS). This may result from RS overflow, or from RS deallocation because of the RS array Write Port allocation scheme (each RS entry has two write ports instead of four. As a result, empty entries could not be used, although RS is not really full). This counts cycles that the pipeline backend blocked uop delivery from the front end\000"
/* offset=2504009 */ "resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000"
/* offset=2504132 */ "resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2504245 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000"
/* offset=2504559 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000"
/* offset=2504874 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Cycles stalled due to no store buffers available (not including draining form sync)\000"
/* offset=2505112 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts cycles during which no instructions were allocated because no Store Buffers (SB) were available\000"
/* offset=2505380 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts stall cycles caused by the store buffer (SB) overflow (excluding draining from synch). This counts cycles that the pipeline backend blocked uop delivery from the front end\000"
/* offset=2505724 */ "resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000\000"
/* offset=2505879 */ "resource_stalls.sb\000cpu_core\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync). Unit: cpu_core \000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000"
/* offset=2506218 */ "resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000"
/* offset=2506369 */ "resource_stalls.scoreboard\000cpu_core\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations. Unit: cpu_core \000event=0xa2,period=100003,umask=0x2\000\00000\000\000"
/* offset=2506545 */ "resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000"
/* offset=2506644 */ "resource_stalls2.all_fl_empty\000\000pipeline\000Cycles with either free list is empty\000event=0x5b,period=2000003,umask=0xc\000\00000\000\000"
/* offset=2506763 */ "resource_stalls2.all_prf_control\000\000pipeline\000Resource stalls2 control structures full for physical registers\000event=0x5b,period=2000003,umask=0xf\000\00000\000\000"
/* offset=2506911 */ "resource_stalls2.bob_full\000\000pipeline\000Cycles when Allocator is stalled if BOB is full and new branch needs it\000event=0x5b,period=2000003,umask=0x40\000\00000\000\000"
/* offset=2507061 */ "resource_stalls2.ooo_rsrc\000\000pipeline\000Resource stalls out of order resources full\000event=0x5b,period=2000003,umask=0x4f\000\00000\000\000"
/* offset=2507183 */ "resyncs_or_nc_redirects\000\000other\000Pipeline restarts not caused by branch mispredicts\000event=0x96\000\00000\000\000"
/* offset=2507281 */ "rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000Count cases of saving new LBR records by hardware\000"
/* offset=2507440 */ "rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000This event counts cases of saving new LBR records by hardware. This assumes proper enabling of LBRs and takes into account LBR filtering done by the LBR_SELECT register\000"
/* offset=2507718 */ "rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000\000"
/* offset=2507828 */ "rob_misc_events.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=2000003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000"
/* offset=2508199 */ "rob_misc_events.pause_inst\000\000pipeline\000Number of retired PAUSE instructions (that do not end up with a VMExit to the VMM; TSX aborted Instructions may be counted). This event is not supported on first SKL and KBL products\000event=0xcc,period=2000003,umask=0x40\000\00000\000\000"
/* offset=2508461 */ "rs.empty\000\000other\000Cycles when Reservation Station (RS) is empty for the thread\000event=0xa5,period=1000003,umask=0x7\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into starvation periods (e.g. branch mispredictions or i-cache misses)\000"
/* offset=2508798 */ "rs.empty\000cpu_core\000other\000Cycles when Reservation Station (RS) is empty for the thread. Unit: cpu_core \000event=0xa5,period=1000003,umask=0x7\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into starvation periods (e.g. branch mispredictions or i-cache misses)\000"
/* offset=2509160 */ "rs.empty_count\000\000other\000Counts end of periods where the Reservation Station (RS) was empty\000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000"
/* offset=2509501 */ "rs.empty_count\000cpu_core\000other\000Counts end of periods where the Reservation Station (RS) was empty. Unit: cpu_core \000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000"
/* offset=2509867 */ "rs_empty.count\000\000other\000This event is deprecated. Refer to new event RS.EMPTY_COUNT\000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00010\000\000"
/* offset=2510010 */ "rs_empty.count\000cpu_core\000other\000This event is deprecated. Refer to new event RS.EMPTY_COUNT. Unit: cpu_core \000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00010\000\000"
/* offset=2510178 */ "rs_empty.cycles\000\000other\000This event is deprecated. Refer to new event RS.EMPTY\000event=0xa5,period=1000003,umask=0x7\000\00010\000\000"
/* offset=2510296 */ "rs_empty.cycles\000cpu_core\000other\000This event is deprecated. Refer to new event RS.EMPTY. Unit: cpu_core \000event=0xa5,period=1000003,umask=0x7\000\00010\000\000"
/* offset=2510439 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=1000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into stravation periods (e.g. branch mispredictions or i-cache misses)\000"
/* offset=2510793 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for the thread.; Note: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000"
/* offset=2511149 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Cycles the RS is empty for the thread\000"
/* offset=2511321 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the reservation station (RS) is empty for the thread.\nNote: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000"
/* offset=2511687 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles when the Reservation Station ( RS ) is empty for the thread. The RS is a structure that buffers allocated micro-ops from the Front-end. If there are many cycles when the RS is empty, it may represent an underflow of instructions delivered from the Front-end\000"
/* offset=2512104 */ "rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2512239 */ "rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate front-end Latency Bound issues\000"
/* offset=2512599 */ "rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2512825 */ "rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000"
/* offset=2513050 */ "rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty\000event=0x5e,cmask=1,edge=1,inv=1,period=100003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000"
/* offset=2513399 */ "rs_full_stall.all\000\000pipeline\000Counts the number of cycles the Alloc pipeline is stalled when any one of the RSs (IEC, FPC and MEC) is full. This event is a superset of all the individual RS stall event counts\000event=0xcb,period=200003,umask=0x1f\000\00000\000\000"
/* offset=2513647 */ "rs_full_stall.all\000\000pipeline\000Counts the total number of core cycles the Alloc pipeline is stalled when any one of the reservation stations is full\000event=0xcb,period=200003,umask=0x1f\000\00000\000\000"
/* offset=2513834 */ "rs_full_stall.mec\000\000pipeline\000Counts the number of core cycles when allocation pipeline is stalled and is waiting for a free MEC reservation station entry\000event=0xcb,period=200003,umask=0x1\000\00000\000\000"
/* offset=2514027 */ "rs_full_stall.mec\000\000pipeline\000Counts the number of cycles and allocation pipeline is stalled and is waiting for a free MEC reservation station entry.  The cycles should be appropriately counted in case of the cracked ops e.g. In case of a cracked load-op, the load portion is sent to M\000event=0xcb,period=200003,umask=0x1\000\00000\000Counts the number of cycles and allocation pipeline is stalled and is waiting for a free MEC reservation station entry.  The cycles should be appropriately counted in case of the cracked ops e.g. In case of a cracked load-op, the load portion is sent to M\000"
/* offset=2514606 */ "rtm_retired.aborted\000\000memory\000Number of times RTM abort was triggered (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered  (Precise event)\000"
/* offset=2514787 */ "rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered (Precise event)\000"
/* offset=2515026 */ "rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000\000"
/* offset=2515210 */ "rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000"
/* offset=2515369 */ "rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000"
/* offset=2515653 */ "rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000"
/* offset=2515927 */ "rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000"
/* offset=2516231 */ "rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000"
/* offset=2516525 */ "rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000"
/* offset=2516758 */ "rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times an RTM execution aborted due to incompatible memory type\000"
/* offset=2516981 */ "rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000"
/* offset=2517278 */ "rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000"
/* offset=2517574 */ "rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an RTM abort\000"
/* offset=2517816 */ "rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000"
/* offset=2518004 */ "rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an RTM abort\000"
/* offset=2518214 */ "rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000\000"
/* offset=2518366 */ "rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc9,period=2000003,umask=0x40\000\00000\000\000"
/* offset=2518535 */ "rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times a RTM caused a fault\000"
/* offset=2518720 */ "rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times RTM aborted and was not due to the abort conditions in subevents 3-6\000"
/* offset=2518979 */ "rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000"
/* offset=2519252 */ "rtm_retired.aborted_timer\000\000memory\000Number of times an RTM execution aborted due to uncommon conditions\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000"
/* offset=2519396 */ "rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000"
/* offset=2519638 */ "rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000"
/* offset=2519870 */ "rtm_retired.commit\000\000memory\000Number of times RTM commit succeeded\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000"
/* offset=2520011 */ "rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000"
/* offset=2520181 */ "rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000"
/* offset=2520341 */ "rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2520465 */ "rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000"
/* offset=2520659 */ "rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region. Does not count nested transactions\000"
/* offset=2520843 */ "rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2520951 */ "rtm_retired.start\000\000memory\000Number of times we entered an RTM region; does not count nested transactions\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region\n does not count nested transactions\000"
/* offset=2521171 */ "sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000"
/* offset=2521260 */ "seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2521354 */ "segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\00000\000\000"
/* offset=2521456 */ "serialization.c01_ms_scb\000cpu_atom\000other\000Counts the number of issue slots in a UMWAIT or TPAUSE instruction where no uop issues due to the instruction putting the CPU into the C0.1 activity state. For Tremont, UMWAIT and TPAUSE will only put the CPU into C0.1 activity state (not C0.2 activity state). Unit: cpu_atom \000event=0x75,period=200003,umask=0x4\000\00000\000\000"
/* offset=2521813 */ "serialization.non_c01_ms_scb\000\000pipeline\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires\000event=0x75,period=200003,umask=0x2\000\00000\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. The most commonly executed instruction with an MS scoreboard is PAUSE\000"
/* offset=2522348 */ "serialization.non_c01_ms_scb\000cpu_atom\000pipeline\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. Unit: cpu_atom \000event=0x75,period=200003,umask=0x2\000\00000\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. The most commonly executed instruction with an MS scoreboard is PAUSE\000"
/* offset=2522908 */ "simd_assist\000\000floating point\000SIMD assists invoked\000event=0xcd,period=100000\000\00000\000\000"
/* offset=2522987 */ "simd_comp_inst_retired.packed_single\000\000floating point\000Retired computational Streaming SIMD Extensions (SSE) packed-single instructions\000event=0xca,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2523162 */ "simd_comp_inst_retired.scalar_double\000\000floating point\000Retired computational Streaming SIMD Extensions 2 (SSE2) scalar-double instructions\000event=0xca,period=2000000,umask=0x8\000\00000\000\000"
/* offset=2523340 */ "simd_comp_inst_retired.scalar_single\000\000floating point\000Retired computational Streaming SIMD Extensions (SSE) scalar-single instructions\000event=0xca,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2523515 */ "simd_fp_256.packed_double\000\000floating point\000Number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2523673 */ "simd_fp_256.packed_double\000\000floating point\000number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000Counts 256-bit packed double-precision floating-point instructions\000"
/* offset=2523897 */ "simd_fp_256.packed_single\000\000floating point\000Number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2524056 */ "simd_fp_256.packed_single\000\000floating point\000number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000Counts 256-bit packed single-precision floating-point instructions\000"
/* offset=2524281 */ "simd_inst_retired.packed_single\000\000floating point\000Retired Streaming SIMD Extensions (SSE) packed-single instructions\000event=0xc7,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2524437 */ "simd_inst_retired.scalar_double\000\000floating point\000Retired Streaming SIMD Extensions 2 (SSE2) scalar-double instructions\000event=0xc7,period=2000000,umask=0x8\000\00000\000\000"
/* offset=2524596 */ "simd_inst_retired.scalar_single\000\000floating point\000Retired Streaming SIMD Extensions (SSE) scalar-single instructions\000event=0xc7,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2524752 */ "simd_inst_retired.vector\000\000floating point\000Retired Streaming SIMD Extensions 2 (SSE2) vector instructions\000event=0xc7,period=2000000,umask=0x10\000\00000\000\000"
/* offset=2524898 */ "simd_instr_retired\000\000floating point\000SIMD Instructions retired\000event=0xce,period=2000000\000\00000\000\000"
/* offset=2524990 */ "simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000"
/* offset=2525101 */ "simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000"
/* offset=2525227 */ "simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000"
/* offset=2525352 */ "simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000"
/* offset=2525473 */ "simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000"
/* offset=2525593 */ "simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000"
/* offset=2525721 */ "simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000"
/* offset=2525836 */ "simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000"
/* offset=2525945 */ "simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000"
/* offset=2526069 */ "simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000"
/* offset=2526192 */ "simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000"
/* offset=2526318 */ "simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000"
/* offset=2526436 */ "simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000"
/* offset=2526562 */ "simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000"
/* offset=2526675 */ "simd_sat_instr_retired\000\000floating point\000Saturated arithmetic instructions retired\000event=0xcf,period=2000000\000\00000\000\000"
/* offset=2526787 */ "simd_sat_uop_exec.ar\000\000floating point\000SIMD saturated arithmetic micro-ops retired\000event=0xb1,period=2000000,umask=0x80\000\00000\000\000"
/* offset=2526910 */ "simd_sat_uop_exec.s\000\000floating point\000SIMD saturated arithmetic micro-ops executed\000event=0xb1,period=2000000\000\00000\000\000"
/* offset=2527022 */ "simd_uop_type_exec.arithmetic.ar\000\000floating point\000SIMD packed arithmetic micro-ops retired\000event=0xb3,period=2000000,umask=0xa0\000\00000\000\000"
/* offset=2527154 */ "simd_uop_type_exec.arithmetic.s\000\000floating point\000SIMD packed arithmetic micro-ops executed\000event=0xb3,period=2000000,umask=0x20\000\00000\000\000"
/* offset=2527286 */ "simd_uop_type_exec.logical.ar\000\000floating point\000SIMD packed logical micro-ops retired\000event=0xb3,period=2000000,umask=0x90\000\00000\000\000"
/* offset=2527412 */ "simd_uop_type_exec.logical.s\000\000floating point\000SIMD packed logical micro-ops executed\000event=0xb3,period=2000000,umask=0x10\000\00000\000\000"
/* offset=2527538 */ "simd_uop_type_exec.mul.ar\000\000floating point\000SIMD packed multiply micro-ops retired\000event=0xb3,period=2000000,umask=0x81\000\00000\000\000"
/* offset=2527661 */ "simd_uop_type_exec.mul.s\000\000floating point\000SIMD packed multiply micro-ops executed\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2527783 */ "simd_uop_type_exec.pack.ar\000\000floating point\000SIMD packed micro-ops retired\000event=0xb3,period=2000000,umask=0x84\000\00000\000\000"
/* offset=2527898 */ "simd_uop_type_exec.pack.s\000\000floating point\000SIMD packed micro-ops executed\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2528012 */ "simd_uop_type_exec.shift.ar\000\000floating point\000SIMD packed shift micro-ops retired\000event=0xb3,period=2000000,umask=0x82\000\00000\000\000"
/* offset=2528134 */ "simd_uop_type_exec.shift.s\000\000floating point\000SIMD packed shift micro-ops executed\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2528255 */ "simd_uop_type_exec.unpack.ar\000\000floating point\000SIMD unpacked micro-ops retired\000event=0xb3,period=2000000,umask=0x88\000\00000\000\000"
/* offset=2528374 */ "simd_uop_type_exec.unpack.s\000\000floating point\000SIMD unpacked micro-ops executed\000event=0xb3,period=2000000,umask=0x8\000\00000\000\000"
/* offset=2528492 */ "simd_uops_exec.ar\000\000floating point\000SIMD micro-ops retired (excluding stores) (Must be precise)\000event=0xb0,period=2000000,umask=0x80\000\00000\000\000"
/* offset=2528628 */ "simd_uops_exec.s\000\000floating point\000SIMD micro-ops executed (excluding stores)\000event=0xb0,period=2000000\000\00000\000\000"
/* offset=2528735 */ "snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000"
/* offset=2528831 */ "snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000"
/* offset=2528929 */ "snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000"
/* offset=2529027 */ "snoop_stall_drv.all_agents\000\000other\000Bus stalled for snoops\000event=0x7e,period=200000,umask=0xe0\000\00000\000\000"
/* offset=2529125 */ "snoop_stall_drv.self\000\000other\000Bus stalled for snoops\000event=0x7e,period=200000,umask=0x40\000\00000\000\000"
/* offset=2529217 */ "snoopq_requests.code\000\000other\000Snoop code requests\000event=0xb4,period=100000,umask=0x4\000\00000\000\000"
/* offset=2529305 */ "snoopq_requests.data\000\000other\000Snoop data requests\000event=0xb4,period=100000,umask=0x1\000\00000\000\000"
/* offset=2529393 */ "snoopq_requests.invalidate\000\000other\000Snoop invalidate requests\000event=0xb4,period=100000,umask=0x2\000\00000\000\000"
/* offset=2529493 */ "snoopq_requests_outstanding.code\000\000other\000Outstanding snoop code requests\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2529606 */ "snoopq_requests_outstanding.code_not_empty\000\000other\000Cycles snoop code requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2529739 */ "snoopq_requests_outstanding.data\000\000other\000Outstanding snoop data requests\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2529852 */ "snoopq_requests_outstanding.data_not_empty\000\000other\000Cycles snoop data requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2529985 */ "snoopq_requests_outstanding.invalidate\000\000other\000Outstanding snoop invalidate requests\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2530110 */ "snoopq_requests_outstanding.invalidate_not_empty\000\000other\000Cycles snoop invalidate requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x2\000\00000\000\000"
/* offset=2530255 */ "sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2530354 */ "sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0x2c,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000"
/* offset=2530749 */ "sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000"
/* offset=2531144 */ "sq_misc.bus_lock\000cpu_core\000cache\000Counts bus locks, accounts for cache line split locks and UC locks. Unit: cpu_core \000event=0x2c,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000"
/* offset=2531564 */ "sq_misc.lru_hints\000\000cache\000Super Queue LRU hints sent to LLC\000event=0xf4,period=2000000,umask=0x4\000\00000\000\000"
/* offset=2531664 */ "sq_misc.split_lock\000\000cache\000Number of cache line split locks sent to uncore\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the number of cache line split locks sent to the uncore\000"
/* offset=2531841 */ "sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000This event counts the number of split locks in the super queue\000"
/* offset=2531988 */ "sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000"
/* offset=2532073 */ "sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000"
/* offset=2532185 */ "sq_misc.sq_full\000\000cache\000Cycles the queue waiting for offcore responses is full\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the queue waiting for responses from the uncore cannot take any more entries\000"
/* offset=2532432 */ "sq_misc.sq_full\000\000cache\000Cycles the superQ cannot take any more entries\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the superQ cannot take any more entries\000"
/* offset=2532634 */ "sse_avx_ops_retired.all\000\000floating point\000Retired SSE, AVX and MMX integer ops of all types\000event=0xb,umask=0xff\000\00000\000\000"
/* offset=2532750 */ "sse_avx_ops_retired.mmx_add\000\000floating point\000Retired MMX integer add\000event=0xb,umask=0x01\000\00000\000\000"
/* offset=2532844 */ "sse_avx_ops_retired.mmx_all\000\000floating point\000Retired MMX integer ops of all types\000event=0xb,umask=0x0f\000\00000\000\000"
/* offset=2532951 */ "sse_avx_ops_retired.mmx_cmp\000\000floating point\000Retired MMX integer compare ops\000event=0xb,umask=0x07\000\00000\000\000"
/* offset=2533053 */ "sse_avx_ops_retired.mmx_logical\000\000floating point\000Retired MMX integer logical ops\000event=0xb,umask=0x0d\000\00000\000\000"
/* offset=2533159 */ "sse_avx_ops_retired.mmx_mac\000\000floating point\000Retired MMX integer multiply-accumulate ops\000event=0xb,umask=0x04\000\00000\000\000"
/* offset=2533273 */ "sse_avx_ops_retired.mmx_mov\000\000floating point\000Retired MMX integer MOV ops\000event=0xb,umask=0x0a\000\00000\000\000"
/* offset=2533371 */ "sse_avx_ops_retired.mmx_mul\000\000floating point\000Retired MMX integer multiply ops\000event=0xb,umask=0x03\000\00000\000\000"
/* offset=2533474 */ "sse_avx_ops_retired.mmx_other\000\000floating point\000Retired MMX integer multiply ops of other types\000event=0xb,umask=0x0e\000\00000\000\000"
/* offset=2533594 */ "sse_avx_ops_retired.mmx_pack\000\000floating point\000Retired MMX integer pack ops\000event=0xb,umask=0x0c\000\00000\000\000"
/* offset=2533694 */ "sse_avx_ops_retired.mmx_shift\000\000floating point\000Retired MMX integer shift ops\000event=0xb,umask=0x09\000\00000\000\000"
/* offset=2533796 */ "sse_avx_ops_retired.mmx_shuffle\000\000floating point\000Retired MMX integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xb,umask=0x0b\000\00000\000\000"
/* offset=2534041 */ "sse_avx_ops_retired.mmx_sub\000\000floating point\000Retired MMX integer subtract ops\000event=0xb,umask=0x02\000\00000\000\000"
/* offset=2534144 */ "sse_avx_ops_retired.sse_avx_add\000\000floating point\000Retired SSE and AVX integer add ops\000event=0xb,umask=0x10\000\00000\000\000"
/* offset=2534254 */ "sse_avx_ops_retired.sse_avx_aes\000\000floating point\000Retired SSE and AVX integer AES ops\000event=0xb,umask=0x50\000\00000\000\000"
/* offset=2534364 */ "sse_avx_ops_retired.sse_avx_all\000\000floating point\000Retired SSE and AVX integer ops of all types\000event=0xb,umask=0xf0\000\00000\000\000"
/* offset=2534483 */ "sse_avx_ops_retired.sse_avx_clm\000\000floating point\000Retired SSE and AVX integer CLM ops\000event=0xb,umask=0x80\000\00000\000\000"
/* offset=2534593 */ "sse_avx_ops_retired.sse_avx_cmp\000\000floating point\000Retired SSE and AVX integer compare ops\000event=0xb,umask=0x70\000\00000\000\000"
/* offset=2534707 */ "sse_avx_ops_retired.sse_avx_logical\000\000floating point\000Retired SSE and AVX integer logical ops\000event=0xb,umask=0xd0\000\00000\000\000"
/* offset=2534825 */ "sse_avx_ops_retired.sse_avx_mac\000\000floating point\000Retired SSE and AVX integer multiply-accumulate ops\000event=0xb,umask=0x40\000\00000\000\000"
/* offset=2534951 */ "sse_avx_ops_retired.sse_avx_mov\000\000floating point\000Retired SSE and AVX integer MOV ops\000event=0xb,umask=0xa0\000\00000\000\000"
/* offset=2535061 */ "sse_avx_ops_retired.sse_avx_mul\000\000floating point\000Retired SSE and AVX integer multiply ops\000event=0xb,umask=0x30\000\00000\000\000"
/* offset=2535176 */ "sse_avx_ops_retired.sse_avx_other\000\000floating point\000Retired SSE and AVX integer ops of other types\000event=0xb,umask=0xe0\000\00000\000\000"
/* offset=2535299 */ "sse_avx_ops_retired.sse_avx_pack\000\000floating point\000Retired SSE and AVX integer pack ops\000event=0xb,umask=0xc0\000\00000\000\000"
/* offset=2535411 */ "sse_avx_ops_retired.sse_avx_sha\000\000floating point\000Retired SSE and AVX integer SHA ops\000event=0xb,umask=0x60\000\00000\000\000"
/* offset=2535521 */ "sse_avx_ops_retired.sse_avx_shift\000\000floating point\000Retired SSE and AVX integer shift ops\000event=0xb,umask=0x90\000\00000\000\000"
/* offset=2535635 */ "sse_avx_ops_retired.sse_avx_shuffle\000\000floating point\000Retired SSE and AVX integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xb,umask=0xb0\000\00000\000\000"
/* offset=2535892 */ "sse_avx_ops_retired.sse_avx_sub\000\000floating point\000Retired SSE and AVX integer subtract ops\000event=0xb,umask=0x20\000\00000\000\000"
/* offset=2536007 */ "sse_avx_stalls\000\000recommended\000Mixed SSE/AVX Stalls\000event=0xe,umask=0x0e\000\00000\000\000"
/* offset=2536082 */ "ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000"
/* offset=2536212 */ "ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000"
/* offset=2536342 */ "ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000"
/* offset=2536472 */ "ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000"
/* offset=2536602 */ "ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000"
/* offset=2536735 */ "store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000"
/* offset=2536845 */ "store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000"
/* offset=2536958 */ "store_forwards.any\000\000pipeline\000All store forwards\000event=0x2,period=200000,umask=0x83\000\00000\000\000"
/* offset=2537046 */ "store_forwards.good\000\000pipeline\000Good store forwards\000event=0x2,period=200000,umask=0x81\000\00000\000\000"
/* offset=2537136 */ "sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000"
/* offset=2537304 */ "sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2537419 */ "sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x40,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000"
/* offset=2537587 */ "sw_prefetch_access.nta\000cpu_core\000cache\000Number of PREFETCHNTA instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000"
/* offset=2537780 */ "sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000"
/* offset=2537950 */ "sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=2000003,umask=0x8\000\00000\000\000"
/* offset=2538069 */ "sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x40,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000"
/* offset=2538239 */ "sw_prefetch_access.prefetchw\000cpu_core\000cache\000Number of PREFETCHW instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000"
/* offset=2538434 */ "sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000"
/* offset=2538599 */ "sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2538712 */ "sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x40,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000"
/* offset=2538877 */ "sw_prefetch_access.t0\000cpu_core\000cache\000Number of PREFETCHT0 instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000"
/* offset=2539067 */ "sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000"
/* offset=2539263 */ "sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=2000003,umask=0x4\000\00000\000\000"
/* offset=2539393 */ "sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x40,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000"
/* offset=2539589 */ "sw_prefetch_access.t1_t2\000cpu_core\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000"
/* offset=2539810 */ "sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\0000x01\00000\000\000"
/* offset=2539930 */ "sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000v8\00000\000\000"
/* offset=2540049 */ "thermal_trip\000\000other\000Number of thermal trips\000event=0x3b,period=200000,umask=0xc0\000\00000\000\000"
/* offset=2540134 */ "tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100003,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000"
/* offset=2540313 */ "tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000"
/* offset=2540513 */ "tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000"
/* offset=2540692 */ "tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000This event counts the number of DTLB flush attempts of the thread-specific entries\000"
/* offset=2540903 */ "tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000\000"
/* offset=2541032 */ "tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100003,umask=0x20\000\00000\000Count number of STLB flush attempts\000"
/* offset=2541163 */ "tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Count number of STLB flush attempts\000"
/* offset=2541294 */ "tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000"
/* offset=2541489 */ "tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000This event counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, and so on)\000"
/* offset=2541700 */ "tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000\000"
/* offset=2541796 */ "tlb_flushes.stlb_any\000\000virtual memory\000STLB flushes\000event=0xbd,period=20003,umask=0x20\000\00000\000Counts STLB flushes.  The TLBs are flushed on instructions like INVLPG and MOV to CR3\000"
/* offset=2541971 */ "tma_L1_group\000"
/* offset=2541984 */ "tma_L2_group\000"
/* offset=2541997 */ "tma_L3_group\000"
/* offset=2542010 */ "tma_L4_group\000"
/* offset=2542023 */ "tma_L5_group\000"
/* offset=2542036 */ "tma_L6_group\000"
/* offset=2542049 */ "tma_alu_op_utilization_group\000"
/* offset=2542078 */ "tma_assists_group\000"
/* offset=2542096 */ "tma_backend_bound_aux_group\000"
/* offset=2542124 */ "tma_backend_bound_group\000"
/* offset=2542148 */ "tma_bad_speculation_group\000"
/* offset=2542174 */ "tma_base_group\000"
/* offset=2542189 */ "tma_branch_resteers_group\000"
/* offset=2542215 */ "tma_core_bound_group\000"
/* offset=2542236 */ "tma_dram_bound_group\000"
/* offset=2542257 */ "tma_dtlb_load_group\000"
/* offset=2542277 */ "tma_dtlb_store_group\000"
/* offset=2542298 */ "tma_fetch_bandwidth_group\000"
/* offset=2542324 */ "tma_fetch_latency_group\000"
/* offset=2542348 */ "tma_fp_arith_group\000"
/* offset=2542367 */ "tma_fp_vector_group\000"
/* offset=2542387 */ "tma_frontend_bound_group\000"
/* offset=2542412 */ "tma_heavy_operations_group\000"
/* offset=2542439 */ "tma_int_operations_group\000"
/* offset=2542464 */ "tma_issue2P\000"
/* offset=2542476 */ "tma_issueBC\000"
/* offset=2542488 */ "tma_issueBM\000"
/* offset=2542500 */ "tma_issueBW\000"
/* offset=2542512 */ "tma_issueD0\000"
/* offset=2542524 */ "tma_issueFB\000"
/* offset=2542536 */ "tma_issueFL\000"
/* offset=2542548 */ "tma_issueL1\000"
/* offset=2542560 */ "tma_issueLat\000"
/* offset=2542573 */ "tma_issueMC\000"
/* offset=2542585 */ "tma_issueMS\000"
/* offset=2542597 */ "tma_issueMV\000"
/* offset=2542609 */ "tma_issueRFO\000"
/* offset=2542622 */ "tma_issueSL\000"
/* offset=2542634 */ "tma_issueSO\000"
/* offset=2542646 */ "tma_issueSmSt\000"
/* offset=2542660 */ "tma_issueSpSt\000"
/* offset=2542674 */ "tma_issueSyncxn\000"
/* offset=2542690 */ "tma_issueTLB\000"
/* offset=2542703 */ "tma_l1_bound_group\000"
/* offset=2542722 */ "tma_l3_bound_group\000"
/* offset=2542741 */ "tma_light_operations_group\000"
/* offset=2542768 */ "tma_load_op_utilization_group\000"
/* offset=2542798 */ "tma_machine_clears_group\000"
/* offset=2542823 */ "tma_mem_bandwidth_group\000"
/* offset=2542847 */ "tma_mem_latency_group\000"
/* offset=2542869 */ "tma_mem_scheduler_group\000"
/* offset=2542893 */ "tma_memory_bound_group\000"
/* offset=2542916 */ "tma_microcode_sequencer_group\000"
/* offset=2542946 */ "tma_mite_group\000"
/* offset=2542961 */ "tma_nuke_group\000"
/* offset=2542976 */ "tma_ports_utilization_group\000"
/* offset=2543004 */ "tma_ports_utilized_0_group\000"
/* offset=2543031 */ "tma_ports_utilized_3m_group\000"
/* offset=2543059 */ "tma_resource_bound_group\000"
/* offset=2543084 */ "tma_retiring_group\000"
/* offset=2543103 */ "tma_serializing_operation_group\000"
/* offset=2543135 */ "tma_store_bound_group\000"
/* offset=2543157 */ "tma_store_op_utilization_group\000"
/* offset=2543188 */ "topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Counts the number of Top-down Microarchitecture Analysis (TMA) method's  slots where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000"
/* offset=2543542 */ "topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Number of slots in TMA method where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000"
/* offset=2543847 */ "topdown.backend_bound_slots\000\000pipeline\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions\000event=0xa4,period=10000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions.\nThe count is distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Backend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=2544697 */ "topdown.backend_bound_slots\000cpu_core\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x2\000\00000\000Number of slots in TMA method where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000"
/* offset=2545027 */ "topdown.backend_bound_slots\000cpu_core\000pipeline\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions.\nThe count is distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Backend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=2545902 */ "topdown.bad_spec_slots\000\000pipeline\000TMA slots wasted due to incorrect speculations\000event=0xa4,period=10000003,umask=0x4\000\00000\000Number of slots of TMA method that were wasted due to incorrect speculation. It covers all types of control-flow or data-related mis-speculations\000"
/* offset=2546169 */ "topdown.bad_spec_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculations. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x4\000\00000\000Number of slots of TMA method that were wasted due to incorrect speculation. It covers all types of control-flow or data-related mis-speculations\000"
/* offset=2546461 */ "topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of speculative operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000"
/* offset=2546876 */ "topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by branch mispredictions. This event estimates number of operations that were issued but not retired from the speculative path as well as the out-of-order engine recovery past a branch misprediction\000"
/* offset=2547291 */ "topdown.br_mispredict_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of specualtive operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000"
/* offset=2547731 */ "topdown.br_mispredict_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of speculative operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000"
/* offset=2548171 */ "topdown.memory_bound_slots\000\000pipeline\000TOPDOWN.MEMORY_BOUND_SLOTS\000event=0xa4,period=10000003,umask=0x10\000\00000\000\000"
/* offset=2548278 */ "topdown.memory_bound_slots\000cpu_core\000pipeline\000TOPDOWN.MEMORY_BOUND_SLOTS. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x10\000\00000\000\000"
/* offset=2548410 */ "topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000"
/* offset=2549042 */ "topdown.slots\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event. Unit: cpu_core \000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000"
/* offset=2549699 */ "topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000"
/* offset=2550166 */ "topdown.slots_p\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000"
/* offset=2550658 */ "topdown_bad_speculation.all\000\000pipeline\000Counts the number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window, including relevant microcode flows, and while uops are not yet available in the instruction queue (IQ) or until an FE_BOUND event occurs besides OTHER and CISC. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000"
/* offset=2551516 */ "topdown_bad_speculation.all\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003,umask=0x6\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000"
/* offset=2552383 */ "topdown_bad_speculation.all\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000"
/* offset=2553240 */ "topdown_bad_speculation.all\000cpu_atom\000pipeline\000Counts the number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window, including relevant microcode flows, and while uops are not yet available in the instruction queue (IQ) or until an FE_BOUND event occurs besides OTHER and CISC. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000"
/* offset=2554123 */ "topdown_bad_speculation.all\000cpu_atom\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000"
/* offset=2555005 */ "topdown_bad_speculation.fastnuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears\000event=0x73,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2555255 */ "topdown_bad_speculation.fastnuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to Fast Nukes such as  Memory Ordering Machine clears and MRN nukes. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2555519 */ "topdown_bad_speculation.fastnuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2555794 */ "topdown_bad_speculation.machine_clears\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000event=0x73,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2556085 */ "topdown_bad_speculation.machine_clears\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000event=0x73,period=1000003,umask=0x3\000\00000\000\000"
/* offset=2556376 */ "topdown_bad_speculation.machine_clears\000cpu_atom\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x3\000\00000\000\000"
/* offset=2556692 */ "topdown_bad_speculation.mispredict\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts\000event=0x73,period=1000003,umask=0x4\000\00000\000\000"
/* offset=2556887 */ "topdown_bad_speculation.mispredict\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x4\000\00000\000\000"
/* offset=2557107 */ "topdown_bad_speculation.monuke\000\000pipeline\000This event is deprecated. Refer to new event TOPDOWN_BAD_SPECULATION.FASTNUKE\000event=0x73,period=1000003,umask=0x2\000\00010\000\000"
/* offset=2557267 */ "topdown_bad_speculation.nuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to a machine clear (nuke)\000event=0x73,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2557460 */ "topdown_bad_speculation.nuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to a machine clear (nuke). Unit: cpu_atom \000event=0x73,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2557678 */ "topdown_be_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to backend stalls\000event=0x74,period=1000003\000\00000\000\000"
/* offset=2557813 */ "topdown_be_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls\000event=0x74,period=1000003\000\00000\000\000"
/* offset=2557986 */ "topdown_be_bound.all\000cpu_atom\000pipeline\000Counts the number of retirement slots not consumed due to backend stalls. Unit: cpu_atom \000event=0x74,period=1000003\000\00000\000\000"
/* offset=2558146 */ "topdown_be_bound.all\000cpu_atom\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000event=0x74,period=1000003\000\00000\000\000"
/* offset=2558344 */ "topdown_be_bound.alloc_restrictions\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions\000event=0x74,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2558553 */ "topdown_be_bound.alloc_restrictions\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2558787 */ "topdown_be_bound.alloc_restrictions\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to due to certain allocation restrictions. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2559028 */ "topdown_be_bound.mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2559274 */ "topdown_be_bound.mem_scheduler\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2559545 */ "topdown_be_bound.non_mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x8\000\00000\000\000"
/* offset=2559876 */ "topdown_be_bound.non_mem_scheduler\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x8\000\00000\000\000"
/* offset=2560232 */ "topdown_be_bound.register\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000event=0x74,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2560469 */ "topdown_be_bound.register\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to mrbl stall.  A 'marble' refers to a physical register file entry, also known as the physical destination (PDST). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2560774 */ "topdown_be_bound.register\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2561036 */ "topdown_be_bound.reorder_buffer\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000event=0x74,period=1000003,umask=0x40\000\00000\000\000"
/* offset=2561253 */ "topdown_be_bound.reorder_buffer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x40\000\00000\000\000"
/* offset=2561495 */ "topdown_be_bound.serialization\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000event=0x74,period=1000003,umask=0x10\000\00000\000\000"
/* offset=2561768 */ "topdown_be_bound.serialization\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to iq/jeu scoreboards or ms scb. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x10\000\00000\000\000"
/* offset=2561995 */ "topdown_be_bound.serialization\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x10\000\00000\000\000"
/* offset=2562293 */ "topdown_be_bound.store_buffer\000\000pipeline\000This event is deprecated\000event=0x74,period=1000003,umask=0x4\000\00010\000\000"
/* offset=2562399 */ "topdown_fe_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to front end stalls\000event=0x71,period=1000003\000\00000\000\000"
/* offset=2562536 */ "topdown_fe_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls\000event=0x71,period=1000003\000\00000\000\000"
/* offset=2562710 */ "topdown_fe_bound.all\000cpu_atom\000pipeline\000Counts the number of retirement slots not consumed due to front end stalls. Unit: cpu_atom \000event=0x71,period=1000003\000\00000\000\000"
/* offset=2562872 */ "topdown_fe_bound.all\000cpu_atom\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls. Unit: cpu_atom \000event=0x71,period=1000003\000\00000\000\000"
/* offset=2563071 */ "topdown_fe_bound.branch_detect\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS\000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=2563611 */ "topdown_fe_bound.branch_detect\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000"
/* offset=2564176 */ "topdown_fe_bound.branch_detect\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BAClear. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x2\000\00000\000\000"
/* offset=2564383 */ "topdown_fe_bound.branch_resteer\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS\000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000"
/* offset=2564742 */ "topdown_fe_bound.branch_resteer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000"
/* offset=2565126 */ "topdown_fe_bound.branch_resteer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTClear. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x40\000\00000\000\000"
/* offset=2565335 */ "topdown_fe_bound.cisc\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS)\000event=0x71,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2565529 */ "topdown_fe_bound.cisc\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ms. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2565722 */ "topdown_fe_bound.cisc\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS). Unit: cpu_atom \000event=0x71,period=1000003,umask=0x1\000\00000\000\000"
/* offset=2565941 */ "topdown_fe_bound.decode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls\000event=0x71,period=1000003,umask=0x8\000\00000\000\000"
/* offset=2566122 */ "topdown_fe_bound.decode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stall. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8\000\00000\000\000"
/* offset=2566327 */ "topdown_fe_bound.decode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8\000\00000\000\000"
/* offset=2566533 */ "topdown_fe_bound.frontend_bandwidth\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000event=0x71,period=1000003,umask=0x8d\000\00000\000\000"
/* offset=2566799 */ "topdown_fe_bound.frontend_bandwidth\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8d\000\00000\000\000"
/* offset=2567090 */ "topdown_fe_bound.frontend_latency\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to a latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses\000event=0x71,period=1000003,umask=0x72\000\00000\000\000"
/* offset=2567354 */ "topdown_fe_bound.frontend_latency\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to a latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x72\000\00000\000\000"
/* offset=2567643 */ "topdown_fe_bound.frontend_latency\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x72\000\00000\000\000"
/* offset=2567930 */ "topdown_fe_bound.icache\000\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses\000event=0x71,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2568120 */ "topdown_fe_bound.icache\000cpu_atom\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to an icache miss. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2568325 */ "topdown_fe_bound.icache\000cpu_atom\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x20\000\00000\000\000"
/* offset=2568540 */ "topdown_fe_bound.itlb\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses\000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000"
/* offset=2568858 */ "topdown_fe_bound.itlb\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000"
/* offset=2569201 */ "topdown_fe_bound.itlb\000cpu_atom\000pipeline\000This event is deprecated. [This event is alias to TOPDOWN_FE_BOUND.ITLB_MISS]. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00010\000\000"
/* offset=2569378 */ "topdown_fe_bound.itlb_miss\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to itlb miss [This event is alias to TOPDOWN_FE_BOUND.ITLB]. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00000\000\000"
/* offset=2569631 */ "topdown_fe_bound.other\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized\000event=0x71,period=1000003,umask=0x80\000\00000\000\000"
/* offset=2569843 */ "topdown_fe_bound.other\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x80\000\00000\000\000"
/* offset=2570080 */ "topdown_fe_bound.predecode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes\000event=0x71,period=1000003,umask=0x4\000\00000\000\000"
/* offset=2570267 */ "topdown_fe_bound.predecode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to predecode wrong. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x4\000\00000\000\000"
/* offset=2570478 */ "topdown_fe_bound.predecode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x4\000\00000\000\000"
/* offset=2570690 */ "topdown_retiring.all\000\000pipeline\000Counts the number of consumed retirement slots.  Similar to UOPS_RETIRED.ALL (Precise event)\000event=0x72,period=1000003\000\00000\000\000"
/* offset=2570845 */ "topdown_retiring.all\000\000pipeline\000Counts the total number of consumed retirement slots (Precise event)\000event=0xc2,period=1000003\000\00000\000\000"
/* offset=2570976 */ "topdown_retiring.all\000cpu_atom\000pipeline\000Counts the number of consumed retirement slots.  Similar to UOPS_RETIRED.ALL (Precise event). Unit: cpu_atom \000event=0x72,period=1000003\000\00000\000\000"
/* offset=2571156 */ "topdown_retiring.all\000cpu_atom\000pipeline\000Counts the total number of consumed retirement slots (Precise event). Unit: cpu_atom \000event=0xc2,period=1000003\000\00000\000\000"
/* offset=2571312 */ "two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000"
/* offset=2571414 */ "tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2571663 */ "tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by  a vzeroupper instruction\000"
/* offset=2571935 */ "tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by a vzeroupper instruction\000"
/* offset=2572206 */ "tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2572419 */ "tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=100003,umask=0x2\000\00000\000Counts Unfriendly TSX abort triggered by a vzeroupper instruction\000"
/* offset=2572677 */ "tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000"
/* offset=2572916 */ "tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000\000"
/* offset=2573092 */ "tx_exec.misc3\000\000memory\000Number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=100003,umask=0x4\000\00000\000Counts Unfriendly TSX abort triggered by a nest count that is too deep\000"
/* offset=2573326 */ "tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000"
/* offset=2573515 */ "tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000\000"
/* offset=2573674 */ "tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000"
/* offset=2573943 */ "tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000"
/* offset=2574110 */ "tx_mem.abort_capacity\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional reads or writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2574300 */ "tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000"
/* offset=2574626 */ "tx_mem.abort_capacity_write\000\000memory\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000event=0x54,period=2000003,umask=0x2\000\00000\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000"
/* offset=2574898 */ "tx_mem.abort_capacity_write\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000"
/* offset=2575085 */ "tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000"
/* offset=2575413 */ "tx_mem.abort_conflict\000\000memory\000Number of times a TSX line had a cache conflict\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000"
/* offset=2575579 */ "tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000"
/* offset=2575819 */ "tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000"
/* offset=2576049 */ "tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000\000"
/* offset=2576232 */ "tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000"
/* offset=2576510 */ "tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=100003,umask=0x10\000\00000\000Counts the number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000"
/* offset=2576852 */ "tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000"
/* offset=2577184 */ "tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000\000"
/* offset=2577423 */ "tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000"
/* offset=2577677 */ "tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=100003,umask=0x8\000\00000\000Counts the number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000"
/* offset=2577961 */ "tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000"
/* offset=2578235 */ "tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000\000"
/* offset=2578428 */ "tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000"
/* offset=2578735 */ "tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=100003,umask=0x20\000\00000\000Counts the number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000"
/* offset=2579066 */ "tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000"
/* offset=2579387 */ "tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000\000"
/* offset=2579607 */ "tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=100003,umask=0x4\000\00000\000Counts the number of times a TSX Abort was triggered due to a non-release/commit store to lock\000"
/* offset=2579929 */ "tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000"
/* offset=2580241 */ "tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000\000"
/* offset=2580470 */ "tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000"
/* offset=2580724 */ "tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=100003,umask=0x40\000\00000\000Counts the number of times we could not allocate Lock Buffer\000"
/* offset=2580950 */ "tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000"
/* offset=2581166 */ "tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000\000"
/* offset=2581333 */ "tx_mem.hle_elision_buffer_full\000\000memory\000Number of times we could not allocate Lock Buffer\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000"
/* offset=2581513 */ "unc_arb_coh_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Cycles weighted by number of requests pending in Coherency Tracker. Unit: uncore_arb \000event=0x83,umask=0x1\000\00001\000\000"
/* offset=2581686 */ "unc_arb_coh_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle count number of valid entries in Coherency Tracker queue from allocation till deallocation. Aperture requests (snoops) appear as NC decoded internally and become coherent (snoop L3, access memory). Unit: uncore_arb \000event=0x83,umask=0x1\000\00001\000Each cycle count number of valid entries in Coherency Tracker queue from allocation till deallocation. Aperture requests (snoops) appear as NC decoded internally and become coherent (snoop L3, access memory)\000"
/* offset=2582207 */ "unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop,  etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000"
/* offset=2582380 */ "unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop, Core aperture, etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000"
/* offset=2582567 */ "unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of requests allocated in Coherency Tracker. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000"
/* offset=2582722 */ "unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000UNC_ARB_COH_TRK_REQUESTS.ALL. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000"
/* offset=2582856 */ "unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000"
/* offset=2583135 */ "unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000"
/* offset=2583336 */ "unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000"
/* offset=2583633 */ "unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000"
/* offset=2583852 */ "unc_arb_dat_requests.rd\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_REQ_TRK_REQUEST.DRD. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2584025 */ "unc_arb_ifa_occupancy.all\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_DAT_OCCUPANCY.ALL. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000"
/* offset=2584198 */ "unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_OCCUPANCY.RD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=2584516 */ "unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=2584862 */ "unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_REQUESTS.RD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2585084 */ "unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2585257 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Counts cycles weighted by the number of requests waiting for data returning from the memory controller. Accounts for coherent and non-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2585566 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle count number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from it's allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2585861 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all Core outgoing valid entries. Such entry is defined as valid from its allocation till first of IDI0 or DRS0 messages is sent out. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2586171 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2586544 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2586839 */ "unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Number of all Core entries outstanding for the memory controller. The outstanding interval starts after LLC miss till return of first data chunk. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=2587134 */ "unc_arb_trk_occupancy.cycles_over_half_full\000uncore_arb\000uncore interconnect\000Cycles with at least half of the requests outstanding are waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=10,umask=0x1\000\00001\000\000"
/* offset=2587471 */ "unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000"
/* offset=2587799 */ "unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC.;. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000"
/* offset=2588129 */ "unc_arb_trk_occupancy.data_read\000uncore_arb\000uncore interconnect\000Number of Core Data Read entries outstanding for the memory controller. The outstanding interval starts after LLC miss till return of first data chunk. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=2588388 */ "unc_arb_trk_occupancy.drd_direct\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries that are in DirectData mode. Such entry is defined as valid when it is allocated till data sent to Core (first chunk, IDI0). Applicable for IA Cores' requests in normal case. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000Each cycle count number of valid coherent Data Read entries that are in DirectData mode. Such entry is defined as valid when it is allocated till data sent to Core (first chunk, IDI0). Applicable for IA Cores' requests in normal case\000"
/* offset=2588966 */ "unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_OCCUPANCY.DRD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=2589284 */ "unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=2589625 */ "unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Counts the number of coherent and in-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=2589836 */ "unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of Core outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=2590033 */ "unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of all outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=2590229 */ "unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000UNC_ARB_TRK_REQUESTS.ALL. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=2590355 */ "unc_arb_trk_requests.data_read\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read requests sent to memory controller whose data is returned directly to requesting agent. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2590583 */ "unc_arb_trk_requests.drd_direct\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read entries allocated in DirectData mode. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000Number of Core coherent Data Read entries allocated in DirectData mode\000"
/* offset=2590832 */ "unc_arb_trk_requests.drd_direct\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read requests sent to memory controller whose data is returned directly to requesting agent. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2591061 */ "unc_arb_trk_requests.evictions\000uncore_arb\000uncore interconnect\000Counts the number of LLC evictions allocated. Unit: uncore_arb \000event=0x81,umask=0x80\000\00001\000\000"
/* offset=2591214 */ "unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_REQUEST.DRD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2591436 */ "unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=2591683 */ "unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Counts the number of allocated write entries, include full, partial, and LLC evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000"
/* offset=2591875 */ "unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Number of Writes allocated - any write transactions: full/partials writes and evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000"
/* offset=2592068 */ "unc_c_bounce_control\000uncore_cbox\000uncore cache\000Bounce Control. Unit: uncore_cbox \000event=0xa\000\00001\000\000"
/* offset=2592164 */ "unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000"
/* offset=2592253 */ "unc_c_clockticks\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CLOCKTICKS. Unit: uncore_cha \000event=0\000\00011\000\000"
/* offset=2592390 */ "unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000"
/* offset=2592888 */ "unc_c_fast_asserted\000uncore_cbox\000uncore cache\000FaST wire asserted. Unit: uncore_cbox \000event=0x9\000\00001\000Counts the number of cycles either the local distress or incoming distress signals are asserted.  Incoming distress includes both up and dn\000"
/* offset=2593126 */ "unc_c_fast_asserted\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_FAST_ASSERTED.HORZ. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00011\000\000"
/* offset=2593287 */ "unc_c_ismq_drd_miss_occ\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x21\000\00001\000\000"
/* offset=2593371 */ "unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000All LLC Misses (code+ data rd + data wr - including demand and prefetch). Unit: uncore_cbox \000event=0x34,umask=0x11,filter_state=0x1\000\0000164Bytes\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2594135 */ "unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000Cache Lookups; Any Request. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2594837 */ "unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000Cache Lookups; Any Request. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2595531 */ "unc_c_llc_lookup.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.ANY. Unit: uncore_cha \000event=0x34,umask=0x11\000\00011\000\000"
/* offset=2595690 */ "unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Read transactions\000"
/* offset=2596303 */ "unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000"
/* offset=2596894 */ "unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000"
/* offset=2597499 */ "unc_c_llc_lookup.data_read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x3\000\00011\000\000"
/* offset=2597669 */ "unc_c_llc_lookup.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LOCAL. Unit: uncore_cha \000event=0x34,umask=0x31\000\00011\000\000"
/* offset=2597832 */ "unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000"
/* offset=2598632 */ "unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000"
/* offset=2599424 */ "unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; RTID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000"
/* offset=2599997 */ "unc_c_llc_lookup.read\000uncore_cbox\000uncore cache\000Cache Lookups; Any Read Request. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000"
/* offset=2600597 */ "unc_c_llc_lookup.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE. Unit: uncore_cha \000event=0x34,umask=0x91\000\00011\000\000"
/* offset=2600762 */ "unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000"
/* offset=2601446 */ "unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000"
/* offset=2602045 */ "unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000"
/* offset=2602721 */ "unc_c_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE_SNOOP. Unit: uncore_cha \000event=0x34,umask=0x9\000\00011\000\000"
/* offset=2602897 */ "unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2603590 */ "unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000"
/* offset=2604174 */ "unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2604859 */ "unc_c_llc_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITE. Unit: uncore_cha \000event=0x34,umask=0x5\000\00011\000\000"
/* offset=2605021 */ "unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2605267 */ "unc_c_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000"
/* offset=2605435 */ "unc_c_llc_victims.f_state\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2605663 */ "unc_c_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000"
/* offset=2605831 */ "unc_c_llc_victims.i_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2606077 */ "unc_c_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.LOCAL_ALL. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00011\000\000"
/* offset=2606246 */ "unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cbox \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2606492 */ "unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000M line evictions from LLC (writebacks to memory). Unit: uncore_cbox \000event=0x37,umask=0x1\000\0000164Bytes\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2606759 */ "unc_c_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000"
/* offset=2606927 */ "unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x10\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2607153 */ "unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2607378 */ "unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000"
/* offset=2607843 */ "unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2608101 */ "unc_c_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000"
/* offset=2608272 */ "unc_c_llc_victims.s_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2608518 */ "unc_c_llc_victims.s_state\000uncore_cbox\000uncore cache\000Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2608746 */ "unc_c_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000"
/* offset=2608914 */ "unc_c_misc.cvzero_prefetch_miss\000uncore_cbox\000uncore cache\000Cbo Misc; DRd hitting non-M with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2609091 */ "unc_c_misc.cvzero_prefetch_victim\000uncore_cbox\000uncore cache\000Cbo Misc; Clean Victim with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2609265 */ "unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo.; Number of times that an RFO hit in S state.  This is useful for determining if it might be good for a workload to use RspIWB instead of RspSWB\000"
/* offset=2609552 */ "unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2609694 */ "unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000"
/* offset=2610015 */ "unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2610173 */ "unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2610303 */ "unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000"
/* offset=2610646 */ "unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2610806 */ "unc_c_qlru.age0\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 0. Unit: uncore_cbox \000event=0x3c,umask=0x1\000\00001\000How often age was set to 0\000"
/* offset=2610940 */ "unc_c_qlru.age1\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 1. Unit: uncore_cbox \000event=0x3c,umask=0x2\000\00001\000How often age was set to 1\000"
/* offset=2611074 */ "unc_c_qlru.age2\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 2. Unit: uncore_cbox \000event=0x3c,umask=0x4\000\00001\000How often age was set to 2\000"
/* offset=2611208 */ "unc_c_qlru.age3\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 3. Unit: uncore_cbox \000event=0x3c,umask=0x8\000\00001\000How often age was set to 3\000"
/* offset=2611342 */ "unc_c_qlru.lru_decrement\000uncore_cbox\000uncore cache\000LRU Queue; LRU Bits Decremented. Unit: uncore_cbox \000event=0x3c,umask=0x10\000\00001\000How often all LRU bits were decremented by 1\000"
/* offset=2611515 */ "unc_c_qlru.victim_non_zero\000uncore_cbox\000uncore cache\000LRU Queue; Non-0 Aged Victim. Unit: uncore_cbox \000event=0x3c,umask=0x20\000\00001\000How often we picked a victim that had a non-zero age\000"
/* offset=2611695 */ "unc_c_ring_ad_used.all\000uncore_cbox\000uncore cache\000AD Ring In Use; All. Unit: uncore_cbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2612532 */ "unc_c_ring_ad_used.all\000uncore_cbox\000uncore cache\000AD Ring In Use; All. Unit: uncore_cbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2613369 */ "unc_c_ring_ad_used.ccw\000uncore_cbox\000uncore cache\000AD Ring In Use; Counterclockwise. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2614219 */ "unc_c_ring_ad_used.ccw\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2615057 */ "unc_c_ring_ad_used.cw\000uncore_cbox\000uncore cache\000AD Ring In Use; Clockwise. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2615899 */ "unc_c_ring_ad_used.cw\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2616734 */ "unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX-- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2617572 */ "unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2618411 */ "unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2619251 */ "unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2620150 */ "unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2621049 */ "unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2621906 */ "unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2622802 */ "unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2623698 */ "unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2624553 */ "unc_c_ring_ad_used.down_vr0_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000"
/* offset=2625485 */ "unc_c_ring_ad_used.down_vr0_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000"
/* offset=2626414 */ "unc_c_ring_ad_used.down_vr1_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000"
/* offset=2627347 */ "unc_c_ring_ad_used.down_vr1_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000"
/* offset=2628277 */ "unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2629113 */ "unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2629948 */ "unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2630783 */ "unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2631676 */ "unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2632569 */ "unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2633422 */ "unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2634312 */ "unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2635202 */ "unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2636053 */ "unc_c_ring_ad_used.up_vr0_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000"
/* offset=2636979 */ "unc_c_ring_ad_used.up_vr0_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000"
/* offset=2637902 */ "unc_c_ring_ad_used.up_vr1_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000"
/* offset=2638829 */ "unc_c_ring_ad_used.up_vr1_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000"
/* offset=2639753 */ "unc_c_ring_ak_used.all\000uncore_cbox\000uncore cache\000AK Ring In Use; All. Unit: uncore_cbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2640588 */ "unc_c_ring_ak_used.all\000uncore_cbox\000uncore cache\000AK Ring In Use; All. Unit: uncore_cbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2641423 */ "unc_c_ring_ak_used.ccw\000uncore_cbox\000uncore cache\000AK Ring In Use; Counterclockwise. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2642271 */ "unc_c_ring_ak_used.ccw\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2643107 */ "unc_c_ring_ak_used.cw\000uncore_cbox\000uncore cache\000AK Ring In Use; Clockwise. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2643947 */ "unc_c_ring_ak_used.cw\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2644780 */ "unc_c_ring_ak_used.down\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2645617 */ "unc_c_ring_ak_used.down\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2646455 */ "unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2647352 */ "unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2648249 */ "unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2649104 */ "unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2649998 */ "unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2650892 */ "unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2651745 */ "unc_c_ring_ak_used.down_vr0_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000"
/* offset=2652675 */ "unc_c_ring_ak_used.down_vr0_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000"
/* offset=2653602 */ "unc_c_ring_ak_used.down_vr1_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000"
/* offset=2654533 */ "unc_c_ring_ak_used.down_vr1_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000"
/* offset=2655461 */ "unc_c_ring_ak_used.up\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2656295 */ "unc_c_ring_ak_used.up\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2657128 */ "unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2658019 */ "unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2658910 */ "unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2659761 */ "unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2660649 */ "unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2661537 */ "unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2662386 */ "unc_c_ring_ak_used.up_vr0_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000"
/* offset=2663310 */ "unc_c_ring_ak_used.up_vr0_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000"
/* offset=2664231 */ "unc_c_ring_ak_used.up_vr1_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000"
/* offset=2665156 */ "unc_c_ring_ak_used.up_vr1_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000"
/* offset=2666078 */ "unc_c_ring_bl_used.all\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2666914 */ "unc_c_ring_bl_used.all\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2667750 */ "unc_c_ring_bl_used.ccw\000uncore_cbox\000uncore cache\000BL Ring in Use; Counterclockwise. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2668598 */ "unc_c_ring_bl_used.ccw\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2669434 */ "unc_c_ring_bl_used.cw\000uncore_cbox\000uncore cache\000BL Ring in Use; Clockwise. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2670274 */ "unc_c_ring_bl_used.cw\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2671107 */ "unc_c_ring_bl_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2671944 */ "unc_c_ring_bl_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2672782 */ "unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2673638 */ "unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2674535 */ "unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000"
/* offset=2675432 */ "unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2676286 */ "unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2677180 */ "unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=2678074 */ "unc_c_ring_bl_used.down_vr0_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000"
/* offset=2679004 */ "unc_c_ring_bl_used.down_vr0_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000"
/* offset=2679931 */ "unc_c_ring_bl_used.down_vr1_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000"
/* offset=2680862 */ "unc_c_ring_bl_used.down_vr1_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000"
/* offset=2681790 */ "unc_c_ring_bl_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2682624 */ "unc_c_ring_bl_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2683457 */ "unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2684309 */ "unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2685200 */ "unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=2686091 */ "unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2686941 */ "unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2687829 */ "unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=2688717 */ "unc_c_ring_bl_used.up_vr0_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000"
/* offset=2689641 */ "unc_c_ring_bl_used.up_vr0_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000"
/* offset=2690562 */ "unc_c_ring_bl_used.up_vr1_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000"
/* offset=2691487 */ "unc_c_ring_bl_used.up_vr1_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000"
/* offset=2692409 */ "unc_c_ring_bounces.ad\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AD. Unit: uncore_cbox \000event=0x5,umask=0x1\000\00001\000\000"
/* offset=2692555 */ "unc_c_ring_bounces.ad_irq\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=2692700 */ "unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AK. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=2692846 */ "unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=2693014 */ "unc_c_ring_bounces.ak_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=2693187 */ "unc_c_ring_bounces.ak_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=2693360 */ "unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; BL. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=2693506 */ "unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000"
/* offset=2693672 */ "unc_c_ring_bounces.bl_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=2693843 */ "unc_c_ring_bounces.bl_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=2694014 */ "unc_c_ring_bounces.iv\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x10\000\00001\000\000"
/* offset=2694186 */ "unc_c_ring_bounces.iv_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000"
/* offset=2694362 */ "unc_c_ring_bounces.iv_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000"
/* offset=2694538 */ "unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2695093 */ "unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2695648 */ "unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in JKT.  Therefore, if one wants to monitor the 'Even' ring, they should select both UP_EVEN and DN_EVEN.  To monitor the 'Odd' ring, they should select both UP_ODD and DN_ODD\000"
/* offset=2696185 */ "unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000IV Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters any polarity\000"
/* offset=2696543 */ "unc_c_ring_iv_used.dn\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2697097 */ "unc_c_ring_iv_used.dn\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2697651 */ "unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters for Down polarity\000"
/* offset=2698214 */ "unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters for Down polarity\000"
/* offset=2698777 */ "unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000IV Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for Down polarity\000"
/* offset=2699143 */ "unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2699697 */ "unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=2700251 */ "unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000IV Ring in Use; Up. Unit: uncore_cbox \000event=0x1e,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for Up polarity\000"
/* offset=2700611 */ "unc_c_ring_sink_starved.ad\000uncore_cbox\000uncore cache\000AD. Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000"
/* offset=2700711 */ "unc_c_ring_sink_starved.ad\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.AD. Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000"
/* offset=2700835 */ "unc_c_ring_sink_starved.ad_cache\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000"
/* offset=2700937 */ "unc_c_ring_sink_starved.ad_ipq\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000"
/* offset=2701037 */ "unc_c_ring_sink_starved.ad_irq\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000"
/* offset=2701137 */ "unc_c_ring_sink_starved.ak\000uncore_cbox\000uncore cache\000AK. Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000"
/* offset=2701237 */ "unc_c_ring_sink_starved.ak\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.AK. Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000"
/* offset=2701361 */ "unc_c_ring_sink_starved.ak_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000"
/* offset=2701462 */ "unc_c_ring_sink_starved.bl\000uncore_cbox\000uncore cache\000BL. Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000"
/* offset=2701562 */ "unc_c_ring_sink_starved.bl\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.BL. Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000"
/* offset=2701686 */ "unc_c_ring_sink_starved.bl_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000"
/* offset=2701787 */ "unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000IV. Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000"
/* offset=2701887 */ "unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.IV. Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000"
/* offset=2702011 */ "unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x10\000\00001\000\000"
/* offset=2702108 */ "unc_c_ring_sink_starved.iv_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000"
/* offset=2702209 */ "unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Number of cycles the Cbo is actively throttling traffic onto the Ring in order to limit bounce traffic. Unit: uncore_cbox \000event=0x7\000\00001\000\000"
/* offset=2702393 */ "unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x7\000\00001\000\000"
/* offset=2702473 */ "unc_c_ring_src_thrtl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SRC_THRTL. Unit: uncore_cha \000event=0xa4\000\00011\000\000"
/* offset=2702621 */ "unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IPQ is externally startved and therefore we are blocking the IRQ\000"
/* offset=2702940 */ "unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000"
/* offset=2703192 */ "unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IRQ is externally starved and therefore we are blocking the IPQ\000"
/* offset=2703510 */ "unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000"
/* offset=2703762 */ "unc_c_rxr_ext_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000"
/* offset=2704016 */ "unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; Number of times that the ISMQ Bid\000"
/* offset=2704315 */ "unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000"
/* offset=2704578 */ "unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000IRQ is blocking the ingress queue and causing the starvation\000"
/* offset=2704767 */ "unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; PRQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000"
/* offset=2705019 */ "unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2705208 */ "unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2705397 */ "unc_c_rxr_inserts.irq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2705599 */ "unc_c_rxr_inserts.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Allocations: IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2705806 */ "unc_c_rxr_inserts.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2706013 */ "unc_c_rxr_inserts.prq\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2706203 */ "unc_c_rxr_inserts.prq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2706397 */ "unc_c_rxr_inserts.vfifo\000uncore_cbox\000uncore cache\000Ingress Allocations; VFIFO. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue.; Counts the number of allocations into the IRQ Ordering FIFO.  In JKT, it is necessary to keep IO requests in order.  Therefore, they are allocated into an ordering FIFO that sits next to the IRQ, and must be satisfied from the FIFO in order (with respect to each other).  This event, in conjunction with the Occupancy Accumulator event, can be used to calculate average lifetime in the FIFO.  Transactions are allocated into the FIFO as soon as they enter the Cachebo (and the IRQ) and are deallocated from the FIFO as soon as they are deallocated from the IRQ\000"
/* offset=2707154 */ "unc_c_rxr_inserts.vfifo\000uncore_cbox\000uncore cache\000Ingress Allocations; VFIFO. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=2707348 */ "unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IPQ in Internal Starvation\000"
/* offset=2707688 */ "unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000"
/* offset=2707983 */ "unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IRQ in Internal Starvation\000"
/* offset=2708323 */ "unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000"
/* offset=2708618 */ "unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the ISMQ in Internal Starvation\000"
/* offset=2708961 */ "unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000"
/* offset=2709258 */ "unc_c_rxr_int_starved.prq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; PRQ. Unit: uncore_cbox \000event=0x14,umask=0x10\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000"
/* offset=2709554 */ "unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from an address conflicts.  Address conflicts out of the IPQ should be rare.  They will generally only occur if two different sockets are sending requests to the same address at the same time.  This is a true conflict case, unlike the IPQ Address Conflict which is commonly caused by prefetching characteristics\000"
/* offset=2710212 */ "unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000"
/* offset=2710465 */ "unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject.  TOR rejects from the IPQ can be caused by the Egress being full or Address Conflicts\000"
/* offset=2710882 */ "unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000"
/* offset=2711119 */ "unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from the Egress being full.  IPQ requests make use of the AD Egress for regular responses, the BL egress to forward data, and the AK egress to return credits\000"
/* offset=2711615 */ "unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000"
/* offset=2711860 */ "unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000"
/* offset=2712110 */ "unc_c_rxr_ipq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Probe Queue Retries; No AD Sbo Credits. Unit: uncore_cbox \000event=0x28,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000"
/* offset=2712488 */ "unc_c_rxr_ipq_retry2.target\000uncore_cbox\000uncore cache\000Probe Queue Retries; Target Node Filter. Unit: uncore_cbox \000event=0x28,umask=0x40\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000"
/* offset=2712880 */ "unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000Counts the number of times that a request from the IRQ was retried because of an address match in the TOR.  In order to maintain coherency, requests to the same address are not allowed to pass each other up in the Cbo.  Therefore, if there is an outstanding request to a given address, one cannot issue another request to that address until it is complete.  This comes up most commonly with prefetches.  Outstanding prefetches occasionally will not complete their memory fetch and a demand request to the same address will then sit in the IRQ and get retried until the prefetch fills the data into the LLC.  Therefore, it will not be uncommon to see this case in high bandwidth streaming workloads when the LLC Prefetcher in the core is enabled\000"
/* offset=2713777 */ "unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000\000"
/* offset=2713930 */ "unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000Counts the number of IRQ retries that occur.  Requests from the IRQ are retried if they are rejected from the TOR pipeline for a variety of reasons.  Some of the most common reasons include if the Egress is full, there are no RTIDs, or there is a Physical Address match to another outstanding request\000"
/* offset=2714367 */ "unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000\000"
/* offset=2714504 */ "unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000Counts the number of times that a request from the IRQ was retried because it failed to acquire an entry in the Egress.  The egress is the buffer that queues up for allocating onto the ring.  IRQ requests can make use of all four rings and all four Egresses.  If any of the queues that a given request needs to make use of are full, the request will be retried\000"
/* offset=2715009 */ "unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000\000"
/* offset=2715154 */ "unc_c_rxr_irq_retry.iio_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No IIO Credits. Unit: uncore_cbox \000event=0x32,umask=0x20\000\00001\000Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000"
/* offset=2715572 */ "unc_c_rxr_irq_retry.nid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cbox \000event=0x32,umask=0x40\000\00001\000Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000"
/* offset=2715819 */ "unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000Number of requests rejects because of lack of QPI Ingress credits.  These credits are required in order to send transactions to the QPI agent.  Please see the QPI_IGR_CREDITS events for more information\000"
/* offset=2716171 */ "unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000\000"
/* offset=2716321 */ "unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000Counts the number of times that requests from the IRQ were retried because there were no RTIDs available.  RTIDs are required after a request misses the LLC and needs to send snoops and/or requests to memory.  If there are no RTIDs available, requests will queue up in the IRQ and retry until one becomes available.  Note that there are multiple RTID pools for the different sockets.  There may be cases where the local RTIDs are all used, but requests destined for remote memory can still acquire an RTID because there are remote RTIDs available.  This event does not provide any filtering for this case\000"
/* offset=2717061 */ "unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000\000"
/* offset=2717197 */ "unc_c_rxr_irq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x1\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000"
/* offset=2717472 */ "unc_c_rxr_irq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x2\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an BL packet to the Sbo\000"
/* offset=2717747 */ "unc_c_rxr_irq_retry2.target\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x29,umask=0x40\000\00001\000Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000"
/* offset=2718036 */ "unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the total number of times that a request from the ISMQ retried because of a TOR reject.  ISMQ requests generally will not need to retry (or at least ISMQ retries are less common than IRQ retries).  ISMQ requests will retry if they are not able to acquire a needed Egress credit to get onto the ring, or for cache evictions that need to acquire an RTID.  Most ISMQ requests already have an RTID, so eviction retries will be less common here\000"
/* offset=2718861 */ "unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=2719237 */ "unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by a lack of Egress credits. The egress is the buffer that queues up for allocating onto the ring.  If any of the Egress queues that a given request needs to make use of are full, the request will be retried\000"
/* offset=2719926 */ "unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=2720310 */ "unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000"
/* offset=2720970 */ "unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=2721359 */ "unc_c_rxr_ismq_retry.nid\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000"
/* offset=2721848 */ "unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=2722237 */ "unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by no RTIDs.  M-state cache evictions are serviced through the ISMQ, and must acquire an RTID in order to write back to memory.  If no RTIDs are available, they will be retried\000"
/* offset=2722886 */ "unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=2723261 */ "unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000"
/* offset=2723757 */ "unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No WB Credits. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Retries of writes to local memory due to lack of HT WB credits\000"
/* offset=2724209 */ "unc_c_rxr_ismq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x1\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an AD packet to the Sbo\000"
/* offset=2724483 */ "unc_c_rxr_ismq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x2\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an BL packet to the Sbo\000"
/* offset=2724757 */ "unc_c_rxr_ismq_retry2.target\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x2a,umask=0x40\000\00001\000Counts the number of times that a request from the ISMQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000"
/* offset=2725045 */ "unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2725232 */ "unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2725419 */ "unc_c_rxr_occupancy.irq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2725619 */ "unc_c_rxr_occupancy.irq_rejected\000uncore_cbox\000uncore cache\000IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2725805 */ "unc_c_rxr_occupancy.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2726010 */ "unc_c_rxr_occupancy.prq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; PRQ Rejects. Unit: uncore_cbox \000event=0x11,umask=0x20\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2726210 */ "unc_c_rxr_occupancy.vfifo\000uncore_cbox\000uncore cache\000Ingress Occupancy; VFIFO. Unit: uncore_cbox \000event=0x11,umask=0x10\000\00001\000Counts number of entries in the specified Ingress queue in each cycle.; Accumulates the number of used entries in the IRQ Ordering FIFO in each cycle.  In JKT, it is necessary to keep IO requests in order.  Therefore, they are allocated into an ordering FIFO that sits next to the IRQ, and must be satisfied from the FIFO in order (with respect to each other).  This event, in conjunction with the Allocations event, can be used to calculate average lifetime in the FIFO.  This event can be used in conjunction with the Not Empty event to calculate average queue occupancy. Transactions are allocated into the FIFO as soon as they enter the Cachebo (and the IRQ) and are deallocated from the FIFO as soon as they are deallocated from the IRQ\000"
/* offset=2727074 */ "unc_c_rxr_occupancy.vfifo\000uncore_cbox\000uncore cache\000Ingress Occupancy; VFIFO. Unit: uncore_cbox \000event=0x11,umask=0x10\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=2727266 */ "unc_c_sbo_credit_occupancy.ad\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For AD Ring. Unit: uncore_cbox \000event=0x3e,umask=0x1\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000"
/* offset=2727511 */ "unc_c_sbo_credit_occupancy.bl\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For BL Ring. Unit: uncore_cbox \000event=0x3e,umask=0x2\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000"
/* offset=2727756 */ "unc_c_sbo_credits_acquired.ad\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For AD Ring. Unit: uncore_cbox \000event=0x3d,umask=0x1\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000"
/* offset=2728002 */ "unc_c_sbo_credits_acquired.bl\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For BL Ring. Unit: uncore_cbox \000event=0x3d,umask=0x2\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000"
/* offset=2728248 */ "unc_c_tor_inserts.all\000uncore_cbox\000uncore cache\000TOR Inserts; All. Unit: uncore_cbox \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR.    This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000"
/* offset=2729483 */ "unc_c_tor_inserts.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.EVICT. Unit: uncore_cha \000event=0x35,umask=0x2\000\00011\000\000"
/* offset=2729647 */ "unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2730237 */ "unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Eviction transactions inserted into the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000"
/* offset=2731157 */ "unc_c_tor_inserts.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.HIT. Unit: uncore_cha \000event=0x35,umask=0x10\000\00011\000\000"
/* offset=2731318 */ "unc_c_tor_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00011\000\000"
/* offset=2731478 */ "unc_c_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x18\000\00001\000\000"
/* offset=2731696 */ "unc_c_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000"
/* offset=2731817 */ "unc_c_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x28\000\00001\000\000"
/* offset=2732036 */ "unc_c_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000"
/* offset=2732158 */ "unc_c_tor_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000"
/* offset=2732318 */ "unc_c_tor_inserts.irq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x11\000\00001\000\000"
/* offset=2732536 */ "unc_c_tor_inserts.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT. Unit: uncore_cha \000event=0x35,umask=0x11\000\00011\000\000"
/* offset=2732704 */ "unc_c_tor_inserts.irq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x21\000\00001\000\000"
/* offset=2732923 */ "unc_c_tor_inserts.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS. Unit: uncore_cha \000event=0x35,umask=0x21\000\00011\000\000"
/* offset=2733093 */ "unc_c_tor_inserts.loc_all\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ or PRQ. Unit: uncore_cha \000event=0x35,umask=0x37\000\00001\000\000"
/* offset=2733318 */ "unc_c_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000"
/* offset=2733439 */ "unc_c_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000"
/* offset=2733602 */ "unc_c_tor_inserts.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00011\000\000"
/* offset=2733765 */ "unc_c_tor_inserts.local\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x28\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by locally HOMed memory\000"
/* offset=2734438 */ "unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000"
/* offset=2735161 */ "unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000"
/* offset=2735882 */ "unc_c_tor_inserts.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.MISS. Unit: uncore_cha \000event=0x35,umask=0x20\000\00011\000\000"
/* offset=2736045 */ "unc_c_tor_inserts.miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; Miss All. Unit: uncore_cbox \000event=0x35,umask=0xa\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2736634 */ "unc_c_tor_inserts.miss_local\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x2a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by locally HOMed memory\000"
/* offset=2737323 */ "unc_c_tor_inserts.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x23\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode, inserted into the TOR that are satisfied by locally HOMed memory\000"
/* offset=2738061 */ "unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2738662 */ "unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000"
/* offset=2739324 */ "unc_c_tor_inserts.miss_remote\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x8a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2740025 */ "unc_c_tor_inserts.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x83\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2740776 */ "unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2741368 */ "unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched (matches an RTID destination) transactions inserted into the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.  In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000"
/* offset=2742192 */ "unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2742799 */ "unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched eviction transactions inserted into the TOR\000"
/* offset=2743462 */ "unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2744068 */ "unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched miss requests that were inserted into the TOR\000"
/* offset=2744736 */ "unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2745352 */ "unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match a NID and an opcode\000"
/* offset=2746039 */ "unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2746645 */ "unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match a NID and an opcode\000"
/* offset=2747317 */ "unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2747919 */ "unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched write transactions inserted into the TOR\000"
/* offset=2748574 */ "unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2749165 */ "unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=2749852 */ "unc_c_tor_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00011\000\000"
/* offset=2750012 */ "unc_c_tor_inserts.prq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x14\000\00001\000\000"
/* offset=2750230 */ "unc_c_tor_inserts.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_HIT. Unit: uncore_cha \000event=0x35,umask=0x14\000\00011\000\000"
/* offset=2750398 */ "unc_c_tor_inserts.prq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x24\000\00001\000\000"
/* offset=2750617 */ "unc_c_tor_inserts.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_MISS. Unit: uncore_cha \000event=0x35,umask=0x24\000\00011\000\000"
/* offset=2750787 */ "unc_c_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000"
/* offset=2750908 */ "unc_c_tor_inserts.remote\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x88\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2751593 */ "unc_c_tor_inserts.remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x81\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2752328 */ "unc_c_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000"
/* offset=2752449 */ "unc_c_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000"
/* offset=2752571 */ "unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000"
/* offset=2753157 */ "unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Write transactions inserted into the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000"
/* offset=2753879 */ "unc_c_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000"
/* offset=2754000 */ "unc_c_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000"
/* offset=2754122 */ "unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2754718 */ "unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All valid TOR entries.  This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000"
/* offset=2755950 */ "unc_c_tor_occupancy.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.EVICT. Unit: uncore_cha \000event=0x36,umask=0x2\000\00011\000\000"
/* offset=2756118 */ "unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2756725 */ "unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding eviction transactions in the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000"
/* offset=2757672 */ "unc_c_tor_occupancy.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.HIT. Unit: uncore_cha \000event=0x36,umask=0x10\000\00011\000\000"
/* offset=2757837 */ "unc_c_tor_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00011\000\000"
/* offset=2758001 */ "unc_c_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000"
/* offset=2758124 */ "unc_c_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000"
/* offset=2758248 */ "unc_c_tor_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000"
/* offset=2758412 */ "unc_c_tor_occupancy.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_HIT. Unit: uncore_cha \000event=0x36,umask=0x11\000\00011\000\000"
/* offset=2758584 */ "unc_c_tor_occupancy.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_MISS. Unit: uncore_cha \000event=0x36,umask=0x21\000\00011\000\000"
/* offset=2758758 */ "unc_c_tor_occupancy.llc_data_read\000uncore_cbox\000uncore cache\000Occupancy counter for LLC data reads (demand and L2 prefetch). Derived from unc_c_tor_occupancy.miss_opcode. Unit: uncore_cbox \000event=0x36,umask=0x3,filter_opc=0x182\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000"
/* offset=2759590 */ "unc_c_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000"
/* offset=2759713 */ "unc_c_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000"
/* offset=2759880 */ "unc_c_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00011\000\000"
/* offset=2760047 */ "unc_c_tor_occupancy.local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x28\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2760639 */ "unc_c_tor_occupancy.local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by locally HOMed memory\000"
/* offset=2761386 */ "unc_c_tor_occupancy.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.MISS. Unit: uncore_cha \000event=0x36,umask=0x20\000\00011\000\000"
/* offset=2761553 */ "unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2762159 */ "unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding miss requests in the TOR.  'Miss' means the allocation requires an RTID.  This generally means that the request was sent to memory or MMIO\000"
/* offset=2762925 */ "unc_c_tor_occupancy.miss_local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x2a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2763522 */ "unc_c_tor_occupancy.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x23\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by locally HOMed memory\000"
/* offset=2764287 */ "unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2764905 */ "unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000"
/* offset=2765643 */ "unc_c_tor_occupancy.miss_remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x8a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2766241 */ "unc_c_tor_occupancy.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x83\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2767018 */ "unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2767627 */ "unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of NID matched outstanding requests in the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000"
/* offset=2768438 */ "unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2769062 */ "unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding NID matched eviction transactions in the TOR \000"
/* offset=2769753 */ "unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2770367 */ "unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID\000"
/* offset=2771044 */ "unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2771677 */ "unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID and an opcode\000"
/* offset=2772387 */ "unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2773010 */ "unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match a NID and an opcode\000"
/* offset=2773675 */ "unc_c_tor_occupancy.nid_wb\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x50\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); NID matched write transactions int the TOR\000"
/* offset=2774336 */ "unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2774944 */ "unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000"
/* offset=2775624 */ "unc_c_tor_occupancy.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00011\000\000"
/* offset=2775788 */ "unc_c_tor_occupancy.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_HIT. Unit: uncore_cha \000event=0x36,umask=0x14\000\00011\000\000"
/* offset=2775960 */ "unc_c_tor_occupancy.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_MISS. Unit: uncore_cha \000event=0x36,umask=0x24\000\00011\000\000"
/* offset=2776134 */ "unc_c_tor_occupancy.remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x88\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000"
/* offset=2776727 */ "unc_c_tor_occupancy.remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x81\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by remote caches or remote memory\000"
/* offset=2777486 */ "unc_c_tor_occupancy.wb\000uncore_cbox\000uncore cache\000TOR Occupancy; Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Write transactions in the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000"
/* offset=2778213 */ "unc_c_txr_ads_used.ad\000uncore_cbox\000uncore cache\000Onto AD Ring. Unit: uncore_cbox \000event=0x4,umask=0x1\000\00001\000\000"
/* offset=2778318 */ "unc_c_txr_ads_used.ak\000uncore_cbox\000uncore cache\000Onto AK Ring. Unit: uncore_cbox \000event=0x4,umask=0x2\000\00001\000\000"
/* offset=2778423 */ "unc_c_txr_ads_used.bl\000uncore_cbox\000uncore cache\000Onto BL Ring. Unit: uncore_cbox \000event=0x4,umask=0x4\000\00001\000\000"
/* offset=2778528 */ "unc_c_txr_ads_used\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x4\000\00001\000\000"
/* offset=2778606 */ "unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=2778981 */ "unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2779216 */ "unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=2779557 */ "unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2779791 */ "unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=2780148 */ "unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2780383 */ "unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AK ring.  This is commonly used for snoop responses coming from the core and destined for a Cachebo\000"
/* offset=2780770 */ "unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2781004 */ "unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=2781377 */ "unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2781612 */ "unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=2781976 */ "unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2782210 */ "unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=2782555 */ "unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=2782790 */ "unc_c_txr_starved.ad_core\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AD Ring (to core). Unit: uncore_cbox \000event=0x3,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the core AD egress spent in starvation\000"
/* offset=2783125 */ "unc_c_txr_starved.ak\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=2783391 */ "unc_c_txr_starved.ak_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both AK egresses spent in starvation\000"
/* offset=2783713 */ "unc_c_txr_starved.bl\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=2783979 */ "unc_c_txr_starved.bl_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both BL egresses spent in starvation\000"
/* offset=2784301 */ "unc_c_txr_starved.iv\000uncore_cbox\000uncore cache\000Injection Starvation; Onto IV Ring. Unit: uncore_cbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the cachebo IV egress spent in starvation\000"
/* offset=2784623 */ "unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000L3 Lookup any request that access cache and found line in E or S-state\000"
/* offset=2784864 */ "unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000\000"
/* offset=2785035 */ "unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000L3 Lookup any request that access cache and found line in I-state\000"
/* offset=2785265 */ "unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000\000"
/* offset=2785430 */ "unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000L3 Lookup any request that access cache and found line in M-state\000"
/* offset=2785660 */ "unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000\000"
/* offset=2785825 */ "unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000L3 Lookup any request that access cache and found line in MESI-state\000"
/* offset=2786064 */ "unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000\000"
/* offset=2786235 */ "unc_cbo_cache_lookup.extsnp_es\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x46\000\00001\000\000"
/* offset=2786420 */ "unc_cbo_cache_lookup.extsnp_i\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x48\000\00001\000\000"
/* offset=2786599 */ "unc_cbo_cache_lookup.extsnp_m\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000\000"
/* offset=2786778 */ "unc_cbo_cache_lookup.extsnp_mesi\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x4f\000\00001\000\000"
/* offset=2786963 */ "unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000L3 Lookup read request that access cache and found line in E or S-state\000"
/* offset=2787207 */ "unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000\000"
/* offset=2787380 */ "unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000L3 Lookup read request that access cache and found line in I-state\000"
/* offset=2787613 */ "unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000\000"
/* offset=2787780 */ "unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000L3 Lookup read request that access cache and found line in M-state\000"
/* offset=2788013 */ "unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000\000"
/* offset=2788180 */ "unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000L3 Lookup read request that access cache and found line in any MESI-state\000"
/* offset=2788430 */ "unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000\000"
/* offset=2788607 */ "unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000L3 Lookup write request that access cache and found line in E or S-state\000"
/* offset=2788854 */ "unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000\000"
/* offset=2789029 */ "unc_cbo_cache_lookup.write_i\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x28\000\00001\000\000"
/* offset=2789198 */ "unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000L3 Lookup write request that access cache and found line in M-state\000"
/* offset=2789434 */ "unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000\000"
/* offset=2789603 */ "unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000L3 Lookup write request that access cache and found line in MESI-state\000"
/* offset=2789848 */ "unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000\000"
/* offset=2790023 */ "unc_cbo_xsnp_response.hit_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x84\000\00001\000\000"
/* offset=2790229 */ "unc_cbo_xsnp_response.hit_external\000uncore_cbox\000uncore cache\000An external snoop hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x24\000\00001\000\000"
/* offset=2790402 */ "unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000"
/* offset=2790639 */ "unc_cbo_xsnp_response.hitm_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x88\000\00001\000\000"
/* offset=2790842 */ "unc_cbo_xsnp_response.hitm_external\000uncore_cbox\000uncore cache\000An external snoop hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x28\000\00001\000\000"
/* offset=2791012 */ "unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000"
/* offset=2791246 */ "unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000"
/* offset=2791435 */ "unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000"
/* offset=2791698 */ "unc_cbo_xsnp_response.miss_external\000uncore_cbox\000uncore cache\000An external snoop misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x21\000\00001\000\000"
/* offset=2791854 */ "unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000"
/* offset=2792074 */ "unc_cha_2lm_nm_invitox.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.LOCAL. Unit: uncore_cha \000event=0x65,umask=0x1\000\00011\000\000"
/* offset=2792254 */ "unc_cha_2lm_nm_invitox.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.REMOTE. Unit: uncore_cha \000event=0x65,umask=0x2\000\00011\000\000"
/* offset=2792436 */ "unc_cha_2lm_nm_invitox.setconflict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.SETCONFLICT. Unit: uncore_cha \000event=0x65,umask=0x4\000\00011\000\000"
/* offset=2792628 */ "unc_cha_2lm_nm_setconflicts.llc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00011\000\000"
/* offset=2792814 */ "unc_cha_2lm_nm_setconflicts.sf\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.SF. Unit: uncore_cha \000event=0x64,umask=0x1\000\00011\000\000"
/* offset=2792998 */ "unc_cha_2lm_nm_setconflicts.tor\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00011\000\000"
/* offset=2793184 */ "unc_cha_2lm_nm_setconflicts2.memwr\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWR. Unit: uncore_cha \000event=0x70,umask=0x2\000\00011\000\000"
/* offset=2793376 */ "unc_cha_2lm_nm_setconflicts2.memwrni\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWRNI. Unit: uncore_cha \000event=0x70,umask=0x4\000\00011\000\000"
/* offset=2793572 */ "unc_cha_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2793797 */ "unc_cha_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2794022 */ "unc_cha_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2794247 */ "unc_cha_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2794472 */ "unc_cha_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2794698 */ "unc_cha_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2794924 */ "unc_cha_ag0_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2795203 */ "unc_cha_ag0_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2795482 */ "unc_cha_ag0_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2795761 */ "unc_cha_ag0_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2796040 */ "unc_cha_ag0_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2796320 */ "unc_cha_ag0_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2796600 */ "unc_cha_ag0_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2796880 */ "unc_cha_ag0_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2797160 */ "unc_cha_ag0_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2797442 */ "unc_cha_ag0_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2797721 */ "unc_cha_ag0_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=2798000 */ "unc_cha_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2798225 */ "unc_cha_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2798450 */ "unc_cha_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2798675 */ "unc_cha_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2798900 */ "unc_cha_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2799126 */ "unc_cha_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2799352 */ "unc_cha_ag0_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2799632 */ "unc_cha_ag0_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2799912 */ "unc_cha_ag0_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2800192 */ "unc_cha_ag0_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2800472 */ "unc_cha_ag0_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2800753 */ "unc_cha_ag0_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2801034 */ "unc_cha_ag0_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2801315 */ "unc_cha_ag0_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2801596 */ "unc_cha_ag0_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2801879 */ "unc_cha_ag0_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2802159 */ "unc_cha_ag0_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=2802439 */ "unc_cha_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2802664 */ "unc_cha_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2802889 */ "unc_cha_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2803114 */ "unc_cha_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2803339 */ "unc_cha_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2803565 */ "unc_cha_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2803791 */ "unc_cha_ag0_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2804070 */ "unc_cha_ag0_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2804349 */ "unc_cha_ag0_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2804628 */ "unc_cha_ag0_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2804907 */ "unc_cha_ag0_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2805187 */ "unc_cha_ag0_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2805467 */ "unc_cha_ag0_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2805747 */ "unc_cha_ag0_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2806027 */ "unc_cha_ag0_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2806309 */ "unc_cha_ag0_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2806588 */ "unc_cha_ag0_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=2806867 */ "unc_cha_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2807092 */ "unc_cha_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2807317 */ "unc_cha_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2807542 */ "unc_cha_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2807767 */ "unc_cha_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2807993 */ "unc_cha_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2808219 */ "unc_cha_ag0_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2808499 */ "unc_cha_ag0_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2808779 */ "unc_cha_ag0_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2809059 */ "unc_cha_ag0_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2809339 */ "unc_cha_ag0_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2809620 */ "unc_cha_ag0_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2809901 */ "unc_cha_ag0_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2810182 */ "unc_cha_ag0_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2810463 */ "unc_cha_ag0_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2810746 */ "unc_cha_ag0_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2811026 */ "unc_cha_ag0_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=2811306 */ "unc_cha_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2811531 */ "unc_cha_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2811756 */ "unc_cha_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2811981 */ "unc_cha_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2812206 */ "unc_cha_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2812432 */ "unc_cha_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2812658 */ "unc_cha_ag1_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2812937 */ "unc_cha_ag1_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2813216 */ "unc_cha_ag1_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2813495 */ "unc_cha_ag1_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2813774 */ "unc_cha_ag1_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2814054 */ "unc_cha_ag1_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2814334 */ "unc_cha_ag1_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2814614 */ "unc_cha_ag1_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2814894 */ "unc_cha_ag1_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2815176 */ "unc_cha_ag1_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2815455 */ "unc_cha_ag1_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=2815734 */ "unc_cha_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2815959 */ "unc_cha_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2816184 */ "unc_cha_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2816409 */ "unc_cha_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2816634 */ "unc_cha_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2816860 */ "unc_cha_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2817086 */ "unc_cha_ag1_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2817366 */ "unc_cha_ag1_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2817646 */ "unc_cha_ag1_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2817926 */ "unc_cha_ag1_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2818206 */ "unc_cha_ag1_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2818487 */ "unc_cha_ag1_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2818768 */ "unc_cha_ag1_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2819049 */ "unc_cha_ag1_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2819330 */ "unc_cha_ag1_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2819613 */ "unc_cha_ag1_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2819893 */ "unc_cha_ag1_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=2820173 */ "unc_cha_ag1_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2820452 */ "unc_cha_ag1_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2820731 */ "unc_cha_ag1_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2821010 */ "unc_cha_ag1_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2821289 */ "unc_cha_ag1_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2821569 */ "unc_cha_ag1_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2821849 */ "unc_cha_ag1_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2822129 */ "unc_cha_ag1_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2822409 */ "unc_cha_ag1_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2822691 */ "unc_cha_ag1_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2822970 */ "unc_cha_ag1_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2823249 */ "unc_cha_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2823474 */ "unc_cha_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2823699 */ "unc_cha_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2823924 */ "unc_cha_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2824149 */ "unc_cha_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2824375 */ "unc_cha_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2824601 */ "unc_cha_ag1_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2824881 */ "unc_cha_ag1_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2825161 */ "unc_cha_ag1_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2825441 */ "unc_cha_ag1_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2825721 */ "unc_cha_ag1_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2826002 */ "unc_cha_ag1_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2826283 */ "unc_cha_ag1_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2826564 */ "unc_cha_ag1_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2826845 */ "unc_cha_ag1_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2827128 */ "unc_cha_ag1_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2827408 */ "unc_cha_ag1_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=2827688 */ "unc_cha_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2827917 */ "unc_cha_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2828146 */ "unc_cha_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2828375 */ "unc_cha_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2828604 */ "unc_cha_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2828834 */ "unc_cha_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=2829064 */ "unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000CHA to iMC Bypass : Intermediate bypass Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the intermediate bypass\000"
/* offset=2829596 */ "unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the intermediate bypass\000"
/* offset=2830078 */ "unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000CHA to iMC Bypass : Not Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000"
/* offset=2830692 */ "unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000"
/* offset=2831272 */ "unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000CHA to iMC Bypass : Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the full bypass\000"
/* offset=2831749 */ "unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the full bypass\000"
/* offset=2832196 */ "unc_cha_clockticks\000uncore_cha\000uncore cache\000CHA Clockticks. Unit: uncore_cha \000event=0x1\000\00001\000Number of CHA clock cycles while the event is enabled\000"
/* offset=2832341 */ "unc_cha_clockticks\000uncore_cha\000uncore cache\000Clockticks of the uncore caching & home agent (CHA). Unit: uncore_cha \000event=0\000\00001\000Counts clockticks of the clock controlling the uncore caching and home agent (CHA)\000"
/* offset=2832550 */ "unc_cha_clockticks\000uncore_cha\000uncore cache\000Clockticks of the uncore caching and home agent (CHA). Unit: uncore_cha \000event=0\000\00001\000\000"
/* offset=2832679 */ "unc_cha_clockticks\000uncore_cha\000uncore cache\000Uncore cache clock ticks. Unit: uncore_cha \000event=0\000\00001\000Counts clockticks of the clock controlling the uncore caching and home agent (CHA)\000"
/* offset=2832861 */ "unc_cha_clockticks\000uncore_cha\000uncore cache\000Uncore cache clock ticks. Unit: uncore_cha \000event=0\000\00001\000\000"
/* offset=2832961 */ "unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000"
/* offset=2833058 */ "unc_cha_core_pma.c1_state\000uncore_cha\000uncore cache\000Core PMA Events; C1  State. Unit: uncore_cha \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=2833180 */ "unc_cha_core_pma.c1_transition\000uncore_cha\000uncore cache\000Core PMA Events; C1 Transition. Unit: uncore_cha \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=2833311 */ "unc_cha_core_pma.c6_state\000uncore_cha\000uncore cache\000Core PMA Events; C6 State. Unit: uncore_cha \000event=0x17,umask=0x4\000\00001\000\000"
/* offset=2833432 */ "unc_cha_core_pma.c6_transition\000uncore_cha\000uncore cache\000Core PMA Events; C6 Transition. Unit: uncore_cha \000event=0x17,umask=0x8\000\00001\000\000"
/* offset=2833563 */ "unc_cha_core_pma.gv\000uncore_cha\000uncore cache\000Core PMA Events; GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00001\000\000"
/* offset=2833673 */ "unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xf2\000\00001\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2834469 */ "unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2835204 */ "unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xf1\000\00001\000Core Cross Snoops Issued : Any Single Snoop : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2835970 */ "unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2836689 */ "unc_cha_core_snp.any_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2837419 */ "unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Core Cross Snoops Issued : Multiple Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2838200 */ "unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2838928 */ "unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Core Cross Snoops Issued : Single Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2839703 */ "unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2840427 */ "unc_cha_core_snp.core_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Core Request to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x44\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2841161 */ "unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Core Cross Snoops Issued : Multiple Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2841933 */ "unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2842657 */ "unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Core Cross Snoops Issued : Single Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2843423 */ "unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2844143 */ "unc_cha_core_snp.evict_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Eviction to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x84\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2844874 */ "unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Core Cross Snoops Issued : Multiple External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2845658 */ "unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2846387 */ "unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Core Cross Snoops Issued : Single External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2847165 */ "unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2847890 */ "unc_cha_core_snp.ext_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; External Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x24\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2848625 */ "unc_cha_core_snp.remote_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote. Unit: uncore_cha \000event=0x33,umask=0x12\000\00001\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2849432 */ "unc_cha_core_snp.remote_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Snoop Target from Remote. Unit: uncore_cha \000event=0x33,umask=0x11\000\00001\000Core Cross Snoops Issued : Single Snoop Target from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000"
/* offset=2850231 */ "unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Counter 0 Occupancy : Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000"
/* offset=2850751 */ "unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000"
/* offset=2851249 */ "unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Counts transactions that looked into the multi-socket cacheline Directory state, and therefore did not send a snoop because the Directory indicated it was not needed\000"
/* offset=2851574 */ "unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state lookups : Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Multi-socket cacheline directory state lookups : Snoop Not Needed : Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to. : Filters for transactions that did not have to send any snoops because the directory was clean\000"
/* offset=2852041 */ "unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Counts  transactions that looked into the multi-socket cacheline Directory state, and sent one or more snoops, because the Directory indicated it was needed\000"
/* offset=2852350 */ "unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state lookups : Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Multi-socket cacheline directory state lookups : Snoop Needed : Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to. : Filters for transactions that had to send one or more snoops because the directory was not clean\000"
/* offset=2852809 */ "unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from the HA pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline Directory state updates memory writes issued from the HA pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000"
/* offset=2853191 */ "unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state updates; memory write due to directory update from the home agent (HA) pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline directory state updates memory writes issued from the home agent (HA) pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000"
/* offset=2853605 */ "unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline Directory state updates due to memory writes issued from the TOR pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000"
/* offset=2854084 */ "unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state updates; memory write due to directory update from (table of requests) TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline directory state updates due to memory writes issued from the table of requests (TOR) pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000"
/* offset=2854609 */ "unc_cha_direct_go.ha_suppress_drd\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x4\000\00001\000\000"
/* offset=2854722 */ "unc_cha_direct_go.ha_suppress_no_d2c\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x2\000\00001\000\000"
/* offset=2854838 */ "unc_cha_direct_go.ha_tor_dealloc\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x1\000\00001\000\000"
/* offset=2854950 */ "unc_cha_direct_go_opc.extcmp\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x1\000\00001\000\000"
/* offset=2855058 */ "unc_cha_direct_go_opc.fast_go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x10\000\00001\000\000"
/* offset=2855168 */ "unc_cha_direct_go_opc.fast_go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x20\000\00001\000\000"
/* offset=2855283 */ "unc_cha_direct_go_opc.go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x4\000\00001\000\000"
/* offset=2855387 */ "unc_cha_direct_go_opc.go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x8\000\00001\000\000"
/* offset=2855496 */ "unc_cha_direct_go_opc.idle_due_suppress\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x80\000\00001\000\000"
/* offset=2855616 */ "unc_cha_direct_go_opc.nop\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x40\000\00001\000\000"
/* offset=2855722 */ "unc_cha_direct_go_opc.pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x2\000\00001\000\000"
/* offset=2855828 */ "unc_cha_distress_asserted.dpt_local\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Local. Unit: uncore_cha \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000"
/* offset=2856147 */ "unc_cha_distress_asserted.dpt_nonlocal\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Remote. Unit: uncore_cha \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000"
/* offset=2856470 */ "unc_cha_distress_asserted.dpt_stall_iv\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_cha \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000"
/* offset=2856830 */ "unc_cha_distress_asserted.dpt_stall_nocrd\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_cha \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000"
/* offset=2857203 */ "unc_cha_distress_asserted.horz\000uncore_cha\000uncore cache\000Distress signal asserted : Horizontal. Unit: uncore_cha \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=2857548 */ "unc_cha_distress_asserted.pmm_local\000uncore_cha\000uncore cache\000Distress signal asserted : PMM Local. Unit: uncore_cha \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=2857915 */ "unc_cha_distress_asserted.pmm_nonlocal\000uncore_cha\000uncore cache\000Distress signal asserted : PMM Remote. Unit: uncore_cha \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=2858291 */ "unc_cha_distress_asserted.vert\000uncore_cha\000uncore cache\000Distress signal asserted : Vertical. Unit: uncore_cha \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=2858632 */ "unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_cha \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=2858937 */ "unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_cha \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=2859187 */ "unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_cha \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=2859488 */ "unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_cha \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=2859736 */ "unc_cha_fast_asserted.horz\000uncore_cha\000uncore cache\000FaST wire asserted; Horizontal. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=2859996 */ "unc_cha_fast_asserted.vert\000uncore_cha\000uncore cache\000FaST wire asserted; Vertical. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=2860254 */ "unc_cha_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000Read request from a remote socket which hit in the HitMe Cache to a line In the E state. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00001\000Counts read requests from a remote socket which hit in the HitME cache (used to cache the multi-socket Directory state) to a line in the E(Exclusive) state.  This includes the following read opcodes (RdCode, RdData, RdDataMigratory, RdCur, RdInv*, Inv*)\000"
/* offset=2860689 */ "unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket ownership read requests that hit in S state. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000Counts Number of Hits in HitMe Cache : Remote socket ownership read requests that hit in S state. : Shared hit and op is RdInvOwn, RdInv, Inv*\000"
/* offset=2861029 */ "unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Shared hit and op is RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000\000"
/* offset=2861212 */ "unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; Shared hit and op is RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000\000"
/* offset=2861394 */ "unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket WBMtoE requests. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000"
/* offset=2861557 */ "unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : op is WbMtoE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000"
/* offset=2861703 */ "unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000"
/* offset=2861848 */ "unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket writeback to I or S requests. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000Counts Number of Hits in HitMe Cache : Remote socket writeback to I or S requests : op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS\000"
/* offset=2862158 */ "unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000\000"
/* offset=2862342 */ "unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000\000"
/* offset=2862525 */ "unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : Remote socket read requests. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000Counts Number of times HitMe Cache is accessed : Remote socket read requests : op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*\000"
/* offset=2862843 */ "unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000\000"
/* offset=2863055 */ "unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000\000"
/* offset=2863266 */ "unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : Remote socket write (i.e. writeback) requests. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000Counts Number of times HitMe Cache is accessed : Remote socket write (i.e. writeback) requests : op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS\000"
/* offset=2863606 */ "unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000\000"
/* offset=2863804 */ "unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000\000"
/* offset=2864001 */ "unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : No SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000\000"
/* offset=2864186 */ "unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests that are not to shared line. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests that are not to shared line : No SF/LLC HitS/F and op is RdInvOwn\000"
/* offset=2864533 */ "unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; No SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000\000"
/* offset=2864717 */ "unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket read or invalidate requests. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket read or invalidate requests : op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*\000"
/* offset=2865043 */ "unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000\000"
/* offset=2865243 */ "unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000\000"
/* offset=2865442 */ "unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests to shared line. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests to shared line : SF/LLC HitS/F and op is RdInvOwn\000"
/* offset=2865757 */ "unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000\000"
/* offset=2865936 */ "unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000\000"
/* offset=2866114 */ "unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000"
/* offset=2866314 */ "unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000"
/* offset=2866513 */ "unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request : Received RspFwdI* for a local request, but converted HitME$ to SF entry\000"
/* offset=2866901 */ "unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Received RspFwdI* for a local request, but converted HitME$ to SF entry\000"
/* offset=2867185 */ "unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000"
/* offset=2867390 */ "unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000"
/* offset=2867594 */ "unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request : Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000"
/* offset=2867974 */ "unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000"
/* offset=2868249 */ "unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000"
/* offset=2868429 */ "unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000"
/* offset=2868608 */ "unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2869528 */ "unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2870403 */ "unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2871320 */ "unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2872193 */ "unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2873116 */ "unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2873993 */ "unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2874913 */ "unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2875788 */ "unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2876706 */ "unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2877579 */ "unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2878494 */ "unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2879365 */ "unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2880286 */ "unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2881161 */ "unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2882079 */ "unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2882952 */ "unc_cha_horz_ring_akc_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2883879 */ "unc_cha_horz_ring_akc_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2884803 */ "unc_cha_horz_ring_akc_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2885733 */ "unc_cha_horz_ring_akc_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2886660 */ "unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_cha \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2887579 */ "unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2888453 */ "unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_cha \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2889369 */ "unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2890241 */ "unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_cha \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2891163 */ "unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2892039 */ "unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_cha \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2892958 */ "unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=2893832 */ "unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Left. Unit: uncore_cha \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=2894425 */ "unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Left. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=2894982 */ "unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Right. Unit: uncore_cha \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=2895578 */ "unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Right. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=2896137 */ "unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000"
/* offset=2896411 */ "unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued : ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000HA to iMC Reads Issued : ISOCH : Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000"
/* offset=2896705 */ "unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued; ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000"
/* offset=2896965 */ "unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to any of the memory controller channels\000"
/* offset=2897239 */ "unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to the any of the memory controller channels\000"
/* offset=2897516 */ "unc_cha_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Full Line MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=2897842 */ "unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Full Line : Counts the total number of full line writes issued from the HA into the memory controller\000"
/* offset=2898147 */ "unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=2898479 */ "unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH : Counts the total number of full line writes issued from the HA into the memory controller\000"
/* offset=2898782 */ "unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=2899110 */ "unc_cha_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH.; Filter for memory controller 5 only\000"
/* offset=2899475 */ "unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Partial : Counts the total number of full line writes issued from the HA into the memory controller\000"
/* offset=2899779 */ "unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=2900112 */ "unc_cha_iodc_alloc.invitom\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations. Unit: uncore_cha \000event=0x62,umask=0x1\000\00001\000\000"
/* offset=2900294 */ "unc_cha_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations dropped due to IODC Full. Unit: uncore_cha \000event=0x62,umask=0x2\000\00001\000\000"
/* offset=2900502 */ "unc_cha_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IDOC allocation dropped due to OSB gate. Unit: uncore_cha \000event=0x62,umask=0x4\000\00001\000\000"
/* offset=2900708 */ "unc_cha_iodc_dealloc.all\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to any reason. Unit: uncore_cha \000event=0x63,umask=0x10\000\00001\000\000"
/* offset=2900875 */ "unc_cha_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to conflicting transaction. Unit: uncore_cha \000event=0x63,umask=0x8\000\00001\000\000"
/* offset=2901057 */ "unc_cha_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00001\000\000"
/* offset=2901222 */ "unc_cha_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00001\000\000"
/* offset=2901387 */ "unc_cha_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbPushMtoI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00001\000Moved to Cbo section\000"
/* offset=2901580 */ "unc_cha_llc_lookup.all\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x1fffff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2902299 */ "unc_cha_llc_lookup.all_remote\000uncore_cha\000uncore cache\000Cache Lookups : All transactions from Remote Agents. Unit: uncore_cha \000event=0x34,umask=0x17e0ff\000\00001\000Cache Lookups : All transactions from Remote Agents : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2902911 */ "unc_cha_llc_lookup.all_remote\000uncore_cha\000uncore cache\000Cache Lookups : All transactions from Remote Agents. Unit: uncore_cha \000event=0x34,umask=0x1e20ff\000\00001\000Cache Lookups : All transactions from Remote Agents : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2903523 */ "unc_cha_llc_lookup.any\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2904238 */ "unc_cha_llc_lookup.any_f\000uncore_cha\000uncore cache\000Cache Lookups : All Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : All Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local or remote transaction to the LLC, including prefetch\000"
/* offset=2904862 */ "unc_cha_llc_lookup.any_f\000uncore_cha\000uncore cache\000Cache Lookups : All Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : All Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local or remote transaction to the LLC, including prefetch\000"
/* offset=2905473 */ "unc_cha_llc_lookup.code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2906108 */ "unc_cha_llc_lookup.code\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00011\000\000"
/* offset=2906280 */ "unc_cha_llc_lookup.code_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00011\000\000"
/* offset=2906464 */ "unc_cha_llc_lookup.code_read\000uncore_cha\000uncore cache\000Cache Lookups : Code Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00001\000Cache Lookups : Code Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2907025 */ "unc_cha_llc_lookup.code_read_f\000uncore_cha\000uncore cache\000Cache Lookups : CRd Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : CRd Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2907665 */ "unc_cha_llc_lookup.code_read_f\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2908292 */ "unc_cha_llc_lookup.code_read_local\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2908989 */ "unc_cha_llc_lookup.code_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Code Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd001\000\00001\000Cache Lookups : Code Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2909567 */ "unc_cha_llc_lookup.code_read_remote\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2910245 */ "unc_cha_llc_lookup.code_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ_REMOTE. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00011\000\000"
/* offset=2910431 */ "unc_cha_llc_lookup.corepref_or_dmnd_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local non-prefetch requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local non-prefetch requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local transaction to the LLC, not including prefetch\000"
/* offset=2911085 */ "unc_cha_llc_lookup.corepref_or_dmnd_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local transaction to the LLC, including prefetches from the Core\000"
/* offset=2911738 */ "unc_cha_llc_lookup.data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2912366 */ "unc_cha_llc_lookup.data_rd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00011\000\000"
/* offset=2912541 */ "unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2913171 */ "unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Read transactions\000"
/* offset=2913797 */ "unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000Cache Lookups : Data Reads. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00001\000Cache Lookups : Data Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2914362 */ "unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00011\000\000"
/* offset=2914543 */ "unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00011\000\000"
/* offset=2914675 */ "unc_cha_llc_lookup.data_read_f\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Data Read Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Read transactions\000"
/* offset=2915272 */ "unc_cha_llc_lookup.data_read_f\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Request. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Data Read Request : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Read transactions\000"
/* offset=2915854 */ "unc_cha_llc_lookup.data_read_local\000uncore_cha\000uncore cache\000Cache Lookups : Demand Data Reads, Core and LLC prefetches. Unit: uncore_cha \000event=0x34,umask=0x841ff\000\00001\000Cache Lookups : Demand Data Reads, Core and LLC prefetches : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2916484 */ "unc_cha_llc_lookup.data_read_local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2917171 */ "unc_cha_llc_lookup.data_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc101\000\00001\000Cache Lookups : Data Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2917749 */ "unc_cha_llc_lookup.data_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1fc101\000\00001\000Cache Lookups : Data Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2918327 */ "unc_cha_llc_lookup.data_read_remote\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a01ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2918996 */ "unc_cha_llc_lookup.dmnd_read_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x841ff\000\00011\000\000"
/* offset=2919184 */ "unc_cha_llc_lookup.e\000uncore_cha\000uncore cache\000Cache Lookups : E State. Unit: uncore_cha \000event=0x34,umask=0x20\000\00001\000Cache Lookups : E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Exclusive State\000"
/* offset=2919750 */ "unc_cha_llc_lookup.e\000uncore_cha\000uncore cache\000Cache Lookups : E State. Unit: uncore_cha \000event=0x34,umask=0x20\000\00001\000Cache Lookups : E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Exclusive State\000"
/* offset=2920315 */ "unc_cha_llc_lookup.f\000uncore_cha\000uncore cache\000Cache Lookups : F State. Unit: uncore_cha \000event=0x34,umask=0x80\000\00001\000Cache Lookups : F State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Forward State\000"
/* offset=2920879 */ "unc_cha_llc_lookup.f\000uncore_cha\000uncore cache\000Cache Lookups : F State. Unit: uncore_cha \000event=0x34,umask=0x80\000\00001\000Cache Lookups : F State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Forward State\000"
/* offset=2921442 */ "unc_cha_llc_lookup.flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests. Unit: uncore_cha \000event=0x34,umask=0x1a44ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2922015 */ "unc_cha_llc_lookup.flush_inv_local\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1844ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2922645 */ "unc_cha_llc_lookup.flush_inv_remote\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a04ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2923256 */ "unc_cha_llc_lookup.flush_or_inv_f\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Flush or Invalidate Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2923839 */ "unc_cha_llc_lookup.flush_or_inv_f\000uncore_cha\000uncore cache\000Cache Lookups : Flush. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2924379 */ "unc_cha_llc_lookup.i\000uncore_cha\000uncore cache\000Cache Lookups : I State. Unit: uncore_cha \000event=0x34,umask=0x1\000\00001\000Cache Lookups : I State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Miss\000"
/* offset=2924929 */ "unc_cha_llc_lookup.i\000uncore_cha\000uncore cache\000Cache Lookups : I State. Unit: uncore_cha \000event=0x34,umask=0x1\000\00001\000Cache Lookups : I State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Miss\000"
/* offset=2925478 */ "unc_cha_llc_lookup.llc_pf_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LLCPREF_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00011\000\000"
/* offset=2925662 */ "unc_cha_llc_lookup.llcpref_local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Prefetch requests to the LLC that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2926358 */ "unc_cha_llc_lookup.llcpref_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local LLC prefetch requests (from LLC) Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local LLC prefetch requests (from LLC) Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local LLC prefetch to the LLC\000"
/* offset=2927017 */ "unc_cha_llc_lookup.llcpref_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local LLC prefetch requests (from LLC). Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local LLC prefetch requests (from LLC) : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local LLC prefetch to the LLC\000"
/* offset=2927661 */ "unc_cha_llc_lookup.loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000"
/* offset=2928303 */ "unc_cha_llc_lookup.local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Local. Unit: uncore_cha \000event=0x34,umask=0x31\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000"
/* offset=2928894 */ "unc_cha_llc_lookup.local_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2929586 */ "unc_cha_llc_lookup.local_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2930271 */ "unc_cha_llc_lookup.local_dmnd_code\000uncore_cha\000uncore cache\000Cache Lookups : Demand CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1850ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2930975 */ "unc_cha_llc_lookup.local_dmnd_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Demand Data Reads that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1841ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2931665 */ "unc_cha_llc_lookup.local_dmnd_rfo\000uncore_cha\000uncore cache\000Cache Lookups : Demand RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1848ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2932368 */ "unc_cha_llc_lookup.local_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed locally Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000"
/* offset=2933011 */ "unc_cha_llc_lookup.local_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000"
/* offset=2933639 */ "unc_cha_llc_lookup.local_flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1844ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2934269 */ "unc_cha_llc_lookup.local_llc_pf\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Prefetch requests to the LLC that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2934964 */ "unc_cha_llc_lookup.local_pf\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x199dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2935647 */ "unc_cha_llc_lookup.local_pf_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1910ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2936344 */ "unc_cha_llc_lookup.local_pf_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1981ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2937035 */ "unc_cha_llc_lookup.local_pf_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1908ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2937731 */ "unc_cha_llc_lookup.local_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2938422 */ "unc_cha_llc_lookup.locally_homed_address\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000"
/* offset=2939078 */ "unc_cha_llc_lookup.locally_homed_address\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LOC_HOM. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00011\000\000"
/* offset=2939264 */ "unc_cha_llc_lookup.m\000uncore_cha\000uncore cache\000Cache Lookups : M State. Unit: uncore_cha \000event=0x34,umask=0x40\000\00001\000Cache Lookups : M State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Modified State\000"
/* offset=2939829 */ "unc_cha_llc_lookup.m\000uncore_cha\000uncore cache\000Cache Lookups : M State. Unit: uncore_cha \000event=0x34,umask=0x40\000\00001\000Cache Lookups : M State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Modified State\000"
/* offset=2940393 */ "unc_cha_llc_lookup.miss_all\000uncore_cha\000uncore cache\000Cache Lookups : All Misses. Unit: uncore_cha \000event=0x34,umask=0x1fe001\000\00001\000Cache Lookups : All Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2940953 */ "unc_cha_llc_lookup.miss_all\000uncore_cha\000uncore cache\000Cache Lookups : All Misses. Unit: uncore_cha \000event=0x34,umask=0x1fe001\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2941484 */ "unc_cha_llc_lookup.other_req_f\000uncore_cha\000uncore cache\000Cache Lookups : Write Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Write Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Writeback transactions to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2942152 */ "unc_cha_llc_lookup.other_req_f\000uncore_cha\000uncore cache\000Cache Lookups : Write Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2942815 */ "unc_cha_llc_lookup.pref_or_dmnd_remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote non-snoop request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote non-snoop request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Non-snoop transactions to the LLC from remote agent\000"
/* offset=2943470 */ "unc_cha_llc_lookup.pref_or_dmnd_remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote non-snoop requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote non-snoop requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Remote non-snoop transactions to the LLC\000"
/* offset=2944101 */ "unc_cha_llc_lookup.read\000uncore_cha\000uncore cache\000Cache Lookups : Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd9ff\000\00001\000Cache Lookups : Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2944647 */ "unc_cha_llc_lookup.read_local_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0x9d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2945288 */ "unc_cha_llc_lookup.read_local_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x11d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2945932 */ "unc_cha_llc_lookup.read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd901\000\00001\000Cache Lookups : Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2946495 */ "unc_cha_llc_lookup.read_miss_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0xbd901\000\00001\000Cache Lookups : Locally HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2947093 */ "unc_cha_llc_lookup.read_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0x13d901\000\00001\000Cache Lookups : Remotely HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2947694 */ "unc_cha_llc_lookup.read_or_snoop_remote_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x161901\000\00001\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2948385 */ "unc_cha_llc_lookup.read_remote_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0xa19ff\000\00001\000Cache Lookups : Remotely Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2949029 */ "unc_cha_llc_lookup.read_sf_hit\000uncore_cha\000uncore cache\000Cache Lookups : Reads that Hit the Snoop Filter. Unit: uncore_cha \000event=0x34,umask=0x1bd90e\000\00001\000Cache Lookups : Reads that Hit the Snoop Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2949634 */ "unc_cha_llc_lookup.rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000"
/* offset=2950278 */ "unc_cha_llc_lookup.remote\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Remote. Unit: uncore_cha \000event=0x34,umask=0x91\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000"
/* offset=2950871 */ "unc_cha_llc_lookup.remote_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000"
/* offset=2951544 */ "unc_cha_llc_lookup.remote_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a01ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000"
/* offset=2952211 */ "unc_cha_llc_lookup.remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed remotely Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000"
/* offset=2952856 */ "unc_cha_llc_lookup.remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000"
/* offset=2953486 */ "unc_cha_llc_lookup.remote_flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a04ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000"
/* offset=2954097 */ "unc_cha_llc_lookup.remote_other\000uncore_cha\000uncore cache\000Cache Lookups : Filters Requests for those that write info into the cache that come from a remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a02ff\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2954850 */ "unc_cha_llc_lookup.remote_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a08ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2955522 */ "unc_cha_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; External Snoop Request. Unit: uncore_cha \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000"
/* offset=2956219 */ "unc_cha_llc_lookup.remote_snoop_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote snoop request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote snoop request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Snoop transactions to the LLC from remote agent\000"
/* offset=2956855 */ "unc_cha_llc_lookup.remote_snoop_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote snoop requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote snoop requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Remote snoop transactions to the LLC\000"
/* offset=2957467 */ "unc_cha_llc_lookup.remote_snp\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Snoop Requests from a Remote Socket. Unit: uncore_cha \000event=0x34,umask=0x1c19ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000"
/* offset=2958217 */ "unc_cha_llc_lookup.remotely_homed_address\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000"
/* offset=2958876 */ "unc_cha_llc_lookup.remotely_homed_address\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REM_HOM. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00011\000\000"
/* offset=2959064 */ "unc_cha_llc_lookup.rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests. Unit: uncore_cha \000event=0x34,umask=0x1bc8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2959698 */ "unc_cha_llc_lookup.rfo_f\000uncore_cha\000uncore cache\000Cache Lookups : RFO Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : RFO Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2960332 */ "unc_cha_llc_lookup.rfo_f\000uncore_cha\000uncore cache\000Cache Lookups : RFO Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2960929 */ "unc_cha_llc_lookup.rfo_local\000uncore_cha\000uncore cache\000Cache Lookups : Locally HOMed RFOs - Demand and Prefetches. Unit: uncore_cha \000event=0x34,umask=0x9c8ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2961492 */ "unc_cha_llc_lookup.rfo_local\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2962183 */ "unc_cha_llc_lookup.rfo_miss\000uncore_cha\000uncore cache\000Cache Lookups : RFO Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc801\000\00001\000Cache Lookups : RFO Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2962743 */ "unc_cha_llc_lookup.rfo_pref_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.RFO_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x888ff\000\00011\000\000"
/* offset=2962924 */ "unc_cha_llc_lookup.rfo_remote\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a08ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000"
/* offset=2963596 */ "unc_cha_llc_lookup.s\000uncore_cha\000uncore cache\000Cache Lookups : S State. Unit: uncore_cha \000event=0x34,umask=0x10\000\00001\000Cache Lookups : S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Shared State\000"
/* offset=2964159 */ "unc_cha_llc_lookup.s\000uncore_cha\000uncore cache\000Cache Lookups : S State. Unit: uncore_cha \000event=0x34,umask=0x10\000\00001\000Cache Lookups : S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Shared State\000"
/* offset=2964721 */ "unc_cha_llc_lookup.sf_e\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - E State. Unit: uncore_cha \000event=0x34,umask=0x4\000\00001\000Cache Lookups : SnoopFilter - E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Exclusive State\000"
/* offset=2965320 */ "unc_cha_llc_lookup.sf_e\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - E State. Unit: uncore_cha \000event=0x34,umask=0x4\000\00001\000Cache Lookups : SnoopFilter - E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit Exclusive State\000"
/* offset=2965918 */ "unc_cha_llc_lookup.sf_h\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - H State. Unit: uncore_cha \000event=0x34,umask=0x8\000\00001\000Cache Lookups : SnoopFilter - H State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit HitMe State\000"
/* offset=2966513 */ "unc_cha_llc_lookup.sf_h\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - H State. Unit: uncore_cha \000event=0x34,umask=0x8\000\00001\000Cache Lookups : SnoopFilter - H State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit HitMe State\000"
/* offset=2967107 */ "unc_cha_llc_lookup.sf_s\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - S State. Unit: uncore_cha \000event=0x34,umask=0x2\000\00001\000Cache Lookups : SnoopFilter - S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Shared State\000"
/* offset=2967703 */ "unc_cha_llc_lookup.sf_s\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - S State. Unit: uncore_cha \000event=0x34,umask=0x2\000\00001\000Cache Lookups : SnoopFilter - S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit Shared State\000"
/* offset=2968298 */ "unc_cha_llc_lookup.write\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Write Requests. Unit: uncore_cha \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2969004 */ "unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000Cache Lookups : Writes. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Requests that install or change a line in the LLC.    Examples:  Writebacks from Core L2's and UPI.  Prefetches into the LLC\000"
/* offset=2969661 */ "unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITES_AND_OTHER. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00011\000\000"
/* offset=2969846 */ "unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00011\000\000"
/* offset=2969975 */ "unc_cha_llc_lookup.write_remote\000uncore_cha\000uncore cache\000Cache Lookups : Remote Writes. Unit: uncore_cha \000event=0x34,umask=0x17c2ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000"
/* offset=2970513 */ "unc_cha_llc_lookup.write_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITES_AND_OTHER. Unit: uncore_cha \000event=0x34,umask=0x17c2ff\000\00011\000\000"
/* offset=2970700 */ "unc_cha_llc_lookup.writes_and_other\000uncore_cha\000uncore cache\000Cache Lookups : Filters Requests for those that write info into the cache. Unit: uncore_cha \000event=0x34,umask=0x1a42ff\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000"
/* offset=2971426 */ "unc_cha_llc_victims.all\000uncore_cha\000uncore cache\000Lines Victimized : All Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0xf\000\00001\000Lines Victimized : All Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2971715 */ "unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Lines Victimized : Lines in E state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2972000 */ "unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000"
/* offset=2972170 */ "unc_cha_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000"
/* offset=2972340 */ "unc_cha_llc_victims.ia\000uncore_cha\000uncore cache\000Lines Victimized : IA traffic. Unit: uncore_cha \000event=0x37,umask=0x20\000\00001\000Lines Victimized : IA traffic : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2972609 */ "unc_cha_llc_victims.io\000uncore_cha\000uncore cache\000Lines Victimized : IO traffic. Unit: uncore_cha \000event=0x37,umask=0x10\000\00001\000Lines Victimized : IO traffic : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2972878 */ "unc_cha_llc_victims.io_e\000uncore_cha\000uncore cache\000All LLC lines in E state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x12\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2973160 */ "unc_cha_llc_victims.io_fs\000uncore_cha\000uncore cache\000All LLC lines in F or S state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x1c\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2973448 */ "unc_cha_llc_victims.io_m\000uncore_cha\000uncore cache\000All LLC lines in M state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x11\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2973730 */ "unc_cha_llc_victims.io_mesf\000uncore_cha\000uncore cache\000All LLC lines in any state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x1f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2974017 */ "unc_cha_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x37,umask=0x20\000\00011\000\000"
/* offset=2974138 */ "unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized : Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x200f\000\00001\000Lines Victimized : Local - All Lines : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2974430 */ "unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized; Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x200f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2974682 */ "unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized; Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2974932 */ "unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x2002\000\00001\000Lines Victimized : Local - Lines in E State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2975236 */ "unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2002\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2975486 */ "unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x22\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2975741 */ "unc_cha_llc_victims.local_f\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x28\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2975996 */ "unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x2001\000\00001\000Lines Victimized : Local - Lines in M State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2976300 */ "unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2001\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2976550 */ "unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x21\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2976805 */ "unc_cha_llc_victims.local_only\000uncore_cha\000uncore cache\000Lines Victimized : Local Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Local Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2977071 */ "unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x2004\000\00001\000Lines Victimized : Local - Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2977375 */ "unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2004\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2977625 */ "unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x24\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2977880 */ "unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Lines Victimized : Lines in M state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2978165 */ "unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000"
/* offset=2978335 */ "unc_cha_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000"
/* offset=2978508 */ "unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized : Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x800f\000\00001\000Lines Victimized : Remote - All Lines : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2978803 */ "unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized; Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x800f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2979057 */ "unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized; Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x8f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2979309 */ "unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x8002\000\00001\000Lines Victimized : Remote - Lines in E State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2979616 */ "unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8002\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2979867 */ "unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x82\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2980124 */ "unc_cha_llc_victims.remote_f\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x88\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2980381 */ "unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x8001\000\00001\000Lines Victimized : Remote - Lines in M State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2980688 */ "unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8001\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2980939 */ "unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x81\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2981196 */ "unc_cha_llc_victims.remote_only\000uncore_cha\000uncore cache\000Lines Victimized : Remote Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Remote Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2981465 */ "unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x8004\000\00001\000Lines Victimized : Remote - Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2981772 */ "unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8004\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2982023 */ "unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x84\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2982280 */ "unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Lines Victimized : Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2982565 */ "unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000"
/* offset=2982735 */ "unc_cha_llc_victims.total_e\000uncore_cha\000uncore cache\000All LLC lines in E state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2983001 */ "unc_cha_llc_victims.total_e\000uncore_cha\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2983247 */ "unc_cha_llc_victims.total_f\000uncore_cha\000uncore cache\000Lines Victimized; Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2983493 */ "unc_cha_llc_victims.total_m\000uncore_cha\000uncore cache\000All LLC lines in M state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2983759 */ "unc_cha_llc_victims.total_m\000uncore_cha\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2984005 */ "unc_cha_llc_victims.total_s\000uncore_cha\000uncore cache\000All LLC lines in S state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2984271 */ "unc_cha_llc_victims.total_s\000uncore_cha\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000"
/* offset=2984517 */ "unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Cbo Misc : CV0 Prefetch Miss : Miscellaneous events in the Cbo\000"
/* offset=2984705 */ "unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2984861 */ "unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Cbo Misc : CV0 Prefetch Victim : Miscellaneous events in the Cbo\000"
/* offset=2985052 */ "unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000"
/* offset=2985209 */ "unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000"
/* offset=2985457 */ "unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc : Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Cbo Misc : Silent Snoop Eviction : Miscellaneous events in the Cbo. : Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000"
/* offset=2985815 */ "unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000"
/* offset=2986136 */ "unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc : Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Cbo Misc : Write Combining Aliasing : Miscellaneous events in the Cbo. : Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000"
/* offset=2986519 */ "unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000"
/* offset=2986862 */ "unc_cha_misc_external.mbe_inst0\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_cha \000event=0xe6,umask=0x1\000\00001\000\000"
/* offset=2987048 */ "unc_cha_misc_external.mbe_inst1\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_cha \000event=0xe6,umask=0x2\000\00001\000\000"
/* offset=2987234 */ "unc_cha_osb.local_invitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local InvItoE. Unit: uncore_cha \000event=0x55,umask=0x1\000\00001\000OSB Snoop Broadcast : Local InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2987540 */ "unc_cha_osb.local_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local Rd. Unit: uncore_cha \000event=0x55,umask=0x2\000\00001\000OSB Snoop Broadcast : Local Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2987833 */ "unc_cha_osb.off_pwrheuristic\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Off. Unit: uncore_cha \000event=0x55,umask=0x20\000\00001\000OSB Snoop Broadcast : Off : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2988123 */ "unc_cha_osb.remote_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd. Unit: uncore_cha \000event=0x55,umask=0x4\000\00001\000OSB Snoop Broadcast : Remote Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2988419 */ "unc_cha_osb.remote_readinvitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd InvItoE. Unit: uncore_cha \000event=0x55,umask=0x8\000\00001\000OSB Snoop Broadcast : Remote Rd InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2988738 */ "unc_cha_osb.rfo_hits_snp_bcast\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast. Unit: uncore_cha \000event=0x55,umask=0x10\000\00001\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2989072 */ "unc_cha_osb\000uncore_cha\000uncore cache\000OSB Snoop Broadcast. Unit: uncore_cha \000event=0x55\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=2989300 */ "unc_cha_pipe_reject.adegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2989455 */ "unc_cha_pipe_reject.akegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2989610 */ "unc_cha_pipe_reject.allrsfways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2989768 */ "unc_cha_pipe_reject.blegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2989923 */ "unc_cha_pipe_reject.fsf_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990075 */ "unc_cha_pipe_reject.gotrack_allowsnp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x4\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990245 */ "unc_cha_pipe_reject.gotrack_allwayrsv\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x10\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990417 */ "unc_cha_pipe_reject.gotrack_pamatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x2\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990586 */ "unc_cha_pipe_reject.gotrack_waymatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x8\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990756 */ "unc_cha_pipe_reject.hacredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2990908 */ "unc_cha_pipe_reject.idx_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991062 */ "unc_cha_pipe_reject.ipq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991223 */ "unc_cha_pipe_reject.irq_pmm\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x20\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991385 */ "unc_cha_pipe_reject.irq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991546 */ "unc_cha_pipe_reject.ismq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991708 */ "unc_cha_pipe_reject.ivegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2991863 */ "unc_cha_pipe_reject.llc_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992019 */ "unc_cha_pipe_reject.notallowsnoop\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992176 */ "unc_cha_pipe_reject.one_fsf_vic\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992331 */ "unc_cha_pipe_reject.one_rsp_con\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992486 */ "unc_cha_pipe_reject.pmm_memmode_tor_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992651 */ "unc_cha_pipe_reject.pmm_memmode_tormatch_multi\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992821 */ "unc_cha_pipe_reject.prq_pmm\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x40\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2992983 */ "unc_cha_pipe_reject.ptl_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x80\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993148 */ "unc_cha_pipe_reject.rmw_setmatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x1\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993314 */ "unc_cha_pipe_reject.rrq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993475 */ "unc_cha_pipe_reject.setmatchentrywsct\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993636 */ "unc_cha_pipe_reject.sf_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993791 */ "unc_cha_pipe_reject.topa_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2993945 */ "unc_cha_pipe_reject.torid_match_go_p\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994105 */ "unc_cha_pipe_reject.vn_ad_req\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994258 */ "unc_cha_pipe_reject.vn_ad_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994411 */ "unc_cha_pipe_reject.vn_bl_ncb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994564 */ "unc_cha_pipe_reject.vn_bl_ncs\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994717 */ "unc_cha_pipe_reject.vn_bl_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2994870 */ "unc_cha_pipe_reject.vn_bl_wb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2995022 */ "unc_cha_pipe_reject.way_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000"
/* offset=2995175 */ "unc_cha_pmm_memmode_nm_invitox.local\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.LOCAL. Unit: uncore_cha \000event=0x65,umask=0x1\000\00001\000\000"
/* offset=2995318 */ "unc_cha_pmm_memmode_nm_invitox.remote\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.REMOTE. Unit: uncore_cha \000event=0x65,umask=0x2\000\00001\000\000"
/* offset=2995463 */ "unc_cha_pmm_memmode_nm_invitox.setconflict\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.SETCONFLICT. Unit: uncore_cha \000event=0x65,umask=0x4\000\00001\000\000"
/* offset=2995618 */ "unc_cha_pmm_memmode_nm_setconflicts.iodc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in IODC. Unit: uncore_cha \000event=0x64,umask=0x10\000\00001\0002LM related events; Counts the number of times CHA saw NM Set conflict in IODC\000"
/* offset=2995894 */ "unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000NM evictions due to another read to the same near memory set in the LLC\000"
/* offset=2996163 */ "unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near Memory set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000Near Memory evictions due to another read to the same Near Memory set in the LLC\000"
/* offset=2996452 */ "unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC : NM evictions due to another read to the same near memory set in the LLC\000"
/* offset=2996822 */ "unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000NM evictions due to another read to the same near memory set in the SF\000"
/* offset=2997089 */ "unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near memory set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000Near Memory evictions due to another read to the same Near Memory set in the SF\000"
/* offset=2997376 */ "unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC : NM evictions due to another read to the same near memory set in the SF\000"
/* offset=2997744 */ "unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000No Reject in the CHA due to a pending read to the same near memory set in the TOR\000"
/* offset=2998020 */ "unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near Memory set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000No Reject in the CHA due to a pending read to the same Near Memory set in the TOR\000"
/* offset=2998307 */ "unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in TOR : No Reject in the CHA due to a pending read to the same near memory set in the TOR\000"
/* offset=2998681 */ "unc_cha_pmm_memmode_nm_setconflicts.tor_reject\000uncore_cha\000uncore cache\000Memory mode related events; Counts the number of times CHA saw NM Set conflict in TOR and the transaction was rejected. Unit: uncore_cha \000event=0x64,umask=0x8\000\00001\000Rejects in the CHA due to a pending read to the same near memory set in the TOR\000"
/* offset=2998995 */ "unc_cha_pmm_memmode_nm_setconflicts2.iodc\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.IODC. Unit: uncore_cha \000event=0x70,umask=0x1\000\00001\000\000"
/* offset=2999148 */ "unc_cha_pmm_memmode_nm_setconflicts2.memwr\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWR. Unit: uncore_cha \000event=0x70,umask=0x2\000\00001\000\000"
/* offset=2999303 */ "unc_cha_pmm_memmode_nm_setconflicts2.memwrni\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWRNI. Unit: uncore_cha \000event=0x70,umask=0x4\000\00001\000\000"
/* offset=2999462 */ "unc_cha_pmm_qos.ddr4_fast_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.DDR4_FAST_INSERT. Unit: uncore_cha \000event=0x66,umask=0x2\000\00001\000\000"
/* offset=2999597 */ "unc_cha_pmm_qos.rej_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.REJ_IRQ. Unit: uncore_cha \000event=0x66,umask=0x8\000\00001\000\000"
/* offset=2999714 */ "unc_cha_pmm_qos.slow_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOW_INSERT. Unit: uncore_cha \000event=0x66,umask=0x1\000\00001\000\000"
/* offset=2999839 */ "unc_cha_pmm_qos.slowtorq_skip\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOWTORQ_SKIP. Unit: uncore_cha \000event=0x66,umask=0x40\000\00001\000\000"
/* offset=2999969 */ "unc_cha_pmm_qos.throttle\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE. Unit: uncore_cha \000event=0x66,umask=0x4\000\00001\000\000"
/* offset=3000088 */ "unc_cha_pmm_qos.throttle_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_IRQ. Unit: uncore_cha \000event=0x66,umask=0x20\000\00001\000\000"
/* offset=3000216 */ "unc_cha_pmm_qos.throttle_prq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_PRQ. Unit: uncore_cha \000event=0x66,umask=0x10\000\00001\000\000"
/* offset=3000344 */ "unc_cha_pmm_qos_occupancy.ddr_fast_fifo\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS_OCCUPANCY.DDR_FAST_FIFO. Unit: uncore_cha \000event=0x67,umask=0x2\000\00001\000: count # of FAST TOR Request inserted to ha_tor_req_fifo\000"
/* offset=3000550 */ "unc_cha_pmm_qos_occupancy.ddr_slow_fifo\000uncore_cha\000uncore cache\000Number of SLOW TOR Request inserted to ha_pmm_tor_req_fifo. Unit: uncore_cha \000event=0x67,umask=0x1\000\00001\000\000"
/* offset=3000718 */ "unc_cha_pmm_qos_occupancy.ddr_slow_fifo\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS_OCCUPANCY.DDR_SLOW_FIFO. Unit: uncore_cha \000event=0x67,umask=0x1\000\00001\000: count # of SLOW TOR Request inserted to ha_pmm_tor_req_fifo\000"
/* offset=3000928 */ "unc_cha_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 2 only\000"
/* offset=3001337 */ "unc_cha_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 3 only\000"
/* offset=3001746 */ "unc_cha_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 4 only\000"
/* offset=3002156 */ "unc_cha_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 5 only\000"
/* offset=3002566 */ "unc_cha_read_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000CHA iMC CHNx READ Credits Empty : MC0 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 0 only\000"
/* offset=3003005 */ "unc_cha_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 0 only\000"
/* offset=3003412 */ "unc_cha_read_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC10. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC10 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 10 only\000"
/* offset=3003845 */ "unc_cha_read_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC11. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC11 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 11 only\000"
/* offset=3004278 */ "unc_cha_read_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC12. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC12 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 12 only\000"
/* offset=3004711 */ "unc_cha_read_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC13. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC13 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 13 only\000"
/* offset=3005144 */ "unc_cha_read_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000CHA iMC CHNx READ Credits Empty : MC1 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 1 only\000"
/* offset=3005583 */ "unc_cha_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 1 only\000"
/* offset=3005990 */ "unc_cha_read_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000CHA iMC CHNx READ Credits Empty : MC2 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 2 only\000"
/* offset=3006429 */ "unc_cha_read_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000CHA iMC CHNx READ Credits Empty : MC3 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 3 only\000"
/* offset=3006868 */ "unc_cha_read_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000CHA iMC CHNx READ Credits Empty : MC4 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 4 only\000"
/* offset=3007308 */ "unc_cha_read_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000CHA iMC CHNx READ Credits Empty : MC5 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 5 only\000"
/* offset=3007748 */ "unc_cha_read_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC6. Unit: uncore_cha \000event=0x58,umask=0x40\000\00001\000CHA iMC CHNx READ Credits Empty : MC6 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 6 only\000"
/* offset=3008188 */ "unc_cha_read_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC7. Unit: uncore_cha \000event=0x58,umask=0x80\000\00001\000CHA iMC CHNx READ Credits Empty : MC7 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 7 only\000"
/* offset=3008628 */ "unc_cha_read_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC8. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC8 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 8 only\000"
/* offset=3009057 */ "unc_cha_read_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC9. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC9 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 9 only\000"
/* offset=3009486 */ "unc_cha_requests.invitoe\000uncore_cha\000uncore cache\000Local INVITOE requests (exclusive ownership of a cache line without receiving data) that miss the SF/LLC and remote INVITOE requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x30\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3009896 */ "unc_cha_requests.invitoe\000uncore_cha\000uncore cache\000Requests for exclusive ownership of a cache line without receiving data. Unit: uncore_cha \000event=0x50,umask=0x30\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3010216 */ "unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local INVITOE requests (exclusive ownership of a cache line without receiving data) that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3010612 */ "unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3010945 */ "unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line without receiving data. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3011272 */ "unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Remote INVITOE requests (exclusive ownership of a cache line without receiving data) sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3011635 */ "unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Remote requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000"
/* offset=3011964 */ "unc_cha_requests.reads\000uncore_cha\000uncore cache\000Local read requests that miss the SF/LLC and remote read requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000"
/* offset=3012286 */ "unc_cha_requests.reads\000uncore_cha\000uncore cache\000Read requests made into the CHA. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000"
/* offset=3012545 */ "unc_cha_requests.reads\000uncore_cha\000uncore cache\000Read requests. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000"
/* offset=3012786 */ "unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Local read requests that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000"
/* offset=3013130 */ "unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Read requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000"
/* offset=3013437 */ "unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Read requests from a remote socket. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000"
/* offset=3013732 */ "unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Remote read requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000"
/* offset=3014042 */ "unc_cha_requests.writes\000uncore_cha\000uncore cache\000Local write requests that miss the SF/LLC and remote write requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000"
/* offset=3014364 */ "unc_cha_requests.writes\000uncore_cha\000uncore cache\000Write requests made into the CHA. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000"
/* offset=3014622 */ "unc_cha_requests.writes\000uncore_cha\000uncore cache\000Write requests. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000"
/* offset=3014862 */ "unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Local write requests that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000"
/* offset=3015208 */ "unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Write Requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000"
/* offset=3015517 */ "unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Read and Write Requests; Writes Remote. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000"
/* offset=3015831 */ "unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Remote write requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000"
/* offset=3016157 */ "unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3016450 */ "unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3016689 */ "unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_cha \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3016982 */ "unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3017221 */ "unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3017514 */ "unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3017753 */ "unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_cha \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3018046 */ "unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=3018285 */ "unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3018572 */ "unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3018807 */ "unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3019138 */ "unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3019395 */ "unc_cha_ring_bounces_vert.akc\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. Unit: uncore_cha \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3019673 */ "unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3020000 */ "unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3020255 */ "unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3020593 */ "unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=3020853 */ "unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000\000"
/* offset=3020996 */ "unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000\000"
/* offset=3021138 */ "unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_cha \000event=0xad,umask=0x2\000\00001\000\000"
/* offset=3021281 */ "unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000\000"
/* offset=3021423 */ "unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xad,umask=0x20\000\00001\000\000"
/* offset=3021596 */ "unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00001\000\000"
/* offset=3021768 */ "unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000\000"
/* offset=3021911 */ "unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000\000"
/* offset=3022053 */ "unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_cha \000event=0xad,umask=0x8\000\00001\000\000"
/* offset=3022196 */ "unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000\000"
/* offset=3022338 */ "unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : AD. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000\000"
/* offset=3022479 */ "unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000\000"
/* offset=3022619 */ "unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000\000"
/* offset=3022782 */ "unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000\000"
/* offset=3022944 */ "unc_cha_ring_sink_starved_vert.akc\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring. Unit: uncore_cha \000event=0xab,umask=0x10\000\00001\000\000"
/* offset=3023082 */ "unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000\000"
/* offset=3023243 */ "unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000\000"
/* offset=3023403 */ "unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000\000"
/* offset=3023569 */ "unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000\000"
/* offset=3023734 */ "unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xa4\000\00001\000\000"
/* offset=3023832 */ "unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xae\000\00001\000\000"
/* offset=3023930 */ "unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Ingress (from CMS) Allocations : IPQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3024170 */ "unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3024370 */ "unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Ingress (from CMS) Allocations : IRQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3024610 */ "unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3024810 */ "unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Ingress (from CMS) Allocations : IRQ Rejected : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3025072 */ "unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3025285 */ "unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3025526 */ "unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3025727 */ "unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3025972 */ "unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3026177 */ "unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Ingress (from CMS) Allocations : RRQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3026418 */ "unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3026619 */ "unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Ingress (from CMS) Allocations : WBQ : Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3026860 */ "unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000"
/* offset=3027061 */ "unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000"
/* offset=3027322 */ "unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000\000"
/* offset=3027469 */ "unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000"
/* offset=3027731 */ "unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000\000"
/* offset=3027878 */ "unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000"
/* offset=3028137 */ "unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000\000"
/* offset=3028290 */ "unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000"
/* offset=3028535 */ "unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000\000"
/* offset=3028683 */ "unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000"
/* offset=3028928 */ "unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000\000"
/* offset=3029076 */ "unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000"
/* offset=3029338 */ "unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000\000"
/* offset=3029485 */ "unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000"
/* offset=3029745 */ "unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000\000"
/* offset=3029890 */ "unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000"
/* offset=3030149 */ "unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000\000"
/* offset=3030302 */ "unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000"
/* offset=3030461 */ "unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000"
/* offset=3030606 */ "unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IPQ0 Reject counter was true\000"
/* offset=3030858 */ "unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000\000"
/* offset=3030990 */ "unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000"
/* offset=3031132 */ "unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000"
/* offset=3031260 */ "unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000"
/* offset=3031540 */ "unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000\000"
/* offset=3031735 */ "unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000"
/* offset=3031893 */ "unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000"
/* offset=3032037 */ "unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000"
/* offset=3032315 */ "unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000\000"
/* offset=3032461 */ "unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000"
/* offset=3032717 */ "unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000\000"
/* offset=3032859 */ "unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000"
/* offset=3033010 */ "unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000"
/* offset=3033147 */ "unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000"
/* offset=3033408 */ "unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=3033568 */ "unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000"
/* offset=3033830 */ "unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=3033990 */ "unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000"
/* offset=3034249 */ "unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000\000"
/* offset=3034415 */ "unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000"
/* offset=3034660 */ "unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000\000"
/* offset=3034821 */ "unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000"
/* offset=3035066 */ "unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000\000"
/* offset=3035227 */ "unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000"
/* offset=3035489 */ "unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000\000"
/* offset=3035649 */ "unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000"
/* offset=3035909 */ "unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000\000"
/* offset=3036067 */ "unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000"
/* offset=3036326 */ "unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000\000"
/* offset=3036492 */ "unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000"
/* offset=3036651 */ "unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000"
/* offset=3036809 */ "unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IRQ0 Reject counter was true\000"
/* offset=3037061 */ "unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000\000"
/* offset=3037206 */ "unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000"
/* offset=3037348 */ "unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000"
/* offset=3037489 */ "unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way : Way conflict with another request that caused the reject\000"
/* offset=3037769 */ "unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000\000"
/* offset=3037977 */ "unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000"
/* offset=3038135 */ "unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000"
/* offset=3038292 */ "unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000"
/* offset=3038451 */ "unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000"
/* offset=3038707 */ "unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000\000"
/* offset=3038862 */ "unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000"
/* offset=3039013 */ "unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000"
/* offset=3039163 */ "unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000ISMQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000"
/* offset=3039644 */ "unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3040032 */ "unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000ISMQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000"
/* offset=3040514 */ "unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3040902 */ "unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000ISMQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000"
/* offset=3041381 */ "unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3041775 */ "unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000ISMQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000"
/* offset=3042240 */ "unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3042629 */ "unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000ISMQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000"
/* offset=3043094 */ "unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3043483 */ "unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000ISMQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000"
/* offset=3043965 */ "unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3044353 */ "unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000ISMQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000"
/* offset=3044833 */ "unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3045219 */ "unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000ISMQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000"
/* offset=3045698 */ "unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3046092 */ "unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000ISMQ Retries - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000"
/* offset=3046572 */ "unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3046959 */ "unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000ISMQ Retries - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000"
/* offset=3047440 */ "unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3047827 */ "unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000ISMQ Retries - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000"
/* offset=3048305 */ "unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3048698 */ "unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000ISMQ Retries - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000"
/* offset=3049162 */ "unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3049550 */ "unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000ISMQ Retries - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000"
/* offset=3050014 */ "unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3050402 */ "unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000ISMQ Retries - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000"
/* offset=3050883 */ "unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3051270 */ "unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000ISMQ Retries - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000"
/* offset=3051749 */ "unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3052134 */ "unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000ISMQ Retries - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000"
/* offset=3052612 */ "unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3053005 */ "unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000ISMQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000"
/* offset=3053478 */ "unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects; ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3053851 */ "unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000ISMQ Rejects - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3054257 */ "unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects; HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3054626 */ "unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000ISMQ Retries - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000"
/* offset=3055098 */ "unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries; ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3055470 */ "unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000ISMQ Retries - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3055875 */ "unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries; HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000"
/* offset=3056243 */ "unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Occupancy : IPQ : Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3056479 */ "unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3056677 */ "unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Occupancy : IRQ : Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3056913 */ "unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3057111 */ "unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Occupancy : RRQ : Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3057348 */ "unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3057547 */ "unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Occupancy : WBQ : Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3057784 */ "unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000"
/* offset=3057983 */ "unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Other Retries - Set 0 : AD REQ on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a request\000"
/* offset=3058333 */ "unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3058590 */ "unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Other Retries - Set 0 : AD RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a response\000"
/* offset=3058941 */ "unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3059198 */ "unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Other Retries - Set 0 : Non UPI AK Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject AK ring message\000"
/* offset=3059546 */ "unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3059809 */ "unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Other Retries - Set 0 : BL NCB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCB\000"
/* offset=3060143 */ "unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3060401 */ "unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Other Retries - Set 0 : BL NCS on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCS\000"
/* offset=3060735 */ "unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3060993 */ "unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Other Retries - Set 0 : BL RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a response\000"
/* offset=3061344 */ "unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3061601 */ "unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Other Retries - Set 0 : BL WB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a writeback\000"
/* offset=3061950 */ "unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3062205 */ "unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Other Retries - Set 0 : Non UPI IV Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject IV ring message\000"
/* offset=3062553 */ "unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3062816 */ "unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Other Retries - Set 1 : Allow Snoop : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3063118 */ "unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries; Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3063373 */ "unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Other Retries - Set 1 : ANY0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Any condition listed in the Other0 Reject counter was true\000"
/* offset=3063716 */ "unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries; ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3063958 */ "unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Other Retries - Set 1 : HA : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3064234 */ "unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries; HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3064472 */ "unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Other Retries - Set 1 : LLC OR SF Way : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Way conflict with another request that caused the reject\000"
/* offset=3064841 */ "unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3065146 */ "unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Other Retries - Set 1 : LLC Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3065446 */ "unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries; LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3065700 */ "unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Other Retries - Set 1 : PhyAddr Match : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Address match with an outstanding request that was rejected\000"
/* offset=3066067 */ "unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3066323 */ "unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Other Retries - Set 1 : SF Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Requests did not generate Snoop filter victim\000"
/* offset=3066668 */ "unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries; SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3066920 */ "unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Other Retries - Set 1 : Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3067209 */ "unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries; Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000"
/* offset=3067456 */ "unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000\000"
/* offset=3067616 */ "unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000"
/* offset=3067877 */ "unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000\000"
/* offset=3068037 */ "unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000"
/* offset=3068299 */ "unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000\000"
/* offset=3068465 */ "unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000"
/* offset=3068724 */ "unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000\000"
/* offset=3068885 */ "unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000"
/* offset=3069130 */ "unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000\000"
/* offset=3069291 */ "unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000"
/* offset=3069536 */ "unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000\000"
/* offset=3069696 */ "unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000"
/* offset=3069958 */ "unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000\000"
/* offset=3070116 */ "unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000"
/* offset=3070376 */ "unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000\000"
/* offset=3070542 */ "unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000"
/* offset=3070801 */ "unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000"
/* offset=3070959 */ "unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000"
/* offset=3071118 */ "unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000\000"
/* offset=3071263 */ "unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the PRQ0 Reject counter was true\000"
/* offset=3071515 */ "unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000"
/* offset=3071656 */ "unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000"
/* offset=3071798 */ "unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000\000"
/* offset=3071962 */ "unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000"
/* offset=3072242 */ "unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000"
/* offset=3072399 */ "unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000"
/* offset=3072557 */ "unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000\000"
/* offset=3072716 */ "unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000"
/* offset=3072994 */ "unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000\000"
/* offset=3073149 */ "unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000"
/* offset=3073405 */ "unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000"
/* offset=3073555 */ "unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000"
/* offset=3073706 */ "unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000Request Queue Retries - Set 0 : AD REQ on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a request\000"
/* offset=3074021 */ "unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3074235 */ "unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000Request Queue Retries - Set 0 : AD RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a response\000"
/* offset=3074551 */ "unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3074765 */ "unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000Request Queue Retries - Set 0 : Non UPI AK Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject AK ring message\000"
/* offset=3075078 */ "unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3075298 */ "unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000Request Queue Retries - Set 0 : BL NCB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCB\000"
/* offset=3075597 */ "unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3075812 */ "unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000Request Queue Retries - Set 0 : BL NCS on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCS\000"
/* offset=3076111 */ "unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3076326 */ "unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000Request Queue Retries - Set 0 : BL RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a response\000"
/* offset=3076642 */ "unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3076856 */ "unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000Request Queue Retries - Set 0 : BL WB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a writeback\000"
/* offset=3077170 */ "unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3077382 */ "unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000Request Queue Retries - Set 0 : Non UPI IV Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject IV ring message\000"
/* offset=3077695 */ "unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3077915 */ "unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000Request Queue Retries - Set 1 : Allow Snoop : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3078182 */ "unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries; Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3078394 */ "unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000Request Queue Retries - Set 1 : ANY0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Any condition listed in the WBQ0 Reject counter was true\000"
/* offset=3078700 */ "unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries; ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3078899 */ "unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000Request Queue Retries - Set 1 : HA : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3079140 */ "unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries; HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3079335 */ "unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000Request Queue Retries - Set 1 : LLC OR SF Way : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Way conflict with another request that caused the reject\000"
/* offset=3079669 */ "unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3079931 */ "unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000Request Queue Retries - Set 1 : LLC Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3080196 */ "unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries; LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3080407 */ "unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000Request Queue Retries - Set 1 : PhyAddr Match : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Address match with an outstanding request that was rejected\000"
/* offset=3080739 */ "unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3080952 */ "unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000Request Queue Retries - Set 1 : SF Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Requests did not generate Snoop filter victim\000"
/* offset=3081262 */ "unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries; SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3081471 */ "unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000Request Queue Retries - Set 1 : Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3081725 */ "unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries; Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000"
/* offset=3081929 */ "unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000RRQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a request\000"
/* offset=3082242 */ "unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3082463 */ "unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000RRQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a response\000"
/* offset=3082777 */ "unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3082998 */ "unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000RRQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject AK ring message\000"
/* offset=3083309 */ "unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3083536 */ "unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000RRQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCB\000"
/* offset=3083833 */ "unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3084055 */ "unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000RRQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCS\000"
/* offset=3084352 */ "unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3084574 */ "unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000RRQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a response\000"
/* offset=3084888 */ "unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3085109 */ "unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000RRQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a writeback\000"
/* offset=3085421 */ "unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3085640 */ "unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000RRQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject IV ring message\000"
/* offset=3085951 */ "unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3086178 */ "unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000RRQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3086442 */ "unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3086661 */ "unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000RRQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Any condition listed in the RRQ0 Reject counter was true\000"
/* offset=3086965 */ "unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects; ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3087171 */ "unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000RRQ Rejects - Set 1 : HA : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3087409 */ "unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects; HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3087611 */ "unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000RRQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Way conflict with another request that caused the reject\000"
/* offset=3087943 */ "unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3088212 */ "unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000RRQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3088474 */ "unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3088692 */ "unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000RRQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Address match with an outstanding request that was rejected\000"
/* offset=3089022 */ "unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3089242 */ "unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000RRQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Requests did not generate Snoop filter victim\000"
/* offset=3089550 */ "unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects; SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3089766 */ "unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000RRQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3090017 */ "unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects; Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000"
/* offset=3090228 */ "unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000WBQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a request\000"
/* offset=3090535 */ "unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3090750 */ "unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000WBQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a response\000"
/* offset=3091058 */ "unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3091273 */ "unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000WBQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject AK ring message\000"
/* offset=3091578 */ "unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3091799 */ "unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000WBQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCB\000"
/* offset=3092090 */ "unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3092306 */ "unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000WBQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCS\000"
/* offset=3092597 */ "unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3092813 */ "unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000WBQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a response\000"
/* offset=3093121 */ "unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3093336 */ "unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000WBQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a writeback\000"
/* offset=3093642 */ "unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3093855 */ "unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000WBQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject IV ring message\000"
/* offset=3094160 */ "unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3094381 */ "unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000WBQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3094639 */ "unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3094852 */ "unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000WBQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Any condition listed in the WBQ0 Reject counter was true\000"
/* offset=3095150 */ "unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects; ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3095350 */ "unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000WBQ Rejects - Set 1 : HA : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3095582 */ "unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects; HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3095778 */ "unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000WBQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Way conflict with another request that caused the reject\000"
/* offset=3096104 */ "unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3096367 */ "unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000WBQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3096623 */ "unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3096835 */ "unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000WBQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Address match with an outstanding request that was rejected\000"
/* offset=3097159 */ "unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3097373 */ "unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000WBQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Requests did not generate Snoop filter victim\000"
/* offset=3097675 */ "unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects; SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3097885 */ "unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000WBQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3098130 */ "unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects; Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000"
/* offset=3098335 */ "unc_cha_rxr_busy_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=3098794 */ "unc_cha_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3099178 */ "unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3099616 */ "unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3100001 */ "unc_cha_rxr_busy_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3100444 */ "unc_cha_rxr_busy_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=3100903 */ "unc_cha_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3101287 */ "unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3101725 */ "unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3102110 */ "unc_cha_rxr_busy_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=3102553 */ "unc_cha_rxr_bypass.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - All. Unit: uncore_cha \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=3102799 */ "unc_cha_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3102976 */ "unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_cha \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=3103201 */ "unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3103379 */ "unc_cha_rxr_bypass.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=3103609 */ "unc_cha_rxr_bypass.ak\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AK. Unit: uncore_cha \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000"
/* offset=3103807 */ "unc_cha_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3103984 */ "unc_cha_rxr_bypass.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=3104218 */ "unc_cha_rxr_bypass.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - All. Unit: uncore_cha \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=3104464 */ "unc_cha_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3104641 */ "unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_cha \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=3104866 */ "unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3105044 */ "unc_cha_rxr_bypass.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=3105274 */ "unc_cha_rxr_bypass.iv\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : IV. Unit: uncore_cha \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000"
/* offset=3105472 */ "unc_cha_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=3105649 */ "unc_cha_rxr_crd_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=3106120 */ "unc_cha_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3106515 */ "unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3106964 */ "unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3107360 */ "unc_cha_rxr_crd_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3107814 */ "unc_cha_rxr_crd_starved.ak\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AK. Unit: uncore_cha \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3108236 */ "unc_cha_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3108631 */ "unc_cha_rxr_crd_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=3109102 */ "unc_cha_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3109497 */ "unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3109946 */ "unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3110342 */ "unc_cha_rxr_crd_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3110796 */ "unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_cha \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3111244 */ "unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3111638 */ "unc_cha_rxr_crd_starved.iv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IV. Unit: uncore_cha \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3112060 */ "unc_cha_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3112455 */ "unc_cha_rxr_crd_starved_1\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Unit: uncore_cha \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=3112856 */ "unc_cha_rxr_inserts.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - All. Unit: uncore_cha \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=3113177 */ "unc_cha_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3113424 */ "unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_cha \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3113724 */ "unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3113972 */ "unc_cha_rxr_inserts.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3114277 */ "unc_cha_rxr_inserts.ak\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AK. Unit: uncore_cha \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3114550 */ "unc_cha_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3114797 */ "unc_cha_rxr_inserts.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3115106 */ "unc_cha_rxr_inserts.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - All. Unit: uncore_cha \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=3115427 */ "unc_cha_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3115674 */ "unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_cha \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3115974 */ "unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3116222 */ "unc_cha_rxr_inserts.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3116527 */ "unc_cha_rxr_inserts.iv\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : IV. Unit: uncore_cha \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3116800 */ "unc_cha_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3117047 */ "unc_cha_rxr_occupancy.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - All. Unit: uncore_cha \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=3117374 */ "unc_cha_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3117629 */ "unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3117935 */ "unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3118191 */ "unc_cha_rxr_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3118502 */ "unc_cha_rxr_occupancy.ak\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AK. Unit: uncore_cha \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3118781 */ "unc_cha_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3119036 */ "unc_cha_rxr_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3119351 */ "unc_cha_rxr_occupancy.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - All. Unit: uncore_cha \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=3119678 */ "unc_cha_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3119933 */ "unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3120239 */ "unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3120495 */ "unc_cha_rxr_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3120806 */ "unc_cha_rxr_occupancy.iv\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : IV. Unit: uncore_cha \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3121085 */ "unc_cha_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=3121340 */ "unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3121811 */ "unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3122286 */ "unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3122756 */ "unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3123230 */ "unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3123698 */ "unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000"
/* offset=3124170 */ "unc_cha_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000Rsp*Fwd*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Counts when a transaction with the opcode type Rsp*Fwd*WB Snoop Response was received which indicates the data was written back to its home socket, and the cacheline was forwarded to the requestor socket.  This snoop response is only used in >= 4 socket systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to its home socket to be written back to memory\000"
/* offset=3124752 */ "unc_cha_snoop_resp.rsp_wbwb\000uncore_cha\000uncore cache\000Rsp*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Counts when a transaction with the opcode type Rsp*WB Snoop Response was received which indicates which indicates the data was written back to its home.  This is returned when a non-RFO request hits a cacheline in the Modified state. The Cache can either downgrade the cacheline to a S (Shared) or I (Invalid) state depending on how the system has been configured.  This response will also be sent when a cache requests E (Exclusive) ownership of a cache line without receiving data, because the cache must acquire ownership\000"
/* offset=3125406 */ "unc_cha_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received : RSPCNFLCT*. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Snoop Responses Received : RSPCNFLCT* : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000"
/* offset=3126267 */ "unc_cha_snoop_resp.rspcnflcts\000uncore_cha\000uncore cache\000RspCnflct* Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Counts when a a transaction with the opcode type RspCnflct* Snoop Response was received. This is returned when a snoop finds an existing outstanding transaction in a remote caching agent. This triggers conflict resolution hardware. This covers both the opcode RspCnflct and RspCnflctWbI\000"
/* offset=3126689 */ "unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Snoop Responses Received : RspFwd : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000"
/* offset=3127517 */ "unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received; RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000"
/* offset=3128307 */ "unc_cha_snoop_resp.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*Fwd*WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Snoop Responses Received : Rsp*Fwd*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3129170 */ "unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000RspI Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000"
/* offset=3129566 */ "unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received : RspI. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000"
/* offset=3129964 */ "unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000RspIFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000"
/* offset=3130529 */ "unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspIFwd. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000"
/* offset=3131096 */ "unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000RspS Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Counts when a transaction with the opcode type RspS Snoop Response was received which indicates when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3131490 */ "unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received : RspS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Counts when a transaction with the opcode type RspS Snoop Response was received which indicates when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3131886 */ "unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received : RspS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Snoop Responses Received : RspS : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3132693 */ "unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000RspSFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000"
/* offset=3133103 */ "unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspSFwd. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000"
/* offset=3133515 */ "unc_cha_snoop_resp.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*WB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Snoop Responses Received : Rsp*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000"
/* offset=3134392 */ "unc_cha_snoop_resp_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3134888 */ "unc_cha_snoop_resp_local.rsp_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000"
/* offset=3135401 */ "unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Snoop Responses Received Local : RspCnflct : Number of snoop responses received for a Local  request : Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000"
/* offset=3135939 */ "unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000"
/* offset=3136430 */ "unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Snoop Responses Received Local : RspFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000"
/* offset=3136921 */ "unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000"
/* offset=3137368 */ "unc_cha_snoop_resp_local.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Snoop Responses Received Local : Rsp*FWD*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3137910 */ "unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Snoop Responses Received Local : RspI : Number of snoop responses received for a Local  request : Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000"
/* offset=3138358 */ "unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000"
/* offset=3138764 */ "unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Snoop Responses Received Local : RspIFwd : Number of snoop responses received for a Local  request : Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000"
/* offset=3139285 */ "unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000"
/* offset=3139761 */ "unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Snoop Responses Received Local : RspS : Number of snoop responses received for a Local  request : Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3140247 */ "unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3140691 */ "unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Snoop Responses Received Local : RspSFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3141174 */ "unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Snoop Responses Received Local : RspSFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3141659 */ "unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3142097 */ "unc_cha_snoop_resp_local.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Snoop Responses Received Local : Rsp*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000"
/* offset=3142653 */ "unc_cha_snoop_rsp_misc.mtoi_rspdatam\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIDataM. Unit: uncore_cha \000event=0x6b,umask=0x2\000\00001\000\000"
/* offset=3142806 */ "unc_cha_snoop_rsp_misc.mtoi_rspifwdm\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIFwdM. Unit: uncore_cha \000event=0x6b,umask=0x1\000\00001\000\000"
/* offset=3142958 */ "unc_cha_snoop_rsp_misc.pulldataptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x20\000\00001\000\000"
/* offset=3143130 */ "unc_cha_snoop_rsp_misc.pulldataptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x10\000\00001\000\000"
/* offset=3143300 */ "unc_cha_snoop_rsp_misc.rspifwdmptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x8\000\00001\000\000"
/* offset=3143462 */ "unc_cha_snoop_rsp_misc.rspifwdmptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x4\000\00001\000\000"
/* offset=3143622 */ "unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent : All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Snoops Sent : All : Counts the number of snoops issued by the HA\000"
/* offset=3143797 */ "unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent; All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Counts the number of snoops issued by the HA\000"
/* offset=3143951 */ "unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoop for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Snoops Sent : Broadcast snoop for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA. This filter includes only requests coming from local sockets\000"
/* offset=3144316 */ "unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Snoops Sent : Broadcast snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA responding to local requests\000"
/* offset=3144650 */ "unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoop for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA. This filter includes only requests coming from local sockets\000"
/* offset=3144962 */ "unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Snoops Sent : Broadcast snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA responding to remote requests\000"
/* offset=3145300 */ "unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Snoops Sent : Broadcast snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA.This filter includes only requests coming from remote sockets\000"
/* offset=3145670 */ "unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA.This filter includes only requests coming from remote sockets\000"
/* offset=3145985 */ "unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Snoops Sent : Directed snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA responding to local requests\000"
/* offset=3146318 */ "unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Snoops Sent : Directed snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA. This filter includes only requests coming from local sockets\000"
/* offset=3146684 */ "unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from local sockets\000"
/* offset=3146997 */ "unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Snoops Sent : Directed snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA responding to remote requests\000"
/* offset=3147334 */ "unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Snoops Sent : Directed snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA. This filter includes only requests coming from remote sockets\000"
/* offset=3147704 */ "unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from remote sockets\000"
/* offset=3148020 */ "unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast or directed Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Snoops Sent : Broadcast or directed Snoops sent for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the local socket\000"
/* offset=3148442 */ "unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent : Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Snoops Sent : Snoops sent for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA responding to local requests\000"
/* offset=3148772 */ "unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the local socket\000"
/* offset=3149123 */ "unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast or directed Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Snoops Sent : Broadcast or directed Snoops sent for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the remote socket\000"
/* offset=3149549 */ "unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent : Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Snoops Sent : Snoops sent for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA responding to remote requests\000"
/* offset=3149883 */ "unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the remote socket\000"
/* offset=3150237 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3150588 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3150939 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3151290 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3151641 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3151993 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3152345 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3152697 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3153049 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3153400 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3153751 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3154102 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3154453 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3154805 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3155157 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3155509 */ "unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3155861 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3156212 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3156563 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3156914 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3157265 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3157617 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3157969 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3158321 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3158673 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3159024 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3159375 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3159726 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3160077 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3160429 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3160781 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3161133 */ "unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3161485 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3161839 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3162190 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3162541 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3162897 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3163250 */ "unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3163603 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3163959 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3164312 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3164665 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3165021 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3165374 */ "unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3165727 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3166014 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3166301 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3166588 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3166875 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3167163 */ "unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3167451 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3167738 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3168025 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3168312 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3168599 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3168887 */ "unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3169175 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3169462 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3169749 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3170036 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3170323 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3170611 */ "unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3170899 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3171186 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3171473 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3171760 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3172047 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3172335 */ "unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=3172623 */ "unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts : All. Unit: uncore_cha \000event=0x35,umask=0xc001ffff\000\00001\000TOR Inserts : All : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3172946 */ "unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts : All. Unit: uncore_cha \000event=0x35,umask=0xc001ffff\000\00001\000TOR Inserts : All : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3173199 */ "unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts; All. Unit: uncore_cha \000event=0x35,umask=0xff\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3173425 */ "unc_cha_tor_inserts.all_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local. Unit: uncore_cha \000event=0x35,umask=0x15\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3173667 */ "unc_cha_tor_inserts.all_io_ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0x35\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests\000"
/* offset=3173953 */ "unc_cha_tor_inserts.all_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local. Unit: uncore_cha \000event=0x35,umask=0x25\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3174198 */ "unc_cha_tor_inserts.ddr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.DDR. Unit: uncore_cha \000event=0x35\000\00011\000\000"
/* offset=3174351 */ "unc_cha_tor_inserts.ddr\000uncore_cha\000uncore cache\000TOR Inserts : DDR Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : DDR Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3174601 */ "unc_cha_tor_inserts.ddr\000uncore_cha\000uncore cache\000TOR Inserts : DDR4 Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : DDR4 Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3174923 */ "unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts : SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000TOR Inserts : SF/LLC Evictions : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3175347 */ "unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts : SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000TOR Inserts : SF/LLC Evictions : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3175701 */ "unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts; SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3176020 */ "unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts : Just Hits. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Hits : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3176338 */ "unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts : Just Hits. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Hits : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3176586 */ "unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts; Hit (Not a Miss). Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000"
/* offset=3176970 */ "unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc001ff01\000\00001\000TOR Inserts : All requests from iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3177338 */ "unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests from IA Cores\000"
/* offset=3177630 */ "unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests from iA Cores\000"
/* offset=3177916 */ "unc_cha_tor_inserts.ia_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8c7ff01\000\00001\000TOR Inserts : CLFlushes issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3178296 */ "unc_cha_tor_inserts.ia_clflush\000uncore_cha\000uncore cache\000TOR Inserts;CLFlush from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc8c7ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; CLFlush events that are initiated from the Core\000"
/* offset=3178602 */ "unc_cha_tor_inserts.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8d7ff01\000\00001\000TOR Inserts : CLFlushOpts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3178989 */ "unc_cha_tor_inserts.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Inserts;CLFlushOpt from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc8d7ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; CLFlushOpt events that are initiated from the Core\000"
/* offset=3179304 */ "unc_cha_tor_inserts.ia_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc80fff01\000\00001\000TOR Inserts : CRDs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3179670 */ "unc_cha_tor_inserts.ia_crd\000uncore_cha\000uncore cache\000TOR Inserts; CRd from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80fff01\000\00001\000TOR Inserts; Code read from local IA that misses in the snoop filter\000"
/* offset=3179872 */ "unc_cha_tor_inserts.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88fff01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000"
/* offset=3180093 */ "unc_cha_tor_inserts.ia_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc817ff01\000\00001\000TOR Inserts : DRds issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3180459 */ "unc_cha_tor_inserts.ia_drd\000uncore_cha\000uncore cache\000TOR Inserts; DRd from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817ff01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3180661 */ "unc_cha_tor_inserts.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc827ff01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3181039 */ "unc_cha_tor_inserts.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827ff01\000\00001\000TOR Inserts; Data read opt from local IA that misses in the snoop filter\000"
/* offset=3181253 */ "unc_cha_tor_inserts.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8a7ff01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3181646 */ "unc_cha_tor_inserts.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7ff01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that misses in the snoop filter\000"
/* offset=3181879 */ "unc_cha_tor_inserts.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc897ff01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3182260 */ "unc_cha_tor_inserts.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897ff01\000\00001\000TOR Inserts; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3182481 */ "unc_cha_tor_inserts.ia_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc837ff01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3182877 */ "unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd01\000\00001\000TOR Inserts : All requests from iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3183283 */ "unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001fd01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3183533 */ "unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local iA. Unit: uncore_cha \000event=0x35,umask=0x11\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3183777 */ "unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3184191 */ "unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffd01\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3184595 */ "unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts; CRd hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80ffd01\000\00001\000TOR Inserts; Code read from local IA that hits in the snoop filter\000"
/* offset=3184804 */ "unc_cha_tor_inserts.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffd01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3185223 */ "unc_cha_tor_inserts.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88ffd01\000\00001\000TOR Inserts; Code read prefetch from local IA that hits in the snoop filter\000"
/* offset=3185451 */ "unc_cha_tor_inserts.ia_hit_cxl_acc\000uncore_cha\000uncore cache\000All requests issued from IA cores to CXL accelerator memory regions that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x10c0018101\000\00001\000\000"
/* offset=3185649 */ "unc_cha_tor_inserts.ia_hit_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008101\000\00001\000\000"
/* offset=3185823 */ "unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3186237 */ "unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc817fd01\000\00001\000TOR Inserts : DRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3186641 */ "unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts; DRd hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817fd01\000\00001\000TOR Inserts; Data read from local IA that hits in the snoop filter\000"
/* offset=3186850 */ "unc_cha_tor_inserts.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fd01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3187266 */ "unc_cha_tor_inserts.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827fd01\000\00001\000TOR Inserts; Data read opt from local IA that hits in the snoop filter\000"
/* offset=3187487 */ "unc_cha_tor_inserts.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fd01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3187918 */ "unc_cha_tor_inserts.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7fd01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that hits in the snoop filter\000"
/* offset=3188158 */ "unc_cha_tor_inserts.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc897fd01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3188577 */ "unc_cha_tor_inserts.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897fd01\000\00001\000TOR Inserts; Data read prefetch from local IA that hits in the snoop filter\000"
/* offset=3188805 */ "unc_cha_tor_inserts.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fd01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to page walks that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3189238 */ "unc_cha_tor_inserts.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fd01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3189583 */ "unc_cha_tor_inserts.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fd01\000\00001\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3189982 */ "unc_cha_tor_inserts.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3190408 */ "unc_cha_tor_inserts.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA that hits in the snoop filter\000"
/* offset=3190659 */ "unc_cha_tor_inserts.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT_LLCPREFCODE. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00011\000\000"
/* offset=3190857 */ "unc_cha_tor_inserts.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b233\000\00001\000\000"
/* offset=3191019 */ "unc_cha_tor_inserts.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3191445 */ "unc_cha_tor_inserts.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA that hits in the snoop filter\000"
/* offset=3191696 */ "unc_cha_tor_inserts.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT_LLCPREFDATA. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00011\000\000"
/* offset=3191894 */ "unc_cha_tor_inserts.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b433\000\00001\000\000"
/* offset=3192056 */ "unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3192489 */ "unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xccc7fd01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3192912 */ "unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7fd01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that hits in the snoop filter\000"
/* offset=3193170 */ "unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3193584 */ "unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fd01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3193988 */ "unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807fd01\000\00001\000TOR Inserts; Read for ownership from local IA that hits in the snoop filter\000"
/* offset=3194206 */ "unc_cha_tor_inserts.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fd01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3194625 */ "unc_cha_tor_inserts.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887fd01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that hits in the snoop filter\000"
/* offset=3194862 */ "unc_cha_tor_inserts.ia_hit_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores that hit in the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc57fd01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3195287 */ "unc_cha_tor_inserts.ia_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcc47ff01\000\00001\000TOR Inserts : ItoMs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3195656 */ "unc_cha_tor_inserts.ia_itom\000uncore_cha\000uncore cache\000TOR Inserts;ItoM from Local IA. Unit: uncore_cha \000event=0x35,umask=0xcc47ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; ItoM events that are initiated from the Core\000"
/* offset=3195953 */ "unc_cha_tor_inserts.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcd47ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3196299 */ "unc_cha_tor_inserts.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcd47ff01\000\00001\000TOR Inserts : ItoMCacheNears issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3196695 */ "unc_cha_tor_inserts.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcccfff01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3197083 */ "unc_cha_tor_inserts.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccfff01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA\000"
/* offset=3197295 */ "unc_cha_tor_inserts.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xccd7ff01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3197683 */ "unc_cha_tor_inserts.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7ff01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA\000"
/* offset=3197895 */ "unc_cha_tor_inserts.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xccc7ff01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3198280 */ "unc_cha_tor_inserts.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7ff01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000"
/* offset=3198531 */ "unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3198938 */ "unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe01\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3199351 */ "unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts; misses from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001fe01\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3199737 */ "unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3200158 */ "unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffe01\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3200569 */ "unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts for CRd misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80ffe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode CRd\000"
/* offset=3200814 */ "unc_cha_tor_inserts.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc80efe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3201186 */ "unc_cha_tor_inserts.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc80efe01\000\00001\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3201633 */ "unc_cha_tor_inserts.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffe01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3202059 */ "unc_cha_tor_inserts.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88ffe01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000"
/* offset=3202292 */ "unc_cha_tor_inserts.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc88efe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3202675 */ "unc_cha_tor_inserts.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc88efe01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3203139 */ "unc_cha_tor_inserts.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc88f7e01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3203524 */ "unc_cha_tor_inserts.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc88f7e01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3203991 */ "unc_cha_tor_inserts.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc80f7e01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3204365 */ "unc_cha_tor_inserts.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc80f7e01\000\00001\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3204815 */ "unc_cha_tor_inserts.ia_miss_crdmorph_cxl_acc\000uncore_cha\000uncore cache\000CRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c80b8201\000\00001\000\000"
/* offset=3205053 */ "unc_cha_tor_inserts.ia_miss_cxl_acc\000uncore_cha\000uncore cache\000All requests issued from IA cores to CXL accelerator memory regions that miss the LLC. Unit: uncore_cha \000event=0x35,umask=0x10c0018201\000\00001\000\000"
/* offset=3205253 */ "unc_cha_tor_inserts.ia_miss_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008201\000\00001\000\000"
/* offset=3205429 */ "unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3205850 */ "unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc817fe01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3206261 */ "unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd\000"
/* offset=3206506 */ "unc_cha_tor_inserts.ia_miss_drd_cxl_acc\000uncore_cha\000uncore cache\000DRds issued from an IA core which miss the L3 and target memory in a CXL type 2 memory expander card. Unit: uncore_cha \000event=0x35,umask=0x10c8178201\000\00001\000\000"
/* offset=3206725 */ "unc_cha_tor_inserts.ia_miss_drd_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8168201\000\00001\000\000"
/* offset=3206909 */ "unc_cha_tor_inserts.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3207360 */ "unc_cha_tor_inserts.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Inserts for DRds issued by IA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178601\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target DDR memory\000"
/* offset=3207675 */ "unc_cha_tor_inserts.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc816fe01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3208124 */ "unc_cha_tor_inserts.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA targeting local memory. Unit: uncore_cha \000event=0x35,umask=0xc816fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target local memory\000"
/* offset=3208429 */ "unc_cha_tor_inserts.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3208824 */ "unc_cha_tor_inserts.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3209313 */ "unc_cha_tor_inserts.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3209708 */ "unc_cha_tor_inserts.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3210197 */ "unc_cha_tor_inserts.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fe01\000\00001\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3210618 */ "unc_cha_tor_inserts.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827fe01\000\00001\000TOR Inserts; Data read opt from local IA that misses in the snoop filter\000"
/* offset=3210844 */ "unc_cha_tor_inserts.ia_miss_drd_opt_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_OPT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8268201\000\00001\000\000"
/* offset=3211036 */ "unc_cha_tor_inserts.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fe01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3211474 */ "unc_cha_tor_inserts.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7fe01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that misses in the snoop filter\000"
/* offset=3211719 */ "unc_cha_tor_inserts.ia_miss_drd_opt_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_OPT_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8a68201\000\00001\000\000"
/* offset=3211921 */ "unc_cha_tor_inserts.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3212372 */ "unc_cha_tor_inserts.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Inserts for DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178a01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target PMM memory\000"
/* offset=3212687 */ "unc_cha_tor_inserts.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc897fe01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3213113 */ "unc_cha_tor_inserts.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF\000"
/* offset=3213373 */ "unc_cha_tor_inserts.ia_miss_drd_pref_cxl_acc\000uncore_cha\000uncore cache\000L2 data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8978201\000\00001\000\000"
/* offset=3213602 */ "unc_cha_tor_inserts.ia_miss_drd_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8968201\000\00001\000\000"
/* offset=3213796 */ "unc_cha_tor_inserts.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3214179 */ "unc_cha_tor_inserts.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3214645 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA targeting local memory. Unit: uncore_cha \000event=0x35,umask=0xc896fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF, and target local memory\000"
/* offset=3214959 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc896fe01\000\00001\000TOR Inserts; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3215198 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3215603 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3216107 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3216512 */ "unc_cha_tor_inserts.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3217016 */ "unc_cha_tor_inserts.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3217399 */ "unc_cha_tor_inserts.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3217865 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8977e01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF, and target remote memory\000"
/* offset=3218182 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8977e01\000\00001\000TOR Inserts; Data read prefetch from remote IA that misses in the snoop filter\000"
/* offset=3218423 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3218830 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3219337 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3219744 */ "unc_cha_tor_inserts.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3220251 */ "unc_cha_tor_inserts.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8177e01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3220703 */ "unc_cha_tor_inserts.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8177e01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and target remote memory\000"
/* offset=3221005 */ "unc_cha_tor_inserts.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3221402 */ "unc_cha_tor_inserts.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3221894 */ "unc_cha_tor_inserts.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3222291 */ "unc_cha_tor_inserts.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3222783 */ "unc_cha_tor_inserts.ia_miss_drdmorph_cxl_acc\000uncore_cha\000uncore cache\000DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8138201\000\00001\000\000"
/* offset=3223021 */ "unc_cha_tor_inserts.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fe01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3223462 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3223692 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3223926 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00011\000\000"
/* offset=3224136 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3224376 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_LOCAL_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00011\000\000"
/* offset=3224598 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3224838 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3225072 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3225313 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_REMOTE_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00011\000\000"
/* offset=3225537 */ "unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3225778 */ "unc_cha_tor_inserts.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3226127 */ "unc_cha_tor_inserts.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fe01\000\00001\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3226533 */ "unc_cha_tor_inserts.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcccffe01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3226966 */ "unc_cha_tor_inserts.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccffe01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA that misses in the snoop filter\000"
/* offset=3227222 */ "unc_cha_tor_inserts.ia_miss_llcprefcode_cxl_acc\000uncore_cha\000uncore cache\000LLC Prefetch Code transactions issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10cccf8201\000\00001\000\000"
/* offset=3227466 */ "unc_cha_tor_inserts.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b233\000\00001\000\000"
/* offset=3227630 */ "unc_cha_tor_inserts.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xccd7fe01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3228063 */ "unc_cha_tor_inserts.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7fe01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA that misses in the snoop filter\000"
/* offset=3228319 */ "unc_cha_tor_inserts.ia_miss_llcprefdata_cxl_acc\000uncore_cha\000uncore cache\000LLC data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10ccd78201\000\00001\000\000"
/* offset=3228552 */ "unc_cha_tor_inserts.ia_miss_llcprefdata_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFDATA_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccd68201\000\00001\000\000"
/* offset=3228752 */ "unc_cha_tor_inserts.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b433\000\00001\000\000"
/* offset=3228916 */ "unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3229356 */ "unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xccc7fe01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3229786 */ "unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7fe01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000"
/* offset=3230049 */ "unc_cha_tor_inserts.ia_miss_llcprefrfo_cxl_acc\000uncore_cha\000uncore cache\000L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8878201\000\00001\000\000"
/* offset=3230279 */ "unc_cha_tor_inserts.ia_miss_llcprefrfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFRFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8868201\000\00001\000\000"
/* offset=3230477 */ "unc_cha_tor_inserts.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3230870 */ "unc_cha_tor_inserts.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3231354 */ "unc_cha_tor_inserts.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3231747 */ "unc_cha_tor_inserts.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3232231 */ "unc_cha_tor_inserts.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3232626 */ "unc_cha_tor_inserts.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3233113 */ "unc_cha_tor_inserts.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3233508 */ "unc_cha_tor_inserts.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3233995 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3234227 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3234463 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00011\000\000"
/* offset=3234675 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3234917 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_LOCAL_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00011\000\000"
/* offset=3235141 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3235383 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3235619 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3235862 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_REMOTE_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00011\000\000"
/* offset=3236088 */ "unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000"
/* offset=3236331 */ "unc_cha_tor_inserts.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3236726 */ "unc_cha_tor_inserts.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3237213 */ "unc_cha_tor_inserts.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3237608 */ "unc_cha_tor_inserts.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3238095 */ "unc_cha_tor_inserts.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3238492 */ "unc_cha_tor_inserts.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3238982 */ "unc_cha_tor_inserts.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3239477 */ "unc_cha_tor_inserts.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3239874 */ "unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3240295 */ "unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fe01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3240706 */ "unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807fe01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3240929 */ "unc_cha_tor_inserts.ia_miss_rfo_cxl_acc\000uncore_cha\000uncore cache\000RFOs issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8078201\000\00001\000\000"
/* offset=3241139 */ "unc_cha_tor_inserts.ia_miss_rfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_RFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8068201\000\00001\000\000"
/* offset=3241323 */ "unc_cha_tor_inserts.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc806fe01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3241772 */ "unc_cha_tor_inserts.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Inserts RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc806fe01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3242000 */ "unc_cha_tor_inserts.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fe01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3242426 */ "unc_cha_tor_inserts.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887fe01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3242668 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_cxl_acc\000uncore_cha\000uncore cache\000LLC RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10ccc78201\000\00001\000\000"
/* offset=3242897 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_RFO_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccc68201\000\00001\000\000"
/* offset=3243091 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc886fe01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3243555 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Inserts; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc886fe01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3243807 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8877e01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3244274 */ "unc_cha_tor_inserts.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8877e01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3244527 */ "unc_cha_tor_inserts.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8077e01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3244979 */ "unc_cha_tor_inserts.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8077e01\000\00001\000TOR Inserts Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3245208 */ "unc_cha_tor_inserts.ia_miss_rfomorph_cxl_acc\000uncore_cha\000uncore cache\000RFO and L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8038201\000\00001\000\000"
/* offset=3245444 */ "unc_cha_tor_inserts.ia_miss_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc57fe01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3245870 */ "unc_cha_tor_inserts.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc877de01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3246221 */ "unc_cha_tor_inserts.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc877de01\000\00001\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3246630 */ "unc_cha_tor_inserts.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3246983 */ "unc_cha_tor_inserts.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3247397 */ "unc_cha_tor_inserts.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3247768 */ "unc_cha_tor_inserts.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3248214 */ "unc_cha_tor_inserts.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3248585 */ "unc_cha_tor_inserts.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3249031 */ "unc_cha_tor_inserts.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3249385 */ "unc_cha_tor_inserts.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3249800 */ "unc_cha_tor_inserts.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3250173 */ "unc_cha_tor_inserts.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3250622 */ "unc_cha_tor_inserts.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3250995 */ "unc_cha_tor_inserts.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3251444 */ "unc_cha_tor_inserts.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Inserts : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc87fde01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3251791 */ "unc_cha_tor_inserts.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Inserts : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc87fde01\000\00001\000TOR Inserts : WiLs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3252194 */ "unc_cha_tor_inserts.ia_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc807ff01\000\00001\000TOR Inserts : RFOs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3252560 */ "unc_cha_tor_inserts.ia_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807ff01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3252771 */ "unc_cha_tor_inserts.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc887ff01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3253152 */ "unc_cha_tor_inserts.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887ff01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3253382 */ "unc_cha_tor_inserts.ia_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcc57ff01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3253763 */ "unc_cha_tor_inserts.ia_specitom\000uncore_cha\000uncore cache\000TOR Inserts;SpecItoM from Local IA. Unit: uncore_cha \000event=0x35,umask=0xcc57ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; SpecItoM events that are initiated from the Core\000"
/* offset=3254072 */ "unc_cha_tor_inserts.ia_wbeftoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc3fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3254494 */ "unc_cha_tor_inserts.ia_wbeftoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc37ff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3254916 */ "unc_cha_tor_inserts.ia_wbeftoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc37ff01\000\00001\000WbEFtoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3255338 */ "unc_cha_tor_inserts.ia_wbmtoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc2fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3255759 */ "unc_cha_tor_inserts.ia_wbmtoe\000uncore_cha\000uncore cache\000TOR Inserts : WBMtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc2fff01\000\00001\000WbMtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3256178 */ "unc_cha_tor_inserts.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by an iA Cores. Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc27ff01\000\00001\000WbMtoIs issued by iA Cores .  (Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3256589 */ "unc_cha_tor_inserts.ia_wbstoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc67ff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3257010 */ "unc_cha_tor_inserts.ia_wbstoi\000uncore_cha\000uncore cache\000TOR Inserts : WBStoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc67ff01\000\00001\000WbStoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000"
/* offset=3257429 */ "unc_cha_tor_inserts.ia_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc86fff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3257757 */ "unc_cha_tor_inserts.ia_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc86fff01\000\00001\000TOR Inserts : WCiLs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3258126 */ "unc_cha_tor_inserts.ia_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc867ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3258455 */ "unc_cha_tor_inserts.ia_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc867ff01\000\00001\000TOR Inserts : WCiLF issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3258825 */ "unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc001ff04\000\00001\000TOR Inserts : All requests from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3259197 */ "unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts; All from Local IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally generated IO traffic\000"
/* offset=3259471 */ "unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts; All from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3259786 */ "unc_cha_tor_inserts.io_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8c3ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3260123 */ "unc_cha_tor_inserts.io_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8c3ff04\000\00001\000TOR Inserts : CLFlushes issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3260507 */ "unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd04\000\00001\000TOR Inserts : All requests from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3260917 */ "unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local IO. Unit: uncore_cha \000event=0x35,umask=0x14\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3261161 */ "unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3261481 */ "unc_cha_tor_inserts.io_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fd04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3261892 */ "unc_cha_tor_inserts.io_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3262222 */ "unc_cha_tor_inserts.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fd04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3262724 */ "unc_cha_tor_inserts.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fd04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3263147 */ "unc_cha_tor_inserts.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur and FsRdCur hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3fd04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3263558 */ "unc_cha_tor_inserts.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fd04\000\00001\000TOR Inserts : RFOs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3263966 */ "unc_cha_tor_inserts.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3264294 */ "unc_cha_tor_inserts.io_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc43ff04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3264667 */ "unc_cha_tor_inserts.io_itom\000uncore_cha\000uncore cache\000TOR Inserts for ItoM from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43ff04\000\00001\000Inserts into the TOR from local IO with the opcode ItoM\000"
/* offset=3264861 */ "unc_cha_tor_inserts.io_itom_local\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices to locally HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcc42ff04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3265264 */ "unc_cha_tor_inserts.io_itom_remote\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices to remotely HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcc437f04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3265669 */ "unc_cha_tor_inserts.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcd43ff04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3266133 */ "unc_cha_tor_inserts.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts for ItoMCacheNears from IO devices. Unit: uncore_cha \000event=0x35,umask=0xcd43ff04\000\00001\000Inserts into the TOR from local IO devices with the opcode ItoMCacheNears.  This event indicates a partial write request\000"
/* offset=3266413 */ "unc_cha_tor_inserts.io_itomcachenear_local\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices to locally HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcd42ff04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3266907 */ "unc_cha_tor_inserts.io_itomcachenear_remote\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices to remotely HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcd437f04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3267403 */ "unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe04\000\00001\000TOR Inserts : All requests from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3267820 */ "unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3268067 */ "unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001fe04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3268390 */ "unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fe04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3268808 */ "unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x49033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM request is used by IIO to request a data write without first reading the data for ownership\000"
/* offset=3269195 */ "unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43fe04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3269528 */ "unc_cha_tor_inserts.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fe04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3270037 */ "unc_cha_tor_inserts.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fe04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3270467 */ "unc_cha_tor_inserts.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur and FsRdCur misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3fe04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3270884 */ "unc_cha_tor_inserts.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x43C33\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RdCur requests and miss the LLC. A RdCur request is used by IIO to read data without changing state\000"
/* offset=3271240 */ "unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fe04\000\00001\000TOR Inserts : RFOs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3271655 */ "unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x40033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests a cache line to be cached in E state with the intent to modify\000"
/* offset=3272038 */ "unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803fe04\000\00001\000TOR Inserts : RFOs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3272431 */ "unc_cha_tor_inserts.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8f3ff04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3272816 */ "unc_cha_tor_inserts.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts for RdCur from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3ff04\000\00001\000Inserts into the TOR from local IO with the opcode RdCur\000"
/* offset=3273016 */ "unc_cha_tor_inserts.io_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc803ff04\000\00001\000TOR Inserts : RFOs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3273386 */ "unc_cha_tor_inserts.io_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803ff04\000\00001\000TOR Inserts : RFOs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3273747 */ "unc_cha_tor_inserts.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc23ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3274081 */ "unc_cha_tor_inserts.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc23ff04\000\00001\000TOR Inserts : WbMtoIs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3274460 */ "unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts : IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000TOR Inserts : IPQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3274776 */ "unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts : IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000TOR Inserts : IPQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3275022 */ "unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts; IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3275247 */ "unc_cha_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000"
/* offset=3275370 */ "unc_cha_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000"
/* offset=3275494 */ "unc_cha_tor_inserts.irq\000uncore_cha\000uncore cache\000TOR Inserts; IRQ. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3275719 */ "unc_cha_tor_inserts.irq_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - iA. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000TOR Inserts : IRQ - iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From an iA Core\000"
/* offset=3276067 */ "unc_cha_tor_inserts.irq_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - iA. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000TOR Inserts : IRQ - iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : From an iA Core\000"
/* offset=3276345 */ "unc_cha_tor_inserts.irq_non_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - Non iA. Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000TOR Inserts : IRQ - Non iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3276687 */ "unc_cha_tor_inserts.irq_non_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - Non iA. Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000TOR Inserts : IRQ - Non iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3276959 */ "unc_cha_tor_inserts.isoc\000uncore_cha\000uncore cache\000TOR Inserts : Just ISOC. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just ISOC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3277278 */ "unc_cha_tor_inserts.isoc\000uncore_cha\000uncore cache\000TOR Inserts : Just ISOC. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just ISOC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3277527 */ "unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff05\000\00001\000TOR Inserts : All from Local iA and IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000"
/* offset=3277930 */ "unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff05\000\00001\000TOR Inserts : All from Local iA and IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally initiated requests\000"
/* offset=3278263 */ "unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000"
/* offset=3278386 */ "unc_cha_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA. Unit: uncore_cha \000event=0x35,umask=0xc000ff01\000\00001\000TOR Inserts : All from Local iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000"
/* offset=3278788 */ "unc_cha_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA. Unit: uncore_cha \000event=0x35,umask=0xc000ff01\000\00001\000TOR Inserts : All from Local iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally initiated requests from iA Cores\000"
/* offset=3279120 */ "unc_cha_tor_inserts.loc_io\000uncore_cha\000uncore cache\000TOR Inserts : All from Local IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff04\000\00001\000TOR Inserts : All from Local IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000"
/* offset=3279510 */ "unc_cha_tor_inserts.loc_io\000uncore_cha\000uncore cache\000TOR Inserts : All from Local IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff04\000\00001\000TOR Inserts : All from Local IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally generated IO traffic\000"
/* offset=3279830 */ "unc_cha_tor_inserts.local_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Local Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Local Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3280172 */ "unc_cha_tor_inserts.local_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Local Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Local Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3280444 */ "unc_cha_tor_inserts.match_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3280862 */ "unc_cha_tor_inserts.match_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3281210 */ "unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts : Just Misses. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Misses : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3281533 */ "unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts : Just Misses. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Misses : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3281786 */ "unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts; Miss. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000"
/* offset=3282517 */ "unc_cha_tor_inserts.mmcfg\000uncore_cha\000uncore cache\000TOR Inserts : MMCFG Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMCFG Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3282843 */ "unc_cha_tor_inserts.mmcfg\000uncore_cha\000uncore cache\000TOR Inserts : MMCFG Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMCFG Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3283099 */ "unc_cha_tor_inserts.mmio\000uncore_cha\000uncore cache\000TOR Inserts : MMIO Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMIO Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3283352 */ "unc_cha_tor_inserts.nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3283680 */ "unc_cha_tor_inserts.nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3283938 */ "unc_cha_tor_inserts.noncoh\000uncore_cha\000uncore cache\000TOR Inserts : Just NonCoherent. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NonCoherent : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3284273 */ "unc_cha_tor_inserts.noncoh\000uncore_cha\000uncore cache\000TOR Inserts : Just NonCoherent. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NonCoherent : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3284538 */ "unc_cha_tor_inserts.not_nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NotNearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NotNearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3284876 */ "unc_cha_tor_inserts.not_nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NotNearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NotNearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3285144 */ "unc_cha_tor_inserts.pmm\000uncore_cha\000uncore cache\000TOR Inserts : PMM Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : PM Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3285393 */ "unc_cha_tor_inserts.pmm\000uncore_cha\000uncore cache\000TOR Inserts : PMM Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : PMM Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3285713 */ "unc_cha_tor_inserts.premorph_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3286156 */ "unc_cha_tor_inserts.premorph_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3286529 */ "unc_cha_tor_inserts.prq\000uncore_cha\000uncore cache\000TOR Inserts; PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3286754 */ "unc_cha_tor_inserts.prq_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - IOSF. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000TOR Inserts : PRQ - IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000"
/* offset=3287111 */ "unc_cha_tor_inserts.prq_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - IOSF. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000TOR Inserts : PRQ - IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : From a PCIe Device\000"
/* offset=3287398 */ "unc_cha_tor_inserts.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - Non IOSF. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000TOR Inserts : PRQ - Non IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3287746 */ "unc_cha_tor_inserts.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - Non IOSF. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000TOR Inserts : PRQ - Non IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3288024 */ "unc_cha_tor_inserts.rem_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ffc8\000\00001\000TOR Inserts : All from Remote : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All remote requests (e.g. snoops, writebacks) that came from remote sockets\000"
/* offset=3288384 */ "unc_cha_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000"
/* offset=3288507 */ "unc_cha_tor_inserts.rem_snps\000uncore_cha\000uncore cache\000TOR Inserts : All Snoops from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ff08\000\00001\000TOR Inserts : All Snoops from Remote : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All snoops to this LLC that came from remote sockets\000"
/* offset=3288859 */ "unc_cha_tor_inserts.remote_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Remote Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Remote Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3289204 */ "unc_cha_tor_inserts.remote_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Remote Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Remote Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3289479 */ "unc_cha_tor_inserts.rrq\000uncore_cha\000uncore cache\000TOR Inserts : RRQ. Unit: uncore_cha \000event=0x35,umask=0x40\000\00001\000TOR Inserts : RRQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3289796 */ "unc_cha_tor_inserts.rrq\000uncore_cha\000uncore cache\000TOR Inserts : RRQ. Unit: uncore_cha \000event=0x35,umask=0x40\000\00001\000TOR Inserts : RRQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3290043 */ "unc_cha_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000"
/* offset=3290166 */ "unc_cha_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000"
/* offset=3290290 */ "unc_cha_tor_inserts.snps_from_rem\000uncore_cha\000uncore cache\000TOR Inserts; All Snoops from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ff08\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. All snoops to this LLC that came from remote sockets\000"
/* offset=3290605 */ "unc_cha_tor_inserts.wbq\000uncore_cha\000uncore cache\000TOR Inserts : WBQ. Unit: uncore_cha \000event=0x35,umask=0x80\000\00001\000TOR Inserts : WBQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000"
/* offset=3290922 */ "unc_cha_tor_inserts.wbq\000uncore_cha\000uncore cache\000TOR Inserts : WBQ. Unit: uncore_cha \000event=0x35,umask=0x80\000\00001\000TOR Inserts : WBQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000"
/* offset=3291169 */ "unc_cha_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000"
/* offset=3291292 */ "unc_cha_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000"
/* offset=3291416 */ "unc_cha_tor_occupancy.all\000uncore_cha\000uncore cache\000TOR Occupancy : All. Unit: uncore_cha \000event=0x36,umask=0xc001ffff\000\00001\000TOR Occupancy : All : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3291694 */ "unc_cha_tor_occupancy.all\000uncore_cha\000uncore cache\000TOR Occupancy : All. Unit: uncore_cha \000event=0x36,umask=0xff\000\00001\000TOR Occupancy : All : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3292033 */ "unc_cha_tor_occupancy.all_from_loc\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local. Unit: uncore_cha \000event=0x36,umask=0x37\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All remotely generated requests\000"
/* offset=3292681 */ "unc_cha_tor_occupancy.all_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local. Unit: uncore_cha \000event=0x36,umask=0x17\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3292946 */ "unc_cha_tor_occupancy.all_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local. Unit: uncore_cha \000event=0x36,umask=0x27\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3293214 */ "unc_cha_tor_occupancy.ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DDR Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : DDR Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent\000"
/* offset=3293484 */ "unc_cha_tor_occupancy.ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DDR4 Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : DDR4 Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3293828 */ "unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy : SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000TOR Occupancy : SF/LLC Evictions : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3294274 */ "unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy : SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000TOR Occupancy : SF/LLC Evictions : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3294652 */ "unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy; SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000"
/* offset=3294993 */ "unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy : Just Hits. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Hits : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3295333 */ "unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy : Just Hits. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Hits : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3295606 */ "unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hit (Not a Miss). Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000"
/* offset=3296012 */ "unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc001ff01\000\00001\000TOR Occupancy : All requests from iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3296402 */ "unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local iA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally initiated requests from iA Cores\000"
/* offset=3296710 */ "unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy; All from local IA. Unit: uncore_cha \000event=0x36,umask=0xc001ff01\000\00001\000TOR Occupancy : All requests from iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3297090 */ "unc_cha_tor_occupancy.ia_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8c7ff01\000\00001\000TOR Occupancy : CLFlushes issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3297492 */ "unc_cha_tor_occupancy.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8d7ff01\000\00001\000TOR Occupancy : CLFlushOpts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3297901 */ "unc_cha_tor_occupancy.ia_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc80fff01\000\00001\000TOR Occupancy : CRDs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3298289 */ "unc_cha_tor_occupancy.ia_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80fff01\000\00001\000TOR Occupancy; Code read from local IA that misses in the snoop filter\000"
/* offset=3298497 */ "unc_cha_tor_occupancy.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88fff01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000"
/* offset=3298724 */ "unc_cha_tor_occupancy.ia_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc817ff01\000\00001\000TOR Occupancy : DRds issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3299112 */ "unc_cha_tor_occupancy.ia_drd\000uncore_cha\000uncore cache\000TOR Occupancy; DRd from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817ff01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3299320 */ "unc_cha_tor_occupancy.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc827ff01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3299720 */ "unc_cha_tor_occupancy.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827ff01\000\00001\000TOR Occupancy; Data read opt from local IA that misses in the snoop filter\000"
/* offset=3299940 */ "unc_cha_tor_occupancy.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8a7ff01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3300355 */ "unc_cha_tor_occupancy.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7ff01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that misses in the snoop filter\000"
/* offset=3300594 */ "unc_cha_tor_occupancy.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc897ff01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3300997 */ "unc_cha_tor_occupancy.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897ff01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3301224 */ "unc_cha_tor_occupancy.ia_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837ff01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3301695 */ "unc_cha_tor_occupancy.ia_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk. Unit: uncore_cha \000event=0x36,umask=0xc837ff01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3302128 */ "unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd01\000\00001\000TOR Occupancy : All requests from iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3302556 */ "unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local iA. Unit: uncore_cha \000event=0x36,umask=0x11\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3302823 */ "unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc001fd01\000\00001\000TOR Occupancy : All requests from iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3303225 */ "unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3303661 */ "unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffd01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3304087 */ "unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80ffd01\000\00001\000TOR Occupancy; Code read from local IA that hits in the snoop filter\000"
/* offset=3304302 */ "unc_cha_tor_occupancy.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffd01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3304743 */ "unc_cha_tor_occupancy.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88ffd01\000\00001\000TOR Occupancy; Code read prefetch from local IA that hits in the snoop filter\000"
/* offset=3304977 */ "unc_cha_tor_occupancy.ia_hit_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for All requests issued from IA cores to CXL accelerator memory regions that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x10c0018101\000\00001\000\000"
/* offset=3305195 */ "unc_cha_tor_occupancy.ia_hit_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008101\000\00001\000\000"
/* offset=3305373 */ "unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3305809 */ "unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc817fd01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3306235 */ "unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy; DRd hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817fd01\000\00001\000TOR Occupancy; Data read from local IA that hits in the snoop filter\000"
/* offset=3306450 */ "unc_cha_tor_occupancy.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fd01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3306888 */ "unc_cha_tor_occupancy.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827fd01\000\00001\000TOR Occupancy; Data read opt from local IA that hits in the snoop filter\000"
/* offset=3307115 */ "unc_cha_tor_occupancy.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fd01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3307568 */ "unc_cha_tor_occupancy.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7fd01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that hits in the snoop filter\000"
/* offset=3307814 */ "unc_cha_tor_occupancy.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc897fd01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3308255 */ "unc_cha_tor_occupancy.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897fd01\000\00001\000TOR Occupancy; Data read prefetch from local IA that hits in the snoop filter\000"
/* offset=3308489 */ "unc_cha_tor_occupancy.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837fd01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3308998 */ "unc_cha_tor_occupancy.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fd01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3309469 */ "unc_cha_tor_occupancy.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fd01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3309890 */ "unc_cha_tor_occupancy.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcccffd01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3310338 */ "unc_cha_tor_occupancy.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccffd01\000\00001\000TOR Occupancy; Last level cache prefetch code read from local IA that hits in the snoop filter\000"
/* offset=3310595 */ "unc_cha_tor_occupancy.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b233\000\00001\000\000"
/* offset=3310761 */ "unc_cha_tor_occupancy.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xccd7fd01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3311209 */ "unc_cha_tor_occupancy.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7fd01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that hits in the snoop filter\000"
/* offset=3311466 */ "unc_cha_tor_occupancy.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b433\000\00001\000\000"
/* offset=3311632 */ "unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3312087 */ "unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xccc7fd01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3312532 */ "unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7fd01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that hits in the snoop filter\000"
/* offset=3312796 */ "unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3313232 */ "unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fd01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3313658 */ "unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807fd01\000\00001\000TOR Occupancy; Read for ownership from local IA that hits in the snoop filter\000"
/* offset=3313882 */ "unc_cha_tor_occupancy.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fd01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3314323 */ "unc_cha_tor_occupancy.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887fd01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that hits in the snoop filter\000"
/* offset=3314566 */ "unc_cha_tor_occupancy.ia_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc47ff01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3314957 */ "unc_cha_tor_occupancy.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcd47ff01\000\00001\000TOR Occupancy : ItoMCacheNears issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3315375 */ "unc_cha_tor_occupancy.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcccfff01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3315785 */ "unc_cha_tor_occupancy.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccfff01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA\000"
/* offset=3316003 */ "unc_cha_tor_occupancy.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xccd7ff01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3316413 */ "unc_cha_tor_occupancy.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7ff01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that misses in the snoop filter\000"
/* offset=3316663 */ "unc_cha_tor_occupancy.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xccc7ff01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3317070 */ "unc_cha_tor_occupancy.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7ff01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000"
/* offset=3317327 */ "unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe01\000\00001\000TOR Occupancy : All requests from iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3317762 */ "unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local IA. Unit: uncore_cha \000event=0x36,umask=0xc001fe01\000\00001\000TOR Occupancy : All requests from iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3318170 */ "unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local iA. Unit: uncore_cha \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3318440 */ "unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3318883 */ "unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffe01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3319316 */ "unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80ffe01\000\00001\000TOR Occupancy; Code read from local IA that misses in the snoop filter\000"
/* offset=3319536 */ "unc_cha_tor_occupancy.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc80efe01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3320005 */ "unc_cha_tor_occupancy.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3320453 */ "unc_cha_tor_occupancy.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88ffe01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000"
/* offset=3320692 */ "unc_cha_tor_occupancy.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc88efe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3321178 */ "unc_cha_tor_occupancy.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc88f7e01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3321667 */ "unc_cha_tor_occupancy.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc80f7e01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3322139 */ "unc_cha_tor_occupancy.ia_miss_crdmorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for CRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c80b8201\000\00001\000\000"
/* offset=3322397 */ "unc_cha_tor_occupancy.ia_miss_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for All requests issued from IA cores to CXL accelerator memory regions that miss the LLC. Unit: uncore_cha \000event=0x36,umask=0x10c0018201\000\00001\000\000"
/* offset=3322617 */ "unc_cha_tor_occupancy.ia_miss_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008201\000\00001\000\000"
/* offset=3322797 */ "unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3323240 */ "unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc817fe01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3323673 */ "unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817fe01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd\000"
/* offset=3323942 */ "unc_cha_tor_occupancy.ia_miss_drd_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 memory expander card. Unit: uncore_cha \000event=0x36,umask=0x10c8178201\000\00001\000\000"
/* offset=3324204 */ "unc_cha_tor_occupancy.ia_miss_drd_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8168201\000\00001\000\000"
/* offset=3324392 */ "unc_cha_tor_occupancy.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3324865 */ "unc_cha_tor_occupancy.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Occupancy for DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178601\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target DDR memory\000"
/* offset=3325204 */ "unc_cha_tor_occupancy.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc816fe01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3325675 */ "unc_cha_tor_occupancy.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA targeting local memory. Unit: uncore_cha \000event=0x36,umask=0xc816fe01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target local memory\000"
/* offset=3326004 */ "unc_cha_tor_occupancy.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3326515 */ "unc_cha_tor_occupancy.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3327026 */ "unc_cha_tor_occupancy.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fe01\000\00001\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3327469 */ "unc_cha_tor_occupancy.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827fe01\000\00001\000TOR Occupancy; Data read opt from local IA that misses in the snoop filter\000"
/* offset=3327701 */ "unc_cha_tor_occupancy.ia_miss_drd_opt_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_OPT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8268201\000\00001\000\000"
/* offset=3327897 */ "unc_cha_tor_occupancy.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fe01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3328357 */ "unc_cha_tor_occupancy.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7fe01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that misses in the snoop filter\000"
/* offset=3328608 */ "unc_cha_tor_occupancy.ia_miss_drd_opt_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_OPT_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8a68201\000\00001\000\000"
/* offset=3328814 */ "unc_cha_tor_occupancy.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3329287 */ "unc_cha_tor_occupancy.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Occupancy for DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178a01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target PMM memory\000"
/* offset=3329626 */ "unc_cha_tor_occupancy.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc897fe01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3330074 */ "unc_cha_tor_occupancy.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897fe01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3330313 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for L2 data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8978201\000\00001\000\000"
/* offset=3330562 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8968201\000\00001\000\000"
/* offset=3330760 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3331248 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc896fe01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3331493 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3332019 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3332545 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3333033 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8977e01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000"
/* offset=3333279 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3333808 */ "unc_cha_tor_occupancy.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3334337 */ "unc_cha_tor_occupancy.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8177e01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3334811 */ "unc_cha_tor_occupancy.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x36,umask=0xc8177e01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target remote memory\000"
/* offset=3335143 */ "unc_cha_tor_occupancy.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3335657 */ "unc_cha_tor_occupancy.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3336171 */ "unc_cha_tor_occupancy.ia_miss_drdmorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8138201\000\00001\000\000"
/* offset=3336429 */ "unc_cha_tor_occupancy.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837fe01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3336945 */ "unc_cha_tor_occupancy.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fe01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3337423 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3337659 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8678601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3337899 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8668601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3338145 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8668a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3338391 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8678a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3338631 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8670601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3338878 */ "unc_cha_tor_occupancy.ia_miss_full_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8670a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3339125 */ "unc_cha_tor_occupancy.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fe01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3339553 */ "unc_cha_tor_occupancy.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcccffe01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3340008 */ "unc_cha_tor_occupancy.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccffe01\000\00001\000TOR Occupancy; Last level cache prefetch code read from local IA that misses in the snoop filter\000"
/* offset=3340270 */ "unc_cha_tor_occupancy.ia_miss_llcprefcode_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC Prefetch Code transactions issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10cccf8201\000\00001\000\000"
/* offset=3340534 */ "unc_cha_tor_occupancy.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b233\000\00001\000\000"
/* offset=3340702 */ "unc_cha_tor_occupancy.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xccd7fe01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3341157 */ "unc_cha_tor_occupancy.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7fe01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that misses in the snoop filter\000"
/* offset=3341419 */ "unc_cha_tor_occupancy.ia_miss_llcprefdata_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10ccd78201\000\00001\000\000"
/* offset=3341672 */ "unc_cha_tor_occupancy.ia_miss_llcprefdata_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LLCPREFDATA_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccd68201\000\00001\000\000"
/* offset=3341876 */ "unc_cha_tor_occupancy.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b433\000\00001\000\000"
/* offset=3342044 */ "unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3342506 */ "unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xccc7fe01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3342958 */ "unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7fe01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000"
/* offset=3343227 */ "unc_cha_tor_occupancy.ia_miss_llcprefrfo_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8878201\000\00001\000\000"
/* offset=3343477 */ "unc_cha_tor_occupancy.ia_miss_llcprefrfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LLCPREFRFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8868201\000\00001\000\000"
/* offset=3343679 */ "unc_cha_tor_occupancy.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3344185 */ "unc_cha_tor_occupancy.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3344691 */ "unc_cha_tor_occupancy.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3345200 */ "unc_cha_tor_occupancy.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3345709 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3345947 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f8601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3346189 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86e8601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3346437 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86e8a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3346685 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f8a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3346927 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f0601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3347176 */ "unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f0a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000"
/* offset=3347425 */ "unc_cha_tor_occupancy.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3347934 */ "unc_cha_tor_occupancy.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3348443 */ "unc_cha_tor_occupancy.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3348955 */ "unc_cha_tor_occupancy.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3349467 */ "unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3349910 */ "unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fe01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3350343 */ "unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807fe01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3350572 */ "unc_cha_tor_occupancy.ia_miss_rfo_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for RFOs issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8078201\000\00001\000\000"
/* offset=3350802 */ "unc_cha_tor_occupancy.ia_miss_rfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_RFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8068201\000\00001\000\000"
/* offset=3350990 */ "unc_cha_tor_occupancy.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc806fe01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3351461 */ "unc_cha_tor_occupancy.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc806fe01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3351696 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fe01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3352144 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887fe01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3352396 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10ccc78201\000\00001\000\000"
/* offset=3352645 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_RFO_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccc68201\000\00001\000\000"
/* offset=3352843 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc886fe01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3353329 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc886fe01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3353587 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8877e01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3354076 */ "unc_cha_tor_occupancy.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8877e01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3354335 */ "unc_cha_tor_occupancy.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8077e01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3354809 */ "unc_cha_tor_occupancy.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8077e01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3355045 */ "unc_cha_tor_occupancy.ia_miss_rfomorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for RFO and L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8038201\000\00001\000\000"
/* offset=3355301 */ "unc_cha_tor_occupancy.ia_miss_specitom\000uncore_cha\000uncore cache\000TOR Occupancy : SpecItoMs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc57fe01\000\00001\000TOR Occupancy : SpecItoMs issued by iA Cores that missed the LLC: For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent. Does not include addressless requests such as locks and interrupts\000"
/* offset=3355744 */ "unc_cha_tor_occupancy.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc877de01\000\00001\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3356175 */ "unc_cha_tor_occupancy.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3356611 */ "unc_cha_tor_occupancy.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3357079 */ "unc_cha_tor_occupancy.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3357547 */ "unc_cha_tor_occupancy.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3357984 */ "unc_cha_tor_occupancy.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3358455 */ "unc_cha_tor_occupancy.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3358926 */ "unc_cha_tor_occupancy.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc87fde01\000\00001\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3359351 */ "unc_cha_tor_occupancy.ia_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc807ff01\000\00001\000TOR Occupancy : RFOs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3359739 */ "unc_cha_tor_occupancy.ia_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807ff01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000"
/* offset=3359956 */ "unc_cha_tor_occupancy.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc887ff01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3360359 */ "unc_cha_tor_occupancy.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887ff01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000"
/* offset=3360599 */ "unc_cha_tor_occupancy.ia_specitom\000uncore_cha\000uncore cache\000TOR Occupancy : SpecItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc57ff01\000\00001\000TOR Occupancy : SpecItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3361002 */ "unc_cha_tor_occupancy.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc27ff01\000\00001\000TOR Occupancy : WbMtoIs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3361399 */ "unc_cha_tor_occupancy.ia_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc86fff01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3361790 */ "unc_cha_tor_occupancy.ia_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc867ff01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3362182 */ "unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc001ff04\000\00001\000TOR Occupancy : All requests from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3362576 */ "unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally generated IO traffic\000"
/* offset=3362872 */ "unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy; All from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001ff04\000\00001\000TOR Occupancy : All requests from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3363254 */ "unc_cha_tor_occupancy.io_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8c3ff04\000\00001\000TOR Occupancy : CLFlushes issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3363660 */ "unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd04\000\00001\000TOR Occupancy : All requests from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3364092 */ "unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local IO. Unit: uncore_cha \000event=0x36,umask=0x14\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3364359 */ "unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001fd04\000\00001\000TOR Occupancy : All requests from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3364763 */ "unc_cha_tor_occupancy.io_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fd04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3365196 */ "unc_cha_tor_occupancy.io_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43fd04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3365608 */ "unc_cha_tor_occupancy.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fd04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3366132 */ "unc_cha_tor_occupancy.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fd04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3366577 */ "unc_cha_tor_occupancy.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3fd04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3367010 */ "unc_cha_tor_occupancy.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fd04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3367440 */ "unc_cha_tor_occupancy.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803fd04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3367849 */ "unc_cha_tor_occupancy.io_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc43ff04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3368244 */ "unc_cha_tor_occupancy.io_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43ff04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3368630 */ "unc_cha_tor_occupancy.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xcd43ff04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3369154 */ "unc_cha_tor_occupancy.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcd43ff04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3369640 */ "unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe04\000\00001\000TOR Occupancy : All requests from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3370079 */ "unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3370349 */ "unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001fe04\000\00001\000TOR Occupancy : All requests from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3370759 */ "unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fe04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3371199 */ "unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy;  ITOM Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x49033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM is used by IIO to request a data write without first reading the data for ownership\000"
/* offset=3371597 */ "unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43fe04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3372015 */ "unc_cha_tor_occupancy.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fe04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3372546 */ "unc_cha_tor_occupancy.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fe04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3372998 */ "unc_cha_tor_occupancy.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3fe04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3373437 */ "unc_cha_tor_occupancy.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Occupancy;  RDCUR misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x43C33\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RdCur requests that miss the LLC. A RdCur request is used by IIO to read data without changing state\000"
/* offset=3373813 */ "unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fe04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3374250 */ "unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy;  RFO misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x40033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests data to be cached in E state with the intent to modify\000"
/* offset=3374644 */ "unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803fe04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3375059 */ "unc_cha_tor_occupancy.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8f3ff04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3375466 */ "unc_cha_tor_occupancy.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3ff04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3375873 */ "unc_cha_tor_occupancy.io_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc803ff04\000\00001\000TOR Occupancy : RFOs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3376265 */ "unc_cha_tor_occupancy.io_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; ItoM from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803ff04\000\00001\000TOR Occupancy : RFOs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3376649 */ "unc_cha_tor_occupancy.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc23ff04\000\00001\000TOR Occupancy : WbMtoIs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3377050 */ "unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy : IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000TOR Occupancy : IPQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3377388 */ "unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy : IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000TOR Occupancy : IPQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3377659 */ "unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy; IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3377907 */ "unc_cha_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000"
/* offset=3378032 */ "unc_cha_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000"
/* offset=3378158 */ "unc_cha_tor_occupancy.irq\000uncore_cha\000uncore cache\000TOR Occupancy; IRQ. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3378406 */ "unc_cha_tor_occupancy.irq_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - iA. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000TOR Occupancy : IRQ - iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From an iA Core\000"
/* offset=3378776 */ "unc_cha_tor_occupancy.irq_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - iA. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000TOR Occupancy : IRQ - iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : From an iA Core\000"
/* offset=3379078 */ "unc_cha_tor_occupancy.irq_non_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - Non iA. Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000TOR Occupancy : IRQ - Non iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3379442 */ "unc_cha_tor_occupancy.irq_non_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - Non iA. Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000TOR Occupancy : IRQ - Non iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3379739 */ "unc_cha_tor_occupancy.isoc\000uncore_cha\000uncore cache\000TOR Occupancy : Just ISOC. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just ISOC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3380080 */ "unc_cha_tor_occupancy.isoc\000uncore_cha\000uncore cache\000TOR Occupancy : Just ISOC. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just ISOC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3380354 */ "unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA and IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff05\000\00001\000TOR Occupancy : All from Local iA and IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000"
/* offset=3380779 */ "unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA and IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff05\000\00001\000TOR Occupancy : All from Local iA and IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally initiated requests\000"
/* offset=3381136 */ "unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.ALL_FROM_LOC. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000"
/* offset=3381316 */ "unc_cha_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA. Unit: uncore_cha \000event=0x36,umask=0xc000ff01\000\00001\000TOR Occupancy : All from Local iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000"
/* offset=3381740 */ "unc_cha_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA. Unit: uncore_cha \000event=0x36,umask=0xc000ff01\000\00001\000TOR Occupancy : All from Local iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally initiated requests from iA Cores\000"
/* offset=3382096 */ "unc_cha_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff04\000\00001\000TOR Occupancy : All from Local IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000"
/* offset=3382508 */ "unc_cha_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff04\000\00001\000TOR Occupancy : All from Local IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally generated IO traffic\000"
/* offset=3382852 */ "unc_cha_tor_occupancy.local_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Local Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Local Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3383216 */ "unc_cha_tor_occupancy.local_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Local Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Local Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3383513 */ "unc_cha_tor_occupancy.match_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3383953 */ "unc_cha_tor_occupancy.match_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3384326 */ "unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy : Just Misses. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Misses : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3384671 */ "unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy : Just Misses. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Misses : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3384949 */ "unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy; Miss. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000"
/* offset=3385702 */ "unc_cha_tor_occupancy.mmcfg\000uncore_cha\000uncore cache\000TOR Occupancy : MMCFG Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMCFG Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3386050 */ "unc_cha_tor_occupancy.mmcfg\000uncore_cha\000uncore cache\000TOR Occupancy : MMCFG Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMCFG Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3386331 */ "unc_cha_tor_occupancy.mmio\000uncore_cha\000uncore cache\000TOR Occupancy : MMIO Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMIO Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3386609 */ "unc_cha_tor_occupancy.nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3386959 */ "unc_cha_tor_occupancy.nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3387242 */ "unc_cha_tor_occupancy.noncoh\000uncore_cha\000uncore cache\000TOR Occupancy : Just NonCoherent. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NonCoherent : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3387599 */ "unc_cha_tor_occupancy.noncoh\000uncore_cha\000uncore cache\000TOR Occupancy : Just NonCoherent. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NonCoherent : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3387889 */ "unc_cha_tor_occupancy.not_nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NotNearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NotNearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3388249 */ "unc_cha_tor_occupancy.not_nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NotNearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NotNearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3388542 */ "unc_cha_tor_occupancy.pmm\000uncore_cha\000uncore cache\000TOR Occupancy : PMM Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : PMM Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3388884 */ "unc_cha_tor_occupancy.pmm\000uncore_cha\000uncore cache\000TOR Occupancy : PMM Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : PMM Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent\000"
/* offset=3389154 */ "unc_cha_tor_occupancy.premorph_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3389619 */ "unc_cha_tor_occupancy.premorph_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3390017 */ "unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - IOSF. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000TOR Occupancy : PRQ - IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000"
/* offset=3390391 */ "unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - IOSF. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000TOR Occupancy : PRQ - IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : From a PCIe Device\000"
/* offset=3390697 */ "unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy; PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3390945 */ "unc_cha_tor_occupancy.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - Non IOSF. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000TOR Occupancy : PRQ - Non IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3391315 */ "unc_cha_tor_occupancy.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - Non IOSF. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000TOR Occupancy : PRQ - Non IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3391618 */ "unc_cha_tor_occupancy.rem_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ffc8\000\00001\000TOR Occupancy : All from Remote : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All remote requests (e.g. snoops, writebacks) that came from remote sockets\000"
/* offset=3392002 */ "unc_cha_tor_occupancy.rem_snps\000uncore_cha\000uncore cache\000TOR Occupancy : All Snoops from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ff08\000\00001\000TOR Occupancy : All Snoops from Remote : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All snoops to this LLC that came from remote sockets\000"
/* offset=3392378 */ "unc_cha_tor_occupancy.remote_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Remote Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Remote Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000"
/* offset=3392745 */ "unc_cha_tor_occupancy.remote_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Remote Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Remote Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3393045 */ "unc_cha_tor_occupancy.rrq\000uncore_cha\000uncore cache\000TOR Occupancy : RRQ. Unit: uncore_cha \000event=0x36,umask=0x40\000\00001\000TOR Occupancy : RRQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3393317 */ "unc_cha_tor_occupancy.snps_from_rem\000uncore_cha\000uncore cache\000TOR Occupancy; All Snoops from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ff08\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   All snoops to this LLC that came from remote sockets\000"
/* offset=3393652 */ "unc_cha_tor_occupancy.wbq\000uncore_cha\000uncore cache\000TOR Occupancy : WBQ. Unit: uncore_cha \000event=0x36,umask=0x80\000\00001\000TOR Occupancy : WBQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000"
/* offset=3393924 */ "unc_cha_txr_horz_ads_used.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - All. Unit: uncore_cha \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=3394228 */ "unc_cha_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3394464 */ "unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_cha \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3394746 */ "unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3394983 */ "unc_cha_txr_horz_ads_used.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3395270 */ "unc_cha_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3395506 */ "unc_cha_txr_horz_ads_used.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - All. Unit: uncore_cha \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=3395810 */ "unc_cha_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3396046 */ "unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_cha \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3396328 */ "unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3396565 */ "unc_cha_txr_horz_ads_used.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3396852 */ "unc_cha_txr_horz_bypass.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_cha \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=3397152 */ "unc_cha_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3397381 */ "unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_cha \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3397659 */ "unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3397889 */ "unc_cha_txr_horz_bypass.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3398172 */ "unc_cha_txr_horz_bypass.ak\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AK. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3398423 */ "unc_cha_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3398652 */ "unc_cha_txr_horz_bypass.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3398939 */ "unc_cha_txr_horz_bypass.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_cha \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=3399239 */ "unc_cha_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3399468 */ "unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_cha \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3399746 */ "unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3399976 */ "unc_cha_txr_horz_bypass.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3400259 */ "unc_cha_txr_horz_bypass.iv\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : IV. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3400510 */ "unc_cha_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=3400739 */ "unc_cha_txr_horz_cycles_full.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_cha \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3401136 */ "unc_cha_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3401446 */ "unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_cha \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3401821 */ "unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3402132 */ "unc_cha_txr_horz_cycles_full.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3402512 */ "unc_cha_txr_horz_cycles_full.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3402860 */ "unc_cha_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3403170 */ "unc_cha_txr_horz_cycles_full.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3403554 */ "unc_cha_txr_horz_cycles_full.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_cha \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3403951 */ "unc_cha_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3404261 */ "unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_cha \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3404636 */ "unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3404947 */ "unc_cha_txr_horz_cycles_full.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3405327 */ "unc_cha_txr_horz_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3405675 */ "unc_cha_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3405985 */ "unc_cha_txr_horz_cycles_ne.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_cha \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3406395 */ "unc_cha_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3406713 */ "unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_cha \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3407101 */ "unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_cha \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3407420 */ "unc_cha_txr_horz_cycles_ne.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3407813 */ "unc_cha_txr_horz_cycles_ne.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3408174 */ "unc_cha_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3408492 */ "unc_cha_txr_horz_cycles_ne.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3408889 */ "unc_cha_txr_horz_cycles_ne.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_cha \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3409299 */ "unc_cha_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_cha \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3409617 */ "unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_cha \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3410005 */ "unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_cha \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3410324 */ "unc_cha_txr_horz_cycles_ne.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3410717 */ "unc_cha_txr_horz_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3411078 */ "unc_cha_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_cha \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3411396 */ "unc_cha_txr_horz_inserts.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_cha \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3411773 */ "unc_cha_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3412076 */ "unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_cha \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3412431 */ "unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_cha \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3412735 */ "unc_cha_txr_horz_inserts.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3413095 */ "unc_cha_txr_horz_inserts.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3413423 */ "unc_cha_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3413726 */ "unc_cha_txr_horz_inserts.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3414090 */ "unc_cha_txr_horz_inserts.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_cha \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3414467 */ "unc_cha_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_cha \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3414770 */ "unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_cha \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3415125 */ "unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_cha \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3415429 */ "unc_cha_txr_horz_inserts.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3415789 */ "unc_cha_txr_horz_inserts.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3416117 */ "unc_cha_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_cha \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3416420 */ "unc_cha_txr_horz_nack.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_cha \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=3416695 */ "unc_cha_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3416899 */ "unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_cha \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3417153 */ "unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_cha \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3417358 */ "unc_cha_txr_horz_nack.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3417617 */ "unc_cha_txr_horz_nack.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AK. Unit: uncore_cha \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3417844 */ "unc_cha_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3418048 */ "unc_cha_txr_horz_nack.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3418311 */ "unc_cha_txr_horz_nack.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_cha \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=3418586 */ "unc_cha_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_cha \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3418790 */ "unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_cha \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3419044 */ "unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_cha \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3419249 */ "unc_cha_txr_horz_nack.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3419508 */ "unc_cha_txr_horz_nack.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : IV. Unit: uncore_cha \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3419735 */ "unc_cha_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_cha \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=3419939 */ "unc_cha_txr_horz_occupancy.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_cha \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3420315 */ "unc_cha_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3420615 */ "unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3420969 */ "unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3421270 */ "unc_cha_txr_horz_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3421629 */ "unc_cha_txr_horz_occupancy.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3421956 */ "unc_cha_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3422256 */ "unc_cha_txr_horz_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3422619 */ "unc_cha_txr_horz_occupancy.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_cha \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=3422995 */ "unc_cha_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3423295 */ "unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3423649 */ "unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3423950 */ "unc_cha_txr_horz_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3424309 */ "unc_cha_txr_horz_occupancy.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3424636 */ "unc_cha_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=3424936 */ "unc_cha_txr_horz_starved.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=3425345 */ "unc_cha_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3425668 */ "unc_cha_txr_horz_starved.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3426061 */ "unc_cha_txr_horz_starved.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3426422 */ "unc_cha_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3426745 */ "unc_cha_txr_horz_starved.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3427142 */ "unc_cha_txr_horz_starved.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=3427551 */ "unc_cha_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3427874 */ "unc_cha_txr_horz_starved.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3428267 */ "unc_cha_txr_horz_starved.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_cha \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3428628 */ "unc_cha_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=3428951 */ "unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3429224 */ "unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3429457 */ "unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3429731 */ "unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3429965 */ "unc_cha_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3430198 */ "unc_cha_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3430432 */ "unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3430705 */ "unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3430938 */ "unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3431212 */ "unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=3431446 */ "unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3431709 */ "unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3431932 */ "unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3432196 */ "unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3432420 */ "unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3432683 */ "unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3432906 */ "unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3433170 */ "unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3433394 */ "unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3433657 */ "unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3433880 */ "unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3434144 */ "unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3434368 */ "unc_cha_txr_vert_bypass.iv\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3434577 */ "unc_cha_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3434840 */ "unc_cha_txr_vert_bypass_1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3435108 */ "unc_cha_txr_vert_bypass_1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=3435376 */ "unc_cha_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3435814 */ "unc_cha_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3436221 */ "unc_cha_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3436641 */ "unc_cha_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3437002 */ "unc_cha_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3437438 */ "unc_cha_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3437868 */ "unc_cha_txr_vert_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3438262 */ "unc_cha_txr_vert_cycles_full0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3438761 */ "unc_cha_txr_vert_cycles_full0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3439229 */ "unc_cha_txr_vert_cycles_full0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3439710 */ "unc_cha_txr_vert_cycles_full0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3440132 */ "unc_cha_txr_vert_cycles_full0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3440629 */ "unc_cha_txr_vert_cycles_full0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3441120 */ "unc_cha_txr_vert_cycles_full0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3441589 */ "unc_cha_txr_vert_cycles_full1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3442091 */ "unc_cha_txr_vert_cycles_full1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3442575 */ "unc_cha_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3443017 */ "unc_cha_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3443428 */ "unc_cha_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3443852 */ "unc_cha_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3444217 */ "unc_cha_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3444657 */ "unc_cha_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3445091 */ "unc_cha_txr_vert_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3445489 */ "unc_cha_txr_vert_cycles_ne0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3445997 */ "unc_cha_txr_vert_cycles_ne0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3446474 */ "unc_cha_txr_vert_cycles_ne0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3446964 */ "unc_cha_txr_vert_cycles_ne0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3447395 */ "unc_cha_txr_vert_cycles_ne0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3447901 */ "unc_cha_txr_vert_cycles_ne0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3448401 */ "unc_cha_txr_vert_cycles_ne0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3448879 */ "unc_cha_txr_vert_cycles_ne1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3449390 */ "unc_cha_txr_vert_cycles_ne1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3449883 */ "unc_cha_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3450301 */ "unc_cha_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3450688 */ "unc_cha_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3451088 */ "unc_cha_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3451429 */ "unc_cha_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3451845 */ "unc_cha_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3452255 */ "unc_cha_txr_vert_inserts.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3452629 */ "unc_cha_txr_vert_inserts0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3453095 */ "unc_cha_txr_vert_inserts0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3453530 */ "unc_cha_txr_vert_inserts0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3453978 */ "unc_cha_txr_vert_inserts0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3454367 */ "unc_cha_txr_vert_inserts0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3454831 */ "unc_cha_txr_vert_inserts0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3455289 */ "unc_cha_txr_vert_inserts0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3455725 */ "unc_cha_txr_vert_inserts1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3456194 */ "unc_cha_txr_vert_inserts1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3456645 */ "unc_cha_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3456846 */ "unc_cha_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3457048 */ "unc_cha_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3457249 */ "unc_cha_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3457451 */ "unc_cha_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3457652 */ "unc_cha_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3457854 */ "unc_cha_txr_vert_nack.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3458041 */ "unc_cha_txr_vert_nack0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3458287 */ "unc_cha_txr_vert_nack0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3458534 */ "unc_cha_txr_vert_nack0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3458780 */ "unc_cha_txr_vert_nack0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3459027 */ "unc_cha_txr_vert_nack0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3459273 */ "unc_cha_txr_vert_nack0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3459520 */ "unc_cha_txr_vert_nack0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3459746 */ "unc_cha_txr_vert_nack1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3459995 */ "unc_cha_txr_vert_nack1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=3460244 */ "unc_cha_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3460669 */ "unc_cha_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3461063 */ "unc_cha_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3461470 */ "unc_cha_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3461818 */ "unc_cha_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3462241 */ "unc_cha_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3462658 */ "unc_cha_txr_vert_occupancy.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3463039 */ "unc_cha_txr_vert_occupancy0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3463510 */ "unc_cha_txr_vert_occupancy0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=3463950 */ "unc_cha_txr_vert_occupancy0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3464403 */ "unc_cha_txr_vert_occupancy0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=3464797 */ "unc_cha_txr_vert_occupancy0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=3465266 */ "unc_cha_txr_vert_occupancy0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=3465729 */ "unc_cha_txr_vert_occupancy0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=3466170 */ "unc_cha_txr_vert_occupancy1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=3466644 */ "unc_cha_txr_vert_occupancy1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=3467100 */ "unc_cha_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3467409 */ "unc_cha_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3467719 */ "unc_cha_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3468028 */ "unc_cha_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3468338 */ "unc_cha_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3468647 */ "unc_cha_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3468957 */ "unc_cha_txr_vert_starved.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3469252 */ "unc_cha_txr_vert_starved0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3469621 */ "unc_cha_txr_vert_starved0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3469991 */ "unc_cha_txr_vert_starved0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3470360 */ "unc_cha_txr_vert_starved0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3470730 */ "unc_cha_txr_vert_starved0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3471099 */ "unc_cha_txr_vert_starved0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3471469 */ "unc_cha_txr_vert_starved0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3471818 */ "unc_cha_txr_vert_starved1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3472190 */ "unc_cha_txr_vert_starved1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3472562 */ "unc_cha_txr_vert_starved1.tgc\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=3472930 */ "unc_cha_upi_credit_occupancy.vn0_ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD REQ VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x4\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3473763 */ "unc_cha_upi_credit_occupancy.vn0_ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x8\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3474596 */ "unc_cha_upi_credit_occupancy.vn0_bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCB VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x40\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3475430 */ "unc_cha_upi_credit_occupancy.vn0_bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x80\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3476264 */ "unc_cha_upi_credit_occupancy.vn0_bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x10\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3477098 */ "unc_cha_upi_credit_occupancy.vn0_bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL DRS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x20\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3477931 */ "unc_cha_upi_credit_occupancy.vna_ad\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x1\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3478756 */ "unc_cha_upi_credit_occupancy.vna_bl\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x2\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3479581 */ "unc_cha_upi_credits_acquired.ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD REQ Credits. Unit: uncore_cha \000event=0x38,umask=0x4\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3480300 */ "unc_cha_upi_credits_acquired.ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x8\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3481023 */ "unc_cha_upi_credits_acquired.bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCB Credits. Unit: uncore_cha \000event=0x38,umask=0x40\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3481743 */ "unc_cha_upi_credits_acquired.bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCS Credits. Unit: uncore_cha \000event=0x38,umask=0x80\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3482463 */ "unc_cha_upi_credits_acquired.bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL RSP Credits. Unit: uncore_cha \000event=0x38,umask=0x10\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3483183 */ "unc_cha_upi_credits_acquired.bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL DRS Credits. Unit: uncore_cha \000event=0x38,umask=0x20\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3483902 */ "unc_cha_upi_credits_acquired.vn0\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x2\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3484615 */ "unc_cha_upi_credits_acquired.vna\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VNA Credits. Unit: uncore_cha \000event=0x38,umask=0x1\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000"
/* offset=3485328 */ "unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3486241 */ "unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3487111 */ "unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3488021 */ "unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3488889 */ "unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3489798 */ "unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3490666 */ "unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3491572 */ "unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3492438 */ "unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3493351 */ "unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3494221 */ "unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3495131 */ "unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3495999 */ "unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3496908 */ "unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3497776 */ "unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3498682 */ "unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3499548 */ "unc_cha_vert_ring_akc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3500469 */ "unc_cha_vert_ring_akc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3501387 */ "unc_cha_vert_ring_akc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3502304 */ "unc_cha_vert_ring_akc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3503218 */ "unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Even. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3504129 */ "unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Even. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3504997 */ "unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3505905 */ "unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3506771 */ "unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Even. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3507678 */ "unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Even. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3508544 */ "unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3509448 */ "unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3510312 */ "unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Down. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=3510897 */ "unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Down. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=3511448 */ "unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Up. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=3512029 */ "unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Up. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=3512578 */ "unc_cha_vert_ring_tgc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3513499 */ "unc_cha_vert_ring_tgc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3514417 */ "unc_cha_vert_ring_tgc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3515334 */ "unc_cha_vert_ring_tgc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=3516248 */ "unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000WbPushMtoI : Pushed to LLC : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was able to push WbPushMToI to LLC\000"
/* offset=3516538 */ "unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was able to push WbPushMToI to LLC\000"
/* offset=3516797 */ "unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000WbPushMtoI : Pushed to Memory : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000"
/* offset=3517120 */ "unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000"
/* offset=3517409 */ "unc_cha_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 2 only\000"
/* offset=3517822 */ "unc_cha_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 3 only\000"
/* offset=3518235 */ "unc_cha_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 4 only\000"
/* offset=3518649 */ "unc_cha_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 5 only\000"
/* offset=3519063 */ "unc_cha_write_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC0 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 0 only\000"
/* offset=3519507 */ "unc_cha_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 0 only\000"
/* offset=3519918 */ "unc_cha_write_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC10. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC10 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 10 only\000"
/* offset=3520356 */ "unc_cha_write_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC11. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC11 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 11 only\000"
/* offset=3520794 */ "unc_cha_write_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC12. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC12 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 12 only\000"
/* offset=3521232 */ "unc_cha_write_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC13. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC13 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 13 only\000"
/* offset=3521670 */ "unc_cha_write_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC1 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 1 only\000"
/* offset=3522114 */ "unc_cha_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 1 only\000"
/* offset=3522525 */ "unc_cha_write_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC2 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 2 only\000"
/* offset=3522969 */ "unc_cha_write_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC3 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 3 only\000"
/* offset=3523413 */ "unc_cha_write_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC4 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 4 only\000"
/* offset=3523858 */ "unc_cha_write_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC5 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 5 only\000"
/* offset=3524303 */ "unc_cha_write_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC6. Unit: uncore_cha \000event=0x5a,umask=0x40\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC6 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 6 only\000"
/* offset=3524748 */ "unc_cha_write_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC7. Unit: uncore_cha \000event=0x5a,umask=0x80\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC7 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 7 only\000"
/* offset=3525193 */ "unc_cha_write_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC8. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC8 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 8 only\000"
/* offset=3525627 */ "unc_cha_write_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC9. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC9 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 9 only\000"
/* offset=3526061 */ "unc_cha_xpt_pref.drop0_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x8\000\00001\000XPT Prefetches : Dropped (on 0?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000"
/* offset=3526320 */ "unc_cha_xpt_pref.drop0_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x4\000\00001\000XPT Prefetches : Dropped (on 0?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000"
/* offset=3526581 */ "unc_cha_xpt_pref.drop1_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x80\000\00001\000XPT Prefetches : Dropped (on 1?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000"
/* offset=3526841 */ "unc_cha_xpt_pref.drop1_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x40\000\00001\000XPT Prefetches : Dropped (on 1?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000"
/* offset=3527103 */ "unc_cha_xpt_pref.sent0\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 0?). Unit: uncore_cha \000event=0x6f,umask=0x1\000\00001\000XPT Prefetches : Sent (on 0?) : Number of XPT prefetches sent\000"
/* offset=3527286 */ "unc_cha_xpt_pref.sent1\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 1?). Unit: uncore_cha \000event=0x6f,umask=0x10\000\00001\000XPT Prefetches : Sent (on 1?) : Number of XPT prefetches sent\000"
/* offset=3527470 */ "unc_cha_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response any to Hit F/S/E\000"
/* offset=3528109 */ "unc_cha_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd F/E\000"
/* offset=3528744 */ "unc_cha_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd M\000"
/* offset=3529361 */ "unc_cha_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd F/E\000"
/* offset=3529996 */ "unc_cha_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd M\000"
/* offset=3530627 */ "unc_cha_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response any to Hit F/S/E\000"
/* offset=3531269 */ "unc_cha_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd F/E\000"
/* offset=3531907 */ "unc_cha_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd M\000"
/* offset=3532541 */ "unc_cha_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd F/E\000"
/* offset=3533179 */ "unc_cha_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd M\000"
/* offset=3533813 */ "unc_cha_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response any to Hit F/S/E\000"
/* offset=3534461 */ "unc_cha_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd F/E\000"
/* offset=3535105 */ "unc_cha_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd M\000"
/* offset=3535745 */ "unc_cha_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd F/E\000"
/* offset=3536389 */ "unc_cha_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd M\000"
/* offset=3537029 */ "unc_cha_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response any to Hit F/S/E\000"
/* offset=3537678 */ "unc_cha_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd F/E\000"
/* offset=3538323 */ "unc_cha_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd M\000"
/* offset=3538964 */ "unc_cha_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd F/E\000"
/* offset=3539609 */ "unc_cha_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd M\000"
/* offset=3540250 */ "unc_clock.socket\000uncore_arb\000uncore interconnect\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_arb \000event=0xff\000\00001\000\000"
/* offset=3540382 */ "unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000This 48-bit fixed counter counts the UCLK cycles\000"
/* offset=3540559 */ "unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000\000"
/* offset=3540688 */ "unc_clock.socket\000uncore_clock\000uncore other\000UNC_CLOCK.SOCKET. Unit: uncore_clock \000event=0xff\000\00001\000\000"
/* offset=3540785 */ "unc_cxlcm_clockticks\000uncore_cxlcm\000uncore cxl\000Counts the number of lfclk ticks. Unit: uncore_cxlcm \000event=0x1,umask=0x2\000\00001\000\000"
/* offset=3540909 */ "unc_cxlcm_rxc_agf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx AGF 0. Unit: uncore_cxlcm \000event=0x43,umask=0x8\000\00001\000\000"
/* offset=3541055 */ "unc_cxlcm_rxc_agf_inserts.cache_req0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req AGF0. Unit: uncore_cxlcm \000event=0x43,umask=0x1\000\00001\000\000"
/* offset=3541202 */ "unc_cxlcm_rxc_agf_inserts.cache_req1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x2\000\00001\000\000"
/* offset=3541348 */ "unc_cxlcm_rxc_agf_inserts.cache_rsp0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x4\000\00001\000\000"
/* offset=3541495 */ "unc_cxlcm_rxc_agf_inserts.cache_rsp1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x40\000\00001\000\000"
/* offset=3541642 */ "unc_cxlcm_rxc_agf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req AGF 1. Unit: uncore_cxlcm \000event=0x43,umask=0x20\000\00001\000\000"
/* offset=3541789 */ "unc_cxlcm_rxc_agf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x10\000\00001\000\000"
/* offset=3541932 */ "unc_cxlcm_rxc_flits.ak_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with AK set. Unit: uncore_cxlcm \000event=0x4b,umask=0x10\000\00001\000\000"
/* offset=3542069 */ "unc_cxlcm_rxc_flits.be_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with BE set. Unit: uncore_cxlcm \000event=0x4b,umask=0x20\000\00001\000\000"
/* offset=3542206 */ "unc_cxlcm_rxc_flits.ctrl\000uncore_cxlcm\000uncore cxl\000Count the number of control flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x4\000\00001\000\000"
/* offset=3542345 */ "unc_cxlcm_rxc_flits.no_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Headerless flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x8\000\00001\000\000"
/* offset=3542489 */ "unc_cxlcm_rxc_flits.prot\000uncore_cxlcm\000uncore cxl\000Count the number of protocol flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x2\000\00001\000\000"
/* offset=3542629 */ "unc_cxlcm_rxc_flits.sz_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with SZ set. Unit: uncore_cxlcm \000event=0x4b,umask=0x40\000\00001\000\000"
/* offset=3542766 */ "unc_cxlcm_rxc_flits.valid\000uncore_cxlcm\000uncore cxl\000Count the number of flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x1\000\00001\000\000"
/* offset=3542898 */ "unc_cxlcm_rxc_flits.valid_msg\000uncore_cxlcm\000uncore cxl\000Count the number of valid messages in the flit. Unit: uncore_cxlcm \000event=0x4b,umask=0x80\000\00001\000\000"
/* offset=3543047 */ "unc_cxlcm_rxc_misc.crc_errors\000uncore_cxlcm\000uncore cxl\000Count the number of CRC errors detected. Unit: uncore_cxlcm \000event=0x40,umask=0x8\000\00001\000\000"
/* offset=3543188 */ "unc_cxlcm_rxc_misc.init\000uncore_cxlcm\000uncore cxl\000Count the number of Init flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x4\000\00001\000\000"
/* offset=3543319 */ "unc_cxlcm_rxc_misc.llcrd\000uncore_cxlcm\000uncore cxl\000Count the number of LLCRD flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=3543452 */ "unc_cxlcm_rxc_misc.retry\000uncore_cxlcm\000uncore cxl\000Count the number of Retry flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=3543585 */ "unc_cxlcm_rxc_pack_buf_full.cache_data\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x4\000\00001\000\000"
/* offset=3543739 */ "unc_cxlcm_rxc_pack_buf_full.cache_req\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x1\000\00001\000\000"
/* offset=3543892 */ "unc_cxlcm_rxc_pack_buf_full.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x2\000\00001\000\000"
/* offset=3544045 */ "unc_cxlcm_rxc_pack_buf_full.mem_data\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x10\000\00001\000\000"
/* offset=3544198 */ "unc_cxlcm_rxc_pack_buf_full.mem_req\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x8\000\00001\000\000"
/* offset=3544349 */ "unc_cxlcm_rxc_pack_buf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x4\000\00001\000\000"
/* offset=3544512 */ "unc_cxlcm_rxc_pack_buf_inserts.cache_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x1\000\00001\000\000"
/* offset=3544673 */ "unc_cxlcm_rxc_pack_buf_inserts.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x2\000\00001\000\000"
/* offset=3544834 */ "unc_cxlcm_rxc_pack_buf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x10\000\00001\000\000"
/* offset=3544994 */ "unc_cxlcm_rxc_pack_buf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x8\000\00001\000\000"
/* offset=3545151 */ "unc_cxlcm_rxc_pack_buf_ne.cache_data\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x4\000\00001\000\000"
/* offset=3545319 */ "unc_cxlcm_rxc_pack_buf_ne.cache_req\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x1\000\00001\000\000"
/* offset=3545485 */ "unc_cxlcm_rxc_pack_buf_ne.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Rsp Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x2\000\00001\000\000"
/* offset=3545651 */ "unc_cxlcm_rxc_pack_buf_ne.mem_data\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x10\000\00001\000\000"
/* offset=3545816 */ "unc_cxlcm_rxc_pack_buf_ne.mem_req\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x8\000\00001\000\000"
/* offset=3545978 */ "unc_cxlcm_txc_flits.ak_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with AK set. Unit: uncore_cxlcm \000event=0x5,umask=0x10\000\00001\000\000"
/* offset=3546114 */ "unc_cxlcm_txc_flits.be_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with BE set. Unit: uncore_cxlcm \000event=0x5,umask=0x20\000\00001\000\000"
/* offset=3546250 */ "unc_cxlcm_txc_flits.ctrl\000uncore_cxlcm\000uncore cxl\000Count the number of control flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=3546386 */ "unc_cxlcm_txc_flits.no_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Headerless flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x8\000\00001\000\000"
/* offset=3546527 */ "unc_cxlcm_txc_flits.prot\000uncore_cxlcm\000uncore cxl\000Count the number of protocol flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=3546664 */ "unc_cxlcm_txc_flits.sz_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with SZ set. Unit: uncore_cxlcm \000event=0x5,umask=0x40\000\00001\000\000"
/* offset=3546800 */ "unc_cxlcm_txc_flits.valid\000uncore_cxlcm\000uncore cxl\000Count the number of flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x1\000\00001\000\000"
/* offset=3546929 */ "unc_cxlcm_txc_pack_buf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x4\000\00001\000\000"
/* offset=3547091 */ "unc_cxlcm_txc_pack_buf_inserts.cache_req0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=3547252 */ "unc_cxlcm_txc_pack_buf_inserts.cache_req1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp1 Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x40\000\00001\000\000"
/* offset=3547415 */ "unc_cxlcm_txc_pack_buf_inserts.cache_rsp0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp0 Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x2\000\00001\000\000"
/* offset=3547577 */ "unc_cxlcm_txc_pack_buf_inserts.cache_rsp1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x20\000\00001\000\000"
/* offset=3547739 */ "unc_cxlcm_txc_pack_buf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x10\000\00001\000\000"
/* offset=3547898 */ "unc_cxlcm_txc_pack_buf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x8\000\00001\000\000"
/* offset=3548054 */ "unc_cxldp_clockticks\000uncore_cxldp\000uncore cxl\000Counts the number of uclk ticks. Unit: uncore_cxldp \000event=0x1,umask=0x1\000\00001\000\000"
/* offset=3548177 */ "unc_cxldp_txc_agf_inserts.m2s_data\000uncore_cxldp\000uncore cxl\000Number of Allocation to M2S Data AGF. Unit: uncore_cxldp \000event=0x2,umask=0x20\000\00001\000\000"
/* offset=3548320 */ "unc_cxldp_txc_agf_inserts.m2s_req\000uncore_cxldp\000uncore cxl\000Number of Allocation to M2S Req AGF. Unit: uncore_cxldp \000event=0x2,umask=0x10\000\00001\000\000"
/* offset=3548461 */ "unc_cxldp_txc_agf_inserts.u2c_data\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Data AGF. Unit: uncore_cxldp \000event=0x2,umask=0x8\000\00001\000\000"
/* offset=3548603 */ "unc_cxldp_txc_agf_inserts.u2c_req\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Req AGF. Unit: uncore_cxldp \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=3548743 */ "unc_cxldp_txc_agf_inserts.u2c_rsp0\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Rsp AGF 0. Unit: uncore_cxldp \000event=0x2,umask=0x2\000\00001\000\000"
/* offset=3548886 */ "unc_cxldp_txc_agf_inserts.u2c_rsp1\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Rsp AGF 1. Unit: uncore_cxldp \000event=0x2,umask=0x4\000\00001\000\000"
/* offset=3549029 */ "unc_e_e_clockticks\000uncore_edc_eclk\000uncore memory\000ECLK count. Unit: uncore_edc_eclk \000event=0\000\00001\000\000"
/* offset=3549126 */ "unc_e_edc_access.hit_clean\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that hit in MCDRAM cache and the data in MCDRAM is clean with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=3549423 */ "unc_e_edc_access.hit_dirty\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that hit in MCDRAM cache and the data in MCDRAM is dirty with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x2\000\00001\000\000"
/* offset=3549720 */ "unc_e_edc_access.miss_clean\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that miss in MCDRAM cache and the data evicted from the MCDRAM is clean with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x4\000\00001\000\000"
/* offset=3550033 */ "unc_e_edc_access.miss_dirty\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that miss in MCDRAM cache and the data evicted from the MCDRAM is dirty with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x8\000\00001\000\000"
/* offset=3550346 */ "unc_e_edc_access.miss_invalid\000uncore_edc_uclk\000uncore memory\000Number of EDC Hits or Misses. Miss I. Unit: uncore_edc_uclk \000event=0x2,umask=0x10\000\00001\000\000"
/* offset=3550493 */ "unc_e_rpq_inserts\000uncore_edc_eclk\000uncore memory\000Counts the number of read requests received by the MCDRAM controller. This event is valid in all three memory modes: flat, cache and hybrid. In cache and hybrid memory mode, this event counts all read requests as well as streaming stores that hit or miss in the MCDRAM cache. Unit: uncore_edc_eclk \000event=0x1,umask=0x1\000\00001\000\000"
/* offset=3550865 */ "unc_e_u_clockticks\000uncore_edc_uclk\000uncore memory\000UCLK count. Unit: uncore_edc_uclk \000event=0\000\00001\000\000"
/* offset=3550962 */ "unc_e_wpq_inserts\000uncore_edc_eclk\000uncore memory\000Counts the number of write requests received by the MCDRAM controller. This event is valid in all three memory modes: flat, cache and hybrid. In cache and hybrid memory mode, this event counts all streaming stores, writebacks and, read requests that miss in MCDRAM cache. Unit: uncore_edc_eclk \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=3551330 */ "unc_h_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000\000"
/* offset=3551478 */ "unc_h_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00011\000\000"
/* offset=3551656 */ "unc_h_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000\000"
/* offset=3551804 */ "unc_h_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00011\000\000"
/* offset=3551982 */ "unc_h_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000\000"
/* offset=3552130 */ "unc_h_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00011\000\000"
/* offset=3552308 */ "unc_h_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000\000"
/* offset=3552456 */ "unc_h_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00011\000\000"
/* offset=3552634 */ "unc_h_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000\000"
/* offset=3552783 */ "unc_h_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00011\000\000"
/* offset=3552962 */ "unc_h_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000\000"
/* offset=3553111 */ "unc_h_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00011\000\000"
/* offset=3553290 */ "unc_h_ag0_ad_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x80,umask=0x40\000\00001\000\000"
/* offset=3553439 */ "unc_h_ag0_ad_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x80,umask=0x80\000\00001\000\000"
/* offset=3553588 */ "unc_h_ag0_ad_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=3553759 */ "unc_h_ag0_ad_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=3553911 */ "unc_h_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000\000"
/* offset=3554061 */ "unc_h_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00011\000\000"
/* offset=3554241 */ "unc_h_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000\000"
/* offset=3554391 */ "unc_h_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00011\000\000"
/* offset=3554571 */ "unc_h_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000\000"
/* offset=3554721 */ "unc_h_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00011\000\000"
/* offset=3554901 */ "unc_h_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000\000"
/* offset=3555051 */ "unc_h_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00011\000\000"
/* offset=3555231 */ "unc_h_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000\000"
/* offset=3555382 */ "unc_h_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00011\000\000"
/* offset=3555563 */ "unc_h_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000\000"
/* offset=3555714 */ "unc_h_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00011\000\000"
/* offset=3555895 */ "unc_h_ag0_ad_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x82,umask=0x40\000\00001\000\000"
/* offset=3556046 */ "unc_h_ag0_ad_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x82,umask=0x80\000\00001\000\000"
/* offset=3556197 */ "unc_h_ag0_ad_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x83,umask=0x2\000\00001\000\000"
/* offset=3556370 */ "unc_h_ag0_ad_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x83,umask=0x1\000\00001\000\000"
/* offset=3556524 */ "unc_h_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000\000"
/* offset=3556672 */ "unc_h_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00011\000\000"
/* offset=3556850 */ "unc_h_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000\000"
/* offset=3556998 */ "unc_h_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00011\000\000"
/* offset=3557176 */ "unc_h_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000\000"
/* offset=3557324 */ "unc_h_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00011\000\000"
/* offset=3557502 */ "unc_h_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000\000"
/* offset=3557650 */ "unc_h_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00011\000\000"
/* offset=3557828 */ "unc_h_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000\000"
/* offset=3557977 */ "unc_h_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00011\000\000"
/* offset=3558156 */ "unc_h_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000\000"
/* offset=3558305 */ "unc_h_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00011\000\000"
/* offset=3558484 */ "unc_h_ag0_bl_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x88,umask=0x40\000\00001\000\000"
/* offset=3558633 */ "unc_h_ag0_bl_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x88,umask=0x80\000\00001\000\000"
/* offset=3558782 */ "unc_h_ag0_bl_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x89,umask=0x2\000\00001\000\000"
/* offset=3558953 */ "unc_h_ag0_bl_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x89,umask=0x1\000\00001\000\000"
/* offset=3559105 */ "unc_h_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000\000"
/* offset=3559255 */ "unc_h_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00011\000\000"
/* offset=3559435 */ "unc_h_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000\000"
/* offset=3559585 */ "unc_h_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00011\000\000"
/* offset=3559765 */ "unc_h_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000\000"
/* offset=3559915 */ "unc_h_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00011\000\000"
/* offset=3560095 */ "unc_h_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000\000"
/* offset=3560245 */ "unc_h_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00011\000\000"
/* offset=3560425 */ "unc_h_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000\000"
/* offset=3560576 */ "unc_h_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00011\000\000"
/* offset=3560757 */ "unc_h_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000\000"
/* offset=3560908 */ "unc_h_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00011\000\000"
/* offset=3561089 */ "unc_h_ag0_bl_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x8a,umask=0x40\000\00001\000\000"
/* offset=3561240 */ "unc_h_ag0_bl_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x8a,umask=0x80\000\00001\000\000"
/* offset=3561391 */ "unc_h_ag0_bl_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x8b,umask=0x2\000\00001\000\000"
/* offset=3561564 */ "unc_h_ag0_bl_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x8b,umask=0x1\000\00001\000\000"
/* offset=3561718 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000\000"
/* offset=3561881 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000\000"
/* offset=3562044 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000\000"
/* offset=3562207 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000\000"
/* offset=3562370 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000\000"
/* offset=3562534 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000\000"
/* offset=3562698 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd0,umask=0x40\000\00001\000\000"
/* offset=3562862 */ "unc_h_ag0_stall_no_crd_egress_horz_ad.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd0,umask=0x80\000\00001\000\000"
/* offset=3563026 */ "unc_h_ag0_stall_no_crd_egress_horz_ad_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd1,umask=0x2\000\00001\000\000"
/* offset=3563212 */ "unc_h_ag0_stall_no_crd_egress_horz_ad_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd1,umask=0x1\000\00001\000\000"
/* offset=3563379 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000\000"
/* offset=3563542 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000\000"
/* offset=3563705 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000\000"
/* offset=3563868 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000\000"
/* offset=3564031 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000\000"
/* offset=3564195 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000\000"
/* offset=3564359 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd4,umask=0x40\000\00001\000\000"
/* offset=3564523 */ "unc_h_ag0_stall_no_crd_egress_horz_bl.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd4,umask=0x80\000\00001\000\000"
/* offset=3564687 */ "unc_h_ag0_stall_no_crd_egress_horz_bl_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd5,umask=0x2\000\00001\000\000"
/* offset=3564873 */ "unc_h_ag0_stall_no_crd_egress_horz_bl_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd5,umask=0x1\000\00001\000\000"
/* offset=3565040 */ "unc_h_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000\000"
/* offset=3565188 */ "unc_h_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00011\000\000"
/* offset=3565366 */ "unc_h_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000\000"
/* offset=3565514 */ "unc_h_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00011\000\000"
/* offset=3565692 */ "unc_h_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000\000"
/* offset=3565840 */ "unc_h_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00011\000\000"
/* offset=3566018 */ "unc_h_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000\000"
/* offset=3566166 */ "unc_h_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00011\000\000"
/* offset=3566344 */ "unc_h_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000\000"
/* offset=3566493 */ "unc_h_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00011\000\000"
/* offset=3566672 */ "unc_h_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000\000"
/* offset=3566821 */ "unc_h_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00011\000\000"
/* offset=3567000 */ "unc_h_ag1_ad_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x84,umask=0x40\000\00001\000\000"
/* offset=3567149 */ "unc_h_ag1_ad_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x84,umask=0x80\000\00001\000\000"
/* offset=3567298 */ "unc_h_ag1_ad_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x85,umask=0x2\000\00001\000\000"
/* offset=3567469 */ "unc_h_ag1_ad_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x85,umask=0x1\000\00001\000\000"
/* offset=3567621 */ "unc_h_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000\000"
/* offset=3567771 */ "unc_h_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00011\000\000"
/* offset=3567951 */ "unc_h_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000\000"
/* offset=3568101 */ "unc_h_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00011\000\000"
/* offset=3568281 */ "unc_h_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000\000"
/* offset=3568431 */ "unc_h_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00011\000\000"
/* offset=3568611 */ "unc_h_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000\000"
/* offset=3568761 */ "unc_h_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00011\000\000"
/* offset=3568941 */ "unc_h_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000\000"
/* offset=3569092 */ "unc_h_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00011\000\000"
/* offset=3569273 */ "unc_h_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000\000"
/* offset=3569424 */ "unc_h_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00011\000\000"
/* offset=3569605 */ "unc_h_ag1_ad_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x86,umask=0x40\000\00001\000\000"
/* offset=3569756 */ "unc_h_ag1_ad_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x86,umask=0x80\000\00001\000\000"
/* offset=3569907 */ "unc_h_ag1_ad_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x87,umask=0x2\000\00001\000\000"
/* offset=3570080 */ "unc_h_ag1_ad_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x87,umask=0x1\000\00001\000\000"
/* offset=3570234 */ "unc_h_ag1_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000\000"
/* offset=3570382 */ "unc_h_ag1_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000\000"
/* offset=3570530 */ "unc_h_ag1_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000\000"
/* offset=3570678 */ "unc_h_ag1_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000\000"
/* offset=3570826 */ "unc_h_ag1_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000\000"
/* offset=3570975 */ "unc_h_ag1_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000\000"
/* offset=3571124 */ "unc_h_ag1_bl_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x8c,umask=0x40\000\00001\000\000"
/* offset=3571273 */ "unc_h_ag1_bl_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x8c,umask=0x80\000\00001\000\000"
/* offset=3571422 */ "unc_h_ag1_bl_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x8d,umask=0x2\000\00001\000\000"
/* offset=3571593 */ "unc_h_ag1_bl_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x8d,umask=0x1\000\00001\000\000"
/* offset=3571745 */ "unc_h_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000\000"
/* offset=3571895 */ "unc_h_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00011\000\000"
/* offset=3572075 */ "unc_h_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000\000"
/* offset=3572225 */ "unc_h_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00011\000\000"
/* offset=3572405 */ "unc_h_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000\000"
/* offset=3572555 */ "unc_h_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00011\000\000"
/* offset=3572735 */ "unc_h_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000\000"
/* offset=3572885 */ "unc_h_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00011\000\000"
/* offset=3573065 */ "unc_h_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000\000"
/* offset=3573216 */ "unc_h_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00011\000\000"
/* offset=3573397 */ "unc_h_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000\000"
/* offset=3573548 */ "unc_h_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00011\000\000"
/* offset=3573729 */ "unc_h_ag1_bl_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x8e,umask=0x40\000\00001\000\000"
/* offset=3573880 */ "unc_h_ag1_bl_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x8e,umask=0x80\000\00001\000\000"
/* offset=3574031 */ "unc_h_ag1_bl_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x8f,umask=0x2\000\00001\000\000"
/* offset=3574204 */ "unc_h_ag1_bl_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x8f,umask=0x1\000\00001\000\000"
/* offset=3574358 */ "unc_h_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00011\000\000"
/* offset=3574544 */ "unc_h_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00011\000\000"
/* offset=3574730 */ "unc_h_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00011\000\000"
/* offset=3574916 */ "unc_h_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00011\000\000"
/* offset=3575102 */ "unc_h_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00011\000\000"
/* offset=3575289 */ "unc_h_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00011\000\000"
/* offset=3575476 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000\000"
/* offset=3575639 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000\000"
/* offset=3575802 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000\000"
/* offset=3575965 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000\000"
/* offset=3576128 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000\000"
/* offset=3576292 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000\000"
/* offset=3576456 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd2,umask=0x40\000\00001\000\000"
/* offset=3576620 */ "unc_h_ag1_stall_no_crd_egress_horz_ad.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd2,umask=0x80\000\00001\000\000"
/* offset=3576784 */ "unc_h_ag1_stall_no_crd_egress_horz_ad_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd3,umask=0x2\000\00001\000\000"
/* offset=3576970 */ "unc_h_ag1_stall_no_crd_egress_horz_ad_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd3,umask=0x1\000\00001\000\000"
/* offset=3577137 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000\000"
/* offset=3577300 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000\000"
/* offset=3577463 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000\000"
/* offset=3577626 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000\000"
/* offset=3577789 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000\000"
/* offset=3577953 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000\000"
/* offset=3578117 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd6,umask=0x40\000\00001\000\000"
/* offset=3578281 */ "unc_h_ag1_stall_no_crd_egress_horz_bl.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd6,umask=0x80\000\00001\000\000"
/* offset=3578445 */ "unc_h_ag1_stall_no_crd_egress_horz_bl_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd7,umask=0x2\000\00001\000\000"
/* offset=3578631 */ "unc_h_ag1_stall_no_crd_egress_horz_bl_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd7,umask=0x1\000\00001\000\000"
/* offset=3578798 */ "unc_h_bt_bypass\000uncore_ha\000uncore cache\000BT Bypass. Unit: uncore_ha \000event=0x52\000\00001\000Number of transactions that bypass the BT (fifo) to HT\000"
/* offset=3578935 */ "unc_h_bt_cycles_ne.local\000uncore_ha\000uncore cache\000BT Cycles Not Empty: Local. Unit: uncore_ha \000event=0x42,umask=0x1\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000"
/* offset=3579138 */ "unc_h_bt_cycles_ne.remote\000uncore_ha\000uncore cache\000BT Cycles Not Empty: Remote. Unit: uncore_ha \000event=0x42,umask=0x2\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000"
/* offset=3579343 */ "unc_h_bt_cycles_ne\000uncore_ha\000uncore cache\000BT Cycles Not Empty. Unit: uncore_ha \000event=0x42\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000"
/* offset=3579523 */ "unc_h_bt_occupancy.local\000uncore_ha\000uncore cache\000BT Occupancy; Local. Unit: uncore_ha \000event=0x43,umask=0x1\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3580030 */ "unc_h_bt_occupancy.reads_local\000uncore_ha\000uncore cache\000BT Occupancy; Reads Local. Unit: uncore_ha \000event=0x43,umask=0x4\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3580549 */ "unc_h_bt_occupancy.reads_remote\000uncore_ha\000uncore cache\000BT Occupancy; Reads Remote. Unit: uncore_ha \000event=0x43,umask=0x8\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3581070 */ "unc_h_bt_occupancy.remote\000uncore_ha\000uncore cache\000BT Occupancy; Remote. Unit: uncore_ha \000event=0x43,umask=0x2\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3581579 */ "unc_h_bt_occupancy.writes_local\000uncore_ha\000uncore cache\000BT Occupancy; Writes Local. Unit: uncore_ha \000event=0x43,umask=0x10\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3582101 */ "unc_h_bt_occupancy.writes_remote\000uncore_ha\000uncore cache\000BT Occupancy; Writes Remote. Unit: uncore_ha \000event=0x43,umask=0x20\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3582625 */ "unc_h_bt_to_ht_not_issued.incoming_bl_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x4\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000"
/* offset=3582923 */ "unc_h_bt_to_ht_not_issued.incoming_snp_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Snoop Hazard. Unit: uncore_ha \000event=0x51,umask=0x2\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming snoop hazard\000"
/* offset=3583221 */ "unc_h_bt_to_ht_not_issued.rspackcflt_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x8\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000"
/* offset=3583518 */ "unc_h_bt_to_ht_not_issued.wbmdata_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x10\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000"
/* offset=3583813 */ "unc_h_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.INTERMEDIATE. Unit: uncore_cha \000event=0x57,umask=0x2\000\00011\000\000"
/* offset=3583997 */ "unc_h_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.NOT_TAKEN. Unit: uncore_cha \000event=0x57,umask=0x4\000\00011\000\000"
/* offset=3584175 */ "unc_h_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.TAKEN. Unit: uncore_cha \000event=0x57,umask=0x1\000\00011\000\000"
/* offset=3584345 */ "unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass\000"
/* offset=3584766 */ "unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not\000"
/* offset=3585130 */ "unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the bypass\000"
/* offset=3585548 */ "unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not\000"
/* offset=3585904 */ "unc_h_cache_lines_victimized.e_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000\000"
/* offset=3586179 */ "unc_h_cache_lines_victimized.f_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ. Unit: uncore_cha \000event=0x37,umask=0x8\000\00001\000\000"
/* offset=3586467 */ "unc_h_cache_lines_victimized.local\000uncore_cha\000uncore cache\000Lines Victimized that Match NID. Unit: uncore_cha \000event=0x37,umask=0x20\000\00001\000\000"
/* offset=3586604 */ "unc_h_cache_lines_victimized.m_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Read transactions. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000\000"
/* offset=3586792 */ "unc_h_cache_lines_victimized.remote\000uncore_cha\000uncore cache\000Lines Victimized that Does Not Match NID. Unit: uncore_cha \000event=0x37,umask=0x80\000\00001\000\000"
/* offset=3586939 */ "unc_h_cache_lines_victimized.s_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for only snoop requests coming from the remote socket(s) through the IPQ. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000\000"
/* offset=3587190 */ "unc_h_clock\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CMS_CLOCKTICKS. Unit: uncore_cha \000event=0xc0\000\00011\000\000"
/* offset=3587329 */ "unc_h_clock\000uncore_cha\000uncore cache\000Uncore Clocks. Unit: uncore_cha \000event=0xc0\000\00001\000\000"
/* offset=3587414 */ "unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000"
/* offset=3587782 */ "unc_h_conflict_cycles.ackcnflts\000uncore_ha\000uncore cache\000Conflict Checks; Acknowledge Conflicts. Unit: uncore_ha \000event=0xb,umask=0x8\000\00001\000Count the number of Ackcnflts\000"
/* offset=3587948 */ "unc_h_conflict_cycles.cmp_fwds\000uncore_ha\000uncore cache\000Conflict Checks; Cmp Fwds. Unit: uncore_ha \000event=0xb,umask=0x10\000\00001\000Count the number of Cmp_Fwd. This will give the number of late conflicts\000"
/* offset=3588144 */ "unc_h_conflict_cycles.conflict\000uncore_ha\000uncore cache\000Conflict Checks; Conflict Detected. Unit: uncore_ha \000event=0xb,umask=0x2\000\00001\000Counts the number of cycles that we are handling conflicts\000"
/* offset=3588334 */ "unc_h_conflict_cycles.conflict\000uncore_ha\000uncore cache\000Conflict Checks; Conflict Detected. Unit: uncore_ha \000event=0xb,umask=0x2\000\00001\000\000"
/* offset=3588466 */ "unc_h_conflict_cycles.last\000uncore_ha\000uncore cache\000Conflict Checks; Last in conflict chain. Unit: uncore_ha \000event=0xb,umask=0x4\000\00001\000Count every last conflictor in conflict chain. Can be used to compute the average conflict chain length as (#Ackcnflts/#LastConflictor)+1. This can be used to give a feel for the conflict chain lengths while analyzing lock kernels\000"
/* offset=3588829 */ "unc_h_conflict_cycles.no_conflict\000uncore_ha\000uncore cache\000Conflict Checks; No Conflict. Unit: uncore_ha \000event=0xb,umask=0x1\000\00001\000\000"
/* offset=3588958 */ "unc_h_core_pma.c1_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_STATE. Unit: uncore_cha \000event=0x17,umask=0x1\000\00011\000\000"
/* offset=3589122 */ "unc_h_core_pma.c1_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x2\000\00011\000\000"
/* offset=3589296 */ "unc_h_core_pma.c6_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_STATE. Unit: uncore_cha \000event=0x17,umask=0x4\000\00011\000\000"
/* offset=3589460 */ "unc_h_core_pma.c6_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x8\000\00011\000\000"
/* offset=3589634 */ "unc_h_core_pma.gv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00011\000\000"
/* offset=3589787 */ "unc_h_core_snp.any_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_GTONE. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00011\000\000"
/* offset=3589954 */ "unc_h_core_snp.any_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_ONE. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00011\000\000"
/* offset=3590117 */ "unc_h_core_snp.any_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_REMOTE. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00011\000\000"
/* offset=3590286 */ "unc_h_core_snp.core_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_GTONE. Unit: uncore_cha \000event=0x33,umask=0x42\000\00011\000\000"
/* offset=3590455 */ "unc_h_core_snp.core_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_ONE. Unit: uncore_cha \000event=0x33,umask=0x41\000\00011\000\000"
/* offset=3590620 */ "unc_h_core_snp.core_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x44\000\00011\000\000"
/* offset=3590791 */ "unc_h_core_snp.evict_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x82\000\00011\000\000"
/* offset=3590962 */ "unc_h_core_snp.evict_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_ONE. Unit: uncore_cha \000event=0x33,umask=0x81\000\00011\000\000"
/* offset=3591129 */ "unc_h_core_snp.evict_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x84\000\00011\000\000"
/* offset=3591302 */ "unc_h_core_snp.ext_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x22\000\00011\000\000"
/* offset=3591469 */ "unc_h_core_snp.ext_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_ONE. Unit: uncore_cha \000event=0x33,umask=0x21\000\00011\000\000"
/* offset=3591632 */ "unc_h_core_snp.ext_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x24\000\00011\000\000"
/* offset=3591801 */ "unc_h_counter0_occupancy\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_COUNTER0_OCCUPANCY. Unit: uncore_cha \000event=0x1f\000\00011\000\000"
/* offset=3591957 */ "unc_h_dir_lookup.no_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.NO_SNP. Unit: uncore_cha \000event=0x53,umask=0x2\000\00011\000\000"
/* offset=3592121 */ "unc_h_dir_lookup.snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.SNP. Unit: uncore_cha \000event=0x53,umask=0x1\000\00011\000\000"
/* offset=3592279 */ "unc_h_dir_update.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.HA. Unit: uncore_cha \000event=0x54,umask=0x1\000\00011\000\000"
/* offset=3592435 */ "unc_h_dir_update.tor\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.TOR. Unit: uncore_cha \000event=0x54,umask=0x2\000\00011\000\000"
/* offset=3592593 */ "unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000"
/* offset=3592735 */ "unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000"
/* offset=3592913 */ "unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000"
/* offset=3593093 */ "unc_h_directory_lat_opt\000uncore_ha\000uncore cache\000Directory Lat Opt Return. Unit: uncore_ha \000event=0x41\000\00001\000Directory Latency Optimization Data Return Path Taken. When directory mode is enabled and the directory returned for a read is Dir=I, then data can be returned using a faster path if certain conditions are met (credits, free pipeline, etc)\000"
/* offset=3593438 */ "unc_h_directory_lookup.any\000uncore_ha\000uncore cache\000Directory Lookups: Any state. Unit: uncore_ha \000event=0xc,umask=0x10\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3593702 */ "unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that did not have to send any snoops because the directory bit was clear\000"
/* offset=3594075 */ "unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3594348 */ "unc_h_directory_lookup.snoop_a\000uncore_ha\000uncore cache\000Directory Lookups: Snoop A. Unit: uncore_ha \000event=0xc,umask=0x8\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3594613 */ "unc_h_directory_lookup.snoop_s\000uncore_ha\000uncore cache\000Directory Lookups: Snoop S. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3594878 */ "unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that had to send one or more snoops because the directory bit was set\000"
/* offset=3595241 */ "unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3595507 */ "unc_h_directory_lookup.state_a\000uncore_ha\000uncore cache\000Directory Lookups: A State. Unit: uncore_ha \000event=0xc,umask=0x80\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3595773 */ "unc_h_directory_lookup.state_i\000uncore_ha\000uncore cache\000Directory Lookups: I State. Unit: uncore_ha \000event=0xc,umask=0x20\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3596039 */ "unc_h_directory_lookup.state_s\000uncore_ha\000uncore cache\000Directory Lookups: S State. Unit: uncore_ha \000event=0xc,umask=0x40\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000"
/* offset=3596305 */ "unc_h_directory_update.a2i\000uncore_ha\000uncore cache\000Directory Updates: A2I. Unit: uncore_ha \000event=0xd,umask=0x20\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3596591 */ "unc_h_directory_update.a2s\000uncore_ha\000uncore cache\000Directory Updates: A2S. Unit: uncore_ha \000event=0xd,umask=0x40\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3596877 */ "unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3597179 */ "unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory clears.  This occurs when snoops were sent and all returned with RspI\000"
/* offset=3597571 */ "unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3597870 */ "unc_h_directory_update.i2a\000uncore_ha\000uncore cache\000Directory Updates: I2A. Unit: uncore_ha \000event=0xd,umask=0x4\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3598155 */ "unc_h_directory_update.i2s\000uncore_ha\000uncore cache\000Directory Updates: I2S. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3598440 */ "unc_h_directory_update.s2a\000uncore_ha\000uncore cache\000Directory Updates: S2A. Unit: uncore_ha \000event=0xd,umask=0x10\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3598726 */ "unc_h_directory_update.s2i\000uncore_ha\000uncore cache\000Directory Updates: S2I. Unit: uncore_ha \000event=0xd,umask=0x8\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3599011 */ "unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory sets.  This occurs when a remote read transaction requests memory, bringing it to a remote cache\000"
/* offset=3599426 */ "unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000"
/* offset=3599721 */ "unc_h_egress_horz_ads_used.ad\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000\000"
/* offset=3599844 */ "unc_h_egress_horz_ads_used.ak\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000\000"
/* offset=3599967 */ "unc_h_egress_horz_ads_used.bl\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000\000"
/* offset=3600090 */ "unc_h_egress_horz_bypass.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. AD ring. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00001\000\000"
/* offset=3600225 */ "unc_h_egress_horz_bypass.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. AK ring. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00001\000\000"
/* offset=3600360 */ "unc_h_egress_horz_bypass.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. BL ring. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00001\000\000"
/* offset=3600495 */ "unc_h_egress_horz_bypass.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. IV ring. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00001\000\000"
/* offset=3600630 */ "unc_h_egress_horz_cycles_full.ad\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full AD. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000\000"
/* offset=3600778 */ "unc_h_egress_horz_cycles_full.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full AK. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000\000"
/* offset=3600926 */ "unc_h_egress_horz_cycles_full.bl\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full BL. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000\000"
/* offset=3601074 */ "unc_h_egress_horz_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full IV. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000\000"
/* offset=3601222 */ "unc_h_egress_horz_cycles_ne.ad\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty AD. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000\000"
/* offset=3601373 */ "unc_h_egress_horz_cycles_ne.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty AK. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000\000"
/* offset=3601524 */ "unc_h_egress_horz_cycles_ne.bl\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty BL. Unit: uncore_cha \000event=0x97,umask=0x4\000\00001\000\000"
/* offset=3601675 */ "unc_h_egress_horz_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty IV. Unit: uncore_cha \000event=0x97,umask=0x8\000\00001\000\000"
/* offset=3601826 */ "unc_h_egress_horz_inserts.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts AD. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000\000"
/* offset=3601957 */ "unc_h_egress_horz_inserts.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts AK. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000\000"
/* offset=3602088 */ "unc_h_egress_horz_inserts.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts BL. Unit: uncore_cha \000event=0x95,umask=0x4\000\00001\000\000"
/* offset=3602219 */ "unc_h_egress_horz_inserts.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts IV. Unit: uncore_cha \000event=0x95,umask=0x8\000\00001\000\000"
/* offset=3602350 */ "unc_h_egress_horz_nack.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000\000"
/* offset=3602473 */ "unc_h_egress_horz_nack.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000\000"
/* offset=3602596 */ "unc_h_egress_horz_nack.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x4\000\00001\000\000"
/* offset=3602719 */ "unc_h_egress_horz_nack.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x8\000\00001\000\000"
/* offset=3602842 */ "unc_h_egress_horz_occupancy.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy AD. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000\000"
/* offset=3602977 */ "unc_h_egress_horz_occupancy.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy AK. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000\000"
/* offset=3603112 */ "unc_h_egress_horz_occupancy.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy BL. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000\000"
/* offset=3603247 */ "unc_h_egress_horz_occupancy.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy IV. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000\000"
/* offset=3603382 */ "unc_h_egress_horz_starved.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000\000"
/* offset=3603523 */ "unc_h_egress_horz_starved.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000\000"
/* offset=3603664 */ "unc_h_egress_horz_starved.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000\000"
/* offset=3603805 */ "unc_h_egress_horz_starved.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00001\000\000"
/* offset=3603946 */ "unc_h_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_DN. Unit: uncore_cha \000event=0xae,umask=0x4\000\00011\000\000"
/* offset=3604134 */ "unc_h_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_UP. Unit: uncore_cha \000event=0xae,umask=0x1\000\00011\000\000"
/* offset=3604322 */ "unc_h_egress_ordering.iv_snp_go_dn\000uncore_cha\000uncore cache\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements. Unit: uncore_cha \000event=0xae,umask=0x4\000\00001\000\000"
/* offset=3604519 */ "unc_h_egress_ordering.iv_snp_go_up\000uncore_cha\000uncore cache\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements. Unit: uncore_cha \000event=0xae,umask=0x1\000\00001\000\000"
/* offset=3604716 */ "unc_h_egress_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000\000"
/* offset=3604841 */ "unc_h_egress_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000\000"
/* offset=3604967 */ "unc_h_egress_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00001\000\000"
/* offset=3605092 */ "unc_h_egress_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00001\000\000"
/* offset=3605218 */ "unc_h_egress_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000\000"
/* offset=3605343 */ "unc_h_egress_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000\000"
/* offset=3605469 */ "unc_h_egress_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AD ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000\000"
/* offset=3605614 */ "unc_h_egress_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AD ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00001\000\000"
/* offset=3605760 */ "unc_h_egress_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AK ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000\000"
/* offset=3605905 */ "unc_h_egress_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AK ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00001\000\000"
/* offset=3606051 */ "unc_h_egress_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. BL ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00001\000\000"
/* offset=3606196 */ "unc_h_egress_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. BL ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00001\000\000"
/* offset=3606342 */ "unc_h_egress_vert_bypass.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. IV ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00001\000\000"
/* offset=3606483 */ "unc_h_egress_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000\000"
/* offset=3606643 */ "unc_h_egress_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000\000"
/* offset=3606804 */ "unc_h_egress_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000\000"
/* offset=3606964 */ "unc_h_egress_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000\000"
/* offset=3607125 */ "unc_h_egress_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000\000"
/* offset=3607285 */ "unc_h_egress_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000\000"
/* offset=3607446 */ "unc_h_egress_vert_cycles_full.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full IV - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000\000"
/* offset=3607606 */ "unc_h_egress_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AD - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000\000"
/* offset=3607769 */ "unc_h_egress_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AD - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00001\000\000"
/* offset=3607933 */ "unc_h_egress_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AK - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000\000"
/* offset=3608096 */ "unc_h_egress_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AK - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00001\000\000"
/* offset=3608260 */ "unc_h_egress_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty BL - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00001\000\000"
/* offset=3608423 */ "unc_h_egress_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty BL - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00001\000\000"
/* offset=3608587 */ "unc_h_egress_vert_cycles_ne.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty IV - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x8\000\00001\000\000"
/* offset=3608750 */ "unc_h_egress_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AD - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000\000"
/* offset=3608893 */ "unc_h_egress_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AD - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00001\000\000"
/* offset=3609037 */ "unc_h_egress_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AK - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000\000"
/* offset=3609180 */ "unc_h_egress_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AK - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00001\000\000"
/* offset=3609324 */ "unc_h_egress_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations BL - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00001\000\000"
/* offset=3609467 */ "unc_h_egress_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations BL - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00001\000\000"
/* offset=3609611 */ "unc_h_egress_vert_inserts.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations IV - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x8\000\00001\000\000"
/* offset=3609754 */ "unc_h_egress_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000\000"
/* offset=3609879 */ "unc_h_egress_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000\000"
/* offset=3610005 */ "unc_h_egress_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs Onto AK Ring. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000\000"
/* offset=3610143 */ "unc_h_egress_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000\000"
/* offset=3610269 */ "unc_h_egress_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs Onto BL Ring. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000\000"
/* offset=3610407 */ "unc_h_egress_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000\000"
/* offset=3610533 */ "unc_h_egress_vert_nack.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000\000"
/* offset=3610658 */ "unc_h_egress_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000\000"
/* offset=3610801 */ "unc_h_egress_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000\000"
/* offset=3610945 */ "unc_h_egress_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000\000"
/* offset=3611088 */ "unc_h_egress_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000\000"
/* offset=3611232 */ "unc_h_egress_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000\000"
/* offset=3611375 */ "unc_h_egress_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000\000"
/* offset=3611519 */ "unc_h_egress_vert_occupancy.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy IV - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000\000"
/* offset=3611662 */ "unc_h_egress_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000\000"
/* offset=3611805 */ "unc_h_egress_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000\000"
/* offset=3611949 */ "unc_h_egress_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation Onto AK Ring. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000\000"
/* offset=3612105 */ "unc_h_egress_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000\000"
/* offset=3612249 */ "unc_h_egress_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation Onto BL Ring. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000\000"
/* offset=3612405 */ "unc_h_egress_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000\000"
/* offset=3612549 */ "unc_h_egress_vert_starved.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000\000"
/* offset=3612692 */ "unc_h_fast_asserted.horz\000uncore_cha\000uncore cache\000Counts cycles source throttling is asserted - horizontal. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000\000"
/* offset=3612843 */ "unc_h_fast_asserted.vert\000uncore_cha\000uncore cache\000Counts cycles source throttling is asserted - vertical. Unit: uncore_cha \000event=0xa5\000\00001\000\000"
/* offset=3612982 */ "unc_h_hitme_hit.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is AckCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x4\000\00001\000\000"
/* offset=3613133 */ "unc_h_hitme_hit.all\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; All Requests. Unit: uncore_ha \000event=0x71,umask=0xff\000\00001\000\000"
/* offset=3613272 */ "unc_h_hitme_hit.allocs\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x70\000\00001\000\000"
/* offset=3613413 */ "unc_h_hitme_hit.evicts\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x42\000\00001\000\000"
/* offset=3613554 */ "unc_h_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.EX_RDS. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00011\000\000"
/* offset=3613716 */ "unc_h_hitme_hit.hom\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; HOM Requests. Unit: uncore_ha \000event=0x71,umask=0xf\000\00001\000\000"
/* offset=3613854 */ "unc_h_hitme_hit.invals\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Invalidations. Unit: uncore_ha \000event=0x71,umask=0x26\000\00001\000\000"
/* offset=3613997 */ "unc_h_hitme_hit.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x71,umask=0x1\000\00001\000\000"
/* offset=3614200 */ "unc_h_hitme_hit.rsp\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x80\000\00001\000\000"
/* offset=3614384 */ "unc_h_hitme_hit.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x71,umask=0x20\000\00001\000\000"
/* offset=3614567 */ "unc_h_hitme_hit.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x71,umask=0x10\000\00001\000\000"
/* offset=3614752 */ "unc_h_hitme_hit.rspfwds\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x71,umask=0x40\000\00001\000\000"
/* offset=3614908 */ "unc_h_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.SHARED_OWNREQ. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00011\000\000"
/* offset=3615084 */ "unc_h_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00011\000\000"
/* offset=3615246 */ "unc_h_hitme_hit.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x71,umask=0x8\000\00001\000\000"
/* offset=3615402 */ "unc_h_hitme_hit.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI. Unit: uncore_ha \000event=0x71,umask=0x2\000\00001\000\000"
/* offset=3615543 */ "unc_h_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOI_OR_S. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00011\000\000"
/* offset=3615716 */ "unc_h_hitme_hit_pv_bits_set.ackcnfltwbi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is AckCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x4\000\00001\000\000"
/* offset=3615896 */ "unc_h_hitme_hit_pv_bits_set.all\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; All Requests. Unit: uncore_ha \000event=0x72,umask=0xff\000\00001\000\000"
/* offset=3616064 */ "unc_h_hitme_hit_pv_bits_set.hom\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; HOM Requests. Unit: uncore_ha \000event=0x72,umask=0xf\000\00001\000\000"
/* offset=3616231 */ "unc_h_hitme_hit_pv_bits_set.read_or_invitoe\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x72,umask=0x1\000\00001\000\000"
/* offset=3616463 */ "unc_h_hitme_hit_pv_bits_set.rsp\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x80\000\00001\000\000"
/* offset=3616676 */ "unc_h_hitme_hit_pv_bits_set.rspfwdi_local\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x72,umask=0x20\000\00001\000\000"
/* offset=3616888 */ "unc_h_hitme_hit_pv_bits_set.rspfwdi_remote\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x72,umask=0x10\000\00001\000\000"
/* offset=3617102 */ "unc_h_hitme_hit_pv_bits_set.rspfwds\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x72,umask=0x40\000\00001\000\000"
/* offset=3617287 */ "unc_h_hitme_hit_pv_bits_set.wbmtoe_or_s\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x72,umask=0x8\000\00001\000\000"
/* offset=3617472 */ "unc_h_hitme_hit_pv_bits_set.wbmtoi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoI. Unit: uncore_ha \000event=0x72,umask=0x2\000\00001\000\000"
/* offset=3617642 */ "unc_h_hitme_lookup.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is AckCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x4\000\00001\000\000"
/* offset=3617806 */ "unc_h_hitme_lookup.all\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; All Requests. Unit: uncore_ha \000event=0x70,umask=0xff\000\00001\000\000"
/* offset=3617958 */ "unc_h_hitme_lookup.allocs\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Allocations. Unit: uncore_ha \000event=0x70,umask=0x70\000\00001\000\000"
/* offset=3618112 */ "unc_h_hitme_lookup.hom\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; HOM Requests. Unit: uncore_ha \000event=0x70,umask=0xf\000\00001\000\000"
/* offset=3618263 */ "unc_h_hitme_lookup.invals\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Invalidations. Unit: uncore_ha \000event=0x70,umask=0x26\000\00001\000\000"
/* offset=3618419 */ "unc_h_hitme_lookup.read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.READ. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00011\000\000"
/* offset=3618583 */ "unc_h_hitme_lookup.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x70,umask=0x1\000\00001\000\000"
/* offset=3618799 */ "unc_h_hitme_lookup.rsp\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x80\000\00001\000\000"
/* offset=3618996 */ "unc_h_hitme_lookup.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x70,umask=0x20\000\00001\000\000"
/* offset=3619192 */ "unc_h_hitme_lookup.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x70,umask=0x10\000\00001\000\000"
/* offset=3619390 */ "unc_h_hitme_lookup.rspfwds\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x70,umask=0x40\000\00001\000\000"
/* offset=3619559 */ "unc_h_hitme_lookup.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x70,umask=0x8\000\00001\000\000"
/* offset=3619728 */ "unc_h_hitme_lookup.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoI. Unit: uncore_ha \000event=0x70,umask=0x2\000\00001\000\000"
/* offset=3619882 */ "unc_h_hitme_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.WRITE. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00011\000\000"
/* offset=3620048 */ "unc_h_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.NOTSHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x40\000\00011\000\000"
/* offset=3620237 */ "unc_h_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.READ_OR_INV. Unit: uncore_cha \000event=0x60,umask=0x80\000\00011\000\000"
/* offset=3620412 */ "unc_h_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.SHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x20\000\00011\000\000"
/* offset=3620595 */ "unc_h_hitme_update.deallocate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE. Unit: uncore_cha \000event=0x61,umask=0x10\000\00011\000\000"
/* offset=3620772 */ "unc_h_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE_RSPFWDI_LOC. Unit: uncore_cha \000event=0x61,umask=0x1\000\00011\000\000"
/* offset=3620972 */ "unc_h_hitme_update.rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RDINVOWN. Unit: uncore_cha \000event=0x61,umask=0x8\000\00011\000\000"
/* offset=3621144 */ "unc_h_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RSPFWDI_REM. Unit: uncore_cha \000event=0x61,umask=0x2\000\00011\000\000"
/* offset=3621322 */ "unc_h_hitme_update.shared\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.SHARED. Unit: uncore_cha \000event=0x61,umask=0x4\000\00011\000\000"
/* offset=3621490 */ "unc_h_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000\000"
/* offset=3621699 */ "unc_h_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00011\000\000"
/* offset=3621887 */ "unc_h_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000\000"
/* offset=3622094 */ "unc_h_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00011\000\000"
/* offset=3622280 */ "unc_h_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000\000"
/* offset=3622491 */ "unc_h_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00011\000\000"
/* offset=3622681 */ "unc_h_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000\000"
/* offset=3622890 */ "unc_h_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00011\000\000"
/* offset=3623078 */ "unc_h_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00001\000\000"
/* offset=3623287 */ "unc_h_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00011\000\000"
/* offset=3623475 */ "unc_h_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00001\000\000"
/* offset=3623682 */ "unc_h_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00011\000\000"
/* offset=3623868 */ "unc_h_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00001\000\000"
/* offset=3624079 */ "unc_h_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00011\000\000"
/* offset=3624269 */ "unc_h_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00001\000\000"
/* offset=3624478 */ "unc_h_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00011\000\000"
/* offset=3624666 */ "unc_h_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000\000"
/* offset=3624875 */ "unc_h_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x1\000\00011\000\000"
/* offset=3625063 */ "unc_h_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000\000"
/* offset=3625270 */ "unc_h_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xab,umask=0x2\000\00011\000\000"
/* offset=3625456 */ "unc_h_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000\000"
/* offset=3625667 */ "unc_h_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x4\000\00011\000\000"
/* offset=3625857 */ "unc_h_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000\000"
/* offset=3626066 */ "unc_h_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xab,umask=0x8\000\00011\000\000"
/* offset=3626254 */ "unc_h_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop - Left. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000\000"
/* offset=3626449 */ "unc_h_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.LEFT. Unit: uncore_cha \000event=0xad,umask=0x1\000\00011\000\000"
/* offset=3626627 */ "unc_h_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop - Right. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000\000"
/* offset=3626824 */ "unc_h_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.RIGHT. Unit: uncore_cha \000event=0xad,umask=0x4\000\00011\000\000"
/* offset=3627004 */ "unc_h_igr_ad_qpi2_accumulator\000uncore_ha\000uncore cache\000AD QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x59\000\00001\000Accumulates the number of credits available to the QPI Link 2 AD Ingress buffer\000"
/* offset=3627203 */ "unc_h_igr_bl_qpi2_accumulator\000uncore_ha\000uncore cache\000BL QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x5a\000\00001\000Accumulates the number of credits available to the QPI Link 2 BL Ingress buffer\000"
/* offset=3627402 */ "unc_h_igr_credits_ad_qpi2\000uncore_ha\000uncore cache\000AD QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x59\000\00001\000Accumulates the number of credits available to the QPI Link 2 AD Ingress buffer\000"
/* offset=3627597 */ "unc_h_igr_credits_bl_qpi2\000uncore_ha\000uncore cache\000BL QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x5a\000\00001\000Accumulates the number of credits available to the QPI Link 2 BL Ingress buffer\000"
/* offset=3627792 */ "unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3628119 */ "unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3628446 */ "unc_h_igr_no_credit_cycles.ad_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3628774 */ "unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3629101 */ "unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3629428 */ "unc_h_igr_no_credit_cycles.bl_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000"
/* offset=3629756 */ "unc_h_imc_reads.normal\000uncore_ha\000uncore cache\000HA to iMC Normal Priority Reads Issued; Normal Priority. Unit: uncore_ha \000event=0x17,umask=0x1\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000"
/* offset=3630030 */ "unc_h_imc_reads_count.normal\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.NORMAL. Unit: uncore_cha \000event=0x59,umask=0x1\000\00011\000\000"
/* offset=3630204 */ "unc_h_imc_reads_count.priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.PRIORITY. Unit: uncore_cha \000event=0x59,umask=0x2\000\00011\000\000"
/* offset=3630382 */ "unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000"
/* offset=3630468 */ "unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=3630784 */ "unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=3631110 */ "unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=3631438 */ "unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=3631765 */ "unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000"
/* offset=3632094 */ "unc_h_imc_writes_count.full\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00011\000\000"
/* offset=3632266 */ "unc_h_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00011\000\000"
/* offset=3632447 */ "unc_h_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00011\000\000"
/* offset=3632637 */ "unc_h_imc_writes_count.partial\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00011\000\000"
/* offset=3632815 */ "unc_h_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00011\000\000"
/* offset=3633002 */ "unc_h_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00011\000\000"
/* offset=3633198 */ "unc_h_ingress_inserts.ipq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000\000"
/* offset=3633393 */ "unc_h_ingress_inserts.irq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000\000"
/* offset=3633588 */ "unc_h_ingress_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000\000"
/* offset=3633796 */ "unc_h_ingress_inserts.prq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000\000"
/* offset=3633992 */ "unc_h_ingress_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - PRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000\000"
/* offset=3634201 */ "unc_h_ingress_int_starved.ipq\000uncore_cha\000uncore cache\000Cycles with the IPQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x4\000\00001\000\000"
/* offset=3634343 */ "unc_h_ingress_int_starved.irq\000uncore_cha\000uncore cache\000Cycles with the IRQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x1\000\00001\000\000"
/* offset=3634485 */ "unc_h_ingress_int_starved.ismq\000uncore_cha\000uncore cache\000Cycles with the ISMQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x8\000\00001\000\000"
/* offset=3634629 */ "unc_h_ingress_int_starved.prq\000uncore_cha\000uncore cache\000Ingress internal starvation cycles. Counts cycles in internal starvation. This occurs when one or more of the entries in the ingress queue are being starved out by other entries in the queue. Unit: uncore_cha \000event=0x14,umask=0x10\000\00001\000\000"
/* offset=3634920 */ "unc_h_ingress_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000\000"
/* offset=3635113 */ "unc_h_ingress_occupancy.irq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000\000"
/* offset=3635306 */ "unc_h_ingress_occupancy.irq_rej\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IRQ Rejected. Unit: uncore_cha \000event=0x11,umask=0x2\000\00001\000\000"
/* offset=3635512 */ "unc_h_ingress_occupancy.prq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - PRQ. Unit: uncore_cha \000event=0x11,umask=0x10\000\00001\000\000"
/* offset=3635706 */ "unc_h_ingress_occupancy.prq_rej\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - PRQ Rejected. Unit: uncore_cha \000event=0x11,umask=0x20\000\00001\000\000"
/* offset=3635913 */ "unc_h_ingress_retry_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000\000"
/* offset=3636053 */ "unc_h_ingress_retry_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000\000"
/* offset=3636193 */ "unc_h_ingress_retry_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000\000"
/* offset=3636334 */ "unc_h_ingress_retry_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000\000"
/* offset=3636475 */ "unc_h_ingress_retry_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000\000"
/* offset=3636616 */ "unc_h_ingress_retry_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000\000"
/* offset=3636756 */ "unc_h_ingress_retry_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000\000"
/* offset=3636895 */ "unc_h_ingress_retry_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000\000"
/* offset=3637036 */ "unc_h_ingress_retry_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000"
/* offset=3637176 */ "unc_h_ingress_retry_ipq1_reject.any_reject_ipq0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000\000"
/* offset=3637321 */ "unc_h_ingress_retry_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000\000"
/* offset=3637460 */ "unc_h_ingress_retry_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000\000"
/* offset=3637599 */ "unc_h_ingress_retry_ipq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000\000"
/* offset=3637736 */ "unc_h_ingress_retry_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=3637878 */ "unc_h_ingress_retry_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=3638020 */ "unc_h_ingress_retry_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000\000"
/* offset=3638163 */ "unc_h_ingress_retry_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000\000"
/* offset=3638306 */ "unc_h_ingress_retry_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000\000"
/* offset=3638449 */ "unc_h_ingress_retry_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000\000"
/* offset=3638591 */ "unc_h_ingress_retry_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000\000"
/* offset=3638732 */ "unc_h_ingress_retry_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000\000"
/* offset=3638875 */ "unc_h_ingress_retry_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000"
/* offset=3639017 */ "unc_h_ingress_retry_irq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000\000"
/* offset=3639164 */ "unc_h_ingress_retry_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000"
/* offset=3639305 */ "unc_h_ingress_retry_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000\000"
/* offset=3639446 */ "unc_h_ingress_retry_irq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000\000"
/* offset=3639585 */ "unc_h_ingress_retry_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000\000"
/* offset=3639711 */ "unc_h_ingress_retry_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000\000"
/* offset=3639837 */ "unc_h_ingress_retry_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000\000"
/* offset=3639964 */ "unc_h_ingress_retry_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000\000"
/* offset=3640091 */ "unc_h_ingress_retry_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000\000"
/* offset=3640218 */ "unc_h_ingress_retry_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000\000"
/* offset=3640344 */ "unc_h_ingress_retry_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000\000"
/* offset=3640469 */ "unc_h_ingress_retry_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000\000"
/* offset=3640596 */ "unc_h_ingress_retry_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000\000"
/* offset=3640721 */ "unc_h_ingress_retry_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000\000"
/* offset=3640846 */ "unc_h_ingress_retry_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000\000"
/* offset=3640972 */ "unc_h_ingress_retry_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000\000"
/* offset=3641098 */ "unc_h_ingress_retry_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000\000"
/* offset=3641224 */ "unc_h_ingress_retry_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000\000"
/* offset=3641349 */ "unc_h_ingress_retry_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000\000"
/* offset=3641473 */ "unc_h_ingress_retry_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000\000"
/* offset=3641599 */ "unc_h_ingress_retry_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000\000"
/* offset=3641732 */ "unc_h_ingress_retry_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000\000"
/* offset=3641865 */ "unc_h_ingress_retry_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000\000"
/* offset=3641999 */ "unc_h_ingress_retry_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000\000"
/* offset=3642133 */ "unc_h_ingress_retry_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000\000"
/* offset=3642267 */ "unc_h_ingress_retry_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000\000"
/* offset=3642400 */ "unc_h_ingress_retry_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000\000"
/* offset=3642532 */ "unc_h_ingress_retry_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000\000"
/* offset=3642666 */ "unc_h_ingress_retry_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000\000"
/* offset=3642799 */ "unc_h_ingress_retry_other1_retry.any_reject_irq0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000\000"
/* offset=3642937 */ "unc_h_ingress_retry_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000\000"
/* offset=3643069 */ "unc_h_ingress_retry_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000\000"
/* offset=3643201 */ "unc_h_ingress_retry_other1_retry.sf_way\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000\000"
/* offset=3643331 */ "unc_h_ingress_retry_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000\000"
/* offset=3643473 */ "unc_h_ingress_retry_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000\000"
/* offset=3643615 */ "unc_h_ingress_retry_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000\000"
/* offset=3643758 */ "unc_h_ingress_retry_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000\000"
/* offset=3643901 */ "unc_h_ingress_retry_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000\000"
/* offset=3644044 */ "unc_h_ingress_retry_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000\000"
/* offset=3644186 */ "unc_h_ingress_retry_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000\000"
/* offset=3644327 */ "unc_h_ingress_retry_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000\000"
/* offset=3644470 */ "unc_h_ingress_retry_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000"
/* offset=3644612 */ "unc_h_ingress_retry_prq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000\000"
/* offset=3644759 */ "unc_h_ingress_retry_prq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000\000"
/* offset=3644900 */ "unc_h_ingress_retry_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000\000"
/* offset=3645041 */ "unc_h_ingress_retry_prq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000\000"
/* offset=3645180 */ "unc_h_ingress_retry_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000\000"
/* offset=3645368 */ "unc_h_ingress_retry_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000\000"
/* offset=3645556 */ "unc_h_ingress_retry_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000\000"
/* offset=3645745 */ "unc_h_ingress_retry_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000\000"
/* offset=3645934 */ "unc_h_ingress_retry_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000\000"
/* offset=3646123 */ "unc_h_ingress_retry_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000\000"
/* offset=3646311 */ "unc_h_ingress_retry_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000\000"
/* offset=3646498 */ "unc_h_ingress_retry_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000\000"
/* offset=3646687 */ "unc_h_ingress_retry_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000\000"
/* offset=3646875 */ "unc_h_ingress_retry_req_q1_retry.any_reject_irq0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000\000"
/* offset=3647068 */ "unc_h_ingress_retry_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000\000"
/* offset=3647255 */ "unc_h_ingress_retry_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000\000"
/* offset=3647442 */ "unc_h_ingress_retry_req_q1_retry.sf_way\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000\000"
/* offset=3647627 */ "unc_h_iodc_alloc.invitom\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.INVITOM. Unit: uncore_cha \000event=0x62,umask=0x1\000\00011\000\000"
/* offset=3647793 */ "unc_h_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.IODCFULL. Unit: uncore_cha \000event=0x62,umask=0x2\000\00011\000\000"
/* offset=3647961 */ "unc_h_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.OSBGATED. Unit: uncore_cha \000event=0x62,umask=0x4\000\00011\000\000"
/* offset=3648129 */ "unc_h_iodc_conflicts.any\000uncore_ha\000uncore cache\000IODC Conflicts; Any Conflict. Unit: uncore_ha \000event=0x57,umask=0x1\000\00001\000\000"
/* offset=3648250 */ "unc_h_iodc_conflicts.last\000uncore_ha\000uncore cache\000IODC Conflicts; Last Conflict. Unit: uncore_ha \000event=0x57,umask=0x4\000\00001\000\000"
/* offset=3648373 */ "unc_h_iodc_conflicts.remote_invi2e_same_rtid\000uncore_ha\000uncore cache\000IODC Conflicts: Remote InvItoE - Same RTID. Unit: uncore_ha \000event=0x57,umask=0x1\000\00001\000\000"
/* offset=3648528 */ "unc_h_iodc_conflicts.remote_other_same_addr\000uncore_ha\000uncore cache\000IODC Conflicts: Remote (Other) - Same Addr. Unit: uncore_ha \000event=0x57,umask=0x4\000\00001\000\000"
/* offset=3648682 */ "unc_h_iodc_dealloc.all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.ALL. Unit: uncore_cha \000event=0x63,umask=0x10\000\00011\000\000"
/* offset=3648845 */ "unc_h_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.SNPOUT. Unit: uncore_cha \000event=0x63,umask=0x8\000\00011\000\000"
/* offset=3649013 */ "unc_h_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00011\000\000"
/* offset=3649181 */ "unc_h_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00011\000\000"
/* offset=3649349 */ "unc_h_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBPUSHMTOI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00011\000\000"
/* offset=3649525 */ "unc_h_iodc_inserts\000uncore_ha\000uncore cache\000IODC Inserts. Unit: uncore_ha \000event=0x56\000\00001\000IODC Allocations\000"
/* offset=3649630 */ "unc_h_iodc_olen_wbmtoi\000uncore_ha\000uncore cache\000Num IODC 0 Length Writes. Unit: uncore_ha \000event=0x58\000\00001\000Num IODC 0 Length Writebacks M to I - All of which are dropped\000"
/* offset=3649797 */ "unc_h_iot_backpressure.hub\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x2\000\00001\000\000"
/* offset=3649908 */ "unc_h_iot_backpressure.sat\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x1\000\00001\000\000"
/* offset=3650019 */ "unc_h_iot_cts_east_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650171 */ "unc_h_iot_cts_east_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650323 */ "unc_h_iot_cts_hi.cts2\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650470 */ "unc_h_iot_cts_hi.cts3\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650617 */ "unc_h_iot_cts_west_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650769 */ "unc_h_iot_cts_west_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=3650921 */ "unc_h_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000\000"
/* offset=3651067 */ "unc_h_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_MISS. Unit: uncore_cha \000event=0x39,umask=0x20\000\00011\000\000"
/* offset=3651234 */ "unc_h_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000\000"
/* offset=3651381 */ "unc_h_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_VIC. Unit: uncore_cha \000event=0x39,umask=0x10\000\00011\000\000"
/* offset=3651546 */ "unc_h_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. RFO HitS. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000\000"
/* offset=3651678 */ "unc_h_misc.rfo_hit_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RFO_HIT_S. Unit: uncore_cha \000event=0x39,umask=0x8\000\00011\000\000"
/* offset=3651836 */ "unc_h_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000\000"
/* offset=3651984 */ "unc_h_misc.rspi_was_fse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RSPI_WAS_FSE. Unit: uncore_cha \000event=0x39,umask=0x1\000\00011\000\000"
/* offset=3652148 */ "unc_h_misc.wc_aliasing\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000\000"
/* offset=3652298 */ "unc_h_misc.wc_aliasing\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.WC_ALIASING. Unit: uncore_cha \000event=0x39,umask=0x2\000\00011\000\000"
/* offset=3652460 */ "unc_h_osb.cancelled\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Cancelled. Unit: uncore_ha \000event=0x53,umask=0x10\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB.; OSB Snoop broadcast cancelled due to D2C or Other. OSB cancel is counted when OSB local read is not allowed even when the transaction in local InItoE. It also counts D2C OSB cancel, but also includes the cases were D2C was not set in the first place for the transaction coming from the ring\000"
/* offset=3653009 */ "unc_h_osb.invitoe_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local InvItoE. Unit: uncore_ha \000event=0x53,umask=0x4\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=3653272 */ "unc_h_osb.reads_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local Reads. Unit: uncore_ha \000event=0x53,umask=0x2\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=3653531 */ "unc_h_osb.reads_local_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Reads Local -  Useful. Unit: uncore_ha \000event=0x53,umask=0x20\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=3653808 */ "unc_h_osb.remote\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote. Unit: uncore_ha \000event=0x53,umask=0x8\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=3654057 */ "unc_h_osb.remote_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote - Useful. Unit: uncore_ha \000event=0x53,umask=0x40\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000"
/* offset=3654323 */ "unc_h_osb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_OSB. Unit: uncore_cha \000event=0x55\000\00011\000\000"
/* offset=3654449 */ "unc_h_osb_edr.all\000uncore_ha\000uncore cache\000OSB Early Data Return; All. Unit: uncore_ha \000event=0x54,umask=0x1\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000"
/* offset=3654695 */ "unc_h_osb_edr.reads_local_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local  I. Unit: uncore_ha \000event=0x54,umask=0x2\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000"
/* offset=3654965 */ "unc_h_osb_edr.reads_local_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local S. Unit: uncore_ha \000event=0x54,umask=0x8\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000"
/* offset=3655234 */ "unc_h_osb_edr.reads_remote_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote I. Unit: uncore_ha \000event=0x54,umask=0x4\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000"
/* offset=3655505 */ "unc_h_osb_edr.reads_remote_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote S. Unit: uncore_ha \000event=0x54,umask=0x10\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000"
/* offset=3655777 */ "unc_h_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00011\000\000"
/* offset=3655957 */ "unc_h_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00011\000\000"
/* offset=3656137 */ "unc_h_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00011\000\000"
/* offset=3656318 */ "unc_h_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00011\000\000"
/* offset=3656499 */ "unc_h_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00011\000\000"
/* offset=3656677 */ "unc_h_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00011\000\000"
/* offset=3656855 */ "unc_h_requests.invitoe_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_LOCAL. Unit: uncore_cha \000event=0x50,umask=0x10\000\00011\000\000"
/* offset=3657030 */ "unc_h_requests.invitoe_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x10\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from the local socket\000"
/* offset=3657407 */ "unc_h_requests.invitoe_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_REMOTE. Unit: uncore_cha \000event=0x50,umask=0x20\000\00011\000\000"
/* offset=3657584 */ "unc_h_requests.invitoe_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x20\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from remote sockets\000"
/* offset=3657961 */ "unc_h_requests.reads\000uncore_cha\000uncore cache\000read requests from home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00011\000\000"
/* offset=3658081 */ "unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming ead requests.  This is a good proxy for LLC Read Misses (including RFOs)\000"
/* offset=3658458 */ "unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000"
/* offset=3658751 */ "unc_h_requests.reads_local\000uncore_cha\000uncore cache\000read requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x1\000\00011\000\000"
/* offset=3658883 */ "unc_h_requests.reads_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Reads. Unit: uncore_ha \000event=0x1,umask=0x1\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the local socket.  This is a good proxy for LLC Read Misses (including RFOs) from the local socket\000"
/* offset=3659341 */ "unc_h_requests.reads_remote\000uncore_cha\000uncore cache\000read requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x2\000\00011\000\000"
/* offset=3659475 */ "unc_h_requests.reads_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Reads. Unit: uncore_ha \000event=0x1,umask=0x2\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the remote socket.  This is a good proxy for LLC Read Misses (including RFOs) from the remote socket\000"
/* offset=3659937 */ "unc_h_requests.writes\000uncore_cha\000uncore cache\000write requests from home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00011\000\000"
/* offset=3660059 */ "unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming write requests\000"
/* offset=3660380 */ "unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000"
/* offset=3660675 */ "unc_h_requests.writes_local\000uncore_cha\000uncore cache\000write requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x4\000\00011\000\000"
/* offset=3660809 */ "unc_h_requests.writes_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Writes. Unit: uncore_ha \000event=0x1,umask=0x4\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from the local socket\000"
/* offset=3661180 */ "unc_h_requests.writes_remote\000uncore_cha\000uncore cache\000write requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x8\000\00011\000\000"
/* offset=3661316 */ "unc_h_requests.writes_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Writes. Unit: uncore_ha \000event=0x1,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from remote sockets\000"
/* offset=3661687 */ "unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3662034 */ "unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3662382 */ "unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=3662801 */ "unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3663162 */ "unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=3663578 */ "unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3663937 */ "unc_h_ring_ad_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3664389 */ "unc_h_ring_ad_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3664838 */ "unc_h_ring_ad_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3665291 */ "unc_h_ring_ad_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3665741 */ "unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3666081 */ "unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3666420 */ "unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=3666824 */ "unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3667177 */ "unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=3667578 */ "unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3667929 */ "unc_h_ring_ad_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3668366 */ "unc_h_ring_ad_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3668800 */ "unc_h_ring_ad_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3669238 */ "unc_h_ring_ad_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3669673 */ "unc_h_ring_ak_used.all\000uncore_ha\000uncore cache\000HA AK Ring in Use; All. Unit: uncore_ha \000event=0x3f,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3670007 */ "unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3670354 */ "unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3670702 */ "unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=3671121 */ "unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3671482 */ "unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=3671898 */ "unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3672257 */ "unc_h_ring_ak_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3672709 */ "unc_h_ring_ak_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3673158 */ "unc_h_ring_ak_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3673611 */ "unc_h_ring_ak_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3674061 */ "unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3674401 */ "unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3674740 */ "unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=3675144 */ "unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3675497 */ "unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=3675898 */ "unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3676249 */ "unc_h_ring_ak_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3676686 */ "unc_h_ring_ak_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3677120 */ "unc_h_ring_ak_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3677558 */ "unc_h_ring_ak_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3677993 */ "unc_h_ring_bl_used.all\000uncore_ha\000uncore cache\000HA BL Ring in Use; All. Unit: uncore_ha \000event=0x40,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3678327 */ "unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3678674 */ "unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3679022 */ "unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=3679441 */ "unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3679802 */ "unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=3680218 */ "unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3680577 */ "unc_h_ring_bl_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3681029 */ "unc_h_ring_bl_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3681478 */ "unc_h_ring_bl_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3681931 */ "unc_h_ring_bl_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3682381 */ "unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3682721 */ "unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3683060 */ "unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=3683464 */ "unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3683817 */ "unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=3684218 */ "unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=3684569 */ "unc_h_ring_bl_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=3685006 */ "unc_h_ring_bl_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=3685440 */ "unc_h_ring_bl_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=3685878 */ "unc_h_ring_bl_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=3686313 */ "unc_h_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000\000"
/* offset=3686494 */ "unc_h_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00011\000\000"
/* offset=3686664 */ "unc_h_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Acknowledgements to core. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000\000"
/* offset=3686872 */ "unc_h_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00011\000\000"
/* offset=3687042 */ "unc_h_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Data Responses to core. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000\000"
/* offset=3687248 */ "unc_h_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00011\000\000"
/* offset=3687418 */ "unc_h_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Snoops of processor's cache. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000\000"
/* offset=3687629 */ "unc_h_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00011\000\000"
/* offset=3687799 */ "unc_h_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000\000"
/* offset=3687978 */ "unc_h_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00011\000\000"
/* offset=3688148 */ "unc_h_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Acknowledgements to core. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000\000"
/* offset=3688354 */ "unc_h_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00011\000\000"
/* offset=3688524 */ "unc_h_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Data Responses to core. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000\000"
/* offset=3688728 */ "unc_h_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.BL. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00011\000\000"
/* offset=3688898 */ "unc_h_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Snoops of processor's cache. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000\000"
/* offset=3689107 */ "unc_h_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00011\000\000"
/* offset=3689277 */ "unc_h_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - AD ring. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000\000"
/* offset=3689426 */ "unc_h_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00011\000\000"
/* offset=3689606 */ "unc_h_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - AK ring. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000\000"
/* offset=3689755 */ "unc_h_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00011\000\000"
/* offset=3689935 */ "unc_h_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK_AG1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00011\000\000"
/* offset=3690124 */ "unc_h_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - BL ring. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000\000"
/* offset=3690273 */ "unc_h_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00011\000\000"
/* offset=3690453 */ "unc_h_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - IV ring. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000\000"
/* offset=3690602 */ "unc_h_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00011\000\000"
/* offset=3690782 */ "unc_h_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00011\000\000"
/* offset=3690962 */ "unc_h_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - AD ring. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000\000"
/* offset=3691109 */ "unc_h_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00011\000\000"
/* offset=3691289 */ "unc_h_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - AK ring. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000\000"
/* offset=3691436 */ "unc_h_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.BL. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00011\000\000"
/* offset=3691616 */ "unc_h_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - BL ring. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000\000"
/* offset=3691763 */ "unc_h_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00011\000\000"
/* offset=3691943 */ "unc_h_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - IV ring. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000\000"
/* offset=3692090 */ "unc_h_ring_src_thrtl\000uncore_cha\000uncore cache\000Counts cycles in throttle mode. Unit: uncore_cha \000event=0xa4\000\00001\000\000"
/* offset=3692201 */ "unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3693072 */ "unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000"
/* offset=3693985 */ "unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3694856 */ "unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000"
/* offset=3695769 */ "unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3696640 */ "unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000"
/* offset=3697553 */ "unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3698424 */ "unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000"
/* offset=3699337 */ "unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3700168 */ "unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000"
/* offset=3701039 */ "unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3701870 */ "unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000"
/* offset=3702741 */ "unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3703572 */ "unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000"
/* offset=3704443 */ "unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3705274 */ "unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000"
/* offset=3706145 */ "unc_h_rxc_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00011\000\000"
/* offset=3706305 */ "unc_h_rxc_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00011\000\000"
/* offset=3706465 */ "unc_h_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x2\000\00011\000\000"
/* offset=3706633 */ "unc_h_rxc_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00011\000\000"
/* offset=3706794 */ "unc_h_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00011\000\000"
/* offset=3706963 */ "unc_h_rxc_inserts.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00011\000\000"
/* offset=3707124 */ "unc_h_rxc_inserts.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00011\000\000"
/* offset=3707285 */ "unc_h_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00011\000\000"
/* offset=3707467 */ "unc_h_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00011\000\000"
/* offset=3707649 */ "unc_h_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00011\000\000"
/* offset=3707832 */ "unc_h_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00011\000\000"
/* offset=3708015 */ "unc_h_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00011\000\000"
/* offset=3708197 */ "unc_h_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00011\000\000"
/* offset=3708377 */ "unc_h_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x23,umask=0x40\000\00011\000\000"
/* offset=3708558 */ "unc_h_rxc_ipq1_reject.any_ipq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00011\000\000"
/* offset=3708732 */ "unc_h_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00011\000\000"
/* offset=3708898 */ "unc_h_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x23,umask=0x20\000\00011\000\000"
/* offset=3709087 */ "unc_h_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x4\000\00011\000\000"
/* offset=3709269 */ "unc_h_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x23,umask=0x80\000\00011\000\000"
/* offset=3709448 */ "unc_h_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x8\000\00011\000\000"
/* offset=3709628 */ "unc_h_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x23,umask=0x10\000\00011\000\000"
/* offset=3709803 */ "unc_h_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00011\000\000"
/* offset=3709985 */ "unc_h_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00011\000\000"
/* offset=3710167 */ "unc_h_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00011\000\000"
/* offset=3710350 */ "unc_h_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00011\000\000"
/* offset=3710533 */ "unc_h_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00011\000\000"
/* offset=3710715 */ "unc_h_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00011\000\000"
/* offset=3710895 */ "unc_h_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x19,umask=0x40\000\00011\000\000"
/* offset=3711076 */ "unc_h_rxc_irq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00011\000\000"
/* offset=3711257 */ "unc_h_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00011\000\000"
/* offset=3711423 */ "unc_h_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x19,umask=0x20\000\00011\000\000"
/* offset=3711612 */ "unc_h_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x4\000\00011\000\000"
/* offset=3711794 */ "unc_h_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x19,umask=0x80\000\00011\000\000"
/* offset=3711973 */ "unc_h_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x8\000\00011\000\000"
/* offset=3712153 */ "unc_h_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x19,umask=0x10\000\00011\000\000"
/* offset=3712328 */ "unc_h_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00011\000\000"
/* offset=3712512 */ "unc_h_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00011\000\000"
/* offset=3712696 */ "unc_h_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00011\000\000"
/* offset=3712881 */ "unc_h_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00011\000\000"
/* offset=3713066 */ "unc_h_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00011\000\000"
/* offset=3713250 */ "unc_h_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00011\000\000"
/* offset=3713432 */ "unc_h_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00011\000\000"
/* offset=3713614 */ "unc_h_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00011\000\000"
/* offset=3713796 */ "unc_h_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00011\000\000"
/* offset=3713979 */ "unc_h_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00011\000\000"
/* offset=3714162 */ "unc_h_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00011\000\000"
/* offset=3714344 */ "unc_h_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00011\000\000"
/* offset=3714524 */ "unc_h_rxc_ismq1_reject.any_ismq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00011\000\000"
/* offset=3714701 */ "unc_h_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00011\000\000"
/* offset=3714869 */ "unc_h_rxc_ismq1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00011\000\000"
/* offset=3715038 */ "unc_h_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00011\000\000"
/* offset=3715204 */ "unc_h_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00011\000\000"
/* offset=3715368 */ "unc_h_rxc_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00011\000\000"
/* offset=3715532 */ "unc_h_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00011\000\000"
/* offset=3715697 */ "unc_h_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00011\000\000"
/* offset=3715862 */ "unc_h_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00011\000\000"
/* offset=3716046 */ "unc_h_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00011\000\000"
/* offset=3716230 */ "unc_h_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00011\000\000"
/* offset=3716415 */ "unc_h_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00011\000\000"
/* offset=3716600 */ "unc_h_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00011\000\000"
/* offset=3716784 */ "unc_h_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00011\000\000"
/* offset=3716966 */ "unc_h_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00011\000\000"
/* offset=3717149 */ "unc_h_rxc_other1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00011\000\000"
/* offset=3717320 */ "unc_h_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00011\000\000"
/* offset=3717488 */ "unc_h_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00011\000\000"
/* offset=3717679 */ "unc_h_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00011\000\000"
/* offset=3717863 */ "unc_h_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00011\000\000"
/* offset=3718044 */ "unc_h_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00011\000\000"
/* offset=3718226 */ "unc_h_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00011\000\000"
/* offset=3718403 */ "unc_h_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00011\000\000"
/* offset=3718585 */ "unc_h_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00011\000\000"
/* offset=3718767 */ "unc_h_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00011\000\000"
/* offset=3718950 */ "unc_h_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00011\000\000"
/* offset=3719133 */ "unc_h_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00011\000\000"
/* offset=3719315 */ "unc_h_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00011\000\000"
/* offset=3719495 */ "unc_h_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x21,umask=0x40\000\00011\000\000"
/* offset=3719676 */ "unc_h_rxc_prq1_reject.any_prq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00011\000\000"
/* offset=3719850 */ "unc_h_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00011\000\000"
/* offset=3720016 */ "unc_h_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x21,umask=0x20\000\00011\000\000"
/* offset=3720205 */ "unc_h_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x4\000\00011\000\000"
/* offset=3720387 */ "unc_h_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x21,umask=0x80\000\00011\000\000"
/* offset=3720566 */ "unc_h_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x8\000\00011\000\000"
/* offset=3720746 */ "unc_h_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x21,umask=0x10\000\00011\000\000"
/* offset=3720921 */ "unc_h_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00011\000\000"
/* offset=3721105 */ "unc_h_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00011\000\000"
/* offset=3721289 */ "unc_h_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00011\000\000"
/* offset=3721474 */ "unc_h_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00011\000\000"
/* offset=3721659 */ "unc_h_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00011\000\000"
/* offset=3721843 */ "unc_h_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00011\000\000"
/* offset=3722025 */ "unc_h_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00011\000\000"
/* offset=3722208 */ "unc_h_rxc_req_q1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00011\000\000"
/* offset=3722379 */ "unc_h_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00011\000\000"
/* offset=3722547 */ "unc_h_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00011\000\000"
/* offset=3722738 */ "unc_h_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00011\000\000"
/* offset=3722922 */ "unc_h_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00011\000\000"
/* offset=3723103 */ "unc_h_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00011\000\000"
/* offset=3723285 */ "unc_h_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00011\000\000"
/* offset=3723462 */ "unc_h_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00011\000\000"
/* offset=3723644 */ "unc_h_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00011\000\000"
/* offset=3723826 */ "unc_h_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00011\000\000"
/* offset=3724009 */ "unc_h_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00011\000\000"
/* offset=3724192 */ "unc_h_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00011\000\000"
/* offset=3724374 */ "unc_h_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00011\000\000"
/* offset=3724554 */ "unc_h_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x27,umask=0x40\000\00011\000\000"
/* offset=3724735 */ "unc_h_rxc_rrq1_reject.any_rrq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00011\000\000"
/* offset=3724909 */ "unc_h_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00011\000\000"
/* offset=3725075 */ "unc_h_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x27,umask=0x20\000\00011\000\000"
/* offset=3725264 */ "unc_h_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x4\000\00011\000\000"
/* offset=3725446 */ "unc_h_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x27,umask=0x80\000\00011\000\000"
/* offset=3725625 */ "unc_h_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x8\000\00011\000\000"
/* offset=3725805 */ "unc_h_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x27,umask=0x10\000\00011\000\000"
/* offset=3725980 */ "unc_h_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00011\000\000"
/* offset=3726162 */ "unc_h_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00011\000\000"
/* offset=3726344 */ "unc_h_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00011\000\000"
/* offset=3726527 */ "unc_h_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00011\000\000"
/* offset=3726710 */ "unc_h_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00011\000\000"
/* offset=3726892 */ "unc_h_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00011\000\000"
/* offset=3727072 */ "unc_h_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x29,umask=0x40\000\00011\000\000"
/* offset=3727253 */ "unc_h_rxc_wbq1_reject.any_wbq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00011\000\000"
/* offset=3727427 */ "unc_h_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00011\000\000"
/* offset=3727593 */ "unc_h_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x29,umask=0x20\000\00011\000\000"
/* offset=3727782 */ "unc_h_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x4\000\00011\000\000"
/* offset=3727964 */ "unc_h_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x29,umask=0x80\000\00011\000\000"
/* offset=3728143 */ "unc_h_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x8\000\00011\000\000"
/* offset=3728323 */ "unc_h_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x29,umask=0x10\000\00011\000\000"
/* offset=3728498 */ "unc_h_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00011\000\000"
/* offset=3728674 */ "unc_h_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00011\000\000"
/* offset=3728851 */ "unc_h_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00011\000\000"
/* offset=3729027 */ "unc_h_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00011\000\000"
/* offset=3729204 */ "unc_h_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_BNC. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00011\000\000"
/* offset=3729368 */ "unc_h_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_CRD. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00011\000\000"
/* offset=3729533 */ "unc_h_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AK_BNC. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00011\000\000"
/* offset=3729697 */ "unc_h_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_BNC. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00011\000\000"
/* offset=3729861 */ "unc_h_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_CRD. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00011\000\000"
/* offset=3730026 */ "unc_h_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.IV_BNC. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00011\000\000"
/* offset=3730190 */ "unc_h_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00011\000\000"
/* offset=3730364 */ "unc_h_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00011\000\000"
/* offset=3730539 */ "unc_h_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AK_BNC. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00011\000\000"
/* offset=3730713 */ "unc_h_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00011\000\000"
/* offset=3730887 */ "unc_h_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00011\000\000"
/* offset=3731062 */ "unc_h_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IFV. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00011\000\000"
/* offset=3731231 */ "unc_h_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IV_BNC. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00011\000\000"
/* offset=3731405 */ "unc_h_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_BNC. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00011\000\000"
/* offset=3731571 */ "unc_h_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_CRD. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00011\000\000"
/* offset=3731738 */ "unc_h_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AK_BNC. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00011\000\000"
/* offset=3731904 */ "unc_h_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_BNC. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00011\000\000"
/* offset=3732070 */ "unc_h_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_CRD. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00011\000\000"
/* offset=3732237 */ "unc_h_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.IV_BNC. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00011\000\000"
/* offset=3732403 */ "unc_h_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00011\000\000"
/* offset=3732573 */ "unc_h_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00011\000\000"
/* offset=3732744 */ "unc_h_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00011\000\000"
/* offset=3732914 */ "unc_h_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00011\000\000"
/* offset=3733084 */ "unc_h_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00011\000\000"
/* offset=3733255 */ "unc_h_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00011\000\000"
/* offset=3733425 */ "unc_h_sbo0_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=3733616 */ "unc_h_sbo0_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=3733807 */ "unc_h_sbo0_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x68,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=3733999 */ "unc_h_sbo0_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x68,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=3734191 */ "unc_h_sbo1_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000"
/* offset=3734382 */ "unc_h_sbo1_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000"
/* offset=3734573 */ "unc_h_sbo1_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x69,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000"
/* offset=3734765 */ "unc_h_sbo1_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x69,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000"
/* offset=3734957 */ "unc_h_sf_eviction.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.E_STATE. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00011\000\000"
/* offset=3735125 */ "unc_h_sf_eviction.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.M_STATE. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00011\000\000"
/* offset=3735293 */ "unc_h_sf_eviction.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.S_STATE. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00011\000\000"
/* offset=3735461 */ "unc_h_sf_lookup.any\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ. Unit: uncore_cha \000event=0x34,umask=0x11\000\00001\000\000"
/* offset=3735733 */ "unc_h_sf_lookup.data_read\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Read transactions. Unit: uncore_cha \000event=0x34,umask=0x3\000\00001\000\000"
/* offset=3735910 */ "unc_h_sf_lookup.remote_snoop\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for only snoop requests coming from the remote socket(s) through the IPQ. Unit: uncore_cha \000event=0x34,umask=0x9\000\00001\000\000"
/* offset=3736153 */ "unc_h_sf_lookup.write\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC. Unit: uncore_cha \000event=0x34,umask=0x5\000\00001\000\000"
/* offset=3736413 */ "unc_h_snoop_cycles_ne.all\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; All Requests. Unit: uncore_ha \000event=0x8,umask=0x3\000\00001\000Counts cycles when one or more snoops are outstanding.; Tracked for snoops from both local and remote sockets\000"
/* offset=3736659 */ "unc_h_snoop_cycles_ne.local\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Local Requests. Unit: uncore_ha \000event=0x8,umask=0x1\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from the local socket\000"
/* offset=3736919 */ "unc_h_snoop_cycles_ne.remote\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Remote Requests. Unit: uncore_ha \000event=0x8,umask=0x2\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from remote sockets\000"
/* offset=3737179 */ "unc_h_snoop_occupancy.local\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Local Requests. Unit: uncore_ha \000event=0x9,umask=0x1\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from the local socket\000"
/* offset=3737841 */ "unc_h_snoop_occupancy.remote\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Remote Requests. Unit: uncore_ha \000event=0x9,umask=0x2\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from remote sockets\000"
/* offset=3738503 */ "unc_h_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_FWD_WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00011\000\000"
/* offset=3738676 */ "unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000M line forwarded from remote cache along with writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x20\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3739531 */ "unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*Fwd*WB. Unit: uncore_ha \000event=0x21,umask=0x20\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3740350 */ "unc_h_snoop_resp.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_WBWB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00011\000\000"
/* offset=3740517 */ "unc_h_snoop_resp.rsp_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*WB. Unit: uncore_ha \000event=0x21,umask=0x10\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000"
/* offset=3741353 */ "unc_h_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPCNFLCTS. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00011\000\000"
/* offset=3741525 */ "unc_h_snoop_resp.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received; RSPCNFLCT*. Unit: uncore_ha \000event=0x21,umask=0x40\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000"
/* offset=3742340 */ "unc_h_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPFWD. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00011\000\000"
/* offset=3742505 */ "unc_h_snoop_resp.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPI. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00011\000\000"
/* offset=3742665 */ "unc_h_snoop_resp.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received; RspI. Unit: uncore_ha \000event=0x21,umask=0x1\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000"
/* offset=3743394 */ "unc_h_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPIFWD. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00011\000\000"
/* offset=3743560 */ "unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000M line forwarded from remote cache with no writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x4\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000"
/* offset=3744395 */ "unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspIFwd. Unit: uncore_ha \000event=0x21,umask=0x4\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000"
/* offset=3745194 */ "unc_h_snoop_resp.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00011\000\000"
/* offset=3745354 */ "unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Shared line response from remote cache. Unit: uncore_ha \000event=0x21,umask=0x2\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3746136 */ "unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received; RspS. Unit: uncore_ha \000event=0x21,umask=0x2\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3746903 */ "unc_h_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPSFWD. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00011\000\000"
/* offset=3747069 */ "unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Shared line forwarded from remote cache. Unit: uncore_ha \000event=0x21,umask=0x8\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3747843 */ "unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Shared line forwarded from remote cache. Unit: uncore_ha \000event=0x21,umask=0x8\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3748619 */ "unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspSFwd. Unit: uncore_ha \000event=0x21,umask=0x8\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3749380 */ "unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspSFwd. Unit: uncore_ha \000event=0x21,umask=0x8\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3750143 */ "unc_h_snoops_rsp_after_data.local\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Local Requests. Unit: uncore_ha \000event=0xa,umask=0x1\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from the local socket\000"
/* offset=3750440 */ "unc_h_snoops_rsp_after_data.remote\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Remote Requests. Unit: uncore_ha \000event=0xa,umask=0x2\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from remote sockets\000"
/* offset=3750737 */ "unc_h_snoops_sent.\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.ALL. Unit: uncore_cha \000event=0x51,umask=0x1\000\00011\000\000"
/* offset=3750894 */ "unc_h_snoops_sent.bcst_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x10\000\00011\000\000"
/* offset=3751067 */ "unc_h_snoops_sent.bcst_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x20\000\00011\000\000"
/* offset=3751241 */ "unc_h_snoops_sent.direct_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x40\000\00011\000\000"
/* offset=3751418 */ "unc_h_snoops_sent.direct_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x80\000\00011\000\000"
/* offset=3751596 */ "unc_h_snoops_sent.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.LOCAL. Unit: uncore_cha \000event=0x51,umask=0x4\000\00011\000\000"
/* offset=3751760 */ "unc_h_snoops_sent.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.REMOTE. Unit: uncore_cha \000event=0x51,umask=0x8\000\00011\000\000"
/* offset=3751926 */ "unc_h_snp_resp_recv_local.other\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Other. Unit: uncore_ha \000event=0x60,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for all other snoop responses\000"
/* offset=3752158 */ "unc_h_snp_resp_recv_local.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_ha \000event=0x60,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000"
/* offset=3752627 */ "unc_h_snp_resp_recv_local.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_ha \000event=0x60,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000"
/* offset=3753011 */ "unc_h_snp_resp_recv_local.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_ha \000event=0x60,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000"
/* offset=3753465 */ "unc_h_snp_resp_recv_local.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_ha \000event=0x60,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000"
/* offset=3753887 */ "unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3754303 */ "unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000"
/* offset=3754721 */ "unc_h_snp_resp_recv_local.rspxfwdxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_ha \000event=0x60,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000"
/* offset=3755195 */ "unc_h_snp_resp_recv_local.rspxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_ha \000event=0x60,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000"
/* offset=3755686 */ "unc_h_snp_rsp_rcv_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_FWD_WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00011\000\000"
/* offset=3755872 */ "unc_h_snp_rsp_rcv_local.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00011\000\000"
/* offset=3756050 */ "unc_h_snp_rsp_rcv_local.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPCNFLCT. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00011\000\000"
/* offset=3756234 */ "unc_h_snp_rsp_rcv_local.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPFWD. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00011\000\000"
/* offset=3756412 */ "unc_h_snp_rsp_rcv_local.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00011\000\000"
/* offset=3756585 */ "unc_h_snp_rsp_rcv_local.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPIFWD. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00011\000\000"
/* offset=3756764 */ "unc_h_snp_rsp_rcv_local.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00011\000\000"
/* offset=3756937 */ "unc_h_snp_rsp_rcv_local.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPSFWD. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00011\000\000"
/* offset=3757116 */ "unc_h_stall_no_sbo_credit.sbo0_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=3757360 */ "unc_h_stall_no_sbo_credit.sbo0_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=3757604 */ "unc_h_stall_no_sbo_credit.sbo1_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=3757848 */ "unc_h_stall_no_sbo_credit.sbo1_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=3758092 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00011\000\000"
/* offset=3758288 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00011\000\000"
/* offset=3758484 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00011\000\000"
/* offset=3758680 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00011\000\000"
/* offset=3758876 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00011\000\000"
/* offset=3759073 */ "unc_h_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00011\000\000"
/* offset=3759270 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00011\000\000"
/* offset=3759466 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00011\000\000"
/* offset=3759662 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00011\000\000"
/* offset=3759858 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00011\000\000"
/* offset=3760054 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00011\000\000"
/* offset=3760251 */ "unc_h_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00011\000\000"
/* offset=3760448 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00011\000\000"
/* offset=3760644 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00011\000\000"
/* offset=3760840 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00011\000\000"
/* offset=3761036 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00011\000\000"
/* offset=3761232 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00011\000\000"
/* offset=3761429 */ "unc_h_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00011\000\000"
/* offset=3761626 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00011\000\000"
/* offset=3761822 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00011\000\000"
/* offset=3762018 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00011\000\000"
/* offset=3762214 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00011\000\000"
/* offset=3762410 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00011\000\000"
/* offset=3762607 */ "unc_h_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00011\000\000"
/* offset=3762804 */ "unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3763538 */ "unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 0\000"
/* offset=3764309 */ "unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3765043 */ "unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 1\000"
/* offset=3765814 */ "unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3766548 */ "unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 2\000"
/* offset=3767319 */ "unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3768053 */ "unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 3\000"
/* offset=3768824 */ "unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3769559 */ "unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 4\000"
/* offset=3770331 */ "unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3771066 */ "unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 5\000"
/* offset=3771838 */ "unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3772573 */ "unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 6\000"
/* offset=3773345 */ "unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3774080 */ "unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 7\000"
/* offset=3774852 */ "unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3775589 */ "unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 10\000"
/* offset=3776364 */ "unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3777101 */ "unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 11\000"
/* offset=3777876 */ "unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3778611 */ "unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 8\000"
/* offset=3779383 */ "unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000"
/* offset=3780118 */ "unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 9\000"
/* offset=3780890 */ "unc_h_tg_ingress_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000\000"
/* offset=3781268 */ "unc_h_tg_ingress_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00001\000\000"
/* offset=3781647 */ "unc_h_tg_ingress_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000\000"
/* offset=3782025 */ "unc_h_tg_ingress_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00001\000\000"
/* offset=3782404 */ "unc_h_tg_ingress_bypass.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000\000"
/* offset=3782576 */ "unc_h_tg_ingress_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x10\000\00001\000\000"
/* offset=3782749 */ "unc_h_tg_ingress_bypass.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000\000"
/* offset=3782921 */ "unc_h_tg_ingress_bypass.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000\000"
/* offset=3783093 */ "unc_h_tg_ingress_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x40\000\00001\000\000"
/* offset=3783266 */ "unc_h_tg_ingress_bypass.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000\000"
/* offset=3783438 */ "unc_h_tg_ingress_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000\000"
/* offset=3783827 */ "unc_h_tg_ingress_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00001\000\000"
/* offset=3784217 */ "unc_h_tg_ingress_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00001\000\000"
/* offset=3784606 */ "unc_h_tg_ingress_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000\000"
/* offset=3784995 */ "unc_h_tg_ingress_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00001\000\000"
/* offset=3785385 */ "unc_h_tg_ingress_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00001\000\000"
/* offset=3785772 */ "unc_h_tg_ingress_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00001\000\000"
/* offset=3786161 */ "unc_h_tg_ingress_inserts.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000\000"
/* offset=3786402 */ "unc_h_tg_ingress_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00001\000\000"
/* offset=3786644 */ "unc_h_tg_ingress_inserts.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000\000"
/* offset=3786885 */ "unc_h_tg_ingress_inserts.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000\000"
/* offset=3787126 */ "unc_h_tg_ingress_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00001\000\000"
/* offset=3787368 */ "unc_h_tg_ingress_inserts.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000\000"
/* offset=3787609 */ "unc_h_tg_ingress_occupancy.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000\000"
/* offset=3787858 */ "unc_h_tg_ingress_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00001\000\000"
/* offset=3788108 */ "unc_h_tg_ingress_occupancy.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000\000"
/* offset=3788357 */ "unc_h_tg_ingress_occupancy.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000\000"
/* offset=3788606 */ "unc_h_tg_ingress_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00001\000\000"
/* offset=3788856 */ "unc_h_tg_ingress_occupancy.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000\000"
/* offset=3789105 */ "unc_h_tor_inserts.evict\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x32\000\00001\000\000"
/* offset=3789334 */ "unc_h_tor_inserts.hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -Hit (Not a Miss). Unit: uncore_cha \000event=0x35,umask=0x1f\000\00001\000\000"
/* offset=3789561 */ "unc_h_tor_inserts.ipq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x38\000\00001\000\000"
/* offset=3789775 */ "unc_h_tor_inserts.irq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x31\000\00001\000\000"
/* offset=3789989 */ "unc_h_tor_inserts.miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -Miss. Unit: uncore_cha \000event=0x35,umask=0x2f\000\00001\000\000"
/* offset=3790205 */ "unc_h_tor_inserts.prq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x34\000\00001\000\000"
/* offset=3790419 */ "unc_h_tor_occupancy.evict\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x32\000\00001\000\000"
/* offset=3790663 */ "unc_h_tor_occupancy.hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -Hit (Not a Miss). Unit: uncore_cha \000event=0x36,umask=0x1f\000\00001\000\000"
/* offset=3790905 */ "unc_h_tor_occupancy.ipq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x36,umask=0x38\000\00001\000\000"
/* offset=3791134 */ "unc_h_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ hit. Unit: uncore_cha \000event=0x36,umask=0x18\000\00001\000\000"
/* offset=3791371 */ "unc_h_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ miss. Unit: uncore_cha \000event=0x36,umask=0x28\000\00001\000\000"
/* offset=3791610 */ "unc_h_tor_occupancy.irq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ. Unit: uncore_cha \000event=0x36,umask=0x31\000\00001\000\000"
/* offset=3791846 */ "unc_h_tor_occupancy.irq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ hit. Unit: uncore_cha \000event=0x36,umask=0x11\000\00001\000\000"
/* offset=3792090 */ "unc_h_tor_occupancy.irq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ miss. Unit: uncore_cha \000event=0x36,umask=0x21\000\00001\000\000"
/* offset=3792336 */ "unc_h_tor_occupancy.miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -Miss. Unit: uncore_cha \000event=0x36,umask=0x2f\000\00001\000\000"
/* offset=3792567 */ "unc_h_tor_occupancy.prq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x36,umask=0x34\000\00001\000\000"
/* offset=3792796 */ "unc_h_tor_occupancy.prq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ hit. Unit: uncore_cha \000event=0x36,umask=0x14\000\00001\000\000"
/* offset=3793033 */ "unc_h_tor_occupancy.prq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ miss. Unit: uncore_cha \000event=0x36,umask=0x24\000\00001\000\000"
/* offset=3793272 */ "unc_h_tracker_cycles_full.all\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles Completely Used. Unit: uncore_ha \000event=0x2,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the HA tracker pool (HT) is completely used including reserved HT entries.  It will not return valid count when BT is disabled\000"
/* offset=3794203 */ "unc_h_tracker_cycles_full.gp\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles GP Completely Used. Unit: uncore_ha \000event=0x2,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the general purpose (GP) HA tracker pool (HT) is completely used.  It will not return valid count when BT is disabled\000"
/* offset=3795127 */ "unc_h_tracker_cycles_ne.all\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; All Requests. Unit: uncore_ha \000event=0x3,umask=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Requests coming from both local and remote sockets\000"
/* offset=3796110 */ "unc_h_tracker_cycles_ne.local\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Local Requests. Unit: uncore_ha \000event=0x3,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from the local socket\000"
/* offset=3797110 */ "unc_h_tracker_cycles_ne.remote\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Remote Requests. Unit: uncore_ha \000event=0x3,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from remote sockets\000"
/* offset=3798110 */ "unc_h_tracker_cycles_ne\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty. Unit: uncore_ha \000event=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3799012 */ "unc_h_tracker_inserts.all\000uncore_ha\000uncore cache\000Tracker Allocations; All Requests. Unit: uncore_ha \000event=0x6,umask=0x3\000\00001\000Counts the number of allocations into the local HA tracker pool.  This can be used in conjunction with the occupancy accumulation event in order to calculate average latency.  One cannot filter between reads and writes.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3799550 */ "unc_h_tracker_occupancy.invitoe_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x40\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3800176 */ "unc_h_tracker_occupancy.invitoe_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x80\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3800804 */ "unc_h_tracker_occupancy.reads_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Read Requests. Unit: uncore_ha \000event=0x4,umask=0x4\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3801424 */ "unc_h_tracker_occupancy.reads_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Read Requests. Unit: uncore_ha \000event=0x4,umask=0x8\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3802046 */ "unc_h_tracker_occupancy.writes_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Write Requests. Unit: uncore_ha \000event=0x4,umask=0x10\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3802669 */ "unc_h_tracker_occupancy.writes_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Write Requests. Unit: uncore_ha \000event=0x4,umask=0x20\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000"
/* offset=3803294 */ "unc_h_tracker_pending_occupancy.local\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Local Requests. Unit: uncore_ha \000event=0x5,umask=0x1\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from the local socket\000"
/* offset=3803895 */ "unc_h_tracker_pending_occupancy.remote\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Remote Requests. Unit: uncore_ha \000event=0x5,umask=0x2\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from remote sockets\000"
/* offset=3804496 */ "unc_h_txr_ad.hom\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x4\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details.; Filter for outbound NDR transactions sent on the AD ring.  NDR stands for non-data response and is generally used for completions that do not include data.  AD NDR is used for transactions to remote sockets\000"
/* offset=3805001 */ "unc_h_txr_ad.ndr\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x1\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details\000"
/* offset=3805297 */ "unc_h_txr_ad.snp\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Snoops. Unit: uncore_ha \000event=0xf,umask=0x2\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details\000"
/* offset=3805581 */ "unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000AD Egress Full; Cycles full from both schedulers\000"
/* offset=3805745 */ "unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000\000"
/* offset=3805861 */ "unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 0\000"
/* offset=3806049 */ "unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000\000"
/* offset=3806176 */ "unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 1\000"
/* offset=3806364 */ "unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000\000"
/* offset=3806491 */ "unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000AD Egress Not Empty; Cycles full from both schedulers\000"
/* offset=3806663 */ "unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000\000"
/* offset=3806782 */ "unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000AD Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000"
/* offset=3806983 */ "unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000\000"
/* offset=3807113 */ "unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000AD Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000"
/* offset=3807313 */ "unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000\000"
/* offset=3807443 */ "unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000AD Egress Allocations; Allocations from both schedulers\000"
/* offset=3807617 */ "unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000\000"
/* offset=3807736 */ "unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 0\000"
/* offset=3807933 */ "unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000\000"
/* offset=3808063 */ "unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 1\000"
/* offset=3808260 */ "unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000\000"
/* offset=3808390 */ "unc_h_txr_ad_occupancy.all\000uncore_ha\000uncore cache\000AD Egress Occupancy; All. Unit: uncore_ha \000event=0x28,umask=0x3\000\00001\000\000"
/* offset=3808509 */ "unc_h_txr_ad_occupancy.sched0\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x28,umask=0x1\000\00001\000AD Egress Occupancy; Filter for occupancy from scheduler bank 0\000"
/* offset=3808702 */ "unc_h_txr_ad_occupancy.sched0\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x28,umask=0x1\000\00001\000\000"
/* offset=3808832 */ "unc_h_txr_ad_occupancy.sched1\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x28,umask=0x2\000\00001\000AD Egress Occupancy; Filter for occupancy from scheduler bank 1\000"
/* offset=3809025 */ "unc_h_txr_ad_occupancy.sched1\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x28,umask=0x2\000\00001\000\000"
/* offset=3809155 */ "unc_h_txr_ak.crd_cbo\000uncore_ha\000uncore cache\000Outbound Ring Transactions on AK: CRD Transactions to Cbo. Unit: uncore_ha \000event=0xe,umask=0x2\000\00001\000\000"
/* offset=3809300 */ "unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000AK Egress Full; Cycles full from both schedulers\000"
/* offset=3809464 */ "unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000\000"
/* offset=3809580 */ "unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 0\000"
/* offset=3809768 */ "unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000\000"
/* offset=3809895 */ "unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 1\000"
/* offset=3810083 */ "unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000\000"
/* offset=3810210 */ "unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000AK Egress Not Empty; Cycles full from both schedulers\000"
/* offset=3810382 */ "unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000\000"
/* offset=3810501 */ "unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000AK Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000"
/* offset=3810702 */ "unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000\000"
/* offset=3810832 */ "unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000AK Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000"
/* offset=3811032 */ "unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000\000"
/* offset=3811162 */ "unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000AK Egress Allocations; Allocations from both schedulers\000"
/* offset=3811336 */ "unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000\000"
/* offset=3811455 */ "unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 0\000"
/* offset=3811652 */ "unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000\000"
/* offset=3811782 */ "unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 1\000"
/* offset=3811979 */ "unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000\000"
/* offset=3812109 */ "unc_h_txr_ak_ndr\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions. Unit: uncore_ha \000event=0xe\000\00001\000Counts the number of outbound NDR transactions sent on the AK ring.  NDR stands for 'non-data response' and is generally used for completions that do not include data.  AK NDR is used for messages to the local socket\000"
/* offset=3812429 */ "unc_h_txr_ak_occupancy.all\000uncore_ha\000uncore cache\000AK Egress Occupancy; All. Unit: uncore_ha \000event=0x30,umask=0x3\000\00001\000\000"
/* offset=3812548 */ "unc_h_txr_ak_occupancy.sched0\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x30,umask=0x1\000\00001\000AK Egress Occupancy; Filter for occupancy from scheduler bank 0\000"
/* offset=3812741 */ "unc_h_txr_ak_occupancy.sched0\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x30,umask=0x1\000\00001\000\000"
/* offset=3812871 */ "unc_h_txr_ak_occupancy.sched1\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x30,umask=0x2\000\00001\000AK Egress Occupancy; Filter for occupancy from scheduler bank 1\000"
/* offset=3813064 */ "unc_h_txr_ak_occupancy.sched1\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x30,umask=0x2\000\00001\000\000"
/* offset=3813194 */ "unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to the cache\000"
/* offset=3813481 */ "unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000"
/* offset=3813726 */ "unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent directly to the requesting core\000"
/* offset=3814030 */ "unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000"
/* offset=3814273 */ "unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to a remote socket over QPI\000"
/* offset=3814571 */ "unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000"
/* offset=3814812 */ "unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000BL Egress Full; Cycles full from both schedulers\000"
/* offset=3814976 */ "unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000\000"
/* offset=3815092 */ "unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 0\000"
/* offset=3815280 */ "unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000\000"
/* offset=3815407 */ "unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 1\000"
/* offset=3815595 */ "unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000\000"
/* offset=3815722 */ "unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000BL Egress Not Empty; Cycles full from both schedulers\000"
/* offset=3815894 */ "unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000\000"
/* offset=3816013 */ "unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000BL Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000"
/* offset=3816214 */ "unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000\000"
/* offset=3816344 */ "unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000BL Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000"
/* offset=3816544 */ "unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000\000"
/* offset=3816674 */ "unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000BL Egress Allocations; Allocations from both schedulers\000"
/* offset=3816848 */ "unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000\000"
/* offset=3816967 */ "unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 0\000"
/* offset=3817164 */ "unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000\000"
/* offset=3817294 */ "unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 1\000"
/* offset=3817491 */ "unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000\000"
/* offset=3817621 */ "unc_h_txr_bl_occupancy.all\000uncore_ha\000uncore cache\000BL Egress Occupancy: All. Unit: uncore_ha \000event=0x34,umask=0x3\000\00001\000\000"
/* offset=3817740 */ "unc_h_txr_bl_occupancy.all\000uncore_ha\000uncore cache\000BL Egress Occupancy; All. Unit: uncore_ha \000event=0x34,umask=0x3\000\00001\000\000"
/* offset=3817859 */ "unc_h_txr_bl_occupancy.sched0\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x34,umask=0x1\000\00001\000BL Egress Occupancy; Filter for occupancy from scheduler bank 0\000"
/* offset=3818052 */ "unc_h_txr_bl_occupancy.sched0\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x34,umask=0x1\000\00001\000\000"
/* offset=3818182 */ "unc_h_txr_bl_occupancy.sched1\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x34,umask=0x2\000\00001\000BL Egress Occupancy; Filter for occupancy from scheduler bank 1\000"
/* offset=3818375 */ "unc_h_txr_bl_occupancy.sched1\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x34,umask=0x2\000\00001\000\000"
/* offset=3818505 */ "unc_h_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_BNC. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00011\000\000"
/* offset=3818683 */ "unc_h_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_CRD. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00011\000\000"
/* offset=3818862 */ "unc_h_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AK_BNC. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00011\000\000"
/* offset=3819040 */ "unc_h_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_BNC. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00011\000\000"
/* offset=3819218 */ "unc_h_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_CRD. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00011\000\000"
/* offset=3819397 */ "unc_h_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_BNC. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00011\000\000"
/* offset=3819571 */ "unc_h_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_CRD. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00011\000\000"
/* offset=3819746 */ "unc_h_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AK_BNC. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00011\000\000"
/* offset=3819920 */ "unc_h_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_BNC. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00011\000\000"
/* offset=3820094 */ "unc_h_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_CRD. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00011\000\000"
/* offset=3820269 */ "unc_h_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.IV_BNC. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00011\000\000"
/* offset=3820443 */ "unc_h_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_BNC. Unit: uncore_cha \000event=0x96,umask=0x1\000\00011\000\000"
/* offset=3820627 */ "unc_h_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_CRD. Unit: uncore_cha \000event=0x96,umask=0x10\000\00011\000\000"
/* offset=3820812 */ "unc_h_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AK_BNC. Unit: uncore_cha \000event=0x96,umask=0x2\000\00011\000\000"
/* offset=3820996 */ "unc_h_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_BNC. Unit: uncore_cha \000event=0x96,umask=0x4\000\00011\000\000"
/* offset=3821180 */ "unc_h_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_CRD. Unit: uncore_cha \000event=0x96,umask=0x40\000\00011\000\000"
/* offset=3821365 */ "unc_h_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.IV_BNC. Unit: uncore_cha \000event=0x96,umask=0x8\000\00011\000\000"
/* offset=3821549 */ "unc_h_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_BNC. Unit: uncore_cha \000event=0x97,umask=0x1\000\00011\000\000"
/* offset=3821729 */ "unc_h_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_CRD. Unit: uncore_cha \000event=0x97,umask=0x10\000\00011\000\000"
/* offset=3821910 */ "unc_h_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AK_BNC. Unit: uncore_cha \000event=0x97,umask=0x2\000\00011\000\000"
/* offset=3822090 */ "unc_h_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_BNC. Unit: uncore_cha \000event=0x97,umask=0x4\000\00011\000\000"
/* offset=3822270 */ "unc_h_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_CRD. Unit: uncore_cha \000event=0x97,umask=0x40\000\00011\000\000"
/* offset=3822451 */ "unc_h_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.IV_BNC. Unit: uncore_cha \000event=0x97,umask=0x8\000\00011\000\000"
/* offset=3822631 */ "unc_h_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_BNC. Unit: uncore_cha \000event=0x95,umask=0x1\000\00011\000\000"
/* offset=3822807 */ "unc_h_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_CRD. Unit: uncore_cha \000event=0x95,umask=0x10\000\00011\000\000"
/* offset=3822984 */ "unc_h_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AK_BNC. Unit: uncore_cha \000event=0x95,umask=0x2\000\00011\000\000"
/* offset=3823160 */ "unc_h_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_BNC. Unit: uncore_cha \000event=0x95,umask=0x4\000\00011\000\000"
/* offset=3823336 */ "unc_h_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_CRD. Unit: uncore_cha \000event=0x95,umask=0x40\000\00011\000\000"
/* offset=3823513 */ "unc_h_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.IV_BNC. Unit: uncore_cha \000event=0x95,umask=0x8\000\00011\000\000"
/* offset=3823689 */ "unc_h_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_BNC. Unit: uncore_cha \000event=0x99,umask=0x1\000\00011\000\000"
/* offset=3823859 */ "unc_h_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_CRD. Unit: uncore_cha \000event=0x99,umask=0x20\000\00011\000\000"
/* offset=3824030 */ "unc_h_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AK_BNC. Unit: uncore_cha \000event=0x99,umask=0x2\000\00011\000\000"
/* offset=3824200 */ "unc_h_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_BNC. Unit: uncore_cha \000event=0x99,umask=0x4\000\00011\000\000"
/* offset=3824370 */ "unc_h_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_CRD. Unit: uncore_cha \000event=0x99,umask=0x40\000\00011\000\000"
/* offset=3824541 */ "unc_h_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.IV_BNC. Unit: uncore_cha \000event=0x99,umask=0x8\000\00011\000\000"
/* offset=3824711 */ "unc_h_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0x94,umask=0x1\000\00011\000\000"
/* offset=3824891 */ "unc_h_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0x94,umask=0x10\000\00011\000\000"
/* offset=3825072 */ "unc_h_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0x94,umask=0x2\000\00011\000\000"
/* offset=3825252 */ "unc_h_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0x94,umask=0x4\000\00011\000\000"
/* offset=3825432 */ "unc_h_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0x94,umask=0x40\000\00011\000\000"
/* offset=3825613 */ "unc_h_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0x94,umask=0x8\000\00011\000\000"
/* offset=3825793 */ "unc_h_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AD_BNC. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00011\000\000"
/* offset=3825969 */ "unc_h_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AK_BNC. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00011\000\000"
/* offset=3826145 */ "unc_h_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.BL_BNC. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00011\000\000"
/* offset=3826321 */ "unc_h_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.IV_BNC. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00011\000\000"
/* offset=3826497 */ "unc_h_txr_starved.ak\000uncore_ha\000uncore cache\000Injection Starvation; For AK Ring. Unit: uncore_ha \000event=0x6d,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=3826759 */ "unc_h_txr_starved.bl\000uncore_ha\000uncore cache\000Injection Starvation; For BL Ring. Unit: uncore_ha \000event=0x6d,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=3827021 */ "unc_h_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00011\000\000"
/* offset=3827199 */ "unc_h_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00011\000\000"
/* offset=3827378 */ "unc_h_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00011\000\000"
/* offset=3827556 */ "unc_h_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00011\000\000"
/* offset=3827735 */ "unc_h_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00011\000\000"
/* offset=3827913 */ "unc_h_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00011\000\000"
/* offset=3828092 */ "unc_h_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00011\000\000"
/* offset=3828266 */ "unc_h_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00011\000\000"
/* offset=3828441 */ "unc_h_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00011\000\000"
/* offset=3828615 */ "unc_h_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00011\000\000"
/* offset=3828790 */ "unc_h_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00011\000\000"
/* offset=3828964 */ "unc_h_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00011\000\000"
/* offset=3829139 */ "unc_h_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00011\000\000"
/* offset=3829309 */ "unc_h_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00011\000\000"
/* offset=3829493 */ "unc_h_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00011\000\000"
/* offset=3829678 */ "unc_h_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00011\000\000"
/* offset=3829862 */ "unc_h_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00011\000\000"
/* offset=3830047 */ "unc_h_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00011\000\000"
/* offset=3830231 */ "unc_h_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00011\000\000"
/* offset=3830416 */ "unc_h_txr_vert_cycles_full.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00011\000\000"
/* offset=3830596 */ "unc_h_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00011\000\000"
/* offset=3830776 */ "unc_h_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00011\000\000"
/* offset=3830957 */ "unc_h_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00011\000\000"
/* offset=3831137 */ "unc_h_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00011\000\000"
/* offset=3831318 */ "unc_h_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00011\000\000"
/* offset=3831498 */ "unc_h_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00011\000\000"
/* offset=3831679 */ "unc_h_txr_vert_cycles_ne.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00011\000\000"
/* offset=3831855 */ "unc_h_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00011\000\000"
/* offset=3832031 */ "unc_h_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00011\000\000"
/* offset=3832208 */ "unc_h_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00011\000\000"
/* offset=3832384 */ "unc_h_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00011\000\000"
/* offset=3832561 */ "unc_h_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00011\000\000"
/* offset=3832737 */ "unc_h_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00011\000\000"
/* offset=3832914 */ "unc_h_txr_vert_inserts.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00011\000\000"
/* offset=3833086 */ "unc_h_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00011\000\000"
/* offset=3833256 */ "unc_h_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00011\000\000"
/* offset=3833427 */ "unc_h_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00011\000\000"
/* offset=3833597 */ "unc_h_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00011\000\000"
/* offset=3833768 */ "unc_h_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00011\000\000"
/* offset=3833938 */ "unc_h_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00011\000\000"
/* offset=3834109 */ "unc_h_txr_vert_nack.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00011\000\000"
/* offset=3834271 */ "unc_h_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00011\000\000"
/* offset=3834451 */ "unc_h_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00011\000\000"
/* offset=3834632 */ "unc_h_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00011\000\000"
/* offset=3834812 */ "unc_h_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00011\000\000"
/* offset=3834993 */ "unc_h_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00011\000\000"
/* offset=3835173 */ "unc_h_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00011\000\000"
/* offset=3835354 */ "unc_h_txr_vert_occupancy.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00011\000\000"
/* offset=3835530 */ "unc_h_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00011\000\000"
/* offset=3835706 */ "unc_h_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00011\000\000"
/* offset=3835883 */ "unc_h_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00011\000\000"
/* offset=3836059 */ "unc_h_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00011\000\000"
/* offset=3836236 */ "unc_h_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00011\000\000"
/* offset=3836412 */ "unc_h_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00011\000\000"
/* offset=3836589 */ "unc_h_txr_vert_starved.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00011\000\000"
/* offset=3836757 */ "unc_h_u_clockticks\000uncore_cha\000uncore cache\000Uncore Clocks. Unit: uncore_cha \000event=0\000\00001\000\000"
/* offset=3836846 */ "unc_h_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000\000"
/* offset=3837051 */ "unc_h_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00011\000\000"
/* offset=3837235 */ "unc_h_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00001\000\000"
/* offset=3837438 */ "unc_h_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00011\000\000"
/* offset=3837620 */ "unc_h_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000\000"
/* offset=3837823 */ "unc_h_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00011\000\000"
/* offset=3838007 */ "unc_h_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00001\000\000"
/* offset=3838208 */ "unc_h_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00011\000\000"
/* offset=3838390 */ "unc_h_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00001\000\000"
/* offset=3838595 */ "unc_h_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00011\000\000"
/* offset=3838779 */ "unc_h_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00001\000\000"
/* offset=3838982 */ "unc_h_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00011\000\000"
/* offset=3839164 */ "unc_h_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00001\000\000"
/* offset=3839367 */ "unc_h_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00011\000\000"
/* offset=3839551 */ "unc_h_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00001\000\000"
/* offset=3839752 */ "unc_h_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00011\000\000"
/* offset=3839934 */ "unc_h_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000\000"
/* offset=3840139 */ "unc_h_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00011\000\000"
/* offset=3840323 */ "unc_h_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000\000"
/* offset=3840526 */ "unc_h_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00011\000\000"
/* offset=3840708 */ "unc_h_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000\000"
/* offset=3840911 */ "unc_h_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00011\000\000"
/* offset=3841095 */ "unc_h_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000\000"
/* offset=3841296 */ "unc_h_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00011\000\000"
/* offset=3841478 */ "unc_h_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop - Down. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000\000"
/* offset=3841669 */ "unc_h_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.DN. Unit: uncore_cha \000event=0xac,umask=0x4\000\00011\000\000"
/* offset=3841843 */ "unc_h_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop - Up. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000\000"
/* offset=3842032 */ "unc_h_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.UP. Unit: uncore_cha \000event=0xac,umask=0x1\000\00011\000\000"
/* offset=3842206 */ "unc_h_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00011\000\000"
/* offset=3842368 */ "unc_h_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.MEM. Unit: uncore_cha \000event=0x56,umask=0x2\000\00011\000\000"
/* offset=3842530 */ "unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3843414 */ "unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000"
/* offset=3844340 */ "unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3845224 */ "unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000"
/* offset=3846150 */ "unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3847034 */ "unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000"
/* offset=3847960 */ "unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3848844 */ "unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000"
/* offset=3849770 */ "unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3850614 */ "unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000"
/* offset=3851498 */ "unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3852342 */ "unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000"
/* offset=3853226 */ "unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3854070 */ "unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000"
/* offset=3854954 */ "unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000"
/* offset=3855798 */ "unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000"
/* offset=3856682 */ "unc_h_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00011\000\000"
/* offset=3856864 */ "unc_h_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00011\000\000"
/* offset=3857046 */ "unc_h_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00011\000\000"
/* offset=3857229 */ "unc_h_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00011\000\000"
/* offset=3857412 */ "unc_h_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00011\000\000"
/* offset=3857592 */ "unc_h_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00011\000\000"
/* offset=3857772 */ "unc_h_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00011\000\000"
/* offset=3857951 */ "unc_h_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00011\000\000"
/* offset=3858130 */ "unc_h_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00011\000\000"
/* offset=3858307 */ "unc_h_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00011\000\000"
/* offset=3858486 */ "unc_h_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00011\000\000"
/* offset=3858663 */ "unc_h_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00011\000\000"
/* offset=3858844 */ "unc_h_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00011\000\000"
/* offset=3859025 */ "unc_h_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00011\000\000"
/* offset=3859204 */ "unc_h_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00011\000\000"
/* offset=3859385 */ "unc_h_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00011\000\000"
/* offset=3859564 */ "unc_h_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00011\000\000"
/* offset=3859747 */ "unc_h_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00011\000\000"
/* offset=3859930 */ "unc_h_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00011\000\000"
/* offset=3860111 */ "unc_h_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00011\000\000"
/* offset=3860294 */ "unc_h_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00011\000\000"
/* offset=3860475 */ "unc_h_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00011\000\000"
/* offset=3860654 */ "unc_h_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00011\000\000"
/* offset=3860833 */ "unc_h_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00011\000\000"
/* offset=3861010 */ "unc_h_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00011\000\000"
/* offset=3861189 */ "unc_h_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00011\000\000"
/* offset=3861366 */ "unc_hac_arb_req_trk_request.drd\000uncore_hac_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. Unit: uncore_hac_arb \000event=0x81,umask=0x2\000\00001\000\000"
/* offset=3861551 */ "unc_hac_arb_transactions.all\000uncore_hac_arb\000uncore interconnect\000Number of all CMI transactions. Unit: uncore_hac_arb \000event=0x8a,umask=0x1\000\00001\000\000"
/* offset=3861695 */ "unc_hac_arb_transactions.reads\000uncore_hac_arb\000uncore interconnect\000Number of all CMI reads. Unit: uncore_hac_arb \000event=0x8a,umask=0x2\000\00001\000\000"
/* offset=3861834 */ "unc_hac_arb_transactions.writes\000uncore_hac_arb\000uncore interconnect\000Number of all CMI writes not including Mflush. Unit: uncore_hac_arb \000event=0x8a,umask=0x4\000\00001\000\000"
/* offset=3861996 */ "unc_hac_arb_trk_requests.all\000uncore_hac_arb\000uncore interconnect\000Total number of all outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_hac_arb \000event=0x81,umask=0x1\000\00001\000\000"
/* offset=3862204 */ "unc_hac_cbo_tor_allocation.all\000uncore_hac_cbo\000uncore cache\000Number of all entries allocated. Includes also retries. Unit: uncore_hac_cbo \000event=0x35,umask=0x8\000\00001\000\000"
/* offset=3862367 */ "unc_hac_cbo_tor_allocation.drd\000uncore_hac_cbo\000uncore cache\000Asserted on coherent DRD + DRdPref  allocations into the queue. Cacheable only. Unit: uncore_hac_cbo \000event=0x35,umask=0x1\000\00001\000\000"
/* offset=3862554 */ "unc_i_address_match.merge_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Merges. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache.; When two requests to the same address from the same source are received back to back, it is possible to merge the two of them together\000"
/* offset=3863000 */ "unc_i_address_match.merge_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Merges. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache\000"
/* offset=3863309 */ "unc_i_address_match.stall_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Stalls. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache.; When it is not possible to merge two conflicting requests, a stall event occurs.  This is bad for performance\000"
/* offset=3863730 */ "unc_i_address_match.stall_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Stalls. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache\000"
/* offset=3864039 */ "unc_i_cache_ack_pending_occupancy.any\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Any Source. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000"
/* offset=3864871 */ "unc_i_cache_ack_pending_occupancy.any\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Any Source. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements\000"
/* offset=3865485 */ "unc_i_cache_ack_pending_occupancy.source\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Select Source. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements.; Tracks all requests from any source port\000"
/* offset=3866148 */ "unc_i_cache_ack_pending_occupancy.source\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Select Source. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements\000"
/* offset=3866768 */ "unc_i_cache_own_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Any Source. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned.; Tracks all requests from any source port\000"
/* offset=3867304 */ "unc_i_cache_own_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Any Source. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned\000"
/* offset=3867797 */ "unc_i_cache_own_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Select Source. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000"
/* offset=3868514 */ "unc_i_cache_own_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Select Source. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned\000"
/* offset=3869013 */ "unc_i_cache_read_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Any Source. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned.; Tracks all requests from any source port\000"
/* offset=3869484 */ "unc_i_cache_read_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Any Source. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned\000"
/* offset=3869912 */ "unc_i_cache_read_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Select Source. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000"
/* offset=3870564 */ "unc_i_cache_read_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Select Source. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned\000"
/* offset=3870998 */ "unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Total Write Cache Occupancy : Any Source : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events. : Tracks all requests from any source port\000"
/* offset=3871403 */ "unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000"
/* offset=3871764 */ "unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000"
/* offset=3872082 */ "unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000"
/* offset=3872442 */ "unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Total Write Cache Occupancy : Snoops : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000"
/* offset=3872796 */ "unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000"
/* offset=3873110 */ "unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests to coherent memory. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests to coherent memory.  This is effectively the sum of read occupancy and write occupancy\000"
/* offset=3873432 */ "unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests.  This is effectively the sum of read occupancy and write occupancy\000"
/* offset=3873716 */ "unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000"
/* offset=3874258 */ "unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000"
/* offset=3874582 */ "unc_i_cache_write_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Any Source. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore.; Tracks all requests from any source port\000"
/* offset=3875099 */ "unc_i_cache_write_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Any Source. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore\000"
/* offset=3875573 */ "unc_i_cache_write_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Select Source. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000"
/* offset=3876271 */ "unc_i_cache_write_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Select Source. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore\000"
/* offset=3876751 */ "unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000"
/* offset=3876876 */ "unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clockticks of the IO coherency tracker (IRP). Unit: uncore_irp \000event=0x1\000\00001\000\000"
/* offset=3877003 */ "unc_i_clockticks\000uncore_irp\000uncore interconnect\000IRP Clocks. Unit: uncore_irp \000event=0x1\000\00001\000\000"
/* offset=3877096 */ "unc_i_clockticks\000uncore_irp\000uncore interconnect\000IRP Clockticks. Unit: uncore_irp \000event=0x1\000\00001\000Number of IRP clock cycles while the event is enabled\000"
/* offset=3877246 */ "unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops : CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Coherent Ops : CLFlush : Counts the number of coherency related operations servied by the IRP\000"
/* offset=3877466 */ "unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3877660 */ "unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3877854 */ "unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878039 */ "unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878224 */ "unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x10,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878409 */ "unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878594 */ "unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x10,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878795 */ "unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3878996 */ "unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3879191 */ "unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3879386 */ "unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIItoM. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3879579 */ "unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline. Unit: uncore_irp \000event=0x10,umask=0x10\000\00001\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline to coherent memory, without a RFO.  PCIITOM is a speculative Invalidate to Modified command that requests ownership of the cacheline and does not move data from the mesh to IRP cache\000"
/* offset=3880060 */ "unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000Coherent Ops; RFO. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3880245 */ "unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline. Unit: uncore_irp \000event=0x10,umask=0x8\000\00001\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline to coherent memory.  RFO is a Read For Ownership command that requests ownership of the cacheline and moves data from the mesh to IRP cache\000"
/* offset=3880677 */ "unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops : WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Coherent Ops : WbMtoI : Counts the number of coherency related operations servied by the IRP\000"
/* offset=3880894 */ "unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3881086 */ "unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000"
/* offset=3881278 */ "unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000"
/* offset=3881371 */ "unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000FAF - request insert from TC. Unit: uncore_irp \000event=0x18\000\00001\000\000"
/* offset=3881484 */ "unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000Inbound read requests received by the IRP and inserted into the FAF queue. Unit: uncore_irp \000event=0x18\000\00001\000Inbound read requests to coherent memory, received by the IRP and inserted into the Fire and Forget queue (FAF), a queue used for processing inbound reads in the IRP\000"
/* offset=3881807 */ "unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000FAF occupancy. Unit: uncore_irp \000event=0x19\000\00001\000\000"
/* offset=3881907 */ "unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000Occupancy of the IRP FAF queue. Unit: uncore_irp \000event=0x19\000\00001\000Occupancy of the IRP Fire and Forget (FAF) queue, a queue used for processing inbound reads in the IRP\000"
/* offset=3882126 */ "unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000"
/* offset=3882245 */ "unc_i_irp_all.evicts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x4\000\00001\000\000"
/* offset=3882382 */ "unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x20,umask=0x1\000\00001\000\000"
/* offset=3882529 */ "unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000"
/* offset=3882674 */ "unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x2\000\00001\000\000"
/* offset=3882821 */ "unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000"
/* offset=3882966 */ "unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x10\000\00001\000\000"
/* offset=3883149 */ "unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x10\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary\000"
/* offset=3883402 */ "unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x10\000\00001\000\000"
/* offset=3883580 */ "unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x4\000\00001\000\000"
/* offset=3883756 */ "unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x4\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary\000"
/* offset=3884000 */ "unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x4\000\00001\000\000"
/* offset=3884171 */ "unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x8\000\00001\000\000"
/* offset=3884348 */ "unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x8\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary\000"
/* offset=3884594 */ "unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x8\000\00001\000\000"
/* offset=3884766 */ "unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Rejects. Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000"
/* offset=3884906 */ "unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Counts Timeouts - Set 0 : Fastpath Rejects\000"
/* offset=3885083 */ "unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=3885218 */ "unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Requests. Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000"
/* offset=3885359 */ "unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Counts Timeouts - Set 0 : Fastpath Requests\000"
/* offset=3885538 */ "unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x1c,umask=0x1\000\00001\000\000"
/* offset=3885674 */ "unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x20\000\00001\000\000"
/* offset=3885844 */ "unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x20\000\00001\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary\000"
/* offset=3886079 */ "unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x20\000\00001\000\000"
/* offset=3886244 */ "unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x40\000\00001\000\000"
/* offset=3886416 */ "unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x40\000\00001\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary\000"
/* offset=3886653 */ "unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x40\000\00001\000\000"
/* offset=3886820 */ "unc_i_misc0.pf_timeout\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch TimeOut. Unit: uncore_irp \000event=0x14,umask=0x80\000\00001\000Indicates the fetch for a previous prefetch wasn't accepted by the prefetch.   This happens in the case of a prefetch TimeOut\000"
/* offset=3887083 */ "unc_i_misc0.slowpath_fwpf_no_prf\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Slow path fwpf didn't find prefetch. Unit: uncore_irp \000event=0x1e,umask=0x80\000\00001\000\000"
/* offset=3887255 */ "unc_i_misc0.unknown\000uncore_irp\000uncore interconnect\000Misc Events - Set 0. Unit: uncore_irp \000event=0x1c,umask=0x80\000\00001\000\000"
/* offset=3887372 */ "unc_i_misc1.data_throttle\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Data Throttled. Unit: uncore_irp \000event=0x15,umask=0x80\000\00001\000IRP throttled switch data\000"
/* offset=3887536 */ "unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Lost Forward. Unit: uncore_irp \000event=0x1f,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000"
/* offset=3887762 */ "unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1. Unit: uncore_irp \000event=0x15,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000"
/* offset=3887973 */ "unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Lost Forward. Unit: uncore_irp \000event=0x1d,umask=0x10\000\00001\000Snoop pulled away ownership before a write was committed\000"
/* offset=3888161 */ "unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Invalid. Unit: uncore_irp \000event=0x1f,umask=0x20\000\00001\000Misc Events - Set 1 : Received Invalid : Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3888414 */ "unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x15,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3888625 */ "unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x1d,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3888836 */ "unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Valid. Unit: uncore_irp \000event=0x1f,umask=0x40\000\00001\000Misc Events - Set 1 : Received Valid : Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3889079 */ "unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x15,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3889282 */ "unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x1d,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3889485 */ "unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of E Line. Unit: uncore_irp \000event=0x1f,umask=0x4\000\00001\000Misc Events - Set 1 : Slow Transfer of E Line : Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3889739 */ "unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3889944 */ "unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x1d,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000"
/* offset=3890149 */ "unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of I Line. Unit: uncore_irp \000event=0x1f,umask=0x1\000\00001\000Misc Events - Set 1 : Slow Transfer of I Line : Snoop took cacheline ownership before write from data was committed\000"
/* offset=3890405 */ "unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000"
/* offset=3890612 */ "unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x1d,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000"
/* offset=3890819 */ "unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of M Line. Unit: uncore_irp \000event=0x1f,umask=0x8\000\00001\000Misc Events - Set 1 : Slow Transfer of M Line : Snoop took cacheline ownership before write from data was committed\000"
/* offset=3891075 */ "unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x15,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000"
/* offset=3891282 */ "unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x1d,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000"
/* offset=3891489 */ "unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of S Line. Unit: uncore_irp \000event=0x1f,umask=0x2\000\00001\000Misc Events - Set 1 : Slow Transfer of S Line : Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3891747 */ "unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3891956 */ "unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x1d,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000"
/* offset=3892165 */ "unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P Requests : P2P requests from the ITC\000"
/* offset=3892302 */ "unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P requests from the ITC\000"
/* offset=3892424 */ "unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P B & S Queue Occupancy\000"
/* offset=3892549 */ "unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P Occupancy : P2P B & S Queue Occupancy\000"
/* offset=3892690 */ "unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000"
/* offset=3892829 */ "unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000"
/* offset=3892967 */ "unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000"
/* offset=3893110 */ "unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000"
/* offset=3893252 */ "unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000"
/* offset=3893423 */ "unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000"
/* offset=3893593 */ "unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000"
/* offset=3893727 */ "unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000"
/* offset=3893860 */ "unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000"
/* offset=3893991 */ "unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000"
/* offset=3894121 */ "unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions : Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000"
/* offset=3894265 */ "unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions; Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000"
/* offset=3894408 */ "unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000"
/* offset=3894580 */ "unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000"
/* offset=3894751 */ "unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000"
/* offset=3894883 */ "unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000"
/* offset=3895014 */ "unc_i_rxr_ak_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xb\000\00001\000Counts the number of cycles when the AK Ingress is full.  This queue is where the IRP receives responses from R2PCIe (the ring)\000"
/* offset=3895230 */ "unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000"
/* offset=3895461 */ "unc_i_rxr_ak_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the occupancy of the AK Ingress in each cycles.  This queue is where the IRP receives responses from R2PCIe (the ring)\000"
/* offset=3895678 */ "unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_CYCLES_FULL. Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3896003 */ "unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3896298 */ "unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3896614 */ "unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_OCCUPANCY. Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3896938 */ "unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3897234 */ "unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_CYCLES_FULL. Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3897559 */ "unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3897854 */ "unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3898170 */ "unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_OCCUPANCY. Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3898494 */ "unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3898790 */ "unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_CYCLES_FULL. Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3899115 */ "unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3899410 */ "unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3899726 */ "unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_OCCUPANCY. Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3900050 */ "unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000"
/* offset=3900346 */ "unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000"
/* offset=3900612 */ "unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000"
/* offset=3900881 */ "unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000"
/* offset=3901139 */ "unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000"
/* offset=3901397 */ "unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000"
/* offset=3901636 */ "unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000"
/* offset=3901765 */ "unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000"
/* offset=3901893 */ "unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x17,umask=0x4\000\00001\000Snoop Responses : Hit E or S\000"
/* offset=3902049 */ "unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000"
/* offset=3902172 */ "unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000"
/* offset=3902294 */ "unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Snoop Responses : Hit I\000"
/* offset=3902439 */ "unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000"
/* offset=3902562 */ "unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000"
/* offset=3902684 */ "unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x17,umask=0x8\000\00001\000Snoop Responses : Hit M\000"
/* offset=3902829 */ "unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses : Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000"
/* offset=3902950 */ "unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000"
/* offset=3903070 */ "unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Snoop Responses : Miss\000"
/* offset=3903212 */ "unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000"
/* offset=3903340 */ "unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000"
/* offset=3903467 */ "unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x17,umask=0x10\000\00001\000Snoop Responses : SnpCode\000"
/* offset=3903619 */ "unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000"
/* offset=3903747 */ "unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000"
/* offset=3903874 */ "unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x17,umask=0x20\000\00001\000Snoop Responses : SnpData\000"
/* offset=3904026 */ "unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000"
/* offset=3904152 */ "unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000"
/* offset=3904277 */ "unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x17,umask=0x40\000\00001\000Snoop Responses : SnpInv\000"
/* offset=3904426 */ "unc_i_tickles.lost_ownership\000uncore_irp\000uncore interconnect\000Tickle Count; Ownership Lost. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles.; Tracks the number of requests that lost ownership as a result of a tickle.  When a tickle comes in, if the request is not at the head of the queue in the switch, then that request as well as any requests behind it in the switch queue will lose ownership and have to re-acquire it later when they get to the head of the queue.  This will therefore track the number of requests that lost ownership and not just the number of tickles\000"
/* offset=3905119 */ "unc_i_tickles.lost_ownership\000uncore_irp\000uncore interconnect\000Tickle Count; Ownership Lost. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles\000"
/* offset=3905379 */ "unc_i_tickles.top_of_queue\000uncore_irp\000uncore interconnect\000Tickle Count; Data Returned. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles.; Tracks the number of cases when a tickle was received but the requests was at the head of the queue in the switch.  In this case, data is returned rather than releasing ownership\000"
/* offset=3905817 */ "unc_i_tickles.top_of_queue\000uncore_irp\000uncore interconnect\000Tickle Count; Data Returned. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles\000"
/* offset=3906074 */ "unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Inbound Transaction Count : Atomic : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of atomic transactions\000"
/* offset=3906606 */ "unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000"
/* offset=3907099 */ "unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x16,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000"
/* offset=3907592 */ "unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Inbound Transaction Count : Other : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of 'other' kinds of transactions\000"
/* offset=3908131 */ "unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000"
/* offset=3908632 */ "unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x16,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000"
/* offset=3909133 */ "unc_i_transactions.pd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count: Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000"
/* offset=3909598 */ "unc_i_transactions.pd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000"
/* offset=3910065 */ "unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x11,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000"
/* offset=3910563 */ "unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x16,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000"
/* offset=3911061 */ "unc_i_transactions.rd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000"
/* offset=3911565 */ "unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000"
/* offset=3912072 */ "unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000"
/* offset=3912521 */ "unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000"
/* offset=3913028 */ "unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000"
/* offset=3913535 */ "unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Write Prefetches. Unit: uncore_irp \000event=0x16,umask=0x8\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of write prefetches\000"
/* offset=3914035 */ "unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000"
/* offset=3914331 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Inbound Transaction Count : Writes : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000"
/* offset=3915045 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000"
/* offset=3915720 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000"
/* offset=3916171 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000"
/* offset=3916846 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000"
/* offset=3917521 */ "unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests\000"
/* offset=3918099 */ "unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000"
/* offset=3918207 */ "unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000"
/* offset=3918327 */ "unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000"
/* offset=3918439 */ "unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000"
/* offset=3918555 */ "unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000"
/* offset=3918675 */ "unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000"
/* offset=3918787 */ "unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000"
/* offset=3918903 */ "unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000"
/* offset=3919023 */ "unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000"
/* offset=3919135 */ "unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000"
/* offset=3919251 */ "unc_i_txr2_ad01_stall_credit_cycles\000uncore_irp\000uncore interconnect\000UNC_I_TxR2_AD01_STALL_CREDIT_CYCLES. Unit: uncore_irp \000event=0x1c\000\00001\000: Counts the number times when it is not possible to issue a request to the M2PCIe because there are no Egress Credits available on AD0, A1 or AD0&AD1 both. Stalls on both AD0 and AD1 will count as 2\000"
/* offset=3919588 */ "unc_i_txr2_ad01_stall_credit_cycles\000uncore_irp\000uncore interconnect\000UNC_I_TxR2_AD01_STALL_CREDIT_CYCLES. Unit: uncore_irp \000event=0x1c\000\00001\000: Counts the number times when it is not possible to issue a request to the M2PCIe because there are no Egress Credits available on AD0, A1 or AD0AD1 both. Stalls on both AD0 and AD1 will count as 2\000"
/* offset=3919924 */ "unc_i_txr2_ad0_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD0 Egress Credits Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000No AD0 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD0 Egress Credits available\000"
/* offset=3920215 */ "unc_i_txr2_ad1_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD1 Egress Credits Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000No AD1 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD1 Egress Credits available\000"
/* offset=3920506 */ "unc_i_txr2_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000"
/* offset=3920762 */ "unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000"
/* offset=3921013 */ "unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1d\000\00001\000No BL Egress Credit Stalls : Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000"
/* offset=3921293 */ "unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000"
/* offset=3921548 */ "unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000"
/* offset=3921798 */ "unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3921985 */ "unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3922172 */ "unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000"
/* offset=3922522 */ "unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumultes the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjuection with the allocations event in order to calculate average latency of outbound requests\000"
/* offset=3922871 */ "unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3923058 */ "unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3923270 */ "unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3923457 */ "unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000"
/* offset=3923669 */ "unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000"
/* offset=3924019 */ "unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Outbound Request Queue Occupancy : Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000"
/* offset=3924404 */ "unc_i_write_ordering_stall_cycles\000uncore_irp\000uncore interconnect\000Write Ordering Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number of cycles when there are pending write ACK's in the switch but the switch->IRP pipeline is not utilized\000"
/* offset=3924647 */ "unc_iio_bandwidth_in.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x20\000\00001\000\000"
/* offset=3924873 */ "unc_iio_bandwidth_in.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x21\000\00001\000\000"
/* offset=3925099 */ "unc_iio_bandwidth_in.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x22\000\00001\000\000"
/* offset=3925325 */ "unc_iio_bandwidth_in.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x23\000\00001\000\000"
/* offset=3925551 */ "unc_iio_bandwidth_in.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x24\000\00001\000\000"
/* offset=3925777 */ "unc_iio_bandwidth_in.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x25\000\00001\000\000"
/* offset=3926003 */ "unc_iio_bandwidth_in.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x26\000\00001\000\000"
/* offset=3926229 */ "unc_iio_bandwidth_in.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x27\000\00001\000\000"
/* offset=3926455 */ "unc_iio_bandwidth_out.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x30\000\00001\000\000"
/* offset=3926682 */ "unc_iio_bandwidth_out.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x31\000\00001\000\000"
/* offset=3926909 */ "unc_iio_bandwidth_out.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x32\000\00001\000\000"
/* offset=3927136 */ "unc_iio_bandwidth_out.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x33\000\00001\000\000"
/* offset=3927363 */ "unc_iio_bandwidth_out.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x34\000\00001\000\000"
/* offset=3927590 */ "unc_iio_bandwidth_out.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x35\000\00001\000\000"
/* offset=3927817 */ "unc_iio_bandwidth_out.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x36\000\00001\000\000"
/* offset=3928044 */ "unc_iio_bandwidth_out.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x37\000\00001\000\000"
/* offset=3928271 */ "unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the IIO Traffic Controller. Unit: uncore_iio \000event=0x1\000\00001\000Counts clockticks of the 1GHz traffic controller clock in the IIO unit\000"
/* offset=3928456 */ "unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the IIO Traffic Controller. Unit: uncore_iio \000event=0x1\000\00001\000Counts clockticks of the 1GHz trafiic controller clock in the IIO unit\000"
/* offset=3928641 */ "unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the integrated IO (IIO) traffic controller. Unit: uncore_iio \000event=0x1\000\00001\000Clockticks of the integrated IO (IIO) traffic controller : Increments counter once every Traffic Controller clock, the LSCLK (500MHz)\000"
/* offset=3928905 */ "unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the integrated IO (IIO) traffic controller. Unit: uncore_iio \000event=0x1\000\00001\000\000"
/* offset=3929036 */ "unc_iio_clockticks\000uncore_iio\000uncore io\000IIO Clockticks. Unit: uncore_iio \000event=0x1,ch_mask=0x0000\000\00001\000Number of IIO clock cycles while the event is enabled\000"
/* offset=3929193 */ "unc_iio_clockticks_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for IIO clocktick. Unit: uncore_iio_free_running \000event=0xff,umask=0x10\000\00001\000Free running counter that increments for integrated IO (IIO) traffic controller clockticks\000"
/* offset=3929458 */ "unc_iio_clockticks_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for IIO clocktick. Unit: uncore_iio_free_running \000event=0xff,umask=0x10\000\00001\000\000"
/* offset=3929633 */ "unc_iio_comp_buf_inserts.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts : All Ports. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x04,umask=0x3\000\00001\000\000"
/* offset=3929802 */ "unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-3. Unit: uncore_iio \000event=0xc2,ch_mask=0x0f,fc_mask=0x4,umask=0x3\000\00001\000\000"
/* offset=3929999 */ "unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-7. Unit: uncore_iio \000event=0xc2,ch_mask=0xff,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0-7\000"
/* offset=3930263 */ "unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-7. Unit: uncore_iio \000event=0xc2,ch_mask=0xff,fc_mask=0x07,umask=0x4\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0-7\000"
/* offset=3930527 */ "unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x0001,fc_mask=0x07,umask=0x7001004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3930900 */ "unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3931265 */ "unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x4,umask=0x3\000\00001\000\000"
/* offset=3931456 */ "unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x0002,fc_mask=0x07,umask=0x7002004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000"
/* offset=3931829 */ "unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000"
/* offset=3932194 */ "unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x4,umask=0x3\000\00001\000\000"
/* offset=3932385 */ "unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x0004,fc_mask=0x07,umask=0x7004004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000"
/* offset=3932758 */ "unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000"
/* offset=3933123 */ "unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x4,umask=0x3\000\00001\000\000"
/* offset=3933314 */ "unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x0008,fc_mask=0x07,umask=0x7008004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000"
/* offset=3933687 */ "unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000"
/* offset=3934052 */ "unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x4,umask=0x3\000\00001\000\000"
/* offset=3934243 */ "unc_iio_comp_buf_inserts.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 4. Unit: uncore_iio \000event=0xc2,ch_mask=0x0010,fc_mask=0x07,umask=0x7010004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000"
/* offset=3934616 */ "unc_iio_comp_buf_inserts.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 4. Unit: uncore_iio \000event=0xc2,ch_mask=0x10,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000"
/* offset=3934981 */ "unc_iio_comp_buf_inserts.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 5. Unit: uncore_iio \000event=0xc2,ch_mask=0x0020,fc_mask=0x07,umask=0x7020004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000"
/* offset=3935354 */ "unc_iio_comp_buf_inserts.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 5. Unit: uncore_iio \000event=0xc2,ch_mask=0x20,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000"
/* offset=3935719 */ "unc_iio_comp_buf_inserts.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 6. Unit: uncore_iio \000event=0xc2,ch_mask=0x0040,fc_mask=0x07,umask=0x7040004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000"
/* offset=3936092 */ "unc_iio_comp_buf_inserts.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 6. Unit: uncore_iio \000event=0xc2,ch_mask=0x40,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000"
/* offset=3936457 */ "unc_iio_comp_buf_inserts.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 7. Unit: uncore_iio \000event=0xc2,ch_mask=0x0080,fc_mask=0x07,umask=0x7080004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000"
/* offset=3936830 */ "unc_iio_comp_buf_inserts.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 7. Unit: uncore_iio \000event=0xc2,ch_mask=0x80,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000"
/* offset=3937195 */ "unc_iio_comp_buf_inserts.port0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x7,umask=0x4\000\00001\000\000"
/* offset=3937356 */ "unc_iio_comp_buf_inserts.port1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x7,umask=0x4\000\00001\000\000"
/* offset=3937517 */ "unc_iio_comp_buf_inserts.port2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x7,umask=0x4\000\00001\000\000"
/* offset=3937678 */ "unc_iio_comp_buf_inserts.port3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x7,umask=0x4\000\00001\000\000"
/* offset=3937839 */ "unc_iio_comp_buf_occupancy.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000"
/* offset=3938067 */ "unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000"
/* offset=3938301 */ "unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0-3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xf\000\00001\000\000"
/* offset=3938490 */ "unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000UNC_IIO_COMP_BUF_OCCUPANCY.CMPD.ALL_PARTS. Unit: uncore_iio \000event=0xd5,fc_mask=0x07,umask=0xff\000\00001\000\000"
/* offset=3938654 */ "unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 0. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000001\000\00001\000x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3938933 */ "unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000PCIe Completion Buffer Occupancy : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3939267 */ "unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000\000"
/* offset=3939450 */ "unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 1. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000002\000\00001\000x4 card is plugged in to slot 1\000"
/* offset=3939661 */ "unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000PCIe Completion Buffer Occupancy : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000"
/* offset=3939995 */ "unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000\000"
/* offset=3940178 */ "unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 2. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000004\000\00001\000x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3940424 */ "unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000PCIe Completion Buffer Occupancy : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000"
/* offset=3940758 */ "unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000\000"
/* offset=3940941 */ "unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 3. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000008\000\00001\000x4 card is plugged in to slot 3\000"
/* offset=3941152 */ "unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000PCIe Completion Buffer Occupancy : Part 3 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000"
/* offset=3941486 */ "unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000\000"
/* offset=3941669 */ "unc_iio_comp_buf_occupancy.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 4. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000010\000\00001\000x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3941948 */ "unc_iio_comp_buf_occupancy.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 4. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x10\000\00001\000PCIe Completion Buffer Occupancy : Part 4 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000"
/* offset=3942283 */ "unc_iio_comp_buf_occupancy.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 5. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000020\000\00001\000x4 card is plugged in to slot 1\000"
/* offset=3942494 */ "unc_iio_comp_buf_occupancy.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 5. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x20\000\00001\000PCIe Completion Buffer Occupancy : Part 5 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000"
/* offset=3942829 */ "unc_iio_comp_buf_occupancy.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 6. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000040\000\00001\000x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3943075 */ "unc_iio_comp_buf_occupancy.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 6. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x40\000\00001\000PCIe Completion Buffer Occupancy : Part 6 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000"
/* offset=3943410 */ "unc_iio_comp_buf_occupancy.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 7. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000080\000\00001\000x4 card is plugged in to slot 3\000"
/* offset=3943621 */ "unc_iio_comp_buf_occupancy.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x80\000\00001\000PCIe Completion Buffer Occupancy : Part 7 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000"
/* offset=3943956 */ "unc_iio_data_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3944369 */ "unc_iio_data_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3944782 */ "unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3945285 */ "unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3945673 */ "unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3946101 */ "unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000"
/* offset=3946421 */ "unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3946884 */ "unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3947239 */ "unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3947667 */ "unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000"
/* offset=3947987 */ "unc_iio_data_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3948490 */ "unc_iio_data_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3948918 */ "unc_iio_data_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3949381 */ "unc_iio_data_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3949809 */ "unc_iio_data_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3950109 */ "unc_iio_data_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3950409 */ "unc_iio_data_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3950819 */ "unc_iio_data_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3951229 */ "unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3951729 */ "unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3952116 */ "unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3952541 */ "unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000"
/* offset=3952860 */ "unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3953320 */ "unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3953674 */ "unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3954099 */ "unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000"
/* offset=3954418 */ "unc_iio_data_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3954918 */ "unc_iio_data_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3955343 */ "unc_iio_data_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3955803 */ "unc_iio_data_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3956228 */ "unc_iio_data_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3956527 */ "unc_iio_data_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3956826 */ "unc_iio_data_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3957230 */ "unc_iio_data_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3957634 */ "unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3958128 */ "unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3958511 */ "unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3958930 */ "unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000"
/* offset=3959245 */ "unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3959699 */ "unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3960049 */ "unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3960468 */ "unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000"
/* offset=3960783 */ "unc_iio_data_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3961277 */ "unc_iio_data_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3961696 */ "unc_iio_data_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3962150 */ "unc_iio_data_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3962569 */ "unc_iio_data_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3962864 */ "unc_iio_data_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3963159 */ "unc_iio_data_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3963560 */ "unc_iio_data_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3963961 */ "unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3964452 */ "unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3964834 */ "unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3965250 */ "unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000"
/* offset=3965564 */ "unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3966015 */ "unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3966364 */ "unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3966780 */ "unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000"
/* offset=3967094 */ "unc_iio_data_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3967585 */ "unc_iio_data_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3968001 */ "unc_iio_data_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3968452 */ "unc_iio_data_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3968868 */ "unc_iio_data_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3969162 */ "unc_iio_data_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3969456 */ "unc_iio_data_req_by_cpu.mem_read.all_parts\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0-7. Unit: uncore_iio \000event=0xc0,ch_mask=0x00ff,fc_mask=0x07,umask=0x4\000\00001\000\000"
/* offset=3969649 */ "unc_iio_data_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3970093 */ "unc_iio_data_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3970537 */ "unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3971071 */ "unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3971560 */ "unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=3972248 */ "unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3972707 */ "unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3973128 */ "unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=3973705 */ "unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3974199 */ "unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3974655 */ "unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=3975247 */ "unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3975706 */ "unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3976127 */ "unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=3976708 */ "unc_iio_data_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3977205 */ "unc_iio_data_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3977739 */ "unc_iio_data_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3978168 */ "unc_iio_data_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3978627 */ "unc_iio_data_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3979091 */ "unc_iio_data_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3979585 */ "unc_iio_data_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3980014 */ "unc_iio_data_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3980473 */ "unc_iio_data_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3980770 */ "unc_iio_data_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3981067 */ "unc_iio_data_req_by_cpu.mem_write.all_parts\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0-7 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x00ff,fc_mask=0x07,umask=0x1\000\00001\000\000"
/* offset=3981261 */ "unc_iio_data_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3981666 */ "unc_iio_data_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0100,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3982070 */ "unc_iio_data_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3982475 */ "unc_iio_data_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0200,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3982879 */ "unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3983374 */ "unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3983856 */ "unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=3984545 */ "unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3984965 */ "unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3985379 */ "unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=3985957 */ "unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3986412 */ "unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3986861 */ "unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=3987455 */ "unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3987875 */ "unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3988289 */ "unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=3988871 */ "unc_iio_data_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=3989366 */ "unc_iio_data_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3989854 */ "unc_iio_data_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=3990274 */ "unc_iio_data_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3990694 */ "unc_iio_data_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=3991149 */ "unc_iio_data_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3991604 */ "unc_iio_data_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=3992024 */ "unc_iio_data_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3992444 */ "unc_iio_data_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=3992740 */ "unc_iio_data_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=3993036 */ "unc_iio_data_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=3993490 */ "unc_iio_data_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=3993944 */ "unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3994488 */ "unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=3995027 */ "unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=3995763 */ "unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3996232 */ "unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=3996703 */ "unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=3997328 */ "unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=3997832 */ "unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=3998338 */ "unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=3998978 */ "unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3999447 */ "unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=3999918 */ "unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4000547 */ "unc_iio_data_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4001092 */ "unc_iio_data_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4001636 */ "unc_iio_data_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4002113 */ "unc_iio_data_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4002582 */ "unc_iio_data_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4003094 */ "unc_iio_data_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4003598 */ "unc_iio_data_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4004075 */ "unc_iio_data_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4004544 */ "unc_iio_data_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=4004864 */ "unc_iio_data_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=4005184 */ "unc_iio_data_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4005635 */ "unc_iio_data_req_by_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4006086 */ "unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4006627 */ "unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4007165 */ "unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit.  In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4007904 */ "unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4008370 */ "unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4008840 */ "unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4009467 */ "unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4009968 */ "unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4010473 */ "unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4011115 */ "unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4011581 */ "unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4012051 */ "unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4012681 */ "unc_iio_data_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4013223 */ "unc_iio_data_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4013764 */ "unc_iio_data_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4014238 */ "unc_iio_data_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4014704 */ "unc_iio_data_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4015213 */ "unc_iio_data_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4015714 */ "unc_iio_data_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4016188 */ "unc_iio_data_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4016654 */ "unc_iio_data_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000"
/* offset=4016973 */ "unc_iio_data_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000"
/* offset=4017292 */ "unc_iio_data_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4017695 */ "unc_iio_data_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4018098 */ "unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4018591 */ "unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4018962 */ "unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4019380 */ "unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000"
/* offset=4019683 */ "unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4020136 */ "unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4020474 */ "unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4020892 */ "unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000"
/* offset=4021195 */ "unc_iio_data_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4021688 */ "unc_iio_data_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4022106 */ "unc_iio_data_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4022559 */ "unc_iio_data_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4022977 */ "unc_iio_data_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4023260 */ "unc_iio_data_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4023543 */ "unc_iio_data_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4023931 */ "unc_iio_data_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000"
/* offset=4024251 */ "unc_iio_data_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4024606 */ "unc_iio_data_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000"
/* offset=4024926 */ "unc_iio_data_req_of_cpu.cmpd.all_parts\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0xff,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4025455 */ "unc_iio_data_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4025890 */ "unc_iio_data_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4026325 */ "unc_iio_data_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4026852 */ "unc_iio_data_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4027377 */ "unc_iio_data_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4027829 */ "unc_iio_data_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4028279 */ "unc_iio_data_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4028766 */ "unc_iio_data_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4029251 */ "unc_iio_data_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4029703 */ "unc_iio_data_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4030153 */ "unc_iio_data_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4030680 */ "unc_iio_data_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4031205 */ "unc_iio_data_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4031657 */ "unc_iio_data_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4032107 */ "unc_iio_data_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4032594 */ "unc_iio_data_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4033079 */ "unc_iio_data_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4033531 */ "unc_iio_data_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4033981 */ "unc_iio_data_req_of_cpu.mem_read.all_parts\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part0-7 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x00ff,fc_mask=0x07,umask=0x4\000\00001\000\000"
/* offset=4034173 */ "unc_iio_data_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4034569 */ "unc_iio_data_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4034965 */ "unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4035451 */ "unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4036079 */ "unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4036551 */ "unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4037026 */ "unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4037437 */ "unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4037954 */ "unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4038351 */ "unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4038758 */ "unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4039204 */ "unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4039736 */ "unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4040168 */ "unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4040610 */ "unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4041021 */ "unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4041542 */ "unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4041939 */ "unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4042346 */ "unc_iio_data_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4042819 */ "unc_iio_data_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4043305 */ "unc_iio_data_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4043710 */ "unc_iio_data_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4044121 */ "unc_iio_data_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4044561 */ "unc_iio_data_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4045007 */ "unc_iio_data_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4045412 */ "unc_iio_data_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4045823 */ "unc_iio_data_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4046099 */ "unc_iio_data_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4046375 */ "unc_iio_data_req_of_cpu.mem_write.all_parts\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part0-7 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x00ff,fc_mask=0x07,umask=0x1\000\00001\000\000"
/* offset=4046568 */ "unc_iio_data_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4046961 */ "unc_iio_data_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4047354 */ "unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4047837 */ "unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4048466 */ "unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4048937 */ "unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4049411 */ "unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4049819 */ "unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4050337 */ "unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4050733 */ "unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4051139 */ "unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4051582 */ "unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4052115 */ "unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4052546 */ "unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4052987 */ "unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4053395 */ "unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4053917 */ "unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4054313 */ "unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4054719 */ "unc_iio_data_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4055189 */ "unc_iio_data_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4055672 */ "unc_iio_data_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4056074 */ "unc_iio_data_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4056482 */ "unc_iio_data_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4056919 */ "unc_iio_data_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4057362 */ "unc_iio_data_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4057764 */ "unc_iio_data_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4058172 */ "unc_iio_data_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4058447 */ "unc_iio_data_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4058722 */ "unc_iio_data_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4059078 */ "unc_iio_data_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4059434 */ "unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4059880 */ "unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4060226 */ "unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4060597 */ "unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000"
/* offset=4060875 */ "unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4061281 */ "unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4061594 */ "unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4061965 */ "unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000"
/* offset=4062243 */ "unc_iio_data_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4062689 */ "unc_iio_data_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4063060 */ "unc_iio_data_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4063466 */ "unc_iio_data_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4063837 */ "unc_iio_data_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4064095 */ "unc_iio_data_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4064353 */ "unc_iio_data_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4064810 */ "unc_iio_data_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4065267 */ "unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4065814 */ "unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4066474 */ "unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4066946 */ "unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4067495 */ "unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4068002 */ "unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4068566 */ "unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4069038 */ "unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4069590 */ "unc_iio_data_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4070137 */ "unc_iio_data_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4070609 */ "unc_iio_data_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4071116 */ "unc_iio_data_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4071588 */ "unc_iio_data_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4071899 */ "unc_iio_data_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4072210 */ "unc_iio_data_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4072664 */ "unc_iio_data_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4073118 */ "unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4073662 */ "unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4074191 */ "unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4074852 */ "unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4075321 */ "unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4075782 */ "unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4076332 */ "unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4076836 */ "unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4077332 */ "unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4077897 */ "unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4078366 */ "unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4078827 */ "unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4079381 */ "unc_iio_data_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4079920 */ "unc_iio_data_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4080464 */ "unc_iio_data_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4080935 */ "unc_iio_data_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4081404 */ "unc_iio_data_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4081910 */ "unc_iio_data_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4082414 */ "unc_iio_data_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4082885 */ "unc_iio_data_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4083354 */ "unc_iio_data_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000"
/* offset=4083664 */ "unc_iio_data_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000"
/* offset=4083974 */ "unc_iio_inbound_arb_req.data\000uncore_iio\000uncore io\000Incoming arbitration requests : Passing data to be written. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Incoming arbitration requests : Passing data to be written : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4084330 */ "unc_iio_inbound_arb_req.data\000uncore_iio\000uncore io\000Incoming arbitration requests : Passing data to be written. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests : Passing data to be written : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4084679 */ "unc_iio_inbound_arb_req.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing final read or write of line. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests : Issuing final read or write of line : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4085027 */ "unc_iio_inbound_arb_req.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing final read or write of line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests : Issuing final read or write of line : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4085373 */ "unc_iio_inbound_arb_req.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests : Processing response from IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests : Processing response from IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4085709 */ "unc_iio_inbound_arb_req.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests : Processing response from IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests : Processing response from IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4086043 */ "unc_iio_inbound_arb_req.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing to IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests : Issuing to IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4086351 */ "unc_iio_inbound_arb_req.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing to IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests : Issuing to IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000"
/* offset=4086657 */ "unc_iio_inbound_arb_req.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests : Request Ownership. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Incoming arbitration requests : Request Ownership : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4086998 */ "unc_iio_inbound_arb_req.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests : Request Ownership. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests : Request Ownership : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4087331 */ "unc_iio_inbound_arb_req.wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Writing line. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Incoming arbitration requests : Writing line : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4087657 */ "unc_iio_inbound_arb_req.wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Writing line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests : Writing line : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000"
/* offset=4087976 */ "unc_iio_inbound_arb_won.data\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Passing data to be written. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Incoming arbitration requests granted : Passing data to be written : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4088356 */ "unc_iio_inbound_arb_won.data\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Passing data to be written. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests granted : Passing data to be written : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4088729 */ "unc_iio_inbound_arb_won.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing final read or write of line. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Incoming arbitration requests granted : Issuing final read or write of line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4089107 */ "unc_iio_inbound_arb_won.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing final read or write of line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests granted : Issuing final read or write of line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4089477 */ "unc_iio_inbound_arb_won.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Processing response from IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff002\000\00001\000Incoming arbitration requests granted : Processing response from IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4089843 */ "unc_iio_inbound_arb_won.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Processing response from IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests granted : Processing response from IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4090201 */ "unc_iio_inbound_arb_won.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing to IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff001\000\00001\000Incoming arbitration requests granted : Issuing to IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4090539 */ "unc_iio_inbound_arb_won.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing to IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests granted : Issuing to IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000"
/* offset=4090869 */ "unc_iio_inbound_arb_won.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Request Ownership. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Incoming arbitration requests granted : Request Ownership : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4091234 */ "unc_iio_inbound_arb_won.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Request Ownership. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests granted : Request Ownership : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4091591 */ "unc_iio_inbound_arb_won.wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Writing line. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Incoming arbitration requests granted : Writing line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4091941 */ "unc_iio_inbound_arb_won.wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Writing line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests granted : Writing line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000"
/* offset=4092284 */ "unc_iio_iommu0.1g_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 1G Page. Unit: uncore_iio \000event=0x40,umask=0x10\000\00001\000: IOTLB Hits to a 1G Page : Counts if a transaction to a 1G page, on its first lookup, hits the IOTLB\000"
/* offset=4092501 */ "unc_iio_iommu0.2m_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 2M Page. Unit: uncore_iio \000event=0x40,umask=0x8\000\00001\000: IOTLB Hits to a 2M Page : Counts if a transaction to a 2M page, on its first lookup, hits the IOTLB\000"
/* offset=4092717 */ "unc_iio_iommu0.4k_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 4K Page. Unit: uncore_iio \000event=0x40,umask=0x4\000\00001\000: IOTLB Hits to a 4K Page : Counts if a transaction to a 4K page, on its first lookup, hits the IOTLB\000"
/* offset=4092933 */ "unc_iio_iommu0.all_lookups\000uncore_iio\000uncore io\000: IOTLB lookups all. Unit: uncore_iio \000event=0x40,umask=0x2\000\00001\000: IOTLB lookups all : Some transactions have to look up IOTLB multiple times.  Counts every time a request looks up IOTLB\000"
/* offset=4093167 */ "unc_iio_iommu0.ctxt_cache_hits\000uncore_iio\000uncore io\000: Context cache hits. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x80\000\00001\000: Context cache hits : Counts each time a first look up of the transaction hits the RCC\000"
/* offset=4093388 */ "unc_iio_iommu0.ctxt_cache_hits\000uncore_iio\000uncore io\000: Context cache hits. Unit: uncore_iio \000event=0x40,umask=0x80\000\00001\000: Context cache hits : Counts each time a first look up of the transaction hits the RCC\000"
/* offset=4093594 */ "unc_iio_iommu0.ctxt_cache_lookups\000uncore_iio\000uncore io\000: Context cache lookups. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x40\000\00001\000: Context cache lookups : Counts each time a transaction looks up root context cache\000"
/* offset=4093818 */ "unc_iio_iommu0.ctxt_cache_lookups\000uncore_iio\000uncore io\000: Context cache lookups. Unit: uncore_iio \000event=0x40,umask=0x40\000\00001\000: Context cache lookups : Counts each time a transaction looks up root context cache\000"
/* offset=4094027 */ "unc_iio_iommu0.first_lookups\000uncore_iio\000uncore io\000: IOTLB lookups first. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x1\000\00001\000: IOTLB lookups first : Some transactions have to look up IOTLB multiple times.  Counts the first time a request looks up IOTLB\000"
/* offset=4094286 */ "unc_iio_iommu0.first_lookups\000uncore_iio\000uncore io\000: IOTLB lookups first. Unit: uncore_iio \000event=0x40,umask=0x1\000\00001\000: IOTLB lookups first : Some transactions have to look up IOTLB multiple times.  Counts the first time a request looks up IOTLB\000"
/* offset=4094530 */ "unc_iio_iommu0.misses\000uncore_iio\000uncore io\000: IOTLB Fills (same as IOTLB miss). Unit: uncore_iio \000event=0x40,umask=0x20\000\00001\000: IOTLB Fills (same as IOTLB miss) : When a transaction misses IOTLB, it does a page walk to look up memory and bring in the relevant page translation. Counts when this page translation is written to IOTLB\000"
/* offset=4094859 */ "unc_iio_iommu0.misses\000uncore_iio\000uncore io\000IOTLB Fills (same as IOTLB miss). Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x20\000\00001\000IOTLB Fills (same as IOTLB miss) : When a transaction misses IOTLB, it does a page walk to look up memory and bring in the relevant page translation. Counts when this page translation is written to IOTLB\000"
/* offset=4095199 */ "unc_iio_iommu1.cyc_pwt_full\000uncore_iio\000uncore io\000: Cycles PWT full. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000: Cycles PWT full : Counts cycles the IOMMU has reached its maximum limit for outstanding page walks\000"
/* offset=4095412 */ "unc_iio_iommu1.num_mem_accesses\000uncore_iio\000uncore io\000: IOMMU memory access. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000: IOMMU memory access : IOMMU sends out memory fetches when it misses the cache look up which is indicated by this signal.  M2IOSF only uses low priority channel\000"
/* offset=4095694 */ "unc_iio_iommu1.num_mem_accesses\000uncore_iio\000uncore io\000: IOMMU memory access. Unit: uncore_iio \000event=0x41,umask=0xc0\000\00001\000: IOMMU memory access : IOMMU sends out memory fetches when it misses the cache look up which is indicated by this signal.  M2IOSF only uses low priority channel\000"
/* offset=4095976 */ "unc_iio_iommu1.pwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000"
/* offset=4096194 */ "unc_iio_iommu1.pwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000"
/* offset=4096412 */ "unc_iio_iommu1.pwc_256t_hits\000uncore_iio\000uncore io\000: PWT Hit to a 256T page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWT Hit to a 256T page : Counts each time a transaction's first look up hits the SLPWC at the 512G level\000"
/* offset=4096639 */ "unc_iio_iommu1.pwc_2m_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000"
/* offset=4096857 */ "unc_iio_iommu1.pwc_2m_hits\000uncore_iio\000uncore io\000: PWC Hit to a 4K page. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000: PWC Hit to a 4K page : Counts each time a transaction's first look up hits the SLPWC at the 4K level\000"
/* offset=4097075 */ "unc_iio_iommu1.pwc_4k_hits\000uncore_iio\000uncore io\000: PWC Hit to a 4K page. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000: PWC Hit to a 4K page : Counts each time a transaction's first look up hits the SLPWC at the 4K level\000"
/* offset=4097293 */ "unc_iio_iommu1.pwc_512g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000"
/* offset=4097513 */ "unc_iio_iommu1.pwc_512g_hits\000uncore_iio\000uncore io\000: PWT Hit to a 256T page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWT Hit to a 256T page : Counts each time a transaction's first look up hits the SLPWC at the 512G level\000"
/* offset=4097740 */ "unc_iio_iommu1.pwc_cache_fills\000uncore_iio\000uncore io\000: PageWalk cache fill. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000: PageWalk cache fill : When a transaction misses SLPWC, it does a page walk to look up memory and bring in the relevant page translation. When this page translation is written to SLPWC, ObsPwcFillValid_nnnH is asserted\000"
/* offset=4098079 */ "unc_iio_iommu1.pwt_cache_lookups\000uncore_iio\000uncore io\000: PageWalk cache lookup. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000: PageWalk cache lookup : Counts each time a transaction looks up second level page walk cache\000"
/* offset=4098296 */ "unc_iio_iommu1.slpwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000"
/* offset=4098516 */ "unc_iio_iommu1.slpwc_256t_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000"
/* offset=4098739 */ "unc_iio_iommu1.slpwc_512g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000"
/* offset=4098961 */ "unc_iio_iommu3.int_cache_hits\000uncore_iio\000uncore io\000: Interrupt Entry cache hit. Unit: uncore_iio \000event=0x43,umask=0x80\000\00001\000: Interrupt Entry cache hit : Counts each time a transaction's first look up hits the IEC\000"
/* offset=4099175 */ "unc_iio_iommu3.int_cache_lookups\000uncore_iio\000uncore io\000: Interrupt Entry cache lookup. Unit: uncore_iio \000event=0x43,umask=0x40\000\00001\000: Interrupt Entry cache lookup : Counts the number of transaction looks up that interrupt remapping cache\000"
/* offset=4099411 */ "unc_iio_iommu3.num_ctxt_cache_inval_device\000uncore_iio\000uncore io\000: Device-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x20\000\00001\000: Device-selective Context cache invalidation cycles : Counts number of Device selective context cache invalidation events\000"
/* offset=4099696 */ "unc_iio_iommu3.num_ctxt_cache_inval_domain\000uncore_iio\000uncore io\000: Domain-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x10\000\00001\000: Domain-selective Context cache invalidation cycles : Counts number of Domain selective context cache invalidation events\000"
/* offset=4099981 */ "unc_iio_iommu3.num_ctxt_cache_inval_gbl\000uncore_iio\000uncore io\000: Context cache global invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x8\000\00001\000: Context cache global invalidation cycles : Counts number of Context Cache global invalidation events\000"
/* offset=4100232 */ "unc_iio_iommu3.num_inval_domain\000uncore_iio\000uncore io\000: Domain-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x2\000\00001\000: Domain-selective IOTLB invalidation cycles : Counts number of Domain selective invalidation events\000"
/* offset=4100475 */ "unc_iio_iommu3.num_inval_gbl\000uncore_iio\000uncore io\000: Global IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x1\000\00001\000: Global IOTLB invalidation cycles : Indicates that IOMMU is doing global invalidation\000"
/* offset=4100691 */ "unc_iio_iommu3.num_inval_page\000uncore_iio\000uncore io\000: Page-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x4\000\00001\000: Page-selective IOTLB invalidation cycles : Counts number of Page-selective within Domain Invalidation events\000"
/* offset=4100940 */ "unc_iio_iommu3.pwt_occupancy_msb\000uncore_iio\000uncore io\000: Global IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,ch_mask=0x0000,umask=0x1\000\00001\000: Global IOTLB invalidation cycles : Indicates that IOMMU is doing global invalidation\000"
/* offset=4101175 */ "unc_iio_link_num_corr_err\000uncore_iio\000uncore io\000Num Link  Correctable Errors. Unit: uncore_iio \000event=0xf\000\00001\000\000"
/* offset=4101285 */ "unc_iio_link_num_retries\000uncore_iio\000uncore io\000Num Link Retries. Unit: uncore_iio \000event=0xe\000\00001\000\000"
/* offset=4101382 */ "unc_iio_mask_match\000uncore_iio\000uncore io\000Number packets that passed the Mask/Match Filter. Unit: uncore_iio \000event=0x21\000\00001\000\000"
/* offset=4101506 */ "unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x1\000\00001\000AND Mask/match for debug bus : Non-PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4101748 */ "unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000AND Mask/match for debug bus : Non-PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4101975 */ "unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4102155 */ "unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x8\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4102428 */ "unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4102686 */ "unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4102884 */ "unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x4\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if all bits specified by mask match\000"
/* offset=4103167 */ "unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if all bits specified by mask match\000"
/* offset=4103435 */ "unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4103640 */ "unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x2\000\00001\000AND Mask/match for debug bus : PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4103874 */ "unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000AND Mask/match for debug bus : PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4104093 */ "unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4104269 */ "unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x10\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4104553 */ "unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if all bits specified by mask match\000"
/* offset=4104822 */ "unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4105028 */ "unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x20\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if all bits specified by mask match\000"
/* offset=4105322 */ "unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if all bits specified by mask match\000"
/* offset=4105601 */ "unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus. Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000Asserted if all bits specified by mask match\000"
/* offset=4105781 */ "unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x1\000\00001\000OR Mask/match for debug bus : Non-PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4106020 */ "unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000OR Mask/match for debug bus : Non-PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4106244 */ "unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4106422 */ "unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x8\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4106692 */ "unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4106947 */ "unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4107143 */ "unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x4\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if any bits specified by mask match\000"
/* offset=4107423 */ "unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if any bits specified by mask match\000"
/* offset=4107688 */ "unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4107891 */ "unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x2\000\00001\000OR Mask/match for debug bus : PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4108122 */ "unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000OR Mask/match for debug bus : PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4108338 */ "unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4108512 */ "unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x10\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4108793 */ "unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if any bits specified by mask match\000"
/* offset=4109059 */ "unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4109263 */ "unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x20\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if any bits specified by mask match\000"
/* offset=4109554 */ "unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if any bits specified by mask match\000"
/* offset=4109830 */ "unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000Asserted if any bits specified by mask match\000"
/* offset=4110041 */ "unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0\000\00001\000\000"
/* offset=4110128 */ "unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0x80\000\00001\000\000"
/* offset=4110218 */ "unc_iio_num_oustanding_req_from_cpu.to_io\000uncore_iio\000uncore io\000Occupancy of outbound request queue : To device. Unit: uncore_iio \000event=0xc5,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Occupancy of outbound request queue : To device : Counts number of outbound requests/completions IIO is currently processing\000"
/* offset=4110524 */ "unc_iio_num_outstanding_req_of_cpu.data\000uncore_iio\000uncore io\000: Passing data to be written. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000: Passing data to be written : Only for posted requests\000"
/* offset=4110741 */ "unc_iio_num_outstanding_req_of_cpu.final_rd_wr\000uncore_iio\000uncore io\000: Issuing final read or write of line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000"
/* offset=4110918 */ "unc_iio_num_outstanding_req_of_cpu.iommu_hit\000uncore_iio\000uncore io\000: Processing response from IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000"
/* offset=4111088 */ "unc_iio_num_outstanding_req_of_cpu.iommu_req\000uncore_iio\000uncore io\000: Issuing to IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000"
/* offset=4111244 */ "unc_iio_num_outstanding_req_of_cpu.req_own\000uncore_iio\000uncore io\000: Request Ownership. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000: Request Ownership : Only for posted requests\000"
/* offset=4111445 */ "unc_iio_num_outstanding_req_of_cpu.wr\000uncore_iio\000uncore io\000: Writing line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000: Writing line : Only for posted requests\000"
/* offset=4111632 */ "unc_iio_num_req_from_cpu.irp\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From IRP. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests sent to PCIe from main die : From IRP : Captures Posted/Non-posted allocations from IRP. i.e. either non-confined P2P traffic or from the CPU\000"
/* offset=4111964 */ "unc_iio_num_req_from_cpu.itc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From ITC. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests sent to PCIe from main die : From ITC : Confined P2P\000"
/* offset=4112207 */ "unc_iio_num_req_from_cpu.prealloc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : Completion allocations. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000"
/* offset=4112401 */ "unc_iio_num_req_of_cpu.all.drop\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : Drop request. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests PCIe makes of the main die : Drop request : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU. : Packet error detected, must be dropped\000"
/* offset=4112824 */ "unc_iio_num_req_of_cpu.commit.all\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : All. Unit: uncore_iio \000event=0x85,ch_mask=0x0FFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests PCIe makes of the main die : All : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU\000"
/* offset=4113191 */ "unc_iio_num_req_of_cpu.commit.all\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : All. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests PCIe makes of the main die : All : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU\000"
/* offset=4113556 */ "unc_iio_num_req_of_cpu_by_tgt.abort\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Abort. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x80\000\00001\000\000"
/* offset=4113733 */ "unc_iio_num_req_of_cpu_by_tgt.abort\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Abort. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x80\000\00001\000\000"
/* offset=4113908 */ "unc_iio_num_req_of_cpu_by_tgt.confined_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Confined P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x40\000\00001\000\000"
/* offset=4114099 */ "unc_iio_num_req_of_cpu_by_tgt.confined_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Confined P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x40\000\00001\000\000"
/* offset=4114288 */ "unc_iio_num_req_of_cpu_by_tgt.loc_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Local P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x20\000\00001\000\000"
/* offset=4114471 */ "unc_iio_num_req_of_cpu_by_tgt.loc_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Local P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000\000"
/* offset=4114652 */ "unc_iio_num_req_of_cpu_by_tgt.mcast\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Multi-cast. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x2\000\00001\000\000"
/* offset=4114833 */ "unc_iio_num_req_of_cpu_by_tgt.mcast\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Multi-cast. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000"
/* offset=4115012 */ "unc_iio_num_req_of_cpu_by_tgt.mem\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Memory. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000\000"
/* offset=4115187 */ "unc_iio_num_req_of_cpu_by_tgt.mem\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Memory. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000"
/* offset=4115360 */ "unc_iio_num_req_of_cpu_by_tgt.msgb\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : MsgB. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x1\000\00001\000\000"
/* offset=4115534 */ "unc_iio_num_req_of_cpu_by_tgt.msgb\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : MsgB. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000"
/* offset=4115706 */ "unc_iio_num_req_of_cpu_by_tgt.rem_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Remote P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x10\000\00001\000\000"
/* offset=4115890 */ "unc_iio_num_req_of_cpu_by_tgt.rem_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Remote P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000\000"
/* offset=4116072 */ "unc_iio_num_req_of_cpu_by_tgt.ubox\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Ubox. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x4\000\00001\000\000"
/* offset=4116246 */ "unc_iio_num_req_of_cpu_by_tgt.ubox\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Ubox. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000"
/* offset=4116418 */ "unc_iio_num_tgt_matched_req_of_cpu\000uncore_iio\000uncore io\000ITC address map 1. Unit: uncore_iio \000event=0x8f,ch_mask=0x0000\000\00001\000UNC_IIO_NUM_TGT_MATCHED_REQ_OF_CPU\000"
/* offset=4116576 */ "unc_iio_num_tgt_matched_req_of_cpu\000uncore_iio\000uncore io\000ITC address map 1. Unit: uncore_iio \000event=0x8f\000\00001\000\000"
/* offset=4116685 */ "unc_iio_outbound_cl_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound cacheline requests issued : 64B requests issued to device. Unit: uncore_iio \000event=0xd0,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Outbound cacheline requests issued : 64B requests issued to device : Each outbound cacheline granular request may need to make multiple passes through the pipeline.  Each time a cacheline completes all its passes it advances line\000"
/* offset=4117113 */ "unc_iio_outbound_cl_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound cacheline requests issued : 64B requests issued to device. Unit: uncore_iio \000event=0xd0,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound cacheline requests issued : 64B requests issued to device : Each outbound cacheline granular request may need to make multiple passes through the pipeline.  Each time a cacheline completes all its passes it advances line\000"
/* offset=4117539 */ "unc_iio_outbound_tlp_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound TLP (transaction layer packet) requests issued : To device. Unit: uncore_iio \000event=0xd1,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Outbound TLP (transaction layer packet) requests issued : To device : Each time an outbound completes all its passes it advances the pointer\000"
/* offset=4117880 */ "unc_iio_outbound_tlp_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound TLP (transaction layer packet) requests issued : To device. Unit: uncore_iio \000event=0xd1,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound TLP (transaction layer packet) requests issued : To device : Each time an outbound completes all its passes it advances the pointer\000"
/* offset=4118219 */ "unc_iio_payload_bytes_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4118430 */ "unc_iio_payload_bytes_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4118641 */ "unc_iio_payload_bytes_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4118852 */ "unc_iio_payload_bytes_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4119063 */ "unc_iio_payload_bytes_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4119273 */ "unc_iio_payload_bytes_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4119483 */ "unc_iio_payload_bytes_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4119700 */ "unc_iio_payload_bytes_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4119917 */ "unc_iio_payload_bytes_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4120134 */ "unc_iio_payload_bytes_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4120351 */ "unc_iio_payload_bytes_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4120565 */ "unc_iio_payload_bytes_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4120779 */ "unc_iio_payload_bytes_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4120993 */ "unc_iio_payload_bytes_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4121207 */ "unc_iio_payload_bytes_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4121420 */ "unc_iio_payload_bytes_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4121633 */ "unc_iio_payload_bytes_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4121849 */ "unc_iio_payload_bytes_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4122065 */ "unc_iio_payload_bytes_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4122281 */ "unc_iio_payload_bytes_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4122497 */ "unc_iio_payload_bytes_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4122712 */ "unc_iio_payload_bytes_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4122927 */ "unc_iio_payload_bytes_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4123132 */ "unc_iio_payload_bytes_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4123337 */ "unc_iio_payload_bytes_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4123542 */ "unc_iio_payload_bytes_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4123747 */ "unc_iio_payload_bytes_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4123951 */ "unc_iio_payload_bytes_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4124155 */ "unc_iio_payload_bytes_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4124371 */ "unc_iio_payload_bytes_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4124587 */ "unc_iio_payload_bytes_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4124803 */ "unc_iio_payload_bytes_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4125019 */ "unc_iio_payload_bytes_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4125234 */ "unc_iio_payload_bytes_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4125449 */ "unc_iio_payload_bytes_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4125667 */ "unc_iio_payload_bytes_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4125885 */ "unc_iio_payload_bytes_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4126103 */ "unc_iio_payload_bytes_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4126321 */ "unc_iio_payload_bytes_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4126538 */ "unc_iio_payload_bytes_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4126755 */ "unc_iio_payload_bytes_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4126971 */ "unc_iio_payload_bytes_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4127187 */ "unc_iio_payload_bytes_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4127403 */ "unc_iio_payload_bytes_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4127619 */ "unc_iio_payload_bytes_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4127834 */ "unc_iio_payload_bytes_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4128049 */ "unc_iio_payload_bytes_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4128267 */ "unc_iio_payload_bytes_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4128485 */ "unc_iio_payload_bytes_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4128703 */ "unc_iio_payload_bytes_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4128921 */ "unc_iio_payload_bytes_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4129138 */ "unc_iio_payload_bytes_out.cfg_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4129355 */ "unc_iio_payload_bytes_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4129569 */ "unc_iio_payload_bytes_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4129783 */ "unc_iio_payload_bytes_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4129997 */ "unc_iio_payload_bytes_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4130211 */ "unc_iio_payload_bytes_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4130424 */ "unc_iio_payload_bytes_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4130637 */ "unc_iio_payload_bytes_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4130853 */ "unc_iio_payload_bytes_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4131069 */ "unc_iio_payload_bytes_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4131285 */ "unc_iio_payload_bytes_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4131501 */ "unc_iio_payload_bytes_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4131716 */ "unc_iio_payload_bytes_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4131931 */ "unc_iio_payload_bytes_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4132146 */ "unc_iio_payload_bytes_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4132361 */ "unc_iio_payload_bytes_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4132576 */ "unc_iio_payload_bytes_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4132791 */ "unc_iio_payload_bytes_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4133005 */ "unc_iio_payload_bytes_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4133219 */ "unc_iio_payload_bytes_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4133436 */ "unc_iio_payload_bytes_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4133653 */ "unc_iio_payload_bytes_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4133870 */ "unc_iio_payload_bytes_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4134087 */ "unc_iio_payload_bytes_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4134303 */ "unc_iio_payload_bytes_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4134519 */ "unc_iio_payload_bytes_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4134736 */ "unc_iio_payload_bytes_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4134953 */ "unc_iio_payload_bytes_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4135170 */ "unc_iio_payload_bytes_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4135387 */ "unc_iio_payload_bytes_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4135603 */ "unc_iio_payload_bytes_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4135819 */ "unc_iio_payload_bytes_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4136038 */ "unc_iio_payload_bytes_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4136257 */ "unc_iio_payload_bytes_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4136476 */ "unc_iio_payload_bytes_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4136695 */ "unc_iio_payload_bytes_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4136913 */ "unc_iio_payload_bytes_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4137131 */ "unc_iio_pwt_occupancy\000uncore_iio\000uncore io\000PWT occupancy.  Does not include 9th bit of occupancy (will undercount if PWT is greater than 255 per cycle). Unit: uncore_iio \000event=0x42,ch_mask=0x0000,umask=0xff\000\00001\000PWT occupancy : Indicates how many page walks are outstanding at any point in time\000"
/* offset=4137426 */ "unc_iio_pwt_occupancy\000uncore_iio\000uncore io\000PWT occupancy. Unit: uncore_iio \000event=0x42\000\00001\000PWT occupancy : Indicates how many page walks are outstanding at any point in time\000"
/* offset=4137600 */ "unc_iio_req_from_pcie_cl_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Passing data to be written. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - cacheline complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000"
/* offset=4138213 */ "unc_iio_req_from_pcie_cl_cmpl.data\000uncore_iio\000uncore io\000Request Ownership : PCIe Request complete. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Request Ownership : PCIe Request complete : Only for posted requests : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000"
/* offset=4138769 */ "unc_iio_req_from_pcie_cl_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - cacheline complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line\000"
/* offset=4139379 */ "unc_iio_req_from_pcie_cl_cmpl.final_rd_wr\000uncore_iio\000uncore io\000Request Ownership : Writing line. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Request Ownership : Writing line : Only for posted requests : Only for posted requests\000"
/* offset=4139640 */ "unc_iio_req_from_pcie_cl_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Request Ownership. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - cacheline complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000"
/* offset=4140237 */ "unc_iio_req_from_pcie_cl_cmpl.req_own\000uncore_iio\000uncore io\000Request Ownership : Issuing final read or write of line. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Request Ownership : Issuing final read or write of line : Only for posted requests\000"
/* offset=4140513 */ "unc_iio_req_from_pcie_cl_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Writing line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - cacheline complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000"
/* offset=4141096 */ "unc_iio_req_from_pcie_cl_cmpl.wr\000uncore_iio\000uncore io\000Request Ownership : Passing data to be written. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Request Ownership : Passing data to be written : Only for posted requests : Only for posted requests\000"
/* offset=4141376 */ "unc_iio_req_from_pcie_cmpl.data\000uncore_iio\000uncore io\000PCIe Request complete : Passing data to be written. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000"
/* offset=4141941 */ "unc_iio_req_from_pcie_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000"
/* offset=4142502 */ "unc_iio_req_from_pcie_cmpl.final_rd_wr\000uncore_iio\000uncore io\000Processing response from IOMMU : Passing data to be written. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Processing response from IOMMU : Passing data to be written : Only for posted requests\000"
/* offset=4142787 */ "unc_iio_req_from_pcie_cmpl.iommu_hit\000uncore_iio\000uncore io\000PCIe Request complete : Processing response from IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000PCIe Request complete : Processing response from IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000"
/* offset=4143336 */ "unc_iio_req_from_pcie_cmpl.iommu_hit\000uncore_iio\000uncore io\000Processing response from IOMMU : Issuing final read or write of line. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff002\000\00001\000\000"
/* offset=4143542 */ "unc_iio_req_from_pcie_cmpl.iommu_req\000uncore_iio\000uncore io\000PCIe Request complete : Issuing to IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000PCIe Request complete : Issuing to IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000"
/* offset=4144063 */ "unc_iio_req_from_pcie_cmpl.iommu_req\000uncore_iio\000uncore io\000Processing response from IOMMU : Request Ownership. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff001\000\00001\000Processing response from IOMMU : Request Ownership : Only for posted requests\000"
/* offset=4144328 */ "unc_iio_req_from_pcie_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request complete : Request Ownership. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000"
/* offset=4144877 */ "unc_iio_req_from_pcie_cmpl.req_own\000uncore_iio\000uncore io\000Processing response from IOMMU : Writing line. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Processing response from IOMMU : Writing line : Only for posted requests\000"
/* offset=4145130 */ "unc_iio_req_from_pcie_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request complete : Writing line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000"
/* offset=4145665 */ "unc_iio_req_from_pcie_pass_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - pass complete : Passing data to be written. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000PCIe Request - pass complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4146269 */ "unc_iio_req_from_pcie_pass_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - pass complete : Passing data to be written. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - pass complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4146866 */ "unc_iio_req_from_pcie_pass_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - pass complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state\000"
/* offset=4147462 */ "unc_iio_req_from_pcie_pass_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - pass complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state\000"
/* offset=4148056 */ "unc_iio_req_from_pcie_pass_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - pass complete : Request Ownership. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000PCIe Request - pass complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4148645 */ "unc_iio_req_from_pcie_pass_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - pass complete : Request Ownership. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - pass complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4149226 */ "unc_iio_req_from_pcie_pass_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Writing line. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000PCIe Request - pass complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4149800 */ "unc_iio_req_from_pcie_pass_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Writing line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - pass complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000"
/* offset=4150367 */ "unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000"
/* offset=4150562 */ "unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Symbol Times on Link : Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000"
/* offset=4150780 */ "unc_iio_txn_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4150924 */ "unc_iio_txn_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4151068 */ "unc_iio_txn_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4151212 */ "unc_iio_txn_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4151356 */ "unc_iio_txn_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4151500 */ "unc_iio_txn_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4151644 */ "unc_iio_txn_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4151791 */ "unc_iio_txn_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4151938 */ "unc_iio_txn_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4152085 */ "unc_iio_txn_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4152232 */ "unc_iio_txn_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4152377 */ "unc_iio_txn_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4152522 */ "unc_iio_txn_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4152667 */ "unc_iio_txn_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4152812 */ "unc_iio_txn_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4152957 */ "unc_iio_txn_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4153102 */ "unc_iio_txn_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4153307 */ "unc_iio_txn_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4153512 */ "unc_iio_txn_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4153717 */ "unc_iio_txn_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4153922 */ "unc_iio_txn_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4154126 */ "unc_iio_txn_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4154330 */ "unc_iio_txn_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4154471 */ "unc_iio_txn_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4154612 */ "unc_iio_txn_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4154753 */ "unc_iio_txn_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4154894 */ "unc_iio_txn_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4155035 */ "unc_iio_txn_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4155176 */ "unc_iio_txn_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4155322 */ "unc_iio_txn_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4155468 */ "unc_iio_txn_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4155614 */ "unc_iio_txn_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4155760 */ "unc_iio_txn_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4155906 */ "unc_iio_txn_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4156052 */ "unc_iio_txn_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156199 */ "unc_iio_txn_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156346 */ "unc_iio_txn_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156493 */ "unc_iio_txn_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156640 */ "unc_iio_txn_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156787 */ "unc_iio_txn_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4156934 */ "unc_iio_txn_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4157139 */ "unc_iio_txn_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4157344 */ "unc_iio_txn_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4157549 */ "unc_iio_txn_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4157754 */ "unc_iio_txn_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4157958 */ "unc_iio_txn_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000"
/* offset=4158162 */ "unc_iio_txn_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4158369 */ "unc_iio_txn_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4158576 */ "unc_iio_txn_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4158783 */ "unc_iio_txn_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4158990 */ "unc_iio_txn_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000"
/* offset=4159196 */ "unc_iio_txn_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4159399 */ "unc_iio_txn_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4159602 */ "unc_iio_txn_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4159805 */ "unc_iio_txn_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4160008 */ "unc_iio_txn_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4160210 */ "unc_iio_txn_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000"
/* offset=4160412 */ "unc_iio_txn_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4160617 */ "unc_iio_txn_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4160822 */ "unc_iio_txn_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4161027 */ "unc_iio_txn_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4161232 */ "unc_iio_txn_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4161436 */ "unc_iio_txn_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000"
/* offset=4161640 */ "unc_iio_txn_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4161844 */ "unc_iio_txn_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4162048 */ "unc_iio_txn_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4162252 */ "unc_iio_txn_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4162456 */ "unc_iio_txn_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4162659 */ "unc_iio_txn_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000"
/* offset=4162862 */ "unc_iio_txn_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4163068 */ "unc_iio_txn_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4163274 */ "unc_iio_txn_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4163480 */ "unc_iio_txn_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4163686 */ "unc_iio_txn_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4163891 */ "unc_iio_txn_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000"
/* offset=4164096 */ "unc_iio_txn_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4164302 */ "unc_iio_txn_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4164508 */ "unc_iio_txn_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4164714 */ "unc_iio_txn_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4164920 */ "unc_iio_txn_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4165125 */ "unc_iio_txn_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000"
/* offset=4165330 */ "unc_iio_txn_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4165538 */ "unc_iio_txn_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4165746 */ "unc_iio_txn_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4165954 */ "unc_iio_txn_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4166162 */ "unc_iio_txn_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4166369 */ "unc_iio_txn_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000"
/* offset=4166576 */ "unc_iio_txn_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4166988 */ "unc_iio_txn_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4167400 */ "unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4167902 */ "unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4168309 */ "unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4168736 */ "unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000"
/* offset=4169075 */ "unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4169537 */ "unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4169911 */ "unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4170338 */ "unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000"
/* offset=4170677 */ "unc_iio_txn_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4171179 */ "unc_iio_txn_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4171606 */ "unc_iio_txn_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4172068 */ "unc_iio_txn_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4172495 */ "unc_iio_txn_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4172814 */ "unc_iio_txn_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4173133 */ "unc_iio_txn_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4173542 */ "unc_iio_txn_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4173951 */ "unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4174450 */ "unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4174856 */ "unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4175280 */ "unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000"
/* offset=4175618 */ "unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4176077 */ "unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4176450 */ "unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4176874 */ "unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000"
/* offset=4177212 */ "unc_iio_txn_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4177711 */ "unc_iio_txn_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4178135 */ "unc_iio_txn_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4178594 */ "unc_iio_txn_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4179018 */ "unc_iio_txn_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4179336 */ "unc_iio_txn_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4179654 */ "unc_iio_txn_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4180057 */ "unc_iio_txn_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4180460 */ "unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4180953 */ "unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4181355 */ "unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4181773 */ "unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000"
/* offset=4182107 */ "unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4182560 */ "unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4182929 */ "unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4183347 */ "unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000"
/* offset=4183681 */ "unc_iio_txn_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4184174 */ "unc_iio_txn_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4184592 */ "unc_iio_txn_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4185045 */ "unc_iio_txn_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4185463 */ "unc_iio_txn_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4185777 */ "unc_iio_txn_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4186091 */ "unc_iio_txn_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4186491 */ "unc_iio_txn_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4186891 */ "unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4187381 */ "unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4187782 */ "unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4188197 */ "unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000"
/* offset=4188530 */ "unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4188980 */ "unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4189348 */ "unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4189763 */ "unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000"
/* offset=4190096 */ "unc_iio_txn_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4190586 */ "unc_iio_txn_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4191001 */ "unc_iio_txn_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4191451 */ "unc_iio_txn_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4191866 */ "unc_iio_txn_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4192179 */ "unc_iio_txn_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4192492 */ "unc_iio_txn_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4192899 */ "unc_iio_txn_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4193306 */ "unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4193803 */ "unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4194293 */ "unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4195023 */ "unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4195445 */ "unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4195867 */ "unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4196486 */ "unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4196943 */ "unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4197400 */ "unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4198034 */ "unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4198456 */ "unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4198878 */ "unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4199501 */ "unc_iio_txn_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4199998 */ "unc_iio_txn_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4200488 */ "unc_iio_txn_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4200910 */ "unc_iio_txn_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4201332 */ "unc_iio_txn_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4201789 */ "unc_iio_txn_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4202246 */ "unc_iio_txn_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4202668 */ "unc_iio_txn_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4203090 */ "unc_iio_txn_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4203406 */ "unc_iio_txn_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4203722 */ "unc_iio_txn_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4204126 */ "unc_iio_txn_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4204530 */ "unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4205024 */ "unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4205513 */ "unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4206244 */ "unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4206663 */ "unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4207084 */ "unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4207704 */ "unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4208158 */ "unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4208614 */ "unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4209249 */ "unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4209668 */ "unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4210089 */ "unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4210713 */ "unc_iio_txn_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4211207 */ "unc_iio_txn_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4211694 */ "unc_iio_txn_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4212113 */ "unc_iio_txn_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4212532 */ "unc_iio_txn_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4212986 */ "unc_iio_txn_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4213440 */ "unc_iio_txn_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4213859 */ "unc_iio_txn_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4214278 */ "unc_iio_txn_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4214593 */ "unc_iio_txn_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4214908 */ "unc_iio_txn_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000"
/* offset=4215361 */ "unc_iio_txn_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4215814 */ "unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4216357 */ "unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4217136 */ "unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4217604 */ "unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4218272 */ "unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4218775 */ "unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4219458 */ "unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4219926 */ "unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4220598 */ "unc_iio_txn_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4221141 */ "unc_iio_txn_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4221609 */ "unc_iio_txn_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4222112 */ "unc_iio_txn_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4222580 */ "unc_iio_txn_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4222919 */ "unc_iio_txn_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4223258 */ "unc_iio_txn_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000"
/* offset=4223708 */ "unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x7001002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4224256 */ "unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4224796 */ "unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4225576 */ "unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x7002002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4226049 */ "unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4226514 */ "unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4227183 */ "unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x7004002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4227691 */ "unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4228191 */ "unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4228875 */ "unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x7008002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4229348 */ "unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4229813 */ "unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4230486 */ "unc_iio_txn_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x7010002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4231034 */ "unc_iio_txn_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4231574 */ "unc_iio_txn_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x7020002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4232047 */ "unc_iio_txn_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4232512 */ "unc_iio_txn_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x7040002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4233020 */ "unc_iio_txn_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4233520 */ "unc_iio_txn_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x7080002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4233993 */ "unc_iio_txn_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4234458 */ "unc_iio_txn_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000"
/* offset=4234796 */ "unc_iio_txn_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000"
/* offset=4235134 */ "unc_iio_txn_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4235540 */ "unc_iio_txn_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4235946 */ "unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4236442 */ "unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4236840 */ "unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4237261 */ "unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000"
/* offset=4237591 */ "unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4238047 */ "unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4238412 */ "unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4238833 */ "unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000"
/* offset=4239163 */ "unc_iio_txn_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4239659 */ "unc_iio_txn_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4240080 */ "unc_iio_txn_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4240536 */ "unc_iio_txn_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4240957 */ "unc_iio_txn_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4241267 */ "unc_iio_txn_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4241577 */ "unc_iio_txn_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4241992 */ "unc_iio_txn_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000"
/* offset=4242339 */ "unc_iio_txn_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4242721 */ "unc_iio_txn_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000"
/* offset=4243068 */ "unc_iio_txn_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4243506 */ "unc_iio_txn_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4243944 */ "unc_iio_txn_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4244474 */ "unc_iio_txn_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4245002 */ "unc_iio_txn_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4245457 */ "unc_iio_txn_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4245910 */ "unc_iio_txn_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4246400 */ "unc_iio_txn_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4246888 */ "unc_iio_txn_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4247343 */ "unc_iio_txn_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4247796 */ "unc_iio_txn_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4248326 */ "unc_iio_txn_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4248854 */ "unc_iio_txn_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4249309 */ "unc_iio_txn_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4249762 */ "unc_iio_txn_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4250252 */ "unc_iio_txn_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4250740 */ "unc_iio_txn_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4251195 */ "unc_iio_txn_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4251648 */ "unc_iio_txn_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4252039 */ "unc_iio_txn_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4252430 */ "unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4252911 */ "unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4253397 */ "unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4254075 */ "unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4254481 */ "unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is  made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4254900 */ "unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is  made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4255468 */ "unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4255909 */ "unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4256362 */ "unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4256944 */ "unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4257350 */ "unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4257768 */ "unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4258339 */ "unc_iio_txn_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4258815 */ "unc_iio_txn_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4259296 */ "unc_iio_txn_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4259704 */ "unc_iio_txn_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4260110 */ "unc_iio_txn_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4260553 */ "unc_iio_txn_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4260994 */ "unc_iio_txn_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4261402 */ "unc_iio_txn_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4261808 */ "unc_iio_txn_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4262111 */ "unc_iio_txn_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4262414 */ "unc_iio_txn_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4262802 */ "unc_iio_txn_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4263190 */ "unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4263668 */ "unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4264153 */ "unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4264832 */ "unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4265235 */ "unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4265652 */ "unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4266220 */ "unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4266658 */ "unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4267110 */ "unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4267693 */ "unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4268096 */ "unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4268513 */ "unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4269085 */ "unc_iio_txn_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4269558 */ "unc_iio_txn_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4270036 */ "unc_iio_txn_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4270441 */ "unc_iio_txn_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4270844 */ "unc_iio_txn_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000"
/* offset=4271284 */ "unc_iio_txn_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4271722 */ "unc_iio_txn_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4272127 */ "unc_iio_txn_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4272530 */ "unc_iio_txn_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4272832 */ "unc_iio_txn_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4273134 */ "unc_iio_txn_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4273493 */ "unc_iio_txn_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4273852 */ "unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4274301 */ "unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4274674 */ "unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4275048 */ "unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000"
/* offset=4275353 */ "unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4275762 */ "unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4276102 */ "unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4276476 */ "unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000"
/* offset=4276781 */ "unc_iio_txn_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4277230 */ "unc_iio_txn_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4277604 */ "unc_iio_txn_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4278013 */ "unc_iio_txn_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4278387 */ "unc_iio_txn_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4278672 */ "unc_iio_txn_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4278957 */ "unc_iio_txn_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4279417 */ "unc_iio_txn_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4279877 */ "unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4280427 */ "unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4281119 */ "unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4281594 */ "unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4282175 */ "unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4282685 */ "unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4283281 */ "unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4283756 */ "unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4284340 */ "unc_iio_txn_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4284890 */ "unc_iio_txn_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4285365 */ "unc_iio_txn_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4285875 */ "unc_iio_txn_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4286350 */ "unc_iio_txn_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4286688 */ "unc_iio_txn_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4287026 */ "unc_iio_txn_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000"
/* offset=4287483 */ "unc_iio_txn_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000"
/* offset=4287940 */ "unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4288489 */ "unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000"
/* offset=4289036 */ "unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000"
/* offset=4289739 */ "unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4290213 */ "unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000"
/* offset=4290685 */ "unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part1 to the MMIO space of an IIO target.In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000"
/* offset=4291276 */ "unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4291785 */ "unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000"
/* offset=4292292 */ "unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000"
/* offset=4292899 */ "unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4293373 */ "unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000"
/* offset=4293845 */ "unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000"
/* offset=4294441 */ "unc_iio_txn_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4294990 */ "unc_iio_txn_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000"
/* offset=4295537 */ "unc_iio_txn_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4296011 */ "unc_iio_txn_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000"
/* offset=4296483 */ "unc_iio_txn_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4296992 */ "unc_iio_txn_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000"
/* offset=4297499 */ "unc_iio_txn_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4297973 */ "unc_iio_txn_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000"
/* offset=4298445 */ "unc_iio_txn_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000"
/* offset=4298782 */ "unc_iio_txn_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000"
/* offset=4299119 */ "unc_iio_vtd_access.ctxt_miss\000uncore_iio\000uncore io\000VTd Access; context cache miss. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000\000"
/* offset=4299245 */ "unc_iio_vtd_access.l1_miss\000uncore_iio\000uncore io\000VTd Access; L1 miss. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000\000"
/* offset=4299358 */ "unc_iio_vtd_access.l2_miss\000uncore_iio\000uncore io\000VTd Access; L2 miss. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000\000"
/* offset=4299471 */ "unc_iio_vtd_access.l3_miss\000uncore_iio\000uncore io\000VTd Access; L3 miss. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000\000"
/* offset=4299585 */ "unc_iio_vtd_access.l4_page_hit\000uncore_iio\000uncore io\000VTd Access; Vtd hit. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000\000"
/* offset=4299702 */ "unc_iio_vtd_access.tlb1_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000\000"
/* offset=4299819 */ "unc_iio_vtd_access.tlb_full\000uncore_iio\000uncore io\000VTd Access; TLB is full. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000\000"
/* offset=4299938 */ "unc_iio_vtd_access.tlb_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000\000"
/* offset=4300054 */ "unc_iio_vtd_occupancy\000uncore_iio\000uncore io\000VTd Occupancy. Unit: uncore_iio \000event=0x40\000\00001\000\000"
/* offset=4300146 */ "unc_m2hbm_clockticks\000uncore_m2hbm\000uncore memory\000Cycles - at UCLK. Unit: uncore_m2hbm \000event=0x1\000\00001\000\000"
/* offset=4300247 */ "unc_m2hbm_cms_clockticks\000uncore_m2hbm\000uncore memory\000CMS Clockticks. Unit: uncore_m2hbm \000event=0xc0\000\00001\000\000"
/* offset=4300351 */ "unc_m2hbm_direct2core_not_taken_dirstate.non_cisgress\000uncore_m2hbm\000uncore memory\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress. Unit: uncore_m2hbm \000event=0x17,umask=0x2\000\00001\000Counts the number of time non cisgress D2C was not honoured by egress due to directory state constraints\000"
/* offset=4300668 */ "unc_m2hbm_direct2core_not_taken_dirstate\000uncore_m2hbm\000uncore memory\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2hbm \000event=0x17,umask=0x7\000\00001\000\000"
/* offset=4300853 */ "unc_m2hbm_direct2core_not_taken_notforked\000uncore_m2hbm\000uncore memory\000Counts the time when FM didn't do d2c for fill reads (cross tile case). Unit: uncore_m2hbm \000event=0x4a\000\00001\000\000"
/* offset=4301030 */ "unc_m2hbm_direct2core_txn_override.cisgress\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to core transaction was overridden : Cisgress. Unit: uncore_m2hbm \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=4301226 */ "unc_m2hbm_direct2core_txn_override\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2hbm \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=4301403 */ "unc_m2hbm_direct2upi_not_taken_credits\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2hbm \000event=0x1b,umask=0x7\000\00001\000\000"
/* offset=4301590 */ "unc_m2hbm_direct2upi_not_taken_dirstate.cisgress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x4\000\00001\000Counts cisgress d2K that was not honored due to directory constraints\000"
/* offset=4301879 */ "unc_m2hbm_direct2upi_not_taken_dirstate.egress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts the number of time D2K was not honoured by egress due to directory state constraints\000"
/* offset=4302186 */ "unc_m2hbm_direct2upi_not_taken_dirstate.non_cisgress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x2\000\00001\000Counts non cisgress d2K that was not honored due to directory constraints\000"
/* offset=4302487 */ "unc_m2hbm_direct2upi_not_taken_dirstate\000uncore_m2hbm\000uncore memory\000Cycles when direct to Intel UPI was disabled. Unit: uncore_m2hbm \000event=0x1a,umask=0x7\000\00001\000\000"
/* offset=4302646 */ "unc_m2hbm_direct2upi_txn_override.cisgress\000uncore_m2hbm\000uncore memory\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2hbm \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=4302822 */ "unc_m2hbm_direct2upi_txn_override\000uncore_m2hbm\000uncore memory\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2hbm \000event=0x1c,umask=0x3\000\00001\000\000"
/* offset=4302999 */ "unc_m2hbm_directory_hit.clean_a\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2hbm \000event=0x1d,umask=0x80\000\00001\000\000"
/* offset=4303150 */ "unc_m2hbm_directory_hit.clean_i\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2hbm \000event=0x1d,umask=0x10\000\00001\000\000"
/* offset=4303301 */ "unc_m2hbm_directory_hit.clean_p\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2hbm \000event=0x1d,umask=0x40\000\00001\000\000"
/* offset=4303452 */ "unc_m2hbm_directory_hit.clean_s\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2hbm \000event=0x1d,umask=0x20\000\00001\000\000"
/* offset=4303603 */ "unc_m2hbm_directory_hit.dirty_a\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2hbm \000event=0x1d,umask=0x8\000\00001\000\000"
/* offset=4303750 */ "unc_m2hbm_directory_hit.dirty_i\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2hbm \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=4303897 */ "unc_m2hbm_directory_hit.dirty_p\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2hbm \000event=0x1d,umask=0x4\000\00001\000\000"
/* offset=4304044 */ "unc_m2hbm_directory_hit.dirty_s\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2hbm \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=4304191 */ "unc_m2hbm_directory_lookup.any\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2hbm \000event=0x20,umask=0x1\000\00001\000Counts the number of hit data returns to egress with any directory to non persistent memory\000"
/* offset=4304446 */ "unc_m2hbm_directory_lookup.state_a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2hbm \000event=0x20,umask=0x8\000\00001\000Counts the number of hit data returns to egress with directory A to non persistent memory\000"
/* offset=4304714 */ "unc_m2hbm_directory_lookup.state_i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2hbm \000event=0x20,umask=0x2\000\00001\000Counts the number of hit data returns to egress with directory I to non persistent memory\000"
/* offset=4304981 */ "unc_m2hbm_directory_lookup.state_s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2hbm \000event=0x20,umask=0x4\000\00001\000Counts the number of hit data returns to egress with directory S to non persistent memory\000"
/* offset=4305248 */ "unc_m2hbm_directory_miss.clean_a\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2hbm \000event=0x1e,umask=0x80\000\00001\000\000"
/* offset=4305401 */ "unc_m2hbm_directory_miss.clean_i\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2hbm \000event=0x1e,umask=0x10\000\00001\000\000"
/* offset=4305554 */ "unc_m2hbm_directory_miss.clean_p\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2hbm \000event=0x1e,umask=0x40\000\00001\000\000"
/* offset=4305707 */ "unc_m2hbm_directory_miss.clean_s\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2hbm \000event=0x1e,umask=0x20\000\00001\000\000"
/* offset=4305860 */ "unc_m2hbm_directory_miss.dirty_a\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2hbm \000event=0x1e,umask=0x8\000\00001\000\000"
/* offset=4306009 */ "unc_m2hbm_directory_miss.dirty_i\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2hbm \000event=0x1e,umask=0x1\000\00001\000\000"
/* offset=4306158 */ "unc_m2hbm_directory_miss.dirty_p\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2hbm \000event=0x1e,umask=0x4\000\00001\000\000"
/* offset=4306307 */ "unc_m2hbm_directory_miss.dirty_s\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2hbm \000event=0x1e,umask=0x2\000\00001\000\000"
/* offset=4306456 */ "unc_m2hbm_directory_update.a2i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2hbm \000event=0x21,umask=0x320\000\00001\000\000"
/* offset=4306615 */ "unc_m2hbm_directory_update.a2s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2hbm \000event=0x21,umask=0x340\000\00001\000\000"
/* offset=4306774 */ "unc_m2hbm_directory_update.a_to_i_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x120\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to I to non persistent memory\000"
/* offset=4307085 */ "unc_m2hbm_directory_update.a_to_i_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x220\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to I to non persistent memory\000"
/* offset=4307391 */ "unc_m2hbm_directory_update.a_to_s_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x140\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to S to non persistent memory\000"
/* offset=4307702 */ "unc_m2hbm_directory_update.a_to_s_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x240\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to S to non persistent memory\000"
/* offset=4308008 */ "unc_m2hbm_directory_update.any\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2hbm \000event=0x21,umask=0x301\000\00001\000\000"
/* offset=4308173 */ "unc_m2hbm_directory_update.hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000Counts any 1lm or 2lm hit data return that would result in directory update to non persistent memory\000"
/* offset=4308467 */ "unc_m2hbm_directory_update.i2a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2hbm \000event=0x21,umask=0x304\000\00001\000\000"
/* offset=4308626 */ "unc_m2hbm_directory_update.i2s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2hbm \000event=0x21,umask=0x302\000\00001\000\000"
/* offset=4308785 */ "unc_m2hbm_directory_update.i_to_a_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to A to non persistent memory\000"
/* offset=4309096 */ "unc_m2hbm_directory_update.i_to_a_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000Counts 2lm miss  data returns that would result in directory update from I to A to non persistent memory\000"
/* offset=4309402 */ "unc_m2hbm_directory_update.i_to_s_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x102\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to S to non persistent memory\000"
/* offset=4309713 */ "unc_m2hbm_directory_update.i_to_s_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x202\000\00001\000Counts  2lm miss  data returns that would result in directory update from I to S to non persistent memory\000"
/* offset=4310020 */ "unc_m2hbm_directory_update.miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000Counts any 2lm miss data return that would result in directory update to non persistent memory\000"
/* offset=4310309 */ "unc_m2hbm_directory_update.s2a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2hbm \000event=0x21,umask=0x310\000\00001\000\000"
/* offset=4310468 */ "unc_m2hbm_directory_update.s2i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2hbm \000event=0x21,umask=0x308\000\00001\000\000"
/* offset=4310627 */ "unc_m2hbm_directory_update.s_to_a_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x110\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to A to non persistent memory\000"
/* offset=4310938 */ "unc_m2hbm_directory_update.s_to_a_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x210\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to A to non persistent memory\000"
/* offset=4311244 */ "unc_m2hbm_directory_update.s_to_i_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x108\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to I to non persistent memory\000"
/* offset=4311555 */ "unc_m2hbm_directory_update.s_to_i_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x208\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to I to non persistent memory\000"
/* offset=4311861 */ "unc_m2hbm_distress.ad\000uncore_m2hbm\000uncore memory\000Count distress signalled on AkAd cmp message. Unit: uncore_m2hbm \000event=0x67,umask=0x20\000\00001\000\000"
/* offset=4312003 */ "unc_m2hbm_distress.all\000uncore_m2hbm\000uncore memory\000Count distress signalled on any packet type. Unit: uncore_m2hbm \000event=0x67,umask=0x1\000\00001\000\000"
/* offset=4312144 */ "unc_m2hbm_distress.bl_cmp\000uncore_m2hbm\000uncore memory\000Count distress signalled on Bl Cmp message. Unit: uncore_m2hbm \000event=0x67,umask=0x40\000\00001\000\000"
/* offset=4312288 */ "unc_m2hbm_distress.crosstile_nmwr\000uncore_m2hbm\000uncore memory\000Count distress signalled on NM fill write message. Unit: uncore_m2hbm \000event=0x67,umask=0x10\000\00001\000\000"
/* offset=4312447 */ "unc_m2hbm_distress.d2cha\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2Cha message. Unit: uncore_m2hbm \000event=0x67,umask=0x8\000\00001\000\000"
/* offset=4312588 */ "unc_m2hbm_distress.d2core\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2c message. Unit: uncore_m2hbm \000event=0x67,umask=0x2\000\00001\000\000"
/* offset=4312728 */ "unc_m2hbm_distress.d2upi\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2k message. Unit: uncore_m2hbm \000event=0x67,umask=0x4\000\00001\000\000"
/* offset=4312867 */ "unc_m2hbm_egress_ordering.iv_snoopgo_dn\000uncore_m2hbm\000uncore memory\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2hbm \000event=0xba,umask=0x80000004\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4313186 */ "unc_m2hbm_egress_ordering.iv_snoopgo_up\000uncore_m2hbm\000uncore memory\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2hbm \000event=0xba,umask=0x80000001\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4313501 */ "unc_m2hbm_igr_starve_winner.mask7\000uncore_m2hbm\000uncore memory\000Count when Starve Glocab counter is at 7. Unit: uncore_m2hbm \000event=0x44,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000\000"
/* offset=4313689 */ "unc_m2hbm_imc_reads.all\000uncore_m2hbm\000uncore memory\000Reads to iMC issued. Unit: uncore_m2hbm \000event=0x24,umask=0x304\000\00001\000\000"
/* offset=4313809 */ "unc_m2hbm_imc_reads.ch0.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0.ALL. Unit: uncore_m2hbm \000event=0x24,umask=0x104\000\00001\000\000"
/* offset=4313941 */ "unc_m2hbm_imc_reads.ch0.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x101\000\00001\000\000"
/* offset=4314079 */ "unc_m2hbm_imc_reads.ch0_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_ALL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000\000"
/* offset=4314249 */ "unc_m2hbm_imc_reads.ch0_from_tgr\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_FROM_TGR. Unit: uncore_m2hbm \000event=0x24,umask=0x140\000\00001\000\000"
/* offset=4314391 */ "unc_m2hbm_imc_reads.ch0_isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - Ch0. Unit: uncore_m2hbm \000event=0x24,umask=0x102\000\00001\000\000"
/* offset=4314521 */ "unc_m2hbm_imc_reads.ch0_normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_NORMAL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000\000"
/* offset=4314697 */ "unc_m2hbm_imc_reads.ch1.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1.ALL. Unit: uncore_m2hbm \000event=0x24,umask=0x204\000\00001\000\000"
/* offset=4314829 */ "unc_m2hbm_imc_reads.ch1.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x201\000\00001\000\000"
/* offset=4314967 */ "unc_m2hbm_imc_reads.ch1_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1_ALL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000\000"
/* offset=4315137 */ "unc_m2hbm_imc_reads.ch1_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch1. Unit: uncore_m2hbm \000event=0x24,umask=0x240\000\00001\000\000"
/* offset=4315261 */ "unc_m2hbm_imc_reads.ch1_isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - Ch1. Unit: uncore_m2hbm \000event=0x24,umask=0x202\000\00001\000\000"
/* offset=4315391 */ "unc_m2hbm_imc_reads.ch1_normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1_NORMAL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000\000"
/* offset=4315567 */ "unc_m2hbm_imc_reads.from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - All Channels. Unit: uncore_m2hbm \000event=0x24,umask=0x340\000\00001\000\000"
/* offset=4315696 */ "unc_m2hbm_imc_reads.isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - All Channels. Unit: uncore_m2hbm \000event=0x24,umask=0x302\000\00001\000\000"
/* offset=4315831 */ "unc_m2hbm_imc_reads.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x301\000\00001\000\000"
/* offset=4315961 */ "unc_m2hbm_imc_writes.all\000uncore_m2hbm\000uncore memory\000All Writes - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1810\000\00001\000\000"
/* offset=4316089 */ "unc_m2hbm_imc_writes.ch0.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.ALL. Unit: uncore_m2hbm \000event=0x25,umask=0x810\000\00001\000\000"
/* offset=4316223 */ "unc_m2hbm_imc_writes.ch0.full\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.FULL. Unit: uncore_m2hbm \000event=0x25,umask=0x801\000\00001\000\000"
/* offset=4316359 */ "unc_m2hbm_imc_writes.ch0.partial\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.PARTIAL. Unit: uncore_m2hbm \000event=0x25,umask=0x802\000\00001\000\000"
/* offset=4316501 */ "unc_m2hbm_imc_writes.ch0_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_ALL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x810\000\00001\000\000"
/* offset=4316673 */ "unc_m2hbm_imc_writes.ch0_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch0. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000"
/* offset=4316786 */ "unc_m2hbm_imc_writes.ch0_full\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_FULL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x801\000\00001\000\000"
/* offset=4316960 */ "unc_m2hbm_imc_writes.ch0_full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - Ch0. Unit: uncore_m2hbm \000event=0x25,umask=0x804\000\00001\000\000"
/* offset=4317094 */ "unc_m2hbm_imc_writes.ch0_ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - Ch0. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4317244 */ "unc_m2hbm_imc_writes.ch0_ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - Ch0. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4317404 */ "unc_m2hbm_imc_writes.ch0_partial\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_PARTIAL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x802\000\00001\000\000"
/* offset=4317584 */ "unc_m2hbm_imc_writes.ch0_partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - Ch0. Unit: uncore_m2hbm \000event=0x25,umask=0x808\000\00001\000\000"
/* offset=4317719 */ "unc_m2hbm_imc_writes.ch1.all\000uncore_m2hbm\000uncore memory\000All Writes - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1010\000\00001\000\000"
/* offset=4317842 */ "unc_m2hbm_imc_writes.ch1.full\000uncore_m2hbm\000uncore memory\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1001\000\00001\000\000"
/* offset=4317975 */ "unc_m2hbm_imc_writes.ch1.partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1002\000\00001\000\000"
/* offset=4318109 */ "unc_m2hbm_imc_writes.ch1_all\000uncore_m2hbm\000uncore memory\000All Writes - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1010\000\00001\000\000"
/* offset=4318270 */ "unc_m2hbm_imc_writes.ch1_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch1. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000"
/* offset=4318383 */ "unc_m2hbm_imc_writes.ch1_full\000uncore_m2hbm\000uncore memory\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1001\000\00001\000\000"
/* offset=4318554 */ "unc_m2hbm_imc_writes.ch1_full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1004\000\00001\000\000"
/* offset=4318689 */ "unc_m2hbm_imc_writes.ch1_ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4318839 */ "unc_m2hbm_imc_writes.ch1_ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4318999 */ "unc_m2hbm_imc_writes.ch1_partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1002\000\00001\000\000"
/* offset=4319171 */ "unc_m2hbm_imc_writes.ch1_partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1008\000\00001\000\000"
/* offset=4319307 */ "unc_m2hbm_imc_writes.from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - All Channels. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000"
/* offset=4319425 */ "unc_m2hbm_imc_writes.full\000uncore_m2hbm\000uncore memory\000Full Non-ISOCH - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1801\000\00001\000\000"
/* offset=4319558 */ "unc_m2hbm_imc_writes.full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1804\000\00001\000\000"
/* offset=4319698 */ "unc_m2hbm_imc_writes.ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - All Channels. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4319853 */ "unc_m2hbm_imc_writes.ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - All Channels. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4320018 */ "unc_m2hbm_imc_writes.partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1802\000\00001\000\000"
/* offset=4320157 */ "unc_m2hbm_imc_writes.partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1808\000\00001\000\000"
/* offset=4320298 */ "unc_m2hbm_prefcam_cis_drops\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_CIS_DROPS. Unit: uncore_m2hbm \000event=0x5c\000\00001\000\000"
/* offset=4320418 */ "unc_m2hbm_prefcam_demand_drops.ch0_upi\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x2\000\00001\000\000"
/* offset=4320555 */ "unc_m2hbm_prefcam_demand_drops.ch0_xpt\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x1\000\00001\000\000"
/* offset=4320692 */ "unc_m2hbm_prefcam_demand_drops.ch1_upi\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x8\000\00001\000\000"
/* offset=4320829 */ "unc_m2hbm_prefcam_demand_drops.ch1_xpt\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x4\000\00001\000\000"
/* offset=4320966 */ "unc_m2hbm_prefcam_demand_drops.upi_allch\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2hbm \000event=0x58,umask=0xa\000\00001\000\000"
/* offset=4321126 */ "unc_m2hbm_prefcam_demand_drops.xpt_allch\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x5\000\00001\000\000"
/* offset=4321265 */ "unc_m2hbm_prefcam_demand_merge.upi_allch\000uncore_m2hbm\000uncore memory\000: UPI - All Channels. Unit: uncore_m2hbm \000event=0x5d,umask=0xa\000\00001\000\000"
/* offset=4321401 */ "unc_m2hbm_prefcam_demand_merge.xpt_allch\000uncore_m2hbm\000uncore memory\000: XPT - All Channels. Unit: uncore_m2hbm \000event=0x5d,umask=0x5\000\00001\000\000"
/* offset=4321537 */ "unc_m2hbm_prefcam_demand_no_merge.rd_merged\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x40\000\00001\000\000"
/* offset=4321697 */ "unc_m2hbm_prefcam_demand_no_merge.wr_merged\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x20\000\00001\000\000"
/* offset=4321857 */ "unc_m2hbm_prefcam_demand_no_merge.wr_squashed\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x10\000\00001\000\000"
/* offset=4322019 */ "unc_m2hbm_prefcam_inserts.ch0_upi\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2hbm \000event=0x56,umask=0x2\000\00001\000\000"
/* offset=4322161 */ "unc_m2hbm_prefcam_inserts.ch0_xpt\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2hbm \000event=0x56,umask=0x1\000\00001\000\000"
/* offset=4322303 */ "unc_m2hbm_prefcam_inserts.ch1_upi\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2hbm \000event=0x56,umask=0x8\000\00001\000\000"
/* offset=4322445 */ "unc_m2hbm_prefcam_inserts.ch1_xpt\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2hbm \000event=0x56,umask=0x4\000\00001\000\000"
/* offset=4322587 */ "unc_m2hbm_prefcam_inserts.upi_allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2hbm \000event=0x56,umask=0xa\000\00001\000\000"
/* offset=4322739 */ "unc_m2hbm_prefcam_inserts.xpt_allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2hbm \000event=0x56,umask=0x5\000\00001\000Prefetch CAM Inserts : XPT -All Channels\000"
/* offset=4322931 */ "unc_m2hbm_prefcam_occupancy.allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2hbm \000event=0x54,umask=0x3\000\00001\000\000"
/* offset=4323077 */ "unc_m2hbm_prefcam_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x54,umask=0x1\000\00001\000\000"
/* offset=4323218 */ "unc_m2hbm_prefcam_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x54,umask=0x2\000\00001\000\000"
/* offset=4323359 */ "unc_m2hbm_prefcam_resp_miss.allch\000uncore_m2hbm\000uncore memory\000All Channels. Unit: uncore_m2hbm \000event=0x5f,umask=0x3\000\00001\000\000"
/* offset=4323480 */ "unc_m2hbm_prefcam_resp_miss.ch0\000uncore_m2hbm\000uncore memory\000: Channel 0. Unit: uncore_m2hbm \000event=0x5f,umask=0x1\000\00001\000\000"
/* offset=4323598 */ "unc_m2hbm_prefcam_resp_miss.ch1\000uncore_m2hbm\000uncore memory\000: Channel 1. Unit: uncore_m2hbm \000event=0x5f,umask=0x2\000\00001\000\000"
/* offset=4323716 */ "unc_m2hbm_prefcam_rxc_deallocs.1lm_posted\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2hbm \000event=0x62,umask=0x2\000\00001\000\000"
/* offset=4323874 */ "unc_m2hbm_prefcam_rxc_deallocs.cis\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2hbm \000event=0x62,umask=0x8\000\00001\000\000"
/* offset=4324018 */ "unc_m2hbm_prefcam_rxc_deallocs.squashed\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2hbm \000event=0x62,umask=0x1\000\00001\000\000"
/* offset=4324172 */ "unc_m2hbm_prefcam_rxc_occupancy\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_OCCUPANCY. Unit: uncore_m2hbm \000event=0x60,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000"
/* offset=4324338 */ "unc_m2hbm_rxc_ad.inserts\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x2,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000\000"
/* offset=4324532 */ "unc_m2hbm_rxc_ad_inserts\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=4324688 */ "unc_m2hbm_rxc_ad_occupancy\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2hbm \000event=0x3\000\00001\000\000"
/* offset=4324810 */ "unc_m2hbm_rxc_bl.inserts\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) : BL Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x4,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts anytime a BL packet is added to Ingress\000"
/* offset=4325050 */ "unc_m2hbm_rxc_bl_inserts\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) : BL Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x4,umask=0x1\000\00001\000Counts anytime a BL packet is added to Ingress\000"
/* offset=4325252 */ "unc_m2hbm_rxc_bl_occupancy\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2hbm \000event=0x5\000\00001\000\000"
/* offset=4325374 */ "unc_m2hbm_tgr_ad_credits\000uncore_m2hbm\000uncore memory\000Number AD Ingress Credits. Unit: uncore_m2hbm \000event=0x2e\000\00001\000\000"
/* offset=4325489 */ "unc_m2hbm_tgr_bl_credits\000uncore_m2hbm\000uncore memory\000Number BL Ingress Credits. Unit: uncore_m2hbm \000event=0x2f\000\00001\000\000"
/* offset=4325604 */ "unc_m2hbm_tracker_inserts.ch0\000uncore_m2hbm\000uncore memory\000Tracker Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x32,umask=0x104\000\00001\000\000"
/* offset=4325738 */ "unc_m2hbm_tracker_inserts.ch1\000uncore_m2hbm\000uncore memory\000Tracker Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x32,umask=0x204\000\00001\000\000"
/* offset=4325872 */ "unc_m2hbm_tracker_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Tracker Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x33,umask=0x1\000\00001\000\000"
/* offset=4326008 */ "unc_m2hbm_tracker_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Tracker Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x33,umask=0x2\000\00001\000\000"
/* offset=4326144 */ "unc_m2hbm_txc_ad.inserts\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) : AD Egress (to CMS) Allocations. Unit: uncore_m2hbm \000event=0x6,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts anytime a AD packet is added to Egress\000"
/* offset=4326377 */ "unc_m2hbm_txc_ad_inserts\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) : AD Egress (to CMS) Allocations. Unit: uncore_m2hbm \000event=0x6,umask=0x1\000\00001\000Counts anytime a AD packet is added to Egress\000"
/* offset=4326572 */ "unc_m2hbm_txc_ad_occupancy\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) Occupancy. Unit: uncore_m2hbm \000event=0x7\000\00001\000\000"
/* offset=4326691 */ "unc_m2hbm_txc_bl.inserts_cms0\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) : Inserts - CMS0 - Near Side. Unit: uncore_m2hbm \000event=0xe,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000Counts the number of BL transactions to CMS add port 0\000"
/* offset=4326936 */ "unc_m2hbm_txc_bl.inserts_cms1\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) : Inserts - CMS1 - Far Side. Unit: uncore_m2hbm \000event=0xe,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000Counts the number of BL transactions to CMS add port 1\000"
/* offset=4327180 */ "unc_m2hbm_txc_bl_occupancy.all\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : All. Unit: uncore_m2hbm \000event=0xf,umask=0x3\000\00001\000\000"
/* offset=4327319 */ "unc_m2hbm_txc_bl_occupancy.cms0\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : Common Mesh Stop - Near Side. Unit: uncore_m2hbm \000event=0xf,umask=0x1\000\00001\000\000"
/* offset=4327484 */ "unc_m2hbm_txc_bl_occupancy.cms1\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : Common Mesh Stop - Far Side. Unit: uncore_m2hbm \000event=0xf,umask=0x2\000\00001\000\000"
/* offset=4327648 */ "unc_m2hbm_wpq_flush.ch0\000uncore_m2hbm\000uncore memory\000WPQ Flush : Channel 0. Unit: uncore_m2hbm \000event=0x42,umask=0x1\000\00001\000\000"
/* offset=4327768 */ "unc_m2hbm_wpq_flush.ch1\000uncore_m2hbm\000uncore memory\000WPQ Flush : Channel 1. Unit: uncore_m2hbm \000event=0x42,umask=0x2\000\00001\000\000"
/* offset=4327888 */ "unc_m2hbm_wpq_no_reg_crd.chn0\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2hbm \000event=0x37,umask=0x1\000\00001\000\000"
/* offset=4328047 */ "unc_m2hbm_wpq_no_reg_crd.chn1\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2hbm \000event=0x37,umask=0x2\000\00001\000\000"
/* offset=4328206 */ "unc_m2hbm_wpq_no_spec_crd.chn0\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2hbm \000event=0x38,umask=0x1\000\00001\000\000"
/* offset=4328366 */ "unc_m2hbm_wpq_no_spec_crd.chn1\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2hbm \000event=0x38,umask=0x2\000\00001\000\000"
/* offset=4328526 */ "unc_m2hbm_wr_tracker_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=4328667 */ "unc_m2hbm_wr_tracker_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=4328808 */ "unc_m2hbm_wr_tracker_nonposted_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=4328970 */ "unc_m2hbm_wr_tracker_nonposted_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=4329132 */ "unc_m2hbm_wr_tracker_nonposted_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=4329298 */ "unc_m2hbm_wr_tracker_nonposted_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=4329464 */ "unc_m2hbm_wr_tracker_posted_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x48,umask=0x1\000\00001\000\000"
/* offset=4329619 */ "unc_m2hbm_wr_tracker_posted_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x48,umask=0x2\000\00001\000\000"
/* offset=4329774 */ "unc_m2hbm_wr_tracker_posted_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x47,umask=0x1\000\00001\000\000"
/* offset=4329933 */ "unc_m2hbm_wr_tracker_posted_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x47,umask=0x2\000\00001\000\000"
/* offset=4330092 */ "unc_m2m_ag0_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4330324 */ "unc_m2m_ag0_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4330556 */ "unc_m2m_ag0_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4330788 */ "unc_m2m_ag0_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4331020 */ "unc_m2m_ag0_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4331253 */ "unc_m2m_ag0_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4331486 */ "unc_m2m_ag0_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4331772 */ "unc_m2m_ag0_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4332058 */ "unc_m2m_ag0_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4332344 */ "unc_m2m_ag0_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4332630 */ "unc_m2m_ag0_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4332917 */ "unc_m2m_ag0_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4333204 */ "unc_m2m_ag0_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4333491 */ "unc_m2m_ag0_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4333778 */ "unc_m2m_ag0_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4334067 */ "unc_m2m_ag0_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4334353 */ "unc_m2m_ag0_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4334639 */ "unc_m2m_ag0_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4334871 */ "unc_m2m_ag0_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4335103 */ "unc_m2m_ag0_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4335335 */ "unc_m2m_ag0_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4335567 */ "unc_m2m_ag0_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4335800 */ "unc_m2m_ag0_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4336033 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4336320 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4336607 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4336894 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4337181 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4337469 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4337757 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4338045 */ "unc_m2m_ag0_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4338333 */ "unc_m2m_ag0_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4338623 */ "unc_m2m_ag0_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4338910 */ "unc_m2m_ag0_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4339197 */ "unc_m2m_ag0_bl_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4339429 */ "unc_m2m_ag0_bl_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4339661 */ "unc_m2m_ag0_bl_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4339893 */ "unc_m2m_ag0_bl_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4340125 */ "unc_m2m_ag0_bl_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4340358 */ "unc_m2m_ag0_bl_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4340591 */ "unc_m2m_ag0_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4340877 */ "unc_m2m_ag0_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4341163 */ "unc_m2m_ag0_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4341449 */ "unc_m2m_ag0_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4341735 */ "unc_m2m_ag0_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4342022 */ "unc_m2m_ag0_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4342309 */ "unc_m2m_ag0_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4342596 */ "unc_m2m_ag0_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4342883 */ "unc_m2m_ag0_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4343172 */ "unc_m2m_ag0_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4343458 */ "unc_m2m_ag0_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4343744 */ "unc_m2m_ag0_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4343976 */ "unc_m2m_ag0_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4344208 */ "unc_m2m_ag0_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4344440 */ "unc_m2m_ag0_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4344672 */ "unc_m2m_ag0_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4344905 */ "unc_m2m_ag0_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4345138 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4345425 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4345712 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4345999 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4346286 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4346574 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4346862 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4347150 */ "unc_m2m_ag0_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4347438 */ "unc_m2m_ag0_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4347728 */ "unc_m2m_ag0_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4348015 */ "unc_m2m_ag0_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4348302 */ "unc_m2m_ag1_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4348534 */ "unc_m2m_ag1_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4348766 */ "unc_m2m_ag1_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4348998 */ "unc_m2m_ag1_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4349230 */ "unc_m2m_ag1_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4349463 */ "unc_m2m_ag1_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4349696 */ "unc_m2m_ag1_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4349982 */ "unc_m2m_ag1_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4350268 */ "unc_m2m_ag1_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4350554 */ "unc_m2m_ag1_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4350840 */ "unc_m2m_ag1_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4351127 */ "unc_m2m_ag1_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4351414 */ "unc_m2m_ag1_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4351701 */ "unc_m2m_ag1_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4351988 */ "unc_m2m_ag1_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4352277 */ "unc_m2m_ag1_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4352563 */ "unc_m2m_ag1_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4352849 */ "unc_m2m_ag1_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4353081 */ "unc_m2m_ag1_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4353313 */ "unc_m2m_ag1_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4353545 */ "unc_m2m_ag1_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4353777 */ "unc_m2m_ag1_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4354010 */ "unc_m2m_ag1_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4354243 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4354530 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4354817 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4355104 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4355391 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4355679 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4355967 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4356255 */ "unc_m2m_ag1_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4356543 */ "unc_m2m_ag1_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4356833 */ "unc_m2m_ag1_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4357120 */ "unc_m2m_ag1_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4357407 */ "unc_m2m_ag1_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4357693 */ "unc_m2m_ag1_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4357979 */ "unc_m2m_ag1_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4358265 */ "unc_m2m_ag1_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4358551 */ "unc_m2m_ag1_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4358838 */ "unc_m2m_ag1_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4359125 */ "unc_m2m_ag1_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4359412 */ "unc_m2m_ag1_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4359699 */ "unc_m2m_ag1_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4359988 */ "unc_m2m_ag1_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4360274 */ "unc_m2m_ag1_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4360560 */ "unc_m2m_ag1_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4360792 */ "unc_m2m_ag1_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4361024 */ "unc_m2m_ag1_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4361256 */ "unc_m2m_ag1_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4361488 */ "unc_m2m_ag1_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4361721 */ "unc_m2m_ag1_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4361954 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4362241 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4362528 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4362815 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4363102 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4363390 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4363678 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4363966 */ "unc_m2m_ag1_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4364254 */ "unc_m2m_ag1_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4364544 */ "unc_m2m_ag1_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4364831 */ "unc_m2m_ag1_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4365118 */ "unc_m2m_ag1_bl_credits_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4365354 */ "unc_m2m_ag1_bl_credits_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4365590 */ "unc_m2m_ag1_bl_credits_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4365826 */ "unc_m2m_ag1_bl_credits_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4366062 */ "unc_m2m_ag1_bl_credits_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4366299 */ "unc_m2m_ag1_bl_credits_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4366536 */ "unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000\000"
/* offset=4366678 */ "unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000Traffic in which the M2M to iMC Bypass was not taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000Counts traffic in which the M2M (Mesh to Memory) to iMC (Memory Controller) bypass was not taken\000"
/* offset=4366939 */ "unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000"
/* offset=4367073 */ "unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000"
/* offset=4367206 */ "unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000"
/* offset=4367349 */ "unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000"
/* offset=4367491 */ "unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000"
/* offset=4367626 */ "unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000"
/* offset=4367760 */ "unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Clockticks of the mesh to memory (M2M). Unit: uncore_m2m \000event=0\000\00001\000\000"
/* offset=4367881 */ "unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Cycles - at UCLK. Unit: uncore_m2m \000event=0\000\00001\000\000"
/* offset=4367980 */ "unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000M2M Clockticks. Unit: uncore_m2m \000event=0x1\000\00001\000Clockticks of the mesh to memory (M2M)\000"
/* offset=4368117 */ "unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000"
/* offset=4368221 */ "unc_m2m_direct2core_not_taken_dirstate.non_cisgress\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress : Counts the number of time non cisgress D2C was not honoured by egress due to directory state constraints\000"
/* offset=4368625 */ "unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2m \000event=0x17,umask=0x7\000\00001\000\000"
/* offset=4368810 */ "unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000Counts cycles when direct to core mode (which bypasses the CHA) was disabled\000"
/* offset=4369061 */ "unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode, which bypasses the CHA, was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000\000"
/* offset=4369236 */ "unc_m2m_direct2core_not_taken_notforked\000uncore_m2m\000uncore interconnect\000Counts the time when FM didn't do d2c for fill reads (cross tile case). Unit: uncore_m2m \000event=0x4a\000\00001\000\000"
/* offset=4369413 */ "unc_m2m_direct2core_not_taken_notforked\000uncore_m2m\000uncore interconnect\000UNC_M2M_DIRECT2CORE_NOT_TAKEN_NOTFORKED. Unit: uncore_m2m \000event=0x60\000\00001\000\000"
/* offset=4369559 */ "unc_m2m_direct2core_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to core (bypassing the CHA). Unit: uncore_m2m \000event=0x23\000\00001\000Counts when messages were sent direct to core (bypassing the CHA)\000"
/* offset=4369765 */ "unc_m2m_direct2core_txn_override.cisgress\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden : Cisgress. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=4369961 */ "unc_m2m_direct2core_txn_override.pmm_hit\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden : 2LM Hit?. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=4370156 */ "unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4370322 */ "unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=4370499 */ "unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2m \000event=0x25\000\00001\000Counts reads in which direct to core transactions (which would have bypassed the CHA) were overridden\000"
/* offset=4370767 */ "unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2m \000event=0x1b,umask=0x7\000\00001\000\000"
/* offset=4370954 */ "unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2m \000event=0x28\000\00001\000\000"
/* offset=4371131 */ "unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel(R) UPI transactions were overridden. Unit: uncore_m2m \000event=0x28\000\00001\000Counts reads in which direct to Intel(R) Ultra Path Interconnect (UPI) transactions (which would have bypassed the CHA) were overridden\000"
/* offset=4371446 */ "unc_m2m_direct2upi_not_taken_dirstate.cisgress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored. Unit: uncore_m2m \000event=0x1a,umask=0x4\000\00001\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored : Counts cisgress d2K that was not honored due to directory constraints\000"
/* offset=4371758 */ "unc_m2m_direct2upi_not_taken_dirstate.egress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U. Unit: uncore_m2m \000event=0x1a,umask=0x1\000\00001\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U : Counts the number of time D2K was not honoured by egress due to directory state constraints\000"
/* offset=4372086 */ "unc_m2m_direct2upi_not_taken_dirstate.non_cisgress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored. Unit: uncore_m2m \000event=0x1a,umask=0x2\000\00001\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored : Counts non cisgress d2K that was not honored due to directory constraints\000"
/* offset=4372414 */ "unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled. Unit: uncore_m2m \000event=0x27\000\00001\000\000"
/* offset=4372554 */ "unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to Intel UPI was disabled. Unit: uncore_m2m \000event=0x1a,umask=0x7\000\00001\000\000"
/* offset=4372713 */ "unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to Intel(R) UPI was disabled. Unit: uncore_m2m \000event=0x27\000\00001\000Counts cycles when the ability to send messages direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was disabled\000"
/* offset=4372992 */ "unc_m2m_direct2upi_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to the Intel UPI. Unit: uncore_m2m \000event=0x19,umask=0x7\000\00001\000Counts the number of times egress did D2K (Direct to KTI)\000"
/* offset=4373188 */ "unc_m2m_direct2upi_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to the Intel(R) UPI. Unit: uncore_m2m \000event=0x26\000\00001\000Counts when messages were sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA)\000"
/* offset=4373417 */ "unc_m2m_direct2upi_txn_override.cisgress\000uncore_m2m\000uncore interconnect\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=4373593 */ "unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x3\000\00001\000\000"
/* offset=4373770 */ "unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2m \000event=0x29\000\00001\000Clockticks of the mesh to PCI (M2P)\000"
/* offset=4373972 */ "unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel(R) UPI was overridden. Unit: uncore_m2m \000event=0x29\000\00001\000Counts when a read message that was sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was overridden\000"
/* offset=4374264 */ "unc_m2m_direct2upitxn_override.pmm_hit\000uncore_m2m\000uncore interconnect\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000Number of times a direct to UPI transaction was overridden. : Counts the number of times D2K wasn't honored even though the incoming request had d2k set\000"
/* offset=4374590 */ "unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x1d,umask=0x80\000\00001\000\000"
/* offset=4374741 */ "unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x80\000\00001\000\000"
/* offset=4374892 */ "unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x80\000\00001\000\000"
/* offset=4375042 */ "unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x1d,umask=0x10\000\00001\000\000"
/* offset=4375193 */ "unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x10\000\00001\000\000"
/* offset=4375344 */ "unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x10\000\00001\000\000"
/* offset=4375494 */ "unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x1d,umask=0x40\000\00001\000\000"
/* offset=4375645 */ "unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x40\000\00001\000\000"
/* offset=4375796 */ "unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x40\000\00001\000\000"
/* offset=4375946 */ "unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x1d,umask=0x20\000\00001\000\000"
/* offset=4376097 */ "unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x20\000\00001\000\000"
/* offset=4376248 */ "unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x20\000\00001\000\000"
/* offset=4376398 */ "unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2m \000event=0x1d,umask=0x8\000\00001\000\000"
/* offset=4376545 */ "unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x8\000\00001\000\000"
/* offset=4376692 */ "unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x8\000\00001\000\000"
/* offset=4376838 */ "unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=4376985 */ "unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x1\000\00001\000\000"
/* offset=4377132 */ "unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x1\000\00001\000\000"
/* offset=4377278 */ "unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2m \000event=0x1d,umask=0x4\000\00001\000\000"
/* offset=4377425 */ "unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x4\000\00001\000\000"
/* offset=4377572 */ "unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x4\000\00001\000\000"
/* offset=4377718 */ "unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=4377865 */ "unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x2\000\00001\000\000"
/* offset=4378012 */ "unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x2\000\00001\000\000"
/* offset=4378158 */ "unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in any state. Unit: uncore_m2m \000event=0x2d,umask=0x1\000\00001\000\000"
/* offset=4378325 */ "unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000Counts the number of hit data returns to egress with any directory to non persistent memory\000"
/* offset=4378580 */ "unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2m \000event=0x2d,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in Any State (A, I, S or unused)\000"
/* offset=4378899 */ "unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in A state. Unit: uncore_m2m \000event=0x2d,umask=0x8\000\00001\000\000"
/* offset=4379068 */ "unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2m \000event=0x20,umask=0x8\000\00001\000Counts the number of hit data returns to egress with directory A to non persistent memory\000"
/* offset=4379336 */ "unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2m \000event=0x2d,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in the A (SnoopAll) state, indicating the cacheline is stored in another socket in any state, and we must snoop the other sockets to make sure we get the latest data.  The data may be stored in any state in the local socket\000"
/* offset=4379861 */ "unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in I state. Unit: uncore_m2m \000event=0x2d,umask=0x2\000\00001\000\000"
/* offset=4380030 */ "unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000Counts the number of hit data returns to egress with directory I to non persistent memory\000"
/* offset=4380297 */ "unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2m \000event=0x2d,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the I (Invalid) state indicating the cacheline is not stored in another socket, and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000"
/* offset=4380810 */ "unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in S state. Unit: uncore_m2m \000event=0x2d,umask=0x4\000\00001\000\000"
/* offset=4380979 */ "unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2m \000event=0x20,umask=0x4\000\00001\000Counts the number of hit data returns to egress with directory S to non persistent memory\000"
/* offset=4381246 */ "unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2m \000event=0x2d,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the S (Shared) state indicating the cacheline is either stored in another socket in the S(hared) state , and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000"
/* offset=4381784 */ "unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x1e,umask=0x80\000\00001\000\000"
/* offset=4381937 */ "unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x80\000\00001\000\000"
/* offset=4382090 */ "unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x80\000\00001\000\000"
/* offset=4382242 */ "unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x1e,umask=0x10\000\00001\000\000"
/* offset=4382395 */ "unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x10\000\00001\000\000"
/* offset=4382548 */ "unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x10\000\00001\000\000"
/* offset=4382700 */ "unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x1e,umask=0x40\000\00001\000\000"
/* offset=4382853 */ "unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x40\000\00001\000\000"
/* offset=4383006 */ "unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x40\000\00001\000\000"
/* offset=4383158 */ "unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x1e,umask=0x20\000\00001\000\000"
/* offset=4383311 */ "unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x20\000\00001\000\000"
/* offset=4383464 */ "unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x20\000\00001\000\000"
/* offset=4383616 */ "unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2m \000event=0x1e,umask=0x8\000\00001\000\000"
/* offset=4383765 */ "unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x8\000\00001\000\000"
/* offset=4383914 */ "unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x8\000\00001\000\000"
/* offset=4384062 */ "unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2m \000event=0x1e,umask=0x1\000\00001\000\000"
/* offset=4384211 */ "unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x1\000\00001\000\000"
/* offset=4384360 */ "unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x1\000\00001\000\000"
/* offset=4384508 */ "unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2m \000event=0x1e,umask=0x4\000\00001\000\000"
/* offset=4384657 */ "unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x4\000\00001\000\000"
/* offset=4384806 */ "unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x4\000\00001\000\000"
/* offset=4384954 */ "unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2m \000event=0x1e,umask=0x2\000\00001\000\000"
/* offset=4385103 */ "unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x2\000\00001\000\000"
/* offset=4385252 */ "unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x2\000\00001\000\000"
/* offset=4385400 */ "unc_m2m_directory_update.a2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2m \000event=0x21,umask=0x320\000\00001\000\000"
/* offset=4385559 */ "unc_m2m_directory_update.a2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2m \000event=0x2e,umask=0x20\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to I (Invalid)\000"
/* offset=4385837 */ "unc_m2m_directory_update.a2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2m \000event=0x21,umask=0x340\000\00001\000\000"
/* offset=4385996 */ "unc_m2m_directory_update.a2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2m \000event=0x2e,umask=0x40\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to S (Shared)\000"
/* offset=4386273 */ "unc_m2m_directory_update.a_to_i_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x120\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to I to non persistent memory (DRAM or HBM)\000"
/* offset=4386560 */ "unc_m2m_directory_update.a_to_i_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x220\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to I to non persistent memory (DRAM or HBM)\000"
/* offset=4386842 */ "unc_m2m_directory_update.a_to_s_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x140\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to S to non persistent memory (DRAM or HBM)\000"
/* offset=4387129 */ "unc_m2m_directory_update.a_to_s_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x240\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to S to non persistent memory (DRAM or HBM)\000"
/* offset=4387411 */ "unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates : From/to any state. Note: event counts are incorrect in 2LM mode. Unit: uncore_m2m \000event=0x2e,umask=0x1\000\00001\000\000"
/* offset=4387623 */ "unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2m \000event=0x21,umask=0x301\000\00001\000\000"
/* offset=4387788 */ "unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2m \000event=0x2e,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory to a new state\000"
/* offset=4388047 */ "unc_m2m_directory_update.hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x101\000\00001\000Counts any 1lm or 2lm hit data return that would result in directory update to non persistent memory (DRAM or HBM)\000"
/* offset=4388317 */ "unc_m2m_directory_update.i2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2m \000event=0x21,umask=0x304\000\00001\000\000"
/* offset=4388476 */ "unc_m2m_directory_update.i2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2m \000event=0x2e,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to A (SnoopAll)\000"
/* offset=4388753 */ "unc_m2m_directory_update.i2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2m \000event=0x21,umask=0x302\000\00001\000\000"
/* offset=4388912 */ "unc_m2m_directory_update.i2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2m \000event=0x2e,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to S (Shared)\000"
/* offset=4389187 */ "unc_m2m_directory_update.i_to_a_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x104\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to A to non persistent memory (DRAM or HBM)\000"
/* offset=4389474 */ "unc_m2m_directory_update.i_to_a_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x204\000\00001\000Counts 2lm miss  data returns that would result in directory update from I to A to non persistent memory (DRAM or HBM)\000"
/* offset=4389756 */ "unc_m2m_directory_update.i_to_s_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x102\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to S to non persistent memory (DRAM or HBM)\000"
/* offset=4390043 */ "unc_m2m_directory_update.i_to_s_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x202\000\00001\000Counts  2lm miss  data returns that would result in directory update from I to S to non persistent memory (DRAM or HBM)\000"
/* offset=4390326 */ "unc_m2m_directory_update.miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x201\000\00001\000Counts any 2lm miss data return that would result in directory update to non persistent memory (DRAM or HBM)\000"
/* offset=4390591 */ "unc_m2m_directory_update.s2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2m \000event=0x21,umask=0x310\000\00001\000\000"
/* offset=4390750 */ "unc_m2m_directory_update.s2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2m \000event=0x2e,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to A (SnoopAll)\000"
/* offset=4391027 */ "unc_m2m_directory_update.s2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2m \000event=0x21,umask=0x308\000\00001\000\000"
/* offset=4391186 */ "unc_m2m_directory_update.s2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2m \000event=0x2e,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to I (Invalid)\000"
/* offset=4391461 */ "unc_m2m_directory_update.s_to_a_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x110\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to A to non persistent memory (DRAM or HBM)\000"
/* offset=4391748 */ "unc_m2m_directory_update.s_to_a_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x210\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to A to non persistent memory (DRAM or HBM)\000"
/* offset=4392030 */ "unc_m2m_directory_update.s_to_i_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x108\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to I to non persistent memory (DRAM or HBM)\000"
/* offset=4392317 */ "unc_m2m_directory_update.s_to_i_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x208\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to I to non persistent memory (DRAM or HBM)\000"
/* offset=4392599 */ "unc_m2m_distress_asserted.dpt_local\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Local. Unit: uncore_m2m \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000"
/* offset=4392925 */ "unc_m2m_distress_asserted.dpt_nonlocal\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Remote. Unit: uncore_m2m \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000"
/* offset=4393255 */ "unc_m2m_distress_asserted.dpt_stall_iv\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2m \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000"
/* offset=4393622 */ "unc_m2m_distress_asserted.dpt_stall_nocrd\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2m \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000"
/* offset=4394002 */ "unc_m2m_distress_asserted.horz\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Horizontal. Unit: uncore_m2m \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4394354 */ "unc_m2m_distress_asserted.pmm_local\000uncore_m2m\000uncore interconnect\000Distress signal asserted : PMM Local. Unit: uncore_m2m \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4394728 */ "unc_m2m_distress_asserted.pmm_nonlocal\000uncore_m2m\000uncore interconnect\000Distress signal asserted : PMM Remote. Unit: uncore_m2m \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4395111 */ "unc_m2m_distress_asserted.vert\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Vertical. Unit: uncore_m2m \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4395459 */ "unc_m2m_distress_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_DISTRESS_PMM. Unit: uncore_m2m \000event=0xf2\000\00001\000\000"
/* offset=4395567 */ "unc_m2m_distress_pmm_memmode\000uncore_m2m\000uncore interconnect\000UNC_M2M_DISTRESS_PMM_MEMMODE. Unit: uncore_m2m \000event=0xf1\000\00001\000\000"
/* offset=4395691 */ "unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2m \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4396003 */ "unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2m \000event=0xba,umask=0x80000004\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4396322 */ "unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m2m \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4396579 */ "unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2m \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4396887 */ "unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2m \000event=0xba,umask=0x80000001\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4397202 */ "unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m2m \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4397457 */ "unc_m2m_fast_asserted.horz\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=4397724 */ "unc_m2m_fast_asserted.vert\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=4397989 */ "unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4398916 */ "unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4399798 */ "unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4400722 */ "unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4401602 */ "unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4402532 */ "unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4403416 */ "unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4404343 */ "unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4405225 */ "unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4406150 */ "unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4407030 */ "unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4407952 */ "unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4408830 */ "unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4409758 */ "unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4410640 */ "unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4411565 */ "unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4412445 */ "unc_m2m_horz_ring_akc_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4413379 */ "unc_m2m_horz_ring_akc_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4414310 */ "unc_m2m_horz_ring_akc_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4415247 */ "unc_m2m_horz_ring_akc_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4416181 */ "unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2m \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4417107 */ "unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4417988 */ "unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4418911 */ "unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4419790 */ "unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2m \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4420719 */ "unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4421602 */ "unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4422528 */ "unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4423409 */ "unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Left. Unit: uncore_m2m \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4424009 */ "unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4424573 */ "unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Right. Unit: uncore_m2m \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4425176 */ "unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4425742 */ "unc_m2m_igr_starve_winner.mask7\000uncore_m2m\000uncore interconnect\000Count when Starve Glocab counter is at 7. Unit: uncore_m2m \000event=0x44,umask=0x80\000\00001\000\000"
/* offset=4425892 */ "unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x704\000\00001\000\000"
/* offset=4426062 */ "unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000Reads to iMC issued. Unit: uncore_m2m \000event=0x24,umask=0x304\000\00001\000\000"
/* offset=4426182 */ "unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000Reads to iMC issued. Unit: uncore_m2m \000event=0x37,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller)\000"
/* offset=4426380 */ "unc_m2m_imc_reads.ch0.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x108\000\00001\000\000"
/* offset=4426520 */ "unc_m2m_imc_reads.ch0.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0.TO_NMCache. Unit: uncore_m2m \000event=0x24,umask=0x110\000\00001\000\000"
/* offset=4426664 */ "unc_m2m_imc_reads.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x104\000\00001\000\000"
/* offset=4426829 */ "unc_m2m_imc_reads.ch0_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_ALL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000\000"
/* offset=4426997 */ "unc_m2m_imc_reads.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x140\000\00001\000\000"
/* offset=4427147 */ "unc_m2m_imc_reads.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x140\000\00001\000\000"
/* offset=4427287 */ "unc_m2m_imc_reads.ch0_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x102\000\00001\000\000"
/* offset=4427443 */ "unc_m2m_imc_reads.ch0_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x102\000\00001\000\000"
/* offset=4427577 */ "unc_m2m_imc_reads.ch0_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x101\000\00001\000\000"
/* offset=4427732 */ "unc_m2m_imc_reads.ch0_normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_NORMAL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000\000"
/* offset=4427906 */ "unc_m2m_imc_reads.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x110\000\00001\000\000"
/* offset=4428075 */ "unc_m2m_imc_reads.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x110\000\00001\000\000"
/* offset=4428229 */ "unc_m2m_imc_reads.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x108\000\00001\000\000"
/* offset=4428379 */ "unc_m2m_imc_reads.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x108\000\00001\000\000"
/* offset=4428529 */ "unc_m2m_imc_reads.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x120\000\00001\000M2M Reads Issued to iMC : PMM - Ch0 : Counts all PMM dimm read requests(full line) sent from M2M to iMC\000"
/* offset=4428775 */ "unc_m2m_imc_reads.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_PMM. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x120\000\00001\000\000"
/* offset=4428949 */ "unc_m2m_imc_reads.ch1.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x208\000\00001\000\000"
/* offset=4429089 */ "unc_m2m_imc_reads.ch1.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1.TO_NMCache. Unit: uncore_m2m \000event=0x24,umask=0x210\000\00001\000\000"
/* offset=4429233 */ "unc_m2m_imc_reads.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x204\000\00001\000\000"
/* offset=4429398 */ "unc_m2m_imc_reads.ch1_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_ALL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000\000"
/* offset=4429566 */ "unc_m2m_imc_reads.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x240\000\00001\000\000"
/* offset=4429716 */ "unc_m2m_imc_reads.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x240\000\00001\000\000"
/* offset=4429856 */ "unc_m2m_imc_reads.ch1_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x202\000\00001\000\000"
/* offset=4430012 */ "unc_m2m_imc_reads.ch1_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x202\000\00001\000\000"
/* offset=4430146 */ "unc_m2m_imc_reads.ch1_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x201\000\00001\000\000"
/* offset=4430301 */ "unc_m2m_imc_reads.ch1_normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_NORMAL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000\000"
/* offset=4430475 */ "unc_m2m_imc_reads.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x210\000\00001\000\000"
/* offset=4430644 */ "unc_m2m_imc_reads.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x210\000\00001\000\000"
/* offset=4430798 */ "unc_m2m_imc_reads.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x208\000\00001\000\000"
/* offset=4430948 */ "unc_m2m_imc_reads.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x208\000\00001\000\000"
/* offset=4431098 */ "unc_m2m_imc_reads.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x220\000\00001\000M2M Reads Issued to iMC : PMM - Ch1 : Counts all PMM dimm read requests(full line) sent from M2M to iMC\000"
/* offset=4431344 */ "unc_m2m_imc_reads.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_PMM. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x220\000\00001\000\000"
/* offset=4431518 */ "unc_m2m_imc_reads.ch2_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch2. Unit: uncore_m2m \000event=0x37,umask=0x440\000\00001\000\000"
/* offset=4431668 */ "unc_m2m_imc_reads.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x740\000\00001\000\000"
/* offset=4431823 */ "unc_m2m_imc_reads.from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x340\000\00001\000\000"
/* offset=4431955 */ "unc_m2m_imc_reads.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x37,umask=0x10\000\00001\000\000"
/* offset=4432119 */ "unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x702\000\00001\000\000"
/* offset=4432280 */ "unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; Critical Priority. Unit: uncore_m2m \000event=0x37,umask=0x2\000\00001\000\000"
/* offset=4432423 */ "unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x302\000\00001\000\000"
/* offset=4432549 */ "unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x701\000\00001\000\000"
/* offset=4432709 */ "unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000Reads to iMC issued at Normal Priority (Non-Isochronous). Unit: uncore_m2m \000event=0x37,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller).  It only counts  normal priority non-isochronous reads\000"
/* offset=4433003 */ "unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.NORMAL. Unit: uncore_m2m \000event=0x24,umask=0x301\000\00001\000\000"
/* offset=4433131 */ "unc_m2m_imc_reads.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x710\000\00001\000\000"
/* offset=4433305 */ "unc_m2m_imc_reads.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x310\000\00001\000\000"
/* offset=4433451 */ "unc_m2m_imc_reads.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x708\000\00001\000\000"
/* offset=4433606 */ "unc_m2m_imc_reads.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x308\000\00001\000\000"
/* offset=4433748 */ "unc_m2m_imc_reads.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x308\000\00001\000\000"
/* offset=4433880 */ "unc_m2m_imc_reads.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_NMCACHE. Unit: uncore_m2m \000event=0x24,umask=0x310\000\00001\000\000"
/* offset=4434016 */ "unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x720\000\00001\000\000"
/* offset=4434164 */ "unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000Read requests to Intel(R) Optane(TM) DC persistent memory issued to the iMC from M2M. Unit: uncore_m2m \000event=0x37,umask=0x8\000\00001\000M2M Reads Issued to iMC; All, regardless of priority\000"
/* offset=4434402 */ "unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_PMM. Unit: uncore_m2m \000event=0x24,umask=0x320\000\00001\000\000"
/* offset=4434530 */ "unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000All Writes - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1810\000\00001\000\000"
/* offset=4434658 */ "unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c10\000\00001\000\000"
/* offset=4434813 */ "unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000Writes to iMC issued. Unit: uncore_m2m \000event=0x38,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) issues writes to the iMC (Memory Controller)\000"
/* offset=4435015 */ "unc_m2m_imc_writes.ch0.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4435127 */ "unc_m2m_imc_writes.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x410\000\00001\000\000"
/* offset=4435276 */ "unc_m2m_imc_writes.ch0_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_ALL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x810\000\00001\000\000"
/* offset=4435446 */ "unc_m2m_imc_writes.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4435559 */ "unc_m2m_imc_writes.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4435699 */ "unc_m2m_imc_writes.ch0_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x401\000\00001\000\000"
/* offset=4435858 */ "unc_m2m_imc_writes.ch0_full\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_FULL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x801\000\00001\000\000"
/* offset=4436030 */ "unc_m2m_imc_writes.ch0_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x404\000\00001\000\000"
/* offset=4436191 */ "unc_m2m_imc_writes.ch0_full_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_FULL_ISOCH. Unit: uncore_m2m \000event=0x25,umask=0x804\000\00001\000\000"
/* offset=4436337 */ "unc_m2m_imc_writes.ch0_ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4436476 */ "unc_m2m_imc_writes.ch0_ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4436588 */ "unc_m2m_imc_writes.ch0_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4436737 */ "unc_m2m_imc_writes.ch0_ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4436859 */ "unc_m2m_imc_writes.ch0_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x402\000\00001\000\000"
/* offset=4437019 */ "unc_m2m_imc_writes.ch0_partial\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_PARTIAL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x802\000\00001\000\000"
/* offset=4437197 */ "unc_m2m_imc_writes.ch0_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x408\000\00001\000\000"
/* offset=4437359 */ "unc_m2m_imc_writes.ch0_partial_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_PARTIAL_ISOCH. Unit: uncore_m2m \000event=0x25,umask=0x808\000\00001\000\000"
/* offset=4437511 */ "unc_m2m_imc_writes.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x25,umask=0x840\000\00001\000\000"
/* offset=4437655 */ "unc_m2m_imc_writes.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x440\000\00001\000\000"
/* offset=4437826 */ "unc_m2m_imc_writes.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x420\000\00001\000\000"
/* offset=4437978 */ "unc_m2m_imc_writes.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x25,umask=0x820\000\00001\000\000"
/* offset=4438130 */ "unc_m2m_imc_writes.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x480\000\00001\000M2M Writes Issued to iMC : PMM - Ch0 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000"
/* offset=4438393 */ "unc_m2m_imc_writes.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000PMM - Ch0. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x880\000\00001\000PMM - Ch0 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000"
/* offset=4438640 */ "unc_m2m_imc_writes.ch1.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4438752 */ "unc_m2m_imc_writes.ch1_all\000uncore_m2m\000uncore interconnect\000All Writes - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1010\000\00001\000\000"
/* offset=4438913 */ "unc_m2m_imc_writes.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x810\000\00001\000\000"
/* offset=4439062 */ "unc_m2m_imc_writes.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4439175 */ "unc_m2m_imc_writes.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4439315 */ "unc_m2m_imc_writes.ch1_full\000uncore_m2m\000uncore interconnect\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1001\000\00001\000\000"
/* offset=4439486 */ "unc_m2m_imc_writes.ch1_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x801\000\00001\000\000"
/* offset=4439645 */ "unc_m2m_imc_writes.ch1_full_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Full Line - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1004\000\00001\000\000"
/* offset=4439780 */ "unc_m2m_imc_writes.ch1_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x804\000\00001\000\000"
/* offset=4439941 */ "unc_m2m_imc_writes.ch1_ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4440080 */ "unc_m2m_imc_writes.ch1_ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4440192 */ "unc_m2m_imc_writes.ch1_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4440341 */ "unc_m2m_imc_writes.ch1_ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4440463 */ "unc_m2m_imc_writes.ch1_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x802\000\00001\000\000"
/* offset=4440623 */ "unc_m2m_imc_writes.ch1_partial\000uncore_m2m\000uncore interconnect\000Partial Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1002\000\00001\000\000"
/* offset=4440795 */ "unc_m2m_imc_writes.ch1_partial_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Partial - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1008\000\00001\000\000"
/* offset=4440931 */ "unc_m2m_imc_writes.ch1_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x808\000\00001\000\000"
/* offset=4441093 */ "unc_m2m_imc_writes.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1040\000\00001\000\000"
/* offset=4441238 */ "unc_m2m_imc_writes.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x840\000\00001\000\000"
/* offset=4441409 */ "unc_m2m_imc_writes.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000DDR - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1020\000\00001\000\000"
/* offset=4441535 */ "unc_m2m_imc_writes.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x820\000\00001\000\000"
/* offset=4441687 */ "unc_m2m_imc_writes.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x880\000\00001\000M2M Writes Issued to iMC : PMM - Ch1 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000"
/* offset=4441950 */ "unc_m2m_imc_writes.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000PMM - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1080\000\00001\000PMM - Ch1 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000"
/* offset=4442198 */ "unc_m2m_imc_writes.from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4442316 */ "unc_m2m_imc_writes.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4442461 */ "unc_m2m_imc_writes.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x40\000\00001\000\000"
/* offset=4442627 */ "unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000Full Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1801\000\00001\000\000"
/* offset=4442760 */ "unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c01\000\00001\000\000"
/* offset=4442925 */ "unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; Full Line Non-ISOCH. Unit: uncore_m2m \000event=0x38,umask=0x1\000\00001\000\000"
/* offset=4443071 */ "unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Full Line - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1804\000\00001\000\000"
/* offset=4443211 */ "unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c04\000\00001\000\000"
/* offset=4443378 */ "unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Full Line. Unit: uncore_m2m \000event=0x38,umask=0x4\000\00001\000\000"
/* offset=4443526 */ "unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4443670 */ "unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x80\000\00001\000\000"
/* offset=4443823 */ "unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4443940 */ "unc_m2m_imc_writes.ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000"
/* offset=4444094 */ "unc_m2m_imc_writes.ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000"
/* offset=4444221 */ "unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c02\000\00001\000\000"
/* offset=4444387 */ "unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000Partial Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1802\000\00001\000\000"
/* offset=4444526 */ "unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000Partial Non-Isochronous writes to the iMC. Unit: uncore_m2m \000event=0x38,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) issues partial writes to the iMC (Memory Controller).  It only counts normal priority non-isochronous writes\000"
/* offset=4444816 */ "unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Partial - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1808\000\00001\000\000"
/* offset=4444957 */ "unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c08\000\00001\000\000"
/* offset=4445125 */ "unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Partial. Unit: uncore_m2m \000event=0x38,umask=0x8\000\00001\000\000"
/* offset=4445274 */ "unc_m2m_imc_writes.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1840\000\00001\000\000"
/* offset=4445424 */ "unc_m2m_imc_writes.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c40\000\00001\000\000"
/* offset=4445601 */ "unc_m2m_imc_writes.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000DDR - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1820\000\00001\000\000"
/* offset=4445732 */ "unc_m2m_imc_writes.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c20\000\00001\000\000"
/* offset=4445890 */ "unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c80\000\00001\000\000"
/* offset=4446041 */ "unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000PMM - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1880\000\00001\000\000"
/* offset=4446165 */ "unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000Write requests to Intel(R) Optane(TM) DC persistent memory issued to the iMC from M2M. Unit: uncore_m2m \000event=0x38,umask=0x20\000\00001\000M2M Writes Issued to iMC; All, regardless of priority\000"
/* offset=4446407 */ "unc_m2m_mirr_wrq_inserts\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts. Unit: uncore_m2m \000event=0x64\000\00001\000\000"
/* offset=4446520 */ "unc_m2m_mirr_wrq_occupancy\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x65\000\00001\000\000"
/* offset=4446637 */ "unc_m2m_misc_external.mbe_inst0\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2m \000event=0xe6,umask=0x1\000\00001\000\000"
/* offset=4446830 */ "unc_m2m_misc_external.mbe_inst1\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2m \000event=0xe6,umask=0x2\000\00001\000\000"
/* offset=4447023 */ "unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=4447160 */ "unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=4447296 */ "unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=4447437 */ "unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=4447577 */ "unc_m2m_pmm_rpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x4f,umask=0x1\000\00001\000\000"
/* offset=4447744 */ "unc_m2m_pmm_rpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x4f,umask=0x2\000\00001\000\000"
/* offset=4447911 */ "unc_m2m_pmm_rpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x4f,umask=0x4\000\00001\000\000"
/* offset=4448078 */ "unc_m2m_pmm_wpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x51,umask=0x1\000\00001\000\000"
/* offset=4448245 */ "unc_m2m_pmm_wpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x51,umask=0x2\000\00001\000\000"
/* offset=4448412 */ "unc_m2m_pmm_wpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x51,umask=0x4\000\00001\000\000"
/* offset=4448579 */ "unc_m2m_prefcam_cis_drops\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_CIS_DROPS. Unit: uncore_m2m \000event=0x5c\000\00001\000\000"
/* offset=4448697 */ "unc_m2m_prefcam_cis_drops\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_CIS_DROPS. Unit: uncore_m2m \000event=0x73\000\00001\000\000"
/* offset=4448815 */ "unc_m2m_prefcam_cycles_full.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : All Channels. Unit: uncore_m2m \000event=0x6b,umask=0x7\000\00001\000\000"
/* offset=4448965 */ "unc_m2m_prefcam_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000"
/* offset=4449110 */ "unc_m2m_prefcam_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000"
/* offset=4449255 */ "unc_m2m_prefcam_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x6b,umask=0x4\000\00001\000\000"
/* offset=4449400 */ "unc_m2m_prefcam_cycles_full\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full. Unit: uncore_m2m \000event=0x53\000\00001\000\000"
/* offset=4449519 */ "unc_m2m_prefcam_cycles_ne.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : All Channels. Unit: uncore_m2m \000event=0x6c,umask=0x7\000\00001\000\000"
/* offset=4449672 */ "unc_m2m_prefcam_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x6c,umask=0x1\000\00001\000\000"
/* offset=4449820 */ "unc_m2m_prefcam_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x6c,umask=0x2\000\00001\000\000"
/* offset=4449968 */ "unc_m2m_prefcam_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x6c,umask=0x4\000\00001\000\000"
/* offset=4450116 */ "unc_m2m_prefcam_cycles_ne\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty. Unit: uncore_m2m \000event=0x54\000\00001\000\000"
/* offset=4450238 */ "unc_m2m_prefcam_deallocs.ch0_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x1\000\00001\000\000"
/* offset=4450377 */ "unc_m2m_prefcam_deallocs.ch0_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x2\000\00001\000\000"
/* offset=4450516 */ "unc_m2m_prefcam_deallocs.ch0_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x4\000\00001\000\000"
/* offset=4450654 */ "unc_m2m_prefcam_deallocs.ch0_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x8\000\00001\000\000"
/* offset=4450793 */ "unc_m2m_prefcam_deallocs.ch1_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x10\000\00001\000\000"
/* offset=4450933 */ "unc_m2m_prefcam_deallocs.ch1_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x20\000\00001\000\000"
/* offset=4451073 */ "unc_m2m_prefcam_deallocs.ch1_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x40\000\00001\000\000"
/* offset=4451212 */ "unc_m2m_prefcam_deallocs.ch1_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x80\000\00001\000\000"
/* offset=4451352 */ "unc_m2m_prefcam_deallocs.ch2_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000"
/* offset=4451481 */ "unc_m2m_prefcam_deallocs.ch2_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000"
/* offset=4451610 */ "unc_m2m_prefcam_deallocs.ch2_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000"
/* offset=4451738 */ "unc_m2m_prefcam_deallocs.ch2_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000"
/* offset=4451867 */ "unc_m2m_prefcam_demand_drops.ch0_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 0. Unit: uncore_m2m \000event=0x6f,umask=0x2\000\00001\000\000"
/* offset=4452017 */ "unc_m2m_prefcam_demand_drops.ch0_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x2\000\00001\000\000"
/* offset=4452154 */ "unc_m2m_prefcam_demand_drops.ch0_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 0. Unit: uncore_m2m \000event=0x6f,umask=0x1\000\00001\000\000"
/* offset=4452304 */ "unc_m2m_prefcam_demand_drops.ch0_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x1\000\00001\000\000"
/* offset=4452441 */ "unc_m2m_prefcam_demand_drops.ch1_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 1. Unit: uncore_m2m \000event=0x6f,umask=0x8\000\00001\000\000"
/* offset=4452591 */ "unc_m2m_prefcam_demand_drops.ch1_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x8\000\00001\000\000"
/* offset=4452728 */ "unc_m2m_prefcam_demand_drops.ch1_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 1. Unit: uncore_m2m \000event=0x6f,umask=0x4\000\00001\000\000"
/* offset=4452878 */ "unc_m2m_prefcam_demand_drops.ch1_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x4\000\00001\000\000"
/* offset=4453015 */ "unc_m2m_prefcam_demand_drops.ch2_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 2. Unit: uncore_m2m \000event=0x6f,umask=0x20\000\00001\000\000"
/* offset=4453166 */ "unc_m2m_prefcam_demand_drops.ch2_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 2. Unit: uncore_m2m \000event=0x6f,umask=0x10\000\00001\000\000"
/* offset=4453317 */ "unc_m2m_prefcam_demand_drops.upi_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2m \000event=0x58,umask=0xa\000\00001\000\000"
/* offset=4453477 */ "unc_m2m_prefcam_demand_drops.upi_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2m \000event=0x6f,umask=0x2a\000\00001\000\000"
/* offset=4453638 */ "unc_m2m_prefcam_demand_drops.xpt_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - All Channels. Unit: uncore_m2m \000event=0x6f,umask=0x15\000\00001\000\000"
/* offset=4453799 */ "unc_m2m_prefcam_demand_drops.xpt_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x5\000\00001\000\000"
/* offset=4453938 */ "unc_m2m_prefcam_demand_merge.ch0_xpt\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - Ch 0. Unit: uncore_m2m \000event=0x74,umask=0x1\000\00001\000\000"
/* offset=4454101 */ "unc_m2m_prefcam_demand_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 0. Unit: uncore_m2m \000event=0x74,umask=0x1\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 0\000"
/* offset=4454327 */ "unc_m2m_prefcam_demand_merge.ch1_xpt\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - Ch 1. Unit: uncore_m2m \000event=0x74,umask=0x4\000\00001\000\000"
/* offset=4454490 */ "unc_m2m_prefcam_demand_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x74,umask=0x4\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 1\000"
/* offset=4454716 */ "unc_m2m_prefcam_demand_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 2. Unit: uncore_m2m \000event=0x74,umask=0x10\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 2\000"
/* offset=4454943 */ "unc_m2m_prefcam_demand_merge.upi_allch\000uncore_m2m\000uncore interconnect\000: UPI - All Channels. Unit: uncore_m2m \000event=0x5d,umask=0xa\000\00001\000\000"
/* offset=4455079 */ "unc_m2m_prefcam_demand_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000: XPT - All Channels. Unit: uncore_m2m \000event=0x5d,umask=0x5\000\00001\000\000"
/* offset=4455215 */ "unc_m2m_prefcam_demand_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - All Channels. Unit: uncore_m2m \000event=0x74,umask=0x15\000\00001\000\000"
/* offset=4455389 */ "unc_m2m_prefcam_demand_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- All Channels. Unit: uncore_m2m \000event=0x74,umask=0x15\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - All Channels\000"
/* offset=4455634 */ "unc_m2m_prefcam_demand_no_merge.ch0_xpt\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - Ch 0. Unit: uncore_m2m \000event=0x75,umask=0x1\000\00001\000\000"
/* offset=4455804 */ "unc_m2m_prefcam_demand_no_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 0. Unit: uncore_m2m \000event=0x75,umask=0x1\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 0\000"
/* offset=4456041 */ "unc_m2m_prefcam_demand_no_merge.ch1_xpt\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - Ch 1. Unit: uncore_m2m \000event=0x75,umask=0x4\000\00001\000\000"
/* offset=4456211 */ "unc_m2m_prefcam_demand_no_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x75,umask=0x4\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 1\000"
/* offset=4456448 */ "unc_m2m_prefcam_demand_no_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 2. Unit: uncore_m2m \000event=0x75,umask=0x10\000\00001\000\000"
/* offset=4456628 */ "unc_m2m_prefcam_demand_no_merge.rd_merged\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x40\000\00001\000\000"
/* offset=4456788 */ "unc_m2m_prefcam_demand_no_merge.wr_merged\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x20\000\00001\000\000"
/* offset=4456948 */ "unc_m2m_prefcam_demand_no_merge.wr_squashed\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x10\000\00001\000\000"
/* offset=4457110 */ "unc_m2m_prefcam_demand_no_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - All Channels. Unit: uncore_m2m \000event=0x75,umask=0x15\000\00001\000\000"
/* offset=4457291 */ "unc_m2m_prefcam_demand_no_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - All Channels. Unit: uncore_m2m \000event=0x75,umask=0x15\000\00001\000\000"
/* offset=4457481 */ "unc_m2m_prefcam_demand_promotions\000uncore_m2m\000uncore interconnect\000Prefetch requests that got turn into a demand request. Unit: uncore_m2m \000event=0x56\000\00001\000Counts when the M2M (Mesh to Memory) promotes a outstanding request in the prefetch queue due to a subsequent demand read request that entered the M2M with the same address.  Explanatory Side Note: The Prefetch queue is made of CAM (Content Addressable Memory)\000"
/* offset=4457895 */ "unc_m2m_prefcam_drop_reasons_ch0.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x10\000\00001\000\000"
/* offset=4458056 */ "unc_m2m_prefcam_drop_reasons_ch0.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x2\000\00001\000\000"
/* offset=4458221 */ "unc_m2m_prefcam_drop_reasons_ch0.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x20\000\00001\000\000"
/* offset=4458379 */ "unc_m2m_prefcam_drop_reasons_ch0.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x40\000\00001\000\000"
/* offset=4458539 */ "unc_m2m_prefcam_drop_reasons_ch0.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x4\000\00001\000\000"
/* offset=4458697 */ "unc_m2m_prefcam_drop_reasons_ch0.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x1\000\00001\000\000"
/* offset=4458859 */ "unc_m2m_prefcam_drop_reasons_ch0.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000"
/* offset=4459006 */ "unc_m2m_prefcam_drop_reasons_ch0.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x8\000\00001\000\000"
/* offset=4459162 */ "unc_m2m_prefcam_drop_reasons_ch0.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000"
/* offset=4459310 */ "unc_m2m_prefcam_drop_reasons_ch0.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x80\000\00001\000\000"
/* offset=4459468 */ "unc_m2m_prefcam_drop_reasons_ch0.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000"
/* offset=4459616 */ "unc_m2m_prefcam_drop_reasons_ch1.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x10\000\00001\000\000"
/* offset=4459777 */ "unc_m2m_prefcam_drop_reasons_ch1.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x2\000\00001\000\000"
/* offset=4459942 */ "unc_m2m_prefcam_drop_reasons_ch1.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x20\000\00001\000\000"
/* offset=4460100 */ "unc_m2m_prefcam_drop_reasons_ch1.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x40\000\00001\000\000"
/* offset=4460260 */ "unc_m2m_prefcam_drop_reasons_ch1.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x4\000\00001\000\000"
/* offset=4460418 */ "unc_m2m_prefcam_drop_reasons_ch1.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x1\000\00001\000\000"
/* offset=4460580 */ "unc_m2m_prefcam_drop_reasons_ch1.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000"
/* offset=4460727 */ "unc_m2m_prefcam_drop_reasons_ch1.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x8\000\00001\000\000"
/* offset=4460883 */ "unc_m2m_prefcam_drop_reasons_ch1.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000"
/* offset=4461031 */ "unc_m2m_prefcam_drop_reasons_ch1.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x80\000\00001\000\000"
/* offset=4461189 */ "unc_m2m_prefcam_drop_reasons_ch1.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000"
/* offset=4461337 */ "unc_m2m_prefcam_drop_reasons_ch2.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x10\000\00001\000\000"
/* offset=4461498 */ "unc_m2m_prefcam_drop_reasons_ch2.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x2\000\00001\000\000"
/* offset=4461663 */ "unc_m2m_prefcam_drop_reasons_ch2.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x20\000\00001\000\000"
/* offset=4461821 */ "unc_m2m_prefcam_drop_reasons_ch2.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x40\000\00001\000\000"
/* offset=4461981 */ "unc_m2m_prefcam_drop_reasons_ch2.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x4\000\00001\000\000"
/* offset=4462139 */ "unc_m2m_prefcam_drop_reasons_ch2.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x1\000\00001\000\000"
/* offset=4462301 */ "unc_m2m_prefcam_drop_reasons_ch2.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000"
/* offset=4462448 */ "unc_m2m_prefcam_drop_reasons_ch2.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x8\000\00001\000\000"
/* offset=4462604 */ "unc_m2m_prefcam_drop_reasons_ch2.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000"
/* offset=4462752 */ "unc_m2m_prefcam_drop_reasons_ch2.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x80\000\00001\000\000"
/* offset=4462910 */ "unc_m2m_prefcam_drop_reasons_ch2.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000"
/* offset=4463058 */ "unc_m2m_prefcam_inserts.ch0_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2m \000event=0x56,umask=0x2\000\00001\000\000"
/* offset=4463200 */ "unc_m2m_prefcam_inserts.ch0_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2m \000event=0x6d,umask=0x2\000\00001\000\000"
/* offset=4463342 */ "unc_m2m_prefcam_inserts.ch0_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2m \000event=0x56,umask=0x1\000\00001\000\000"
/* offset=4463484 */ "unc_m2m_prefcam_inserts.ch0_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2m \000event=0x6d,umask=0x1\000\00001\000\000"
/* offset=4463626 */ "unc_m2m_prefcam_inserts.ch1_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2m \000event=0x56,umask=0x8\000\00001\000\000"
/* offset=4463768 */ "unc_m2m_prefcam_inserts.ch1_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2m \000event=0x6d,umask=0x8\000\00001\000\000"
/* offset=4463910 */ "unc_m2m_prefcam_inserts.ch1_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2m \000event=0x56,umask=0x4\000\00001\000\000"
/* offset=4464052 */ "unc_m2m_prefcam_inserts.ch1_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2m \000event=0x6d,umask=0x4\000\00001\000\000"
/* offset=4464194 */ "unc_m2m_prefcam_inserts.ch2_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 2. Unit: uncore_m2m \000event=0x6d,umask=0x20\000\00001\000\000"
/* offset=4464337 */ "unc_m2m_prefcam_inserts.ch2_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 2. Unit: uncore_m2m \000event=0x6d,umask=0x10\000\00001\000\000"
/* offset=4464480 */ "unc_m2m_prefcam_inserts.upi_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2m \000event=0x56,umask=0xa\000\00001\000\000"
/* offset=4464632 */ "unc_m2m_prefcam_inserts.upi_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2m \000event=0x6d,umask=0x2a\000\00001\000\000"
/* offset=4464785 */ "unc_m2m_prefcam_inserts.xpt_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2m \000event=0x56,umask=0x5\000\00001\000Prefetch CAM Inserts : XPT -All Channels\000"
/* offset=4464977 */ "unc_m2m_prefcam_inserts.xpt_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2m \000event=0x6d,umask=0x15\000\00001\000\000"
/* offset=4465130 */ "unc_m2m_prefcam_inserts\000uncore_m2m\000uncore interconnect\000Inserts into the Memory Controller Prefetch Queue. Unit: uncore_m2m \000event=0x57\000\00001\000Counts when the M2M (Mesh to Memory) receives a prefetch request and inserts it into its outstanding prefetch queue.  Explanatory Side Note: the prefect queue is made from CAM: Content Addressable Memory\000"
/* offset=4465473 */ "unc_m2m_prefcam_occupancy.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2m \000event=0x54,umask=0x3\000\00001\000\000"
/* offset=4465619 */ "unc_m2m_prefcam_occupancy.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2m \000event=0x6a,umask=0x7\000\00001\000\000"
/* offset=4465765 */ "unc_m2m_prefcam_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2m \000event=0x54,umask=0x1\000\00001\000\000"
/* offset=4465906 */ "unc_m2m_prefcam_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2m \000event=0x6a,umask=0x1\000\00001\000\000"
/* offset=4466047 */ "unc_m2m_prefcam_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2m \000event=0x54,umask=0x2\000\00001\000\000"
/* offset=4466188 */ "unc_m2m_prefcam_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2m \000event=0x6a,umask=0x2\000\00001\000\000"
/* offset=4466329 */ "unc_m2m_prefcam_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 2. Unit: uncore_m2m \000event=0x6a,umask=0x4\000\00001\000\000"
/* offset=4466470 */ "unc_m2m_prefcam_occupancy\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy. Unit: uncore_m2m \000event=0x55\000\00001\000\000"
/* offset=4466585 */ "unc_m2m_prefcam_resp_miss.allch\000uncore_m2m\000uncore interconnect\000: All Channels. Unit: uncore_m2m \000event=0x76,umask=0x7\000\00001\000\000"
/* offset=4466708 */ "unc_m2m_prefcam_resp_miss.allch\000uncore_m2m\000uncore interconnect\000All Channels. Unit: uncore_m2m \000event=0x5f,umask=0x3\000\00001\000\000"
/* offset=4466829 */ "unc_m2m_prefcam_resp_miss.ch0\000uncore_m2m\000uncore interconnect\000: Channel 0. Unit: uncore_m2m \000event=0x5f,umask=0x1\000\00001\000\000"
/* offset=4466947 */ "unc_m2m_prefcam_resp_miss.ch0\000uncore_m2m\000uncore interconnect\000: Channel 0. Unit: uncore_m2m \000event=0x76,umask=0x1\000\00001\000\000"
/* offset=4467065 */ "unc_m2m_prefcam_resp_miss.ch1\000uncore_m2m\000uncore interconnect\000: Channel 1. Unit: uncore_m2m \000event=0x5f,umask=0x2\000\00001\000\000"
/* offset=4467183 */ "unc_m2m_prefcam_resp_miss.ch1\000uncore_m2m\000uncore interconnect\000: Channel 1. Unit: uncore_m2m \000event=0x76,umask=0x2\000\00001\000\000"
/* offset=4467301 */ "unc_m2m_prefcam_resp_miss.ch2\000uncore_m2m\000uncore interconnect\000: Channel 2. Unit: uncore_m2m \000event=0x76,umask=0x4\000\00001\000\000"
/* offset=4467419 */ "unc_m2m_prefcam_rxc_cycles_ne\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_CYCLES_NE. Unit: uncore_m2m \000event=0x79\000\00001\000\000"
/* offset=4467545 */ "unc_m2m_prefcam_rxc_deallocs.1lm_posted\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2m \000event=0x62,umask=0x2\000\00001\000\000"
/* offset=4467701 */ "unc_m2m_prefcam_rxc_deallocs.1lm_posted\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2m \000event=0x7a,umask=0x2\000\00001\000\000"
/* offset=4467857 */ "unc_m2m_prefcam_rxc_deallocs.cis\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2m \000event=0x62,umask=0x8\000\00001\000\000"
/* offset=4467999 */ "unc_m2m_prefcam_rxc_deallocs.cis\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2m \000event=0x7a,umask=0x8\000\00001\000\000"
/* offset=4468141 */ "unc_m2m_prefcam_rxc_deallocs.pmm_memmode_accept\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.PMM_MEMMODE_ACCEPT. Unit: uncore_m2m \000event=0x62,umask=0x4\000\00001\000\000"
/* offset=4468313 */ "unc_m2m_prefcam_rxc_deallocs.pmm_memmode_accept\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.PMM_MEMMODE_ACCEPT. Unit: uncore_m2m \000event=0x7a,umask=0x4\000\00001\000\000"
/* offset=4468485 */ "unc_m2m_prefcam_rxc_deallocs.squashed\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2m \000event=0x62,umask=0x1\000\00001\000\000"
/* offset=4468637 */ "unc_m2m_prefcam_rxc_deallocs.squashed\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2m \000event=0x7a,umask=0x1\000\00001\000\000"
/* offset=4468789 */ "unc_m2m_prefcam_rxc_inserts\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_INSERTS. Unit: uncore_m2m \000event=0x78\000\00001\000\000"
/* offset=4468911 */ "unc_m2m_prefcam_rxc_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy - Prefetches. Unit: uncore_m2m \000event=0x60\000\00001\000\000"
/* offset=4469052 */ "unc_m2m_prefcam_rxc_occupancy\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_OCCUPANCY. Unit: uncore_m2m \000event=0x77\000\00001\000\000"
/* offset=4469178 */ "unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4469478 */ "unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4469724 */ "unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2m \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4470024 */ "unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4470270 */ "unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4470570 */ "unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4470816 */ "unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2m \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4471116 */ "unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4471362 */ "unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4471656 */ "unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4471898 */ "unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4472236 */ "unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4472500 */ "unc_m2m_ring_bounces_vert.akc\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. Unit: uncore_m2m \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4472785 */ "unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4473119 */ "unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4473381 */ "unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4473726 */ "unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4473993 */ "unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000\000"
/* offset=4474143 */ "unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000\000"
/* offset=4474292 */ "unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2m \000event=0xad,umask=0x2\000\00001\000\000"
/* offset=4474442 */ "unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000\000"
/* offset=4474591 */ "unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xad,umask=0x20\000\00001\000\000"
/* offset=4474771 */ "unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xa3,umask=0x20\000\00001\000\000"
/* offset=4474950 */ "unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000\000"
/* offset=4475100 */ "unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000\000"
/* offset=4475249 */ "unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2m \000event=0xad,umask=0x8\000\00001\000\000"
/* offset=4475399 */ "unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000\000"
/* offset=4475548 */ "unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000\000"
/* offset=4475696 */ "unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000\000"
/* offset=4475843 */ "unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000\000"
/* offset=4476013 */ "unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000\000"
/* offset=4476182 */ "unc_m2m_ring_sink_starved_vert.akc\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring. Unit: uncore_m2m \000event=0xab,umask=0x10\000\00001\000\000"
/* offset=4476327 */ "unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000\000"
/* offset=4476495 */ "unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000\000"
/* offset=4476662 */ "unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000\000"
/* offset=4476835 */ "unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000\000"
/* offset=4477007 */ "unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xa4\000\00001\000\000"
/* offset=4477112 */ "unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xae\000\00001\000\000"
/* offset=4477217 */ "unc_m2m_rpq_cycles_no_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00011\000\000"
/* offset=4477415 */ "unc_m2m_rpq_cycles_no_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00011\000\000"
/* offset=4477613 */ "unc_m2m_rpq_cycles_no_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00011\000\000"
/* offset=4477811 */ "unc_m2m_rpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000"
/* offset=4477976 */ "unc_m2m_rpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000"
/* offset=4478141 */ "unc_m2m_rpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x43,umask=0x4\000\00001\000\000"
/* offset=4478306 */ "unc_m2m_rpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000"
/* offset=4478472 */ "unc_m2m_rpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000"
/* offset=4478638 */ "unc_m2m_rpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00001\000\000"
/* offset=4478804 */ "unc_m2m_rpq_no_reg_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000"
/* offset=4478961 */ "unc_m2m_rpq_no_reg_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000"
/* offset=4479118 */ "unc_m2m_rpq_no_reg_crd.ch2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 2. Unit: uncore_m2m \000event=0x43,umask=0x4\000\00001\000\000"
/* offset=4479275 */ "unc_m2m_rpq_no_reg_crd_pmm.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 0. Unit: uncore_m2m \000event=0x4f,umask=0x1\000\00001\000\000"
/* offset=4479431 */ "unc_m2m_rpq_no_reg_crd_pmm.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 1. Unit: uncore_m2m \000event=0x4f,umask=0x2\000\00001\000\000"
/* offset=4479587 */ "unc_m2m_rpq_no_reg_crd_pmm.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 2. Unit: uncore_m2m \000event=0x4f,umask=0x4\000\00001\000\000"
/* offset=4479743 */ "unc_m2m_rpq_no_spec_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000"
/* offset=4479901 */ "unc_m2m_rpq_no_spec_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000"
/* offset=4480059 */ "unc_m2m_rpq_no_spec_crd.ch2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00001\000\000"
/* offset=4480217 */ "unc_m2m_rxc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x4\000\00001\000\000"
/* offset=4480336 */ "unc_m2m_rxc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x3\000\00001\000\000"
/* offset=4480458 */ "unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x2,umask=0x1\000\00001\000\000"
/* offset=4480614 */ "unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x1\000\00001\000\000"
/* offset=4480736 */ "unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Queue Inserts. Unit: uncore_m2m \000event=0x1\000\00001\000Counts when the a new entry is Received(RxC) and then added to the AD (Address Ring) Ingress Queue from the CMS (Common Mesh Stop).  This is generally used for reads, and\000"
/* offset=4481030 */ "unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x2\000\00001\000\000"
/* offset=4481152 */ "unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x3\000\00001\000\000"
/* offset=4481274 */ "unc_m2m_rxc_ad_pref_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy - Prefetches. Unit: uncore_m2m \000event=0x77\000\00001\000\000"
/* offset=4481415 */ "unc_m2m_rxc_ak_wr_cmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x5c\000\00001\000\000"
/* offset=4481534 */ "unc_m2m_rxc_bl_cycles_full\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x8\000\00001\000\000"
/* offset=4481653 */ "unc_m2m_rxc_bl_cycles_ne\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x7\000\00001\000\000"
/* offset=4481775 */ "unc_m2m_rxc_bl_inserts\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x5\000\00001\000\000"
/* offset=4481897 */ "unc_m2m_rxc_bl_occupancy\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x6\000\00001\000\000"
/* offset=4482019 */ "unc_m2m_rxr_busy_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=4482485 */ "unc_m2m_rxr_busy_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4482876 */ "unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4483321 */ "unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4483713 */ "unc_m2m_rxr_busy_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4484163 */ "unc_m2m_rxr_busy_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=4484629 */ "unc_m2m_rxr_busy_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4485020 */ "unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4485465 */ "unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4485857 */ "unc_m2m_rxr_busy_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4486307 */ "unc_m2m_rxr_bypass.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2m \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=4486560 */ "unc_m2m_rxr_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4486744 */ "unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=4486976 */ "unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4487161 */ "unc_m2m_rxr_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4487398 */ "unc_m2m_rxr_bypass.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AK. Unit: uncore_m2m \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000"
/* offset=4487603 */ "unc_m2m_rxr_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4487787 */ "unc_m2m_rxr_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4488028 */ "unc_m2m_rxr_bypass.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2m \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=4488281 */ "unc_m2m_rxr_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4488465 */ "unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=4488697 */ "unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4488882 */ "unc_m2m_rxr_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4489119 */ "unc_m2m_rxr_bypass.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : IV. Unit: uncore_m2m \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000"
/* offset=4489324 */ "unc_m2m_rxr_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=4489508 */ "unc_m2m_rxr_crd_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=4489986 */ "unc_m2m_rxr_crd_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4490388 */ "unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4490844 */ "unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4491247 */ "unc_m2m_rxr_crd_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4491708 */ "unc_m2m_rxr_crd_starved.ak\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AK. Unit: uncore_m2m \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4492137 */ "unc_m2m_rxr_crd_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4492539 */ "unc_m2m_rxr_crd_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=4493017 */ "unc_m2m_rxr_crd_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4493419 */ "unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4493875 */ "unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4494278 */ "unc_m2m_rxr_crd_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4494739 */ "unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4495194 */ "unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4495595 */ "unc_m2m_rxr_crd_starved.iv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IV. Unit: uncore_m2m \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4496024 */ "unc_m2m_rxr_crd_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4496426 */ "unc_m2m_rxr_crd_starved_1\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation. Unit: uncore_m2m \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4496834 */ "unc_m2m_rxr_inserts.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2m \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4497162 */ "unc_m2m_rxr_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4497416 */ "unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4497723 */ "unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4497978 */ "unc_m2m_rxr_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4498290 */ "unc_m2m_rxr_inserts.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AK. Unit: uncore_m2m \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4498570 */ "unc_m2m_rxr_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4498824 */ "unc_m2m_rxr_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4499140 */ "unc_m2m_rxr_inserts.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2m \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4499468 */ "unc_m2m_rxr_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4499722 */ "unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4500029 */ "unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4500284 */ "unc_m2m_rxr_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4500596 */ "unc_m2m_rxr_inserts.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : IV. Unit: uncore_m2m \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4500876 */ "unc_m2m_rxr_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4501130 */ "unc_m2m_rxr_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2m \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4501464 */ "unc_m2m_rxr_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4501726 */ "unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4502039 */ "unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4502302 */ "unc_m2m_rxr_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4502620 */ "unc_m2m_rxr_occupancy.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AK. Unit: uncore_m2m \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4502906 */ "unc_m2m_rxr_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4503168 */ "unc_m2m_rxr_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4503490 */ "unc_m2m_rxr_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2m \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4503824 */ "unc_m2m_rxr_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4504086 */ "unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4504399 */ "unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4504662 */ "unc_m2m_rxr_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4504980 */ "unc_m2m_rxr_occupancy.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : IV. Unit: uncore_m2m \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4505266 */ "unc_m2m_rxr_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4505528 */ "unc_m2m_scoreboard_ad_retry_accepts\000uncore_m2m\000uncore interconnect\000UNC_M2M_SCOREBOARD_AD_RETRY_ACCEPTS. Unit: uncore_m2m \000event=0x33\000\00001\000\000"
/* offset=4505666 */ "unc_m2m_scoreboard_ad_retry_rejects\000uncore_m2m\000uncore interconnect\000UNC_M2M_SCOREBOARD_AD_RETRY_REJECTS. Unit: uncore_m2m \000event=0x34\000\00001\000\000"
/* offset=4505804 */ "unc_m2m_scoreboard_bl_retry_accepts\000uncore_m2m\000uncore interconnect\000Retry - Mem Mirroring Mode. Unit: uncore_m2m \000event=0x35\000\00001\000\000"
/* offset=4505933 */ "unc_m2m_scoreboard_bl_retry_rejects\000uncore_m2m\000uncore interconnect\000Retry - Mem Mirroring Mode. Unit: uncore_m2m \000event=0x36\000\00001\000\000"
/* offset=4506062 */ "unc_m2m_scoreboard_rd_accepts\000uncore_m2m\000uncore interconnect\000Scoreboard Accepts. Unit: uncore_m2m \000event=0x2f\000\00001\000\000"
/* offset=4506177 */ "unc_m2m_scoreboard_rd_rejects\000uncore_m2m\000uncore interconnect\000Scoreboard Rejects. Unit: uncore_m2m \000event=0x30\000\00001\000\000"
/* offset=4506292 */ "unc_m2m_scoreboard_wr_accepts\000uncore_m2m\000uncore interconnect\000Scoreboard Accepts. Unit: uncore_m2m \000event=0x31\000\00001\000\000"
/* offset=4506407 */ "unc_m2m_scoreboard_wr_rejects\000uncore_m2m\000uncore interconnect\000Scoreboard Rejects. Unit: uncore_m2m \000event=0x32\000\00001\000\000"
/* offset=4506522 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4506880 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4507238 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4507596 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4507954 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4508313 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4508672 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4509031 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4509390 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4509748 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4510106 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4510464 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4510822 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4511181 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4511540 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4511899 */ "unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4512258 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4512616 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4512974 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4513332 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4513690 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4514049 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4514408 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4514767 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4515126 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4515484 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4515842 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4516200 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4516558 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4516917 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4517276 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4517635 */ "unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4517994 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4518355 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4518713 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4519071 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4519434 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4519794 */ "unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4520154 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4520517 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4520877 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4521237 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4521600 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4521960 */ "unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4522320 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4522614 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4522908 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4523202 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4523496 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4523791 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4524086 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4524380 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4524674 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4524968 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4525262 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4525557 */ "unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4525852 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4526146 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4526440 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4526734 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4527028 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4527323 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4527618 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4527912 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4528206 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4528500 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4528794 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4529089 */ "unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4529384 */ "unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Clean NearMem Read Hit. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000Counts clean full line read hits (reads and RFOs)\000"
/* offset=4529564 */ "unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Clean line read hits(Regular and RFO) to Near Memory(DRAM cache) in Memory Mode and regular reads to DRAM in 1LM. Unit: uncore_m2m \000event=0x2c,umask=0x1\000\00001\000Tag Hit; Read Hit from NearMem, Clean Line\000"
/* offset=4529827 */ "unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Read Hit. Unit: uncore_m2m \000event=0x2c,umask=0x1\000\00001\000Tag Hit : Clean NearMem Read Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean full line read hits (reads and RFOs)\000"
/* offset=4530123 */ "unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty NearMem Read Hit. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000Counts dirty full line read hits (reads and RFOs)\000"
/* offset=4530303 */ "unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty line read hits(Regular and RFO) to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x2\000\00001\000Tag Hit; Read Hit from NearMem, Dirty  Line\000"
/* offset=4530534 */ "unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Read Hit. Unit: uncore_m2m \000event=0x2c,umask=0x2\000\00001\000Tag Hit : Dirty NearMem Read Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty full line read hits (reads and RFOs)\000"
/* offset=4530830 */ "unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Clean line underfill read hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x4\000\00001\000Tag Hit; Underfill Rd Hit from NearMem, Clean Line\000"
/* offset=4531064 */ "unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Underfill Hit. Unit: uncore_m2m \000event=0x1f,umask=0x4\000\00001\000Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean underfill hits due to a partial write\000"
/* offset=4531334 */ "unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Underfill Hit. Unit: uncore_m2m \000event=0x2c,umask=0x4\000\00001\000Tag Hit : Clean NearMem Underfill Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean underfill hits due to a partial write\000"
/* offset=4531644 */ "unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty line underfill read hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x8\000\00001\000Tag Hit; Underfill Rd Hit from NearMem, Dirty  Line\000"
/* offset=4531879 */ "unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Underfill Hit. Unit: uncore_m2m \000event=0x1f,umask=0x8\000\00001\000Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty underfill read hits due to a partial write\000"
/* offset=4532154 */ "unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Underfill Hit. Unit: uncore_m2m \000event=0x2c,umask=0x8\000\00001\000Tag Hit : Dirty NearMem Underfill Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty underfill read hits due to a partial write\000"
/* offset=4532469 */ "unc_m2m_tag_miss\000uncore_m2m\000uncore interconnect\000Tag Miss. Unit: uncore_m2m \000event=0x61\000\00001\000\000"
/* offset=4532561 */ "unc_m2m_tag_miss\000uncore_m2m\000uncore interconnect\000UNC_M2M_TAG_MISS. Unit: uncore_m2m \000event=0x4b,umask=0x3\000\00001\000\000"
/* offset=4532671 */ "unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x2e\000\00001\000\000"
/* offset=4532786 */ "unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x41\000\00001\000\000"
/* offset=4532901 */ "unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x2f\000\00001\000\000"
/* offset=4533016 */ "unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x42\000\00001\000\000"
/* offset=4533131 */ "unc_m2m_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000"
/* offset=4533270 */ "unc_m2m_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000"
/* offset=4533409 */ "unc_m2m_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x45,umask=0x4\000\00001\000\000"
/* offset=4533548 */ "unc_m2m_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000"
/* offset=4533690 */ "unc_m2m_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000"
/* offset=4533832 */ "unc_m2m_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x46,umask=0x4\000\00001\000\000"
/* offset=4533974 */ "unc_m2m_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000"
/* offset=4534107 */ "unc_m2m_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000"
/* offset=4534240 */ "unc_m2m_tracker_full.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x45,umask=0x4\000\00001\000\000"
/* offset=4534373 */ "unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x32,umask=0x104\000\00001\000\000"
/* offset=4534507 */ "unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000"
/* offset=4534639 */ "unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000"
/* offset=4534770 */ "unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x32,umask=0x204\000\00001\000\000"
/* offset=4534904 */ "unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000"
/* offset=4535036 */ "unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000"
/* offset=4535167 */ "unc_m2m_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 2. Unit: uncore_m2m \000event=0x49,umask=0x4\000\00001\000\000"
/* offset=4535299 */ "unc_m2m_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x49,umask=0x4\000\00001\000\000"
/* offset=4535430 */ "unc_m2m_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000"
/* offset=4535566 */ "unc_m2m_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000"
/* offset=4535702 */ "unc_m2m_tracker_ne.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x46,umask=0x4\000\00001\000\000"
/* offset=4535838 */ "unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x33,umask=0x1\000\00001\000\000"
/* offset=4535974 */ "unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000"
/* offset=4536110 */ "unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000"
/* offset=4536245 */ "unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x33,umask=0x2\000\00001\000\000"
/* offset=4536381 */ "unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000"
/* offset=4536517 */ "unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000"
/* offset=4536652 */ "unc_m2m_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 2. Unit: uncore_m2m \000event=0x47,umask=0x4\000\00001\000\000"
/* offset=4536788 */ "unc_m2m_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x47,umask=0x4\000\00001\000\000"
/* offset=4536923 */ "unc_m2m_tracker_pending_occupancy\000uncore_m2m\000uncore interconnect\000Data Pending Occupancy. Unit: uncore_m2m \000event=0x48\000\00001\000\000"
/* offset=4537046 */ "unc_m2m_txc_ad_credit_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credits Occupancy. Unit: uncore_m2m \000event=0xe\000\00001\000\000"
/* offset=4537180 */ "unc_m2m_txc_ad_credits_acquired\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credit Acquired. Unit: uncore_m2m \000event=0xd\000\00001\000\000"
/* offset=4537312 */ "unc_m2m_txc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Full. Unit: uncore_m2m \000event=0xc\000\00001\000\000"
/* offset=4537428 */ "unc_m2m_txc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0xb\000\00001\000\000"
/* offset=4537547 */ "unc_m2m_txc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x9\000\00001\000\000"
/* offset=4537666 */ "unc_m2m_txc_ad_no_credit_cycles\000uncore_m2m\000uncore interconnect\000Cycles with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0xf\000\00001\000\000"
/* offset=4537805 */ "unc_m2m_txc_ad_no_credit_stalled\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0x10\000\00001\000\000"
/* offset=4537954 */ "unc_m2m_txc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0xa\000\00001\000\000"
/* offset=4538073 */ "unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000"
/* offset=4538231 */ "unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000"
/* offset=4538388 */ "unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000"
/* offset=4538535 */ "unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000"
/* offset=4538681 */ "unc_m2m_txc_ak_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1e,umask=0x1\000\00001\000\000"
/* offset=4538861 */ "unc_m2m_txc_ak_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1e,umask=0x2\000\00001\000\000"
/* offset=4539040 */ "unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=4539219 */ "unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=4539397 */ "unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=4539575 */ "unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=4539752 */ "unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000"
/* offset=4539889 */ "unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000"
/* offset=4540025 */ "unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000"
/* offset=4540188 */ "unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000"
/* offset=4540350 */ "unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000"
/* offset=4540512 */ "unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000"
/* offset=4540673 */ "unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000"
/* offset=4540807 */ "unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000"
/* offset=4540962 */ "unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000"
/* offset=4541097 */ "unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000"
/* offset=4541253 */ "unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000"
/* offset=4541388 */ "unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000"
/* offset=4541546 */ "unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000"
/* offset=4541681 */ "unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000"
/* offset=4541839 */ "unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000"
/* offset=4541974 */ "unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000"
/* offset=4542131 */ "unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000"
/* offset=4542266 */ "unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000"
/* offset=4542423 */ "unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000"
/* offset=4542563 */ "unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000"
/* offset=4542702 */ "unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000"
/* offset=4542868 */ "unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000"
/* offset=4543033 */ "unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000"
/* offset=4543198 */ "unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000"
/* offset=4543362 */ "unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000"
/* offset=4543498 */ "unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Read Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000"
/* offset=4543655 */ "unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000"
/* offset=4543792 */ "unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Compare Request. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000"
/* offset=4543952 */ "unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000"
/* offset=4544089 */ "unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000"
/* offset=4544248 */ "unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000"
/* offset=4544388 */ "unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000"
/* offset=4544527 */ "unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000"
/* offset=4544693 */ "unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000"
/* offset=4544858 */ "unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000"
/* offset=4545023 */ "unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000"
/* offset=4545187 */ "unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000"
/* offset=4545334 */ "unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Prefetch Read Cam Hit. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000"
/* offset=4545504 */ "unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000"
/* offset=4545640 */ "unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Read Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000"
/* offset=4545797 */ "unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000"
/* offset=4545934 */ "unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Compare Request. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000"
/* offset=4546094 */ "unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000"
/* offset=4546231 */ "unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000"
/* offset=4546390 */ "unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000"
/* offset=4546576 */ "unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000"
/* offset=4546761 */ "unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000"
/* offset=4546946 */ "unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000"
/* offset=4547130 */ "unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000"
/* offset=4547325 */ "unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000"
/* offset=4547519 */ "unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000"
/* offset=4547713 */ "unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000"
/* offset=4547906 */ "unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000"
/* offset=4548046 */ "unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000"
/* offset=4548185 */ "unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000"
/* offset=4548351 */ "unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000"
/* offset=4548516 */ "unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000"
/* offset=4548681 */ "unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000"
/* offset=4548845 */ "unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000"
/* offset=4548981 */ "unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Read Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000"
/* offset=4549138 */ "unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000"
/* offset=4549275 */ "unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Compare Request. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000"
/* offset=4549435 */ "unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000"
/* offset=4549572 */ "unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000"
/* offset=4549731 */ "unc_m2m_txc_ak_sideband.rd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000"
/* offset=4549862 */ "unc_m2m_txc_ak_sideband.wr\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000"
/* offset=4549993 */ "unc_m2m_txc_akc_credits\000uncore_m2m\000uncore interconnect\000AKC Credits. Unit: uncore_m2m \000event=0x5f\000\00001\000\000"
/* offset=4550095 */ "unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=4550252 */ "unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=4550408 */ "unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=4550563 */ "unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=4550717 */ "unc_m2m_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to QPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00001\000\000"
/* offset=4550870 */ "unc_m2m_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00001\000\000"
/* offset=4551022 */ "unc_m2m_txc_bl_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1a,umask=0x1\000\00001\000\000"
/* offset=4551202 */ "unc_m2m_txc_bl_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1a,umask=0x2\000\00001\000\000"
/* offset=4551381 */ "unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000"
/* offset=4551560 */ "unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000"
/* offset=4551738 */ "unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000"
/* offset=4551916 */ "unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000"
/* offset=4552093 */ "unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=4552230 */ "unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=4552366 */ "unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=4552529 */ "unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=4552691 */ "unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=4552853 */ "unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=4553014 */ "unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000"
/* offset=4553154 */ "unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000"
/* offset=4553293 */ "unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=4553459 */ "unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=4553624 */ "unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=4553789 */ "unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=4553953 */ "unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000"
/* offset=4554093 */ "unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000"
/* offset=4554232 */ "unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000"
/* offset=4554398 */ "unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000"
/* offset=4554563 */ "unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000"
/* offset=4554728 */ "unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000"
/* offset=4554892 */ "unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000"
/* offset=4555078 */ "unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000"
/* offset=4555263 */ "unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000"
/* offset=4555448 */ "unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000"
/* offset=4555632 */ "unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000"
/* offset=4555827 */ "unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000"
/* offset=4556021 */ "unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=4556215 */ "unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=4556408 */ "unc_m2m_txc_bl_occupancy.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x16,umask=0x3\000\00001\000\000"
/* offset=4556547 */ "unc_m2m_txc_bl_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x16,umask=0x1\000\00001\000\000"
/* offset=4556712 */ "unc_m2m_txc_bl_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x16,umask=0x2\000\00001\000\000"
/* offset=4556876 */ "unc_m2m_txr_horz_ads_used.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2m \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4557187 */ "unc_m2m_txr_horz_ads_used.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4557430 */ "unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4557719 */ "unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4557963 */ "unc_m2m_txr_horz_ads_used.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4558257 */ "unc_m2m_txr_horz_ads_used.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4558500 */ "unc_m2m_txr_horz_ads_used.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2m \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4558811 */ "unc_m2m_txr_horz_ads_used.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4559054 */ "unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4559343 */ "unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4559587 */ "unc_m2m_txr_horz_ads_used.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4559881 */ "unc_m2m_txr_horz_bypass.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2m \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4560188 */ "unc_m2m_txr_horz_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4560424 */ "unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4560709 */ "unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4560946 */ "unc_m2m_txr_horz_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4561236 */ "unc_m2m_txr_horz_bypass.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4561494 */ "unc_m2m_txr_horz_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4561730 */ "unc_m2m_txr_horz_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4562024 */ "unc_m2m_txr_horz_bypass.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2m \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4562331 */ "unc_m2m_txr_horz_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4562567 */ "unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4562852 */ "unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4563089 */ "unc_m2m_txr_horz_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4563379 */ "unc_m2m_txr_horz_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4563637 */ "unc_m2m_txr_horz_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4563873 */ "unc_m2m_txr_horz_cycles_full.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2m \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4564277 */ "unc_m2m_txr_horz_cycles_full.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4564594 */ "unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4564976 */ "unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4565294 */ "unc_m2m_txr_horz_cycles_full.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4565681 */ "unc_m2m_txr_horz_cycles_full.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4566036 */ "unc_m2m_txr_horz_cycles_full.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4566353 */ "unc_m2m_txr_horz_cycles_full.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4566744 */ "unc_m2m_txr_horz_cycles_full.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2m \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4567148 */ "unc_m2m_txr_horz_cycles_full.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4567465 */ "unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4567847 */ "unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4568165 */ "unc_m2m_txr_horz_cycles_full.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4568552 */ "unc_m2m_txr_horz_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4568907 */ "unc_m2m_txr_horz_cycles_full.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4569224 */ "unc_m2m_txr_horz_cycles_ne.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2m \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4569641 */ "unc_m2m_txr_horz_cycles_ne.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4569966 */ "unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4570361 */ "unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m2m \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4570687 */ "unc_m2m_txr_horz_cycles_ne.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4571087 */ "unc_m2m_txr_horz_cycles_ne.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4571455 */ "unc_m2m_txr_horz_cycles_ne.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4571780 */ "unc_m2m_txr_horz_cycles_ne.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4572184 */ "unc_m2m_txr_horz_cycles_ne.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2m \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4572601 */ "unc_m2m_txr_horz_cycles_ne.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4572926 */ "unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4573321 */ "unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m2m \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4573647 */ "unc_m2m_txr_horz_cycles_ne.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4574047 */ "unc_m2m_txr_horz_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4574415 */ "unc_m2m_txr_horz_cycles_ne.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4574740 */ "unc_m2m_txr_horz_inserts.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2m \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4575124 */ "unc_m2m_txr_horz_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4575434 */ "unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4575796 */ "unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m2m \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4576107 */ "unc_m2m_txr_horz_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4576474 */ "unc_m2m_txr_horz_inserts.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4576809 */ "unc_m2m_txr_horz_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4577119 */ "unc_m2m_txr_horz_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4577490 */ "unc_m2m_txr_horz_inserts.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2m \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4577874 */ "unc_m2m_txr_horz_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4578184 */ "unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4578546 */ "unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m2m \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4578857 */ "unc_m2m_txr_horz_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4579224 */ "unc_m2m_txr_horz_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4579559 */ "unc_m2m_txr_horz_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4579869 */ "unc_m2m_txr_horz_nack.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2m \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=4580151 */ "unc_m2m_txr_horz_nack.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4580362 */ "unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4580623 */ "unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m2m \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4580835 */ "unc_m2m_txr_horz_nack.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4581101 */ "unc_m2m_txr_horz_nack.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2m \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4581335 */ "unc_m2m_txr_horz_nack.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4581546 */ "unc_m2m_txr_horz_nack.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4581816 */ "unc_m2m_txr_horz_nack.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2m \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=4582098 */ "unc_m2m_txr_horz_nack.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4582309 */ "unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4582570 */ "unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m2m \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4582782 */ "unc_m2m_txr_horz_nack.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4583048 */ "unc_m2m_txr_horz_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2m \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4583282 */ "unc_m2m_txr_horz_nack.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4583493 */ "unc_m2m_txr_horz_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2m \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4583876 */ "unc_m2m_txr_horz_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4584183 */ "unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4584544 */ "unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4584852 */ "unc_m2m_txr_horz_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4585218 */ "unc_m2m_txr_horz_occupancy.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4585552 */ "unc_m2m_txr_horz_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4585859 */ "unc_m2m_txr_horz_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4586229 */ "unc_m2m_txr_horz_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2m \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4586612 */ "unc_m2m_txr_horz_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4586919 */ "unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4587280 */ "unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4587588 */ "unc_m2m_txr_horz_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4587954 */ "unc_m2m_txr_horz_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4588288 */ "unc_m2m_txr_horz_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4588595 */ "unc_m2m_txr_horz_starved.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=4589011 */ "unc_m2m_txr_horz_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4589341 */ "unc_m2m_txr_horz_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4589741 */ "unc_m2m_txr_horz_starved.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4590109 */ "unc_m2m_txr_horz_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4590439 */ "unc_m2m_txr_horz_starved.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4590843 */ "unc_m2m_txr_horz_starved.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=4591259 */ "unc_m2m_txr_horz_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4591589 */ "unc_m2m_txr_horz_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4591989 */ "unc_m2m_txr_horz_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4592357 */ "unc_m2m_txr_horz_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4592687 */ "unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4592967 */ "unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4593207 */ "unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4593488 */ "unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4593729 */ "unc_m2m_txr_vert_ads_used.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4593969 */ "unc_m2m_txr_vert_ads_used.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4594210 */ "unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4594490 */ "unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4594730 */ "unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4595011 */ "unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4595252 */ "unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4595522 */ "unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4595752 */ "unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4596023 */ "unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4596254 */ "unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4596524 */ "unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4596754 */ "unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4597025 */ "unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4597256 */ "unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4597526 */ "unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4597756 */ "unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4598027 */ "unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4598258 */ "unc_m2m_txr_vert_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m2m \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4598474 */ "unc_m2m_txr_vert_bypass.iv_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4598744 */ "unc_m2m_txr_vert_bypass_1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4599019 */ "unc_m2m_txr_vert_bypass_1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4599294 */ "unc_m2m_txr_vert_cycles_full.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4599739 */ "unc_m2m_txr_vert_cycles_full.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4600153 */ "unc_m2m_txr_vert_cycles_full.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4600580 */ "unc_m2m_txr_vert_cycles_full.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4600948 */ "unc_m2m_txr_vert_cycles_full.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4601391 */ "unc_m2m_txr_vert_cycles_full.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4601828 */ "unc_m2m_txr_vert_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4602229 */ "unc_m2m_txr_vert_cycles_full0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4602735 */ "unc_m2m_txr_vert_cycles_full0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4603210 */ "unc_m2m_txr_vert_cycles_full0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4603698 */ "unc_m2m_txr_vert_cycles_full0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4604127 */ "unc_m2m_txr_vert_cycles_full0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4604631 */ "unc_m2m_txr_vert_cycles_full0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4605129 */ "unc_m2m_txr_vert_cycles_full0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4605605 */ "unc_m2m_txr_vert_cycles_full1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4606114 */ "unc_m2m_txr_vert_cycles_full1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4606605 */ "unc_m2m_txr_vert_cycles_ne.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4607054 */ "unc_m2m_txr_vert_cycles_ne.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4607472 */ "unc_m2m_txr_vert_cycles_ne.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4607903 */ "unc_m2m_txr_vert_cycles_ne.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4608275 */ "unc_m2m_txr_vert_cycles_ne.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4608722 */ "unc_m2m_txr_vert_cycles_ne.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4609163 */ "unc_m2m_txr_vert_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m2m \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4609568 */ "unc_m2m_txr_vert_cycles_ne0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4610083 */ "unc_m2m_txr_vert_cycles_ne0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4610567 */ "unc_m2m_txr_vert_cycles_ne0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4611064 */ "unc_m2m_txr_vert_cycles_ne0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4611502 */ "unc_m2m_txr_vert_cycles_ne0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4612015 */ "unc_m2m_txr_vert_cycles_ne0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4612522 */ "unc_m2m_txr_vert_cycles_ne0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4613007 */ "unc_m2m_txr_vert_cycles_ne1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4613525 */ "unc_m2m_txr_vert_cycles_ne1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4614025 */ "unc_m2m_txr_vert_inserts.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4614450 */ "unc_m2m_txr_vert_inserts.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4614844 */ "unc_m2m_txr_vert_inserts.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4615251 */ "unc_m2m_txr_vert_inserts.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4615599 */ "unc_m2m_txr_vert_inserts.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4616022 */ "unc_m2m_txr_vert_inserts.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4616439 */ "unc_m2m_txr_vert_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m2m \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4616820 */ "unc_m2m_txr_vert_inserts0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4617293 */ "unc_m2m_txr_vert_inserts0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4617735 */ "unc_m2m_txr_vert_inserts0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4618190 */ "unc_m2m_txr_vert_inserts0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4618586 */ "unc_m2m_txr_vert_inserts0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4619057 */ "unc_m2m_txr_vert_inserts0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4619522 */ "unc_m2m_txr_vert_inserts0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4619965 */ "unc_m2m_txr_vert_inserts1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4620441 */ "unc_m2m_txr_vert_inserts1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4620899 */ "unc_m2m_txr_vert_nack.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4621107 */ "unc_m2m_txr_vert_nack.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4621316 */ "unc_m2m_txr_vert_nack.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4621524 */ "unc_m2m_txr_vert_nack.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4621733 */ "unc_m2m_txr_vert_nack.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4621941 */ "unc_m2m_txr_vert_nack.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4622150 */ "unc_m2m_txr_vert_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4622344 */ "unc_m2m_txr_vert_nack0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4622597 */ "unc_m2m_txr_vert_nack0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4622851 */ "unc_m2m_txr_vert_nack0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4623104 */ "unc_m2m_txr_vert_nack0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4623358 */ "unc_m2m_txr_vert_nack0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4623611 */ "unc_m2m_txr_vert_nack0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4623865 */ "unc_m2m_txr_vert_nack0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4624098 */ "unc_m2m_txr_vert_nack1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4624354 */ "unc_m2m_txr_vert_nack1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4624610 */ "unc_m2m_txr_vert_occupancy.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4625042 */ "unc_m2m_txr_vert_occupancy.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4625443 */ "unc_m2m_txr_vert_occupancy.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4625857 */ "unc_m2m_txr_vert_occupancy.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4626212 */ "unc_m2m_txr_vert_occupancy.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4626642 */ "unc_m2m_txr_vert_occupancy.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4627066 */ "unc_m2m_txr_vert_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4627454 */ "unc_m2m_txr_vert_occupancy0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4627932 */ "unc_m2m_txr_vert_occupancy0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4628379 */ "unc_m2m_txr_vert_occupancy0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4628839 */ "unc_m2m_txr_vert_occupancy0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4629240 */ "unc_m2m_txr_vert_occupancy0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4629716 */ "unc_m2m_txr_vert_occupancy0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4630186 */ "unc_m2m_txr_vert_occupancy0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4630634 */ "unc_m2m_txr_vert_occupancy1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4631115 */ "unc_m2m_txr_vert_occupancy1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4631578 */ "unc_m2m_txr_vert_starved.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4631894 */ "unc_m2m_txr_vert_starved.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4632211 */ "unc_m2m_txr_vert_starved.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4632527 */ "unc_m2m_txr_vert_starved.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4632844 */ "unc_m2m_txr_vert_starved.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4633160 */ "unc_m2m_txr_vert_starved.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4633477 */ "unc_m2m_txr_vert_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4633779 */ "unc_m2m_txr_vert_starved0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4634155 */ "unc_m2m_txr_vert_starved0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4634532 */ "unc_m2m_txr_vert_starved0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4634908 */ "unc_m2m_txr_vert_starved0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4635285 */ "unc_m2m_txr_vert_starved0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4635661 */ "unc_m2m_txr_vert_starved0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4636038 */ "unc_m2m_txr_vert_starved0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4636394 */ "unc_m2m_txr_vert_starved1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4636773 */ "unc_m2m_txr_vert_starved1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4637152 */ "unc_m2m_txr_vert_starved1.tgc\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4637527 */ "unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4638447 */ "unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4639324 */ "unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4640241 */ "unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4641116 */ "unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4642032 */ "unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4642907 */ "unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4643820 */ "unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4644693 */ "unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4645613 */ "unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4646490 */ "unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4647407 */ "unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4648282 */ "unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4649198 */ "unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4650073 */ "unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4650986 */ "unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4651859 */ "unc_m2m_vert_ring_akc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4652787 */ "unc_m2m_vert_ring_akc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4653712 */ "unc_m2m_vert_ring_akc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4654636 */ "unc_m2m_vert_ring_akc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4655557 */ "unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4656475 */ "unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4657350 */ "unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4658265 */ "unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4659138 */ "unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4660052 */ "unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4660925 */ "unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4661836 */ "unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4662707 */ "unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Down. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4663299 */ "unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4663857 */ "unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Up. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4664445 */ "unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4665001 */ "unc_m2m_vert_ring_tgc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4665929 */ "unc_m2m_vert_ring_tgc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4666854 */ "unc_m2m_vert_ring_tgc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4667778 */ "unc_m2m_vert_ring_tgc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4668699 */ "unc_m2m_wpq_cycles_no_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00011\000\000"
/* offset=4668895 */ "unc_m2m_wpq_cycles_no_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00011\000\000"
/* offset=4669091 */ "unc_m2m_wpq_cycles_no_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00011\000\000"
/* offset=4669287 */ "unc_m2m_wpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=4669450 */ "unc_m2m_wpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=4669613 */ "unc_m2m_wpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000"
/* offset=4669776 */ "unc_m2m_wpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000"
/* offset=4669940 */ "unc_m2m_wpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000"
/* offset=4670104 */ "unc_m2m_wpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000"
/* offset=4670268 */ "unc_m2m_wpq_flush.ch0\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 0. Unit: uncore_m2m \000event=0x42,umask=0x1\000\00001\000\000"
/* offset=4670388 */ "unc_m2m_wpq_flush.ch0\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 0. Unit: uncore_m2m \000event=0x58,umask=0x1\000\00001\000\000"
/* offset=4670508 */ "unc_m2m_wpq_flush.ch1\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 1. Unit: uncore_m2m \000event=0x42,umask=0x2\000\00001\000\000"
/* offset=4670628 */ "unc_m2m_wpq_flush.ch1\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 1. Unit: uncore_m2m \000event=0x58,umask=0x2\000\00001\000\000"
/* offset=4670748 */ "unc_m2m_wpq_flush.ch2\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 2. Unit: uncore_m2m \000event=0x58,umask=0x4\000\00001\000\000"
/* offset=4670868 */ "unc_m2m_wpq_no_reg_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x37,umask=0x1\000\00001\000\000"
/* offset=4671024 */ "unc_m2m_wpq_no_reg_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=4671180 */ "unc_m2m_wpq_no_reg_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x37,umask=0x2\000\00001\000\000"
/* offset=4671336 */ "unc_m2m_wpq_no_reg_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=4671492 */ "unc_m2m_wpq_no_reg_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000"
/* offset=4671648 */ "unc_m2m_wpq_no_reg_crd_pmm.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 0. Unit: uncore_m2m \000event=0x51,umask=0x1\000\00001\000\000"
/* offset=4671804 */ "unc_m2m_wpq_no_reg_crd_pmm.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 1. Unit: uncore_m2m \000event=0x51,umask=0x2\000\00001\000\000"
/* offset=4671960 */ "unc_m2m_wpq_no_reg_crd_pmm.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 2. Unit: uncore_m2m \000event=0x51,umask=0x4\000\00001\000\000"
/* offset=4672116 */ "unc_m2m_wpq_no_spec_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x38,umask=0x1\000\00001\000\000"
/* offset=4672273 */ "unc_m2m_wpq_no_spec_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000"
/* offset=4672430 */ "unc_m2m_wpq_no_spec_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x38,umask=0x2\000\00001\000\000"
/* offset=4672587 */ "unc_m2m_wpq_no_spec_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000"
/* offset=4672744 */ "unc_m2m_wpq_no_spec_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000"
/* offset=4672901 */ "unc_m2m_wr_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000"
/* offset=4673043 */ "unc_m2m_wr_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000"
/* offset=4673185 */ "unc_m2m_wr_tracker_full.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x4a,umask=0x4\000\00001\000\000"
/* offset=4673327 */ "unc_m2m_wr_tracker_full.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Mirror. Unit: uncore_m2m \000event=0x4a,umask=0x8\000\00001\000\000"
/* offset=4673467 */ "unc_m2m_wr_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=4673608 */ "unc_m2m_wr_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x56,umask=0x1\000\00001\000\000"
/* offset=4673749 */ "unc_m2m_wr_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=4673890 */ "unc_m2m_wr_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x56,umask=0x2\000\00001\000\000"
/* offset=4674031 */ "unc_m2m_wr_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 2. Unit: uncore_m2m \000event=0x56,umask=0x4\000\00001\000\000"
/* offset=4674172 */ "unc_m2m_wr_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x35,umask=0x1\000\00001\000\000"
/* offset=4674317 */ "unc_m2m_wr_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000"
/* offset=4674462 */ "unc_m2m_wr_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x35,umask=0x2\000\00001\000\000"
/* offset=4674607 */ "unc_m2m_wr_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000"
/* offset=4674752 */ "unc_m2m_wr_tracker_ne.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x4b,umask=0x4\000\00001\000\000"
/* offset=4674897 */ "unc_m2m_wr_tracker_ne.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Mirror. Unit: uncore_m2m \000event=0x35,umask=0x4\000\00001\000\000"
/* offset=4675040 */ "unc_m2m_wr_tracker_ne.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Mirror. Unit: uncore_m2m \000event=0x4b,umask=0x8\000\00001\000\000"
/* offset=4675183 */ "unc_m2m_wr_tracker_ne.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x35,umask=0x8\000\00001\000\000"
/* offset=4675324 */ "unc_m2m_wr_tracker_ne.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x10\000\00001\000\000"
/* offset=4675466 */ "unc_m2m_wr_tracker_ne.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x35,umask=0x10\000\00001\000\000"
/* offset=4675605 */ "unc_m2m_wr_tracker_ne.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x20\000\00001\000\000"
/* offset=4675744 */ "unc_m2m_wr_tracker_nonposted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=4675906 */ "unc_m2m_wr_tracker_nonposted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x63,umask=0x1\000\00001\000\000"
/* offset=4676068 */ "unc_m2m_wr_tracker_nonposted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=4676230 */ "unc_m2m_wr_tracker_nonposted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x63,umask=0x2\000\00001\000\000"
/* offset=4676392 */ "unc_m2m_wr_tracker_nonposted_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 2. Unit: uncore_m2m \000event=0x63,umask=0x4\000\00001\000\000"
/* offset=4676554 */ "unc_m2m_wr_tracker_nonposted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=4676720 */ "unc_m2m_wr_tracker_nonposted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x62,umask=0x1\000\00001\000\000"
/* offset=4676886 */ "unc_m2m_wr_tracker_nonposted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=4677052 */ "unc_m2m_wr_tracker_nonposted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x62,umask=0x2\000\00001\000\000"
/* offset=4677218 */ "unc_m2m_wr_tracker_nonposted_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 2. Unit: uncore_m2m \000event=0x62,umask=0x4\000\00001\000\000"
/* offset=4677384 */ "unc_m2m_wr_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x55,umask=0x1\000\00001\000\000"
/* offset=4677529 */ "unc_m2m_wr_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x55,umask=0x2\000\00001\000\000"
/* offset=4677674 */ "unc_m2m_wr_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 2. Unit: uncore_m2m \000event=0x55,umask=0x4\000\00001\000\000"
/* offset=4677819 */ "unc_m2m_wr_tracker_occupancy.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Mirror. Unit: uncore_m2m \000event=0x55,umask=0x8\000\00001\000\000"
/* offset=4677962 */ "unc_m2m_wr_tracker_occupancy.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x10\000\00001\000\000"
/* offset=4678104 */ "unc_m2m_wr_tracker_occupancy.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x20\000\00001\000\000"
/* offset=4678243 */ "unc_m2m_wr_tracker_posted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x48,umask=0x1\000\00001\000\000"
/* offset=4678398 */ "unc_m2m_wr_tracker_posted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x5e,umask=0x1\000\00001\000\000"
/* offset=4678553 */ "unc_m2m_wr_tracker_posted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x48,umask=0x2\000\00001\000\000"
/* offset=4678708 */ "unc_m2m_wr_tracker_posted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x5e,umask=0x2\000\00001\000\000"
/* offset=4678863 */ "unc_m2m_wr_tracker_posted_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 2. Unit: uncore_m2m \000event=0x5e,umask=0x4\000\00001\000\000"
/* offset=4679018 */ "unc_m2m_wr_tracker_posted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000"
/* offset=4679177 */ "unc_m2m_wr_tracker_posted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x5d,umask=0x1\000\00001\000\000"
/* offset=4679336 */ "unc_m2m_wr_tracker_posted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000"
/* offset=4679495 */ "unc_m2m_wr_tracker_posted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x5d,umask=0x2\000\00001\000\000"
/* offset=4679654 */ "unc_m2m_wr_tracker_posted_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 2. Unit: uncore_m2m \000event=0x5d,umask=0x4\000\00001\000\000"
/* offset=4679813 */ "unc_m2m_write_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000"
/* offset=4679964 */ "unc_m2m_write_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000"
/* offset=4680115 */ "unc_m2m_write_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x4a,umask=0x4\000\00001\000\000"
/* offset=4680266 */ "unc_m2m_write_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000"
/* offset=4680420 */ "unc_m2m_write_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000"
/* offset=4680574 */ "unc_m2m_write_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x4b,umask=0x4\000\00001\000\000"
/* offset=4680728 */ "unc_m2m_write_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x61,umask=0x1\000\00001\000\000"
/* offset=4680871 */ "unc_m2m_write_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x61,umask=0x2\000\00001\000\000"
/* offset=4681014 */ "unc_m2m_write_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x61,umask=0x4\000\00001\000\000"
/* offset=4681157 */ "unc_m2m_write_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x60,umask=0x1\000\00001\000\000"
/* offset=4681304 */ "unc_m2m_write_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x60,umask=0x2\000\00001\000\000"
/* offset=4681451 */ "unc_m2m_write_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x60,umask=0x4\000\00001\000\000"
/* offset=4681598 */ "unc_m2p_ag0_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4681880 */ "unc_m2p_ag0_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4682162 */ "unc_m2p_ag0_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4682444 */ "unc_m2p_ag0_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4682726 */ "unc_m2p_ag0_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4683009 */ "unc_m2p_ag0_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4683292 */ "unc_m2p_ag0_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4683575 */ "unc_m2p_ag0_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4683858 */ "unc_m2p_ag0_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4684143 */ "unc_m2p_ag0_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4684425 */ "unc_m2p_ag0_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4684707 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4684990 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4685273 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4685556 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4685839 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4686123 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4686407 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4686691 */ "unc_m2p_ag0_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4686975 */ "unc_m2p_ag0_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4687261 */ "unc_m2p_ag0_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4687544 */ "unc_m2p_ag0_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4687827 */ "unc_m2p_ag0_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4688109 */ "unc_m2p_ag0_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4688391 */ "unc_m2p_ag0_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4688673 */ "unc_m2p_ag0_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4688955 */ "unc_m2p_ag0_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4689238 */ "unc_m2p_ag0_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4689521 */ "unc_m2p_ag0_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4689804 */ "unc_m2p_ag0_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4690087 */ "unc_m2p_ag0_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4690372 */ "unc_m2p_ag0_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4690654 */ "unc_m2p_ag0_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4690936 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4691219 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4691502 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4691785 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4692068 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4692352 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4692636 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4692920 */ "unc_m2p_ag0_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4693204 */ "unc_m2p_ag0_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4693490 */ "unc_m2p_ag0_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4693773 */ "unc_m2p_ag0_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4694056 */ "unc_m2p_ag1_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4694338 */ "unc_m2p_ag1_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4694620 */ "unc_m2p_ag1_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4694902 */ "unc_m2p_ag1_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4695184 */ "unc_m2p_ag1_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4695467 */ "unc_m2p_ag1_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4695750 */ "unc_m2p_ag1_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4696033 */ "unc_m2p_ag1_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4696316 */ "unc_m2p_ag1_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4696601 */ "unc_m2p_ag1_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4696883 */ "unc_m2p_ag1_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4697165 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4697448 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4697731 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4698014 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4698297 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4698581 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4698865 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4699149 */ "unc_m2p_ag1_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4699433 */ "unc_m2p_ag1_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4699719 */ "unc_m2p_ag1_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4700002 */ "unc_m2p_ag1_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4700285 */ "unc_m2p_ag1_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4700567 */ "unc_m2p_ag1_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4700849 */ "unc_m2p_ag1_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4701131 */ "unc_m2p_ag1_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4701413 */ "unc_m2p_ag1_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4701696 */ "unc_m2p_ag1_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4701979 */ "unc_m2p_ag1_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4702262 */ "unc_m2p_ag1_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4702545 */ "unc_m2p_ag1_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4702830 */ "unc_m2p_ag1_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4703112 */ "unc_m2p_ag1_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4703394 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4703677 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4703960 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4704243 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4704526 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4704810 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4705094 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4705378 */ "unc_m2p_ag1_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4705662 */ "unc_m2p_ag1_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4705948 */ "unc_m2p_ag1_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4706231 */ "unc_m2p_ag1_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4706514 */ "unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000Clockticks of the mesh to PCI (M2P). Unit: uncore_m2pcie \000event=0x1\000\00001\000Clockticks of the mesh to PCI (M2P) : Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000"
/* offset=4706925 */ "unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000Clockticks of the mesh to PCI (M2P). Unit: uncore_m2pcie \000event=0x1\000\00001\000\000"
/* offset=4707041 */ "unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000M2P Clockticks. Unit: uncore_m2pcie \000event=0x1\000\00001\000Number of M2P clock cycles while the event is enabled\000"
/* offset=4707189 */ "unc_m2p_cms_clockticks\000uncore_m2pcie\000uncore io\000CMS Clockticks. Unit: uncore_m2pcie \000event=0xc0\000\00001\000\000"
/* offset=4707289 */ "unc_m2p_distress_asserted.dpt_local\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Local. Unit: uncore_m2pcie \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000"
/* offset=4707611 */ "unc_m2p_distress_asserted.dpt_nonlocal\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Remote. Unit: uncore_m2pcie \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000"
/* offset=4707937 */ "unc_m2p_distress_asserted.dpt_stall_iv\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2pcie \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000"
/* offset=4708300 */ "unc_m2p_distress_asserted.dpt_stall_nocrd\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2pcie \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000"
/* offset=4708676 */ "unc_m2p_distress_asserted.horz\000uncore_m2pcie\000uncore io\000Distress signal asserted : Horizontal. Unit: uncore_m2pcie \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4709024 */ "unc_m2p_distress_asserted.pmm_local\000uncore_m2pcie\000uncore io\000Distress signal asserted : PMM Local. Unit: uncore_m2pcie \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4709394 */ "unc_m2p_distress_asserted.pmm_nonlocal\000uncore_m2pcie\000uncore io\000Distress signal asserted : PMM Remote. Unit: uncore_m2pcie \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4709773 */ "unc_m2p_distress_asserted.vert\000uncore_m2pcie\000uncore io\000Distress signal asserted : Vertical. Unit: uncore_m2pcie \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4710117 */ "unc_m2p_egress_cycles_full.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AD_0. Unit: uncore_m2pcie \000event=0x25,umask=0x1\000\00001\000\000"
/* offset=4710316 */ "unc_m2p_egress_cycles_full.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AD_1. Unit: uncore_m2pcie \000event=0x25,umask=0x8\000\00001\000\000"
/* offset=4710515 */ "unc_m2p_egress_cycles_full.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AK_0. Unit: uncore_m2pcie \000event=0x25,umask=0x2\000\00001\000\000"
/* offset=4710714 */ "unc_m2p_egress_cycles_full.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AK_1. Unit: uncore_m2pcie \000event=0x25,umask=0x10\000\00001\000\000"
/* offset=4710914 */ "unc_m2p_egress_cycles_full.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  BL_0. Unit: uncore_m2pcie \000event=0x25,umask=0x4\000\00001\000\000"
/* offset=4711113 */ "unc_m2p_egress_cycles_full.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  BL_1. Unit: uncore_m2pcie \000event=0x25,umask=0x20\000\00001\000\000"
/* offset=4711313 */ "unc_m2p_egress_cycles_ne.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AD_0. Unit: uncore_m2pcie \000event=0x23,umask=0x1\000\00001\000\000"
/* offset=4711520 */ "unc_m2p_egress_cycles_ne.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AD_1. Unit: uncore_m2pcie \000event=0x23,umask=0x8\000\00001\000\000"
/* offset=4711727 */ "unc_m2p_egress_cycles_ne.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AK_0. Unit: uncore_m2pcie \000event=0x23,umask=0x2\000\00001\000\000"
/* offset=4711934 */ "unc_m2p_egress_cycles_ne.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AK_1. Unit: uncore_m2pcie \000event=0x23,umask=0x10\000\00001\000\000"
/* offset=4712142 */ "unc_m2p_egress_cycles_ne.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  BL_0. Unit: uncore_m2pcie \000event=0x23,umask=0x4\000\00001\000\000"
/* offset=4712349 */ "unc_m2p_egress_cycles_ne.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  BL_1. Unit: uncore_m2pcie \000event=0x23,umask=0x20\000\00001\000\000"
/* offset=4712557 */ "unc_m2p_egress_inserts.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AD_0. Unit: uncore_m2pcie \000event=0x24,umask=0x1\000\00001\000\000"
/* offset=4712771 */ "unc_m2p_egress_inserts.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AD_1. Unit: uncore_m2pcie \000event=0x24,umask=0x10\000\00001\000\000"
/* offset=4712986 */ "unc_m2p_egress_inserts.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_0. Unit: uncore_m2pcie \000event=0x24,umask=0x2\000\00001\000\000"
/* offset=4713200 */ "unc_m2p_egress_inserts.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_1. Unit: uncore_m2pcie \000event=0x24,umask=0x20\000\00001\000\000"
/* offset=4713415 */ "unc_m2p_egress_inserts.ak_crd_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_CRD_0. Unit: uncore_m2pcie \000event=0x24,umask=0x8\000\00001\000\000"
/* offset=4713637 */ "unc_m2p_egress_inserts.ak_crd_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_CRD_1. Unit: uncore_m2pcie \000event=0x24,umask=0x80\000\00001\000\000"
/* offset=4713860 */ "unc_m2p_egress_inserts.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. BL_0. Unit: uncore_m2pcie \000event=0x24,umask=0x4\000\00001\000\000"
/* offset=4714074 */ "unc_m2p_egress_inserts.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. BL_1. Unit: uncore_m2pcie \000event=0x24,umask=0x40\000\00001\000\000"
/* offset=4714289 */ "unc_m2p_egress_ordering.iv_snoopgo_dn\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2pcie \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4714597 */ "unc_m2p_egress_ordering.iv_snoopgo_up\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2pcie \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4714901 */ "unc_m2p_horz_ring_ad_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4715824 */ "unc_m2p_horz_ring_ad_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4716744 */ "unc_m2p_horz_ring_ad_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4717670 */ "unc_m2p_horz_ring_ad_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4718593 */ "unc_m2p_horz_ring_ak_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4719514 */ "unc_m2p_horz_ring_ak_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4720432 */ "unc_m2p_horz_ring_ak_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4721356 */ "unc_m2p_horz_ring_ak_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4722277 */ "unc_m2p_horz_ring_akc_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4723207 */ "unc_m2p_horz_ring_akc_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4724134 */ "unc_m2p_horz_ring_akc_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4725067 */ "unc_m2p_horz_ring_akc_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4725997 */ "unc_m2p_horz_ring_bl_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4726919 */ "unc_m2p_horz_ring_bl_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4727838 */ "unc_m2p_horz_ring_bl_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4728763 */ "unc_m2p_horz_ring_bl_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4729685 */ "unc_m2p_horz_ring_iv_in_use.left\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Left. Unit: uncore_m2pcie \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4730281 */ "unc_m2p_horz_ring_iv_in_use.right\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Right. Unit: uncore_m2pcie \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4730880 */ "unc_m2p_iio_credits_acquired.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x1\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000"
/* offset=4731581 */ "unc_m2p_iio_credits_acquired.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x2\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000"
/* offset=4732282 */ "unc_m2p_iio_credits_acquired.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x4\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000"
/* offset=4732983 */ "unc_m2p_iio_credits_acquired.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x8\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000"
/* offset=4733684 */ "unc_m2p_iio_credits_acquired.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x10\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000"
/* offset=4734386 */ "unc_m2p_iio_credits_acquired.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x20\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000"
/* offset=4735088 */ "unc_m2p_iio_credits_reject.drs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : DRS. Unit: uncore_m2pcie \000event=0x34,umask=0x8\000\00001\000M2PCIe IIO Failed to Acquire a Credit : DRS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the DRS message class\000"
/* offset=4735684 */ "unc_m2p_iio_credits_reject.ncb\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCB. Unit: uncore_m2pcie \000event=0x34,umask=0x10\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCB : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCB message class\000"
/* offset=4736281 */ "unc_m2p_iio_credits_reject.ncs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCS. Unit: uncore_m2pcie \000event=0x34,umask=0x20\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCS message class\000"
/* offset=4736878 */ "unc_m2p_iio_credits_used.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x1\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000"
/* offset=4737607 */ "unc_m2p_iio_credits_used.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x2\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000"
/* offset=4738336 */ "unc_m2p_iio_credits_used.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x4\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000"
/* offset=4739065 */ "unc_m2p_iio_credits_used.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x8\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000"
/* offset=4739794 */ "unc_m2p_iio_credits_used.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x10\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000"
/* offset=4740524 */ "unc_m2p_iio_credits_used.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x20\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000"
/* offset=4741254 */ "unc_m2p_ingress_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.ALL. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000\000"
/* offset=4741458 */ "unc_m2p_ingress_cycles_ne.cbo_idi\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_IDI. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000\000"
/* offset=4741669 */ "unc_m2p_ingress_cycles_ne.cbo_ncb\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_NCB. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000\000"
/* offset=4741880 */ "unc_m2p_ingress_cycles_ne.cbo_ncs\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_NCS. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000\000"
/* offset=4742091 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x1\000\00001\000\000"
/* offset=4742262 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x2\000\00001\000\000"
/* offset=4742433 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x4\000\00001\000\000"
/* offset=4742604 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x8\000\00001\000\000"
/* offset=4742775 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x10\000\00001\000\000"
/* offset=4742947 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x20\000\00001\000\000"
/* offset=4743119 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x40\000\00001\000\000"
/* offset=4743291 */ "unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x80\000\00001\000\000"
/* offset=4743463 */ "unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x1\000\00001\000\000"
/* offset=4743634 */ "unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x2\000\00001\000\000"
/* offset=4743805 */ "unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x4\000\00001\000\000"
/* offset=4743976 */ "unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x8\000\00001\000\000"
/* offset=4744147 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x1\000\00001\000\000"
/* offset=4744322 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x2\000\00001\000\000"
/* offset=4744497 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x4\000\00001\000\000"
/* offset=4744672 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x8\000\00001\000\000"
/* offset=4744847 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000"
/* offset=4745023 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000"
/* offset=4745199 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000"
/* offset=4745375 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x40\000\00001\000\000"
/* offset=4745551 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000"
/* offset=4745727 */ "unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x80\000\00001\000\000"
/* offset=4745903 */ "unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x1\000\00001\000\000"
/* offset=4746078 */ "unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x2\000\00001\000\000"
/* offset=4746253 */ "unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x4\000\00001\000\000"
/* offset=4746428 */ "unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x8\000\00001\000\000"
/* offset=4746603 */ "unc_m2p_local_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=4746758 */ "unc_m2p_local_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=4746913 */ "unc_m2p_local_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x17,umask=0x4\000\00001\000\000"
/* offset=4747068 */ "unc_m2p_local_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x44,umask=0x1\000\00001\000\000"
/* offset=4747241 */ "unc_m2p_local_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x44,umask=0x2\000\00001\000\000"
/* offset=4747414 */ "unc_m2p_local_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x44,umask=0x4\000\00001\000\000"
/* offset=4747587 */ "unc_m2p_local_shar_p2p_crd_returned.agent_3\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent3. Unit: uncore_m2pcie \000event=0x44,umask=0x8\000\00001\000\000"
/* offset=4747760 */ "unc_m2p_local_shar_p2p_crd_returned.agent_4\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent4. Unit: uncore_m2pcie \000event=0x44,umask=0x10\000\00001\000\000"
/* offset=4747934 */ "unc_m2p_local_shar_p2p_crd_returned.agent_5\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent5. Unit: uncore_m2pcie \000event=0x44,umask=0x20\000\00001\000\000"
/* offset=4748108 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x1\000\00001\000\000"
/* offset=4748277 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x2\000\00001\000\000"
/* offset=4748446 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x4\000\00001\000\000"
/* offset=4748615 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x8\000\00001\000\000"
/* offset=4748784 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x10\000\00001\000\000"
/* offset=4748954 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x20\000\00001\000\000"
/* offset=4749124 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x40\000\00001\000\000"
/* offset=4749294 */ "unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x80\000\00001\000\000"
/* offset=4749464 */ "unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x1\000\00001\000\000"
/* offset=4749633 */ "unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x2\000\00001\000\000"
/* offset=4749802 */ "unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x4\000\00001\000\000"
/* offset=4749971 */ "unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x8\000\00001\000\000"
/* offset=4750140 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x1\000\00001\000\000"
/* offset=4750313 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x2\000\00001\000\000"
/* offset=4750486 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x4\000\00001\000\000"
/* offset=4750659 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x8\000\00001\000\000"
/* offset=4750832 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x10\000\00001\000\000"
/* offset=4751006 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x20\000\00001\000\000"
/* offset=4751180 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x40\000\00001\000\000"
/* offset=4751354 */ "unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x80\000\00001\000\000"
/* offset=4751528 */ "unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x1\000\00001\000\000"
/* offset=4751701 */ "unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x2\000\00001\000\000"
/* offset=4751874 */ "unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x4\000\00001\000\000"
/* offset=4752047 */ "unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x8\000\00001\000\000"
/* offset=4752220 */ "unc_m2p_misc_external.mbe_inst0\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2pcie \000event=0xe6,umask=0x1\000\00001\000\000"
/* offset=4752409 */ "unc_m2p_misc_external.mbe_inst1\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2pcie \000event=0xe6,umask=0x2\000\00001\000\000"
/* offset=4752598 */ "unc_m2p_p2p_crd_occupancy.all\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : All. Unit: uncore_m2pcie \000event=0x14,umask=0x10\000\00001\000\000"
/* offset=4752728 */ "unc_m2p_p2p_crd_occupancy.local_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x1\000\00001\000\000"
/* offset=4752869 */ "unc_m2p_p2p_crd_occupancy.local_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x2\000\00001\000\000"
/* offset=4753010 */ "unc_m2p_p2p_crd_occupancy.remote_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x4\000\00001\000\000"
/* offset=4753153 */ "unc_m2p_p2p_crd_occupancy.remote_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x8\000\00001\000\000"
/* offset=4753296 */ "unc_m2p_p2p_ded_received.all\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : All. Unit: uncore_m2pcie \000event=0x16,umask=0x10\000\00001\000\000"
/* offset=4753431 */ "unc_m2p_p2p_ded_received.local_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x1\000\00001\000\000"
/* offset=4753577 */ "unc_m2p_p2p_ded_received.local_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x2\000\00001\000\000"
/* offset=4753723 */ "unc_m2p_p2p_ded_received.remote_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x4\000\00001\000\000"
/* offset=4753871 */ "unc_m2p_p2p_ded_received.remote_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x8\000\00001\000\000"
/* offset=4754019 */ "unc_m2p_p2p_shar_received.all\000uncore_m2pcie\000uncore io\000Shared Credits  Received : All. Unit: uncore_m2pcie \000event=0x15,umask=0x10\000\00001\000\000"
/* offset=4754153 */ "unc_m2p_p2p_shar_received.local_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x1\000\00001\000\000"
/* offset=4754298 */ "unc_m2p_p2p_shar_received.local_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x2\000\00001\000\000"
/* offset=4754443 */ "unc_m2p_p2p_shar_received.remote_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x4\000\00001\000\000"
/* offset=4754590 */ "unc_m2p_p2p_shar_received.remote_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x8\000\00001\000\000"
/* offset=4754737 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x1\000\00001\000\000"
/* offset=4754904 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x2\000\00001\000\000"
/* offset=4755071 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x4\000\00001\000\000"
/* offset=4755238 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x8\000\00001\000\000"
/* offset=4755405 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x10\000\00001\000\000"
/* offset=4755573 */ "unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x20\000\00001\000\000"
/* offset=4755741 */ "unc_m2p_remote_ded_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x49,umask=0x1\000\00001\000\000"
/* offset=4755908 */ "unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x49,umask=0x2\000\00001\000\000"
/* offset=4756075 */ "unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x49,umask=0x4\000\00001\000\000"
/* offset=4756242 */ "unc_m2p_remote_p2p_ded_returned.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x1\000\00001\000\000"
/* offset=4756406 */ "unc_m2p_remote_p2p_ded_returned.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x2\000\00001\000\000"
/* offset=4756570 */ "unc_m2p_remote_p2p_ded_returned.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x4\000\00001\000\000"
/* offset=4756734 */ "unc_m2p_remote_p2p_ded_returned.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x8\000\00001\000\000"
/* offset=4756898 */ "unc_m2p_remote_p2p_ded_returned.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x10\000\00001\000\000"
/* offset=4757063 */ "unc_m2p_remote_p2p_ded_returned.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x20\000\00001\000\000"
/* offset=4757228 */ "unc_m2p_remote_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=4757385 */ "unc_m2p_remote_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=4757542 */ "unc_m2p_remote_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x18,umask=0x4\000\00001\000\000"
/* offset=4757699 */ "unc_m2p_remote_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x45,umask=0x1\000\00001\000\000"
/* offset=4757874 */ "unc_m2p_remote_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x45,umask=0x2\000\00001\000\000"
/* offset=4758049 */ "unc_m2p_remote_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x45,umask=0x4\000\00001\000\000"
/* offset=4758224 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x1\000\00001\000\000"
/* offset=4758389 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x2\000\00001\000\000"
/* offset=4758554 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x4\000\00001\000\000"
/* offset=4758719 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x8\000\00001\000\000"
/* offset=4758884 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x10\000\00001\000\000"
/* offset=4759050 */ "unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x20\000\00001\000\000"
/* offset=4759216 */ "unc_m2p_remote_shar_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x43,umask=0x1\000\00001\000\000"
/* offset=4759381 */ "unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x43,umask=0x2\000\00001\000\000"
/* offset=4759546 */ "unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x43,umask=0x4\000\00001\000\000"
/* offset=4759711 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi0_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=4759880 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=4760049 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x4\000\00001\000\000"
/* offset=4760218 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi1_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x8\000\00001\000\000"
/* offset=4760387 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x10\000\00001\000\000"
/* offset=4760557 */ "unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x20\000\00001\000\000"
/* offset=4760727 */ "unc_m2p_remote_shar_p2p_crd_wait_1.upi2_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=4760896 */ "unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=4761065 */ "unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x4d,umask=0x4\000\00001\000\000"
/* offset=4761234 */ "unc_m2p_ring_bounces_horz.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2pcie \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4761530 */ "unc_m2p_ring_bounces_horz.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2pcie \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4761826 */ "unc_m2p_ring_bounces_horz.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2pcie \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4762122 */ "unc_m2p_ring_bounces_horz.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2pcie \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4762418 */ "unc_m2p_ring_bounces_vert.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2pcie \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4762708 */ "unc_m2p_ring_bounces_vert.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4763042 */ "unc_m2p_ring_bounces_vert.akc\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. Unit: uncore_m2pcie \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4763323 */ "unc_m2p_ring_bounces_vert.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4763653 */ "unc_m2p_ring_bounces_vert.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4763994 */ "unc_m2p_ring_sink_starved_horz.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2pcie \000event=0xad,umask=0x1\000\00001\000\000"
/* offset=4764140 */ "unc_m2p_ring_sink_starved_horz.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2pcie \000event=0xad,umask=0x2\000\00001\000\000"
/* offset=4764286 */ "unc_m2p_ring_sink_starved_horz.ak_ag1\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2pcie \000event=0xad,umask=0x20\000\00001\000\000"
/* offset=4764462 */ "unc_m2p_ring_sink_starved_horz.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2pcie \000event=0xad,umask=0x4\000\00001\000\000"
/* offset=4764608 */ "unc_m2p_ring_sink_starved_horz.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2pcie \000event=0xad,umask=0x8\000\00001\000\000"
/* offset=4764754 */ "unc_m2p_ring_sink_starved_vert.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2pcie \000event=0xab,umask=0x1\000\00001\000\000"
/* offset=4764898 */ "unc_m2p_ring_sink_starved_vert.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xab,umask=0x2\000\00001\000\000"
/* offset=4765064 */ "unc_m2p_ring_sink_starved_vert.akc\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring. Unit: uncore_m2pcie \000event=0xab,umask=0x10\000\00001\000\000"
/* offset=4765205 */ "unc_m2p_ring_sink_starved_vert.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2pcie \000event=0xab,umask=0x4\000\00001\000\000"
/* offset=4765369 */ "unc_m2p_ring_sink_starved_vert.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xab,umask=0x8\000\00001\000\000"
/* offset=4765538 */ "unc_m2p_ring_src_thrtl\000uncore_m2pcie\000uncore io\000Source Throttle. Unit: uncore_m2pcie \000event=0xae\000\00001\000\000"
/* offset=4765639 */ "unc_m2p_rxc_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4765888 */ "unc_m2p_rxc_cycles_ne.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4766140 */ "unc_m2p_rxc_cycles_ne.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4766392 */ "unc_m2p_rxc_cycles_ne.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4766644 */ "unc_m2p_rxc_cycles_ne.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x20\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4766897 */ "unc_m2p_rxc_cycles_ne.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x40\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4767150 */ "unc_m2p_rxc_cycles_ne.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x8\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4767402 */ "unc_m2p_rxc_cycles_ne.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x10\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000"
/* offset=4767655 */ "unc_m2p_rxc_inserts.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4768017 */ "unc_m2p_rxc_inserts.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4768382 */ "unc_m2p_rxc_inserts.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x2\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4768747 */ "unc_m2p_rxc_inserts.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4769112 */ "unc_m2p_rxc_inserts.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x20\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4769478 */ "unc_m2p_rxc_inserts.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4769844 */ "unc_m2p_rxc_inserts.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x8\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4770209 */ "unc_m2p_rxc_inserts.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x10\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000"
/* offset=4770575 */ "unc_m2p_rxr_busy_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=4771037 */ "unc_m2p_rxr_busy_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4771478 */ "unc_m2p_rxr_busy_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4771924 */ "unc_m2p_rxr_busy_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=4772386 */ "unc_m2p_rxr_busy_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4772827 */ "unc_m2p_rxr_busy_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=4773273 */ "unc_m2p_rxr_bypass.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=4773522 */ "unc_m2p_rxr_bypass.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=4773750 */ "unc_m2p_rxr_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4773983 */ "unc_m2p_rxr_bypass.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AK. Unit: uncore_m2pcie \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000"
/* offset=4774184 */ "unc_m2p_rxr_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4774421 */ "unc_m2p_rxr_bypass.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=4774670 */ "unc_m2p_rxr_bypass.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=4774898 */ "unc_m2p_rxr_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=4775131 */ "unc_m2p_rxr_bypass.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : IV. Unit: uncore_m2pcie \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000"
/* offset=4775332 */ "unc_m2p_rxr_crd_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=4775806 */ "unc_m2p_rxr_crd_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4776258 */ "unc_m2p_rxr_crd_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4776715 */ "unc_m2p_rxr_crd_starved.ak\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4777140 */ "unc_m2p_rxr_crd_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=4777614 */ "unc_m2p_rxr_crd_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4778066 */ "unc_m2p_rxr_crd_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4778523 */ "unc_m2p_rxr_crd_starved.ifv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4778974 */ "unc_m2p_rxr_crd_starved.iv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4779399 */ "unc_m2p_rxr_crd_starved_1\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation. Unit: uncore_m2pcie \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=4779803 */ "unc_m2p_rxr_inserts.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4780127 */ "unc_m2p_rxr_inserts.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4780430 */ "unc_m2p_rxr_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4780738 */ "unc_m2p_rxr_inserts.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AK. Unit: uncore_m2pcie \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4781014 */ "unc_m2p_rxr_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4781326 */ "unc_m2p_rxr_inserts.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4781650 */ "unc_m2p_rxr_inserts.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4781953 */ "unc_m2p_rxr_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4782261 */ "unc_m2p_rxr_inserts.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : IV. Unit: uncore_m2pcie \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4782537 */ "unc_m2p_rxr_occupancy.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4782867 */ "unc_m2p_rxr_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4783176 */ "unc_m2p_rxr_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4783490 */ "unc_m2p_rxr_occupancy.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AK. Unit: uncore_m2pcie \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4783772 */ "unc_m2p_rxr_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4784090 */ "unc_m2p_rxr_occupancy.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=4784420 */ "unc_m2p_rxr_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4784729 */ "unc_m2p_rxr_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4785043 */ "unc_m2p_rxr_occupancy.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : IV. Unit: uncore_m2pcie \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=4785325 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4785679 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4786033 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4786387 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4786741 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4787096 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4787451 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4787806 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4788161 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4788515 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4788869 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4789223 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4789577 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4789932 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4790287 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4790642 */ "unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4790997 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4791351 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4791705 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4792059 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4792413 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4792768 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4793123 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4793478 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4793833 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4794187 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4794541 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4794895 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4795249 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4795604 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4795959 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4796314 */ "unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4796669 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4797026 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4797380 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4797734 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4798093 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4798449 */ "unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4798805 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4799164 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4799520 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4799876 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4800235 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4800591 */ "unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=4800947 */ "unc_m2p_txc_credits.pmm\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PMM. Unit: uncore_m2pcie \000event=0x2d,umask=0x2\000\00001\000\000"
/* offset=4801067 */ "unc_m2p_txc_credits.prq\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PRQ. Unit: uncore_m2pcie \000event=0x2d,umask=0x1\000\00001\000\000"
/* offset=4801187 */ "unc_m2p_txc_cycles_full.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x1\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4801490 */ "unc_m2p_txc_cycles_full.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x10\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4801794 */ "unc_m2p_txc_cycles_full.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x2\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4802097 */ "unc_m2p_txc_cycles_full.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x20\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4802401 */ "unc_m2p_txc_cycles_full.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x4\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4802704 */ "unc_m2p_txc_cycles_full.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x40\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4803008 */ "unc_m2p_txc_cycles_full.pmm_block_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4803357 */ "unc_m2p_txc_cycles_full.pmm_block_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x80\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4803668 */ "unc_m2p_txc_cycles_full.pmm_block_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x8\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4804016 */ "unc_m2p_txc_cycles_full.pmm_block_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x8\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000"
/* offset=4804326 */ "unc_m2p_txc_cycles_ne.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x1\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4804855 */ "unc_m2p_txc_cycles_ne.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x10\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4805385 */ "unc_m2p_txc_cycles_ne.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x2\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4805914 */ "unc_m2p_txc_cycles_ne.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x20\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4806444 */ "unc_m2p_txc_cycles_ne.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x4\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4806973 */ "unc_m2p_txc_cycles_ne.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x40\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4807503 */ "unc_m2p_txc_cycles_ne.pmm_distress_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4808081 */ "unc_m2p_txc_cycles_ne.pmm_distress_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x80\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4808621 */ "unc_m2p_txc_cycles_ne.pmm_distress_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x8\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4809198 */ "unc_m2p_txc_cycles_ne.pmm_distress_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x8\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000"
/* offset=4809737 */ "unc_m2p_txc_inserts.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x1\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4810184 */ "unc_m2p_txc_inserts.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x10\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4810632 */ "unc_m2p_txc_inserts.ak_crd_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x8\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4811083 */ "unc_m2p_txc_inserts.ak_crd_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x80\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4811535 */ "unc_m2p_txc_inserts.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x4\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4811982 */ "unc_m2p_txc_inserts.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x40\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000"
/* offset=4812430 */ "unc_m2p_txr_horz_ads_used.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4812737 */ "unc_m2p_txr_horz_ads_used.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4813022 */ "unc_m2p_txr_horz_ads_used.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4813312 */ "unc_m2p_txr_horz_ads_used.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4813619 */ "unc_m2p_txr_horz_ads_used.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4813904 */ "unc_m2p_txr_horz_ads_used.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4814194 */ "unc_m2p_txr_horz_bypass.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4814497 */ "unc_m2p_txr_horz_bypass.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4814778 */ "unc_m2p_txr_horz_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4815064 */ "unc_m2p_txr_horz_bypass.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2pcie \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4815318 */ "unc_m2p_txr_horz_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4815608 */ "unc_m2p_txr_horz_bypass.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=4815911 */ "unc_m2p_txr_horz_bypass.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4816192 */ "unc_m2p_txr_horz_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4816478 */ "unc_m2p_txr_horz_bypass.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2pcie \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=4816732 */ "unc_m2p_txr_horz_cycles_full.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4817132 */ "unc_m2p_txr_horz_cycles_full.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4817510 */ "unc_m2p_txr_horz_cycles_full.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4817893 */ "unc_m2p_txr_horz_cycles_full.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2pcie \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4818244 */ "unc_m2p_txr_horz_cycles_full.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4818631 */ "unc_m2p_txr_horz_cycles_full.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4819031 */ "unc_m2p_txr_horz_cycles_full.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4819409 */ "unc_m2p_txr_horz_cycles_full.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4819792 */ "unc_m2p_txr_horz_cycles_full.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2pcie \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4820143 */ "unc_m2p_txr_horz_cycles_ne.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4820556 */ "unc_m2p_txr_horz_cycles_ne.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4820947 */ "unc_m2p_txr_horz_cycles_ne.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4821343 */ "unc_m2p_txr_horz_cycles_ne.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2pcie \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4821707 */ "unc_m2p_txr_horz_cycles_ne.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4822107 */ "unc_m2p_txr_horz_cycles_ne.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4822520 */ "unc_m2p_txr_horz_cycles_ne.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4822911 */ "unc_m2p_txr_horz_cycles_ne.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4823307 */ "unc_m2p_txr_horz_cycles_ne.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2pcie \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4823671 */ "unc_m2p_txr_horz_inserts.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4824051 */ "unc_m2p_txr_horz_inserts.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4824409 */ "unc_m2p_txr_horz_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4824772 */ "unc_m2p_txr_horz_inserts.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2pcie \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4825103 */ "unc_m2p_txr_horz_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4825470 */ "unc_m2p_txr_horz_inserts.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4825850 */ "unc_m2p_txr_horz_inserts.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4826208 */ "unc_m2p_txr_horz_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4826571 */ "unc_m2p_txr_horz_inserts.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2pcie \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4826902 */ "unc_m2p_txr_horz_nack.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=4827180 */ "unc_m2p_txr_horz_nack.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4827437 */ "unc_m2p_txr_horz_nack.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4827699 */ "unc_m2p_txr_horz_nack.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2pcie \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4827929 */ "unc_m2p_txr_horz_nack.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4828195 */ "unc_m2p_txr_horz_nack.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=4828473 */ "unc_m2p_txr_horz_nack.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4828730 */ "unc_m2p_txr_horz_nack.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4828992 */ "unc_m2p_txr_horz_nack.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2pcie \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=4829222 */ "unc_m2p_txr_horz_occupancy.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4829601 */ "unc_m2p_txr_horz_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4829958 */ "unc_m2p_txr_horz_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4830320 */ "unc_m2p_txr_horz_occupancy.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2pcie \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4830650 */ "unc_m2p_txr_horz_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4831016 */ "unc_m2p_txr_horz_occupancy.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=4831395 */ "unc_m2p_txr_horz_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4831752 */ "unc_m2p_txr_horz_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4832114 */ "unc_m2p_txr_horz_occupancy.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2pcie \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=4832444 */ "unc_m2p_txr_horz_starved.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=4832856 */ "unc_m2p_txr_horz_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4833252 */ "unc_m2p_txr_horz_starved.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4833616 */ "unc_m2p_txr_horz_starved.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4834016 */ "unc_m2p_txr_horz_starved.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=4834428 */ "unc_m2p_txr_horz_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4834824 */ "unc_m2p_txr_horz_starved.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=4835188 */ "unc_m2p_txr_vert_ads_used.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4835464 */ "unc_m2p_txr_vert_ads_used.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4835741 */ "unc_m2p_txr_vert_ads_used.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4836017 */ "unc_m2p_txr_vert_ads_used.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=4836294 */ "unc_m2p_txr_vert_bypass.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4836560 */ "unc_m2p_txr_vert_bypass.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4836827 */ "unc_m2p_txr_vert_bypass.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4837093 */ "unc_m2p_txr_vert_bypass.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4837360 */ "unc_m2p_txr_vert_bypass.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4837626 */ "unc_m2p_txr_vert_bypass.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4837893 */ "unc_m2p_txr_vert_bypass.iv_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4838159 */ "unc_m2p_txr_vert_bypass_1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4838430 */ "unc_m2p_txr_vert_bypass_1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=4838701 */ "unc_m2p_txr_vert_cycles_full0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4839203 */ "unc_m2p_txr_vert_cycles_full0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4839674 */ "unc_m2p_txr_vert_cycles_full0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4840158 */ "unc_m2p_txr_vert_cycles_full0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4840583 */ "unc_m2p_txr_vert_cycles_full0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4841083 */ "unc_m2p_txr_vert_cycles_full0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4841577 */ "unc_m2p_txr_vert_cycles_full0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4842049 */ "unc_m2p_txr_vert_cycles_full1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4842554 */ "unc_m2p_txr_vert_cycles_full1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4843041 */ "unc_m2p_txr_vert_cycles_ne0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4843552 */ "unc_m2p_txr_vert_cycles_ne0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4844032 */ "unc_m2p_txr_vert_cycles_ne0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4844525 */ "unc_m2p_txr_vert_cycles_ne0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4844959 */ "unc_m2p_txr_vert_cycles_ne0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4845468 */ "unc_m2p_txr_vert_cycles_ne0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4845971 */ "unc_m2p_txr_vert_cycles_ne0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4846452 */ "unc_m2p_txr_vert_cycles_ne1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4846966 */ "unc_m2p_txr_vert_cycles_ne1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4847462 */ "unc_m2p_txr_vert_inserts0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4847931 */ "unc_m2p_txr_vert_inserts0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4848369 */ "unc_m2p_txr_vert_inserts0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4848820 */ "unc_m2p_txr_vert_inserts0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4849212 */ "unc_m2p_txr_vert_inserts0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4849679 */ "unc_m2p_txr_vert_inserts0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4850140 */ "unc_m2p_txr_vert_inserts0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4850579 */ "unc_m2p_txr_vert_inserts1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4851051 */ "unc_m2p_txr_vert_inserts1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4851505 */ "unc_m2p_txr_vert_nack0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4851754 */ "unc_m2p_txr_vert_nack0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4852004 */ "unc_m2p_txr_vert_nack0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4852253 */ "unc_m2p_txr_vert_nack0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4852503 */ "unc_m2p_txr_vert_nack0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4852752 */ "unc_m2p_txr_vert_nack0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4853002 */ "unc_m2p_txr_vert_nack0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2pcie \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4853231 */ "unc_m2p_txr_vert_nack1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4853483 */ "unc_m2p_txr_vert_nack1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=4853735 */ "unc_m2p_txr_vert_occupancy0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4854209 */ "unc_m2p_txr_vert_occupancy0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=4854652 */ "unc_m2p_txr_vert_occupancy0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4855108 */ "unc_m2p_txr_vert_occupancy0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=4855505 */ "unc_m2p_txr_vert_occupancy0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=4855977 */ "unc_m2p_txr_vert_occupancy0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=4856443 */ "unc_m2p_txr_vert_occupancy0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=4856887 */ "unc_m2p_txr_vert_occupancy1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=4857364 */ "unc_m2p_txr_vert_occupancy1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=4857823 */ "unc_m2p_txr_vert_starved0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4858195 */ "unc_m2p_txr_vert_starved0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4858568 */ "unc_m2p_txr_vert_starved0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4858940 */ "unc_m2p_txr_vert_starved0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4859313 */ "unc_m2p_txr_vert_starved0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4859685 */ "unc_m2p_txr_vert_starved0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4860058 */ "unc_m2p_txr_vert_starved0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4860410 */ "unc_m2p_txr_vert_starved1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4860785 */ "unc_m2p_txr_vert_starved1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4861160 */ "unc_m2p_txr_vert_starved1.tgc\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=4861531 */ "unc_m2p_vert_ring_ad_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4862447 */ "unc_m2p_vert_ring_ad_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4863360 */ "unc_m2p_vert_ring_ad_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4864272 */ "unc_m2p_vert_ring_ad_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4865181 */ "unc_m2p_vert_ring_ak_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4866097 */ "unc_m2p_vert_ring_ak_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4867010 */ "unc_m2p_vert_ring_ak_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4867922 */ "unc_m2p_vert_ring_ak_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4868831 */ "unc_m2p_vert_ring_akc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4869755 */ "unc_m2p_vert_ring_akc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4870676 */ "unc_m2p_vert_ring_akc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4871596 */ "unc_m2p_vert_ring_akc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4872513 */ "unc_m2p_vert_ring_bl_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4873427 */ "unc_m2p_vert_ring_bl_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4874338 */ "unc_m2p_vert_ring_bl_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4875248 */ "unc_m2p_vert_ring_bl_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4876155 */ "unc_m2p_vert_ring_iv_in_use.dn\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Down. Unit: uncore_m2pcie \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4876743 */ "unc_m2p_vert_ring_iv_in_use.up\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Up. Unit: uncore_m2pcie \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4877327 */ "unc_m2p_vert_ring_tgc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4878251 */ "unc_m2p_vert_ring_tgc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4879172 */ "unc_m2p_vert_ring_tgc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4880092 */ "unc_m2p_vert_ring_tgc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4881009 */ "unc_m3upi_ag0_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4881247 */ "unc_m3upi_ag0_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4881485 */ "unc_m3upi_ag0_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4881723 */ "unc_m3upi_ag0_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4881961 */ "unc_m3upi_ag0_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4882200 */ "unc_m3upi_ag0_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4882439 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4882731 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4883023 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4883315 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4883607 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4883900 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4884193 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4884486 */ "unc_m3upi_ag0_ad_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4884779 */ "unc_m3upi_ag0_ad_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4885074 */ "unc_m3upi_ag0_ad_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4885366 */ "unc_m3upi_ag0_ad_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000"
/* offset=4885658 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4885896 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4886134 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4886372 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4886610 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4886849 */ "unc_m3upi_ag0_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4887088 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4887381 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4887674 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4887967 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4888260 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4888554 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4888848 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4889142 */ "unc_m3upi_ag0_ad_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4889436 */ "unc_m3upi_ag0_ad_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4889732 */ "unc_m3upi_ag0_ad_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4890025 */ "unc_m3upi_ag0_ad_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000"
/* offset=4890318 */ "unc_m3upi_ag0_bl_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4890556 */ "unc_m3upi_ag0_bl_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4890794 */ "unc_m3upi_ag0_bl_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4891032 */ "unc_m3upi_ag0_bl_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4891270 */ "unc_m3upi_ag0_bl_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4891509 */ "unc_m3upi_ag0_bl_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4891748 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4892040 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4892332 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4892624 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4892916 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4893209 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4893502 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4893795 */ "unc_m3upi_ag0_bl_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4894088 */ "unc_m3upi_ag0_bl_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4894383 */ "unc_m3upi_ag0_bl_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4894675 */ "unc_m3upi_ag0_bl_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000"
/* offset=4894967 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4895205 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4895443 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4895681 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4895919 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4896158 */ "unc_m3upi_ag0_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4896397 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4896690 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4896983 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4897276 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4897569 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4897863 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4898157 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4898451 */ "unc_m3upi_ag0_bl_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4898745 */ "unc_m3upi_ag0_bl_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4899041 */ "unc_m3upi_ag0_bl_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4899334 */ "unc_m3upi_ag0_bl_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000"
/* offset=4899627 */ "unc_m3upi_ag1_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4899865 */ "unc_m3upi_ag1_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4900103 */ "unc_m3upi_ag1_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4900341 */ "unc_m3upi_ag1_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4900579 */ "unc_m3upi_ag1_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4900818 */ "unc_m3upi_ag1_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4901057 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4901349 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4901641 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4901933 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4902225 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4902518 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4902811 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4903104 */ "unc_m3upi_ag1_ad_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4903397 */ "unc_m3upi_ag1_ad_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4903692 */ "unc_m3upi_ag1_ad_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4903984 */ "unc_m3upi_ag1_ad_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000"
/* offset=4904276 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4904514 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4904752 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4904990 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4905228 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4905467 */ "unc_m3upi_ag1_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4905706 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4905999 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4906292 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4906585 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4906878 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4907172 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4907466 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4907760 */ "unc_m3upi_ag1_ad_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4908054 */ "unc_m3upi_ag1_ad_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4908350 */ "unc_m3upi_ag1_ad_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4908643 */ "unc_m3upi_ag1_ad_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000"
/* offset=4908936 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4909228 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4909520 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4909812 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4910104 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4910397 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4910690 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4910983 */ "unc_m3upi_ag1_bl_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4911276 */ "unc_m3upi_ag1_bl_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4911571 */ "unc_m3upi_ag1_bl_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4911863 */ "unc_m3upi_ag1_bl_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4912155 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4912393 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4912631 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4912869 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4913107 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4913346 */ "unc_m3upi_ag1_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4913585 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4913878 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4914171 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4914464 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4914757 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4915051 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4915345 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4915639 */ "unc_m3upi_ag1_bl_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4915933 */ "unc_m3upi_ag1_bl_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4916229 */ "unc_m3upi_ag1_bl_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4916522 */ "unc_m3upi_ag1_bl_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000"
/* offset=4916815 */ "unc_m3upi_ag1_bl_credits_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4917057 */ "unc_m3upi_ag1_bl_credits_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4917299 */ "unc_m3upi_ag1_bl_credits_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4917541 */ "unc_m3upi_ag1_bl_credits_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4917783 */ "unc_m3upi_ag1_bl_credits_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4918026 */ "unc_m3upi_ag1_bl_credits_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000"
/* offset=4918269 */ "unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000CBox AD Credits Empty : Requests : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4918526 */ "unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4918747 */ "unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000CBox AD Credits Empty : Snoops : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4919000 */ "unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4919219 */ "unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000CBox AD Credits Empty : VNA Messages : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4919484 */ "unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4919709 */ "unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000CBox AD Credits Empty : Writebacks : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4919969 */ "unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000"
/* offset=4920191 */ "unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000Clockticks of the mesh to UPI (M3UPI). Unit: uncore_m3upi \000event=0x1\000\00001\000Clockticks of the mesh to UPI (M3UPI) : Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000"
/* offset=4920616 */ "unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000M3UPI Clockticks. Unit: uncore_m3upi \000event=0x1\000\00001\000Number of M2UPI clock cycles while the event is enabled\000"
/* offset=4920778 */ "unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_m3upi \000event=0x1\000\00001\000Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000"
/* offset=4921151 */ "unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000"
/* offset=4921261 */ "unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000M3UPI CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000"
/* offset=4921377 */ "unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000Count cases BL sends direct to core\000"
/* offset=4921510 */ "unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000D2C Sent : Count cases BL sends direct to core\000"
/* offset=4921654 */ "unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000Cases where SMI3 sends D2U command\000"
/* offset=4921786 */ "unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000D2U Sent : Cases where SMI3 sends D2U command\000"
/* offset=4921929 */ "unc_m3upi_distress_asserted.dpt_local\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Local. Unit: uncore_m3upi \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000"
/* offset=4922261 */ "unc_m3upi_distress_asserted.dpt_nonlocal\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Remote. Unit: uncore_m3upi \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000"
/* offset=4922597 */ "unc_m3upi_distress_asserted.dpt_stall_iv\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m3upi \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000"
/* offset=4922970 */ "unc_m3upi_distress_asserted.dpt_stall_nocrd\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m3upi \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000"
/* offset=4923356 */ "unc_m3upi_distress_asserted.horz\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : Horizontal. Unit: uncore_m3upi \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4923714 */ "unc_m3upi_distress_asserted.pmm_local\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : PMM Local. Unit: uncore_m3upi \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4924094 */ "unc_m3upi_distress_asserted.pmm_nonlocal\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : PMM Remote. Unit: uncore_m3upi \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000"
/* offset=4924483 */ "unc_m3upi_distress_asserted.vert\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : Vertical. Unit: uncore_m3upi \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000"
/* offset=4924837 */ "unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m3upi \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4925155 */ "unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m3upi \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4925418 */ "unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m3upi \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4925732 */ "unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m3upi \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000"
/* offset=4925993 */ "unc_m3upi_fast_asserted.horz\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m3upi \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=4926266 */ "unc_m3upi_fast_asserted.vert\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=4926537 */ "unc_m3upi_horz_ring_ad_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4927470 */ "unc_m3upi_horz_ring_ad_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4928358 */ "unc_m3upi_horz_ring_ad_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4929288 */ "unc_m3upi_horz_ring_ad_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4930174 */ "unc_m3upi_horz_ring_ad_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4931110 */ "unc_m3upi_horz_ring_ad_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4932000 */ "unc_m3upi_horz_ring_ad_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4932933 */ "unc_m3upi_horz_ring_ad_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4933821 */ "unc_m3upi_horz_ring_ak_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4934752 */ "unc_m3upi_horz_ring_ak_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4935638 */ "unc_m3upi_horz_ring_ak_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4936566 */ "unc_m3upi_horz_ring_ak_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4937450 */ "unc_m3upi_horz_ring_ak_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4938384 */ "unc_m3upi_horz_ring_ak_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4939272 */ "unc_m3upi_horz_ring_ak_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4940203 */ "unc_m3upi_horz_ring_ak_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4941089 */ "unc_m3upi_horz_ring_akc_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4942029 */ "unc_m3upi_horz_ring_akc_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4942966 */ "unc_m3upi_horz_ring_akc_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4943909 */ "unc_m3upi_horz_ring_akc_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4944849 */ "unc_m3upi_horz_ring_bl_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m3upi \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4945781 */ "unc_m3upi_horz_ring_bl_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m3upi \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4946668 */ "unc_m3upi_horz_ring_bl_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m3upi \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4947597 */ "unc_m3upi_horz_ring_bl_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4948482 */ "unc_m3upi_horz_ring_bl_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m3upi \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4949417 */ "unc_m3upi_horz_ring_bl_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m3upi \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4950306 */ "unc_m3upi_horz_ring_bl_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m3upi \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4951238 */ "unc_m3upi_horz_ring_bl_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=4952125 */ "unc_m3upi_horz_ring_iv_in_use.left\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use : Left. Unit: uncore_m3upi \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4952731 */ "unc_m3upi_horz_ring_iv_in_use.left\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m3upi \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4953301 */ "unc_m3upi_horz_ring_iv_in_use.right\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use : Right. Unit: uncore_m3upi \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4953910 */ "unc_m3upi_horz_ring_iv_in_use.right\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m3upi \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=4954482 */ "unc_m3upi_m2_bl_credits_empty.iio0_iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4954740 */ "unc_m3upi_m2_bl_credits_empty.iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only) : No vn0 and vna credits available to send to M2\000"
/* offset=4955085 */ "unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000M2 BL Credits Empty : IIO2 : No vn0 and vna credits available to send to M2\000"
/* offset=4955306 */ "unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4955497 */ "unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000M2 BL Credits Empty : IIO3 : No vn0 and vna credits available to send to M2\000"
/* offset=4955718 */ "unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4955909 */ "unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000M2 BL Credits Empty : IIO4 : No vn0 and vna credits available to send to M2\000"
/* offset=4956130 */ "unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4956321 */ "unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000"
/* offset=4956543 */ "unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4956735 */ "unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together : No vn0 and vna credits available to send to M2\000"
/* offset=4957066 */ "unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4957310 */ "unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x80\000\00001\000M2 BL Credits Empty : Selected M2p BL NCS credits : No vn0 and vna credits available to send to M2\000"
/* offset=4957577 */ "unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000No vn0 and vna credits available to send to M2\000"
/* offset=4957791 */ "unc_m3upi_m2_bl_credits_empty.ubox_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000"
/* offset=4958013 */ "unc_m3upi_misc_external.mbe_inst0\000uncore_m3upi\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m3upi \000event=0xe6,umask=0x1\000\00001\000\000"
/* offset=4958212 */ "unc_m3upi_misc_external.mbe_inst1\000uncore_m3upi\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m3upi \000event=0xe6,umask=0x2\000\00001\000\000"
/* offset=4958411 */ "unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi Slot Flit Received : AD - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4958703 */ "unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4958953 */ "unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi Slot Flit Received : AD - Slot 1 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4959245 */ "unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4959495 */ "unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi Slot Flit Received : AD - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4959787 */ "unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4960037 */ "unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi Slot Flit Received : AK - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4960330 */ "unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4960581 */ "unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi Slot Flit Received : AK - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4960874 */ "unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4961125 */ "unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi Slot Flit Received : BL - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4961417 */ "unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000"
/* offset=4961667 */ "unc_m3upi_ring_bounces_horz.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m3upi \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4961973 */ "unc_m3upi_ring_bounces_horz.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m3upi \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4962225 */ "unc_m3upi_ring_bounces_horz.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m3upi \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4962531 */ "unc_m3upi_ring_bounces_horz.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m3upi \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4962783 */ "unc_m3upi_ring_bounces_horz.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m3upi \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4963089 */ "unc_m3upi_ring_bounces_horz.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m3upi \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4963341 */ "unc_m3upi_ring_bounces_horz.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m3upi \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4963647 */ "unc_m3upi_ring_bounces_horz.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m3upi \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000"
/* offset=4963899 */ "unc_m3upi_ring_bounces_vert.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m3upi \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4964199 */ "unc_m3upi_ring_bounces_vert.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m3upi \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4964447 */ "unc_m3upi_ring_bounces_vert.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m3upi \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4964791 */ "unc_m3upi_ring_bounces_vert.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4965061 */ "unc_m3upi_ring_bounces_vert.akc\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. Unit: uncore_m3upi \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4965352 */ "unc_m3upi_ring_bounces_vert.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m3upi \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4965692 */ "unc_m3upi_ring_bounces_vert.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m3upi \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4965960 */ "unc_m3upi_ring_bounces_vert.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m3upi \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4966311 */ "unc_m3upi_ring_bounces_vert.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000"
/* offset=4966584 */ "unc_m3upi_ring_sink_starved_horz.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m3upi \000event=0xad,umask=0x1\000\00001\000\000"
/* offset=4966740 */ "unc_m3upi_ring_sink_starved_horz.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m3upi \000event=0xa3,umask=0x1\000\00001\000\000"
/* offset=4966895 */ "unc_m3upi_ring_sink_starved_horz.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m3upi \000event=0xad,umask=0x2\000\00001\000\000"
/* offset=4967051 */ "unc_m3upi_ring_sink_starved_horz.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m3upi \000event=0xa3,umask=0x2\000\00001\000\000"
/* offset=4967206 */ "unc_m3upi_ring_sink_starved_horz.ak_ag1\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m3upi \000event=0xad,umask=0x20\000\00001\000\000"
/* offset=4967392 */ "unc_m3upi_ring_sink_starved_horz.ak_ag1\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m3upi \000event=0xa3,umask=0x20\000\00001\000\000"
/* offset=4967577 */ "unc_m3upi_ring_sink_starved_horz.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m3upi \000event=0xad,umask=0x4\000\00001\000\000"
/* offset=4967733 */ "unc_m3upi_ring_sink_starved_horz.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m3upi \000event=0xa3,umask=0x4\000\00001\000\000"
/* offset=4967888 */ "unc_m3upi_ring_sink_starved_horz.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m3upi \000event=0xad,umask=0x8\000\00001\000\000"
/* offset=4968044 */ "unc_m3upi_ring_sink_starved_horz.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m3upi \000event=0xa3,umask=0x8\000\00001\000\000"
/* offset=4968199 */ "unc_m3upi_ring_sink_starved_vert.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m3upi \000event=0xab,umask=0x1\000\00001\000\000"
/* offset=4968353 */ "unc_m3upi_ring_sink_starved_vert.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m3upi \000event=0xa2,umask=0x1\000\00001\000\000"
/* offset=4968506 */ "unc_m3upi_ring_sink_starved_vert.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m3upi \000event=0xab,umask=0x2\000\00001\000\000"
/* offset=4968682 */ "unc_m3upi_ring_sink_starved_vert.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa2,umask=0x2\000\00001\000\000"
/* offset=4968857 */ "unc_m3upi_ring_sink_starved_vert.akc\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring. Unit: uncore_m3upi \000event=0xab,umask=0x10\000\00001\000\000"
/* offset=4969008 */ "unc_m3upi_ring_sink_starved_vert.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m3upi \000event=0xab,umask=0x4\000\00001\000\000"
/* offset=4969182 */ "unc_m3upi_ring_sink_starved_vert.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m3upi \000event=0xa2,umask=0x4\000\00001\000\000"
/* offset=4969355 */ "unc_m3upi_ring_sink_starved_vert.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m3upi \000event=0xab,umask=0x8\000\00001\000\000"
/* offset=4969534 */ "unc_m3upi_ring_sink_starved_vert.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa2,umask=0x8\000\00001\000\000"
/* offset=4969712 */ "unc_m3upi_ring_src_thrtl\000uncore_m3upi\000uncore interconnect\000Source Throttle. Unit: uncore_m3upi \000event=0xa4\000\00001\000\000"
/* offset=4969823 */ "unc_m3upi_ring_src_thrtl\000uncore_m3upi\000uncore interconnect\000Source Throttle. Unit: uncore_m3upi \000event=0xae\000\00001\000\000"
/* offset=4969934 */ "unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000Lost Arb for VN0 : REQ on AD : VN0 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4970259 */ "unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000VN0 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4970551 */ "unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000Lost Arb for VN0 : RSP on AD : VN0 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4970901 */ "unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4971218 */ "unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000Lost Arb for VN0 : SNP on AD : VN0 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4971498 */ "unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000VN0 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4971745 */ "unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000Lost Arb for VN0 : NCB on BL : VN0 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4972113 */ "unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4972448 */ "unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000Lost Arb for VN0 : NCS on BL : VN0 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4972710 */ "unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4972939 */ "unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000Lost Arb for VN0 : RSP on BL : VN0 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4973288 */ "unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4973604 */ "unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000Lost Arb for VN0 : WB on BL : VN0 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4974011 */ "unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000VN0 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4974386 */ "unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000Lost Arb for VN1 : REQ on AD : VN1 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4974711 */ "unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000VN1 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4975003 */ "unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000Lost Arb for VN1 : RSP on AD : VN1 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4975353 */ "unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4975670 */ "unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000Lost Arb for VN1 : SNP on AD : VN1 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4975950 */ "unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000VN1 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4976197 */ "unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000Lost Arb for VN1 : NCB on BL : VN1 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4976565 */ "unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4976900 */ "unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000Lost Arb for VN1 : NCS on BL : VN1 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4977162 */ "unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4977391 */ "unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000Lost Arb for VN1 : RSP on BL : VN1 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4977740 */ "unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4978056 */ "unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000Lost Arb for VN1 : WB on BL : VN1 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4978463 */ "unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000VN1 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4978838 */ "unc_m3upi_rxc_arb_misc.adbl_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; AD, BL Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000AD and BL messages won arbitration concurrently / in parallel\000"
/* offset=4979060 */ "unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN0 : AD and BL messages won arbitration concurrently / in parallel\000"
/* offset=4979337 */ "unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN1 : AD and BL messages won arbitration concurrently / in parallel\000"
/* offset=4979614 */ "unc_m3upi_rxc_arb_misc.all_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : Max Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x80\000\00001\000Arb Miscellaneous : Max Parallel Win : VN0 and VN1 arbitration sub-pipelines both produced AD and BL winners (maximum possible parallel winners)\000"
/* offset=4979916 */ "unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN0 : Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000"
/* offset=4980246 */ "unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000"
/* offset=4980523 */ "unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN1 : Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000"
/* offset=4980853 */ "unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000"
/* offset=4981130 */ "unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN0 : Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000"
/* offset=4981460 */ "unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000"
/* offset=4981738 */ "unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN1 : Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000"
/* offset=4982068 */ "unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000"
/* offset=4982346 */ "unc_m3upi_rxc_arb_misc.par_bias_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn0, delaying vn1 win, because vn0 offered parallel ad/bl\000"
/* offset=4982607 */ "unc_m3upi_rxc_arb_misc.par_bias_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn1, delaying vn0 win, because vn1 offered parallel ad/bl\000"
/* offset=4982868 */ "unc_m3upi_rxc_arb_misc.vn01_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : VN0, VN1 Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000Arb Miscellaneous : VN0, VN1 Parallel Win : VN0 and VN1 arbitration sub-pipelines had parallel winners (at least one AD or BL on each side)\000"
/* offset=4983171 */ "unc_m3upi_rxc_arb_noad_req_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4983514 */ "unc_m3upi_rxc_arb_noad_req_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4983882 */ "unc_m3upi_rxc_arb_noad_req_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4984180 */ "unc_m3upi_rxc_arb_noad_req_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4984566 */ "unc_m3upi_rxc_arb_noad_req_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4984846 */ "unc_m3upi_rxc_arb_noad_req_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4985213 */ "unc_m3upi_rxc_arb_noad_req_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4985639 */ "unc_m3upi_rxc_arb_noad_req_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4985982 */ "unc_m3upi_rxc_arb_noad_req_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4986350 */ "unc_m3upi_rxc_arb_noad_req_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4986648 */ "unc_m3upi_rxc_arb_noad_req_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4987034 */ "unc_m3upi_rxc_arb_noad_req_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4987314 */ "unc_m3upi_rxc_arb_noad_req_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4987681 */ "unc_m3upi_rxc_arb_noad_req_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4988107 */ "unc_m3upi_rxc_arb_nocrd_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000No Credits to Arb for VN0 : REQ on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4988493 */ "unc_m3upi_rxc_arb_nocrd_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000No Credits to Arb for VN0 : RSP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4988904 */ "unc_m3upi_rxc_arb_nocrd_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000No Credits to Arb for VN0 : SNP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4989245 */ "unc_m3upi_rxc_arb_nocrd_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000No Credits to Arb for VN0 : NCB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4989674 */ "unc_m3upi_rxc_arb_nocrd_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000No Credits to Arb for VN0 : NCS on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4989997 */ "unc_m3upi_rxc_arb_nocrd_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000No Credits to Arb for VN0 : RSP on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4990407 */ "unc_m3upi_rxc_arb_nocrd_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000No Credits to Arb for VN0 : WB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4990875 */ "unc_m3upi_rxc_arb_nocrd_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000No Credits to Arb for VN1 : REQ on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4991261 */ "unc_m3upi_rxc_arb_nocrd_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000No Credits to Arb for VN1 : RSP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4991672 */ "unc_m3upi_rxc_arb_nocrd_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000No Credits to Arb for VN1 : SNP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4992013 */ "unc_m3upi_rxc_arb_nocrd_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000No Credits to Arb for VN1 : NCB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4992442 */ "unc_m3upi_rxc_arb_nocrd_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000No Credits to Arb for VN1 : NCS on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4992765 */ "unc_m3upi_rxc_arb_nocrd_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000No Credits to Arb for VN1 : RSP on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4993175 */ "unc_m3upi_rxc_arb_nocrd_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000No Credits to Arb for VN1 : WB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4993643 */ "unc_m3upi_rxc_arb_nocred_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4993988 */ "unc_m3upi_rxc_arb_nocred_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4994358 */ "unc_m3upi_rxc_arb_nocred_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4994658 */ "unc_m3upi_rxc_arb_nocred_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4995046 */ "unc_m3upi_rxc_arb_nocred_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4995328 */ "unc_m3upi_rxc_arb_nocred_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4995697 */ "unc_m3upi_rxc_arb_nocred_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4996125 */ "unc_m3upi_rxc_arb_nocred_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4996470 */ "unc_m3upi_rxc_arb_nocred_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4996840 */ "unc_m3upi_rxc_arb_nocred_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4997140 */ "unc_m3upi_rxc_arb_nocred_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=4997528 */ "unc_m3upi_rxc_arb_nocred_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=4997810 */ "unc_m3upi_rxc_arb_nocred_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4998179 */ "unc_m3upi_rxc_arb_nocred_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=4998607 */ "unc_m3upi_rxc_arb_noreq_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000Can't Arb for VN0 : REQ on AD : VN0 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=4998981 */ "unc_m3upi_rxc_arb_noreq_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000Can't Arb for VN0 : RSP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=4999380 */ "unc_m3upi_rxc_arb_noreq_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000Can't Arb for VN0 : SNP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=4999709 */ "unc_m3upi_rxc_arb_noreq_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000Can't Arb for VN0 : NCB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5000126 */ "unc_m3upi_rxc_arb_noreq_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000Can't Arb for VN0 : NCS on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5000437 */ "unc_m3upi_rxc_arb_noreq_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000Can't Arb for VN0 : RSP on BL : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5000835 */ "unc_m3upi_rxc_arb_noreq_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000Can't Arb for VN0 : WB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5001291 */ "unc_m3upi_rxc_arb_noreq_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000Can't Arb for VN1 : REQ on AD : VN1 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5001665 */ "unc_m3upi_rxc_arb_noreq_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000Can't Arb for VN1 : RSP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5002064 */ "unc_m3upi_rxc_arb_noreq_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000Can't Arb for VN1 : SNP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5002393 */ "unc_m3upi_rxc_arb_noreq_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000Can't Arb for VN1 : NCB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5002810 */ "unc_m3upi_rxc_arb_noreq_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000Can't Arb for VN1 : NCS on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5003121 */ "unc_m3upi_rxc_arb_noreq_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000Can't Arb for VN1 : RSP on BL : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5003519 */ "unc_m3upi_rxc_arb_noreq_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000Can't Arb for VN1 : WB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5003975 */ "unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000"
/* offset=5004336 */ "unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000"
/* offset=5004645 */ "unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on Idle : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while pipeline is idle\000"
/* offset=5004988 */ "unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while pipeline is idle\000"
/* offset=5005281 */ "unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 1 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 1 while merging with bl message in same flit\000"
/* offset=5005626 */ "unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 1 while merging with bl message in same flit\000"
/* offset=5005924 */ "unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 2 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 2 while merging with bl message in same flit\000"
/* offset=5006269 */ "unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 2 while merging with bl message in same flit\000"
/* offset=5006567 */ "unc_m3upi_rxc_collision_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5006906 */ "unc_m3upi_rxc_collision_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5007270 */ "unc_m3upi_rxc_collision_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5007564 */ "unc_m3upi_rxc_collision_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5007946 */ "unc_m3upi_rxc_collision_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x50,umask=0x40\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5008222 */ "unc_m3upi_rxc_collision_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5008585 */ "unc_m3upi_rxc_collision_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5009007 */ "unc_m3upi_rxc_collision_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5009346 */ "unc_m3upi_rxc_collision_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5009710 */ "unc_m3upi_rxc_collision_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5010004 */ "unc_m3upi_rxc_collision_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5010386 */ "unc_m3upi_rxc_collision_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5010662 */ "unc_m3upi_rxc_collision_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5011025 */ "unc_m3upi_rxc_collision_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5011447 */ "unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any In BGF FIFO. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Miscellaneous Credit Events : Any In BGF FIFO : Indication that at least one packet (flit) is in the bgf (fifo only)\000"
/* offset=5011725 */ "unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any In BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Indication that at least one packet (flit) is in the bgf (fifo only)\000"
/* offset=5011954 */ "unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any in BGF Path. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Miscellaneous Credit Events : Any in BGF Path : Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000"
/* offset=5012245 */ "unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000"
/* offset=5012487 */ "unc_m3upi_rxc_crd_misc.lt1_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 1\000"
/* offset=5012692 */ "unc_m3upi_rxc_crd_misc.lt2_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 2\000"
/* offset=5012897 */ "unc_m3upi_rxc_crd_misc.no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; No D2K For Arb. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000VN0 or VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000"
/* offset=5013152 */ "unc_m3upi_rxc_crd_misc.vn0_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : No D2K For Arb. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Miscellaneous Credit Events : No D2K For Arb : VN0 BL RSP message was blocked from arbitration request due to lack of D2K CMP credit\000"
/* offset=5013451 */ "unc_m3upi_rxc_crd_misc.vn1_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Miscellaneous Credit Events : VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000"
/* offset=5013717 */ "unc_m3upi_rxc_crd_occ.consumed\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Credits Consumed. Unit: uncore_m3upi \000event=0x60,umask=0x80\000\00001\000Credit Occupancy : Credits Consumed : number of remote vna credits consumed per cycle\000"
/* offset=5013950 */ "unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : D2K Credits. Unit: uncore_m3upi \000event=0x60,umask=0x10\000\00001\000Credit Occupancy : D2K Credits : D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000"
/* offset=5014209 */ "unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; D2K Credits. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000"
/* offset=5014434 */ "unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Credit Occupancy : Packets in BGF FIFO : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000"
/* offset=5014703 */ "unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000"
/* offset=5014930 */ "unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000Credit Occupancy : Packets in BGF Path : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000"
/* offset=5015227 */ "unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF Path. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000"
/* offset=5015482 */ "unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x40\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in completion fifo only\000"
/* offset=5015699 */ "unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x40\000\00001\000count of bl messages in pump-1-pending state, in completion fifo only\000"
/* offset=5015897 */ "unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x20\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in marker table and in fifo\000"
/* offset=5016119 */ "unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000count of bl messages in pump-1-pending state, in marker table and in fifo\000"
/* offset=5016322 */ "unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Transmit Credits. Unit: uncore_m3upi \000event=0x60,umask=0x8\000\00001\000Credit Occupancy : Transmit Credits : Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000"
/* offset=5016596 */ "unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Transmit Credits. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000"
/* offset=5016831 */ "unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : VNA In Use. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Credit Occupancy : VNA In Use : Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000"
/* offset=5017095 */ "unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; VNA In Use. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000"
/* offset=5017326 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5018013 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5018636 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5019348 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5019996 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5020638 */ "unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5021216 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5021946 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5022612 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5023236 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5023796 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5024507 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5025154 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5025923 */ "unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5026629 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD. Unit: uncore_m3upi \000event=0x44,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5027316 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x44,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5027939 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5028651 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5029299 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5029941 */ "unc_m3upi_rxc_cycles_ne_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5030519 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5031249 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5031915 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL. Unit: uncore_m3upi \000event=0x44,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5032539 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x44,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5033099 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL. Unit: uncore_m3upi \000event=0x44,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5033810 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x44,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5034457 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5035226 */ "unc_m3upi_rxc_cycles_ne_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5035932 */ "unc_m3upi_rxc_data_flits_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000Data Flit Not Sent : All : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but could not be sent for any reason, e.g. low credits, low tsv, stall injection\000"
/* offset=5036278 */ "unc_m3upi_rxc_data_flits_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000Data Flit Not Sent : No BGF Credits : Data flit is ready for transmission but could not be sent\000"
/* offset=5036530 */ "unc_m3upi_rxc_data_flits_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000Data Flit Not Sent : No TxQ Credits : Data flit is ready for transmission but could not be sent\000"
/* offset=5036783 */ "unc_m3upi_rxc_data_flits_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : TSV High. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000Data Flit Not Sent : TSV High : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while tsv high\000"
/* offset=5037093 */ "unc_m3upi_rxc_data_flits_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000Data Flit Not Sent : Cycle valid for Flit : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while cycle is valid for flit transmission\000"
/* offset=5037463 */ "unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Flit Gen - Header 1 : Accumulate : Events related to Header Flit Generation - Set 1 : Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000"
/* offset=5037823 */ "unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000"
/* offset=5038146 */ "unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Ready. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Flit Gen - Header 1 : Accumulate Ready : Events related to Header Flit Generation - Set 1 : header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000"
/* offset=5038553 */ "unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Ready. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 1; header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000"
/* offset=5038917 */ "unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Wasted. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Flit Gen - Header 1 : Accumulate Wasted : Events related to Header Flit Generation - Set 1 : Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000"
/* offset=5039314 */ "unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Wasted. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Events related to Header Flit Generation - Set 1; Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000"
/* offset=5039667 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Flit Gen - Header 1 : Run-Ahead - Blocked : Events related to Header Flit Generation - Set 1 : Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000"
/* offset=5040059 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000"
/* offset=5040405 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x80\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: message was slotted only after run-ahead was over; run-ahead mode definitely wasted\000"
/* offset=5040723 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_during\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Message. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Flit Gen - Header 1 : Run-Ahead - Message : Events related to Header Flit Generation - Set 1 : run-ahead mode: one message slotted during run-ahead\000"
/* offset=5041039 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: second message slotted immediately after run-ahead; potential run-ahead success\000"
/* offset=5041353 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_sent\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: two (or three) message flit sent immediately after run-ahead; complete run-ahead success\000"
/* offset=5041675 */ "unc_m3upi_rxc_flit_gen_hdr1.ahead_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Message. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting is in run-ahead to start new flit, and message is actually slotted into new flit\000"
/* offset=5041986 */ "unc_m3upi_rxc_flit_gen_hdr1.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Ok. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Events related to Header Flit Generation - Set 1; New header flit construction may proceed in parallel with data flit sequence\000"
/* offset=5042258 */ "unc_m3upi_rxc_flit_gen_hdr1.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Flit Finished. Unit: uncore_m3upi \000event=0x53,umask=0x80\000\00001\000Events related to Header Flit Generation - Set 1; Header flit finished assembly in parallel with data flit sequence\000"
/* offset=5042535 */ "unc_m3upi_rxc_flit_gen_hdr1.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Message. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Events related to Header Flit Generation - Set 1; Message is slotted into header flit in parallel with data flit sequence\000"
/* offset=5042811 */ "unc_m3upi_rxc_flit_gen_hdr2.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Ok. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000Flit Gen - Header 2 : Parallel Ok : Events related to Header Flit Generation - Set 2 : new header flit construction may proceed in parallel with data flit sequence\000"
/* offset=5043120 */ "unc_m3upi_rxc_flit_gen_hdr2.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Flit Finished. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000Flit Gen - Header 2 : Parallel Flit Finished : Events related to Header Flit Generation - Set 2 : header flit finished assembly in parallel with data flit sequence\000"
/* offset=5043446 */ "unc_m3upi_rxc_flit_gen_hdr2.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Message. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000Flit Gen - Header 2 : Parallel Message : Events related to Header Flit Generation - Set 2 : message is slotted into header flit in parallel with data flit sequence\000"
/* offset=5043764 */ "unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000Flit Gen - Header 2 : Rate-matching Stall : Events related to Header Flit Generation - Set 2 : Rate-matching stall injected\000"
/* offset=5044045 */ "unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 2; Rate-matching stall injected\000"
/* offset=5044280 */ "unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000Flit Gen - Header 2 : Rate-matching Stall - No Message : Events related to Header Flit Generation - Set 2 : Rate matching stall injected, but no additional message slotted during stall cycle\000"
/* offset=5044647 */ "unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 2; Rate matching stall injected, but no additional message slotted during stall cycle\000"
/* offset=5044955 */ "unc_m3upi_rxc_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent; All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000header flit is ready for transmission but could not be sent\000"
/* offset=5045147 */ "unc_m3upi_rxc_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available\000"
/* offset=5045383 */ "unc_m3upi_rxc_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available; no additional message slotted into flit\000"
/* offset=5045690 */ "unc_m3upi_rxc_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available\000"
/* offset=5045926 */ "unc_m3upi_rxc_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available; no additional message slotted into flit\000"
/* offset=5046234 */ "unc_m3upi_rxc_flit_not_sent.one_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - One Slot Taken. Unit: uncore_m3upi \000event=0x55,umask=0x20\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only one slot taken (two slots free)\000"
/* offset=5046514 */ "unc_m3upi_rxc_flit_not_sent.three_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Three Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x80\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with three slots taken (no slots free)\000"
/* offset=5046796 */ "unc_m3upi_rxc_flit_not_sent.two_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Two Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x40\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only two slots taken (one slots free)\000"
/* offset=5047078 */ "unc_m3upi_rxc_flits_data_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; All. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Data flit is ready for transmission but could not be sent\000"
/* offset=5047277 */ "unc_m3upi_rxc_flits_data_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Data flit is ready for transmission but could not be sent\000"
/* offset=5047490 */ "unc_m3upi_rxc_flits_data_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Data flit is ready for transmission but could not be sent\000"
/* offset=5047703 */ "unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 0. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 0 : generating bl data flit sequence; waiting for data pump 0\000"
/* offset=5047977 */ "unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 0. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000generating bl data flit sequence; waiting for data pump 0\000"
/* offset=5048198 */ "unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 1. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 1 : generating bl data flit sequence; waiting for data pump 1\000"
/* offset=5048472 */ "unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 1. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000generating bl data flit sequence; waiting for data pump 1\000"
/* offset=5048693 */ "unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x10\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000"
/* offset=5048963 */ "unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000"
/* offset=5049198 */ "unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x8\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is tracking at least one message\000"
/* offset=5049435 */ "unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000pump-1-pending logic is tracking at least one message\000"
/* offset=5049637 */ "unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x40\000\00001\000Generating BL Data Flit Sequence : pump-1-pending completion fifo is full\000"
/* offset=5049865 */ "unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000pump-1-pending completion fifo is full\000"
/* offset=5050058 */ "unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x20\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000"
/* offset=5050362 */ "unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000"
/* offset=5050631 */ "unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Generating BL Data Flit Sequence : a bl message finished but is in limbo and moved to pump-1-pending logic\000"
/* offset=5050890 */ "unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000a bl message finished but is in limbo and moved to pump-1-pending logic\000"
/* offset=5051114 */ "unc_m3upi_rxc_flits_misc.s2req_in_holdoff\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_HOLDOFF. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000: slot 2 request naturally serviced during hold-off period\000"
/* offset=5051336 */ "unc_m3upi_rxc_flits_misc.s2req_in_service\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_SERVICE. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000: slot 2 request forcibly serviced during service window\000"
/* offset=5051556 */ "unc_m3upi_rxc_flits_misc.s2req_received\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_RECEIVED. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000: slot 2 request received from link layer while idle (with no slot 2 request active immediately prior)\000"
/* offset=5051818 */ "unc_m3upi_rxc_flits_misc.s2req_withdrawn\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_WITHDRAWN. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000: slot 2 request withdrawn during hold-off period or service window\000"
/* offset=5052047 */ "unc_m3upi_rxc_flits_misc\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC. Unit: uncore_m3upi \000event=0x5a\000\00001\000\000"
/* offset=5052167 */ "unc_m3upi_rxc_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000One message in flit; VNA or non-VNA flit\000"
/* offset=5052348 */ "unc_m3upi_rxc_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message in non-VNA. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000One message in flit; non-VNA flit\000"
/* offset=5052537 */ "unc_m3upi_rxc_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Two Messages. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Two messages in flit; VNA flit\000"
/* offset=5052710 */ "unc_m3upi_rxc_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Three Messages. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Three messages in flit; VNA flit\000"
/* offset=5052887 */ "unc_m3upi_rxc_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000\000"
/* offset=5053018 */ "unc_m3upi_rxc_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000\000"
/* offset=5053149 */ "unc_m3upi_rxc_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000\000"
/* offset=5053280 */ "unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : All. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000\000"
/* offset=5053435 */ "unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; All. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000\000"
/* offset=5053589 */ "unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Needs Data Flit. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Slotting BL Message Into Header Flit : Needs Data Flit : BL message requires data flit sequence\000"
/* offset=5053857 */ "unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Needs Data Flit. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000BL message requires data flit sequence\000"
/* offset=5054067 */ "unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 0. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 0 : Waiting for header pump 0\000"
/* offset=5054318 */ "unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 0. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000Waiting for header pump 0\000"
/* offset=5054512 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 : Header pump 1 is not required for flit\000"
/* offset=5054786 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x10\000\00001\000Header pump 1 is not required for flit\000"
/* offset=5055000 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble : Header pump 1 is not required for flit but flit transmission delayed\000"
/* offset=5055333 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x58,umask=0x20\000\00001\000Header pump 1 is not required for flit but flit transmission delayed\000"
/* offset=5055597 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail : Header pump 1 is not required for flit and not available\000"
/* offset=5055923 */ "unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x58,umask=0x40\000\00001\000Header pump 1 is not required for flit and not available\000"
/* offset=5056177 */ "unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 1 : Waiting for header pump 1\000"
/* offset=5056428 */ "unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000Waiting for header pump 1\000"
/* offset=5056622 */ "unc_m3upi_rxc_hdr_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent : All. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Header Not Sent : All : header flit is ready for transmission but could not be sent : header flit is ready for transmission but could not be sent for any reason, e.g. no credits, low tsv, stall injection\000"
/* offset=5056963 */ "unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Header Not Sent : No BGF Credits : header flit is ready for transmission but could not be sent : No BGF credits available\000"
/* offset=5057240 */ "unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Header Not Sent : No BGF Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No BGF credits available; no additional message slotted into flit\000"
/* offset=5057616 */ "unc_m3upi_rxc_hdr_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Header Not Sent : No TxQ Credits : header flit is ready for transmission but could not be sent : No TxQ credits available\000"
/* offset=5057894 */ "unc_m3upi_rxc_hdr_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Header Not Sent : No TxQ Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No TxQ credits available; no additional message slotted into flit\000"
/* offset=5058270 */ "unc_m3upi_rxc_hdr_flit_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Header Not Sent : TSV High. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Header Not Sent : TSV High : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while tsv high\000"
/* offset=5058576 */ "unc_m3upi_rxc_hdr_flit_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Header Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Header Not Sent : Cycle valid for Flit : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while cycle is valid for flit transmission\000"
/* offset=5058942 */ "unc_m3upi_rxc_hdr_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Sent Header Flit : One Message : One message in flit; VNA or non-VNA flit\000"
/* offset=5059161 */ "unc_m3upi_rxc_hdr_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message in non-VNA. Unit: uncore_m3upi \000event=0x54,umask=0x8\000\00001\000Sent Header Flit : One Message in non-VNA : One message in flit; non-VNA flit\000"
/* offset=5059399 */ "unc_m3upi_rxc_hdr_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Messages. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Sent Header Flit : Two Messages : Two messages in flit; VNA flit\000"
/* offset=5059611 */ "unc_m3upi_rxc_hdr_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Three Messages. Unit: uncore_m3upi \000event=0x54,umask=0x4\000\00001\000Sent Header Flit : Three Messages : Three messages in flit; VNA flit\000"
/* offset=5059829 */ "unc_m3upi_rxc_hdr_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Slot Taken. Unit: uncore_m3upi \000event=0x54,umask=0x10\000\00001\000\000"
/* offset=5059981 */ "unc_m3upi_rxc_hdr_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x20\000\00001\000\000"
/* offset=5060134 */ "unc_m3upi_rxc_hdr_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : All Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x40\000\00001\000\000"
/* offset=5060287 */ "unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot AD. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Message Held : Can't Slot AD : some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000"
/* offset=5060558 */ "unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot AD. Unit: uncore_m3upi \000event=0x52,umask=0x40\000\00001\000some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000"
/* offset=5060797 */ "unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Message Held : Can't Slot BL : some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000"
/* offset=5061068 */ "unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot BL. Unit: uncore_m3upi \000event=0x52,umask=0x80\000\00001\000some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000"
/* offset=5061307 */ "unc_m3upi_rxc_held.parallel_ad_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel AD Lost. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000some AD message lost contest for slot 0 (logical OR of all AD events under INGR_SLOT_LOST_MC_VN{0,1})\000"
/* offset=5061556 */ "unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Attempt. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Message Held : Parallel Attempt : ad and bl messages attempted to slot into the same flit in parallel\000"
/* offset=5061805 */ "unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Attempt. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000ad and bl messages attempted to slot into the same flit in parallel\000"
/* offset=5062019 */ "unc_m3upi_rxc_held.parallel_bl_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel BL Lost. Unit: uncore_m3upi \000event=0x52,umask=0x20\000\00001\000some BL message lost contest for slot 0 (logical OR of all BL events under INGR_SLOT_LOST_MC_VN{0,1})\000"
/* offset=5062268 */ "unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Success. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Message Held : Parallel Success : ad and bl messages were actually slotted into the same flit in parallel\000"
/* offset=5062521 */ "unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Success. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000ad and bl messages were actually slotted into the same flit in parallel\000"
/* offset=5062739 */ "unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held : VN0. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Message Held : VN0 : vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000"
/* offset=5062993 */ "unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held; VN0. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000"
/* offset=5063225 */ "unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held : VN1. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Message Held : VN1 : vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000"
/* offset=5063479 */ "unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held; VN1. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000"
/* offset=5063711 */ "unc_m3upi_rxc_inserts_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : REQ on AD. Unit: uncore_m3upi \000event=0x41,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : REQ on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5064368 */ "unc_m3upi_rxc_inserts_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x41,umask=0x1\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5064970 */ "unc_m3upi_rxc_inserts_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : RSP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : RSP on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5065652 */ "unc_m3upi_rxc_inserts_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x4\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5066279 */ "unc_m3upi_rxc_inserts_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : SNP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : SNP on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5066891 */ "unc_m3upi_rxc_inserts_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x2\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5067448 */ "unc_m3upi_rxc_inserts_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : NCB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : NCB on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5068148 */ "unc_m3upi_rxc_inserts_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x20\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5068793 */ "unc_m3upi_rxc_inserts_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : NCS on BL. Unit: uncore_m3upi \000event=0x41,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : NCS on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5069387 */ "unc_m3upi_rxc_inserts_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x41,umask=0x40\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5069926 */ "unc_m3upi_rxc_inserts_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : RSP on BL. Unit: uncore_m3upi \000event=0x41,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : RSP on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5070607 */ "unc_m3upi_rxc_inserts_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x41,umask=0x8\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5071233 */ "unc_m3upi_rxc_inserts_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : WB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : WB on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5071972 */ "unc_m3upi_rxc_inserts_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x10\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5072657 */ "unc_m3upi_rxc_inserts_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : REQ on AD. Unit: uncore_m3upi \000event=0x42,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : REQ on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5073324 */ "unc_m3upi_rxc_inserts_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x42,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5073936 */ "unc_m3upi_rxc_inserts_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : RSP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : RSP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5074628 */ "unc_m3upi_rxc_inserts_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5075265 */ "unc_m3upi_rxc_inserts_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : SNP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : SNP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5075887 */ "unc_m3upi_rxc_inserts_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5076454 */ "unc_m3upi_rxc_inserts_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : NCB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : NCB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5077164 */ "unc_m3upi_rxc_inserts_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5077819 */ "unc_m3upi_rxc_inserts_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : NCS on BL. Unit: uncore_m3upi \000event=0x42,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : NCS on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5078423 */ "unc_m3upi_rxc_inserts_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x42,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5078972 */ "unc_m3upi_rxc_inserts_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : RSP on BL. Unit: uncore_m3upi \000event=0x42,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : RSP on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5079663 */ "unc_m3upi_rxc_inserts_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x42,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5080299 */ "unc_m3upi_rxc_inserts_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : WB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : WB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5081048 */ "unc_m3upi_rxc_inserts_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5081743 */ "unc_m3upi_rxc_occupancy_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : REQ on AD. Unit: uncore_m3upi \000event=0x45,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : REQ on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5082381 */ "unc_m3upi_rxc_occupancy_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x45,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5082962 */ "unc_m3upi_rxc_occupancy_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5083625 */ "unc_m3upi_rxc_occupancy_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5084231 */ "unc_m3upi_rxc_occupancy_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : SNP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : SNP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5084824 */ "unc_m3upi_rxc_occupancy_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5085360 */ "unc_m3upi_rxc_occupancy_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : NCB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : NCB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5086041 */ "unc_m3upi_rxc_occupancy_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5086665 */ "unc_m3upi_rxc_occupancy_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : NCS on BL. Unit: uncore_m3upi \000event=0x45,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : NCS on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5087240 */ "unc_m3upi_rxc_occupancy_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x45,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5087758 */ "unc_m3upi_rxc_occupancy_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on BL. Unit: uncore_m3upi \000event=0x45,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5088420 */ "unc_m3upi_rxc_occupancy_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x45,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5089025 */ "unc_m3upi_rxc_occupancy_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : WB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : WB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5089745 */ "unc_m3upi_rxc_occupancy_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5090409 */ "unc_m3upi_rxc_occupancy_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : REQ on AD. Unit: uncore_m3upi \000event=0x46,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : REQ on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5091047 */ "unc_m3upi_rxc_occupancy_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x46,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5091628 */ "unc_m3upi_rxc_occupancy_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5092291 */ "unc_m3upi_rxc_occupancy_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5092897 */ "unc_m3upi_rxc_occupancy_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : SNP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : SNP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5093490 */ "unc_m3upi_rxc_occupancy_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5094026 */ "unc_m3upi_rxc_occupancy_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : NCB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : NCB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5094707 */ "unc_m3upi_rxc_occupancy_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5095331 */ "unc_m3upi_rxc_occupancy_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : NCS on BL. Unit: uncore_m3upi \000event=0x46,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : NCS on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5095906 */ "unc_m3upi_rxc_occupancy_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x46,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5096424 */ "unc_m3upi_rxc_occupancy_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on BL. Unit: uncore_m3upi \000event=0x46,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5097086 */ "unc_m3upi_rxc_occupancy_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x46,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5097691 */ "unc_m3upi_rxc_occupancy_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : WB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : WB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5098411 */ "unc_m3upi_rxc_occupancy_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5099075 */ "unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000VN0 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5099553 */ "unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5099982 */ "unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000VN0 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5100485 */ "unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5100939 */ "unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000VN0 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5101372 */ "unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5101756 */ "unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000VN0 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5102277 */ "unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5102749 */ "unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000VN0 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5103164 */ "unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5103530 */ "unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000VN0 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5104032 */ "unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5104485 */ "unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000VN0 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5105045 */ "unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5105557 */ "unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000VN1 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5106035 */ "unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5106464 */ "unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000VN1 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5106967 */ "unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5107421 */ "unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000VN1 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5107854 */ "unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5108238 */ "unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000VN1 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5108759 */ "unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5109231 */ "unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000VN1 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5109646 */ "unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000"
/* offset=5110012 */ "unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000VN1 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5110514 */ "unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5110967 */ "unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000VN1 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5111527 */ "unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5112039 */ "unc_m3upi_rxc_smi3_pftch.arb_lost\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Lost Arbitration. Unit: uncore_m3upi \000event=0x62,umask=0x2\000\00001\000\000"
/* offset=5112194 */ "unc_m3upi_rxc_smi3_pftch.arrived\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Arrived. Unit: uncore_m3upi \000event=0x62,umask=0x1\000\00001\000\000"
/* offset=5112339 */ "unc_m3upi_rxc_smi3_pftch.drop_old\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Old. Unit: uncore_m3upi \000event=0x62,umask=0x8\000\00001\000\000"
/* offset=5112491 */ "unc_m3upi_rxc_smi3_pftch.drop_wrap\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Wrap. Unit: uncore_m3upi \000event=0x62,umask=0x10\000\00001\000Dropped because it was overwritten by new message while prefetch queue was full\000"
/* offset=5112725 */ "unc_m3upi_rxc_smi3_pftch.slotted\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Slotted. Unit: uncore_m3upi \000event=0x62,umask=0x4\000\00001\000\000"
/* offset=5112870 */ "unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Any In Use. Unit: uncore_m3upi \000event=0x5a,umask=0x20\000\00001\000Remote VNA Credits : Any In Use : At least one remote vna credit is in use\000"
/* offset=5113090 */ "unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Any In Use. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000At least one remote vna credit is in use\000"
/* offset=5113275 */ "unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Corrected. Unit: uncore_m3upi \000event=0x5a,umask=0x1\000\00001\000Remote VNA Credits : Corrected : Number of remote vna credits corrected (local return) per cycle\000"
/* offset=5113514 */ "unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Corrected. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000Number of remote vna credits corrected (local return) per cycle\000"
/* offset=5113719 */ "unc_m3upi_rxc_vna_crd.lt10\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 10. Unit: uncore_m3upi \000event=0x5a,umask=0x10\000\00001\000Remote VNA Credits : Level < 10 : remote vna credit level is less than 10; parallel vn0/vn1 arb not possible\000"
/* offset=5113967 */ "unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 1. Unit: uncore_m3upi \000event=0x5a,umask=0x2\000\00001\000Remote VNA Credits : Level < 1 : Remote vna credit level is less than 1 (i.e. no vna credits available)\000"
/* offset=5114207 */ "unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 1. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000Remote vna credit level is less than 1 (i.e. no vna credits available)\000"
/* offset=5114413 */ "unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 4. Unit: uncore_m3upi \000event=0x5a,umask=0x4\000\00001\000Remote VNA Credits : Level < 4 : Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000"
/* offset=5114667 */ "unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 4. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000"
/* offset=5114887 */ "unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 5. Unit: uncore_m3upi \000event=0x5a,umask=0x8\000\00001\000Remote VNA Credits : Level < 5 : Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000"
/* offset=5115135 */ "unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 5. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000"
/* offset=5115350 */ "unc_m3upi_rxc_vna_crd.used\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Used. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000Number of remote vna credits consumed per cycle\000"
/* offset=5115529 */ "unc_m3upi_rxc_vna_crd_misc.req_adbl_alloc_l5\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_ADBL_ALLOC_L5. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000: remote vna credit count was less than 5 and allocation to ad or bl messages was required\000"
/* offset=5115789 */ "unc_m3upi_rxc_vna_crd_misc.req_vn01_alloc_lt10\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_VN01_ALLOC_LT10. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000: remote vna credit count was less than 10 and allocation to vn0 or vn1 was required\000"
/* offset=5116047 */ "unc_m3upi_rxc_vna_crd_misc.vn0_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000: on vn0, remote vna credits were allocated only to ad messages, not to bl\000"
/* offset=5116280 */ "unc_m3upi_rxc_vna_crd_misc.vn0_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000: on vn0, remote vna credits were allocated only to bl messages, not to ad\000"
/* offset=5116513 */ "unc_m3upi_rxc_vna_crd_misc.vn0_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000: remote vna credits were allocated only to vn0, not to vn1\000"
/* offset=5116724 */ "unc_m3upi_rxc_vna_crd_misc.vn1_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000: on vn1, remote vna credits were allocated only to ad messages, not to bl\000"
/* offset=5116957 */ "unc_m3upi_rxc_vna_crd_misc.vn1_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x80\000\00001\000: on vn1, remote vna credits were allocated only to bl messages, not to ad\000"
/* offset=5117190 */ "unc_m3upi_rxc_vna_crd_misc.vn1_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000: remote vna credits were allocated only to vn1, not to vn0\000"
/* offset=5117401 */ "unc_m3upi_rxr_busy_starved.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=5117873 */ "unc_m3upi_rxr_busy_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5118270 */ "unc_m3upi_rxr_busy_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m3upi \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5118721 */ "unc_m3upi_rxr_busy_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5119119 */ "unc_m3upi_rxr_busy_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5119575 */ "unc_m3upi_rxr_busy_starved.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000"
/* offset=5120047 */ "unc_m3upi_rxr_busy_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5120444 */ "unc_m3upi_rxr_busy_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m3upi \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5120895 */ "unc_m3upi_rxr_busy_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5121293 */ "unc_m3upi_rxr_busy_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000"
/* offset=5121749 */ "unc_m3upi_rxr_bypass.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - All. Unit: uncore_m3upi \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=5122008 */ "unc_m3upi_rxr_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5122198 */ "unc_m3upi_rxr_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m3upi \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=5122436 */ "unc_m3upi_rxr_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5122627 */ "unc_m3upi_rxr_bypass.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=5122870 */ "unc_m3upi_rxr_bypass.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AK. Unit: uncore_m3upi \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000"
/* offset=5123081 */ "unc_m3upi_rxr_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5123271 */ "unc_m3upi_rxr_bypass.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=5123518 */ "unc_m3upi_rxr_bypass.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - All. Unit: uncore_m3upi \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000"
/* offset=5123777 */ "unc_m3upi_rxr_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5123967 */ "unc_m3upi_rxr_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m3upi \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000"
/* offset=5124205 */ "unc_m3upi_rxr_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5124396 */ "unc_m3upi_rxr_bypass.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000"
/* offset=5124639 */ "unc_m3upi_rxr_bypass.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : IV. Unit: uncore_m3upi \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000"
/* offset=5124850 */ "unc_m3upi_rxr_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000"
/* offset=5125040 */ "unc_m3upi_rxr_crd_starved.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=5125524 */ "unc_m3upi_rxr_crd_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5125932 */ "unc_m3upi_rxr_crd_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5126394 */ "unc_m3upi_rxr_crd_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5126803 */ "unc_m3upi_rxr_crd_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5127270 */ "unc_m3upi_rxr_crd_starved.ak\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AK. Unit: uncore_m3upi \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5127705 */ "unc_m3upi_rxr_crd_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5128113 */ "unc_m3upi_rxr_crd_starved.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000"
/* offset=5128597 */ "unc_m3upi_rxr_crd_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5129005 */ "unc_m3upi_rxr_crd_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5129467 */ "unc_m3upi_rxr_crd_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5129876 */ "unc_m3upi_rxr_crd_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5130343 */ "unc_m3upi_rxr_crd_starved.ifv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5130804 */ "unc_m3upi_rxr_crd_starved.ifv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5131211 */ "unc_m3upi_rxr_crd_starved.iv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : IV. Unit: uncore_m3upi \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5131646 */ "unc_m3upi_rxr_crd_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5132054 */ "unc_m3upi_rxr_crd_starved_1\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation. Unit: uncore_m3upi \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000"
/* offset=5132468 */ "unc_m3upi_rxr_inserts.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - All. Unit: uncore_m3upi \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=5132802 */ "unc_m3upi_rxr_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5133062 */ "unc_m3upi_rxr_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m3upi \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5133375 */ "unc_m3upi_rxr_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5133636 */ "unc_m3upi_rxr_inserts.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5133954 */ "unc_m3upi_rxr_inserts.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AK. Unit: uncore_m3upi \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5134240 */ "unc_m3upi_rxr_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5134500 */ "unc_m3upi_rxr_inserts.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5134822 */ "unc_m3upi_rxr_inserts.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - All. Unit: uncore_m3upi \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=5135156 */ "unc_m3upi_rxr_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5135416 */ "unc_m3upi_rxr_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m3upi \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5135729 */ "unc_m3upi_rxr_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5135990 */ "unc_m3upi_rxr_inserts.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5136308 */ "unc_m3upi_rxr_inserts.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : IV. Unit: uncore_m3upi \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5136594 */ "unc_m3upi_rxr_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5136854 */ "unc_m3upi_rxr_occupancy.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m3upi \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=5137194 */ "unc_m3upi_rxr_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5137462 */ "unc_m3upi_rxr_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m3upi \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5137781 */ "unc_m3upi_rxr_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5138050 */ "unc_m3upi_rxr_occupancy.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5138374 */ "unc_m3upi_rxr_occupancy.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AK. Unit: uncore_m3upi \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5138666 */ "unc_m3upi_rxr_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5138934 */ "unc_m3upi_rxr_occupancy.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5139262 */ "unc_m3upi_rxr_occupancy.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m3upi \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000"
/* offset=5139602 */ "unc_m3upi_rxr_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5139870 */ "unc_m3upi_rxr_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m3upi \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5140189 */ "unc_m3upi_rxr_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5140458 */ "unc_m3upi_rxr_occupancy.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5140782 */ "unc_m3upi_rxr_occupancy.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : IV. Unit: uncore_m3upi \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5141074 */ "unc_m3upi_rxr_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000"
/* offset=5141342 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5141706 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5142070 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5142434 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5142798 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5143163 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5143528 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5143893 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5144258 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5144622 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5144986 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5145350 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5145714 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5146079 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5146444 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5146809 */ "unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5147174 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5147538 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5147902 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5148266 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5148630 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5148995 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5149360 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5149725 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5150090 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5150454 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5150818 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5151182 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5151546 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5151911 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5152276 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5152641 */ "unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5153006 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5153373 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5153737 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5154101 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5154470 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5154836 */ "unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5155202 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5155571 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5155937 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5156303 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5156672 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5157038 */ "unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5157404 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5157704 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5158004 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5158304 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5158604 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5158905 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5159206 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5159506 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5159806 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5160106 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5160406 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5160707 */ "unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5161008 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5161308 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5161608 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5161908 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5162208 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5162509 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5162810 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5163110 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5163410 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5163710 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5164010 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5164311 */ "unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000"
/* offset=5164612 */ "unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000Failed ARB for AD : VN0 REQ Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5164853 */ "unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5165054 */ "unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000Failed ARB for AD : VN0 RSP Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5165295 */ "unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5165496 */ "unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000Failed ARB for AD : VN0 SNP Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5165737 */ "unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5165938 */ "unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000Failed ARB for AD : VN0 WB Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5166176 */ "unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5166375 */ "unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000Failed ARB for AD : VN1 REQ Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5166617 */ "unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5166819 */ "unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000Failed ARB for AD : VN1 RSP Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5167061 */ "unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5167263 */ "unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000Failed ARB for AD : VN1 SNP Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5167505 */ "unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5167707 */ "unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000Failed ARB for AD : VN1 WB Messages : AD arb but no win; arb request asserted but not won\000"
/* offset=5167946 */ "unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000AD arb but no win; arb request asserted but not won\000"
/* offset=5168146 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5168441 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5168718 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5169013 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5169290 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5169585 */ "unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5169862 */ "unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5170161 */ "unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5170442 */ "unc_m3upi_txc_ad_flq_bypass\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000"
/* offset=5170738 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000AD Flow Q Not Empty : VN0 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5170986 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5171192 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000AD Flow Q Not Empty : VN0 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5171440 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5171646 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000AD Flow Q Not Empty : VN0 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5171894 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5172100 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000AD Flow Q Not Empty : VN0 WB Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5172345 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5172549 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000AD Flow Q Not Empty : VN1 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5172798 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5173005 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000AD Flow Q Not Empty : VN1 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5173254 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5173461 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000AD Flow Q Not Empty : VN1 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5173710 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5173917 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000AD Flow Q Not Empty : VN1 WB Messages : Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5174163 */ "unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000Number of cycles the AD Egress queue is Not Empty\000"
/* offset=5174368 */ "unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000AD Flow Q Inserts : VN0 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5174859 */ "unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5175310 */ "unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000AD Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5175801 */ "unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5176252 */ "unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000AD Flow Q Inserts : VN0 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5176743 */ "unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5177194 */ "unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000AD Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5177682 */ "unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5178131 */ "unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000AD Flow Q Inserts : VN1 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5178623 */ "unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5179075 */ "unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000AD Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5179567 */ "unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5180019 */ "unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000AD Flow Q Inserts : VN1 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5180511 */ "unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5180963 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000"
/* offset=5181121 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000"
/* offset=5181278 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000"
/* offset=5181436 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000"
/* offset=5181593 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=5181751 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000"
/* offset=5181908 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000"
/* offset=5182064 */ "unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000"
/* offset=5182219 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000"
/* offset=5182378 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000"
/* offset=5182536 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000"
/* offset=5182695 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000"
/* offset=5182853 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000"
/* offset=5183012 */ "unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000"
/* offset=5183170 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x4\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to CHA\000"
/* offset=5183450 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x40\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn0 Snpf\000"
/* offset=5183768 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x1\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI0\000"
/* offset=5184066 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x2\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI1\000"
/* offset=5184364 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x20\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to CHA\000"
/* offset=5184645 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x80\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn1 Snpf\000"
/* offset=5184963 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x8\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI0\000"
/* offset=5185261 */ "unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x10\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI1\000"
/* offset=5185560 */ "unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x1\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn0\000"
/* offset=5185795 */ "unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_vn2snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x4\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn0 SnpF issued when SnpF pending on Vn1\000"
/* offset=5186040 */ "unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x2\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn1\000"
/* offset=5186275 */ "unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_vn0snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x8\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn1 SnpF issued when SnpF pending on Vn0\000"
/* offset=5186520 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x1\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5186788 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x2\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5187056 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x8\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5187322 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x10\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5187591 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x20\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5187860 */ "unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x80\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000"
/* offset=5188127 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x1\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5188389 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x2\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5188651 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x8\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5188911 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x10\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5189174 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x20\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5189437 */ "unc_m3upi_txc_ad_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x80\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5189698 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x1\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5190004 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x4\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5190310 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x2\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5190616 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x8\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5190920 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x10\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5191227 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x40\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5191534 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x20\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5191841 */ "unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x80\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5192146 */ "unc_m3upi_txc_ak_flq_inserts\000uncore_m3upi\000uncore interconnect\000AK Flow Q Inserts. Unit: uncore_m3upi \000event=0x2f\000\00001\000\000"
/* offset=5192263 */ "unc_m3upi_txc_ak_flq_occupancy\000uncore_m3upi\000uncore interconnect\000AK Flow Q Occupancy. Unit: uncore_m3upi \000event=0x1e\000\00001\000\000"
/* offset=5192384 */ "unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000Failed ARB for BL : VN0 NCB Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5192625 */ "unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5192826 */ "unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000Failed ARB for BL : VN0 NCS Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5193067 */ "unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5193268 */ "unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000Failed ARB for BL : VN0 RSP Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5193509 */ "unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5193710 */ "unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000Failed ARB for BL : VN0 WB Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5193948 */ "unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5194147 */ "unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000Failed ARB for BL : VN1 NCS Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5194389 */ "unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5194591 */ "unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000Failed ARB for BL : VN1 NCB Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5194833 */ "unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5195035 */ "unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000Failed ARB for BL : VN1 RSP Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5195277 */ "unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5195479 */ "unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000Failed ARB for BL : VN1 WB Messages : BL arb but no win; arb request asserted but not won\000"
/* offset=5195718 */ "unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000BL arb but no win; arb request asserted but not won\000"
/* offset=5195918 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000BL Flow Q Not Empty : VN0 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5196166 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5196372 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000BL Flow Q Not Empty : VN0 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5196620 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5196826 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000BL Flow Q Not Empty : VN0 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5197074 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5197280 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000BL Flow Q Not Empty : VN0 WB Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5197525 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5197729 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000BL Flow Q Not Empty : VN1 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5197978 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5198185 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000BL Flow Q Not Empty : VN1 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5198434 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5198641 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000BL Flow Q Not Empty : VN1 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5198890 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5199097 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000BL Flow Q Not Empty : VN1 WB Messages : Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5199343 */ "unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000Number of cycles the BL Egress queue is Not Empty\000"
/* offset=5199548 */ "unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000BL Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5200039 */ "unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5200490 */ "unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000BL Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5200979 */ "unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5201429 */ "unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000BL Flow Q Inserts : VN0 NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5201920 */ "unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5202371 */ "unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000BL Flow Q Inserts : VN0 NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5202861 */ "unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5203311 */ "unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000BL Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5203803 */ "unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5204255 */ "unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000BL Flow Q Inserts : VN1 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5204745 */ "unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5205196 */ "unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000BL Flow Q Inserts : VN1_NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5205688 */ "unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5206140 */ "unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000BL Flow Q Inserts : VN1_NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5206631 */ "unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5207082 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000"
/* offset=5207240 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000"
/* offset=5207397 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000"
/* offset=5207555 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000"
/* offset=5207712 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=5207870 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000"
/* offset=5208027 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=5208183 */ "unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000"
/* offset=5208338 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000"
/* offset=5208497 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000"
/* offset=5208655 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000"
/* offset=5208814 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000"
/* offset=5208972 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000"
/* offset=5209131 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000"
/* offset=5209289 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000"
/* offset=5209446 */ "unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000"
/* offset=5209602 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x2\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5209863 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x38,umask=0x8\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5210125 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x1\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5210385 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x20\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5210647 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x80\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5210910 */ "unc_m3upi_txc_bl_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x38,umask=0x10\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000"
/* offset=5211172 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x4\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5211484 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x8\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5211796 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x1\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5212108 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x2\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5212418 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x40\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5212731 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x80\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5213044 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x10\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5213357 */ "unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x20\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000"
/* offset=5213668 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn0_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x1\000\00001\000\000"
/* offset=5213831 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn0_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x2\000\00001\000\000"
/* offset=5213995 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn0_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x4\000\00001\000\000"
/* offset=5214159 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn1_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x10\000\00001\000\000"
/* offset=5214323 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn1_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x20\000\00001\000\000"
/* offset=5214488 */ "unc_m3upi_txc_bl_wb_flq_occupancy.vn1_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x40\000\00001\000\000"
/* offset=5214653 */ "unc_m3upi_txr_horz_ads_used.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m3upi \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=5214970 */ "unc_m3upi_txr_horz_ads_used.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5215219 */ "unc_m3upi_txr_horz_ads_used.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m3upi \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5215514 */ "unc_m3upi_txr_horz_ads_used.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5215764 */ "unc_m3upi_txr_horz_ads_used.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m3upi \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5216064 */ "unc_m3upi_txr_horz_ads_used.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5216313 */ "unc_m3upi_txr_horz_ads_used.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m3upi \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=5216630 */ "unc_m3upi_txr_horz_ads_used.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5216879 */ "unc_m3upi_txr_horz_ads_used.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m3upi \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5217174 */ "unc_m3upi_txr_horz_ads_used.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5217424 */ "unc_m3upi_txr_horz_ads_used.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m3upi \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5217724 */ "unc_m3upi_txr_horz_bypass.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m3upi \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=5218037 */ "unc_m3upi_txr_horz_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5218279 */ "unc_m3upi_txr_horz_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m3upi \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5218570 */ "unc_m3upi_txr_horz_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5218813 */ "unc_m3upi_txr_horz_bypass.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5219109 */ "unc_m3upi_txr_horz_bypass.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AK. Unit: uncore_m3upi \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5219373 */ "unc_m3upi_txr_horz_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5219615 */ "unc_m3upi_txr_horz_bypass.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5219915 */ "unc_m3upi_txr_horz_bypass.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m3upi \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000"
/* offset=5220228 */ "unc_m3upi_txr_horz_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5220470 */ "unc_m3upi_txr_horz_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m3upi \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5220761 */ "unc_m3upi_txr_horz_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5221004 */ "unc_m3upi_txr_horz_bypass.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5221300 */ "unc_m3upi_txr_horz_bypass.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : IV. Unit: uncore_m3upi \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5221564 */ "unc_m3upi_txr_horz_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000"
/* offset=5221806 */ "unc_m3upi_txr_horz_cycles_full.ad_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m3upi \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5222216 */ "unc_m3upi_txr_horz_cycles_full.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5222539 */ "unc_m3upi_txr_horz_cycles_full.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m3upi \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5222927 */ "unc_m3upi_txr_horz_cycles_full.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5223251 */ "unc_m3upi_txr_horz_cycles_full.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5223644 */ "unc_m3upi_txr_horz_cycles_full.ak\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m3upi \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5224005 */ "unc_m3upi_txr_horz_cycles_full.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5224328 */ "unc_m3upi_txr_horz_cycles_full.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5224725 */ "unc_m3upi_txr_horz_cycles_full.bl_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m3upi \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5225135 */ "unc_m3upi_txr_horz_cycles_full.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5225458 */ "unc_m3upi_txr_horz_cycles_full.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m3upi \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5225846 */ "unc_m3upi_txr_horz_cycles_full.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5226170 */ "unc_m3upi_txr_horz_cycles_full.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5226563 */ "unc_m3upi_txr_horz_cycles_full.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m3upi \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5226924 */ "unc_m3upi_txr_horz_cycles_full.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5227247 */ "unc_m3upi_txr_horz_cycles_ne.ad_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m3upi \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5227670 */ "unc_m3upi_txr_horz_cycles_ne.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5228001 */ "unc_m3upi_txr_horz_cycles_ne.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m3upi \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5228402 */ "unc_m3upi_txr_horz_cycles_ne.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5228734 */ "unc_m3upi_txr_horz_cycles_ne.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5229140 */ "unc_m3upi_txr_horz_cycles_ne.ak\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m3upi \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5229514 */ "unc_m3upi_txr_horz_cycles_ne.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5229845 */ "unc_m3upi_txr_horz_cycles_ne.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5230255 */ "unc_m3upi_txr_horz_cycles_ne.bl_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m3upi \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5230678 */ "unc_m3upi_txr_horz_cycles_ne.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5231009 */ "unc_m3upi_txr_horz_cycles_ne.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m3upi \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5231410 */ "unc_m3upi_txr_horz_cycles_ne.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5231742 */ "unc_m3upi_txr_horz_cycles_ne.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5232148 */ "unc_m3upi_txr_horz_cycles_ne.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m3upi \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5232522 */ "unc_m3upi_txr_horz_cycles_ne.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5232853 */ "unc_m3upi_txr_horz_inserts.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m3upi \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5233243 */ "unc_m3upi_txr_horz_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5233559 */ "unc_m3upi_txr_horz_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m3upi \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5233927 */ "unc_m3upi_txr_horz_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5234244 */ "unc_m3upi_txr_horz_inserts.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5234617 */ "unc_m3upi_txr_horz_inserts.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m3upi \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5234958 */ "unc_m3upi_txr_horz_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5235274 */ "unc_m3upi_txr_horz_inserts.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5235651 */ "unc_m3upi_txr_horz_inserts.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m3upi \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5236041 */ "unc_m3upi_txr_horz_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5236357 */ "unc_m3upi_txr_horz_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m3upi \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5236725 */ "unc_m3upi_txr_horz_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5237042 */ "unc_m3upi_txr_horz_inserts.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5237415 */ "unc_m3upi_txr_horz_inserts.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m3upi \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5237756 */ "unc_m3upi_txr_horz_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5238072 */ "unc_m3upi_txr_horz_nack.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m3upi \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=5238360 */ "unc_m3upi_txr_horz_nack.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5238577 */ "unc_m3upi_txr_horz_nack.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m3upi \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5238844 */ "unc_m3upi_txr_horz_nack.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5239062 */ "unc_m3upi_txr_horz_nack.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5239334 */ "unc_m3upi_txr_horz_nack.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m3upi \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5239574 */ "unc_m3upi_txr_horz_nack.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5239791 */ "unc_m3upi_txr_horz_nack.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5240067 */ "unc_m3upi_txr_horz_nack.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m3upi \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000"
/* offset=5240355 */ "unc_m3upi_txr_horz_nack.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5240572 */ "unc_m3upi_txr_horz_nack.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m3upi \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5240839 */ "unc_m3upi_txr_horz_nack.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5241057 */ "unc_m3upi_txr_horz_nack.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5241329 */ "unc_m3upi_txr_horz_nack.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m3upi \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5241569 */ "unc_m3upi_txr_horz_nack.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000"
/* offset=5241786 */ "unc_m3upi_txr_horz_occupancy.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m3upi \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5242175 */ "unc_m3upi_txr_horz_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5242488 */ "unc_m3upi_txr_horz_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m3upi \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5242855 */ "unc_m3upi_txr_horz_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5243169 */ "unc_m3upi_txr_horz_occupancy.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5243541 */ "unc_m3upi_txr_horz_occupancy.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m3upi \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5243881 */ "unc_m3upi_txr_horz_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5244194 */ "unc_m3upi_txr_horz_occupancy.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5244570 */ "unc_m3upi_txr_horz_occupancy.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m3upi \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000"
/* offset=5244959 */ "unc_m3upi_txr_horz_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5245272 */ "unc_m3upi_txr_horz_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m3upi \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5245639 */ "unc_m3upi_txr_horz_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5245953 */ "unc_m3upi_txr_horz_occupancy.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5246325 */ "unc_m3upi_txr_horz_occupancy.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m3upi \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5246665 */ "unc_m3upi_txr_horz_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000"
/* offset=5246978 */ "unc_m3upi_txr_horz_starved.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=5247400 */ "unc_m3upi_txr_horz_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5247736 */ "unc_m3upi_txr_horz_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5248142 */ "unc_m3upi_txr_horz_starved.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m3upi \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5248516 */ "unc_m3upi_txr_horz_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5248852 */ "unc_m3upi_txr_horz_starved.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5249262 */ "unc_m3upi_txr_horz_starved.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000"
/* offset=5249684 */ "unc_m3upi_txr_horz_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5250020 */ "unc_m3upi_txr_horz_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5250426 */ "unc_m3upi_txr_horz_starved.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m3upi \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5250800 */ "unc_m3upi_txr_horz_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000"
/* offset=5251136 */ "unc_m3upi_txr_vert_ads_used.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5251422 */ "unc_m3upi_txr_vert_ads_used.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5251668 */ "unc_m3upi_txr_vert_ads_used.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5251955 */ "unc_m3upi_txr_vert_ads_used.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5252202 */ "unc_m3upi_txr_vert_ads_used.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5252448 */ "unc_m3upi_txr_vert_ads_used.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5252695 */ "unc_m3upi_txr_vert_ads_used.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5252981 */ "unc_m3upi_txr_vert_ads_used.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5253227 */ "unc_m3upi_txr_vert_ads_used.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5253514 */ "unc_m3upi_txr_vert_ads_used.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000"
/* offset=5253761 */ "unc_m3upi_txr_vert_bypass.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5254037 */ "unc_m3upi_txr_vert_bypass.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5254273 */ "unc_m3upi_txr_vert_bypass.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5254550 */ "unc_m3upi_txr_vert_bypass.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5254787 */ "unc_m3upi_txr_vert_bypass.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5255063 */ "unc_m3upi_txr_vert_bypass.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5255299 */ "unc_m3upi_txr_vert_bypass.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5255576 */ "unc_m3upi_txr_vert_bypass.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5255813 */ "unc_m3upi_txr_vert_bypass.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5256089 */ "unc_m3upi_txr_vert_bypass.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5256325 */ "unc_m3upi_txr_vert_bypass.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5256602 */ "unc_m3upi_txr_vert_bypass.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5256839 */ "unc_m3upi_txr_vert_bypass.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m3upi \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5257061 */ "unc_m3upi_txr_vert_bypass.iv_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5257337 */ "unc_m3upi_txr_vert_bypass_1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5257618 */ "unc_m3upi_txr_vert_bypass_1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000"
/* offset=5257899 */ "unc_m3upi_txr_vert_cycles_full.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5258350 */ "unc_m3upi_txr_vert_cycles_full.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5258770 */ "unc_m3upi_txr_vert_cycles_full.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5259203 */ "unc_m3upi_txr_vert_cycles_full.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5259577 */ "unc_m3upi_txr_vert_cycles_full.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5260026 */ "unc_m3upi_txr_vert_cycles_full.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5260469 */ "unc_m3upi_txr_vert_cycles_full.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m3upi \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5260876 */ "unc_m3upi_txr_vert_cycles_full0.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5261388 */ "unc_m3upi_txr_vert_cycles_full0.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5261869 */ "unc_m3upi_txr_vert_cycles_full0.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5262363 */ "unc_m3upi_txr_vert_cycles_full0.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5262798 */ "unc_m3upi_txr_vert_cycles_full0.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5263308 */ "unc_m3upi_txr_vert_cycles_full0.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5263812 */ "unc_m3upi_txr_vert_cycles_full0.iv_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5264294 */ "unc_m3upi_txr_vert_cycles_full1.akc_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m3upi \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5264809 */ "unc_m3upi_txr_vert_cycles_full1.akc_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m3upi \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5265306 */ "unc_m3upi_txr_vert_cycles_ne.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5265761 */ "unc_m3upi_txr_vert_cycles_ne.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5266185 */ "unc_m3upi_txr_vert_cycles_ne.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5266622 */ "unc_m3upi_txr_vert_cycles_ne.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5267000 */ "unc_m3upi_txr_vert_cycles_ne.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5267453 */ "unc_m3upi_txr_vert_cycles_ne.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5267900 */ "unc_m3upi_txr_vert_cycles_ne.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m3upi \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5268311 */ "unc_m3upi_txr_vert_cycles_ne0.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5268832 */ "unc_m3upi_txr_vert_cycles_ne0.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5269322 */ "unc_m3upi_txr_vert_cycles_ne0.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5269825 */ "unc_m3upi_txr_vert_cycles_ne0.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5270269 */ "unc_m3upi_txr_vert_cycles_ne0.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5270788 */ "unc_m3upi_txr_vert_cycles_ne0.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5271301 */ "unc_m3upi_txr_vert_cycles_ne0.iv_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5271792 */ "unc_m3upi_txr_vert_cycles_ne1.akc_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m3upi \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5272316 */ "unc_m3upi_txr_vert_cycles_ne1.akc_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m3upi \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5272822 */ "unc_m3upi_txr_vert_inserts.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5273253 */ "unc_m3upi_txr_vert_inserts.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5273653 */ "unc_m3upi_txr_vert_inserts.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5274066 */ "unc_m3upi_txr_vert_inserts.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5274420 */ "unc_m3upi_txr_vert_inserts.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5274849 */ "unc_m3upi_txr_vert_inserts.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5275272 */ "unc_m3upi_txr_vert_inserts.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m3upi \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5275659 */ "unc_m3upi_txr_vert_inserts0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5276138 */ "unc_m3upi_txr_vert_inserts0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5276586 */ "unc_m3upi_txr_vert_inserts0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5277047 */ "unc_m3upi_txr_vert_inserts0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5277449 */ "unc_m3upi_txr_vert_inserts0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5277926 */ "unc_m3upi_txr_vert_inserts0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5278397 */ "unc_m3upi_txr_vert_inserts0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5278846 */ "unc_m3upi_txr_vert_inserts1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5279328 */ "unc_m3upi_txr_vert_inserts1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5279792 */ "unc_m3upi_txr_vert_nack.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5280006 */ "unc_m3upi_txr_vert_nack.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5280221 */ "unc_m3upi_txr_vert_nack.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5280435 */ "unc_m3upi_txr_vert_nack.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5280650 */ "unc_m3upi_txr_vert_nack.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5280864 */ "unc_m3upi_txr_vert_nack.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5281079 */ "unc_m3upi_txr_vert_nack.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m3upi \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5281279 */ "unc_m3upi_txr_vert_nack0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5281538 */ "unc_m3upi_txr_vert_nack0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5281798 */ "unc_m3upi_txr_vert_nack0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5282057 */ "unc_m3upi_txr_vert_nack0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5282317 */ "unc_m3upi_txr_vert_nack0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5282576 */ "unc_m3upi_txr_vert_nack0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5282836 */ "unc_m3upi_txr_vert_nack0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : IV. Unit: uncore_m3upi \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5283075 */ "unc_m3upi_txr_vert_nack1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m3upi \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5283337 */ "unc_m3upi_txr_vert_nack1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m3upi \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000"
/* offset=5283599 */ "unc_m3upi_txr_vert_occupancy.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5284037 */ "unc_m3upi_txr_vert_occupancy.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5284444 */ "unc_m3upi_txr_vert_occupancy.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5284864 */ "unc_m3upi_txr_vert_occupancy.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5285225 */ "unc_m3upi_txr_vert_occupancy.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5285661 */ "unc_m3upi_txr_vert_occupancy.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5286091 */ "unc_m3upi_txr_vert_occupancy.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m3upi \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5286485 */ "unc_m3upi_txr_vert_occupancy0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5286969 */ "unc_m3upi_txr_vert_occupancy0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000"
/* offset=5287422 */ "unc_m3upi_txr_vert_occupancy0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5287888 */ "unc_m3upi_txr_vert_occupancy0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000"
/* offset=5288295 */ "unc_m3upi_txr_vert_occupancy0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000"
/* offset=5288777 */ "unc_m3upi_txr_vert_occupancy0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000"
/* offset=5289253 */ "unc_m3upi_txr_vert_occupancy0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000"
/* offset=5289707 */ "unc_m3upi_txr_vert_occupancy1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000"
/* offset=5290194 */ "unc_m3upi_txr_vert_occupancy1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000"
/* offset=5290663 */ "unc_m3upi_txr_vert_starved.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5290985 */ "unc_m3upi_txr_vert_starved.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5291308 */ "unc_m3upi_txr_vert_starved.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5291630 */ "unc_m3upi_txr_vert_starved.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5291953 */ "unc_m3upi_txr_vert_starved.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5292275 */ "unc_m3upi_txr_vert_starved.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5292598 */ "unc_m3upi_txr_vert_starved.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m3upi \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5292906 */ "unc_m3upi_txr_vert_starved0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5293288 */ "unc_m3upi_txr_vert_starved0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5293671 */ "unc_m3upi_txr_vert_starved0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5294053 */ "unc_m3upi_txr_vert_starved0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5294436 */ "unc_m3upi_txr_vert_starved0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5294818 */ "unc_m3upi_txr_vert_starved0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5295201 */ "unc_m3upi_txr_vert_starved0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m3upi \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5295563 */ "unc_m3upi_txr_vert_starved1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5295948 */ "unc_m3upi_txr_vert_starved1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m3upi \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5296333 */ "unc_m3upi_txr_vert_starved1.tgc\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000"
/* offset=5296714 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000UPI0 AD Credits Empty : VN0 REQ Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5296973 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5297188 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000UPI0 AD Credits Empty : VN0 RSP Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5297447 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5297662 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000UPI0 AD Credits Empty : VN0 SNP Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5297921 */ "unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5298136 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000UPI0 AD Credits Empty : VN1 REQ Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5298396 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5298612 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000UPI0 AD Credits Empty : VN1 RSP Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5298872 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5299088 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000UPI0 AD Credits Empty : VN1 SNP Messages : No credits available to send to UPIs on the AD Ring\000"
/* offset=5299348 */ "unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5299564 */ "unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000UPI0 AD Credits Empty : VNA : No credits available to send to UPIs on the AD Ring\000"
/* offset=5299793 */ "unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000No credits available to send to UPIs on the AD Ring\000"
/* offset=5299991 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000UPI0 BL Credits Empty : VN0 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5300289 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5300543 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000UPI0 BL Credits Empty : VN0 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5300837 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5301087 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000UPI0 BL Credits Empty : VN0 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5301380 */ "unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5301629 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000UPI0 BL Credits Empty : VN1 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5301928 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5302183 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000UPI0 BL Credits Empty : VN1 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5302478 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5302729 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000UPI0 BL Credits Empty : VN1 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5303023 */ "unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5303273 */ "unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000UPI0 BL Credits Empty : VNA : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5303537 */ "unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000"
/* offset=5303770 */ "unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000FlowQ Generated Prefetch. Unit: uncore_m3upi \000event=0x29\000\00001\000FlowQ Generated Prefetch : Count cases where FlowQ causes spawn of Prefetch to iMC/SMI3 target\000"
/* offset=5303988 */ "unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000Prefetches generated by the flow control queue of the M3UPI unit. Unit: uncore_m3upi \000event=0x29\000\00001\000Count cases where flow control queue that sits between the Intel(R) Ultra Path Interconnect (UPI) and the mesh spawns a prefetch to the iMC (Memory Controller)\000"
/* offset=5304311 */ "unc_m3upi_vert_ring_ad_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5305237 */ "unc_m3upi_vert_ring_ad_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5306120 */ "unc_m3upi_vert_ring_ad_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5307043 */ "unc_m3upi_vert_ring_ad_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5307924 */ "unc_m3upi_vert_ring_ad_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5308846 */ "unc_m3upi_vert_ring_ad_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5309727 */ "unc_m3upi_vert_ring_ad_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5310646 */ "unc_m3upi_vert_ring_ad_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5311525 */ "unc_m3upi_vert_ring_ak_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5312451 */ "unc_m3upi_vert_ring_ak_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5313334 */ "unc_m3upi_vert_ring_ak_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5314257 */ "unc_m3upi_vert_ring_ak_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5315138 */ "unc_m3upi_vert_ring_ak_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5316060 */ "unc_m3upi_vert_ring_ak_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5316941 */ "unc_m3upi_vert_ring_ak_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5317860 */ "unc_m3upi_vert_ring_ak_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5318739 */ "unc_m3upi_vert_ring_akc_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5319673 */ "unc_m3upi_vert_ring_akc_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5320604 */ "unc_m3upi_vert_ring_akc_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5321534 */ "unc_m3upi_vert_ring_akc_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5322461 */ "unc_m3upi_vert_ring_bl_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m3upi \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5323385 */ "unc_m3upi_vert_ring_bl_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5324266 */ "unc_m3upi_vert_ring_bl_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m3upi \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5325187 */ "unc_m3upi_vert_ring_bl_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5326066 */ "unc_m3upi_vert_ring_bl_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m3upi \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5326986 */ "unc_m3upi_vert_ring_bl_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5327865 */ "unc_m3upi_vert_ring_bl_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m3upi \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5328782 */ "unc_m3upi_vert_ring_bl_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5329659 */ "unc_m3upi_vert_ring_iv_in_use.dn\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use : Down. Unit: uncore_m3upi \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=5330257 */ "unc_m3upi_vert_ring_iv_in_use.dn\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m3upi \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=5330821 */ "unc_m3upi_vert_ring_iv_in_use.up\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use : Up. Unit: uncore_m3upi \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=5331415 */ "unc_m3upi_vert_ring_iv_in_use.up\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m3upi \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000"
/* offset=5331977 */ "unc_m3upi_vert_ring_tgc_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5332911 */ "unc_m3upi_vert_ring_tgc_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5333842 */ "unc_m3upi_vert_ring_tgc_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5334772 */ "unc_m3upi_vert_ring_tgc_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=5335699 */ "unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000VN0 Credit Used : WB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5336863 */ "unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5337996 */ "unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000VN0 Credit Used : NCB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5339120 */ "unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5340212 */ "unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000VN0 Credit Used : REQ on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5341293 */ "unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5342342 */ "unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000VN0 Credit Used : RSP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5343448 */ "unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5344522 */ "unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000VN0 Credit Used : SNP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5345558 */ "unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5346562 */ "unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000VN0 Credit Used : RSP on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5347666 */ "unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5348738 */ "unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000VN0 No Credits : WB on BL : Number of Cycles there were no VN0 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5349137 */ "unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000Number of Cycles there were no VN0 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5349506 */ "unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000VN0 No Credits : NCB on BL : Number of Cycles there were no VN0 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5349865 */ "unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000Number of Cycles there were no VN0 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5350193 */ "unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000VN0 No Credits : REQ on AD : Number of Cycles there were no VN0 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5350509 */ "unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000Number of Cycles there were no VN0 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5350794 */ "unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000VN0 No Credits : RSP on AD : Number of Cycles there were no VN0 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5351135 */ "unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5351445 */ "unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000VN0 No Credits : SNP on AD : Number of Cycles there were no VN0 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5351716 */ "unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000Number of Cycles there were no VN0 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5351956 */ "unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000VN0 No Credits : RSP on BL : Number of Cycles there were no VN0 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5352295 */ "unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5352603 */ "unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000VN1 Credit Used : WB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5353766 */ "unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5354898 */ "unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000VN1 Credit Used : NCB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5356021 */ "unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5357112 */ "unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000VN1 Credit Used : REQ on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5358192 */ "unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5359240 */ "unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000VN1 Credit Used : RSP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5360345 */ "unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5361418 */ "unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000VN1 Credit Used : SNP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5362453 */ "unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5363456 */ "unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000VN1 Credit Used : RSP on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5364559 */ "unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5365630 */ "unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000VN1 No Credits : WB on BL : Number of Cycles there were no VN1 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5366029 */ "unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Number of Cycles there were no VN1 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000"
/* offset=5366398 */ "unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000VN1 No Credits : NCB on BL : Number of Cycles there were no VN1 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5366757 */ "unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Number of Cycles there were no VN1 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5367085 */ "unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000VN1 No Credits : REQ on AD : Number of Cycles there were no VN1 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5367401 */ "unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Number of Cycles there were no VN1 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000"
/* offset=5367686 */ "unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000VN1 No Credits : RSP on AD : Number of Cycles there were no VN1 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5368027 */ "unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5368337 */ "unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000VN1 No Credits : SNP on AD : Number of Cycles there were no VN1 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5368608 */ "unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Number of Cycles there were no VN1 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000"
/* offset=5368848 */ "unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000VN1 No Credits : RSP on BL : Number of Cycles there were no VN1 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5369187 */ "unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5369495 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x82\000\00001\000\000"
/* offset=5369690 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xa0\000\00001\000\000"
/* offset=5369885 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x81\000\00001\000\000"
/* offset=5370080 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x90\000\00001\000\000"
/* offset=5370275 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x84\000\00001\000\000"
/* offset=5370470 */ "unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xc0\000\00001\000\000"
/* offset=5370665 */ "unc_m3upi_wb_occ_compare.rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x2\000\00001\000\000"
/* offset=5370835 */ "unc_m3upi_wb_occ_compare.rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x20\000\00001\000\000"
/* offset=5371006 */ "unc_m3upi_wb_occ_compare.rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x1\000\00001\000\000"
/* offset=5371176 */ "unc_m3upi_wb_occ_compare.rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x10\000\00001\000\000"
/* offset=5371347 */ "unc_m3upi_wb_occ_compare.rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x4\000\00001\000\000"
/* offset=5371517 */ "unc_m3upi_wb_occ_compare.rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x40\000\00001\000\000"
/* offset=5371688 */ "unc_m3upi_wb_pending.local_and_rt_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x4\000\00001\000\000"
/* offset=5371844 */ "unc_m3upi_wb_pending.local_and_rt_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x40\000\00001\000\000"
/* offset=5372001 */ "unc_m3upi_wb_pending.localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x1\000\00001\000\000"
/* offset=5372151 */ "unc_m3upi_wb_pending.localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x10\000\00001\000\000"
/* offset=5372302 */ "unc_m3upi_wb_pending.routethru_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x2\000\00001\000\000"
/* offset=5372452 */ "unc_m3upi_wb_pending.routethru_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x20\000\00001\000\000"
/* offset=5372603 */ "unc_m3upi_wb_pending.waiting4pull_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x8\000\00001\000\000"
/* offset=5372759 */ "unc_m3upi_wb_pending.waiting4pull_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x80\000\00001\000\000"
/* offset=5372916 */ "unc_m3upi_xpt_pftch.arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARB. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000: xpt prefetch message is making arbitration request\000"
/* offset=5373096 */ "unc_m3upi_xpt_pftch.arrived\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARRIVED. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000: xpt prefetch message arrived in ingress pipeline\000"
/* offset=5373282 */ "unc_m3upi_xpt_pftch.bypass\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.BYPASS. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000: xpt prefetch message took bypass path\000"
/* offset=5373455 */ "unc_m3upi_xpt_pftch.flitted\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.FLITTED. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000: xpt prefetch message was slotted into flit (non bypass)\000"
/* offset=5373649 */ "unc_m3upi_xpt_pftch.lost_arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_ARB. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000: xpt prefetch message lost arbitration\000"
/* offset=5373826 */ "unc_m3upi_xpt_pftch.lost_old\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_OLD. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000: xpt prefetch message was dropped because it became too old\000"
/* offset=5374025 */ "unc_m3upi_xpt_pftch.lost_qfull\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_QFULL. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000: xpt prefetch message was dropped because it was overwritten by new message while prefetch queue was full\000"
/* offset=5374274 */ "unc_m3upi_xpt_pftch.lost_qfull\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_QFULL. Unit: uncore_m3upi \000event=0x61,umask=0x40\000\00001\000: xpt prefetch message was dropped because it was overwritten by new message while prefetch queue was full\000"
/* offset=5374523 */ "unc_m_act_count.all\000uncore_imc\000uncore memory\000Activate due to read, write, underfill, or bypass. Unit: uncore_imc \000event=0x2,umask=0xff\000\00001\000DRAM Activate Count : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5374991 */ "unc_m_act_count.all\000uncore_imc\000uncore memory\000DRAM Activate Count : All Activates. Unit: uncore_imc \000event=0x1,umask=0xb\000\00001\000DRAM Activate Count : All Activates : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5375460 */ "unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count : Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000DRAM Activate Count : Activate due to Bypass : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5375947 */ "unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5376386 */ "unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5376824 */ "unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5377260 */ "unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5377697 */ "unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Page Activate commands sent due to a write request. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts DRAM Page Activate commands sent on this channel due to a write request to the iMC (Memory Controller).  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS (Column Access Select) command\000"
/* offset=5378098 */ "unc_m_act_count\000uncore_imc\000uncore memory\000DRAM Activate Count. Unit: uncore_imc \000event=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5378499 */ "unc_m_act_count_rd\000uncore_imc\000uncore memory\000ACT command for a read request sent to DRAM. Unit: uncore_imc \000event=0x24\000\00001\000\000"
/* offset=5378622 */ "unc_m_act_count_total\000uncore_imc\000uncore memory\000ACT command sent to DRAM. Unit: uncore_imc \000event=0x26\000\00001\000\000"
/* offset=5378729 */ "unc_m_act_count_wr\000uncore_imc\000uncore memory\000ACT command for a write request sent to DRAM. Unit: uncore_imc \000event=0x25\000\00001\000\000"
/* offset=5378853 */ "unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000"
/* offset=5378979 */ "unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000"
/* offset=5379105 */ "unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000"
/* offset=5379231 */ "unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, so this event increments for every read and write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000"
/* offset=5379676 */ "unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x3f\000\00001\000Counts the total number of DRAM CAS commands issued on this channel\000"
/* offset=5379862 */ "unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xff\000\00001\000DRAM RD_CAS and WR_CAS Commands. : All DRAM Read and Write actions : DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM CAS commands issued on this channel\000"
/* offset=5380151 */ "unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM CAS commands issued on this channel\000"
/* offset=5380414 */ "unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000\000"
/* offset=5380577 */ "unc_m_cas_count.all\000uncore_imc_dclk\000uncore memory\000CAS All. Unit: uncore_imc_dclk \000event=0x3,umask=0x3\000\00001\000\000"
/* offset=5380684 */ "unc_m_cas_count.pch0\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 0. Unit: uncore_imc \000event=0x5,umask=0x40\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 0 : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5380912 */ "unc_m_cas_count.pch1\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 1. Unit: uncore_imc \000event=0x5,umask=0x80\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 1 : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5381140 */ "unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000"
/* offset=5381681 */ "unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts the total number of DRAM Read CAS commands, w/ and w/o auto-pre, issued on this channel.  This includes underfills\000"
/* offset=5381947 */ "unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (including underfills). Unit: uncore_imc \000event=0x5,umask=0xcf\000\00001\000DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM Read CAS commands issued on this channel.  This includes underfills\000"
/* offset=5382226 */ "unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000"
/* offset=5382513 */ "unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000\000"
/* offset=5382672 */ "unc_m_cas_count.rd\000uncore_imc_dclk\000uncore memory\000CAS Reads. Unit: uncore_imc_dclk \000event=0x3,umask=0x1\000\00001\000\000"
/* offset=5382780 */ "unc_m_cas_count.rd_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Read ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x40\000\00001\000\000"
/* offset=5382954 */ "unc_m_cas_count.rd_pre_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre : DRAM RD_CAS and WR_CAS Commands : Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with explicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000"
/* offset=5383556 */ "unc_m_cas_count.rd_pre_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xc2\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5383751 */ "unc_m_cas_count.rd_pre_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5383951 */ "unc_m_cas_count.rd_pre_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xc8\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5384152 */ "unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts CAS (Column Access Select) regular read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every regular read.  This event only counts regular reads and does not includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000"
/* offset=5384755 */ "unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts the total number of DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.   We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000"
/* offset=5385180 */ "unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (does not include underfills). Unit: uncore_imc \000event=0x5,umask=0xc1\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/out auto-pre : DRAM RD_CAS and WR_CAS Commands : Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.   We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000"
/* offset=5385713 */ "unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000"
/* offset=5386248 */ "unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000\000"
/* offset=5386414 */ "unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000"
/* offset=5386574 */ "unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000"
/* offset=5386724 */ "unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the number of underfill reads that are issued by the memory controller.  This will generally be about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ.  While it is possible for underfills to be issed in both WMM and RMM, this event counts both\000"
/* offset=5387219 */ "unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000\000"
/* offset=5387373 */ "unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM Underfill Read CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000Counts CAS (Column Access Select) underfill read commands issued to DRAM due to a partial write, on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this command counts underfill reads.  Partial writes must be completed by first reading in the underfill from DRAM and then merging in the partial write data before writing the full line back to DRAM. This event will generally count about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ (due to a previous write request)\000"
/* offset=5388088 */ "unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM underfill read CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total of DRAM Read CAS commands issued due to an underfill\000"
/* offset=5388295 */ "unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM underfill read CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xc4\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Underfill Read Issued : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5388524 */ "unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000"
/* offset=5388684 */ "unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000"
/* offset=5388834 */ "unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM Write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000"
/* offset=5389276 */ "unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x30\000\00001\000Counts the total number of DRAM Write CAS commands issued, w/ and w/o auto-pre, on this channel\000"
/* offset=5389495 */ "unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM write CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xf0\000\00001\000DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM Write CAS commands issued on this channel\000"
/* offset=5389726 */ "unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000"
/* offset=5389983 */ "unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000\000"
/* offset=5390134 */ "unc_m_cas_count.wr\000uncore_imc_dclk\000uncore memory\000CAS Writes. Unit: uncore_imc_dclk \000event=0x3,umask=0x2\000\00001\000\000"
/* offset=5390243 */ "unc_m_cas_count.wr_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Write ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x80\000\00001\000\000"
/* offset=5390418 */ "unc_m_cas_count.wr_nonpre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5390685 */ "unc_m_cas_count.wr_nonpre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre. Unit: uncore_imc \000event=0x5,umask=0xd0\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5390952 */ "unc_m_cas_count.wr_pre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5391214 */ "unc_m_cas_count.wr_pre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xe0\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000"
/* offset=5391405 */ "unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000"
/* offset=5391708 */ "unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000"
/* offset=5392034 */ "unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000\000"
/* offset=5392215 */ "unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000"
/* offset=5392506 */ "unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000"
/* offset=5392820 */ "unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000\000"
/* offset=5393002 */ "unc_m_cas_count_rd\000uncore_imc\000uncore memory\000Read CAS command sent to DRAM. Unit: uncore_imc \000event=0x22\000\00001\000\000"
/* offset=5393111 */ "unc_m_cas_count_wr\000uncore_imc\000uncore memory\000Write CAS command sent to DRAM. Unit: uncore_imc \000event=0x23\000\00001\000\000"
/* offset=5393221 */ "unc_m_cas_issued_req_len.pch0\000uncore_imc\000uncore memory\000Pseudo Channel 0. Unit: uncore_imc \000event=0x6,umask=0x40\000\00001\000\000"
/* offset=5393338 */ "unc_m_cas_issued_req_len.pch1\000uncore_imc\000uncore memory\000Pseudo Channel 1. Unit: uncore_imc \000event=0x6,umask=0x80\000\00001\000\000"
/* offset=5393455 */ "unc_m_cas_issued_req_len.rd_32b\000uncore_imc\000uncore memory\000Read CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xc8\000\00001\000\000"
/* offset=5393600 */ "unc_m_cas_issued_req_len.rd_64b\000uncore_imc\000uncore memory\000Read CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_imc \000event=0x6,umask=0xc1\000\00001\000\000"
/* offset=5393760 */ "unc_m_cas_issued_req_len.rd_ufill_32b\000uncore_imc\000uncore memory\000Underfill Read CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xd0\000\00001\000\000"
/* offset=5393921 */ "unc_m_cas_issued_req_len.rd_ufill_64b\000uncore_imc\000uncore memory\000Underfill Read CAS Command in Regular Mode (64B) in Pseudochannel 1. Unit: uncore_imc \000event=0x6,umask=0xc2\000\00001\000\000"
/* offset=5394097 */ "unc_m_cas_issued_req_len.wr_32b\000uncore_imc\000uncore memory\000Write CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xe0\000\00001\000\000"
/* offset=5394243 */ "unc_m_cas_issued_req_len.wr_64b\000uncore_imc\000uncore memory\000Write CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_imc \000event=0x6,umask=0xc4\000\00001\000\000"
/* offset=5394404 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using a dedicated 48-bit Fixed Counter. Unit: uncore_imc \000event=0xff\000\00001\000\000"
/* offset=5394556 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000"
/* offset=5394646 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000IMC Clockticks at DCLK frequency. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Number of DRAM DCLK clock cycles while the event is enabled\000"
/* offset=5394824 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000Memory controller clock ticks. Unit: uncore_imc \000event=0\000\00001\000Clockticks of the integrated memory controller (IMC)\000"
/* offset=5394980 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000Memory controller clock ticks. Unit: uncore_imc \000event=0\000\00001\000Counts clockticks of the fixed frequency clock of the memory controller using one of the programmable counters\000"
/* offset=5395194 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000Number of clocks. Unit: uncore_imc \000event=0x1\000\00001\000\000"
/* offset=5395287 */ "unc_m_clockticks\000uncore_imc\000uncore memory\000uclks. Unit: uncore_imc \000event=0\000\00001\000Uncore Fixed Counter - uclks\000"
/* offset=5395395 */ "unc_m_clockticks_f\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using a dedicated 48-bit Fixed Counter. Unit: uncore_imc \000event=0xff\000\00001\000\000"
/* offset=5395549 */ "unc_m_clockticks_freerun\000uncore_imc_free_running\000uncore memory\000Free running counter that increments for the Memory Controller. Unit: uncore_imc_free_running \000event=0xff,umask=0x10\000\00001\000\000"
/* offset=5395734 */ "unc_m_clockticks_p\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using one of the programmable counters. Unit: uncore_imc \000event=0\000\00001\000\000"
/* offset=5395885 */ "unc_m_d_clockticks\000uncore_imc_dclk\000uncore memory\000DCLK count. Unit: uncore_imc_dclk \000event=0\000\00001\000\000"
/* offset=5395982 */ "unc_m_dclockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000"
/* offset=5396073 */ "unc_m_dclockticks\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_CLOCKTICKS_P. Unit: uncore_imc \000event=0\000\00001\000\000"
/* offset=5396212 */ "unc_m_dram_page_empty_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Empty. Unit: uncore_imc \000event=0x1d\000\00001\000\000"
/* offset=5396345 */ "unc_m_dram_page_empty_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Empty. Unit: uncore_imc \000event=0x20\000\00001\000\000"
/* offset=5396479 */ "unc_m_dram_page_hit_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Hit. Unit: uncore_imc \000event=0x1c\000\00001\000\000"
/* offset=5396608 */ "unc_m_dram_page_hit_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Hit. Unit: uncore_imc \000event=0x1f\000\00001\000\000"
/* offset=5396738 */ "unc_m_dram_page_miss_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Miss. Unit: uncore_imc \000event=0x1e\000\00001\000\000"
/* offset=5396869 */ "unc_m_dram_page_miss_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Miss. Unit: uncore_imc \000event=0x21\000\00001\000\000"
/* offset=5397001 */ "unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x44,umask=0x3\000\00001\000DRAM Precharge All Commands : Counts the number of times that the precharge all command was sent\000"
/* offset=5397214 */ "unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x44\000\00001\000DRAM Precharge All Commands : Counts the number of times that the precharge all command was sent\000"
/* offset=5397417 */ "unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000"
/* offset=5397589 */ "unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x4\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000"
/* offset=5397786 */ "unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000"
/* offset=5397948 */ "unc_m_dram_refresh.opportunistic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x1\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000"
/* offset=5398154 */ "unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x2\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000"
/* offset=5398352 */ "unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000"
/* offset=5398515 */ "unc_m_dram_thermal_hot\000uncore_imc\000uncore memory\000Any Rank at Hot state. Unit: uncore_imc \000event=0x19\000\00001\000\000"
/* offset=5398620 */ "unc_m_dram_thermal_warm\000uncore_imc\000uncore memory\000Any Rank at Warm state. Unit: uncore_imc \000event=0x1a\000\00001\000\000"
/* offset=5398727 */ "unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000"
/* offset=5399174 */ "unc_m_hclockticks\000uncore_imc\000uncore memory\000Half clockticks for IMC. Unit: uncore_imc \000event=0xff\000\00001\000\000"
/* offset=5399276 */ "unc_m_hclockticks\000uncore_imc\000uncore memory\000IMC Clockticks at HCLK frequency. Unit: uncore_imc \000event=0x1\000\00001\000Number of DRAM HCLK clock cycles while the event is enabled\000"
/* offset=5399445 */ "unc_m_majmode2.dram_cyc\000uncore_imc\000uncore memory\000UNC_M_MAJMODE2.DRAM_CYC. Unit: uncore_imc \000event=0xed,umask=0x2\000\00001\000\000"
/* offset=5399563 */ "unc_m_majmode2.dram_enter\000uncore_imc\000uncore memory\000UNC_M_MAJMODE2.DRAM_ENTER. Unit: uncore_imc \000event=0xed,umask=0x8\000\00001\000\000"
/* offset=5399685 */ "unc_m_majmode2.pmm_cyc\000uncore_imc\000uncore memory\000Major Mode 2 : Cycles in PMM major mode. Unit: uncore_imc \000event=0xed,umask=0x1\000\00001\000\000"
/* offset=5399818 */ "unc_m_majmode2.pmm_enter\000uncore_imc\000uncore memory\000Major Mode 2 : Entered PMM major mode. Unit: uncore_imc \000event=0xed,umask=0x4\000\00001\000\000"
/* offset=5399951 */ "unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000"
/* offset=5400513 */ "unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000"
/* offset=5400821 */ "unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000"
/* offset=5401274 */ "unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000"
/* offset=5401586 */ "unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000"
/* offset=5402012 */ "unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000"
/* offset=5402318 */ "unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000"
/* offset=5402909 */ "unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000"
/* offset=5403217 */ "unc_m_parity_errors\000uncore_imc\000uncore memory\000UNC_M_PARITY_ERRORS. Unit: uncore_imc \000event=0x2c\000\00001\000\000"
/* offset=5403317 */ "unc_m_pcls.rd\000uncore_imc\000uncore memory\000UNC_M_PCLS.RD. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000"
/* offset=5403415 */ "unc_m_pcls.rd\000uncore_imc\000uncore memory\000UNC_M_PCLS.RD. Unit: uncore_imc \000event=0xa0,umask=0x5\000\00001\000\000"
/* offset=5403513 */ "unc_m_pcls.total\000uncore_imc\000uncore memory\000UNC_M_PCLS.TOTAL. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000"
/* offset=5403617 */ "unc_m_pcls.total\000uncore_imc\000uncore memory\000UNC_M_PCLS.TOTAL. Unit: uncore_imc \000event=0xa0,umask=0xf\000\00001\000\000"
/* offset=5403721 */ "unc_m_pcls.wr\000uncore_imc\000uncore memory\000UNC_M_PCLS.WR. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000"
/* offset=5403819 */ "unc_m_pcls.wr\000uncore_imc\000uncore memory\000UNC_M_PCLS.WR. Unit: uncore_imc \000event=0xa0,umask=0xa\000\00001\000\000"
/* offset=5403917 */ "unc_m_pmm_bandwidth.read\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth read (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000event=0xe3\000\000016.103515625E-5MB/sec\000\000"
/* offset=5404116 */ "unc_m_pmm_bandwidth.total\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth total (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000event=0xe3\000\000016.103515625E-5MB/sec\000\000"
/* offset=5404317 */ "unc_m_pmm_bandwidth.write\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth write (MB/sec). Derived from unc_m_pmm_wpq_inserts. Unit: uncore_imc \000event=0xe7\000\000016.103515625E-5MB/sec\000\000"
/* offset=5404518 */ "unc_m_pmm_cmd1.all\000uncore_imc\000uncore memory\000All commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x1\000\00001\000\000"
/* offset=5404665 */ "unc_m_pmm_cmd1.all\000uncore_imc\000uncore memory\000PMM Commands : All. Unit: uncore_imc \000event=0xea,umask=0x1\000\00001\000PMM Commands : All : Counts all commands issued to PMM\000"
/* offset=5404827 */ "unc_m_pmm_cmd1.misc\000uncore_imc\000uncore memory\000Misc Commands (error, flow ACKs). Unit: uncore_imc \000event=0xea,umask=0x80\000\00001\000\000"
/* offset=5404951 */ "unc_m_pmm_cmd1.misc\000uncore_imc\000uncore memory\000PMM Commands : Misc Commands (error, flow ACKs). Unit: uncore_imc \000event=0xea,umask=0x80\000\00001\000\000"
/* offset=5405090 */ "unc_m_pmm_cmd1.misc_gnt\000uncore_imc\000uncore memory\000Misc GNTs. Unit: uncore_imc \000event=0xea,umask=0x40\000\00001\000\000"
/* offset=5405195 */ "unc_m_pmm_cmd1.misc_gnt\000uncore_imc\000uncore memory\000PMM Commands : Misc GNTs. Unit: uncore_imc \000event=0xea,umask=0x40\000\00001\000\000"
/* offset=5405315 */ "unc_m_pmm_cmd1.rd\000uncore_imc\000uncore memory\000PMM Commands : Reads - RPQ. Unit: uncore_imc \000event=0xea,umask=0x2\000\00001\000PMM Commands : Reads - RPQ : Counts read requests issued to the PMM RPQ\000"
/* offset=5405501 */ "unc_m_pmm_cmd1.rd\000uncore_imc\000uncore memory\000Regular reads(RPQ) commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x2\000\00001\000All Reads - RPQ or Ufill\000"
/* offset=5405686 */ "unc_m_pmm_cmd1.rpq_gnts\000uncore_imc\000uncore memory\000PMM Commands : RPQ GNTs. Unit: uncore_imc \000event=0xea,umask=0x10\000\00001\000\000"
/* offset=5405805 */ "unc_m_pmm_cmd1.rpq_gnts\000uncore_imc\000uncore memory\000RPQ GNTs. Unit: uncore_imc \000event=0xea,umask=0x10\000\00001\000\000"
/* offset=5405909 */ "unc_m_pmm_cmd1.ufill_rd\000uncore_imc\000uncore memory\000PMM Commands : Underfill reads. Unit: uncore_imc \000event=0xea,umask=0x8\000\00001\000PMM Commands : Underfill reads : Counts underfill read commands, due to a partial write, issued to PMM\000"
/* offset=5406136 */ "unc_m_pmm_cmd1.ufill_rd\000uncore_imc\000uncore memory\000Underfill read commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x8\000\00001\000Underfill reads\000"
/* offset=5406314 */ "unc_m_pmm_cmd1.wpq_gnts\000uncore_imc\000uncore memory\000PMM Commands : Underfill GNTs. Unit: uncore_imc \000event=0xea,umask=0x20\000\00001\000\000"
/* offset=5406439 */ "unc_m_pmm_cmd1.wpq_gnts\000uncore_imc\000uncore memory\000Underfill GNTs. Unit: uncore_imc \000event=0xea,umask=0x20\000\00001\000\000"
/* offset=5406549 */ "unc_m_pmm_cmd1.wr\000uncore_imc\000uncore memory\000PMM Commands : Writes. Unit: uncore_imc \000event=0xea,umask=0x4\000\00001\000PMM Commands : Writes : Counts write commands issued to PMM\000"
/* offset=5406718 */ "unc_m_pmm_cmd1.wr\000uncore_imc\000uncore memory\000Write commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x4\000\00001\000Writes\000"
/* offset=5406872 */ "unc_m_pmm_cmd2.nodata_exp\000uncore_imc\000uncore memory\000Expected No data packet (ERID matched NDP encoding). Unit: uncore_imc \000event=0xeb,umask=0x2\000\00001\000\000"
/* offset=5407020 */ "unc_m_pmm_cmd2.nodata_exp\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Expected No data packet (ERID matched NDP encoding). Unit: uncore_imc \000event=0xeb,umask=0x2\000\00001\000\000"
/* offset=5407192 */ "unc_m_pmm_cmd2.nodata_unexp\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Unexpected No data packet (ERID matched a Read, but data was a NDP). Unit: uncore_imc \000event=0xeb,umask=0x4\000\00001\000\000"
/* offset=5407382 */ "unc_m_pmm_cmd2.nodata_unexp\000uncore_imc\000uncore memory\000Unexpected No data packet (ERID matched a Read, but data was a NDP). Unit: uncore_imc \000event=0xeb,umask=0x4\000\00001\000\000"
/* offset=5407548 */ "unc_m_pmm_cmd2.opp_rd\000uncore_imc\000uncore memory\000Opportunistic Reads. Unit: uncore_imc \000event=0xeb,umask=0x1\000\00001\000\000"
/* offset=5407660 */ "unc_m_pmm_cmd2.opp_rd\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Opportunistic Reads. Unit: uncore_imc \000event=0xeb,umask=0x1\000\00001\000\000"
/* offset=5407796 */ "unc_m_pmm_cmd2.pmm_ecc_error\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : ECC Errors. Unit: uncore_imc \000event=0xeb,umask=0x20\000\00001\000\000"
/* offset=5407931 */ "unc_m_pmm_cmd2.pmm_ecc_error\000uncore_imc\000uncore memory\000PMM ECC Errors. Unit: uncore_imc \000event=0xeb,umask=0x20\000\00001\000\000"
/* offset=5408046 */ "unc_m_pmm_cmd2.pmm_erid_error\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : ERID detectable parity error. Unit: uncore_imc \000event=0xeb,umask=0x40\000\00001\000\000"
/* offset=5408200 */ "unc_m_pmm_cmd2.pmm_erid_error\000uncore_imc\000uncore memory\000PMM ERID detectable parity error. Unit: uncore_imc \000event=0xeb,umask=0x40\000\00001\000\000"
/* offset=5408334 */ "unc_m_pmm_cmd2.pmm_erid_starved\000uncore_imc\000uncore memory\000PMM Commands - Part 2. Unit: uncore_imc \000event=0xeb,umask=0x80\000\00001\000\000"
/* offset=5408459 */ "unc_m_pmm_cmd2.reqs_slot0\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Read Requests - Slot 0. Unit: uncore_imc \000event=0xeb,umask=0x8\000\00001\000\000"
/* offset=5408602 */ "unc_m_pmm_cmd2.reqs_slot0\000uncore_imc\000uncore memory\000Read Requests - Slot 0. Unit: uncore_imc \000event=0xeb,umask=0x8\000\00001\000\000"
/* offset=5408721 */ "unc_m_pmm_cmd2.reqs_slot1\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Read Requests - Slot 1. Unit: uncore_imc \000event=0xeb,umask=0x10\000\00001\000\000"
/* offset=5408865 */ "unc_m_pmm_cmd2.reqs_slot1\000uncore_imc\000uncore memory\000Read Requests - Slot 1. Unit: uncore_imc \000event=0xeb,umask=0x10\000\00001\000\000"
/* offset=5408985 */ "unc_m_pmm_majmode1.partial_wr_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Partial Write Major Mode. Unit: uncore_imc \000event=0xec,umask=0x4\000\00001\000\000"
/* offset=5409147 */ "unc_m_pmm_majmode1.partial_wr_enter\000uncore_imc\000uncore memory\000PMM Major Mode. Unit: uncore_imc \000event=0xec,umask=0x20\000\00001\000\000"
/* offset=5409269 */ "unc_m_pmm_majmode1.partial_wr_exit\000uncore_imc\000uncore memory\000PMM Major Mode. Unit: uncore_imc \000event=0xec,umask=0x40\000\00001\000\000"
/* offset=5409390 */ "unc_m_pmm_majmode1.rd_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Read Major Mode. Unit: uncore_imc \000event=0xec,umask=0x1\000\00001\000\000"
/* offset=5409535 */ "unc_m_pmm_majmode1.wr_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Write Major Mode. Unit: uncore_imc \000event=0xec,umask=0x2\000\00001\000\000"
/* offset=5409681 */ "unc_m_pmm_read_latency\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory read latency (ns). Derived from unc_m_pmm_rpq_occupancy.all. Unit: uncore_imc \000event=0xe0,umask=0x1\000\000016000000000ns\000\000"
/* offset=5409880 */ "unc_m_pmm_rpq_cycles_full\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Full. Unit: uncore_imc \000event=0xe2\000\00001\000\000"
/* offset=5409993 */ "unc_m_pmm_rpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe1\000\00001\000\000"
/* offset=5410109 */ "unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000PMM Read Pending Queue inserts. Unit: uncore_imc \000event=0xe3\000\00001\000Counts number of read requests allocated in the PMM Read Pending Queue\000"
/* offset=5410292 */ "unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000PMM Read Queue Inserts. Unit: uncore_imc \000event=0xe3\000\00001\000PMM Read Queue Inserts : Counts number of read requests allocated in the PMM Read Pending Queue.   This includes both ISOCH and non-ISOCH requests\000"
/* offset=5410543 */ "unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000Write requests allocated in the PMM Write Pending Queue for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe3\000\00001\000\000"
/* offset=5410719 */ "unc_m_pmm_rpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5410950 */ "unc_m_pmm_rpq_occupancy.all\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy of all read requests for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000\000"
/* offset=5411136 */ "unc_m_pmm_rpq_occupancy.all_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue occupancy. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5411337 */ "unc_m_pmm_rpq_occupancy.all_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue occupancy. Unit: uncore_imc \000event=0xe0,umask=0x2\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5411538 */ "unc_m_pmm_rpq_occupancy.gnt_wait\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000\000"
/* offset=5411655 */ "unc_m_pmm_rpq_occupancy.gnt_wait\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5411891 */ "unc_m_pmm_rpq_occupancy.gnt_wait_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x10\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5412133 */ "unc_m_pmm_rpq_occupancy.gnt_wait_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x20\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5412375 */ "unc_m_pmm_rpq_occupancy.no_gnt\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x2\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5412609 */ "unc_m_pmm_rpq_occupancy.no_gnt_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5412813 */ "unc_m_pmm_rpq_occupancy.no_gnt_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x8\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000"
/* offset=5413017 */ "unc_m_pmm_wpq_cycles_full\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Full. Unit: uncore_imc \000event=0xe6\000\00001\000\000"
/* offset=5413131 */ "unc_m_pmm_wpq_cycles_ne\000uncore_imc\000uncore memory\000PMM (for IXP) Write Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe5\000\00001\000\000"
/* offset=5413258 */ "unc_m_pmm_wpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe5\000\00001\000\000"
/* offset=5413375 */ "unc_m_pmm_wpq_flush\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_FLUSH. Unit: uncore_imc \000event=0xe8\000\00001\000\000"
/* offset=5413475 */ "unc_m_pmm_wpq_flush_cyc\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_FLUSH_CYC. Unit: uncore_imc \000event=0xe9\000\00001\000\000"
/* offset=5413583 */ "unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000PMM Write Pending Queue inserts. Unit: uncore_imc \000event=0xe7\000\00001\000Counts number of  write requests allocated in the PMM Write Pending Queue\000"
/* offset=5413770 */ "unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000PMM Write Queue Inserts. Unit: uncore_imc \000event=0xe7\000\00001\000PMM Write Queue Inserts : Counts number of  write requests allocated in the PMM Write Pending Queue\000"
/* offset=5413975 */ "unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000Write requests allocated in the PMM Write Pending Queue for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe7\000\00001\000\000"
/* offset=5414151 */ "unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000"
/* offset=5414385 */ "unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x3\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the PMM DIMM\000"
/* offset=5414631 */ "unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy of all write requests for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000\000"
/* offset=5414826 */ "unc_m_pmm_wpq_occupancy.all_sch0\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000"
/* offset=5415065 */ "unc_m_pmm_wpq_occupancy.all_sch1\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000"
/* offset=5415304 */ "unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM (for IXP) Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0xc\000\00001\000PMM (for IXP) Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the IXP DIMM\000"
/* offset=5415570 */ "unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000\000"
/* offset=5415682 */ "unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000"
/* offset=5415916 */ "unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM (for IXP) Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x30\000\00001\000PMM (for IXP) Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the IXP DIMM\000"
/* offset=5416183 */ "unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x4\000\00001\000\000"
/* offset=5416295 */ "unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x4\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000"
/* offset=5416529 */ "unc_m_pmm_wpq_pcommit\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_PCOMMIT. Unit: uncore_imc \000event=0xe8\000\00001\000\000"
/* offset=5416633 */ "unc_m_pmm_wpq_pcommit_cyc\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_PCOMMIT_CYC. Unit: uncore_imc \000event=0xe9\000\00001\000\000"
/* offset=5416745 */ "unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000"
/* offset=5416934 */ "unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000"
/* offset=5417303 */ "unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000"
/* offset=5417651 */ "unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode+C37. Unit: uncore_imc \000event=0x85\000\00001\000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000"
/* offset=5418105 */ "unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000event=0x85\000\00001\000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000"
/* offset=5418508 */ "unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000event=0x85\000\00001\000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000"
/* offset=5418958 */ "unc_m_power_cke_cycles.low_0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x1\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5419790 */ "unc_m_power_cke_cycles.low_1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x2\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5420622 */ "unc_m_power_cke_cycles.low_2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x4\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5421454 */ "unc_m_power_cke_cycles.low_3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x8\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5422286 */ "unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5423083 */ "unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5423880 */ "unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5424677 */ "unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5425474 */ "unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5426272 */ "unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5427070 */ "unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5427868 */ "unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000"
/* offset=5428666 */ "unc_m_power_crit_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000"
/* offset=5429254 */ "unc_m_power_crit_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5429729 */ "unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000"
/* offset=5430087 */ "unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000"
/* offset=5430201 */ "unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000Unit: uncore_imc \000event=0x42\000\00001\000\000"
/* offset=5430287 */ "unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000"
/* offset=5430855 */ "unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000"
/* offset=5431394 */ "unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000event=0x43\000\00001\000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000"
/* offset=5431979 */ "unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000"
/* offset=5432603 */ "unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000"
/* offset=5433165 */ "unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5433615 */ "unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5434065 */ "unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5434515 */ "unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5434965 */ "unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5435416 */ "unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5435867 */ "unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5436318 */ "unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5436769 */ "unc_m_power_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000"
/* offset=5437352 */ "unc_m_power_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000"
/* offset=5437822 */ "unc_m_pre_count.all\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x2,umask=0x1c\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5438028 */ "unc_m_pre_count.all\000uncore_imc\000uncore memory\000Precharge due to read, write, underfill, or PGT. Unit: uncore_imc \000event=0x3,umask=0xff\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5438258 */ "unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5438463 */ "unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000"
/* offset=5438879 */ "unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5439100 */ "unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to page miss. Unit: uncore_imc \000event=0x2,umask=0xc\000\00001\000DRAM Precharge commands. : Precharge due to page miss : Counts the number of DRAM Precharge commands sent on this channel. : Pages Misses are due to precharges from bank scheduler (rd/wr requests)\000"
/* offset=5439445 */ "unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of page misses.  This does not include explicit precharge commands sent with CAS commands in Auto-Precharge mode.  This does not include PRE commands sent as a result of the page close counter expiration\000"
/* offset=5439943 */ "unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5440157 */ "unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000Pre-charges due to page misses. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of explicit DRAM Precharge commands sent on this channel as a result of a DRAM page miss. This does not include the implicit precharge commands sent with CAS commands in Auto-Precharge mode. This does not include Precharge commands sent as a result of a page close counter expiration\000"
/* offset=5440584 */ "unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000Pre-charges due to page misses. Unit: uncore_imc \000event=0x2,umask=0xc\000\00001\000DRAM Precharge commands. : Precharge due to page miss : Counts the number of DRAM Precharge commands sent on this channel. : Pages Misses are due to precharges from bank scheduler (rd/wr requests)\000"
/* offset=5440906 */ "unc_m_pre_count.pgt\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to page table. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000DRAM Precharge commands. : Precharge due to page table : Counts the number of DRAM Precharge commands sent on this channel. : Precharges from Page Table\000"
/* offset=5441203 */ "unc_m_pre_count.pgt\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x88\000\00001\000DRAM Precharge commands.  Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5441408 */ "unc_m_pre_count.pgt_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharges from Page Table. Unit: uncore_imc \000event=0x3,umask=0x8\000\00001\000DRAM Precharge commands. : Precharges from Page Table : Counts the number of DRAM Precharge commands sent on this channel. : Equivalent to PAGE_EMPTY\000"
/* offset=5441705 */ "unc_m_pre_count.pgt_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x80\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5441916 */ "unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000"
/* offset=5442207 */ "unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5442408 */ "unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Pre-charge for reads. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of explicit DRAM Precharge commands issued on a per channel basis due to a read, so as to close the previous DRAM page, before opening the requested page\000"
/* offset=5442688 */ "unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Pre-charge for reads. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000"
/* offset=5442951 */ "unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Precharge due to read on page miss. Unit: uncore_imc \000event=0x3,umask=0x11\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5443167 */ "unc_m_pre_count.rd_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to read. Unit: uncore_imc \000event=0x3,umask=0x1\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000"
/* offset=5443463 */ "unc_m_pre_count.rd_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x10\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5443673 */ "unc_m_pre_count.ufill\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x44\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5443881 */ "unc_m_pre_count.ufill_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x4\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5444093 */ "unc_m_pre_count.ufill_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x40\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5444306 */ "unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000"
/* offset=5444600 */ "unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5444802 */ "unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Pre-charge for writes. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5444977 */ "unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Pre-charge for writes. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000"
/* offset=5445243 */ "unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Precharge due to write on page miss. Unit: uncore_imc \000event=0x3,umask=0x22\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5445460 */ "unc_m_pre_count.wr_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to write. Unit: uncore_imc \000event=0x3,umask=0x2\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000"
/* offset=5445759 */ "unc_m_pre_count.wr_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x20\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000"
/* offset=5445969 */ "unc_m_pre_count_idle\000uncore_imc\000uncore memory\000PRE command sent to DRAM due to page table idle timer expiration. Unit: uncore_imc \000event=0x28\000\00001\000\000"
/* offset=5446115 */ "unc_m_pre_count_page_miss\000uncore_imc\000uncore memory\000PRE command sent to DRAM for a read/write request. Unit: uncore_imc \000event=0x27\000\00001\000\000"
/* offset=5446251 */ "unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000"
/* offset=5446888 */ "unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency\000"
/* offset=5447478 */ "unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000"
/* offset=5448111 */ "unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency\000"
/* offset=5448702 */ "unc_m_prefetch_rd\000uncore_imc\000uncore memory\000Incoming read prefetch request from IA. Unit: uncore_imc \000event=0xa\000\00001\000\000"
/* offset=5448818 */ "unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000"
/* offset=5448946 */ "unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000"
/* offset=5449072 */ "unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000"
/* offset=5449201 */ "unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000"
/* offset=5449351 */ "unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5449520 */ "unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000\000"
/* offset=5449654 */ "unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000\000"
/* offset=5449781 */ "unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5449930 */ "unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000\000"
/* offset=5450047 */ "unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5450209 */ "unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000\000"
/* offset=5450338 */ "unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5450500 */ "unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000\000"
/* offset=5450629 */ "unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5450791 */ "unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000\000"
/* offset=5450920 */ "unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5451082 */ "unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000\000"
/* offset=5451211 */ "unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5451373 */ "unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000\000"
/* offset=5451502 */ "unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5451664 */ "unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000\000"
/* offset=5451793 */ "unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5451952 */ "unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000\000"
/* offset=5452079 */ "unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000\000"
/* offset=5452206 */ "unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5452365 */ "unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000\000"
/* offset=5452492 */ "unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000\000"
/* offset=5452619 */ "unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5452778 */ "unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000\000"
/* offset=5452905 */ "unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000\000"
/* offset=5453032 */ "unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000\000"
/* offset=5453160 */ "unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5453319 */ "unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000\000"
/* offset=5453446 */ "unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x20\000\00001\000\000"
/* offset=5453574 */ "unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5453733 */ "unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000\000"
/* offset=5453860 */ "unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x40\000\00001\000\000"
/* offset=5453988 */ "unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5454147 */ "unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000\000"
/* offset=5454274 */ "unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5454433 */ "unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000\000"
/* offset=5454560 */ "unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x80\000\00001\000\000"
/* offset=5454688 */ "unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5454847 */ "unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000\000"
/* offset=5454974 */ "unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5455133 */ "unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000\000"
/* offset=5455260 */ "unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5455457 */ "unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000\000"
/* offset=5455604 */ "unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5455801 */ "unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000\000"
/* offset=5455948 */ "unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5456147 */ "unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000\000"
/* offset=5456295 */ "unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5456496 */ "unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000\000"
/* offset=5456645 */ "unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5456814 */ "unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000\000"
/* offset=5456948 */ "unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000\000"
/* offset=5457075 */ "unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5457224 */ "unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000\000"
/* offset=5457341 */ "unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5457503 */ "unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000\000"
/* offset=5457632 */ "unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5457794 */ "unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000\000"
/* offset=5457923 */ "unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5458085 */ "unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000\000"
/* offset=5458214 */ "unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5458376 */ "unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000\000"
/* offset=5458505 */ "unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5458667 */ "unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000\000"
/* offset=5458796 */ "unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5458958 */ "unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000\000"
/* offset=5459087 */ "unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5459246 */ "unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000\000"
/* offset=5459373 */ "unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000\000"
/* offset=5459500 */ "unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5459659 */ "unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000\000"
/* offset=5459786 */ "unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000\000"
/* offset=5459913 */ "unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5460072 */ "unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000\000"
/* offset=5460199 */ "unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000\000"
/* offset=5460326 */ "unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000\000"
/* offset=5460454 */ "unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5460613 */ "unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000\000"
/* offset=5460740 */ "unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x20\000\00001\000\000"
/* offset=5460868 */ "unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5461027 */ "unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000\000"
/* offset=5461154 */ "unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x40\000\00001\000\000"
/* offset=5461282 */ "unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5461441 */ "unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000\000"
/* offset=5461568 */ "unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5461727 */ "unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000\000"
/* offset=5461854 */ "unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x80\000\00001\000\000"
/* offset=5461982 */ "unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5462141 */ "unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000\000"
/* offset=5462268 */ "unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5462427 */ "unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000\000"
/* offset=5462554 */ "unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5462751 */ "unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000\000"
/* offset=5462898 */ "unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5463095 */ "unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000\000"
/* offset=5463242 */ "unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5463441 */ "unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000\000"
/* offset=5463589 */ "unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5463790 */ "unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000\000"
/* offset=5463939 */ "unc_m_rd_cas_rank2.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xb2,umask=0x10\000\00001\000\000"
/* offset=5464073 */ "unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2,umask=0x1\000\00001\000\000"
/* offset=5464200 */ "unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5464349 */ "unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000\000"
/* offset=5464466 */ "unc_m_rd_cas_rank2.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xb2,umask=0xa\000\00001\000\000"
/* offset=5464595 */ "unc_m_rd_cas_rank2.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xb2,umask=0xb\000\00001\000\000"
/* offset=5464724 */ "unc_m_rd_cas_rank2.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xb2,umask=0xc\000\00001\000\000"
/* offset=5464853 */ "unc_m_rd_cas_rank2.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xb2,umask=0xd\000\00001\000\000"
/* offset=5464982 */ "unc_m_rd_cas_rank2.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xb2,umask=0xe\000\00001\000\000"
/* offset=5465111 */ "unc_m_rd_cas_rank2.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xb2,umask=0xf\000\00001\000\000"
/* offset=5465240 */ "unc_m_rd_cas_rank2.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xb2,umask=0x1\000\00001\000\000"
/* offset=5465367 */ "unc_m_rd_cas_rank2.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xb2,umask=0x2\000\00001\000\000"
/* offset=5465494 */ "unc_m_rd_cas_rank2.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xb2,umask=0x2\000\00001\000\000"
/* offset=5465621 */ "unc_m_rd_cas_rank2.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xb2,umask=0x4\000\00001\000\000"
/* offset=5465748 */ "unc_m_rd_cas_rank2.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xb2,umask=0x3\000\00001\000\000"
/* offset=5465875 */ "unc_m_rd_cas_rank2.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xb2,umask=0x8\000\00001\000\000"
/* offset=5466002 */ "unc_m_rd_cas_rank2.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xb2,umask=0x10\000\00001\000\000"
/* offset=5466130 */ "unc_m_rd_cas_rank2.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xb2,umask=0x4\000\00001\000\000"
/* offset=5466257 */ "unc_m_rd_cas_rank2.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xb2,umask=0x20\000\00001\000\000"
/* offset=5466385 */ "unc_m_rd_cas_rank2.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xb2,umask=0x5\000\00001\000\000"
/* offset=5466512 */ "unc_m_rd_cas_rank2.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xb2,umask=0x40\000\00001\000\000"
/* offset=5466640 */ "unc_m_rd_cas_rank2.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xb2,umask=0x6\000\00001\000\000"
/* offset=5466767 */ "unc_m_rd_cas_rank2.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xb2,umask=0x7\000\00001\000\000"
/* offset=5466894 */ "unc_m_rd_cas_rank2.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xb2,umask=0x80\000\00001\000\000"
/* offset=5467022 */ "unc_m_rd_cas_rank2.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xb2,umask=0x8\000\00001\000\000"
/* offset=5467149 */ "unc_m_rd_cas_rank2.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xb2,umask=0x9\000\00001\000\000"
/* offset=5467276 */ "unc_m_rd_cas_rank2.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb2,umask=0x11\000\00001\000\000"
/* offset=5467423 */ "unc_m_rd_cas_rank2.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb2,umask=0x12\000\00001\000\000"
/* offset=5467570 */ "unc_m_rd_cas_rank2.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb2,umask=0x13\000\00001\000\000"
/* offset=5467718 */ "unc_m_rd_cas_rank2.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb2,umask=0x14\000\00001\000\000"
/* offset=5467867 */ "unc_m_rd_cas_rank3.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xb3,umask=0x10\000\00001\000\000"
/* offset=5468001 */ "unc_m_rd_cas_rank3.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xb3,umask=0x1\000\00001\000\000"
/* offset=5468128 */ "unc_m_rd_cas_rank3.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xb3\000\00001\000\000"
/* offset=5468245 */ "unc_m_rd_cas_rank3.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xb3,umask=0xa\000\00001\000\000"
/* offset=5468374 */ "unc_m_rd_cas_rank3.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xb3,umask=0xb\000\00001\000\000"
/* offset=5468503 */ "unc_m_rd_cas_rank3.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xb3,umask=0xc\000\00001\000\000"
/* offset=5468632 */ "unc_m_rd_cas_rank3.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xb3,umask=0xd\000\00001\000\000"
/* offset=5468761 */ "unc_m_rd_cas_rank3.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xb3,umask=0xe\000\00001\000\000"
/* offset=5468890 */ "unc_m_rd_cas_rank3.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xb3,umask=0xf\000\00001\000\000"
/* offset=5469019 */ "unc_m_rd_cas_rank3.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xb3,umask=0x1\000\00001\000\000"
/* offset=5469146 */ "unc_m_rd_cas_rank3.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xb3,umask=0x2\000\00001\000\000"
/* offset=5469273 */ "unc_m_rd_cas_rank3.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xb3,umask=0x2\000\00001\000\000"
/* offset=5469400 */ "unc_m_rd_cas_rank3.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xb3,umask=0x4\000\00001\000\000"
/* offset=5469527 */ "unc_m_rd_cas_rank3.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xb3,umask=0x3\000\00001\000\000"
/* offset=5469654 */ "unc_m_rd_cas_rank3.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xb3,umask=0x8\000\00001\000\000"
/* offset=5469781 */ "unc_m_rd_cas_rank3.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xb3,umask=0x10\000\00001\000\000"
/* offset=5469909 */ "unc_m_rd_cas_rank3.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xb3,umask=0x4\000\00001\000\000"
/* offset=5470036 */ "unc_m_rd_cas_rank3.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xb3,umask=0x20\000\00001\000\000"
/* offset=5470164 */ "unc_m_rd_cas_rank3.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xb3,umask=0x5\000\00001\000\000"
/* offset=5470291 */ "unc_m_rd_cas_rank3.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xb3,umask=0x40\000\00001\000\000"
/* offset=5470419 */ "unc_m_rd_cas_rank3.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xb3,umask=0x6\000\00001\000\000"
/* offset=5470546 */ "unc_m_rd_cas_rank3.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xb3,umask=0x7\000\00001\000\000"
/* offset=5470673 */ "unc_m_rd_cas_rank3.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xb3,umask=0x80\000\00001\000\000"
/* offset=5470801 */ "unc_m_rd_cas_rank3.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xb3,umask=0x8\000\00001\000\000"
/* offset=5470928 */ "unc_m_rd_cas_rank3.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xb3,umask=0x9\000\00001\000\000"
/* offset=5471055 */ "unc_m_rd_cas_rank3.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb3,umask=0x11\000\00001\000\000"
/* offset=5471202 */ "unc_m_rd_cas_rank3.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb3,umask=0x12\000\00001\000\000"
/* offset=5471349 */ "unc_m_rd_cas_rank3.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb3,umask=0x13\000\00001\000\000"
/* offset=5471497 */ "unc_m_rd_cas_rank3.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb3,umask=0x14\000\00001\000\000"
/* offset=5471646 */ "unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5471815 */ "unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000\000"
/* offset=5471949 */ "unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000\000"
/* offset=5472076 */ "unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5472225 */ "unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000\000"
/* offset=5472342 */ "unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5472504 */ "unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000\000"
/* offset=5472633 */ "unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5472795 */ "unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000\000"
/* offset=5472924 */ "unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5473086 */ "unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000\000"
/* offset=5473215 */ "unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5473377 */ "unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000\000"
/* offset=5473506 */ "unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5473668 */ "unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000\000"
/* offset=5473797 */ "unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5473959 */ "unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000\000"
/* offset=5474088 */ "unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5474247 */ "unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000\000"
/* offset=5474374 */ "unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000\000"
/* offset=5474501 */ "unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5474660 */ "unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000\000"
/* offset=5474787 */ "unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000\000"
/* offset=5474914 */ "unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5475073 */ "unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000\000"
/* offset=5475200 */ "unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000\000"
/* offset=5475327 */ "unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000\000"
/* offset=5475455 */ "unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5475614 */ "unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000\000"
/* offset=5475741 */ "unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x20\000\00001\000\000"
/* offset=5475869 */ "unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5476028 */ "unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000\000"
/* offset=5476155 */ "unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x40\000\00001\000\000"
/* offset=5476283 */ "unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5476442 */ "unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000\000"
/* offset=5476569 */ "unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5476728 */ "unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000\000"
/* offset=5476855 */ "unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x80\000\00001\000\000"
/* offset=5476983 */ "unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5477142 */ "unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000\000"
/* offset=5477269 */ "unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5477428 */ "unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000\000"
/* offset=5477555 */ "unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5477752 */ "unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000\000"
/* offset=5477899 */ "unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5478096 */ "unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000\000"
/* offset=5478243 */ "unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5478442 */ "unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000\000"
/* offset=5478590 */ "unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5478791 */ "unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000\000"
/* offset=5478940 */ "unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5479109 */ "unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000\000"
/* offset=5479243 */ "unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000\000"
/* offset=5479370 */ "unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5479519 */ "unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000\000"
/* offset=5479636 */ "unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5479798 */ "unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000\000"
/* offset=5479927 */ "unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5480089 */ "unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000\000"
/* offset=5480218 */ "unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5480380 */ "unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000\000"
/* offset=5480509 */ "unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5480671 */ "unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000\000"
/* offset=5480800 */ "unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5480962 */ "unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000\000"
/* offset=5481091 */ "unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5481253 */ "unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000\000"
/* offset=5481382 */ "unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5481541 */ "unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000\000"
/* offset=5481668 */ "unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000\000"
/* offset=5481795 */ "unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5481954 */ "unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000\000"
/* offset=5482081 */ "unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000\000"
/* offset=5482208 */ "unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5482367 */ "unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000\000"
/* offset=5482494 */ "unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000\000"
/* offset=5482621 */ "unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000\000"
/* offset=5482749 */ "unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5482908 */ "unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000\000"
/* offset=5483035 */ "unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x20\000\00001\000\000"
/* offset=5483163 */ "unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5483322 */ "unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000\000"
/* offset=5483449 */ "unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x40\000\00001\000\000"
/* offset=5483577 */ "unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5483736 */ "unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000\000"
/* offset=5483863 */ "unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5484022 */ "unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000\000"
/* offset=5484149 */ "unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x80\000\00001\000\000"
/* offset=5484277 */ "unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5484436 */ "unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000\000"
/* offset=5484563 */ "unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5484722 */ "unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000\000"
/* offset=5484849 */ "unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5485046 */ "unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000\000"
/* offset=5485193 */ "unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5485390 */ "unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000\000"
/* offset=5485537 */ "unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5485736 */ "unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000\000"
/* offset=5485884 */ "unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5486085 */ "unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000\000"
/* offset=5486234 */ "unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5486403 */ "unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000\000"
/* offset=5486537 */ "unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000\000"
/* offset=5486664 */ "unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5486813 */ "unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000\000"
/* offset=5486930 */ "unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5487092 */ "unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000\000"
/* offset=5487221 */ "unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5487383 */ "unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000\000"
/* offset=5487512 */ "unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5487674 */ "unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000\000"
/* offset=5487803 */ "unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5487965 */ "unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000\000"
/* offset=5488094 */ "unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5488256 */ "unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000\000"
/* offset=5488385 */ "unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5488547 */ "unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000\000"
/* offset=5488676 */ "unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5488835 */ "unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000\000"
/* offset=5488962 */ "unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000\000"
/* offset=5489089 */ "unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5489248 */ "unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000\000"
/* offset=5489375 */ "unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000\000"
/* offset=5489502 */ "unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5489661 */ "unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000\000"
/* offset=5489788 */ "unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000\000"
/* offset=5489915 */ "unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000\000"
/* offset=5490043 */ "unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5490202 */ "unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000\000"
/* offset=5490329 */ "unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x20\000\00001\000\000"
/* offset=5490457 */ "unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5490616 */ "unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000\000"
/* offset=5490743 */ "unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x40\000\00001\000\000"
/* offset=5490871 */ "unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5491030 */ "unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000\000"
/* offset=5491157 */ "unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5491316 */ "unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000\000"
/* offset=5491443 */ "unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x80\000\00001\000\000"
/* offset=5491571 */ "unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5491730 */ "unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000\000"
/* offset=5491857 */ "unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5492016 */ "unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000\000"
/* offset=5492143 */ "unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5492340 */ "unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000\000"
/* offset=5492487 */ "unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5492684 */ "unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000\000"
/* offset=5492831 */ "unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5493030 */ "unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000\000"
/* offset=5493178 */ "unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5493379 */ "unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000\000"
/* offset=5493528 */ "unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000"
/* offset=5493697 */ "unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000\000"
/* offset=5493831 */ "unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000\000"
/* offset=5493958 */ "unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000"
/* offset=5494107 */ "unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000\000"
/* offset=5494224 */ "unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000"
/* offset=5494386 */ "unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000\000"
/* offset=5494515 */ "unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000"
/* offset=5494677 */ "unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000\000"
/* offset=5494806 */ "unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000"
/* offset=5494968 */ "unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000\000"
/* offset=5495097 */ "unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000"
/* offset=5495259 */ "unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000\000"
/* offset=5495388 */ "unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000"
/* offset=5495550 */ "unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000\000"
/* offset=5495679 */ "unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000"
/* offset=5495841 */ "unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000\000"
/* offset=5495970 */ "unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000"
/* offset=5496129 */ "unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000\000"
/* offset=5496256 */ "unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000\000"
/* offset=5496383 */ "unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000"
/* offset=5496542 */ "unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000\000"
/* offset=5496669 */ "unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000\000"
/* offset=5496796 */ "unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000"
/* offset=5496955 */ "unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000\000"
/* offset=5497082 */ "unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000\000"
/* offset=5497209 */ "unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000\000"
/* offset=5497337 */ "unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000"
/* offset=5497496 */ "unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000\000"
/* offset=5497623 */ "unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x20\000\00001\000\000"
/* offset=5497751 */ "unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000"
/* offset=5497910 */ "unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000\000"
/* offset=5498037 */ "unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x40\000\00001\000\000"
/* offset=5498165 */ "unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000"
/* offset=5498324 */ "unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000\000"
/* offset=5498451 */ "unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000"
/* offset=5498610 */ "unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000\000"
/* offset=5498737 */ "unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x80\000\00001\000\000"
/* offset=5498865 */ "unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000"
/* offset=5499024 */ "unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000\000"
/* offset=5499151 */ "unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000"
/* offset=5499310 */ "unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000\000"
/* offset=5499437 */ "unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5499634 */ "unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000\000"
/* offset=5499781 */ "unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5499978 */ "unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000\000"
/* offset=5500125 */ "unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5500324 */ "unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000\000"
/* offset=5500472 */ "unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5500673 */ "unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000\000"
/* offset=5500822 */ "unc_m_rd_data\000uncore_imc\000uncore memory\000Number of bytes read from DRAM, in 32B chunks. Counter increments by 1 after receiving 32B chunk data. Unit: uncore_imc \000event=0x3a\000\00001\000\000"
/* offset=5500998 */ "unc_m_rdb_full\000uncore_imc\000uncore memory\000Counts the number of cycles where the read buffer has greater than UMASK elements.  This includes reads to both DDR and PMEM.  NOTE: Umask must be set to the maximum number of elements in the queue (24 entries for SPR). Unit: uncore_imc \000event=0x19\000\00001\000\000"
/* offset=5501292 */ "unc_m_rdb_full\000uncore_imc\000uncore memory\000Read Data Buffer Full. Unit: uncore_imc \000event=0x19\000\00001\000\000"
/* offset=5501389 */ "unc_m_rdb_inserts.pch0\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=5501507 */ "unc_m_rdb_inserts.pch1\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=5501625 */ "unc_m_rdb_inserts\000uncore_imc\000uncore memory\000Counts the number of inserts into the read buffer destined for DDR.  Does not count reads destined for PMEM. Unit: uncore_imc \000event=0x17,umask=0x3\000\00001\000\000"
/* offset=5501821 */ "unc_m_rdb_inserts\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17\000\00001\000\000"
/* offset=5501924 */ "unc_m_rdb_ne.pch0\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=5502039 */ "unc_m_rdb_ne.pch1\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=5502154 */ "unc_m_rdb_ne\000uncore_imc\000uncore memory\000Counts the number of cycles where there's at least one element in the read buffer.  This includes reads to both DDR and PMEM. Unit: uncore_imc \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=5502362 */ "unc_m_rdb_not_empty\000uncore_imc\000uncore memory\000Counts the number of cycles where there's at least one element in the read buffer.  This includes reads to both DDR and PMEM. Unit: uncore_imc \000event=0x18,umask=0x3\000\00001\000\000"
/* offset=5502577 */ "unc_m_rdb_not_empty\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18\000\00001\000\000"
/* offset=5502684 */ "unc_m_rdb_occupancy\000uncore_imc\000uncore memory\000Counts the number of elements in the read buffer, including reads to both DDR and PMEM. Unit: uncore_imc \000event=0x1a\000\00001\000\000"
/* offset=5502851 */ "unc_m_rdb_occupancy\000uncore_imc\000uncore memory\000Read Data Buffer Occupancy. Unit: uncore_imc \000event=0x1a\000\00001\000\000"
/* offset=5502958 */ "unc_m_rpq_cycles_full\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000"
/* offset=5503589 */ "unc_m_rpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000"
/* offset=5504258 */ "unc_m_rpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x15\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000"
/* offset=5504927 */ "unc_m_rpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x1\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000"
/* offset=5505763 */ "unc_m_rpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x2\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000"
/* offset=5506599 */ "unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000"
/* offset=5507389 */ "unc_m_rpq_inserts.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000"
/* offset=5507980 */ "unc_m_rpq_inserts.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000"
/* offset=5508571 */ "unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000"
/* offset=5509114 */ "unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of read requests allocated into the Read Pending Queue (RPQ).  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  The requests deallocate after the read CAS command has been issued to DRAM.  This event counts both Isochronous and non-Isochronous requests which were issued to the RPQ\000"
/* offset=5509732 */ "unc_m_rpq_occupancy\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000"
/* offset=5510414 */ "unc_m_rpq_occupancy\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Counts the number of entries in the Read Pending Queue (RPQ) at each cycle.  This can then be used to calculate both the average occupancy of the queue (in conjunction with the number of cycles not empty) and the average latency in the queue (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC. They deallocate from the RPQ after the CAS command has been issued to memory\000"
/* offset=5511146 */ "unc_m_rpq_occupancy_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000"
/* offset=5511864 */ "unc_m_rpq_occupancy_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000"
/* offset=5512582 */ "unc_m_sb_accesses.accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : Scoreboard Accesses Accepted. Unit: uncore_imc \000event=0xd2,umask=0x5\000\00001\000\000"
/* offset=5512729 */ "unc_m_sb_accesses.accepts\000uncore_imc\000uncore memory\000Scoreboard accepts. Unit: uncore_imc \000event=0xd2,umask=0x5\000\00001\000\000"
/* offset=5512844 */ "unc_m_sb_accesses.fm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Accepts. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00001\000\000"
/* offset=5512980 */ "unc_m_sb_accesses.fm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; Write Accepts. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00001\000\000"
/* offset=5513115 */ "unc_m_sb_accesses.fm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Rejects. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00001\000\000"
/* offset=5513251 */ "unc_m_sb_accesses.fm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; Write Rejects. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00001\000\000"
/* offset=5513386 */ "unc_m_sb_accesses.fmrd_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00011\000\000"
/* offset=5513510 */ "unc_m_sb_accesses.fmwr_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00011\000\000"
/* offset=5513634 */ "unc_m_sb_accesses.nm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM read completions. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00001\000\000"
/* offset=5513776 */ "unc_m_sb_accesses.nm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; FM read completions. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00001\000\000"
/* offset=5513917 */ "unc_m_sb_accesses.nm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM write completions. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00001\000\000"
/* offset=5514060 */ "unc_m_sb_accesses.nm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; FM write completions. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00001\000\000"
/* offset=5514202 */ "unc_m_sb_accesses.nmrd_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00011\000\000"
/* offset=5514326 */ "unc_m_sb_accesses.nmwr_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00011\000\000"
/* offset=5514450 */ "unc_m_sb_accesses.rd_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Accepts. Unit: uncore_imc \000event=0xd2,umask=0x1\000\00001\000\000"
/* offset=5514584 */ "unc_m_sb_accesses.rd_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses; Read Accepts. Unit: uncore_imc \000event=0xd2,umask=0x1\000\00001\000\000"
/* offset=5514717 */ "unc_m_sb_accesses.rd_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Rejects. Unit: uncore_imc \000event=0xd2,umask=0x2\000\00001\000\000"
/* offset=5514851 */ "unc_m_sb_accesses.rd_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses; Read Rejects. Unit: uncore_imc \000event=0xd2,umask=0x2\000\00001\000\000"
/* offset=5514984 */ "unc_m_sb_accesses.rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : Scoreboard Accesses Rejected. Unit: uncore_imc \000event=0xd2,umask=0xa\000\00001\000\000"
/* offset=5515131 */ "unc_m_sb_accesses.rejects\000uncore_imc\000uncore memory\000Scoreboard rejects. Unit: uncore_imc \000event=0xd2,umask=0xa\000\00001\000\000"
/* offset=5515246 */ "unc_m_sb_accesses.wr_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM read completions. Unit: uncore_imc \000event=0xd2,umask=0x4\000\00001\000\000"
/* offset=5515387 */ "unc_m_sb_accesses.wr_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses; NM read completions. Unit: uncore_imc \000event=0xd2,umask=0x4\000\00001\000\000"
/* offset=5515527 */ "unc_m_sb_accesses.wr_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM write completions. Unit: uncore_imc \000event=0xd2,umask=0x8\000\00001\000\000"
/* offset=5515669 */ "unc_m_sb_accesses.wr_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses; NM write completions. Unit: uncore_imc \000event=0xd2,umask=0x8\000\00001\000\000"
/* offset=5515810 */ "unc_m_sb_canary.alloc\000uncore_imc\000uncore memory\000: Alloc. Unit: uncore_imc \000event=0xd9,umask=0x1\000\00001\000\000"
/* offset=5515910 */ "unc_m_sb_canary.alloc\000uncore_imc\000uncore memory\000Alloc. Unit: uncore_imc \000event=0xd9,umask=0x1\000\00001\000\000"
/* offset=5516008 */ "unc_m_sb_canary.dealloc\000uncore_imc\000uncore memory\000: Dealloc. Unit: uncore_imc \000event=0xd9,umask=0x2\000\00001\000\000"
/* offset=5516112 */ "unc_m_sb_canary.dealloc\000uncore_imc\000uncore memory\000Dealloc. Unit: uncore_imc \000event=0xd9,umask=0x2\000\00001\000\000"
/* offset=5516214 */ "unc_m_sb_canary.fm_rd_starved\000uncore_imc\000uncore memory\000: Near Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00001\000\000"
/* offset=5516340 */ "unc_m_sb_canary.fm_tgr_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00001\000\000"
/* offset=5516469 */ "unc_m_sb_canary.fm_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00001\000\000"
/* offset=5516593 */ "unc_m_sb_canary.fmrd_starved\000uncore_imc\000uncore memory\000Far Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00001\000\000"
/* offset=5516714 */ "unc_m_sb_canary.fmrd_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_RD_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00011\000\000"
/* offset=5516889 */ "unc_m_sb_canary.fmtgrwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_TGR_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00011\000\000"
/* offset=5517071 */ "unc_m_sb_canary.fmwr_starved\000uncore_imc\000uncore memory\000Far Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00001\000\000"
/* offset=5517193 */ "unc_m_sb_canary.fmwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00011\000\000"
/* offset=5517368 */ "unc_m_sb_canary.nm_rd_starved\000uncore_imc\000uncore memory\000: Valid. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00001\000\000"
/* offset=5517476 */ "unc_m_sb_canary.nm_wr_starved\000uncore_imc\000uncore memory\000: Near Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00001\000\000"
/* offset=5517601 */ "unc_m_sb_canary.nmrd_starved\000uncore_imc\000uncore memory\000Near Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00001\000\000"
/* offset=5517723 */ "unc_m_sb_canary.nmrd_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.NM_RD_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00011\000\000"
/* offset=5517897 */ "unc_m_sb_canary.nmwr_starved\000uncore_imc\000uncore memory\000Near Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00001\000\000"
/* offset=5518020 */ "unc_m_sb_canary.nmwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.NM_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00011\000\000"
/* offset=5518195 */ "unc_m_sb_canary.rej\000uncore_imc\000uncore memory\000Reject. Unit: uncore_imc \000event=0xd9,umask=0x4\000\00001\000\000"
/* offset=5518292 */ "unc_m_sb_canary.vld\000uncore_imc\000uncore memory\000: Reject. Unit: uncore_imc \000event=0xd9,umask=0x4\000\00001\000\000"
/* offset=5518391 */ "unc_m_sb_canary.vld\000uncore_imc\000uncore memory\000Valid. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00001\000\000"
/* offset=5518487 */ "unc_m_sb_cycles_full\000uncore_imc\000uncore memory\000Scoreboard Cycles Full. Unit: uncore_imc \000event=0xd1\000\00001\000\000"
/* offset=5518591 */ "unc_m_sb_cycles_ne\000uncore_imc\000uncore memory\000Scoreboard Cycles Not-Empty. Unit: uncore_imc \000event=0xd0\000\00001\000\000"
/* offset=5518698 */ "unc_m_sb_inserts.block_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region reads. Unit: uncore_imc \000event=0xd6,umask=0x10\000\00001\000\000"
/* offset=5518836 */ "unc_m_sb_inserts.block_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Block region reads. Unit: uncore_imc \000event=0xd6,umask=0x10\000\00001\000\000"
/* offset=5518973 */ "unc_m_sb_inserts.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region writes. Unit: uncore_imc \000event=0xd6,umask=0x20\000\00001\000\000"
/* offset=5519112 */ "unc_m_sb_inserts.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Block region writes. Unit: uncore_imc \000event=0xd6,umask=0x20\000\00001\000\000"
/* offset=5519250 */ "unc_m_sb_inserts.dealloc\000uncore_imc\000uncore memory\000Scoreboard Inserts; Dealloc all commands (for error flows). Unit: uncore_imc \000event=0xd6,umask=0x40\000\00001\000\000"
/* offset=5519405 */ "unc_m_sb_inserts.patrol\000uncore_imc\000uncore memory\000Scoreboard Inserts; Patrol inserts. Unit: uncore_imc \000event=0xd6,umask=0x80\000\00001\000\000"
/* offset=5519535 */ "unc_m_sb_inserts.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem reads. Unit: uncore_imc \000event=0xd6,umask=0x4\000\00001\000\000"
/* offset=5519672 */ "unc_m_sb_inserts.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Persistent Mem reads. Unit: uncore_imc \000event=0xd6,umask=0x4\000\00001\000\000"
/* offset=5519808 */ "unc_m_sb_inserts.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem writes. Unit: uncore_imc \000event=0xd6,umask=0x8\000\00001\000\000"
/* offset=5519946 */ "unc_m_sb_inserts.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Persistent Mem writes. Unit: uncore_imc \000event=0xd6,umask=0x8\000\00001\000\000"
/* offset=5520083 */ "unc_m_sb_inserts.rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Reads. Unit: uncore_imc \000event=0xd6,umask=0x1\000\00001\000\000"
/* offset=5520201 */ "unc_m_sb_inserts.rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Reads. Unit: uncore_imc \000event=0xd6,umask=0x1\000\00001\000\000"
/* offset=5520318 */ "unc_m_sb_inserts.wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Writes. Unit: uncore_imc \000event=0xd6,umask=0x2\000\00001\000\000"
/* offset=5520437 */ "unc_m_sb_inserts.wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Writes. Unit: uncore_imc \000event=0xd6,umask=0x2\000\00001\000\000"
/* offset=5520555 */ "unc_m_sb_occupancy.block_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region reads. Unit: uncore_imc \000event=0xd5,umask=0x20\000\00001\000\000"
/* offset=5520697 */ "unc_m_sb_occupancy.block_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Block region reads. Unit: uncore_imc \000event=0xd5,umask=0x20\000\00001\000\000"
/* offset=5520838 */ "unc_m_sb_occupancy.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region writes. Unit: uncore_imc \000event=0xd5,umask=0x40\000\00001\000\000"
/* offset=5520981 */ "unc_m_sb_occupancy.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Block region writes. Unit: uncore_imc \000event=0xd5,umask=0x40\000\00001\000\000"
/* offset=5521123 */ "unc_m_sb_occupancy.patrol\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Patrol. Unit: uncore_imc \000event=0xd5,umask=0x80\000\00001\000\000"
/* offset=5521249 */ "unc_m_sb_occupancy.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem reads. Unit: uncore_imc \000event=0xd5,umask=0x4\000\00001\000\000"
/* offset=5521390 */ "unc_m_sb_occupancy.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Persistent Mem reads. Unit: uncore_imc \000event=0xd5,umask=0x4\000\00001\000\000"
/* offset=5521530 */ "unc_m_sb_occupancy.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem writes. Unit: uncore_imc \000event=0xd5,umask=0x8\000\00001\000\000"
/* offset=5521672 */ "unc_m_sb_occupancy.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Persistent Mem writes. Unit: uncore_imc \000event=0xd5,umask=0x8\000\00001\000\000"
/* offset=5521813 */ "unc_m_sb_occupancy.rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Reads. Unit: uncore_imc \000event=0xd5,umask=0x1\000\00001\000\000"
/* offset=5521935 */ "unc_m_sb_occupancy.rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Reads. Unit: uncore_imc \000event=0xd5,umask=0x1\000\00001\000\000"
/* offset=5522056 */ "unc_m_sb_occupancy.wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Writes. Unit: uncore_imc \000event=0xd5,umask=0x2\000\00001\000\000"
/* offset=5522178 */ "unc_m_sb_pref_inserts.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : All. Unit: uncore_imc \000event=0xda,umask=0x1\000\00001\000\000"
/* offset=5522308 */ "unc_m_sb_pref_inserts.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : DDR4. Unit: uncore_imc \000event=0xda,umask=0x2\000\00001\000\000"
/* offset=5522439 */ "unc_m_sb_pref_inserts.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : PMM. Unit: uncore_imc \000event=0xda,umask=0x4\000\00001\000\000"
/* offset=5522569 */ "unc_m_sb_pref_inserts.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : Persistent Mem. Unit: uncore_imc \000event=0xda,umask=0x4\000\00001\000\000"
/* offset=5522710 */ "unc_m_sb_pref_occupancy.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : All. Unit: uncore_imc \000event=0xdb,umask=0x1\000\00001\000\000"
/* offset=5522844 */ "unc_m_sb_pref_occupancy.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : DDR4. Unit: uncore_imc \000event=0xdb,umask=0x2\000\00001\000\000"
/* offset=5522979 */ "unc_m_sb_pref_occupancy.pmem\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_PREF_OCCUPANCY.PMM. Unit: uncore_imc \000event=0xdb,umask=0x4\000\00011\000\000"
/* offset=5523151 */ "unc_m_sb_pref_occupancy.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : Persistent Mem. Unit: uncore_imc \000event=0xdb,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x4\000\00001\000\000"
/* offset=5523334 */ "unc_m_sb_pref_occupancy.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : Persistent Mem. Unit: uncore_imc \000event=0xdb,umask=0x4\000\00001\000\000"
/* offset=5523479 */ "unc_m_sb_reject.canary\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x8\000\00001\000\000"
/* offset=5523611 */ "unc_m_sb_reject.ddr_early_cmp\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x20\000\00001\000\000"
/* offset=5523751 */ "unc_m_sb_reject.fm_addr_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : FM requests rejected due to full address conflict. Unit: uncore_imc \000event=0xd4,umask=0x2\000\00001\000\000"
/* offset=5523942 */ "unc_m_sb_reject.fm_addr_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; FM requests rejected due to full address conflict. Unit: uncore_imc \000event=0xd4,umask=0x2\000\00001\000\000"
/* offset=5524132 */ "unc_m_sb_reject.nm_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : NM requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x1\000\00001\000\000"
/* offset=5524313 */ "unc_m_sb_reject.nm_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; NM requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x1\000\00001\000\000"
/* offset=5524493 */ "unc_m_sb_reject.patrol_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : Patrol requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x4\000\00001\000\000"
/* offset=5524682 */ "unc_m_sb_reject.patrol_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; Patrol requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x4\000\00001\000\000"
/* offset=5524870 */ "unc_m_sb_strv_alloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00001\000\000"
/* offset=5524987 */ "unc_m_sb_strv_alloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00001\000\000"
/* offset=5525109 */ "unc_m_sb_strv_alloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00001\000\000"
/* offset=5525227 */ "unc_m_sb_strv_alloc.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_RD. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00011\000\000"
/* offset=5525393 */ "unc_m_sb_strv_alloc.fmrd_clr\000uncore_imc\000uncore memory\000Far Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x20\000\00001\000\000"
/* offset=5525514 */ "unc_m_sb_strv_alloc.fmrd_set\000uncore_imc\000uncore memory\000Far Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00001\000\000"
/* offset=5525632 */ "unc_m_sb_strv_alloc.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_TGR. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00011\000\000"
/* offset=5525801 */ "unc_m_sb_strv_alloc.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_WR. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00011\000\000"
/* offset=5525967 */ "unc_m_sb_strv_alloc.fmwr_clr\000uncore_imc\000uncore memory\000Far Mem Write - Clear. Unit: uncore_imc \000event=0xd7,umask=0x80\000\00001\000\000"
/* offset=5526089 */ "unc_m_sb_strv_alloc.fmwr_set\000uncore_imc\000uncore memory\000Far Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00001\000\000"
/* offset=5526208 */ "unc_m_sb_strv_alloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00001\000\000"
/* offset=5526326 */ "unc_m_sb_strv_alloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00001\000\000"
/* offset=5526445 */ "unc_m_sb_strv_alloc.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.NM_RD. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00011\000\000"
/* offset=5526611 */ "unc_m_sb_strv_alloc.nmrd_clr\000uncore_imc\000uncore memory\000Near Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00001\000\000"
/* offset=5526733 */ "unc_m_sb_strv_alloc.nmrd_set\000uncore_imc\000uncore memory\000Near Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00001\000\000"
/* offset=5526852 */ "unc_m_sb_strv_alloc.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.NM_WR. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00011\000\000"
/* offset=5527018 */ "unc_m_sb_strv_alloc.nmwr_clr\000uncore_imc\000uncore memory\000Near Mem Write - Clear. Unit: uncore_imc \000event=0xd7,umask=0x40\000\00001\000\000"
/* offset=5527141 */ "unc_m_sb_strv_alloc.nmwr_set\000uncore_imc\000uncore memory\000Near Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00001\000\000"
/* offset=5527261 */ "unc_m_sb_strv_dealloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x2\000\00001\000\000"
/* offset=5527380 */ "unc_m_sb_strv_dealloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xde,umask=0x10\000\00001\000\000"
/* offset=5527504 */ "unc_m_sb_strv_dealloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x8\000\00001\000\000"
/* offset=5527624 */ "unc_m_sb_strv_dealloc.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_RD. Unit: uncore_imc \000event=0xde,umask=0x2\000\00011\000\000"
/* offset=5527794 */ "unc_m_sb_strv_dealloc.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_TGR. Unit: uncore_imc \000event=0xde,umask=0x10\000\00011\000\000"
/* offset=5527967 */ "unc_m_sb_strv_dealloc.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_WR. Unit: uncore_imc \000event=0xde,umask=0x8\000\00011\000\000"
/* offset=5528137 */ "unc_m_sb_strv_dealloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x1\000\00001\000\000"
/* offset=5528257 */ "unc_m_sb_strv_dealloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x4\000\00001\000\000"
/* offset=5528378 */ "unc_m_sb_strv_dealloc.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.NM_RD. Unit: uncore_imc \000event=0xde,umask=0x1\000\00011\000\000"
/* offset=5528548 */ "unc_m_sb_strv_dealloc.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.NM_WR. Unit: uncore_imc \000event=0xde,umask=0x4\000\00011\000\000"
/* offset=5528718 */ "unc_m_sb_strv_occ.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00001\000\000"
/* offset=5528827 */ "unc_m_sb_strv_occ.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd8,umask=0x10\000\00001\000\000"
/* offset=5528947 */ "unc_m_sb_strv_occ.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00001\000\000"
/* offset=5529057 */ "unc_m_sb_strv_occ.fmrd\000uncore_imc\000uncore memory\000Far Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00001\000\000"
/* offset=5529163 */ "unc_m_sb_strv_occ.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_RD. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00011\000\000"
/* offset=5529325 */ "unc_m_sb_strv_occ.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_TGR. Unit: uncore_imc \000event=0xd8,umask=0x10\000\00011\000\000"
/* offset=5529490 */ "unc_m_sb_strv_occ.fmwr\000uncore_imc\000uncore memory\000Far Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00001\000\000"
/* offset=5529597 */ "unc_m_sb_strv_occ.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_WR. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00011\000\000"
/* offset=5529759 */ "unc_m_sb_strv_occ.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00001\000\000"
/* offset=5529869 */ "unc_m_sb_strv_occ.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00001\000\000"
/* offset=5529980 */ "unc_m_sb_strv_occ.nmrd\000uncore_imc\000uncore memory\000Near Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00001\000\000"
/* offset=5530087 */ "unc_m_sb_strv_occ.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.NM_RD. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00011\000\000"
/* offset=5530249 */ "unc_m_sb_strv_occ.nmwr\000uncore_imc\000uncore memory\000Near Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00001\000\000"
/* offset=5530357 */ "unc_m_sb_strv_occ.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.NM_WR. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00011\000\000"
/* offset=5530519 */ "unc_m_sb_tagged.ddr4_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.DDR4_CMP. Unit: uncore_imc \000event=0xdd,umask=0x8\000\00001\000\000"
/* offset=5530639 */ "unc_m_sb_tagged.new\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.NEW. Unit: uncore_imc \000event=0xdd,umask=0x1\000\00001\000\000"
/* offset=5530749 */ "unc_m_sb_tagged.occ\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.OCC. Unit: uncore_imc \000event=0xdd,umask=0x80\000\00001\000\000"
/* offset=5530860 */ "unc_m_sb_tagged.pmm0_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM0_CMP. Unit: uncore_imc \000event=0xdd,umask=0x10\000\00001\000\000"
/* offset=5530981 */ "unc_m_sb_tagged.pmm1_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM1_CMP. Unit: uncore_imc \000event=0xdd,umask=0x20\000\00001\000\000"
/* offset=5531102 */ "unc_m_sb_tagged.pmm2_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM2_CMP. Unit: uncore_imc \000event=0xdd,umask=0x40\000\00001\000\000"
/* offset=5531223 */ "unc_m_sb_tagged.rd_hit\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_HIT. Unit: uncore_imc \000event=0xdd,umask=0x2\000\00001\000\000"
/* offset=5531339 */ "unc_m_sb_tagged.rd_miss\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_MISS. Unit: uncore_imc \000event=0xdd,umask=0x4\000\00001\000\000"
/* offset=5531457 */ "unc_m_tagchk.hit\000uncore_imc\000uncore memory\0002LM Tag Check : Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000\000"
/* offset=5531585 */ "unc_m_tagchk.hit\000uncore_imc\000uncore memory\0002LM Tag check hit in near memory cache (DDR4). Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000\000"
/* offset=5531718 */ "unc_m_tagchk.hit\000uncore_imc\000uncore memory\000All hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000Tag Check; Hit\000"
/* offset=5531870 */ "unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\0002LM Tag Check : Miss, no data in this line. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000\000"
/* offset=5532007 */ "unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\0002LM Tag check miss, no data at this line. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000\000"
/* offset=5532142 */ "unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\000All Clean line misses to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000Tag Check; Clean\000"
/* offset=5532316 */ "unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\0002LM Tag Check : Miss, existing data may be evicted to Far Memory. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000\000"
/* offset=5532475 */ "unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\0002LM Tag check miss, existing data may be evicted to PMM. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000\000"
/* offset=5532625 */ "unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\000All dirty line misses to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000Tag Check; Dirty\000"
/* offset=5532799 */ "unc_m_tagchk.nm_rd_hit\000uncore_imc\000uncore memory\0002LM Tag Check : Read Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x8\000\00001\000\000"
/* offset=5532938 */ "unc_m_tagchk.nm_rd_hit\000uncore_imc\000uncore memory\0002LM Tag check hit due to memory read. Unit: uncore_imc \000event=0xd3,umask=0x8\000\00001\000\000"
/* offset=5533068 */ "unc_m_tagchk.nm_wr_hit\000uncore_imc\000uncore memory\0002LM Tag Check : Write Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x10\000\00001\000\000"
/* offset=5533209 */ "unc_m_tagchk.nm_wr_hit\000uncore_imc\000uncore memory\0002LM Tag check hit due to memory write. Unit: uncore_imc \000event=0xd3,umask=0x10\000\00001\000\000"
/* offset=5533341 */ "unc_m_total_data\000uncore_imc\000uncore memory\000Total number of read and write byte transfers to/from DRAM, in 32B chunks. Counter increments by 1 after sending or receiving 32B chunk data. Unit: uncore_imc \000event=0x3c\000\00001\000\000"
/* offset=5533559 */ "unc_m_u_clockticks\000uncore_imc_uclk\000uncore memory\000UCLK count. Unit: uncore_imc_uclk \000event=0\000\00001\000\000"
/* offset=5533656 */ "unc_m_vc0_requests_rd\000uncore_imc\000uncore memory\000Incoming VC0 read request. Unit: uncore_imc \000event=0x2\000\00001\000\000"
/* offset=5533763 */ "unc_m_vc0_requests_wr\000uncore_imc\000uncore memory\000Incoming VC0 write request. Unit: uncore_imc \000event=0x3\000\00001\000\000"
/* offset=5533871 */ "unc_m_vc1_requests_rd\000uncore_imc\000uncore memory\000Incoming VC1 read request. Unit: uncore_imc \000event=0x4\000\00001\000\000"
/* offset=5533978 */ "unc_m_vc1_requests_wr\000uncore_imc\000uncore memory\000Incoming VC1 write request. Unit: uncore_imc \000event=0x5\000\00001\000\000"
/* offset=5534086 */ "unc_m_vmse_mxb_wr_occupancy\000uncore_imc\000uncore memory\000VMSE MXB write buffer occupancy. Unit: uncore_imc \000event=0x91\000\00001\000\000"
/* offset=5534206 */ "unc_m_vmse_wr_push.rmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in RMM. Unit: uncore_imc \000event=0x90,umask=0x2\000\00001\000\000"
/* offset=5534350 */ "unc_m_vmse_wr_push.wmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in WMM. Unit: uncore_imc \000event=0x90,umask=0x1\000\00001\000\000"
/* offset=5534494 */ "unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000"
/* offset=5534698 */ "unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000"
/* offset=5534844 */ "unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000"
/* offset=5534994 */ "unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000"
/* offset=5535448 */ "unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000"
/* offset=5535905 */ "unc_m_wpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000"
/* offset=5536401 */ "unc_m_wpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x16\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000"
/* offset=5536897 */ "unc_m_wpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x1\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000"
/* offset=5537871 */ "unc_m_wpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x2\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000"
/* offset=5538845 */ "unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000"
/* offset=5539772 */ "unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000"
/* offset=5540700 */ "unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000"
/* offset=5541626 */ "unc_m_wpq_inserts.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000"
/* offset=5542390 */ "unc_m_wpq_inserts.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000"
/* offset=5543154 */ "unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC\000"
/* offset=5543870 */ "unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000"
/* offset=5544584 */ "unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of writes requests allocated into the Write Pending Queue (WPQ).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (Memory Controller).  The write requests deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC\000"
/* offset=5545247 */ "unc_m_wpq_occupancy\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the 'not posted' filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The 'posted' filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5546690 */ "unc_m_wpq_occupancy\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Counts the number of entries in the Write Pending Queue (WPQ) at each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (memory controller).  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the 'not posted' filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The 'posted' filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5548167 */ "unc_m_wpq_occupancy_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x82\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5549641 */ "unc_m_wpq_occupancy_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x83\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5551115 */ "unc_m_wpq_read_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5551801 */ "unc_m_wpq_read_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5552487 */ "unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5553164 */ "unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5553803 */ "unc_m_wpq_write_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5554490 */ "unc_m_wpq_write_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5555177 */ "unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5555855 */ "unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5556495 */ "unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5556664 */ "unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000\000"
/* offset=5556798 */ "unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000\000"
/* offset=5556925 */ "unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5557074 */ "unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000\000"
/* offset=5557191 */ "unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5557353 */ "unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000\000"
/* offset=5557482 */ "unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5557644 */ "unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000\000"
/* offset=5557773 */ "unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5557935 */ "unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000\000"
/* offset=5558064 */ "unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5558226 */ "unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000\000"
/* offset=5558355 */ "unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5558517 */ "unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000\000"
/* offset=5558646 */ "unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5558808 */ "unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000\000"
/* offset=5558937 */ "unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5559096 */ "unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000\000"
/* offset=5559223 */ "unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000\000"
/* offset=5559350 */ "unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5559509 */ "unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000\000"
/* offset=5559636 */ "unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000\000"
/* offset=5559763 */ "unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5559922 */ "unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000\000"
/* offset=5560049 */ "unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000\000"
/* offset=5560176 */ "unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000\000"
/* offset=5560304 */ "unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5560463 */ "unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000\000"
/* offset=5560590 */ "unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x20\000\00001\000\000"
/* offset=5560718 */ "unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5560877 */ "unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000\000"
/* offset=5561004 */ "unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x40\000\00001\000\000"
/* offset=5561132 */ "unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5561291 */ "unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000\000"
/* offset=5561418 */ "unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5561577 */ "unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000\000"
/* offset=5561704 */ "unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x80\000\00001\000\000"
/* offset=5561832 */ "unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5561991 */ "unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000\000"
/* offset=5562118 */ "unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5562277 */ "unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000\000"
/* offset=5562404 */ "unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5562601 */ "unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000\000"
/* offset=5562748 */ "unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5562945 */ "unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000\000"
/* offset=5563092 */ "unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5563291 */ "unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000\000"
/* offset=5563439 */ "unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5563640 */ "unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000\000"
/* offset=5563789 */ "unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5563958 */ "unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000\000"
/* offset=5564092 */ "unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000\000"
/* offset=5564219 */ "unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5564368 */ "unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000\000"
/* offset=5564485 */ "unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5564647 */ "unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000\000"
/* offset=5564776 */ "unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5564938 */ "unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000\000"
/* offset=5565067 */ "unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5565229 */ "unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000\000"
/* offset=5565358 */ "unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5565520 */ "unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000\000"
/* offset=5565649 */ "unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5565811 */ "unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000\000"
/* offset=5565940 */ "unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5566102 */ "unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000\000"
/* offset=5566231 */ "unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5566390 */ "unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000\000"
/* offset=5566517 */ "unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000\000"
/* offset=5566644 */ "unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5566803 */ "unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000\000"
/* offset=5566930 */ "unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000\000"
/* offset=5567057 */ "unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5567216 */ "unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000\000"
/* offset=5567343 */ "unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000\000"
/* offset=5567470 */ "unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000\000"
/* offset=5567598 */ "unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5567757 */ "unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000\000"
/* offset=5567884 */ "unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x20\000\00001\000\000"
/* offset=5568012 */ "unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5568171 */ "unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000\000"
/* offset=5568298 */ "unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x40\000\00001\000\000"
/* offset=5568426 */ "unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5568585 */ "unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000\000"
/* offset=5568712 */ "unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5568871 */ "unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000\000"
/* offset=5568998 */ "unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x80\000\00001\000\000"
/* offset=5569126 */ "unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5569285 */ "unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000\000"
/* offset=5569412 */ "unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5569571 */ "unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000\000"
/* offset=5569698 */ "unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5569895 */ "unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000\000"
/* offset=5570042 */ "unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5570239 */ "unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000\000"
/* offset=5570386 */ "unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5570585 */ "unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000\000"
/* offset=5570733 */ "unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5570934 */ "unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000\000"
/* offset=5571083 */ "unc_m_wr_cas_rank2.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xba,umask=0x10\000\00001\000\000"
/* offset=5571217 */ "unc_m_wr_cas_rank2.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xba,umask=0x1\000\00001\000\000"
/* offset=5571344 */ "unc_m_wr_cas_rank2.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xba\000\00001\000\000"
/* offset=5571461 */ "unc_m_wr_cas_rank2.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xba,umask=0xa\000\00001\000\000"
/* offset=5571590 */ "unc_m_wr_cas_rank2.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xba,umask=0xb\000\00001\000\000"
/* offset=5571719 */ "unc_m_wr_cas_rank2.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xba,umask=0xc\000\00001\000\000"
/* offset=5571848 */ "unc_m_wr_cas_rank2.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xba,umask=0xd\000\00001\000\000"
/* offset=5571977 */ "unc_m_wr_cas_rank2.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xba,umask=0xe\000\00001\000\000"
/* offset=5572106 */ "unc_m_wr_cas_rank2.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xba,umask=0xf\000\00001\000\000"
/* offset=5572235 */ "unc_m_wr_cas_rank2.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xba,umask=0x1\000\00001\000\000"
/* offset=5572362 */ "unc_m_wr_cas_rank2.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xba,umask=0x2\000\00001\000\000"
/* offset=5572489 */ "unc_m_wr_cas_rank2.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xba,umask=0x2\000\00001\000\000"
/* offset=5572616 */ "unc_m_wr_cas_rank2.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xba,umask=0x4\000\00001\000\000"
/* offset=5572743 */ "unc_m_wr_cas_rank2.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xba,umask=0x3\000\00001\000\000"
/* offset=5572870 */ "unc_m_wr_cas_rank2.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xba,umask=0x8\000\00001\000\000"
/* offset=5572997 */ "unc_m_wr_cas_rank2.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xba,umask=0x10\000\00001\000\000"
/* offset=5573125 */ "unc_m_wr_cas_rank2.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xba,umask=0x4\000\00001\000\000"
/* offset=5573252 */ "unc_m_wr_cas_rank2.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xba,umask=0x20\000\00001\000\000"
/* offset=5573380 */ "unc_m_wr_cas_rank2.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xba,umask=0x5\000\00001\000\000"
/* offset=5573507 */ "unc_m_wr_cas_rank2.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xba,umask=0x40\000\00001\000\000"
/* offset=5573635 */ "unc_m_wr_cas_rank2.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xba,umask=0x6\000\00001\000\000"
/* offset=5573762 */ "unc_m_wr_cas_rank2.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xba,umask=0x7\000\00001\000\000"
/* offset=5573889 */ "unc_m_wr_cas_rank2.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xba,umask=0x80\000\00001\000\000"
/* offset=5574017 */ "unc_m_wr_cas_rank2.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xba,umask=0x8\000\00001\000\000"
/* offset=5574144 */ "unc_m_wr_cas_rank2.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xba,umask=0x9\000\00001\000\000"
/* offset=5574271 */ "unc_m_wr_cas_rank2.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xba,umask=0x11\000\00001\000\000"
/* offset=5574418 */ "unc_m_wr_cas_rank2.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xba,umask=0x12\000\00001\000\000"
/* offset=5574565 */ "unc_m_wr_cas_rank2.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xba,umask=0x13\000\00001\000\000"
/* offset=5574713 */ "unc_m_wr_cas_rank2.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xba,umask=0x14\000\00001\000\000"
/* offset=5574862 */ "unc_m_wr_cas_rank3.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xbb,umask=0x10\000\00001\000\000"
/* offset=5574996 */ "unc_m_wr_cas_rank3.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xbb,umask=0x1\000\00001\000\000"
/* offset=5575123 */ "unc_m_wr_cas_rank3.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xbb\000\00001\000\000"
/* offset=5575240 */ "unc_m_wr_cas_rank3.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xbb,umask=0xa\000\00001\000\000"
/* offset=5575369 */ "unc_m_wr_cas_rank3.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xbb,umask=0xb\000\00001\000\000"
/* offset=5575498 */ "unc_m_wr_cas_rank3.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xbb,umask=0xc\000\00001\000\000"
/* offset=5575627 */ "unc_m_wr_cas_rank3.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xbb,umask=0xd\000\00001\000\000"
/* offset=5575756 */ "unc_m_wr_cas_rank3.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xbb,umask=0xe\000\00001\000\000"
/* offset=5575885 */ "unc_m_wr_cas_rank3.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xbb,umask=0xf\000\00001\000\000"
/* offset=5576014 */ "unc_m_wr_cas_rank3.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xbb,umask=0x1\000\00001\000\000"
/* offset=5576141 */ "unc_m_wr_cas_rank3.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xbb,umask=0x2\000\00001\000\000"
/* offset=5576268 */ "unc_m_wr_cas_rank3.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xbb,umask=0x2\000\00001\000\000"
/* offset=5576395 */ "unc_m_wr_cas_rank3.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xbb,umask=0x4\000\00001\000\000"
/* offset=5576522 */ "unc_m_wr_cas_rank3.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xbb,umask=0x3\000\00001\000\000"
/* offset=5576649 */ "unc_m_wr_cas_rank3.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xbb,umask=0x8\000\00001\000\000"
/* offset=5576776 */ "unc_m_wr_cas_rank3.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xbb,umask=0x10\000\00001\000\000"
/* offset=5576904 */ "unc_m_wr_cas_rank3.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xbb,umask=0x4\000\00001\000\000"
/* offset=5577031 */ "unc_m_wr_cas_rank3.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xbb,umask=0x20\000\00001\000\000"
/* offset=5577159 */ "unc_m_wr_cas_rank3.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xbb,umask=0x5\000\00001\000\000"
/* offset=5577286 */ "unc_m_wr_cas_rank3.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xbb,umask=0x40\000\00001\000\000"
/* offset=5577414 */ "unc_m_wr_cas_rank3.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xbb,umask=0x6\000\00001\000\000"
/* offset=5577541 */ "unc_m_wr_cas_rank3.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xbb,umask=0x7\000\00001\000\000"
/* offset=5577668 */ "unc_m_wr_cas_rank3.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xbb,umask=0x80\000\00001\000\000"
/* offset=5577796 */ "unc_m_wr_cas_rank3.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xbb,umask=0x8\000\00001\000\000"
/* offset=5577923 */ "unc_m_wr_cas_rank3.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xbb,umask=0x9\000\00001\000\000"
/* offset=5578050 */ "unc_m_wr_cas_rank3.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbb,umask=0x11\000\00001\000\000"
/* offset=5578197 */ "unc_m_wr_cas_rank3.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbb,umask=0x12\000\00001\000\000"
/* offset=5578344 */ "unc_m_wr_cas_rank3.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbb,umask=0x13\000\00001\000\000"
/* offset=5578492 */ "unc_m_wr_cas_rank3.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbb,umask=0x14\000\00001\000\000"
/* offset=5578641 */ "unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5578810 */ "unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000\000"
/* offset=5578944 */ "unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000\000"
/* offset=5579071 */ "unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5579220 */ "unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000\000"
/* offset=5579337 */ "unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5579499 */ "unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000\000"
/* offset=5579628 */ "unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5579790 */ "unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000\000"
/* offset=5579919 */ "unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5580081 */ "unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000\000"
/* offset=5580210 */ "unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5580372 */ "unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000\000"
/* offset=5580501 */ "unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5580663 */ "unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000\000"
/* offset=5580792 */ "unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5580954 */ "unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000\000"
/* offset=5581083 */ "unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5581242 */ "unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000\000"
/* offset=5581369 */ "unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000\000"
/* offset=5581496 */ "unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5581655 */ "unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000\000"
/* offset=5581782 */ "unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000\000"
/* offset=5581909 */ "unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5582068 */ "unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000\000"
/* offset=5582195 */ "unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000\000"
/* offset=5582322 */ "unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000\000"
/* offset=5582450 */ "unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5582609 */ "unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000\000"
/* offset=5582736 */ "unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x20\000\00001\000\000"
/* offset=5582864 */ "unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5583023 */ "unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000\000"
/* offset=5583150 */ "unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x40\000\00001\000\000"
/* offset=5583278 */ "unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5583437 */ "unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000\000"
/* offset=5583564 */ "unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5583723 */ "unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000\000"
/* offset=5583850 */ "unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x80\000\00001\000\000"
/* offset=5583978 */ "unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5584137 */ "unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000\000"
/* offset=5584264 */ "unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5584423 */ "unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000\000"
/* offset=5584550 */ "unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5584747 */ "unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000\000"
/* offset=5584894 */ "unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5585091 */ "unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000\000"
/* offset=5585238 */ "unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5585437 */ "unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000\000"
/* offset=5585585 */ "unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5585786 */ "unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000\000"
/* offset=5585935 */ "unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5586104 */ "unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000\000"
/* offset=5586238 */ "unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000\000"
/* offset=5586365 */ "unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5586514 */ "unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000\000"
/* offset=5586631 */ "unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5586793 */ "unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000\000"
/* offset=5586922 */ "unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5587084 */ "unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000\000"
/* offset=5587213 */ "unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5587375 */ "unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000\000"
/* offset=5587504 */ "unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5587666 */ "unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000\000"
/* offset=5587795 */ "unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5587957 */ "unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000\000"
/* offset=5588086 */ "unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5588248 */ "unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000\000"
/* offset=5588377 */ "unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5588536 */ "unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000\000"
/* offset=5588663 */ "unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000\000"
/* offset=5588790 */ "unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5588949 */ "unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000\000"
/* offset=5589076 */ "unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000\000"
/* offset=5589203 */ "unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5589362 */ "unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000\000"
/* offset=5589489 */ "unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000\000"
/* offset=5589616 */ "unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000\000"
/* offset=5589744 */ "unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5589903 */ "unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000\000"
/* offset=5590030 */ "unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x20\000\00001\000\000"
/* offset=5590158 */ "unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5590317 */ "unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000\000"
/* offset=5590444 */ "unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x40\000\00001\000\000"
/* offset=5590572 */ "unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5590731 */ "unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000\000"
/* offset=5590858 */ "unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5591017 */ "unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000\000"
/* offset=5591144 */ "unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x80\000\00001\000\000"
/* offset=5591272 */ "unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5591431 */ "unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000\000"
/* offset=5591558 */ "unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5591717 */ "unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000\000"
/* offset=5591844 */ "unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5592041 */ "unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000\000"
/* offset=5592188 */ "unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5592385 */ "unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000\000"
/* offset=5592532 */ "unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5592731 */ "unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000\000"
/* offset=5592879 */ "unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5593080 */ "unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000\000"
/* offset=5593229 */ "unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5593398 */ "unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000\000"
/* offset=5593532 */ "unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000\000"
/* offset=5593659 */ "unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5593808 */ "unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000\000"
/* offset=5593925 */ "unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5594087 */ "unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000\000"
/* offset=5594216 */ "unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5594378 */ "unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000\000"
/* offset=5594507 */ "unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5594669 */ "unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000\000"
/* offset=5594798 */ "unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5594960 */ "unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000\000"
/* offset=5595089 */ "unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5595251 */ "unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000\000"
/* offset=5595380 */ "unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5595542 */ "unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000\000"
/* offset=5595671 */ "unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5595830 */ "unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000\000"
/* offset=5595957 */ "unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000\000"
/* offset=5596084 */ "unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5596243 */ "unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000\000"
/* offset=5596370 */ "unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000\000"
/* offset=5596497 */ "unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5596656 */ "unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000\000"
/* offset=5596783 */ "unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000\000"
/* offset=5596910 */ "unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000\000"
/* offset=5597038 */ "unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5597197 */ "unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000\000"
/* offset=5597324 */ "unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x20\000\00001\000\000"
/* offset=5597452 */ "unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5597611 */ "unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000\000"
/* offset=5597738 */ "unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x40\000\00001\000\000"
/* offset=5597866 */ "unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5598025 */ "unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000\000"
/* offset=5598152 */ "unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5598311 */ "unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000\000"
/* offset=5598438 */ "unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x80\000\00001\000\000"
/* offset=5598566 */ "unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5598725 */ "unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000\000"
/* offset=5598852 */ "unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5599011 */ "unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000\000"
/* offset=5599138 */ "unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5599335 */ "unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000\000"
/* offset=5599482 */ "unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5599679 */ "unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000\000"
/* offset=5599826 */ "unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5600025 */ "unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000\000"
/* offset=5600173 */ "unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5600374 */ "unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000\000"
/* offset=5600523 */ "unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000"
/* offset=5600692 */ "unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000\000"
/* offset=5600826 */ "unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000\000"
/* offset=5600953 */ "unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000"
/* offset=5601102 */ "unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000\000"
/* offset=5601219 */ "unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000"
/* offset=5601381 */ "unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000\000"
/* offset=5601510 */ "unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000"
/* offset=5601672 */ "unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000\000"
/* offset=5601801 */ "unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000"
/* offset=5601963 */ "unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000\000"
/* offset=5602092 */ "unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000"
/* offset=5602254 */ "unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000\000"
/* offset=5602383 */ "unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000"
/* offset=5602545 */ "unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000\000"
/* offset=5602674 */ "unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000"
/* offset=5602836 */ "unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000\000"
/* offset=5602965 */ "unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000"
/* offset=5603124 */ "unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000\000"
/* offset=5603251 */ "unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000\000"
/* offset=5603378 */ "unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000"
/* offset=5603537 */ "unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000\000"
/* offset=5603664 */ "unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000\000"
/* offset=5603791 */ "unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000"
/* offset=5603950 */ "unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000\000"
/* offset=5604077 */ "unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000\000"
/* offset=5604204 */ "unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000\000"
/* offset=5604332 */ "unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000"
/* offset=5604491 */ "unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000\000"
/* offset=5604618 */ "unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x20\000\00001\000\000"
/* offset=5604746 */ "unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000"
/* offset=5604905 */ "unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000\000"
/* offset=5605032 */ "unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x40\000\00001\000\000"
/* offset=5605160 */ "unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000"
/* offset=5605319 */ "unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000\000"
/* offset=5605446 */ "unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000"
/* offset=5605605 */ "unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000\000"
/* offset=5605732 */ "unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x80\000\00001\000\000"
/* offset=5605860 */ "unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000"
/* offset=5606019 */ "unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000\000"
/* offset=5606146 */ "unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000"
/* offset=5606305 */ "unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000\000"
/* offset=5606432 */ "unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000"
/* offset=5606629 */ "unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000\000"
/* offset=5606776 */ "unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000"
/* offset=5606973 */ "unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000\000"
/* offset=5607120 */ "unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000"
/* offset=5607319 */ "unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000\000"
/* offset=5607467 */ "unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000"
/* offset=5607668 */ "unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000\000"
/* offset=5607817 */ "unc_m_wr_data\000uncore_imc\000uncore memory\000Number of bytes written to DRAM, in 32B chunks. Counter increments by 1 after sending 32B chunk data. Unit: uncore_imc \000event=0x3b\000\00001\000\000"
/* offset=5607992 */ "unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000"
/* offset=5608104 */ "unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B read  request entering the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read request entering the Memory Controller 0 to DRAM (sum of all channels)\000"
/* offset=5608419 */ "unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every CAS read command sent from the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000Counts every CAS read command sent from the Memory Controller 0 to DRAM (sum of all channels). Each CAS commands can be for 32B or 64B of data\000"
/* offset=5608784 */ "unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every read (RdCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000\000"
/* offset=5609058 */ "unc_mc0_total_reqcount_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B read and write request entering the Memory Controller to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x10\000\00001\000\000"
/* offset=5609481 */ "unc_mc0_total_reqcount_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every read and write request entering the Memory Controller 0. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x10\000\00001\000Counts every read and write request entering the Memory Controller 0 (sum of all channels). All requests are counted as one, whether they are 32B or 64B Read/Write or partial/full line writes. Some write requests to the same address may merge to a single write command to DRAM. Therefore, the total request count may be higher than total DRAM BW\000"
/* offset=5610027 */ "unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B write request entering the Memory Controller 0 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000\000"
/* offset=5610440 */ "unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every CAS write command sent from the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000Counts every CAS write command sent from the Memory Controller 0 to DRAM (sum of all channels).  Each CAS commands can be for 32B or 64B of data\000"
/* offset=5610808 */ "unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every write (WrCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000\000"
/* offset=5611083 */ "unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B read request entering the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read entering the Memory Controller 1 to DRAM (sum of all channels)\000"
/* offset=5611389 */ "unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every CAS read command sent from the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000Counts every CAS read command sent from the Memory Controller 1 to DRAM (sum of all channels). Each CAS commands can be for 32B or 64B of data\000"
/* offset=5611754 */ "unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every read (RdCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000\000"
/* offset=5612028 */ "unc_mc1_total_reqcount_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B read and write request entering the Memory Controller to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x10\000\00001\000\000"
/* offset=5612451 */ "unc_mc1_total_reqcount_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every read and write request entering the Memory Controller 1. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x10\000\00001\000Counts every read and write request entering the Memory Controller 1 (sum of all channels). All requests are counted as one, whether they are 32B or 64B Read/Write or partial/full line writes. Some write requests to the same address may merge to a single write command to DRAM. Therefore, the total request count may be higher than total DRAM BW\000"
/* offset=5612997 */ "unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B write request entering the Memory Controller 1 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000\000"
/* offset=5613410 */ "unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every CAS write command sent from the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000Counts every CAS write command sent from the Memory Controller 1 to DRAM (sum of all channels).  Each CAS commands can be for 32B or 64B of data\000"
/* offset=5613778 */ "unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every write (WrCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000\000"
/* offset=5614053 */ "unc_mchbm_act_count.all\000uncore_mchbm\000uncore memory\000Activate due to read, write, underfill, or bypass. Unit: uncore_mchbm \000event=0x2,umask=0xff\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5614505 */ "unc_mchbm_act_count.rd\000uncore_mchbm\000uncore memory\000Activate due to read. Unit: uncore_mchbm \000event=0x2,umask=0x11\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5614927 */ "unc_mchbm_act_count.rd_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Read in PCH0. Unit: uncore_mchbm \000event=0x2,umask=0x1\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5615382 */ "unc_mchbm_act_count.rd_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Read in PCH1. Unit: uncore_mchbm \000event=0x2,umask=0x10\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5615838 */ "unc_mchbm_act_count.ufill\000uncore_mchbm\000uncore memory\000HBM Activate Count : Underfill Read transaction on Page Empty or Page Miss. Unit: uncore_mchbm \000event=0x2,umask=0x44\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5616317 */ "unc_mchbm_act_count.ufill_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count. Unit: uncore_mchbm \000event=0x2,umask=0x4\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5616744 */ "unc_mchbm_act_count.ufill_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count. Unit: uncore_mchbm \000event=0x2,umask=0x40\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5617172 */ "unc_mchbm_act_count.wr\000uncore_mchbm\000uncore memory\000Activate due to write. Unit: uncore_mchbm \000event=0x2,umask=0x22\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5617595 */ "unc_mchbm_act_count.wr_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Write in PCH0. Unit: uncore_mchbm \000event=0x2,umask=0x2\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5618051 */ "unc_mchbm_act_count.wr_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Write in PCH1. Unit: uncore_mchbm \000event=0x2,umask=0x20\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000"
/* offset=5618508 */ "unc_mchbm_cas_count.all\000uncore_mchbm\000uncore memory\000All CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xff\000\00001\000\000"
/* offset=5618630 */ "unc_mchbm_cas_count.pch0\000uncore_mchbm\000uncore memory\000Pseudo Channel 0. Unit: uncore_mchbm \000event=0x5,umask=0x40\000\00001\000HBM RD_CAS and WR_CAS Commands\000"
/* offset=5618776 */ "unc_mchbm_cas_count.pch1\000uncore_mchbm\000uncore memory\000Pseudo Channel 1. Unit: uncore_mchbm \000event=0x5,umask=0x80\000\00001\000HBM RD_CAS and WR_CAS Commands\000"
/* offset=5618922 */ "unc_mchbm_cas_count.rd\000uncore_mchbm\000uncore memory\000Read CAS commands issued (regular and underfill). Unit: uncore_mchbm \000event=0x5,umask=0xcf\000\00001\000\000"
/* offset=5619068 */ "unc_mchbm_cas_count.rd_pre_reg\000uncore_mchbm\000uncore memory\000Regular read CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xc2\000\00001\000\000"
/* offset=5619214 */ "unc_mchbm_cas_count.rd_pre_underfill\000uncore_mchbm\000uncore memory\000Underfill read CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xc8\000\00001\000\000"
/* offset=5619368 */ "unc_mchbm_cas_count.rd_reg\000uncore_mchbm\000uncore memory\000Regular read CAS commands issued (does not include underfills). Unit: uncore_mchbm \000event=0x5,umask=0xc1\000\00001\000\000"
/* offset=5619532 */ "unc_mchbm_cas_count.rd_underfill\000uncore_mchbm\000uncore memory\000Underfill read CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xc4\000\00001\000\000"
/* offset=5619674 */ "unc_mchbm_cas_count.wr\000uncore_mchbm\000uncore memory\000Write CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xf0\000\00001\000\000"
/* offset=5619797 */ "unc_mchbm_cas_count.wr_nonpre\000uncore_mchbm\000uncore memory\000HBM RD_CAS and WR_CAS Commands. : HBM WR_CAS commands w/o auto-pre. Unit: uncore_mchbm \000event=0x5,umask=0xd0\000\00001\000\000"
/* offset=5619968 */ "unc_mchbm_cas_count.wr_pre\000uncore_mchbm\000uncore memory\000Write CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xe0\000\00001\000\000"
/* offset=5620103 */ "unc_mchbm_cas_issued_req_len.pch0\000uncore_mchbm\000uncore memory\000Pseudo Channel 0. Unit: uncore_mchbm \000event=0x6,umask=0x40\000\00001\000\000"
/* offset=5620228 */ "unc_mchbm_cas_issued_req_len.pch1\000uncore_mchbm\000uncore memory\000Pseudo Channel 1. Unit: uncore_mchbm \000event=0x6,umask=0x80\000\00001\000\000"
/* offset=5620353 */ "unc_mchbm_cas_issued_req_len.rd_32b\000uncore_mchbm\000uncore memory\000Read CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xc8\000\00001\000\000"
/* offset=5620506 */ "unc_mchbm_cas_issued_req_len.rd_64b\000uncore_mchbm\000uncore memory\000Read CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_mchbm \000event=0x6,umask=0xc1\000\00001\000\000"
/* offset=5620674 */ "unc_mchbm_cas_issued_req_len.rd_ufill_32b\000uncore_mchbm\000uncore memory\000Underfill Read CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xd0\000\00001\000\000"
/* offset=5620843 */ "unc_mchbm_cas_issued_req_len.rd_ufill_64b\000uncore_mchbm\000uncore memory\000Underfill Read CAS Command in Regular Mode (64B) in Pseudochannel 1. Unit: uncore_mchbm \000event=0x6,umask=0xc2\000\00001\000\000"
/* offset=5621027 */ "unc_mchbm_cas_issued_req_len.wr_32b\000uncore_mchbm\000uncore memory\000Write CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xe0\000\00001\000\000"
/* offset=5621181 */ "unc_mchbm_cas_issued_req_len.wr_64b\000uncore_mchbm\000uncore memory\000Write CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_mchbm \000event=0x6,umask=0xc4\000\00001\000\000"
/* offset=5621350 */ "unc_mchbm_clockticks\000uncore_mchbm\000uncore memory\000IMC Clockticks at DCLK frequency. Unit: uncore_mchbm \000event=0x1,umask=0x1\000\00001\000\000"
/* offset=5621477 */ "unc_mchbm_hbm_pre_all\000uncore_mchbm\000uncore memory\000All Precharge Commands. Unit: uncore_mchbm \000event=0x44,umask=0x3\000\00001\000Precharge All Commands: Counts the number of times that the precharge all command was sent\000"
/* offset=5621686 */ "unc_mchbm_hbm_preall.pch0\000uncore_mchbm\000uncore memory\000HBM Precharge All Commands. Unit: uncore_mchbm \000event=0x44,umask=0x1\000\00001\000Counts the number of times that the precharge all command was sent\000"
/* offset=5621879 */ "unc_mchbm_hbm_preall.pch1\000uncore_mchbm\000uncore memory\000HBM Precharge All Commands. Unit: uncore_mchbm \000event=0x44,umask=0x2\000\00001\000Counts the number of times that the precharge all command was sent\000"
/* offset=5622072 */ "unc_mchbm_hclockticks\000uncore_mchbm\000uncore memory\000IMC Clockticks at HCLK frequency. Unit: uncore_mchbm \000event=0x1\000\00001\000\000"
/* offset=5622190 */ "unc_mchbm_pre_count.all\000uncore_mchbm\000uncore memory\000All precharge events. Unit: uncore_mchbm \000event=0x3,umask=0xff\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5622373 */ "unc_mchbm_pre_count.pgt\000uncore_mchbm\000uncore memory\000Precharge from MC page table. Unit: uncore_mchbm \000event=0x3,umask=0x88\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5622564 */ "unc_mchbm_pre_count.pgt_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharges from Page Table. Unit: uncore_mchbm \000event=0x3,umask=0x8\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Equivalent to PAGE_EMPTY\000"
/* offset=5622811 */ "unc_mchbm_pre_count.pgt_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x80\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5623001 */ "unc_mchbm_pre_count.rd\000uncore_mchbm\000uncore memory\000Precharge due to read on page miss. Unit: uncore_mchbm \000event=0x3,umask=0x11\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5623197 */ "unc_mchbm_pre_count.rd_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharge due to read. Unit: uncore_mchbm \000event=0x3,umask=0x1\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Precharge from read bank scheduler\000"
/* offset=5623448 */ "unc_mchbm_pre_count.rd_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x10\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5623637 */ "unc_mchbm_pre_count.ufill\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x44\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5623824 */ "unc_mchbm_pre_count.ufill_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x4\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5624015 */ "unc_mchbm_pre_count.ufill_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x40\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5624207 */ "unc_mchbm_pre_count.wr\000uncore_mchbm\000uncore memory\000Precharge due to write on page miss. Unit: uncore_mchbm \000event=0x3,umask=0x22\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5624404 */ "unc_mchbm_pre_count.wr_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharge due to write. Unit: uncore_mchbm \000event=0x3,umask=0x2\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Precharge from write bank scheduler\000"
/* offset=5624657 */ "unc_mchbm_pre_count.wr_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x20\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000"
/* offset=5624846 */ "unc_mchbm_rdb_full\000uncore_mchbm\000uncore memory\000Counts the number of cycles where the read buffer has greater than UMASK elements.  NOTE: Umask must be set to the maximum number of elements in the queue (24 entries for SPR). Unit: uncore_mchbm \000event=0x19\000\00001\000\000"
/* offset=5625105 */ "unc_mchbm_rdb_inserts.pch0\000uncore_mchbm\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_mchbm \000event=0x17,umask=0x1\000\00001\000\000"
/* offset=5625231 */ "unc_mchbm_rdb_inserts.pch1\000uncore_mchbm\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_mchbm \000event=0x17,umask=0x2\000\00001\000\000"
/* offset=5625357 */ "unc_mchbm_rdb_inserts\000uncore_mchbm\000uncore memory\000Counts the number of inserts into the read buffer. Unit: uncore_mchbm \000event=0x17,umask=0x3\000\00001\000\000"
/* offset=5625503 */ "unc_mchbm_rdb_occupancy\000uncore_mchbm\000uncore memory\000Counts the number of elements in the read buffer per cycle. Unit: uncore_mchbm \000event=0x1a\000\00001\000\000"
/* offset=5625650 */ "unc_mchbm_rpq_inserts.pch0\000uncore_mchbm\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_mchbm \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations: Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000"
/* offset=5626248 */ "unc_mchbm_rpq_inserts.pch1\000uncore_mchbm\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_mchbm \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations: Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000"
/* offset=5626846 */ "unc_mchbm_rpq_occupancy_pch0\000uncore_mchbm\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x80\000\00001\000Read Pending Queue Occupancy: Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000"
/* offset=5627571 */ "unc_mchbm_rpq_occupancy_pch1\000uncore_mchbm\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x81\000\00001\000Read Pending Queue Occupancy: Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000"
/* offset=5628296 */ "unc_mchbm_wpq_inserts.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_mchbm \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations: Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000"
/* offset=5629059 */ "unc_mchbm_wpq_inserts.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_mchbm \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations: Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000"
/* offset=5629822 */ "unc_mchbm_wpq_occupancy_pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x82\000\00001\000Write Pending Queue Occupancy: Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to memory.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5631297 */ "unc_mchbm_wpq_occupancy_pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x83\000\00001\000Write Pending Queue Occupancy: Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to memory.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000"
/* offset=5632772 */ "unc_mchbm_wpq_read_hit.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,umask=0x1\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5633465 */ "unc_mchbm_wpq_read_hit.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,umask=0x2\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5634158 */ "unc_mchbm_wpq_read_hit\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5634843 */ "unc_mchbm_wpq_write_hit.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,umask=0x1\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5635537 */ "unc_mchbm_wpq_write_hit.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,umask=0x2\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5636231 */ "unc_mchbm_wpq_write_hit\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000"
/* offset=5636917 */ "unc_mdf_crs_txr_inserts.ad_bnc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AD Bouncable). Unit: uncore_mdf \000event=0x47,umask=0x1\000\00001\000AD Bouncable : Number of allocations into the CRS Egress\000"
/* offset=5637185 */ "unc_mdf_crs_txr_inserts.ad_crd\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AD credited). Unit: uncore_mdf \000event=0x47,umask=0x2\000\00001\000AD credited : Number of allocations into the CRS Egress\000"
/* offset=5637451 */ "unc_mdf_crs_txr_inserts.ak\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AK). Unit: uncore_mdf \000event=0x47,umask=0x10\000\00001\000AK : Number of allocations into the CRS Egress\000"
/* offset=5637696 */ "unc_mdf_crs_txr_inserts.akc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AKC). Unit: uncore_mdf \000event=0x47,umask=0x40\000\00001\000AKC : Number of allocations into the CRS Egress\000"
/* offset=5637944 */ "unc_mdf_crs_txr_inserts.bl_bnc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (BL Bouncable). Unit: uncore_mdf \000event=0x47,umask=0x4\000\00001\000BL Bouncable : Number of allocations into the CRS Egress\000"
/* offset=5638212 */ "unc_mdf_crs_txr_inserts.bl_crd\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (BL credited). Unit: uncore_mdf \000event=0x47,umask=0x8\000\00001\000BL credited : Number of allocations into the CRS Egress\000"
/* offset=5638478 */ "unc_mdf_crs_txr_inserts.iv\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (IV). Unit: uncore_mdf \000event=0x47,umask=0x20\000\00001\000IV : Number of allocations into the CRS Egress\000"
/* offset=5638723 */ "unc_mdf_crs_txr_v_bounces.ad\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AD). Unit: uncore_mdf \000event=0x4b,umask=0x1\000\00001\000AD : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000"
/* offset=5639027 */ "unc_mdf_crs_txr_v_bounces.ak\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AK). Unit: uncore_mdf \000event=0x4b,umask=0x4\000\00001\000AK : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000"
/* offset=5639331 */ "unc_mdf_crs_txr_v_bounces.akc\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AKC). Unit: uncore_mdf \000event=0x4b,umask=0x10\000\00001\000AKC : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000"
/* offset=5639639 */ "unc_mdf_crs_txr_v_bounces.bl\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (BL). Unit: uncore_mdf \000event=0x4b,umask=0x2\000\00001\000BL : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000"
/* offset=5639943 */ "unc_mdf_crs_txr_v_bounces.iv\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (IV). Unit: uncore_mdf \000event=0x4b,umask=0x8\000\00001\000IV : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000"
/* offset=5640247 */ "unc_mdf_fast_asserted.ad_bnc\000uncore_mdf\000uncore interconnect\000Counts the number of cycles when the distress signals are asserted based on SBO Ingress threshold. Unit: uncore_mdf \000event=0x15,umask=0x1\000\00001\000AD bnc : Counts the number of cycles when the  distress signals are asserted based on SBO Ingress threshold\000"
/* offset=5640557 */ "unc_mdf_fast_asserted.bl_crd\000uncore_mdf\000uncore interconnect\000Counts the number of cycles when the distress signals are asserted based on SBO Ingress threshold. Unit: uncore_mdf \000event=0x15,umask=0x2\000\00001\000BL bnc : Counts the number of cycles when the  distress signals are asserted based on SBO Ingress threshold\000"
/* offset=5640867 */ "unc_nounit_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_TxC_BL.DRS_UPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00011\000\000"
/* offset=5641037 */ "unc_p_clockticks\000uncore_pcu\000uncore power\000Clockticks of the power control unit (PCU). Unit: uncore_pcu \000event=0\000\00001\000Clockticks of the power control unit (PCU) : The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000"
/* offset=5641437 */ "unc_p_clockticks\000uncore_pcu\000uncore power\000Clockticks of the power control unit (PCU). Unit: uncore_pcu \000event=0\000\00001\000\000"
/* offset=5641553 */ "unc_p_clockticks\000uncore_pcu\000uncore power\000PCU PCLK Clockticks. Unit: uncore_pcu \000event=0x1\000\00001\000Number of PCU PCLK Clock cycles while the event is enabled\000"
/* offset=5641706 */ "unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000"
/* offset=5642030 */ "unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 800 MHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000"
/* offset=5642356 */ "unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core 0 C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5642566 */ "unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x3\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5642773 */ "unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x60\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5642981 */ "unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core 10 C State Transition Cycles. Unit: uncore_pcu \000event=0x7a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5643193 */ "unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5643402 */ "unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core 11 C State Transition Cycles. Unit: uncore_pcu \000event=0x7b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5643614 */ "unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5643823 */ "unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core 12 C State Transition Cycles. Unit: uncore_pcu \000event=0x7c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5644035 */ "unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5644244 */ "unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core 13 C State Transition Cycles. Unit: uncore_pcu \000event=0x7d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5644456 */ "unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5644665 */ "unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core 14 C State Transition Cycles. Unit: uncore_pcu \000event=0x7e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5644877 */ "unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5645086 */ "unc_p_core15_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6f\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5645295 */ "unc_p_core16_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5645504 */ "unc_p_core17_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5645713 */ "unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core 1 C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5645923 */ "unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5646130 */ "unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5646338 */ "unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core 2 C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5646548 */ "unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5646755 */ "unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5646963 */ "unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core 3 C State Transition Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5647173 */ "unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5647381 */ "unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5647588 */ "unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core 4 C State Transition Cycles. Unit: uncore_pcu \000event=0x74\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5647798 */ "unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x64\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5648006 */ "unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x7\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5648213 */ "unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core 5 C State Transition Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5648423 */ "unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x65\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5648631 */ "unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x8\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5648838 */ "unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core 6 C State Transition Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5649048 */ "unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x66\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5649256 */ "unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x9\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5649463 */ "unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core 7 C State Transition Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5649673 */ "unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x67\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5649881 */ "unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0xa\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5650088 */ "unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core 8 C State Transition Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5650298 */ "unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x68\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5650506 */ "unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core 9 C State Transition Cycles. Unit: uncore_pcu \000event=0x79\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5650716 */ "unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x69\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000"
/* offset=5650924 */ "unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000"
/* offset=5651041 */ "unc_p_delayed_c_state_abort_core0\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 0. Unit: uncore_pcu \000event=0x17\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5651394 */ "unc_p_delayed_c_state_abort_core10\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 10. Unit: uncore_pcu \000event=0x21\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5651749 */ "unc_p_delayed_c_state_abort_core11\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 11. Unit: uncore_pcu \000event=0x22\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5652104 */ "unc_p_delayed_c_state_abort_core12\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 12. Unit: uncore_pcu \000event=0x23\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5652459 */ "unc_p_delayed_c_state_abort_core13\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 13. Unit: uncore_pcu \000event=0x24\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5652814 */ "unc_p_delayed_c_state_abort_core14\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 14. Unit: uncore_pcu \000event=0x25\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5653169 */ "unc_p_delayed_c_state_abort_core1\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 1. Unit: uncore_pcu \000event=0x18\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5653522 */ "unc_p_delayed_c_state_abort_core2\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 2. Unit: uncore_pcu \000event=0x19\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5653875 */ "unc_p_delayed_c_state_abort_core3\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 3. Unit: uncore_pcu \000event=0x1a\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5654228 */ "unc_p_delayed_c_state_abort_core4\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 4. Unit: uncore_pcu \000event=0x1b\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5654581 */ "unc_p_delayed_c_state_abort_core5\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 5. Unit: uncore_pcu \000event=0x1c\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5654934 */ "unc_p_delayed_c_state_abort_core6\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 6. Unit: uncore_pcu \000event=0x1d\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5655287 */ "unc_p_delayed_c_state_abort_core7\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 7. Unit: uncore_pcu \000event=0x1e\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5655640 */ "unc_p_delayed_c_state_abort_core8\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 8. Unit: uncore_pcu \000event=0x1f\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5655993 */ "unc_p_delayed_c_state_abort_core9\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 9. Unit: uncore_pcu \000event=0x20\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000"
/* offset=5656346 */ "unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000"
/* offset=5656437 */ "unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core 0 C State Demotions. Unit: uncore_pcu \000event=0x1e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5656618 */ "unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x1e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5656797 */ "unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x30\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5656976 */ "unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core 10 C State Demotions. Unit: uncore_pcu \000event=0x42\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5657159 */ "unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3a\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5657339 */ "unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core 11 C State Demotions. Unit: uncore_pcu \000event=0x43\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5657522 */ "unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3b\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5657702 */ "unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core 12 C State Demotions. Unit: uncore_pcu \000event=0x44\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5657885 */ "unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3c\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658065 */ "unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core 13 C State Demotions. Unit: uncore_pcu \000event=0x45\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658248 */ "unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3d\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658428 */ "unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core 14 C State Demotions. Unit: uncore_pcu \000event=0x46\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658611 */ "unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658791 */ "unc_p_demotions_core15\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5658971 */ "unc_p_demotions_core16\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5659151 */ "unc_p_demotions_core17\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5659331 */ "unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core 1 C State Demotions. Unit: uncore_pcu \000event=0x1f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5659512 */ "unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x1f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5659691 */ "unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x31\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5659870 */ "unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core 2 C State Demotions. Unit: uncore_pcu \000event=0x20\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660051 */ "unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x20\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660230 */ "unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x32\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660409 */ "unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core 3 C State Demotions. Unit: uncore_pcu \000event=0x21\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660590 */ "unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x21\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660769 */ "unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x33\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5660948 */ "unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core 4 C State Demotions. Unit: uncore_pcu \000event=0x22\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5661129 */ "unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x22\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5661308 */ "unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x34\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5661487 */ "unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core 5 C State Demotions. Unit: uncore_pcu \000event=0x23\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5661668 */ "unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x23\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5661847 */ "unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x35\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662026 */ "unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core 6 C State Demotions. Unit: uncore_pcu \000event=0x24\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662207 */ "unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x24\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662386 */ "unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x36\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662565 */ "unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core 7 C State Demotions. Unit: uncore_pcu \000event=0x25\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662746 */ "unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x25\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5662925 */ "unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x37\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5663104 */ "unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core 8 C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5663285 */ "unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x38\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5663464 */ "unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core 9 C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5663645 */ "unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x39\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000"
/* offset=5663824 */ "unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Cycles spent in phase-shedding power state 0\000"
/* offset=5663972 */ "unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Phase Shed 0 Cycles : Cycles spent in phase-shedding power state 0\000"
/* offset=5664142 */ "unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Cycles spent in phase-shedding power state 1\000"
/* offset=5664290 */ "unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Phase Shed 1 Cycles : Cycles spent in phase-shedding power state 1\000"
/* offset=5664460 */ "unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Cycles spent in phase-shedding power state 2\000"
/* offset=5664608 */ "unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Phase Shed 2 Cycles : Cycles spent in phase-shedding power state 2\000"
/* offset=5664778 */ "unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Cycles spent in phase-shedding power state 3\000"
/* offset=5664926 */ "unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Phase Shed 3 Cycles : Cycles spent in phase-shedding power state 3\000"
/* offset=5665096 */ "unc_p_freq_band0_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xb\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000"
/* offset=5665711 */ "unc_p_freq_band1_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xc\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000"
/* offset=5666326 */ "unc_p_freq_band2_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xd\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000"
/* offset=5666941 */ "unc_p_freq_band3_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xe\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000"
/* offset=5667556 */ "unc_p_freq_clip_avx256\000uncore_pcu\000uncore power\000AVX256 Frequency Clipping. Unit: uncore_pcu \000event=0x49\000\00001\000\000"
/* offset=5667664 */ "unc_p_freq_clip_avx512\000uncore_pcu\000uncore power\000AVX512 Frequency Clipping. Unit: uncore_pcu \000event=0x4a\000\00001\000\000"
/* offset=5667772 */ "unc_p_freq_max_current_cycles\000uncore_pcu\000uncore power\000Current Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x7\000\00001\000Counts the number of cycles when current is the upper limit on frequency\000"
/* offset=5667969 */ "unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000"
/* offset=5668479 */ "unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Thermal Strongest Upper Limit Cycles : Number of cycles any frequency is reduced due to a thermal limit.  Count only if throttling is occurring\000"
/* offset=5668753 */ "unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000"
/* offset=5668939 */ "unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000"
/* offset=5669130 */ "unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Power Strongest Upper Limit Cycles : Counts the number of cycles when power is the upper limit on frequency\000"
/* offset=5669358 */ "unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x1\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000"
/* offset=5669856 */ "unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000"
/* offset=5670355 */ "unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000"
/* offset=5670854 */ "unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000IO P Limit Strongest Lower Limit Cycles : Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000"
/* offset=5671395 */ "unc_p_freq_min_perf_p_cycles\000uncore_pcu\000uncore power\000Perf P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x2\000\00001\000Counts the number of cycles when Perf P Limit is preventing us from dropping the frequency lower.  Perf P Limit is an algorithm that takes input from remote sockets when determining if a socket should drop it's frequency down.  This is largely to minimize increases in snoop and remote read latencies\000"
/* offset=5671824 */ "unc_p_freq_min_perf_p_cycles\000uncore_pcu\000uncore power\000Perf P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Counts the number of cycles when Perf P Limit is preventing us from dropping the frequency lower.  Perf P Limit is an algorithm that takes input from remote sockets when determining if a socket should drop it's frequency down.  This is largely to minimize increases in snoop and remote read latencies\000"
/* offset=5672254 */ "unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000"
/* offset=5672638 */ "unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x60\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000"
/* offset=5673025 */ "unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000"
/* offset=5673412 */ "unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Cycles spent changing Frequency : Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000"
/* offset=5673833 */ "unc_p_mcp_prochot_cycles\000uncore_pcu\000uncore power\000UNC_P_MCP_PROCHOT_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000"
/* offset=5673941 */ "unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000"
/* offset=5674248 */ "unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Memory Phase Shedding Cycles : Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000"
/* offset=5674586 */ "unc_p_pkg_c_exit_latency\000uncore_pcu\000uncore power\000Package C State Exit Latency. Unit: uncore_pcu \000event=0x26\000\00001\000Counts the number of cycles that the package is transitioning from package C2 to C3\000"
/* offset=5674782 */ "unc_p_pkg_c_exit_latency_sel\000uncore_pcu\000uncore power\000Package C State Exit Latency. Unit: uncore_pcu \000event=0x26\000\00001\000Counts the number of cycles that the package is transitioning from package C2 to C3\000"
/* offset=5674982 */ "unc_p_pkg_c_state_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles that the package is in C0\000"
/* offset=5675163 */ "unc_p_pkg_c_state_residency_c2_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles that the package is in C2\000"
/* offset=5675344 */ "unc_p_pkg_c_state_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles that the package is in C3\000"
/* offset=5675525 */ "unc_p_pkg_c_state_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles that the package is in C6\000"
/* offset=5675706 */ "unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5676034 */ "unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Package C State Residency - C0 : Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5676395 */ "unc_p_pkg_residency_c1e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C1E. Unit: uncore_pcu \000event=0x4e\000\00001\000Counts the number of cycles when the package was in C1E.  This event can be used in conjunction with edge detect to count C1E entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5676727 */ "unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5677059 */ "unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Package C State Residency - C2E : Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5677425 */ "unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5677753 */ "unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Package C State Residency - C3 : Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5678114 */ "unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5678442 */ "unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Package C State Residency - C6 : Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5678803 */ "unc_p_pkg_residency_c7_cycles\000uncore_pcu\000uncore power\000Package C7 State Residency. Unit: uncore_pcu \000event=0x2e\000\00001\000Counts the number of cycles when the package was in C7.  This event can be used in conjunction with edge detect to count C7 entrances (or exits using invert).  Residency events do not include transition times\000"
/* offset=5679127 */ "unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000"
/* offset=5679241 */ "unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x7\000\00001\000\000"
/* offset=5679355 */ "unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State : C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C0 and C1 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5679815 */ "unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5680233 */ "unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5680610 */ "unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State : C3. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C3 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5681056 */ "unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5681467 */ "unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5681844 */ "unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State : C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C6 and C7 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5682304 */ "unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5682722 */ "unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5683099 */ "unc_p_power_state_occupancy_cores_c0\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x35\000\00001\000Number of cores in C0 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5683525 */ "unc_p_power_state_occupancy_cores_c3\000uncore_pcu\000uncore power\000Number of cores in C3. Unit: uncore_pcu \000event=0x36\000\00001\000Number of cores in C3 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5683951 */ "unc_p_power_state_occupancy_cores_c6\000uncore_pcu\000uncore power\000Number of cores in C6. Unit: uncore_pcu \000event=0x37\000\00001\000Number of cores in C6 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000"
/* offset=5684377 */ "unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000"
/* offset=5684699 */ "unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000External Prochot : Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000"
/* offset=5685040 */ "unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000"
/* offset=5685335 */ "unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Internal Prochot : Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000"
/* offset=5685649 */ "unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions across all cores\000"
/* offset=5685850 */ "unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000"
/* offset=5686051 */ "unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Total Core C State Transition Cycles : Number of cycles spent performing core C state transitions across all cores\000"
/* offset=5686291 */ "unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0xb\000\00001\000Number of cycles spent performing core C state transitions across all cores\000"
/* offset=5686491 */ "unc_p_ufs_transitions_no_change\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_NO_CHANGE. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000"
/* offset=5686659 */ "unc_p_ufs_transitions_ring_gv\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_RING_GV. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000"
/* offset=5686823 */ "unc_p_volt_trans_cycles_change\000uncore_pcu\000uncore power\000Cycles Changing Voltage. Unit: uncore_pcu \000event=0x3\000\00001\000Counts the number of cycles when the system is changing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition.  This event is calculated by or'ing together the increasing and decreasing events\000"
/* offset=5687295 */ "unc_p_volt_trans_cycles_decrease\000uncore_pcu\000uncore power\000Cycles Decreasing Voltage. Unit: uncore_pcu \000event=0x2\000\00001\000Counts the number of cycles when the system is decreasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000"
/* offset=5687690 */ "unc_p_volt_trans_cycles_increase\000uncore_pcu\000uncore power\000Cycles Increasing Voltage. Unit: uncore_pcu \000event=0x1\000\00001\000Counts the number of cycles when the system is increasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000"
/* offset=5688085 */ "unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x32\000\00001\000\000"
/* offset=5688171 */ "unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000"
/* offset=5688334 */ "unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000\000"
/* offset=5688420 */ "unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/4th the GT/s speed of the QPI link.  For example, a 4GT/s link will have qfclk or 1GHz.  BDX does not support dynamic link speeds, so this frequency is fixed\000"
/* offset=5688742 */ "unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/4th the GT/s speed of the QPI link.  For example, a 4GT/s link will have qfclk or 1GHz.  HSX does not support dynamic link speeds, so this frequency is fixed\000"
/* offset=5689064 */ "unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/8th the 'GT/s' speed of the QPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  JKT does not support dynamic link speeds, so this frequency is fixed\000"
/* offset=5689388 */ "unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/8th the GT/s speed of the QPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  JKT does not support dynamic link speeds, so this frequency is fixed\000"
/* offset=5689710 */ "unc_q_cto_count\000uncore_qpi\000uncore interconnect\000Count of CTO Events. Unit: uncore_qpi \000event=0x38\000\00001\000Counts the number of CTO (cluster trigger outs) events that were asserted across the two slots.  If both slots trigger in a given cycle, the event will increment by 2.  You can use edge detect to count the number of cases when both events triggered\000"
/* offset=5690060 */ "unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits.  Had there been enough credits, the spawn would have worked as the RBT bit was set and the RBT tag matched\000"
/* offset=5690760 */ "unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=5691288 */ "unc_q_direct2core.failure_credits_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x20\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and there weren't enough Egress credits.   The valid bit was set\000"
/* offset=5691945 */ "unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits AND the RBT bit was not set, but the RBT tag matched\000"
/* offset=5692602 */ "unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=5693134 */ "unc_q_direct2core.failure_credits_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss, Invalid. Unit: uncore_qpi \000event=0x13,umask=0x80\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match, the valid bit was not set and there weren't enough Egress credits\000"
/* offset=5693806 */ "unc_q_direct2core.failure_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x10\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match although the valid bit was set and there were enough Egress credits\000"
/* offset=5694447 */ "unc_q_direct2core.failure_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Not Set. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=5694968 */ "unc_q_direct2core.failure_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the route-back table (RBT) specified that the transaction should not trigger a direct2core transaction.  This is common for IO transactions.  There were enough Egress credits and the RBT tag matched but the valid bit was not set\000"
/* offset=5695749 */ "unc_q_direct2core.failure_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss and Invalid. Unit: uncore_qpi \000event=0x13,umask=0x40\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and the valid bit was not set although there were enough Egress credits\000"
/* offset=5696410 */ "unc_q_direct2core.success\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=5696913 */ "unc_q_direct2core.success_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn was successful.  There were sufficient credits, the RBT valid bit was set and there was an RBT tag match.  The message was marked to spawn direct2core\000"
/* offset=5697587 */ "unc_q_l1_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L1. Unit: uncore_qpi \000event=0x12\000\00001\000Number of QPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a QPI link.  Use edge detect to count the number of instances when the QPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000"
/* offset=5698087 */ "unc_q_match_mask\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698169 */ "unc_q_message.drs.anydatac\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698261 */ "unc_q_message.drs.anyresp11flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698359 */ "unc_q_message.drs.anyresp9flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698456 */ "unc_q_message.drs.anyresp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698547 */ "unc_q_message.drs.datac_e\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698638 */ "unc_q_message.drs.datac_e_cmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698733 */ "unc_q_message.drs.datac_e_frcackcnflt\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698836 */ "unc_q_message.drs.datac_f\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5698927 */ "unc_q_message.drs.datac_f_cmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699022 */ "unc_q_message.drs.datac_f_frcackcnflt\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699125 */ "unc_q_message.drs.datac_m\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699216 */ "unc_q_message.drs.wbedata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699307 */ "unc_q_message.drs.wbidata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699398 */ "unc_q_message.drs.wbsdata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699489 */ "unc_q_message.hom.anyreq\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699579 */ "unc_q_message.hom.anyresp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699670 */ "unc_q_message.hom.respfwd\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699761 */ "unc_q_message.hom.respfwdi\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699853 */ "unc_q_message.hom.respfwdiwb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5699947 */ "unc_q_message.hom.respfwds\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700039 */ "unc_q_message.hom.respfwdswb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700133 */ "unc_q_message.hom.respiwb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700224 */ "unc_q_message.hom.respswb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700315 */ "unc_q_message.ncb.anyint\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700405 */ "unc_q_message.ncb.anymsg11flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700502 */ "unc_q_message.ncb.anymsg9flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700598 */ "unc_q_message.ncb.anymsg\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700688 */ "unc_q_message.ncs.anymsg1or2flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700787 */ "unc_q_message.ncs.anymsg3flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700883 */ "unc_q_message.ncs.ncrd\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5700971 */ "unc_q_message.ndr.anycmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5701061 */ "unc_q_message.snp.anysnp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000"
/* offset=5701151 */ "unc_q_rxl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xf\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=5701702 */ "unc_q_rxl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0x10\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000"
/* offset=5702372 */ "unc_q_rxl_bypassed\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x9\000\00001\000Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=5702855 */ "unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during link initialization\000"
/* offset=5703383 */ "unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000"
/* offset=5703862 */ "unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; Normal Operations. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during normal operation\000"
/* offset=5704396 */ "unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; Normal Operations. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000"
/* offset=5704884 */ "unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000UNC_Q_RxL_CRC_ERRORS.NORMAL_OP. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000\000"
/* offset=5705021 */ "unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the DRS message class\000"
/* offset=5705389 */ "unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5705718 */ "unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the HOM message class\000"
/* offset=5706086 */ "unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5706415 */ "unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCB message class\000"
/* offset=5706783 */ "unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5707112 */ "unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCS message class\000"
/* offset=5707480 */ "unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5707809 */ "unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NDR message class\000"
/* offset=5708178 */ "unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5708508 */ "unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the SNP message class\000"
/* offset=5708877 */ "unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5709207 */ "unc_q_rxl_credits_consumed_vn1.drs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x39,umask=0x1\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the DRS message class\000"
/* offset=5709575 */ "unc_q_rxl_credits_consumed_vn1.hom\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x39,umask=0x8\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the HOM message class\000"
/* offset=5709943 */ "unc_q_rxl_credits_consumed_vn1.ncb\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x39,umask=0x2\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCB message class\000"
/* offset=5710311 */ "unc_q_rxl_credits_consumed_vn1.ncs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x39,umask=0x4\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCS message class\000"
/* offset=5710679 */ "unc_q_rxl_credits_consumed_vn1.ndr\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x39,umask=0x20\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NDR message class\000"
/* offset=5711048 */ "unc_q_rxl_credits_consumed_vn1.snp\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x39,umask=0x10\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the SNP message class\000"
/* offset=5711417 */ "unc_q_rxl_credits_consumed_vna\000uncore_qpi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_qpi \000event=0x1d\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=5711727 */ "unc_q_rxl_cycles_ne\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty. Unit: uncore_qpi \000event=0xa\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy\000"
/* offset=5712262 */ "unc_q_rxl_cycles_ne_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN0. Unit: uncore_qpi \000event=0xf,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000"
/* offset=5712861 */ "unc_q_rxl_cycles_ne_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN1. Unit: uncore_qpi \000event=0xf,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000"
/* offset=5713460 */ "unc_q_rxl_cycles_ne_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN0. Unit: uncore_qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000"
/* offset=5714060 */ "unc_q_rxl_cycles_ne_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN1. Unit: uncore_qpi \000event=0x12,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000"
/* offset=5714660 */ "unc_q_rxl_cycles_ne_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN0. Unit: uncore_qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000"
/* offset=5715260 */ "unc_q_rxl_cycles_ne_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN1. Unit: uncore_qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000"
/* offset=5715860 */ "unc_q_rxl_cycles_ne_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN0. Unit: uncore_qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000"
/* offset=5716460 */ "unc_q_rxl_cycles_ne_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN1. Unit: uncore_qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000"
/* offset=5717060 */ "unc_q_rxl_cycles_ne_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN0. Unit: uncore_qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000"
/* offset=5717660 */ "unc_q_rxl_cycles_ne_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN1. Unit: uncore_qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000"
/* offset=5718260 */ "unc_q_rxl_cycles_ne_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN0. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000"
/* offset=5718860 */ "unc_q_rxl_cycles_ne_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN1. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000"
/* offset=5719460 */ "unc_q_rxl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5720685 */ "unc_q_rxl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits received over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000"
/* offset=5722297 */ "unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5723528 */ "unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of flits received over QPI that do not hold protocol payload.  When QPI is not in a power saving state, it continuously transmits flits across the link.  When there are no protocol flits to send, it will send IDLE and NULL flits  across.  These flits sometimes do carry a payload, such as credit returns, but are generally not considered part of the QPI bandwidth\000"
/* offset=5725114 */ "unc_q_rxl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5726356 */ "unc_q_rxl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits received across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000"
/* offset=5727875 */ "unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5729146 */ "unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data\000"
/* offset=5730635 */ "unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5731892 */ "unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000"
/* offset=5733425 */ "unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5734688 */ "unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000"
/* offset=5736264 */ "unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5737511 */ "unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits received over QPI on the home channel\000"
/* offset=5738805 */ "unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5740071 */ "unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits received over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000"
/* offset=5741486 */ "unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5742745 */ "unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request received over QPI on the home channel.  This basically counts the number of remote memory requests received over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000"
/* offset=5744242 */ "unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5745489 */ "unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits received over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are received on the home channel\000"
/* offset=5746909 */ "unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5748168 */ "unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000"
/* offset=5749521 */ "unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5750790 */ "unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000"
/* offset=5752276 */ "unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5753552 */ "unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000"
/* offset=5755033 */ "unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5756302 */ "unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits received over QPI.    This includes extended headers\000"
/* offset=5757650 */ "unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5758922 */ "unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000"
/* offset=5760424 */ "unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5761696 */ "unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000"
/* offset=5763199 */ "unc_q_rxl_inserts\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x8\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=5763737 */ "unc_q_rxl_inserts_drs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN0. Unit: uncore_qpi \000event=0x9,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000"
/* offset=5764339 */ "unc_q_rxl_inserts_drs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN1. Unit: uncore_qpi \000event=0x9,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000"
/* offset=5764941 */ "unc_q_rxl_inserts_drs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS. Unit: uncore_qpi \000event=0x9\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000"
/* offset=5765520 */ "unc_q_rxl_inserts_hom.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN0. Unit: uncore_qpi \000event=0xc,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000"
/* offset=5766122 */ "unc_q_rxl_inserts_hom.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN1. Unit: uncore_qpi \000event=0xc,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000"
/* offset=5766724 */ "unc_q_rxl_inserts_hom\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM. Unit: uncore_qpi \000event=0xc\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000"
/* offset=5767303 */ "unc_q_rxl_inserts_ncb.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN0. Unit: uncore_qpi \000event=0xa,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000"
/* offset=5767905 */ "unc_q_rxl_inserts_ncb.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN1. Unit: uncore_qpi \000event=0xa,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000"
/* offset=5768507 */ "unc_q_rxl_inserts_ncb\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB. Unit: uncore_qpi \000event=0xa\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000"
/* offset=5769086 */ "unc_q_rxl_inserts_ncs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN0. Unit: uncore_qpi \000event=0xb,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000"
/* offset=5769688 */ "unc_q_rxl_inserts_ncs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN1. Unit: uncore_qpi \000event=0xb,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000"
/* offset=5770290 */ "unc_q_rxl_inserts_ncs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS. Unit: uncore_qpi \000event=0xb\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000"
/* offset=5770869 */ "unc_q_rxl_inserts_ndr.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN0. Unit: uncore_qpi \000event=0xe,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000"
/* offset=5771471 */ "unc_q_rxl_inserts_ndr.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN1. Unit: uncore_qpi \000event=0xe,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000"
/* offset=5772073 */ "unc_q_rxl_inserts_ndr\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR. Unit: uncore_qpi \000event=0xe\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000"
/* offset=5772652 */ "unc_q_rxl_inserts_snp.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN0. Unit: uncore_qpi \000event=0xd,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000"
/* offset=5773254 */ "unc_q_rxl_inserts_snp.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN1. Unit: uncore_qpi \000event=0xd,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000"
/* offset=5773856 */ "unc_q_rxl_inserts_snp\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP. Unit: uncore_qpi \000event=0xd\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000"
/* offset=5774435 */ "unc_q_rxl_occupancy\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - All Packets. Unit: uncore_qpi \000event=0xb\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=5775035 */ "unc_q_rxl_occupancy_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x15,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000"
/* offset=5775686 */ "unc_q_rxl_occupancy_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x15,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000"
/* offset=5776337 */ "unc_q_rxl_occupancy_drs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS. Unit: uncore_qpi \000event=0x15\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000"
/* offset=5776965 */ "unc_q_rxl_occupancy_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x18,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000"
/* offset=5777616 */ "unc_q_rxl_occupancy_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x18,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000"
/* offset=5778267 */ "unc_q_rxl_occupancy_hom\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM. Unit: uncore_qpi \000event=0x18\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000"
/* offset=5778895 */ "unc_q_rxl_occupancy_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x16,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000"
/* offset=5779546 */ "unc_q_rxl_occupancy_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x16,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000"
/* offset=5780197 */ "unc_q_rxl_occupancy_ncb\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB. Unit: uncore_qpi \000event=0x16\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000"
/* offset=5780825 */ "unc_q_rxl_occupancy_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x17,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000"
/* offset=5781476 */ "unc_q_rxl_occupancy_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x17,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000"
/* offset=5782127 */ "unc_q_rxl_occupancy_ncs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS. Unit: uncore_qpi \000event=0x17\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000"
/* offset=5782755 */ "unc_q_rxl_occupancy_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN0. Unit: uncore_qpi \000event=0x1a,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000"
/* offset=5783406 */ "unc_q_rxl_occupancy_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN1. Unit: uncore_qpi \000event=0x1a,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000"
/* offset=5784057 */ "unc_q_rxl_occupancy_ndr\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR. Unit: uncore_qpi \000event=0x1a\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000"
/* offset=5784685 */ "unc_q_rxl_occupancy_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x19,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000"
/* offset=5785336 */ "unc_q_rxl_occupancy_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x19,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000"
/* offset=5785987 */ "unc_q_rxl_occupancy_snp\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP. Unit: uncore_qpi \000event=0x19\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000"
/* offset=5786615 */ "unc_q_rxl_stalls.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5786797 */ "unc_q_rxl_stalls.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5786979 */ "unc_q_rxl_stalls.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5787161 */ "unc_q_rxl_stalls.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5787343 */ "unc_q_rxl_stalls.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5787526 */ "unc_q_rxl_stalls.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5787709 */ "unc_q_rxl_stalls.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5787898 */ "unc_q_rxl_stalls.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI\000"
/* offset=5788063 */ "unc_q_rxl_stalls_vn0.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5788473 */ "unc_q_rxl_stalls_vn0.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5788883 */ "unc_q_rxl_stalls_vn0.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5789293 */ "unc_q_rxl_stalls_vn0.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5789703 */ "unc_q_rxl_stalls_vn0.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5790114 */ "unc_q_rxl_stalls_vn0.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5790525 */ "unc_q_rxl_stalls_vn0.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet because there were insufficient BGF credits.  For details on a message class granularity, use the Egress Credit Occupancy events\000"
/* offset=5790893 */ "unc_q_rxl_stalls_vn0.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled because a GV transition (frequency transition) was taking place\000"
/* offset=5791163 */ "unc_q_rxl_stalls_vn1.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - HOM. Unit: uncore_qpi \000event=0x3a,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5791574 */ "unc_q_rxl_stalls_vn1.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - DRS. Unit: uncore_qpi \000event=0x3a,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5791985 */ "unc_q_rxl_stalls_vn1.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - SNP. Unit: uncore_qpi \000event=0x3a,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5792396 */ "unc_q_rxl_stalls_vn1.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NDR. Unit: uncore_qpi \000event=0x3a,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5792807 */ "unc_q_rxl_stalls_vn1.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCS. Unit: uncore_qpi \000event=0x3a,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5793219 */ "unc_q_rxl_stalls_vn1.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCB. Unit: uncore_qpi \000event=0x3a,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000"
/* offset=5793631 */ "unc_q_txl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xc\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=5794182 */ "unc_q_txl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0xd\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000"
/* offset=5794851 */ "unc_q_txl_bypassed\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x5\000\00001\000Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the QPI Link. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000"
/* offset=5795291 */ "unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is almost full, we block some but not all packets\000"
/* offset=5795613 */ "unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall\000"
/* offset=5795874 */ "unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is totally full, we are not allowed to send any packets\000"
/* offset=5796188 */ "unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall\000"
/* offset=5796435 */ "unc_q_txl_cycles_ne\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Cycles not Empty. Unit: uncore_qpi \000event=0x6\000\00001\000Counts the number of cycles when the TxQ is not empty. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000"
/* offset=5796816 */ "unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5798047 */ "unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000"
/* offset=5799668 */ "unc_q_txl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5800905 */ "unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000"
/* offset=5802153 */ "unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000"
/* offset=5803681 */ "unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5804958 */ "unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency\000"
/* offset=5806359 */ "unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5807622 */ "unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000"
/* offset=5809167 */ "unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5810436 */ "unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000"
/* offset=5812024 */ "unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5813277 */ "unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits transmitted over QPI on the home channel\000"
/* offset=5814580 */ "unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5815852 */ "unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits transmitted over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000"
/* offset=5817276 */ "unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5818541 */ "unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request transmitted over QPI on the home channel.  This basically counts the number of remote memory requests transmitted over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000"
/* offset=5820050 */ "unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5821303 */ "unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits transmitted over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are transmitted on the home channel\000"
/* offset=5822735 */ "unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5824009 */ "unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000"
/* offset=5825377 */ "unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5826654 */ "unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000"
/* offset=5828148 */ "unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5829432 */ "unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000"
/* offset=5830921 */ "unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5832198 */ "unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits transmitted over QPI.    This includes extended headers\000"
/* offset=5833557 */ "unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5834837 */ "unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000"
/* offset=5836350 */ "unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000"
/* offset=5837630 */ "unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000"
/* offset=5839144 */ "unc_q_txl_inserts\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x4\000\00001\000Number of allocations into the QPI Tx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=5839647 */ "unc_q_txl_occupancy\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_qpi \000event=0x7\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000"
/* offset=5840151 */ "unc_q_txr_ad_hom_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x26,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000"
/* offset=5840446 */ "unc_q_txr_ad_hom_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x26,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000"
/* offset=5840741 */ "unc_q_txr_ad_hom_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN0. Unit: uncore_qpi \000event=0x22,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000"
/* offset=5841076 */ "unc_q_txr_ad_hom_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN1. Unit: uncore_qpi \000event=0x22,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000"
/* offset=5841411 */ "unc_q_txr_ad_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x28,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000"
/* offset=5841709 */ "unc_q_txr_ad_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x28,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000"
/* offset=5842007 */ "unc_q_txr_ad_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x24,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000"
/* offset=5842342 */ "unc_q_txr_ad_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x24,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000"
/* offset=5842677 */ "unc_q_txr_ad_snp_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x27,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000"
/* offset=5842974 */ "unc_q_txr_ad_snp_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x27,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000"
/* offset=5843271 */ "unc_q_txr_ad_snp_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN0. Unit: uncore_qpi \000event=0x23,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000"
/* offset=5843608 */ "unc_q_txr_ad_snp_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN1. Unit: uncore_qpi \000event=0x23,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000"
/* offset=5843945 */ "unc_q_txr_ak_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN0. Unit: uncore_qpi \000event=0x29,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000"
/* offset=5844227 */ "unc_q_txr_ak_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN1. Unit: uncore_qpi \000event=0x29,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000"
/* offset=5844509 */ "unc_q_txr_ak_ndr_credit_acquired\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x29\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000"
/* offset=5844768 */ "unc_q_txr_ak_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN0. Unit: uncore_qpi \000event=0x25,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000"
/* offset=5845088 */ "unc_q_txr_ak_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN1. Unit: uncore_qpi \000event=0x25,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000"
/* offset=5845408 */ "unc_q_txr_ak_ndr_credit_occupancy\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x25\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000"
/* offset=5845705 */ "unc_q_txr_bl_drs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x2a,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000"
/* offset=5845978 */ "unc_q_txr_bl_drs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x2a,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000"
/* offset=5846251 */ "unc_q_txr_bl_drs_credit_acquired.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for Shared VN. Unit: uncore_qpi \000event=0x2a,umask=0x4\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000"
/* offset=5846533 */ "unc_q_txr_bl_drs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN0. Unit: uncore_qpi \000event=0x1f,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000"
/* offset=5846847 */ "unc_q_txr_bl_drs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN1. Unit: uncore_qpi \000event=0x1f,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000"
/* offset=5847161 */ "unc_q_txr_bl_drs_credit_occupancy.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for Shared VN. Unit: uncore_qpi \000event=0x1f,umask=0x4\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000"
/* offset=5847484 */ "unc_q_txr_bl_ncb_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x2b,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000"
/* offset=5847757 */ "unc_q_txr_bl_ncb_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x2b,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000"
/* offset=5848030 */ "unc_q_txr_bl_ncb_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN0. Unit: uncore_qpi \000event=0x20,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000"
/* offset=5848344 */ "unc_q_txr_bl_ncb_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN1. Unit: uncore_qpi \000event=0x20,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000"
/* offset=5848658 */ "unc_q_txr_bl_ncs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x2c,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000"
/* offset=5848931 */ "unc_q_txr_bl_ncs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x2c,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000"
/* offset=5849204 */ "unc_q_txr_bl_ncs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN0. Unit: uncore_qpi \000event=0x21,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000"
/* offset=5849518 */ "unc_q_txr_bl_ncs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN1. Unit: uncore_qpi \000event=0x21,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000"
/* offset=5849832 */ "unc_q_vna_credit_return_occupancy\000uncore_qpi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_qpi \000event=0x1b\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000"
/* offset=5850059 */ "unc_q_vna_credit_returns\000uncore_qpi\000uncore interconnect\000VNA Credits Returned. Unit: uncore_qpi \000event=0x1c\000\00001\000Number of VNA credits returned\000"
/* offset=5850201 */ "unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000"
/* offset=5850571 */ "unc_r2_iio_credit.isoch_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x4\000\00001\000\000"
/* offset=5850701 */ "unc_r2_iio_credit.isoch_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x8\000\00001\000\000"
/* offset=5850831 */ "unc_r2_iio_credit.prq_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x1\000\00001\000\000"
/* offset=5850957 */ "unc_r2_iio_credit.prq_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x2\000\00001\000\000"
/* offset=5851083 */ "unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000"
/* offset=5851712 */ "unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5852294 */ "unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000"
/* offset=5852924 */ "unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5853507 */ "unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000"
/* offset=5854137 */ "unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5854720 */ "unc_r2_iio_credits_reject.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; DRS. Unit: uncore_r2pcie \000event=0x34,umask=0x8\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000"
/* offset=5855267 */ "unc_r2_iio_credits_reject.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; DRS. Unit: uncore_r2pcie \000event=0x34,umask=0x8\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5855767 */ "unc_r2_iio_credits_reject.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; NCB. Unit: uncore_r2pcie \000event=0x34,umask=0x10\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5856268 */ "unc_r2_iio_credits_reject.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; NCS. Unit: uncore_r2pcie \000event=0x34,umask=0x20\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5856769 */ "unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000"
/* offset=5857399 */ "unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5857982 */ "unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000"
/* offset=5858613 */ "unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5859197 */ "unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000"
/* offset=5859828 */ "unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000"
/* offset=5860412 */ "unc_r2_ring_ad_used.all\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; All. Unit: uncore_r2pcie \000event=0x7,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5860751 */ "unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5861103 */ "unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5861456 */ "unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5861880 */ "unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5862246 */ "unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5862667 */ "unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5863031 */ "unc_r2_ring_ad_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5863488 */ "unc_r2_ring_ad_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5863942 */ "unc_r2_ring_ad_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5864400 */ "unc_r2_ring_ad_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5864855 */ "unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5865200 */ "unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5865544 */ "unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5865953 */ "unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5866311 */ "unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5866717 */ "unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5867073 */ "unc_r2_ring_ad_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5867515 */ "unc_r2_ring_ad_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5867954 */ "unc_r2_ring_ad_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5868397 */ "unc_r2_ring_ad_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5868837 */ "unc_r2_ring_ak_bounces.dn\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Dn. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000"
/* offset=5869035 */ "unc_r2_ring_ak_bounces.up\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Up. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000"
/* offset=5869233 */ "unc_r2_ring_ak_used.all\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; All. Unit: uncore_r2pcie \000event=0x8,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5869572 */ "unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5869924 */ "unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5870277 */ "unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5870701 */ "unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5871067 */ "unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5871488 */ "unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5871852 */ "unc_r2_ring_ak_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5872309 */ "unc_r2_ring_ak_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5872763 */ "unc_r2_ring_ak_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5873221 */ "unc_r2_ring_ak_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5873676 */ "unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5874021 */ "unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5874365 */ "unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5874774 */ "unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5875132 */ "unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5875538 */ "unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5875894 */ "unc_r2_ring_ak_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5876336 */ "unc_r2_ring_ak_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5876775 */ "unc_r2_ring_ak_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5877218 */ "unc_r2_ring_ak_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5877658 */ "unc_r2_ring_bl_used.all\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; All. Unit: uncore_r2pcie \000event=0x9,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5877997 */ "unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5878349 */ "unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5878702 */ "unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5879126 */ "unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5879492 */ "unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5879913 */ "unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5880277 */ "unc_r2_ring_bl_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5880734 */ "unc_r2_ring_bl_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5881188 */ "unc_r2_ring_bl_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5881646 */ "unc_r2_ring_bl_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5882101 */ "unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5882446 */ "unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5882790 */ "unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5883199 */ "unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5883557 */ "unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5883963 */ "unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5884319 */ "unc_r2_ring_bl_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5884761 */ "unc_r2_ring_bl_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5885200 */ "unc_r2_ring_bl_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000"
/* offset=5885643 */ "unc_r2_ring_bl_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000"
/* offset=5886083 */ "unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5886422 */ "unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time\000"
/* offset=5886969 */ "unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xff\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters any polarity\000"
/* offset=5887540 */ "unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5887892 */ "unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Counterclockwise polarity\000"
/* offset=5888493 */ "unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Clockwise polarity\000"
/* offset=5889079 */ "unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5889423 */ "unc_r2_rxr_ak_bounces.ccw\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Counterclockwise. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000"
/* offset=5889635 */ "unc_r2_rxr_ak_bounces.cw\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Clockwise. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000"
/* offset=5889839 */ "unc_r2_rxr_ak_bounces\000uncore_r2pcie\000uncore io\000AK Ingress Bounced. Unit: uncore_r2pcie \000event=0x12\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000"
/* offset=5890019 */ "unc_r2_rxr_cycles_ne.drs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; DRS. Unit: uncore_r2pcie \000event=0x10,umask=0x8\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5890495 */ "unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000"
/* offset=5890992 */ "unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5891469 */ "unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000"
/* offset=5891966 */ "unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5892443 */ "unc_r2_rxr_inserts.ncb\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCB. Unit: uncore_r2pcie \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000"
/* offset=5892923 */ "unc_r2_rxr_inserts.ncs\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCS. Unit: uncore_r2pcie \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000"
/* offset=5893403 */ "unc_r2_rxr_occupancy.drs\000uncore_r2pcie\000uncore io\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r2pcie \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given R2PCIe Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the R2PCIe Ingress Not Empty event to calculate average occupancy or the R2PCIe Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000"
/* offset=5893855 */ "unc_r2_sbo0_credit_occupancy.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=5894052 */ "unc_r2_sbo0_credit_occupancy.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=5894249 */ "unc_r2_sbo0_credits_acquired.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=5894447 */ "unc_r2_sbo0_credits_acquired.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=5894645 */ "unc_r2_stall_no_sbo_credit.sbo0_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5894895 */ "unc_r2_stall_no_sbo_credit.sbo0_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5895145 */ "unc_r2_stall_no_sbo_credit.sbo1_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5895395 */ "unc_r2_stall_no_sbo_credit.sbo1_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5895645 */ "unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AD Egress Queue\000"
/* offset=5895849 */ "unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000"
/* offset=5896035 */ "unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AK Egress Queue\000"
/* offset=5896239 */ "unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000"
/* offset=5896425 */ "unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; BL Egress Queue\000"
/* offset=5896629 */ "unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000"
/* offset=5896815 */ "unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AD Egress Queue\000"
/* offset=5897346 */ "unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5897859 */ "unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AK Egress Queue\000"
/* offset=5898390 */ "unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5898903 */ "unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; BL Egress Queue\000"
/* offset=5899434 */ "unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000"
/* offset=5899947 */ "unc_r2_txr_nack_ccw.ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5900098 */ "unc_r2_txr_nack_ccw.ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000AK CounterClockwise Egress Queue\000"
/* offset=5900249 */ "unc_r2_txr_nack_ccw.bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x4\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5900400 */ "unc_r2_txr_nack_cw.ad\000uncore_r2pcie\000uncore io\000Egress CW NACK; AD CW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD Clockwise Egress Queue\000"
/* offset=5900541 */ "unc_r2_txr_nack_cw.ak\000uncore_r2pcie\000uncore io\000Egress CW NACK; AK CW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000AK Clockwise Egress Queue\000"
/* offset=5900682 */ "unc_r2_txr_nack_cw.bl\000uncore_r2pcie\000uncore io\000Egress CW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000BL Clockwise Egress Queue\000"
/* offset=5900823 */ "unc_r2_txr_nack_cw.dn_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5900976 */ "unc_r2_txr_nack_cw.dn_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000"
/* offset=5901129 */ "unc_r2_txr_nack_cw.dn_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5901282 */ "unc_r2_txr_nack_cw.up_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5901435 */ "unc_r2_txr_nack_cw.up_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000"
/* offset=5901581 */ "unc_r2_txr_nack_cw.up_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5901735 */ "unc_r2_txr_nacks.ad\000uncore_r2pcie\000uncore io\000Egress NACK; AD. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000"
/* offset=5901949 */ "unc_r2_txr_nacks.ak\000uncore_r2pcie\000uncore io\000Egress NACK; AK. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000"
/* offset=5902163 */ "unc_r2_txr_nacks.bl\000uncore_r2pcie\000uncore io\000Egress NACK; BL. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000"
/* offset=5902377 */ "unc_r3_c_hi_ad_credits_empty.cbo10\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 10\000"
/* offset=5902597 */ "unc_r3_c_hi_ad_credits_empty.cbo10\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 10\000"
/* offset=5902817 */ "unc_r3_c_hi_ad_credits_empty.cbo11\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 11\000"
/* offset=5903037 */ "unc_r3_c_hi_ad_credits_empty.cbo11\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 11\000"
/* offset=5903257 */ "unc_r3_c_hi_ad_credits_empty.cbo12\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 12\000"
/* offset=5903478 */ "unc_r3_c_hi_ad_credits_empty.cbo12\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 12\000"
/* offset=5903699 */ "unc_r3_c_hi_ad_credits_empty.cbo13\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 13\000"
/* offset=5903920 */ "unc_r3_c_hi_ad_credits_empty.cbo13\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 13\000"
/* offset=5904141 */ "unc_r3_c_hi_ad_credits_empty.cbo14\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 14&16\000"
/* offset=5904365 */ "unc_r3_c_hi_ad_credits_empty.cbo14_16\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 14&16\000"
/* offset=5904592 */ "unc_r3_c_hi_ad_credits_empty.cbo8\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 8\000"
/* offset=5904810 */ "unc_r3_c_hi_ad_credits_empty.cbo8\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 8\000"
/* offset=5905028 */ "unc_r3_c_hi_ad_credits_empty.cbo9\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 9\000"
/* offset=5905246 */ "unc_r3_c_hi_ad_credits_empty.cbo9\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 9\000"
/* offset=5905464 */ "unc_r3_c_hi_ad_credits_empty.cbo_15_17\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 15&17\000"
/* offset=5905692 */ "unc_r3_c_lo_ad_credits_empty.cbo0\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 0\000"
/* offset=5905909 */ "unc_r3_c_lo_ad_credits_empty.cbo0\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 0\000"
/* offset=5906126 */ "unc_r3_c_lo_ad_credits_empty.cbo1\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 1\000"
/* offset=5906343 */ "unc_r3_c_lo_ad_credits_empty.cbo1\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 1\000"
/* offset=5906560 */ "unc_r3_c_lo_ad_credits_empty.cbo2\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 2\000"
/* offset=5906777 */ "unc_r3_c_lo_ad_credits_empty.cbo2\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 2\000"
/* offset=5906994 */ "unc_r3_c_lo_ad_credits_empty.cbo3\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 3\000"
/* offset=5907211 */ "unc_r3_c_lo_ad_credits_empty.cbo3\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 3\000"
/* offset=5907428 */ "unc_r3_c_lo_ad_credits_empty.cbo4\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 4\000"
/* offset=5907646 */ "unc_r3_c_lo_ad_credits_empty.cbo4\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 4\000"
/* offset=5907864 */ "unc_r3_c_lo_ad_credits_empty.cbo5\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 5\000"
/* offset=5908082 */ "unc_r3_c_lo_ad_credits_empty.cbo5\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 5\000"
/* offset=5908300 */ "unc_r3_c_lo_ad_credits_empty.cbo6\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 6\000"
/* offset=5908518 */ "unc_r3_c_lo_ad_credits_empty.cbo6\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 6\000"
/* offset=5908736 */ "unc_r3_c_lo_ad_credits_empty.cbo7\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 7\000"
/* offset=5908954 */ "unc_r3_c_lo_ad_credits_empty.cbo7\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 7\000"
/* offset=5909172 */ "unc_r3_clockticks\000uncore_r3qpi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_r3qpi \000event=0x1\000\00001\000Counts the number of uclks in the QPI uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the QPI Agent is close to the Ubox, they generally should not diverge by more than a handful of cycles\000"
/* offset=5909550 */ "unc_r3_ha_r2_bl_credits_empty.ha0\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x1\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA0\000"
/* offset=5909754 */ "unc_r3_ha_r2_bl_credits_empty.ha0\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x1\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA0\000"
/* offset=5909958 */ "unc_r3_ha_r2_bl_credits_empty.ha1\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x2\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA1\000"
/* offset=5910162 */ "unc_r3_ha_r2_bl_credits_empty.ha1\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x2\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA1\000"
/* offset=5910366 */ "unc_r3_ha_r2_bl_credits_empty.r2_ncb\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x4\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCB Messages\000"
/* offset=5910585 */ "unc_r3_ha_r2_bl_credits_empty.r2_ncb\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x4\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCB Messages\000"
/* offset=5910804 */ "unc_r3_ha_r2_bl_credits_empty.r2_ncs\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x8\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCS Messages\000"
/* offset=5911023 */ "unc_r3_ha_r2_bl_credits_empty.r2_ncs\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x8\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCS Messages\000"
/* offset=5911242 */ "unc_r3_iio_credits_acquired.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x8\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5911804 */ "unc_r3_iio_credits_acquired.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x10\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5912367 */ "unc_r3_iio_credits_acquired.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x20\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5912930 */ "unc_r3_iio_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x8\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5913562 */ "unc_r3_iio_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x10\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5914195 */ "unc_r3_iio_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x20\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5914828 */ "unc_r3_iio_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5915388 */ "unc_r3_iio_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5915949 */ "unc_r3_iio_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000"
/* offset=5916510 */ "unc_r3_iot_backpressure.hub\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x2\000\00001\000\000"
/* offset=5916634 */ "unc_r3_iot_backpressure.sat\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x1\000\00001\000\000"
/* offset=5916758 */ "unc_r3_iot_cts_hi.cts2\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=5916918 */ "unc_r3_iot_cts_hi.cts3\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=5917078 */ "unc_r3_iot_cts_lo.cts0\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=5917238 */ "unc_r3_iot_cts_lo.cts1\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000"
/* offset=5917398 */ "unc_r3_qpi0_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x2\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 HOM Messages\000"
/* offset=5917606 */ "unc_r3_qpi0_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x2\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 HOM Messages\000"
/* offset=5917814 */ "unc_r3_qpi0_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x8\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 NDR Messages\000"
/* offset=5918022 */ "unc_r3_qpi0_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x8\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 NDR Messages\000"
/* offset=5918230 */ "unc_r3_qpi0_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x4\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 SNP Messages\000"
/* offset=5918438 */ "unc_r3_qpi0_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x4\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 SNP Messages\000"
/* offset=5918646 */ "unc_r3_qpi0_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x10\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 HOM Messages\000"
/* offset=5918855 */ "unc_r3_qpi0_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x10\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 HOM Messages\000"
/* offset=5919064 */ "unc_r3_qpi0_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x40\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 NDR Messages\000"
/* offset=5919273 */ "unc_r3_qpi0_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x40\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 NDR Messages\000"
/* offset=5919482 */ "unc_r3_qpi0_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x20\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 SNP Messages\000"
/* offset=5919691 */ "unc_r3_qpi0_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x20\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 SNP Messages\000"
/* offset=5919900 */ "unc_r3_qpi0_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x1\000\00001\000No credits available to send to QPI0 on the AD Ring; VNA\000"
/* offset=5920091 */ "unc_r3_qpi0_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x1\000\00001\000No credits available to send to QPI0 on the AD Ring; VNA\000"
/* offset=5920282 */ "unc_r3_qpi0_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x2\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 HOM Messages\000"
/* offset=5920490 */ "unc_r3_qpi0_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x8\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 NDR Messages\000"
/* offset=5920698 */ "unc_r3_qpi0_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x4\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 SNP Messages\000"
/* offset=5920906 */ "unc_r3_qpi0_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x10\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 HOM Messages\000"
/* offset=5921115 */ "unc_r3_qpi0_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x10\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 HOM Messages\000"
/* offset=5921324 */ "unc_r3_qpi0_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x40\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 NDR Messages\000"
/* offset=5921533 */ "unc_r3_qpi0_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x40\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 NDR Messages\000"
/* offset=5921742 */ "unc_r3_qpi0_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x20\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 SNP Messages\000"
/* offset=5921951 */ "unc_r3_qpi0_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x20\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 SNP Messages\000"
/* offset=5922160 */ "unc_r3_qpi0_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x1\000\00001\000No credits available to send to QPI0 on the BL Ring; VNA\000"
/* offset=5922351 */ "unc_r3_qpi0_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x1\000\00001\000No credits available to send to QPI0 on the BL Ring; VNA\000"
/* offset=5922542 */ "unc_r3_qpi1_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x2\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 HOM Messages\000"
/* offset=5922750 */ "unc_r3_qpi1_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x8\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 NDR Messages\000"
/* offset=5922958 */ "unc_r3_qpi1_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x4\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 SNP Messages\000"
/* offset=5923166 */ "unc_r3_qpi1_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x10\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 HOM Messages\000"
/* offset=5923375 */ "unc_r3_qpi1_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x10\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 HOM Messages\000"
/* offset=5923584 */ "unc_r3_qpi1_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x40\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 NDR Messages\000"
/* offset=5923793 */ "unc_r3_qpi1_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x40\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 NDR Messages\000"
/* offset=5924002 */ "unc_r3_qpi1_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x20\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 SNP Messages\000"
/* offset=5924211 */ "unc_r3_qpi1_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x20\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 SNP Messages\000"
/* offset=5924420 */ "unc_r3_qpi1_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x1\000\00001\000No credits available to send to QPI1 on the AD Ring; VNA\000"
/* offset=5924611 */ "unc_r3_qpi1_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x1\000\00001\000No credits available to send to QPI1 on the AD Ring; VNA\000"
/* offset=5924802 */ "unc_r3_qpi1_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x2\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 HOM Messages\000"
/* offset=5925010 */ "unc_r3_qpi1_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x2\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 HOM Messages\000"
/* offset=5925218 */ "unc_r3_qpi1_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x8\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 NDR Messages\000"
/* offset=5925426 */ "unc_r3_qpi1_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x8\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 NDR Messages\000"
/* offset=5925634 */ "unc_r3_qpi1_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x4\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 SNP Messages\000"
/* offset=5925842 */ "unc_r3_qpi1_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x4\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 SNP Messages\000"
/* offset=5926050 */ "unc_r3_qpi1_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x10\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 HOM Messages\000"
/* offset=5926259 */ "unc_r3_qpi1_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x10\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 HOM Messages\000"
/* offset=5926468 */ "unc_r3_qpi1_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x40\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 NDR Messages\000"
/* offset=5926677 */ "unc_r3_qpi1_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x40\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 NDR Messages\000"
/* offset=5926886 */ "unc_r3_qpi1_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x20\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 SNP Messages\000"
/* offset=5927095 */ "unc_r3_qpi1_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x20\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 SNP Messages\000"
/* offset=5927304 */ "unc_r3_qpi1_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x1\000\00001\000No credits available to send to QPI1 on the BL Ring; VNA\000"
/* offset=5927495 */ "unc_r3_qpi1_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x1\000\00001\000No credits available to send to QPI1 on the BL Ring; VNA\000"
/* offset=5927686 */ "unc_r3_ring_ad_used.all\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; All. Unit: uncore_r3qpi \000event=0x7,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5928033 */ "unc_r3_ring_ad_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5928393 */ "unc_r3_ring_ad_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x7,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5928754 */ "unc_r3_ring_ad_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5929186 */ "unc_r3_ring_ad_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5929560 */ "unc_r3_ring_ad_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5929989 */ "unc_r3_ring_ad_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5930361 */ "unc_r3_ring_ad_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5930826 */ "unc_r3_ring_ad_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5931288 */ "unc_r3_ring_ad_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x7,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5931641 */ "unc_r3_ring_ad_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5931993 */ "unc_r3_ring_ad_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5932410 */ "unc_r3_ring_ad_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5932776 */ "unc_r3_ring_ad_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5933190 */ "unc_r3_ring_ad_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5933554 */ "unc_r3_ring_ad_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5934004 */ "unc_r3_ring_ad_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5934451 */ "unc_r3_ring_ak_used.all\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; All. Unit: uncore_r3qpi \000event=0x8,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5934798 */ "unc_r3_ring_ak_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5935158 */ "unc_r3_ring_ak_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x8,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5935519 */ "unc_r3_ring_ak_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5935893 */ "unc_r3_ring_ak_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5936325 */ "unc_r3_ring_ak_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5936697 */ "unc_r3_ring_ak_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5937126 */ "unc_r3_ring_ak_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5937591 */ "unc_r3_ring_ak_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5938053 */ "unc_r3_ring_ak_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x8,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5938406 */ "unc_r3_ring_ak_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5938758 */ "unc_r3_ring_ak_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5939124 */ "unc_r3_ring_ak_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5939541 */ "unc_r3_ring_ak_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5939905 */ "unc_r3_ring_ak_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5940319 */ "unc_r3_ring_ak_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5940769 */ "unc_r3_ring_ak_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5941216 */ "unc_r3_ring_bl_used.all\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; All. Unit: uncore_r3qpi \000event=0x9,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5941563 */ "unc_r3_ring_bl_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5941923 */ "unc_r3_ring_bl_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x9,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5942284 */ "unc_r3_ring_bl_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000"
/* offset=5942716 */ "unc_r3_ring_bl_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5943090 */ "unc_r3_ring_bl_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000"
/* offset=5943519 */ "unc_r3_ring_bl_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5943891 */ "unc_r3_ring_bl_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5944356 */ "unc_r3_ring_bl_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5944818 */ "unc_r3_ring_bl_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x9,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5945171 */ "unc_r3_ring_bl_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5945523 */ "unc_r3_ring_bl_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000"
/* offset=5945940 */ "unc_r3_ring_bl_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5946306 */ "unc_r3_ring_bl_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000"
/* offset=5946720 */ "unc_r3_ring_bl_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000"
/* offset=5947084 */ "unc_r3_ring_bl_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000"
/* offset=5947534 */ "unc_r3_ring_bl_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000"
/* offset=5947981 */ "unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xff\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters any polarity\000"
/* offset=5948560 */ "unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time\000"
/* offset=5949115 */ "unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5949462 */ "unc_r3_ring_iv_used.ccw\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0xa,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Counterclockwise polarity\000"
/* offset=5950071 */ "unc_r3_ring_iv_used.cw\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0xa,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Clockwise polarity\000"
/* offset=5950665 */ "unc_r3_ring_iv_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000"
/* offset=5951017 */ "unc_r3_ring_sink_starved.ak\000uncore_r3qpi\000uncore interconnect\000Ring Stop Starved; AK. Unit: uncore_r3qpi \000event=0xe,umask=0x2\000\00001\000Number of cycles the ringstop is in starvation (per ring)\000"
/* offset=5951203 */ "unc_r3_rxr_ad_bypassed\000uncore_r3qpi\000uncore interconnect\000AD Ingress Bypassed. Unit: uncore_r3qpi \000event=0x12\000\00001\000Counts the number of times when the AD Ingress was bypassed and an incoming transaction was bypassed directly across the BGF and into the qfclk domain\000"
/* offset=5951466 */ "unc_r3_rxr_bypassed.ad\000uncore_r3qpi\000uncore interconnect\000Ingress Bypassed. Unit: uncore_r3qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of times when the Ingress was bypassed and an incoming transaction was bypassed directly across the BGF and into the qfclk domain\000"
/* offset=5951733 */ "unc_r3_rxr_cycles_ne.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; DRS. Unit: uncore_r3qpi \000event=0x10,umask=0x8\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5952208 */ "unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000"
/* offset=5952703 */ "unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5953178 */ "unc_r3_rxr_cycles_ne.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NCB. Unit: uncore_r3qpi \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5953654 */ "unc_r3_rxr_cycles_ne.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NCS. Unit: uncore_r3qpi \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5954130 */ "unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000"
/* offset=5954625 */ "unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5955100 */ "unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000"
/* offset=5955595 */ "unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5956070 */ "unc_r3_rxr_cycles_ne_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; DRS. Unit: uncore_r3qpi \000event=0x14,umask=0x8\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000"
/* offset=5956583 */ "unc_r3_rxr_cycles_ne_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000"
/* offset=5957096 */ "unc_r3_rxr_cycles_ne_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCB. Unit: uncore_r3qpi \000event=0x14,umask=0x10\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000"
/* offset=5957610 */ "unc_r3_rxr_cycles_ne_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCS. Unit: uncore_r3qpi \000event=0x14,umask=0x20\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000"
/* offset=5958124 */ "unc_r3_rxr_cycles_ne_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x14,umask=0x4\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000"
/* offset=5958637 */ "unc_r3_rxr_cycles_ne_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000"
/* offset=5959150 */ "unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000"
/* offset=5959628 */ "unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5960086 */ "unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000"
/* offset=5960564 */ "unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5961022 */ "unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000"
/* offset=5961501 */ "unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5961960 */ "unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000"
/* offset=5962439 */ "unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5962898 */ "unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000"
/* offset=5963376 */ "unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5963834 */ "unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000"
/* offset=5964312 */ "unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000"
/* offset=5964770 */ "unc_r3_rxr_inserts_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x15,umask=0x8\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000"
/* offset=5965266 */ "unc_r3_rxr_inserts_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x15,umask=0x1\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000"
/* offset=5965762 */ "unc_r3_rxr_inserts_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x15,umask=0x10\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000"
/* offset=5966259 */ "unc_r3_rxr_inserts_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x15,umask=0x20\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000"
/* offset=5966756 */ "unc_r3_rxr_inserts_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x15,umask=0x4\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000"
/* offset=5967252 */ "unc_r3_rxr_inserts_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x15,umask=0x2\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000"
/* offset=5967748 */ "unc_r3_rxr_occupancy.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000"
/* offset=5968199 */ "unc_r3_rxr_occupancy.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5968630 */ "unc_r3_rxr_occupancy.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; HOM Ingress Queue\000"
/* offset=5969081 */ "unc_r3_rxr_occupancy.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5969512 */ "unc_r3_rxr_occupancy.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NCB Ingress Queue\000"
/* offset=5969964 */ "unc_r3_rxr_occupancy.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5970396 */ "unc_r3_rxr_occupancy.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NCS Ingress Queue\000"
/* offset=5970848 */ "unc_r3_rxr_occupancy.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5971280 */ "unc_r3_rxr_occupancy.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NDR Ingress Queue\000"
/* offset=5971731 */ "unc_r3_rxr_occupancy.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5972162 */ "unc_r3_rxr_occupancy.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; SNP Ingress Queue\000"
/* offset=5972613 */ "unc_r3_rxr_occupancy.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000"
/* offset=5973044 */ "unc_r3_rxr_occupancy_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000"
/* offset=5973518 */ "unc_r3_rxr_occupancy_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; HOM Ingress Queue\000"
/* offset=5973992 */ "unc_r3_rxr_occupancy_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCB Ingress Queue\000"
/* offset=5974467 */ "unc_r3_rxr_occupancy_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCS Ingress Queue\000"
/* offset=5974942 */ "unc_r3_rxr_occupancy_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NDR Ingress Queue\000"
/* offset=5975416 */ "unc_r3_rxr_occupancy_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; SNP Ingress Queue\000"
/* offset=5975890 */ "unc_r3_sbo0_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=5976095 */ "unc_r3_sbo0_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000"
/* offset=5976300 */ "unc_r3_sbo0_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=5976506 */ "unc_r3_sbo0_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000"
/* offset=5976712 */ "unc_r3_sbo1_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000"
/* offset=5976917 */ "unc_r3_sbo1_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000"
/* offset=5977122 */ "unc_r3_sbo1_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000"
/* offset=5977328 */ "unc_r3_sbo1_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000"
/* offset=5977534 */ "unc_r3_stall_no_sbo_credit.sbo0_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5977792 */ "unc_r3_stall_no_sbo_credit.sbo0_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5978050 */ "unc_r3_stall_no_sbo_credit.sbo1_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5978308 */ "unc_r3_stall_no_sbo_credit.sbo1_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000"
/* offset=5978566 */ "unc_r3_txr_nack.dn_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AD CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5978724 */ "unc_r3_txr_nack.dn_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000"
/* offset=5978882 */ "unc_r3_txr_nack.dn_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5979040 */ "unc_r3_txr_nack.up_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5979198 */ "unc_r3_txr_nack.up_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CW. Unit: uncore_r3qpi \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000"
/* offset=5979349 */ "unc_r3_txr_nack.up_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5979508 */ "unc_r3_txr_nack_ccw.ad\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AK CCW. Unit: uncore_r3qpi \000event=0x28,umask=0x1\000\00001\000BL CounterClockwise Egress Queue\000"
/* offset=5979663 */ "unc_r3_txr_nack_ccw.ak\000uncore_r3qpi\000uncore interconnect\000Egress NACK; BL CW. Unit: uncore_r3qpi \000event=0x28,umask=0x2\000\00001\000AD Clockwise Egress Queue\000"
/* offset=5979810 */ "unc_r3_txr_nack_ccw.bl\000uncore_r3qpi\000uncore interconnect\000Egress NACK; BL CCW. Unit: uncore_r3qpi \000event=0x28,umask=0x4\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5979965 */ "unc_r3_txr_nack_cw.ad\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AD CW. Unit: uncore_r3qpi \000event=0x26,umask=0x1\000\00001\000AD Clockwise Egress Queue\000"
/* offset=5980111 */ "unc_r3_txr_nack_cw.ak\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AD CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x2\000\00001\000AD CounterClockwise Egress Queue\000"
/* offset=5980265 */ "unc_r3_txr_nack_cw.bl\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AK CW. Unit: uncore_r3qpi \000event=0x26,umask=0x4\000\00001\000BL Clockwise Egress Queue\000"
/* offset=5980411 */ "unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000"
/* offset=5981403 */ "unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5982203 */ "unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=5983126 */ "unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5983926 */ "unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5984874 */ "unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5985675 */ "unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000"
/* offset=5986546 */ "unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5987347 */ "unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5988249 */ "unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5989049 */ "unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000"
/* offset=5989980 */ "unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000"
/* offset=5990780 */ "unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000"
/* offset=5991917 */ "unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=5992862 */ "unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=5993930 */ "unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=5994875 */ "unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=5995968 */ "unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=5996914 */ "unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000"
/* offset=5997930 */ "unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=5998876 */ "unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=5999923 */ "unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=6000868 */ "unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000"
/* offset=6001944 */ "unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000"
/* offset=6002889 */ "unc_r3_vn1_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x8\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000"
/* offset=6003877 */ "unc_r3_vn1_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x1\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=6004796 */ "unc_r3_vn1_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x10\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=6005740 */ "unc_r3_vn1_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x20\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000"
/* offset=6006607 */ "unc_r3_vn1_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x4\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=6007505 */ "unc_r3_vn1_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x2\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000"
/* offset=6008432 */ "unc_r3_vn1_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x8\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000"
/* offset=6009569 */ "unc_r3_vn1_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x1\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=6010637 */ "unc_r3_vn1_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x10\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=6011730 */ "unc_r3_vn1_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x20\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000"
/* offset=6012746 */ "unc_r3_vn1_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x4\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=6013793 */ "unc_r3_vn1_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x2\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000"
/* offset=6014869 */ "unc_r3_vna_credit_cycles_out\000uncore_r3qpi\000uncore interconnect\000Cycles with no VNA credits available. Unit: uncore_r3qpi \000event=0x31\000\00001\000Number of QPI uclk cycles when the transmitted has no VNA credits available and therefore cannot send any requests on this channel.  Note that this does not mean that no flits can be transmitted, as those holding VN0 credits will still (potentially) be able to transmit.  Generally it is the goal of the uncore that VNA credits should not run out, as this can substantially throttle back useful QPI bandwidth\000"
/* offset=6015413 */ "unc_r3_vna_credit_cycles_used\000uncore_r3qpi\000uncore interconnect\000Cycles with 1 or more VNA credits in use. Unit: uncore_r3qpi \000event=0x32\000\00001\000Number of QPI uclk cycles with one or more VNA credits in use.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average number of used VNA credits\000"
/* offset=6015739 */ "unc_r3_vna_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x1\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=6016691 */ "unc_r3_vna_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x4\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=6017643 */ "unc_r3_vna_credits_acquired\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions. Unit: uncore_r3qpi \000event=0x33\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event\000"
/* offset=6018440 */ "unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000"
/* offset=6019458 */ "unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6020284 */ "unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000"
/* offset=6021233 */ "unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6022059 */ "unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000"
/* offset=6023033 */ "unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6023860 */ "unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Standard (NCS)\000"
/* offset=6024728 */ "unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6025555 */ "unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000"
/* offset=6026483 */ "unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6027309 */ "unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000"
/* offset=6028266 */ "unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000"
/* offset=6029092 */ "unc_s_bounce_control\000uncore_sbox\000uncore interconnect\000Bounce Control. Unit: uncore_sbox \000event=0xa\000\00001\000\000"
/* offset=6029195 */ "unc_s_clockticks\000uncore_sbox\000uncore interconnect\000Uncore Clocks. Unit: uncore_sbox \000event=0\000\00001\000\000"
/* offset=6029291 */ "unc_s_fast_asserted\000uncore_sbox\000uncore interconnect\000FaST wire asserted. Unit: uncore_sbox \000event=0x9\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000"
/* offset=6029530 */ "unc_s_ring_ad_used.all\000uncore_sbox\000uncore interconnect\000AD Ring In Use; All. Unit: uncore_sbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6030374 */ "unc_s_ring_ad_used.down\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down. Unit: uncore_sbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6031220 */ "unc_s_ring_ad_used.down_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6032128 */ "unc_s_ring_ad_used.down_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6033036 */ "unc_s_ring_ad_used.down_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6033939 */ "unc_s_ring_ad_used.down_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6034842 */ "unc_s_ring_ad_used.up\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up. Unit: uncore_sbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6035684 */ "unc_s_ring_ad_used.up_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6036584 */ "unc_s_ring_ad_used.up_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6037484 */ "unc_s_ring_ad_used.up_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6038381 */ "unc_s_ring_ad_used.up_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6039278 */ "unc_s_ring_ak_used.all\000uncore_sbox\000uncore interconnect\000AK Ring In Use; All. Unit: uncore_sbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6040121 */ "unc_s_ring_ak_used.down\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down. Unit: uncore_sbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6040966 */ "unc_s_ring_ak_used.down_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6041873 */ "unc_s_ring_ak_used.down_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6042780 */ "unc_s_ring_ak_used.down_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6043682 */ "unc_s_ring_ak_used.down_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6044584 */ "unc_s_ring_ak_used.up\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up. Unit: uncore_sbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6045425 */ "unc_s_ring_ak_used.up_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6046324 */ "unc_s_ring_ak_used.up_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6047223 */ "unc_s_ring_ak_used.up_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6048119 */ "unc_s_ring_ak_used.up_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6049015 */ "unc_s_ring_bl_used.all\000uncore_sbox\000uncore interconnect\000BL Ring in Use; All. Unit: uncore_sbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6049858 */ "unc_s_ring_bl_used.down\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down. Unit: uncore_sbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6050703 */ "unc_s_ring_bl_used.down_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Event. Unit: uncore_sbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6051610 */ "unc_s_ring_bl_used.down_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Event. Unit: uncore_sbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000"
/* offset=6052517 */ "unc_s_ring_bl_used.down_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6053419 */ "unc_s_ring_bl_used.down_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000"
/* offset=6054321 */ "unc_s_ring_bl_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up. Unit: uncore_sbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000"
/* offset=6055162 */ "unc_s_ring_bl_used.up_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Even. Unit: uncore_sbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6056061 */ "unc_s_ring_bl_used.up_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Even. Unit: uncore_sbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000"
/* offset=6056960 */ "unc_s_ring_bl_used.up_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6057856 */ "unc_s_ring_bl_used.up_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000"
/* offset=6058752 */ "unc_s_ring_bounces.ad_cache\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring. Unit: uncore_sbox \000event=0x5,umask=0x1\000\00001\000\000"
/* offset=6058906 */ "unc_s_ring_bounces.ak_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_sbox \000event=0x5,umask=0x2\000\00001\000\000"
/* offset=6059086 */ "unc_s_ring_bounces.bl_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_sbox \000event=0x5,umask=0x4\000\00001\000\000"
/* offset=6059264 */ "unc_s_ring_bounces.iv_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_sbox \000event=0x5,umask=0x8\000\00001\000\000"
/* offset=6059447 */ "unc_s_ring_iv_used.dn\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=6060009 */ "unc_s_ring_iv_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000"
/* offset=6060571 */ "unc_s_ring_sink_starved.ad_cache\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AD_CACHE. Unit: uncore_sbox \000event=0x6,umask=0x1\000\00001\000\000"
/* offset=6060714 */ "unc_s_ring_sink_starved.ak_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AK_CORE. Unit: uncore_sbox \000event=0x6,umask=0x2\000\00001\000\000"
/* offset=6060855 */ "unc_s_ring_sink_starved.bl_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.BL_CORE. Unit: uncore_sbox \000event=0x6,umask=0x4\000\00001\000\000"
/* offset=6060996 */ "unc_s_ring_sink_starved.iv_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.IV_CORE. Unit: uncore_sbox \000event=0x6,umask=0x8\000\00001\000\000"
/* offset=6061137 */ "unc_s_rxr_busy_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000"
/* offset=6061536 */ "unc_s_rxr_busy_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x15,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000"
/* offset=6061935 */ "unc_s_rxr_busy_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000"
/* offset=6062334 */ "unc_s_rxr_busy_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x15,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000"
/* offset=6062733 */ "unc_s_rxr_bypass.ad_bnc\000uncore_sbox\000uncore interconnect\000Bypass; AD - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x2\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6062878 */ "unc_s_rxr_bypass.ad_crd\000uncore_sbox\000uncore interconnect\000Bypass; AD - Credits. Unit: uncore_sbox \000event=0x12,umask=0x1\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6063023 */ "unc_s_rxr_bypass.ak\000uncore_sbox\000uncore interconnect\000Bypass; AK. Unit: uncore_sbox \000event=0x12,umask=0x10\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6063155 */ "unc_s_rxr_bypass.bl_bnc\000uncore_sbox\000uncore interconnect\000Bypass; BL - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x8\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6063300 */ "unc_s_rxr_bypass.bl_crd\000uncore_sbox\000uncore interconnect\000Bypass; BL - Credits. Unit: uncore_sbox \000event=0x12,umask=0x4\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6063445 */ "unc_s_rxr_bypass.iv\000uncore_sbox\000uncore interconnect\000Bypass; IV. Unit: uncore_sbox \000event=0x12,umask=0x20\000\00001\000Bypass the Sbo Ingress\000"
/* offset=6063577 */ "unc_s_rxr_crd_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6063942 */ "unc_s_rxr_crd_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x14,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6064307 */ "unc_s_rxr_crd_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; AK. Unit: uncore_sbox \000event=0x14,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6064659 */ "unc_s_rxr_crd_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6065024 */ "unc_s_rxr_crd_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x14,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6065389 */ "unc_s_rxr_crd_starved.ifv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IVF Credit. Unit: uncore_sbox \000event=0x14,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6065750 */ "unc_s_rxr_crd_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IV. Unit: uncore_sbox \000event=0x14,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000"
/* offset=6066102 */ "unc_s_rxr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x2\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6066346 */ "unc_s_rxr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x13,umask=0x1\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6066590 */ "unc_s_rxr_inserts.ak\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AK. Unit: uncore_sbox \000event=0x13,umask=0x10\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6066821 */ "unc_s_rxr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x8\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6067065 */ "unc_s_rxr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x13,umask=0x4\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6067309 */ "unc_s_rxr_inserts.iv\000uncore_sbox\000uncore interconnect\000Ingress Allocations; IV. Unit: uncore_sbox \000event=0x13,umask=0x20\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000"
/* offset=6067540 */ "unc_s_rxr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6067793 */ "unc_s_rxr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x11,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6068046 */ "unc_s_rxr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AK. Unit: uncore_sbox \000event=0x11,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6068286 */ "unc_s_rxr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6068539 */ "unc_s_rxr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x11,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6068792 */ "unc_s_rxr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; IV. Unit: uncore_sbox \000event=0x11,umask=0x20\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000"
/* offset=6069032 */ "unc_s_txr_ads_used.ad\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AD. Unit: uncore_sbox \000event=0x4,umask=0x1\000\00001\000\000"
/* offset=6069153 */ "unc_s_txr_ads_used.ak\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AK. Unit: uncore_sbox \000event=0x4,umask=0x2\000\00001\000\000"
/* offset=6069274 */ "unc_s_txr_ads_used.bl\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.BL. Unit: uncore_sbox \000event=0x4,umask=0x4\000\00001\000\000"
/* offset=6069395 */ "unc_s_txr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6069635 */ "unc_s_txr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6069875 */ "unc_s_txr_inserts.ak\000uncore_sbox\000uncore interconnect\000Egress Allocations; AK. Unit: uncore_sbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6070102 */ "unc_s_txr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6070342 */ "unc_s_txr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6070582 */ "unc_s_txr_inserts.iv\000uncore_sbox\000uncore interconnect\000Egress Allocations; IV. Unit: uncore_sbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000"
/* offset=6070809 */ "unc_s_txr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6071057 */ "unc_s_txr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x1,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6071305 */ "unc_s_txr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AK. Unit: uncore_sbox \000event=0x1,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6071540 */ "unc_s_txr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6071788 */ "unc_s_txr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x1,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6072036 */ "unc_s_txr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Egress Occupancy; IV. Unit: uncore_sbox \000event=0x1,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000"
/* offset=6072271 */ "unc_s_txr_starved.ad\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AD Ring. Unit: uncore_sbox \000event=0x3,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=6072544 */ "unc_s_txr_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AK Ring. Unit: uncore_sbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=6072817 */ "unc_s_txr_starved.bl\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto BL Ring. Unit: uncore_sbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=6073090 */ "unc_s_txr_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto IV Ring. Unit: uncore_sbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000"
/* offset=6073363 */ "unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000"
/* offset=6073510 */ "unc_u_clockticks\000uncore_ubox\000uncore interconnect\000UNC_U_CLOCKTICKS. Unit: uncore_ubox \000event=0\000\00001\000\000"
/* offset=6073609 */ "unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Unit: uncore_ubox \000event=0\000\00001\000\000"
/* offset=6073690 */ "unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : Doorbell. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000\000"
/* offset=6073826 */ "unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000"
/* offset=6074014 */ "unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6074265 */ "unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received : Interrupt. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Message Received : Interrupt : Interrupts\000"
/* offset=6074439 */ "unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000"
/* offset=6074623 */ "unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6074870 */ "unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Message Received : IPI : Inter Processor Interrupts\000"
/* offset=6075047 */ "unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Inter Processor Interrupts\000"
/* offset=6075264 */ "unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6075510 */ "unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Message Received : MSI : Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000"
/* offset=6075765 */ "unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000"
/* offset=6076060 */ "unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6076306 */ "unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Message Received : VLW : Virtual Logical Wire (legacy) message were received from Uncore\000"
/* offset=6076520 */ "unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000"
/* offset=6076708 */ "unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6076954 */ "unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6077187 */ "unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6077419 */ "unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6077656 */ "unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000"
/* offset=6077892 */ "unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000IDI Lock/SplitLock Cycles : Number of times an IDI Lock/SplitLock sequence was started\000"
/* offset=6078090 */ "unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000Number of times an IDI Lock/SplitLock sequence was started\000"
/* offset=6078260 */ "unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x1\000\00001\000\000"
/* offset=6078414 */ "unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x2\000\00001\000\000"
/* offset=6078568 */ "unc_u_m2u_misc1.rxc_cycles_ne_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x4\000\00001\000\000"
/* offset=6078722 */ "unc_u_m2u_misc1.rxc_cycles_ne_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x8\000\00001\000\000"
/* offset=6078876 */ "unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x10\000\00001\000\000"
/* offset=6079041 */ "unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x20\000\00001\000\000"
/* offset=6079206 */ "unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x40\000\00001\000\000"
/* offset=6079371 */ "unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x80\000\00001\000\000"
/* offset=6079536 */ "unc_u_m2u_misc2.rxc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x2\000\00001\000\000"
/* offset=6079686 */ "unc_u_m2u_misc2.rxc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x1\000\00001\000\000"
/* offset=6079834 */ "unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCB. Unit: uncore_ubox \000event=0x4e,umask=0x4\000\00001\000\000"
/* offset=6079998 */ "unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCS. Unit: uncore_ubox \000event=0x4e,umask=0x8\000\00001\000\000"
/* offset=6080162 */ "unc_u_m2u_misc2.txc_cycles_empty_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AK. Unit: uncore_ubox \000event=0x4e,umask=0x20\000\00001\000\000"
/* offset=6080313 */ "unc_u_m2u_misc2.txc_cycles_empty_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AKC. Unit: uncore_ubox \000event=0x4e,umask=0x40\000\00001\000\000"
/* offset=6080466 */ "unc_u_m2u_misc2.txc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x10\000\00001\000\000"
/* offset=6080617 */ "unc_u_m2u_misc2.txc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x80\000\00001\000\000"
/* offset=6080766 */ "unc_u_m2u_misc3.txc_cycles_full_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AK. Unit: uncore_ubox \000event=0x4f,umask=0x1\000\00001\000\000"
/* offset=6080914 */ "unc_u_m2u_misc3.txc_cycles_full_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AKC. Unit: uncore_ubox \000event=0x4f,umask=0x2\000\00001\000\000"
/* offset=6081064 */ "unc_u_msg_chnl_size_count.4b\000uncore_ubox\000uncore interconnect\000MsgCh Requests by Size; 4B Requests. Unit: uncore_ubox \000event=0x47,umask=0x1\000\00001\000Number of transactions on the message channel filtered by request size.  This includes both reads and writes\000"
/* offset=6081315 */ "unc_u_msg_chnl_size_count.8b\000uncore_ubox\000uncore interconnect\000MsgCh Requests by Size; 8B Requests. Unit: uncore_ubox \000event=0x47,umask=0x2\000\00001\000Number of transactions on the message channel filtered by request size.  This includes both reads and writes\000"
/* offset=6081566 */ "unc_u_phold_cycles.ack_to_deassert\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; ACK to Deassert. Unit: uncore_ubox \000event=0x45,umask=0x2\000\00001\000PHOLD cycles.  Filter from source CoreID\000"
/* offset=6081763 */ "unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack : Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000Cycles PHOLD Assert to Ack : Assert to ACK : PHOLD cycles\000"
/* offset=6081974 */ "unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000"
/* offset=6082167 */ "unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles\000"
/* offset=6082332 */ "unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000"
/* offset=6082474 */ "unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000"
/* offset=6082598 */ "unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000"
/* offset=6082722 */ "unc_u_racu_requests.count\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46,umask=0x1\000\00001\000\000"
/* offset=6082839 */ "unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000"
/* offset=6083007 */ "unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000RACU Request : Number outstanding register requests within message channel tracker\000"
/* offset=6083190 */ "unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000\000"
/* offset=6083291 */ "unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6083494 */ "unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000"
/* offset=6083700 */ "unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6083890 */ "unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000"
/* offset=6084094 */ "unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6084282 */ "unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000"
/* offset=6084492 */ "unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6084686 */ "unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000"
/* offset=6084896 */ "unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6085090 */ "unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores; PREQ, PSMI, P2U, Thermal, PCUSMI, PMI\000"
/* offset=6085314 */ "unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6085499 */ "unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6085682 */ "unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000"
/* offset=6085887 */ "unc_upi_clockticks\000uncore_upi\000uncore interconnect\000Clocks of the Intel(R) Ultra Path Interconnect (UPI). Unit: uncore_upi \000event=0x1\000\00001\000Counts clockticks of the fixed frequency clock controlling the Intel(R) Ultra Path Interconnect (UPI).  This clock runs at1/8th the 'GT/s' speed of the UPI link.  For example, a  9.6GT/s  link will have a fixed Frequency of 1.2 Ghz\000"
/* offset=6086255 */ "unc_upi_clockticks\000uncore_upi\000uncore interconnect\000Number of kfclks. Unit: uncore_upi \000event=0x1\000\00001\000Number of kfclks : Counts the number of clocks in the UPI LL.  This clock runs at 1/8th the GT/s speed of the UPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  Current products do not support dynamic link speeds, so this frequency is fixed\000"
/* offset=6086608 */ "unc_upi_clockticks\000uncore_upi\000uncore interconnect\000UPI Clockticks. Unit: uncore_upi \000event=0x1\000\00001\000Number of UPI LL clock cycles while the event is enabled\000"
/* offset=6086763 */ "unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to core. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to core bypassing the CHA\000"
/* offset=6087000 */ "unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2C. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Direct packet attempts : D2C : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=6087538 */ "unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2K. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Direct packet attempts : D2K : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000"
/* offset=6088076 */ "unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_DIRECT_ATTEMPTS.D2U. Unit: uncore_upi \000event=0x12,umask=0x2\000\00011\000\000"
/* offset=6088253 */ "unc_upi_direct_attempts.d2u\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to Intel(R) UPI. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to Intel(R) Ultra Path Interconnect (UPI) bypassing the CHA \000"
/* offset=6088533 */ "unc_upi_flowq_no_vna_crd.ad_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x1\000\00001\000\000"
/* offset=6088681 */ "unc_upi_flowq_no_vna_crd.ad_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x2\000\00001\000\000"
/* offset=6088829 */ "unc_upi_flowq_no_vna_crd.ad_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x4\000\00001\000\000"
/* offset=6088977 */ "unc_upi_flowq_no_vna_crd.ak_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x10\000\00001\000\000"
/* offset=6089126 */ "unc_upi_flowq_no_vna_crd.ak_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x20\000\00001\000\000"
/* offset=6089275 */ "unc_upi_flowq_no_vna_crd.ak_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x40\000\00001\000\000"
/* offset=6089424 */ "unc_upi_flowq_no_vna_crd.ak_vna_eq3\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ3. Unit: uncore_upi \000event=0x18,umask=0x80\000\00001\000\000"
/* offset=6089573 */ "unc_upi_flowq_no_vna_crd.bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.BL_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x8\000\00001\000\000"
/* offset=6089721 */ "unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles Intel(R) UPI is in L1 power mode (shutdown). Unit: uncore_upi \000event=0x21\000\00001\000Counts cycles when the Intel(R) Ultra Path Interconnect (UPI) is in L1 power mode.  L1 is a mode that totally shuts down the UPI link.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another, this event only coutns when both links are shutdown\000"
/* offset=6090178 */ "unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L1. Unit: uncore_upi \000event=0x21\000\00001\000Cycles in L1 : Number of UPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a UPI link.  Use edge detect to count the number of instances when the UPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000"
/* offset=6090695 */ "unc_upi_m3_byp_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x14,umask=0x8\000\00001\000\000"
/* offset=6090833 */ "unc_upi_m3_byp_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x14,umask=0x1\000\00001\000\000"
/* offset=6090989 */ "unc_upi_m3_byp_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x14,umask=0x4\000\00001\000\000"
/* offset=6091145 */ "unc_upi_m3_byp_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x14,umask=0x2\000\00001\000\000"
/* offset=6091301 */ "unc_upi_m3_byp_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x14,umask=0x10\000\00001\000\000"
/* offset=6091442 */ "unc_upi_m3_crd_return_blocked\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_CRD_RETURN_BLOCKED. Unit: uncore_upi \000event=0x16\000\00001\000\000"
/* offset=6091568 */ "unc_upi_m3_rxq_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x15,umask=0x20\000\00001\000\000"
/* offset=6091707 */ "unc_upi_m3_rxq_blocked.flowq_ad_vna_btw_2_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_BTW_2_THRESH. Unit: uncore_upi \000event=0x15,umask=0x2\000\00001\000\000"
/* offset=6091881 */ "unc_upi_m3_rxq_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x15,umask=0x1\000\00001\000\000"
/* offset=6092037 */ "unc_upi_m3_rxq_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x15,umask=0x10\000\00001\000\000"
/* offset=6092194 */ "unc_upi_m3_rxq_blocked.flowq_bl_vna_btw_0_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_BTW_0_THRESH. Unit: uncore_upi \000event=0x15,umask=0x8\000\00001\000\000"
/* offset=6092368 */ "unc_upi_m3_rxq_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x15,umask=0x4\000\00001\000\000"
/* offset=6092524 */ "unc_upi_m3_rxq_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x15,umask=0x40\000\00001\000\000"
/* offset=6092665 */ "unc_upi_phy_init_cycles\000uncore_upi\000uncore interconnect\000Cycles where phy is not in L0, L0c, L0p, L1. Unit: uncore_upi \000event=0x20\000\00001\000\000"
/* offset=6092799 */ "unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000"
/* offset=6093557 */ "unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000L1 Req Nack : Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000"
/* offset=6094329 */ "unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000"
/* offset=6095094 */ "unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000L1 Req (same as L1 Ack). : Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000"
/* offset=6095886 */ "unc_upi_req_slot2_from_m3.ack\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.ACK. Unit: uncore_upi \000event=0x46,umask=0x8\000\00001\000\000"
/* offset=6096022 */ "unc_upi_req_slot2_from_m3.vn0\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN0. Unit: uncore_upi \000event=0x46,umask=0x2\000\00001\000\000"
/* offset=6096158 */ "unc_upi_req_slot2_from_m3.vn1\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN1. Unit: uncore_upi \000event=0x46,umask=0x4\000\00001\000\000"
/* offset=6096294 */ "unc_upi_req_slot2_from_m3.vna\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VNA. Unit: uncore_upi \000event=0x46,umask=0x1\000\00001\000\000"
/* offset=6096430 */ "unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Receive side. Unit: uncore_upi \000event=0x24\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=6096998 */ "unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x24\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=6097567 */ "unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x25\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000"
/* offset=6098255 */ "unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles the Rx of the Intel(R) UPI is in L0p power mode. Unit: uncore_upi \000event=0x25\000\00001\000Counts cycles when the receive side (Rx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000"
/* offset=6098611 */ "unc_upi_rxl_any_flits.data\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.DATA. Unit: uncore_upi \000event=0x4b,umask=0x8\000\00001\000\000"
/* offset=6098741 */ "unc_upi_rxl_any_flits.llcrd\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.LLCRD. Unit: uncore_upi \000event=0x4b,umask=0x10\000\00001\000\000"
/* offset=6098874 */ "unc_upi_rxl_any_flits.llctrl\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.LLCTRL. Unit: uncore_upi \000event=0x4b,umask=0x40\000\00001\000\000"
/* offset=6099009 */ "unc_upi_rxl_any_flits.null\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.NULL. Unit: uncore_upi \000event=0x4b,umask=0x20\000\00001\000\000"
/* offset=6099140 */ "unc_upi_rxl_any_flits.prothdr\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.PROTHDR. Unit: uncore_upi \000event=0x4b,umask=0x80\000\00001\000\000"
/* offset=6099277 */ "unc_upi_rxl_any_flits.slot0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT0. Unit: uncore_upi \000event=0x4b,umask=0x1\000\00001\000\000"
/* offset=6099409 */ "unc_upi_rxl_any_flits.slot1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT1. Unit: uncore_upi \000event=0x4b,umask=0x2\000\00001\000\000"
/* offset=6099541 */ "unc_upi_rxl_any_flits.slot2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT2. Unit: uncore_upi \000event=0x4b,umask=0x4\000\00001\000\000"
/* offset=6099673 */ "unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6100380 */ "unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Match Message Class - NCB\000"
/* offset=6100571 */ "unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6101312 */ "unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Match Message Class - NCB\000"
/* offset=6101509 */ "unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6102220 */ "unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Match Message Class - NCS\000"
/* offset=6102413 */ "unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6103158 */ "unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Match Message Class - NCS\000"
/* offset=6103357 */ "unc_upi_rxl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Request. Unit: uncore_upi \000event=0x5,umask=0x8\000\00001\000Matches on Receive path of a UPI Port : Request : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6104040 */ "unc_upi_rxl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request. Unit: uncore_upi \000event=0x5,umask=0x8\000\00001\000REQ Message Class\000"
/* offset=6104211 */ "unc_upi_rxl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Request, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x108\000\00001\000Matches on Receive path of a UPI Port : Request, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6104928 */ "unc_upi_rxl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x5,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000"
/* offset=6105138 */ "unc_upi_rxl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Data. Unit: uncore_upi \000event=0x5,umask=0xc\000\00001\000Matches on Receive path of a UPI Port : Response - Data : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6105842 */ "unc_upi_rxl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0xc\000\00001\000Match Message Class -WB\000"
/* offset=6106032 */ "unc_upi_rxl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Data, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10c\000\00001\000Matches on Receive path of a UPI Port : Response - Data, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6106770 */ "unc_upi_rxl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0x10c\000\00001\000Match Message Class -WB\000"
/* offset=6106966 */ "unc_upi_rxl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - No Data. Unit: uncore_upi \000event=0x5,umask=0xa\000\00001\000Matches on Receive path of a UPI Port : Response - No Data : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6107678 */ "unc_upi_rxl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0xa\000\00001\000Match Message Class - RSP\000"
/* offset=6107875 */ "unc_upi_rxl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - No Data, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10a\000\00001\000Matches on Receive path of a UPI Port : Response - No Data, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6108621 */ "unc_upi_rxl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0x10a\000\00001\000Match Message Class - RSP\000"
/* offset=6108824 */ "unc_upi_rxl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Conflict. Unit: uncore_upi \000event=0x5,umask=0x1aa\000\00001\000Matches on Receive path of a UPI Port : Response - Conflict : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6109538 */ "unc_upi_rxl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x5,umask=0x1aa\000\00001\000\000"
/* offset=6109711 */ "unc_upi_rxl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Invalid. Unit: uncore_upi \000event=0x5,umask=0x12a\000\00001\000Matches on Receive path of a UPI Port : Response - Invalid : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6110419 */ "unc_upi_rxl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x5,umask=0x12a\000\00001\000\000"
/* offset=6110587 */ "unc_upi_rxl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Snoop. Unit: uncore_upi \000event=0x5,umask=0x9\000\00001\000Matches on Receive path of a UPI Port : Snoop : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6111266 */ "unc_upi_rxl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x5,umask=0x9\000\00001\000SNP Message Class\000"
/* offset=6111435 */ "unc_upi_rxl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Snoop, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x109\000\00001\000Matches on Receive path of a UPI Port : Snoop, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6112148 */ "unc_upi_rxl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x5,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000"
/* offset=6112356 */ "unc_upi_rxl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Writeback. Unit: uncore_upi \000event=0x5,umask=0xd\000\00001\000Matches on Receive path of a UPI Port : Writeback : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6113042 */ "unc_upi_rxl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0xd\000\00001\000Match Message Class -WB\000"
/* offset=6113220 */ "unc_upi_rxl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Writeback, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10d\000\00001\000Matches on Receive path of a UPI Port : Writeback, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6113940 */ "unc_upi_rxl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0x10d\000\00001\000Match Message Class -WB\000"
/* offset=6114124 */ "unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot0 RxQ buffer (Receive Queue) and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6114649 */ "unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 0. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000RxQ Flit Buffer Bypassed : Slot 0 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6115197 */ "unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot1 RxQ buffer  (Receive Queue) and passed directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6115744 */ "unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 1. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000RxQ Flit Buffer Bypassed : Slot 1 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6116292 */ "unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot2 RxQ buffer (Receive Queue)  and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6116818 */ "unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 2. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000RxQ Flit Buffer Bypassed : Slot 2 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000"
/* offset=6117366 */ "unc_upi_rxl_crc_errors\000uncore_upi\000uncore interconnect\000CRC Errors Detected. Unit: uncore_upi \000event=0xb\000\00001\000CRC Errors Detected : Number of CRC errors detected in the UPI Agent.  Each UPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the UPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000"
/* offset=6117839 */ "unc_upi_rxl_crc_errors\000uncore_upi\000uncore interconnect\000CRC Errors Detected. Unit: uncore_upi \000event=0xb\000\00001\000Number of CRC errors detected in the UPI Agent.  Each UPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the UPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000"
/* offset=6118290 */ "unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000LLR Requests Sent : Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs.\000"
/* offset=6118668 */ "unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000LLR Requests Sent : Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs\000"
/* offset=6119045 */ "unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs\000"
/* offset=6119402 */ "unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6119714 */ "unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000VN0 Credit Consumed : Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6120048 */ "unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6120360 */ "unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000VN1 Credit Consumed : Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6120694 */ "unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6121044 */ "unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6121356 */ "unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38\000\00001\000VNA Credit Consumed : Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000"
/* offset=6121690 */ "unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Data. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Valid Flits Received : All Data : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6121909 */ "unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Counts valid data FLITs  (80 bit FLow control unITs: 64bits of data) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000"
/* offset=6122222 */ "unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000"
/* offset=6122507 */ "unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000\000"
/* offset=6122644 */ "unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Valid Flits Received : Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000Valid Flits Received : Null FLITs received from any slot : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6122914 */ "unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received : Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Valid Flits Received : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000"
/* offset=6123287 */ "unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received; Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000"
/* offset=6123628 */ "unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received : Idle. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Valid Flits Received : Idle : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6123836 */ "unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received : Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Valid Flits Received : Null FLITs received from any slot : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6124102 */ "unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received; Idle. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6124279 */ "unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Valid Flits Received : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000"
/* offset=6124630 */ "unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000"
/* offset=6124938 */ "unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Valid Flits Received : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000"
/* offset=6125229 */ "unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000"
/* offset=6125486 */ "unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Counts protocol header and credit FLITs  (80 bit FLow control unITs) received from any of the 3 UPI slots on this UPI unit\000"
/* offset=6125767 */ "unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Non Data. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Valid Flits Received : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6125995 */ "unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x3,umask=0x20\000\00011\000\000"
/* offset=6126166 */ "unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x3,umask=0x20\000\00001\000Valid Flits Received : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000"
/* offset=6126547 */ "unc_upi_rxl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x3,umask=0x80\000\00011\000\000"
/* offset=6126721 */ "unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received : Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Valid Flits Received : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000"
/* offset=6127036 */ "unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received; Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000"
/* offset=6127308 */ "unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Valid Flits Received : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000"
/* offset=6127590 */ "unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000"
/* offset=6127838 */ "unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Valid Flits Received : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000"
/* offset=6128120 */ "unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000"
/* offset=6128368 */ "unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Valid Flits Received : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000"
/* offset=6128650 */ "unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000"
/* offset=6128898 */ "unc_upi_rxl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x5,umask=0xc\000\00011\000\000"
/* offset=6129076 */ "unc_upi_rxl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x5,umask=0xd\000\00011\000\000"
/* offset=6129254 */ "unc_upi_rxl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x5,umask=0x8\000\00011\000\000"
/* offset=6129432 */ "unc_upi_rxl_hdr_match.rsp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x5,umask=0xa\000\00011\000\000"
/* offset=6129615 */ "unc_upi_rxl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x5,umask=0x9\000\00011\000\000"
/* offset=6129793 */ "unc_upi_rxl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x5,umask=0xb\000\00011\000\000"
/* offset=6129969 */ "unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000RxQ Flit Buffer Allocations : Slot 0 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6130575 */ "unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6131141 */ "unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000RxQ Flit Buffer Allocations : Slot 1 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6131747 */ "unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6132313 */ "unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000RxQ Flit Buffer Allocations : Slot 2 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6132919 */ "unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6133485 */ "unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000RxQ Occupancy - All Packets : Slot 0 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6134152 */ "unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6134779 */ "unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000RxQ Occupancy - All Packets : Slot 1 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6135446 */ "unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6136073 */ "unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000RxQ Occupancy - All Packets : Slot 2 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6136740 */ "unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000"
/* offset=6137367 */ "unc_upi_rxl_slot_bypass.s0_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x1\000\00001\000\000"
/* offset=6137507 */ "unc_upi_rxl_slot_bypass.s0_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x2\000\00001\000\000"
/* offset=6137647 */ "unc_upi_rxl_slot_bypass.s1_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x4\000\00001\000\000"
/* offset=6137787 */ "unc_upi_rxl_slot_bypass.s1_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x8\000\00001\000\000"
/* offset=6137927 */ "unc_upi_rxl_slot_bypass.s2_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x10\000\00001\000\000"
/* offset=6138068 */ "unc_upi_rxl_slot_bypass.s2_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x20\000\00001\000\000"
/* offset=6138209 */ "unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Transmit side. Unit: uncore_upi \000event=0x26\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=6138778 */ "unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x26\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000"
/* offset=6139347 */ "unc_upi_txl0p_clk_active.cfg_ctl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.CFG_CTL. Unit: uncore_upi \000event=0x2a,umask=0x1\000\00001\000\000"
/* offset=6139489 */ "unc_upi_txl0p_clk_active.dfx\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.DFX. Unit: uncore_upi \000event=0x2a,umask=0x40\000\00001\000\000"
/* offset=6139624 */ "unc_upi_txl0p_clk_active.retry\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RETRY. Unit: uncore_upi \000event=0x2a,umask=0x20\000\00001\000\000"
/* offset=6139763 */ "unc_upi_txl0p_clk_active.rxq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ. Unit: uncore_upi \000event=0x2a,umask=0x2\000\00001\000\000"
/* offset=6139897 */ "unc_upi_txl0p_clk_active.rxq_bypass\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_BYPASS. Unit: uncore_upi \000event=0x2a,umask=0x4\000\00001\000\000"
/* offset=6140045 */ "unc_upi_txl0p_clk_active.rxq_cred\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_CRED. Unit: uncore_upi \000event=0x2a,umask=0x8\000\00001\000\000"
/* offset=6140189 */ "unc_upi_txl0p_clk_active.spare\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.SPARE. Unit: uncore_upi \000event=0x2a,umask=0x80\000\00001\000\000"
/* offset=6140328 */ "unc_upi_txl0p_clk_active.txq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.TXQ. Unit: uncore_upi \000event=0x2a,umask=0x10\000\00001\000\000"
/* offset=6140463 */ "unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x27\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000"
/* offset=6141151 */ "unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in which the Tx of the Intel(R) Ultra Path Interconnect (UPI) is in L0p power mode. Unit: uncore_upi \000event=0x27\000\00001\000Counts cycles when the transmit side (Tx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000"
/* offset=6141543 */ "unc_upi_txl0p_power_cycles_ll_enter\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_LL_ENTER. Unit: uncore_upi \000event=0x28\000\00001\000\000"
/* offset=6141681 */ "unc_upi_txl0p_power_cycles_m3_exit\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_M3_EXIT. Unit: uncore_upi \000event=0x29\000\00001\000\000"
/* offset=6141817 */ "unc_upi_txl_any_flits.data\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.DATA. Unit: uncore_upi \000event=0x4a,umask=0x8\000\00001\000\000"
/* offset=6141947 */ "unc_upi_txl_any_flits.llcrd\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.LLCRD. Unit: uncore_upi \000event=0x4a,umask=0x10\000\00001\000\000"
/* offset=6142080 */ "unc_upi_txl_any_flits.llctrl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.LLCTRL. Unit: uncore_upi \000event=0x4a,umask=0x40\000\00001\000\000"
/* offset=6142215 */ "unc_upi_txl_any_flits.null\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.NULL. Unit: uncore_upi \000event=0x4a,umask=0x20\000\00001\000\000"
/* offset=6142346 */ "unc_upi_txl_any_flits.prothdr\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.PROTHDR. Unit: uncore_upi \000event=0x4a,umask=0x80\000\00001\000\000"
/* offset=6142483 */ "unc_upi_txl_any_flits.slot0\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT0. Unit: uncore_upi \000event=0x4a,umask=0x1\000\00001\000\000"
/* offset=6142615 */ "unc_upi_txl_any_flits.slot1\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT1. Unit: uncore_upi \000event=0x4a,umask=0x2\000\00001\000\000"
/* offset=6142747 */ "unc_upi_txl_any_flits.slot2\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT2. Unit: uncore_upi \000event=0x4a,umask=0x4\000\00001\000\000"
/* offset=6142879 */ "unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6143589 */ "unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Match Message Class - NCB\000"
/* offset=6143781 */ "unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6144525 */ "unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Match Message Class - NCB\000"
/* offset=6144723 */ "unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6145437 */ "unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Match Message Class - NCS\000"
/* offset=6145631 */ "unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6146379 */ "unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Match Message Class - NCS\000"
/* offset=6146579 */ "unc_upi_txl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Request. Unit: uncore_upi \000event=0x4,umask=0x8\000\00001\000Matches on Transmit path of a UPI Port : Request : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6147265 */ "unc_upi_txl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request. Unit: uncore_upi \000event=0x4,umask=0x8\000\00001\000REQ Message Class\000"
/* offset=6147437 */ "unc_upi_txl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Request, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x108\000\00001\000Matches on Transmit path of a UPI Port : Request, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6148157 */ "unc_upi_txl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x4,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000"
/* offset=6148368 */ "unc_upi_txl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Data. Unit: uncore_upi \000event=0x4,umask=0xc\000\00001\000Matches on Transmit path of a UPI Port : Response - Data : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6149075 */ "unc_upi_txl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0xc\000\00001\000Match Message Class -WB\000"
/* offset=6149266 */ "unc_upi_txl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Data, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10c\000\00001\000Matches on Transmit path of a UPI Port : Response - Data, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6150007 */ "unc_upi_txl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0x10c\000\00001\000Match Message Class -WB\000"
/* offset=6150204 */ "unc_upi_txl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - No Data. Unit: uncore_upi \000event=0x4,umask=0xa\000\00001\000Matches on Transmit path of a UPI Port : Response - No Data : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6150919 */ "unc_upi_txl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0xa\000\00001\000Match Message Class - RSP\000"
/* offset=6151117 */ "unc_upi_txl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - No Data, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10a\000\00001\000Matches on Transmit path of a UPI Port : Response - No Data, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6151866 */ "unc_upi_txl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0x10a\000\00001\000Match Message Class - RSP\000"
/* offset=6152070 */ "unc_upi_txl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Conflict. Unit: uncore_upi \000event=0x4,umask=0x1aa\000\00001\000Matches on Transmit path of a UPI Port : Response - Conflict : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6152787 */ "unc_upi_txl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x4,umask=0x1aa\000\00001\000\000"
/* offset=6152961 */ "unc_upi_txl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Invalid. Unit: uncore_upi \000event=0x4,umask=0x12a\000\00001\000Matches on Transmit path of a UPI Port : Response - Invalid : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6153672 */ "unc_upi_txl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x4,umask=0x12a\000\00001\000\000"
/* offset=6153841 */ "unc_upi_txl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Snoop. Unit: uncore_upi \000event=0x4,umask=0x9\000\00001\000Matches on Transmit path of a UPI Port : Snoop : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6154523 */ "unc_upi_txl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x4,umask=0x9\000\00001\000SNP Message Class\000"
/* offset=6154693 */ "unc_upi_txl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Snoop, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x109\000\00001\000Matches on Transmit path of a UPI Port : Snoop, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6155409 */ "unc_upi_txl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x4,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000"
/* offset=6155618 */ "unc_upi_txl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Writeback. Unit: uncore_upi \000event=0x4,umask=0xd\000\00001\000Matches on Transmit path of a UPI Port : Writeback : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6156307 */ "unc_upi_txl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0xd\000\00001\000Match Message Class -WB\000"
/* offset=6156486 */ "unc_upi_txl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Writeback, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10d\000\00001\000Matches on Transmit path of a UPI Port : Writeback, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000"
/* offset=6157209 */ "unc_upi_txl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0x10d\000\00001\000Match Message Class -WB\000"
/* offset=6157394 */ "unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000FLITs that bypassed the TxL Buffer. Unit: uncore_upi \000event=0x41\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the TxL(transmit) FLIT buffer and pass directly out the UPI Link. Generally, when data is transmitted across the Intel(R) Ultra Path Interconnect (UPI), it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used in L0p (Low Power) mode and (Link Layer Retry) LLR  mode, increasing latency to transfer out to the link\000"
/* offset=6157916 */ "unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_upi \000event=0x41\000\00001\000Tx Flit Buffer Bypassed : Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the UPI Link. Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000"
/* offset=6158385 */ "unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Data. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Valid Flits Sent : All Data : Counts number of data flits across this UPI link\000"
/* offset=6158593 */ "unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Data. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Valid Flits Sent : All Data : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6158804 */ "unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs transmitted via any slot. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000"
/* offset=6159112 */ "unc_upi_txl_flits.all_llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x17\000\00001\000Valid Flits Sent : All Data : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6159336 */ "unc_upi_txl_flits.all_llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Valid Flits Sent : All LLCTRL : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6159554 */ "unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000All Null Flits. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000\000"
/* offset=6159672 */ "unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs transmitted from any slot. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) transmitted via any of the 3 Intel(R) Ulra Path Interconnect (UPI) slots on this UPI unit\000"
/* offset=6159947 */ "unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Null FLITs transmitted to any slot. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000Valid Flits Sent : Null FLITs transmitted to any slot : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6160211 */ "unc_upi_txl_flits.all_prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x87\000\00001\000Valid Flits Sent : All ProtDDR : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6160440 */ "unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Valid Flits Sent : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000"
/* offset=6160805 */ "unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000"
/* offset=6161142 */ "unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Idle FLITs transmitted. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Counts when the Intel Ultra Path Interconnect(UPI) transmits an idle FLIT(80 bit FLow control unITs).  Every UPI cycle must be sending either data FLITs, protocol/credit FLITs or idle FLITs\000"
/* offset=6161453 */ "unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Idle. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Valid Flits Sent : Idle : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6161653 */ "unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Valid Flits Sent : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000"
/* offset=6161996 */ "unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000"
/* offset=6162300 */ "unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Valid Flits Sent : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000"
/* offset=6162583 */ "unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000"
/* offset=6162836 */ "unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs transmitted across any slot. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Counts protocol header and credit FLITs (80 bit FLow control unITs) transmitted across any of the 3 UPI (Ultra Path Interconnect) slots on this UPI unit\000"
/* offset=6163152 */ "unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Non Data. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Valid Flits Sent : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000"
/* offset=6163372 */ "unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x2,umask=0x20\000\00011\000\000"
/* offset=6163543 */ "unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x2,umask=0x20\000\00001\000Valid Flits Sent : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000"
/* offset=6163916 */ "unc_upi_txl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x2,umask=0x80\000\00011\000\000"
/* offset=6164090 */ "unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Valid Flits Sent : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000"
/* offset=6164397 */ "unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000"
/* offset=6164665 */ "unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Valid Flits Sent : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000"
/* offset=6164939 */ "unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000"
/* offset=6165183 */ "unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Valid Flits Sent : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000"
/* offset=6165457 */ "unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000"
/* offset=6165701 */ "unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Valid Flits Sent : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000"
/* offset=6165975 */ "unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000"
/* offset=6166219 */ "unc_upi_txl_hdr_match.data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6166340 */ "unc_upi_txl_hdr_match.dual_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6166466 */ "unc_upi_txl_hdr_match.loc\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6166582 */ "unc_upi_txl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x4,umask=0xe\000\00011\000\000"
/* offset=6166760 */ "unc_upi_txl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x4,umask=0xf\000\00011\000\000"
/* offset=6166938 */ "unc_upi_txl_hdr_match.non_data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6167063 */ "unc_upi_txl_hdr_match.rem\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6167179 */ "unc_upi_txl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x4,umask=0x8\000\00011\000\000"
/* offset=6167357 */ "unc_upi_txl_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000"
/* offset=6167545 */ "unc_upi_txl_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_NODATA. Unit: uncore_upi \000event=0x4,umask=0xa\000\00011\000\000"
/* offset=6167737 */ "unc_upi_txl_hdr_match.sgl_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000"
/* offset=6167862 */ "unc_upi_txl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x4,umask=0x9\000\00011\000\000"
/* offset=6168040 */ "unc_upi_txl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000"
/* offset=6168216 */ "unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6168722 */ "unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Tx Flit Buffer Allocations : Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000"
/* offset=6169257 */ "unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000"
/* offset=6169764 */ "unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Tx Flit Buffer Occupancy : Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000"
/* offset=6170298 */ "unc_upi_vna_credit_return_blocked_vn01\000uncore_upi\000uncore interconnect\000UNC_UPI_VNA_CREDIT_RETURN_BLOCKED_VN01. Unit: uncore_upi \000event=0x45\000\00001\000\000"
/* offset=6170442 */ "unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000"
/* offset=6170671 */ "unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000VNA Credits Pending Return - Occupancy : Number of VNA credits in the Rx side that are waitng to be returned back across the link\000"
/* offset=6170941 */ "uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\00000\000DDRC write commands\000"
/* offset=6171067 */ "uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\00000\000Total read hits\000"
/* offset=6171185 */ "uncore_iio\000LLC_MISSES.PCIE_READ\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3\000\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000"
/* offset=6171955 */ "uncore_iio\000LLC_MISSES.PCIE_READ\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3\000\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\0004Bytes\000\000\000\00000"
/* offset=6172569 */ "uncore_iio\000LLC_MISSES.PCIE_WRITE\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3\000\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000"
/* offset=6173345 */ "uncore_iio\000LLC_MISSES.PCIE_WRITE\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3\000\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\0004Bytes\000\000\000\00000"
/* offset=6173963 */ "uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\00000\000Total cache hits\000"
/* offset=6174071 */ "uncore_imc\000UNC_M_PMM_BANDWIDTH.TOTAL\000\000UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS\000\000Intel Optane DC persistent memory bandwidth total (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000\0006.103515625E-5MB/sec\000\000\000\00000"
/* offset=6174297 */ "uncore_imc\000UNC_M_PMM_READ_LATENCY\000\000UNC_M_PMM_RPQ_OCCUPANCY.ALL / UNC_M_PMM_RPQ_INSERTS / UNC_M_CLOCKTICKS\000\000Intel Optane DC persistent memory read latency (ns). Derived from unc_m_pmm_rpq_occupancy.all. Unit: uncore_imc \000\0006000000000ns\000\000\000\00000"
/* offset=6174536 */ "uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode+C37. Unit: uncore_imc \000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000\000\000\000\00000"
/* offset=6175012 */ "uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000\000\000\000\00000"
/* offset=6175437 */ "uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000\000\000\000\00000"
/* offset=6175909 */ "uncore_imc\000power_self_refresh\000\000UNC_M_POWER_SELF_REFRESH / UNC_M_CLOCKTICKS * 100\000\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000\000\000\000\00000"
/* offset=6176517 */ "uncore_imc\000power_self_refresh\000\000UNC_M_POWER_SELF_REFRESH / UNC_M_CLOCKTICKS * 100\000\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000\000\000\000\00000"
/* offset=6177164 */ "uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\00000\000Total cache misses\000"
/* offset=6177315 */ "uop_dispatches_cancelled.simd_prf\000\000floating point\000Micro-op dispatches cancelled due to insufficient SIMD physical register file read ports\000event=0xa0,period=2000003,umask=0x3\000\00000\000This event counts the number of micro-operations cancelled after they were dispatched from the scheduler to the execution units when the total number of physical register read ports across all dispatch ports exceeds the read bandwidth of the physical register file.  The SIMD_PRF subevent applies to the following instructions: VDPPS, DPPS, VPCMPESTRI, PCMPESTRI, VPCMPESTRM, PCMPESTRM, VFMADD*, VFMADDSUB*, VFMSUB*, VMSUBADD*, VFNMADD*, VFNMSUB*.  See the Broadwell Optimization Guide for more information\000"
/* offset=6178001 */ "uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6178100 */ "uops.ms_cycles\000\000frontend\000This event counts the cycles where 1 or more uops are issued by the micro-sequencer (MS), including microcode assists and inserted flows, and written to the IQ\000event=0xa9,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6178334 */ "uops_decoded.dec0\000\000pipeline\000Number of uops decoded out of instructions exclusively fetched by decoder 0\000event=0x56,period=1000003,umask=0x1\000\00000\000Uops exclusively fetched by decoder 0\000"
/* offset=6178516 */ "uops_decoded.dec0_uops\000\000pipeline\000UOPS_DECODED.DEC0_UOPS\000event=0x76,period=1000003,umask=0x1\000\00000\000\000"
/* offset=6178613 */ "uops_decoded.dec0_uops\000cpu_core\000pipeline\000Number of non dec-by-all uops decoded by decoder. Unit: cpu_core \000event=0x76,period=1000003,umask=0x1\000\00000\000This event counts the number of not dec-by-all uops decoded by decoder 0\000"
/* offset=6178833 */ "uops_decoded.dec0_uops\000cpu_core\000pipeline\000UOPS_DECODED.DEC0_UOPS. Unit: cpu_core \000event=0x76,period=1000003,umask=0x1\000\00000\000\000"
/* offset=6178955 */ "uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000"
/* offset=6179066 */ "uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000"
/* offset=6179169 */ "uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000"
/* offset=6179294 */ "uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6179412 */ "uops_dispatched.core\000\000pipeline\000Uops dispatched from any thread\000event=0xb1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6179516 */ "uops_dispatched.port_0\000\000pipeline\000Number of uops executed on port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000"
/* offset=6179751 */ "uops_dispatched.port_0\000\000pipeline\000Uops executed on port 0\000event=0xb2,period=2000003,umask=0x1\000\00000\000Number of uops dispatch to execution  port 0\000"
/* offset=6179893 */ "uops_dispatched.port_0\000cpu_core\000pipeline\000Uops executed on port 0. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x1\000\00000\000Number of uops dispatch to execution  port 0\000"
/* offset=6180060 */ "uops_dispatched.port_1\000\000pipeline\000Number of uops executed on port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000"
/* offset=6180295 */ "uops_dispatched.port_1\000\000pipeline\000Uops executed on port 1\000event=0xb2,period=2000003,umask=0x2\000\00000\000Number of uops dispatch to execution  port 1\000"
/* offset=6180437 */ "uops_dispatched.port_1\000cpu_core\000pipeline\000Uops executed on port 1. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x2\000\00000\000Number of uops dispatch to execution  port 1\000"
/* offset=6180604 */ "uops_dispatched.port_2_3\000\000pipeline\000Number of uops executed on port 2 and 3\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 2 and 3\000"
/* offset=6180854 */ "uops_dispatched.port_2_3_10\000\000pipeline\000Uops executed on ports 2, 3 and 10\000event=0xb2,period=2000003,umask=0x4\000\00000\000Number of uops dispatch to execution ports 2, 3 and 10\000"
/* offset=6181022 */ "uops_dispatched.port_2_3_10\000cpu_core\000pipeline\000Uops executed on ports 2, 3 and 10. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x4\000\00000\000Number of uops dispatch to execution ports 2, 3 and 10\000"
/* offset=6181215 */ "uops_dispatched.port_4_9\000\000pipeline\000Number of uops executed on port 4 and 9\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 5 and 9\000"
/* offset=6181466 */ "uops_dispatched.port_4_9\000\000pipeline\000Uops executed on ports 4 and 9\000event=0xb2,period=2000003,umask=0x10\000\00000\000Number of uops dispatch to execution ports 4 and 9\000"
/* offset=6181624 */ "uops_dispatched.port_4_9\000cpu_core\000pipeline\000Uops executed on ports 4 and 9. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x10\000\00000\000Number of uops dispatch to execution ports 4 and 9\000"
/* offset=6181807 */ "uops_dispatched.port_5\000\000pipeline\000Number of uops executed on port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000"
/* offset=6182043 */ "uops_dispatched.port_5_11\000\000pipeline\000Uops executed on ports 5 and 11\000event=0xb2,period=2000003,umask=0x20\000\00000\000Number of uops dispatch to execution ports 5 and 11\000"
/* offset=6182204 */ "uops_dispatched.port_5_11\000cpu_core\000pipeline\000Uops executed on ports 5 and 11. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x20\000\00000\000Number of uops dispatch to execution ports 5 and 11\000"
/* offset=6182390 */ "uops_dispatched.port_6\000\000pipeline\000Number of uops executed on port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000"
/* offset=6182626 */ "uops_dispatched.port_6\000\000pipeline\000Uops executed on port 6\000event=0xb2,period=2000003,umask=0x40\000\00000\000Number of uops dispatch to execution  port 6\000"
/* offset=6182769 */ "uops_dispatched.port_6\000cpu_core\000pipeline\000Uops executed on port 6. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x40\000\00000\000Number of uops dispatch to execution  port 6\000"
/* offset=6182937 */ "uops_dispatched.port_7_8\000\000pipeline\000Number of uops executed on port 7 and 8\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 7 and 8\000"
/* offset=6183188 */ "uops_dispatched.port_7_8\000\000pipeline\000Uops executed on ports 7 and 8\000event=0xb2,period=2000003,umask=0x80\000\00000\000Number of uops dispatch to execution  ports 7 and 8\000"
/* offset=6183347 */ "uops_dispatched.port_7_8\000cpu_core\000pipeline\000Uops executed on ports 7 and 8. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x80\000\00000\000Number of uops dispatch to execution  ports 7 and 8\000"
/* offset=6183531 */ "uops_dispatched.thread\000\000pipeline\000Uops dispatched per thread\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6183632 */ "uops_dispatched\000\000recommended\000Micro-ops Dispatched\000event=0xaa,umask=0x03\000\00000\000\000"
/* offset=6183709 */ "uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a Uop is dispatched on port 0\000"
/* offset=6183883 */ "uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6184015 */ "uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000"
/* offset=6184272 */ "uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000"
/* offset=6184529 */ "uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6184659 */ "uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000Cycles per core when uops are dispatched to port 0\000"
/* offset=6184850 */ "uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6184991 */ "uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a Uop is dispatched on port 1\000"
/* offset=6185165 */ "uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6185297 */ "uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000"
/* offset=6185554 */ "uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000"
/* offset=6185811 */ "uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6185941 */ "uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000Cycles per core when uops are dispatched to port 1\000"
/* offset=6186132 */ "uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6186273 */ "uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000Cycles which a Uop is dispatched on port 2\000"
/* offset=6186459 */ "uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000\000"
/* offset=6186603 */ "uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 2\000"
/* offset=6186860 */ "uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000"
/* offset=6187117 */ "uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000\000"
/* offset=6187247 */ "uops_dispatched_port.port_2_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000"
/* offset=6187400 */ "uops_dispatched_port.port_2_core\000\000pipeline\000Uops dispatched to port 2, loads and stores per core (speculative and retired)\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000"
/* offset=6187569 */ "uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000Cycles which a Uop is dispatched on port 3\000"
/* offset=6187756 */ "uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000\000"
/* offset=6187901 */ "uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 3\000"
/* offset=6188158 */ "uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000"
/* offset=6188415 */ "uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000\000"
/* offset=6188545 */ "uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000Cycles per core when load or STA uops are dispatched to port 3\000"
/* offset=6188761 */ "uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000\000"
/* offset=6188915 */ "uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a Uop is dispatched on port 4\000"
/* offset=6189090 */ "uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=6189223 */ "uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 4\000"
/* offset=6189481 */ "uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000"
/* offset=6189739 */ "uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000\000"
/* offset=6189870 */ "uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000Cycles per core when uops are dispatched to port 4\000"
/* offset=6190062 */ "uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=6190204 */ "uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a Uop is dispatched on port 5\000"
/* offset=6190379 */ "uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000"
/* offset=6190512 */ "uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000"
/* offset=6190770 */ "uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000"
/* offset=6191028 */ "uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000\000"
/* offset=6191159 */ "uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000Cycles per core when uops are dispatched to port 5\000"
/* offset=6191351 */ "uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000"
/* offset=6191493 */ "uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000"
/* offset=6191751 */ "uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000"
/* offset=6192009 */ "uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=6192140 */ "uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 7\000"
/* offset=6192398 */ "uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000"
/* offset=6192656 */ "uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000"
/* offset=6192787 */ "uops_executed.core\000\000pipeline\000Number of uops executed on the core  Spec update: HSD30, HSM31\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle  Spec update: HSD30, HSM31\000"
/* offset=6193009 */ "uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000"
/* offset=6193165 */ "uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle\000"
/* offset=6193333 */ "uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000"
/* offset=6193478 */ "uops_executed.core\000cpu_core\000pipeline\000Number of uops executed on the core. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000"
/* offset=6193659 */ "uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000"
/* offset=6193804 */ "uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000"
/* offset=6193959 */ "uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6194148 */ "uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000"
/* offset=6194393 */ "uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles at least 1 micro-op is executed from any thread on physical core\000"
/* offset=6194626 */ "uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6194788 */ "uops_executed.core_cycles_ge_1\000cpu_core\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000"
/* offset=6195058 */ "uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6195247 */ "uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000"
/* offset=6195494 */ "uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles at least 2 micro-op is executed from any thread on physical core\000"
/* offset=6195727 */ "uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6195889 */ "uops_executed.core_cycles_ge_2\000cpu_core\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000"
/* offset=6196161 */ "uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6196350 */ "uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000"
/* offset=6196597 */ "uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Cycles at least 3 micro-op is executed from any thread on physical core\000"
/* offset=6196830 */ "uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6196992 */ "uops_executed.core_cycles_ge_3\000cpu_core\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000"
/* offset=6197264 */ "uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6197453 */ "uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000"
/* offset=6197700 */ "uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Cycles at least 4 micro-op is executed from any thread on physical core\000"
/* offset=6197933 */ "uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6198095 */ "uops_executed.core_cycles_ge_4\000cpu_core\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000"
/* offset=6198367 */ "uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6198549 */ "uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6198712 */ "uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000Cycles with no micro-ops executed from any thread on physical core\000"
/* offset=6198933 */ "uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6199088 */ "uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000"
/* offset=6199237 */ "uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000"
/* offset=6199380 */ "uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000"
/* offset=6199539 */ "uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000"
/* offset=6199692 */ "uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000"
/* offset=6199843 */ "uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000"
/* offset=6200004 */ "uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000"
/* offset=6200192 */ "uops_executed.cycles_ge_1\000cpu_core\000pipeline\000Cycles where at least 1 uop was executed per-thread. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000"
/* offset=6200405 */ "uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least one uop was executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000"
/* offset=6200712 */ "uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000"
/* offset=6200909 */ "uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6201055 */ "uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000"
/* offset=6201247 */ "uops_executed.cycles_ge_2\000cpu_core\000pipeline\000Cycles where at least 2 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000"
/* offset=6201464 */ "uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least two uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000"
/* offset=6201775 */ "uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000"
/* offset=6201977 */ "uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6202126 */ "uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000"
/* offset=6202318 */ "uops_executed.cycles_ge_3\000cpu_core\000pipeline\000Cycles where at least 3 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000"
/* offset=6202535 */ "uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least three uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000"
/* offset=6202848 */ "uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000"
/* offset=6203050 */ "uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6203199 */ "uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000"
/* offset=6203391 */ "uops_executed.cycles_ge_4\000cpu_core\000pipeline\000Cycles where at least 4 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000"
/* offset=6203608 */ "uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6203792 */ "uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000"
/* offset=6203994 */ "uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6204143 */ "uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000"
/* offset=6204248 */ "uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000"
/* offset=6204390 */ "uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6204485 */ "uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000"
/* offset=6204580 */ "uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000"
/* offset=6204696 */ "uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000"
/* offset=6204815 */ "uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000"
/* offset=6204934 */ "uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000"
/* offset=6205054 */ "uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000"
/* offset=6205150 */ "uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6205355 */ "uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000"
/* offset=6205620 */ "uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000"
/* offset=6205896 */ "uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6206066 */ "uops_executed.stall_cycles\000\000pipeline\000This event is deprecated. Refer to new event UOPS_EXECUTED.STALLS\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00010\000\000"
/* offset=6206224 */ "uops_executed.stall_cycles\000cpu_core\000pipeline\000This event is deprecated. Refer to new event UOPS_EXECUTED.STALLS. Unit: cpu_core \000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00010\000\000"
/* offset=6206407 */ "uops_executed.stalls\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000"
/* offset=6206666 */ "uops_executed.stalls\000cpu_core\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread. Unit: cpu_core \000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000"
/* offset=6206950 */ "uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Counts total number of uops to be executed per-thread each cycle. Set Cmask = 1, INV =1 to count stall cycles\000"
/* offset=6207194 */ "uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000"
/* offset=6207380 */ "uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6207515 */ "uops_executed.thread\000cpu_core\000pipeline\000Counts the number of uops to be executed per-thread each cycle. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6207675 */ "uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000"
/* offset=6207824 */ "uops_executed.x87\000cpu_core\000pipeline\000Counts the number of x87 uops dispatched. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000"
/* offset=6207998 */ "uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a uop is dispatched on port 0 in this thread\000"
/* offset=6208183 */ "uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000"
/* offset=6208438 */ "uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6208575 */ "uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a uop is dispatched on port 1 in this thread\000"
/* offset=6208760 */ "uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000"
/* offset=6209015 */ "uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6209152 */ "uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Cycles which a uop is dispatched on port 2 in this thread\000"
/* offset=6209337 */ "uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000"
/* offset=6209592 */ "uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000"
/* offset=6209731 */ "uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Cycles which a uop is dispatched on port 3 in this thread\000"
/* offset=6209916 */ "uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000"
/* offset=6210171 */ "uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000"
/* offset=6210310 */ "uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Cycles which a uop is dispatched on port 4 in this thread\000"
/* offset=6210496 */ "uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000"
/* offset=6210752 */ "uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000"
/* offset=6210890 */ "uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Cycles which a uop is dispatched on port 5 in this thread\000"
/* offset=6211076 */ "uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000"
/* offset=6211332 */ "uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000"
/* offset=6211470 */ "uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a uop is dispatched on port 6 in this thread\000"
/* offset=6211656 */ "uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000"
/* offset=6211912 */ "uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000"
/* offset=6212050 */ "uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a uop is dispatched on port 7 in this thread\000"
/* offset=6212236 */ "uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000"
/* offset=6212492 */ "uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000"
/* offset=6212632 */ "uops_issued.any\000\000pipeline\000Counts the number of uops issued by the front end every cycle\000event=0xe,period=200003\000\00000\000Counts the number of uops issued by the front end every cycle. When 4-uops are requested and only 2-uops are delivered, the event counts 2.  Uops_issued correlates to the number of ROB entries.  If uop takes 2 ROB slots it counts as 2 uops_issued\000"
/* offset=6212995 */ "uops_issued.any\000\000pipeline\000Uops issued to the back end per cycle\000event=0xe,period=200003\000\00000\000Counts uops issued by the front end and allocated into the back end of the machine.  This event counts uops that retire as well as uops that were speculatively executed but didn't retire. The sort of speculative uops that might be counted includes, but is not limited to those uops issued in the shadow of a miss-predicted branch, those uops that are inserted during an assist (such as for a denormal floating point result), and (previously allocated) uops that might be canceled during a machine clear\000"
/* offset=6213590 */ "uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6213668 */ "uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xae,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000"
/* offset=6213867 */ "uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000"
/* offset=6214065 */ "uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000"
/* offset=6214313 */ "uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Increments each cycle the # of Uops issued by the RAT to RS. Set Cmask = 1, Inv = 1, Any= 1to count stalled cycles of this core\000"
/* offset=6214583 */ "uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS)\000"
/* offset=6214840 */ "uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the front-end of the pipeilne to the back-end\000"
/* offset=6215075 */ "uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of uops issued by the Front-end of the pipeline to the Back-end. This event is counted at the allocation stage and will count both retired and non-retired uops\000"
/* offset=6215406 */ "uops_issued.any\000cpu_atom\000pipeline\000Counts the number of uops issued by the front end every cycle. Unit: cpu_atom \000event=0xe,period=1000003\000\00000\000Counts the number of uops issued by the front end every cycle. When 4-uops are requested and only 2-uops are delivered, the event counts 2.  Uops_issued correlates to the number of ROB entries.  If uop takes 2 ROB slots it counts as 2 uops_issued\000"
/* offset=6215795 */ "uops_issued.any\000cpu_core\000pipeline\000Uops that RAT issues to RS. Unit: cpu_core \000event=0xae,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000"
/* offset=6216019 */ "uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6216160 */ "uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000"
/* offset=6216475 */ "uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6216683 */ "uops_issued.cycles\000cpu_core\000pipeline\000UOPS_ISSUED.CYCLES. Unit: cpu_core \000event=0xae,cmask=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6216805 */ "uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6216941 */ "uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops add delay\000"
/* offset=6217174 */ "uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops being allocated. Such uops considered perf sensitive\n added by GSR u-arch\000"
/* offset=6217450 */ "uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops adds delay\000"
/* offset=6217626 */ "uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000"
/* offset=6217712 */ "uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000Number of multiply packed/scalar single precision uops allocated\000"
/* offset=6217915 */ "uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000\000"
/* offset=6218054 */ "uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000"
/* offset=6218455 */ "uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (for example, 2 sources + immediate) regardless of whether it is a result of LEA instruction or not\000"
/* offset=6218875 */ "uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000"
/* offset=6219127 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6219243 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread\000event=0xe,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000"
/* offset=6219530 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000"
/* offset=6219867 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000"
/* offset=6220169 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000"
/* offset=6220517 */ "uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6220713 */ "uops_issued.stalls\000cpu_core\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread. Unit: cpu_core \000event=0xae,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000"
/* offset=6221020 */ "uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to 'Mixing Intel AVX and Intel SSE Code' section of the Optimization Guide\000"
/* offset=6221646 */ "uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000"
/* offset=6222270 */ "uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=2000003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000"
/* offset=6222895 */ "uops_not_delivered.any\000\000pipeline\000Uops requested but not-delivered to the back-end per cycle\000event=0x9c,period=200003\000\00000\000This event used to measure front-end inefficiencies. I.e. when front-end of the machine is not delivering uops to the back-end and the back-end has is not stalled. This event can be used to identify if the machine is truly front-end bound.  When this event occurs, it is an indication that the front-end of the machine is operating at less than its theoretical peak performance. Background: We can think of the processor pipeline as being divided into 2 broader parts: Front-end and Back-end. Front-end is responsible for fetching the instruction, decoding into uops in machine understandable format and putting them into a uop queue to be consumed by back end. The back-end then takes these uops, allocates the required resources.  When all resources are ready, uops are executed. If the back-end is not ready to accept uops from the front-end, then we do not want to count these as front-end bottlenecks.  However, whenever we have bottlenecks in the back-end, we will have allocation unit stalls and eventually forcing the front-end to wait until the back-end is ready to receive more uops. This event counts only when back-end is requesting more uops and front-end is not able to provide them. When 3 uops are requested and no uops are delivered, the event counts 3. When 3 are requested, and only 1 is delivered, the event counts 2. When only 2 are delivered, the event counts 1. Alternatively stated, the event will not count if 3 uops are delivered, or if the back end is stalled and not requesting any uops at all.  Counts indicate missed opportunities for the front-end to deliver a uop to the back end. Some examples of conditions that cause front-end efficiencies are: ICache misses, ITLB misses, and decoder restrictions that limit the front-end bandwidth. Known Issues: Some uops require multiple allocation slots.  These uops will not be charged as a front end 'not delivered' opportunity, and will be regarded as a back end problem. For example, the INC instruction has one uop that requires 2 issue slots.  A stream of INC instructions will not count as UOPS_NOT_DELIVERED, even though only one instruction can be issued per clock.  The low uop issue rate for a stream of INC instructions is considered to be a back end issue\000"
/* offset=6225258 */ "uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6225390 */ "uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of micro-ops retired. Use Cmask=1 and invert to count active cycles or stalled cycles (Precise event)\000"
/* offset=6225615 */ "uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts all actually retired uops. Counting increments by two for micro-fused uops, and by one for macro-fused and other uops. Maximal increment value for one cycle is eight (Precise event)\000"
/* offset=6225920 */ "uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired (Precise event)\000"
/* offset=6226091 */ "uops_retired.all\000\000pipeline\000Actually retired uops. (Precise Event - PEBS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired. (Precise Event) (Precise event)\000"
/* offset=6226303 */ "uops_retired.all\000\000pipeline\000Counts the number of micro-ops retired\000event=0xc2,period=2000003,umask=0x10\000\00000\000This event counts the number of micro-ops (uops) retired. The processor decodes complex macro instructions into a sequence of simpler uops. Most instructions are composed of one or two uops. Some instructions are decoded into longer sequences such as repeat instructions, floating point transcendental instructions, and assists\000"
/* offset=6226738 */ "uops_retired.all\000\000pipeline\000Counts the total number of uops retired (Precise event)\000event=0xc2,period=2000003\000\00000\000\000"
/* offset=6226852 */ "uops_retired.all\000\000pipeline\000Micro-ops retired\000event=0xc2,period=2000003,umask=0x10\000\00000\000This event counts the number of micro-ops retired. The processor decodes complex macro instructions into a sequence of simpler micro-ops. Most instructions are composed of one or two micro-ops. Some instructions are decoded into longer sequences such as repeat instructions, floating point transcendental instructions, and assists. In some cases micro-op sequences are fused or whole instructions are fused into one micro-op. See other UOPS_RETIRED events for differentiating retired fused and non-fused micro-ops\000"
/* offset=6227452 */ "uops_retired.all\000\000pipeline\000Retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6227549 */ "uops_retired.all\000cpu_atom\000pipeline\000Counts the total number of uops retired (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003\000\00000\000\000"
/* offset=6227688 */ "uops_retired.any\000\000pipeline\000Micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000"
/* offset=6227775 */ "uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6227872 */ "uops_retired.any\000\000pipeline\000Uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003\000\00000\000Counts uops which retired (Must be precise)\000"
/* offset=6228028 */ "uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6228167 */ "uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6228300 */ "uops_retired.cycles\000\000pipeline\000Cycles with retired uop(s)\000event=0xc2,cmask=1,period=1000003,umask=0x2\000\00000\000Counts cycles where at least one uop has retired\000"
/* offset=6228454 */ "uops_retired.cycles\000cpu_core\000pipeline\000Cycles with retired uop(s). Unit: cpu_core \000event=0xc2,cmask=1,period=1000003,umask=0x2\000\00000\000Counts cycles where at least one uop has retired\000"
/* offset=6228633 */ "uops_retired.fpdiv\000\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event)\000event=0xc2,period=2000003,umask=0x8\000\00000\000\000"
/* offset=6228815 */ "uops_retired.fpdiv\000\000floating point\000Floating point divide uops retired (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x8\000\00000\000Counts the number of floating point divide uops retired (Must be precise)\000"
/* offset=6229041 */ "uops_retired.fpdiv\000\000floating point\000Floating point divide uops retired. (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x8\000\00000\000Counts the number of floating point divide uops retired (Must be precise)\000"
/* offset=6229268 */ "uops_retired.fpdiv\000cpu_atom\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x8\000\00000\000\000"
/* offset=6229475 */ "uops_retired.fpdiv\000cpu_atom\000floating point\000Counts the number of floating point divide uops retired (x87 and sse, including x87 sqrt) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x8\000\00000\000\000"
/* offset=6229682 */ "uops_retired.heavy\000\000pipeline\000Retired uops except the last uop of each instruction\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of retired micro-operations (uops) except the last uop of each instruction. An instruction that is decoded into less than two uops does not contribute to the count\000"
/* offset=6229986 */ "uops_retired.heavy\000cpu_core\000pipeline\000Retired uops except the last uop of each instruction. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of retired micro-operations (uops) except the last uop of each instruction. An instruction that is decoded into less than two uops does not contribute to the count\000"
/* offset=6230315 */ "uops_retired.idiv\000\000pipeline\000Counts the number of integer divide uops retired (Precise event)\000event=0xc2,period=2000003,umask=0x10\000\00000\000\000"
/* offset=6230450 */ "uops_retired.idiv\000\000pipeline\000Integer divide uops retired (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x10\000\00000\000Counts the number of integer divide uops retired (Must be precise)\000"
/* offset=6230656 */ "uops_retired.idiv\000\000pipeline\000Integer divide uops retired. (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x10\000\00000\000Counts the number of integer divide uops retired (Must be precise)\000"
/* offset=6230863 */ "uops_retired.idiv\000cpu_atom\000pipeline\000Counts the number of integer divide uops retired (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x10\000\00000\000\000"
/* offset=6231023 */ "uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000"
/* offset=6231140 */ "uops_retired.macro_fused\000\000pipeline\000Number of macro-fused uops retired. (non precise)\000event=0xc2,period=2000003,umask=0x4\000\00000\000Counts the number of macro-fused uops retired. (non precise)\000"
/* offset=6231326 */ "uops_retired.ms\000\000pipeline\000Counts the number of micro-ops retired that are from the complex flows issued by the micro-sequencer (MS)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired that were supplied from MSROM\000"
/* offset=6231578 */ "uops_retired.ms\000\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000"
/* offset=6231954 */ "uops_retired.ms\000\000pipeline\000MS uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts uops retired that are from the complex flows issued by the micro-sequencer (MS).  Counts both the uops from a micro-coded instruction, and the uops that might be generated from a micro-coded assist (Must be precise)\000"
/* offset=6232301 */ "uops_retired.ms\000\000pipeline\000MSROM micro-ops retired\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired that were supplied from MSROM\000"
/* offset=6232471 */ "uops_retired.ms\000\000pipeline\000UOPS_RETIRED.MS\000event=0xc2,period=2000003,umask=0x4,frontend=0x8\000\00000\000\000"
/* offset=6232567 */ "uops_retired.ms\000cpu_atom\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000"
/* offset=6232968 */ "uops_retired.ms\000cpu_atom\000pipeline\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6233266 */ "uops_retired.ms\000cpu_core\000pipeline\000UOPS_RETIRED.MS. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x4,frontend=0x8\000\00000\000\000"
/* offset=6233387 */ "uops_retired.packed_simd\000\000floating point\000Counts the number of vector SSE, AVX, AVX2, AVX-512 micro-ops retired. More specifically, it counts packed SSE, AVX, AVX2, AVX-512 micro-ops (both floating point and integer) except for loads (memory-to-register mov-type micro-ops), packed byte and word multiplies\000event=0xc2,period=200003,umask=0x40\000\00000\000This event counts the number of packed vector SSE, AVX, AVX2, and AVX-512 micro-ops retired (floating point, integer and store) except for loads (memory-to-register mov-type micro-ops), packed byte and word multiplies\000"
/* offset=6233951 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000"
/* offset=6234066 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used (Precise event)\000"
/* offset=6234250 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 micro-ops or 4 instructions could retire each cycle.  This event is used in determining the 'Retiring' category of the Top-Down pipeline slots characterization (Precise event)\000"
/* offset=6234678 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 uops or 4 instructions could retire each cycle (Precise event)\000"
/* offset=6234993 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6235108 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used. (Precise Event - PEBS) (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 micro-ops or 4 instructions could retire each cycle.  This event is used in determining the 'Retiring' category of the Top-Down pipeline slots characterization. (Precise Event - PEBS) (Precise event)\000"
/* offset=6235584 */ "uops_retired.retire_slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used\000"
/* offset=6235715 */ "uops_retired.scalar_simd\000\000floating point\000Counts the number of scalar SSE, AVX, AVX2, AVX-512 micro-ops retired. More specifically, it counts scalar SSE, AVX, AVX2, AVX-512 micro-ops except for loads (memory-to-register mov-type micro ops), division, sqrt\000event=0xc2,period=200003,umask=0x20\000\00000\000This event counts the number of scalar SSE, AVX, AVX2, AVX-512 micro-ops retired (floating point, integer and store) except for loads (memory-to-register mov-type micro ops), division, sqrt\000"
/* offset=6236200 */ "uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000"
/* offset=6236335 */ "uops_retired.slots\000\000pipeline\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric.\nSoftware can use this event as the numerator for the Retiring metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=6237112 */ "uops_retired.slots\000cpu_core\000pipeline\000Retirement slots used. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000"
/* offset=6237272 */ "uops_retired.slots\000cpu_core\000pipeline\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric.\nSoftware can use this event as the numerator for the Retiring metric (or top-level category) of the Top-down Microarchitecture Analysis method\000"
/* offset=6238074 */ "uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6238210 */ "uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000"
/* offset=6238392 */ "uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles without actually retired uops\000"
/* offset=6238574 */ "uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6238702 */ "uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000"
/* offset=6238884 */ "uops_retired.stall_cycles\000\000pipeline\000This event is deprecated. Refer to new event UOPS_RETIRED.STALLS\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00010\000\000"
/* offset=6239040 */ "uops_retired.stall_cycles\000cpu_core\000pipeline\000This event is deprecated. Refer to new event UOPS_RETIRED.STALLS. Unit: cpu_core \000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00010\000\000"
/* offset=6239221 */ "uops_retired.stalled_cycles\000\000pipeline\000Cycles no micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000"
/* offset=6239329 */ "uops_retired.stalls\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000"
/* offset=6239505 */ "uops_retired.stalls\000\000pipeline\000Periods no micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000"
/* offset=6239606 */ "uops_retired.stalls\000cpu_core\000pipeline\000Cycles without actually retired uops. Unit: cpu_core \000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000"
/* offset=6239807 */ "uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000"
/* offset=6240056 */ "uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6240195 */ "uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000"
/* offset=6240433 */ "uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000\000"
/* offset=6240572 */ "uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x2\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000"
/* offset=6240810 */ "uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6240963 */ "uops_retired.total_cycles\000cpu_core\000pipeline\000Cycles with less than 10 actually retired uops. Unit: cpu_core \000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000"
/* offset=6241237 */ "uops_retired.x87\000\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6241387 */ "uops_retired.x87\000cpu_atom\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6241562 */ "uops_retired.x87\000cpu_atom\000pipeline\000Counts the number of x87 uops retired, includes those in ms flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x2\000\00000\000\000"
/* offset=6241737 */ "uops_retired\000\000recommended\000Micro-ops Retired\000event=0xc1\000\00000\000\000"
/* offset=6241797 */ "upi_data_bandwidth_tx\000uncore_upi\000uncore interconnect\000UPI interconnect send bandwidth for payload. Derived from unc_upi_txl_flits.all_data. Unit: uncore_upi \000event=0x2,umask=0xf\000\000017.11E-06Bytes\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000"
/* offset=6242156 */ "x87_comp_ops_exe.any.ar\000\000floating point\000Floating point computational micro-ops retired (Must be precise)\000event=0x10,period=2000000,umask=0x81\000\00000\000\000"
/* offset=6242303 */ "x87_comp_ops_exe.any.s\000\000floating point\000Floating point computational micro-ops executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000"
/* offset=6242431 */ "x87_comp_ops_exe.fxch.ar\000\000floating point\000FXCH uops retired (Must be precise)\000event=0x10,period=2000000,umask=0x82\000\00000\000\000"
/* offset=6242550 */ "x87_comp_ops_exe.fxch.s\000\000floating point\000FXCH uops executed\000event=0x10,period=2000000,umask=0x2\000\00000\000\000"
/* offset=6242650 */ "xi_ccx_sdp_req1.all_l3_miss_req_typs\000amd_l3\000cache\000All L3 Miss Request Types. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x9a,umask=0x3f\000\00000\000\000"
/* offset=6242802 */ "xi_ccx_sdp_req1\000amd_l3\000cache\000L3 Misses by Request Type. Ignores SliceID, EnAllSlices, CoreID, EnAllCores and ThreadMask. Requires unit mask 0xFF to engage event for counting. Unit: amd_l3 \000event=0x9a,umask=0xff\000\00000\000\000"
/* offset=6243018 */ "xi_sys_fill_latency\000amd_l3\000cache\000L3 Cache Miss Latency. Total cycles for all transactions divided by 16. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x90,umask=0x00\000\00000\000\000"
/* offset=6243198 */ "xi_sys_fill_latency\000amd_l3\000cache\000L3 Cache Miss Latency. Total cycles for all transactions divided by 16. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x90\000\00000\000\000"
/* offset=6243367 */ "xq.full_cycles\000\000other\000Cycles the uncore cannot take further requests\000event=0x2d,cmask=1,period=1000003,umask=0x1\000\00000\000number of cycles when the thread is active and the uncore cannot take any further requests (for example prefetches, loads or stores initiated by the Core that miss the L2 cache)\000"
/* offset=6243662 */ "xq.full_cycles\000cpu_core\000other\000Cycles the uncore cannot take further requests. Unit: cpu_core \000event=0x2d,cmask=1,period=1000003,umask=0x1\000\00000\000number of cycles when the thread is active and the uncore cannot take any further requests (for example prefetches, loads or stores initiated by the Core that miss the L2 cache)\000"
;

static const struct compact_pmu_event pmu_events__test_soc_cpu[] = {
{ 481645 }, /* bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000 */
{ 486559 }, /* bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000 */
{ 1186156 }, /* l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000 */
{ 778587 }, /* dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\00000\000\000 */
{ 831374 }, /* eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\00000\000\000 */
{ 2521354 }, /* segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\00000\000\000 */
{ 835131 }, /* event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\00000\000UNC_CBO_HYPHEN\000 */
{ 835239 }, /* event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\00000\000UNC_CBO_TWO_HYPH\000 */
{ 2791435 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000 */
{ 6170941 }, /* uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\00000\000DDRC write commands\000 */
{ 6171067 }, /* uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\00000\000Total read hits\000 */
{ 6173963 }, /* uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\00000\000Total cache hits\000 */
{ 6177164 }, /* uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\00000\000Total cache misses\000 */
};

static const struct compact_pmu_event pmu_metrics__test_soc_cpu[] = {
{ 4856 }, /* \000CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000 */
{ 4965 }, /* \000DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000 */
{ 5030 }, /* \000DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000 */
{ 5125 }, /* \000DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000 */
{ 5260 }, /* \000DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 5329 }, /* \000DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 5400 }, /* \000Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000 */
{ 5654 }, /* \000IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000 */
{ 6188 }, /* \000L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000 */
{ 6385 }, /* \000M1\000\000ipc + M2\000\000\000\000\000\000\000\00000 */
{ 6408 }, /* \000M2\000\000ipc + M1\000\000\000\000\000\000\000\00000 */
{ 6431 }, /* \000M3\000\0001 / M3\000\000\000\000\000\000\000\00000 */
{ 9533 }, /* \000cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000 */
{ 10047 }, /* \000dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */
{ 16820 }, /* \000icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__test_soc_sys[] = {
{ 2539810 }, /* sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\0000x01\00000\000\000 */
{ 2539930 }, /* sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000v8\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__alderlake[] = {
{ 1100364 }, /* l1d.hwpf_miss\000cpu_core\000cache\000L1D.HWPF_MISS. Unit: cpu_core \000event=0x51,period=1000003,umask=0x20\000\00000\000\000 */
{ 1102201 }, /* l1d.replacement\000cpu_core\000cache\000Counts the number of cache lines replaced in L1 data cache. Unit: cpu_core \000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1106236 }, /* l1d_pend_miss.fb_full\000cpu_core\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106980 }, /* l1d_pend_miss.fb_full_periods\000cpu_core\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107857 }, /* l1d_pend_miss.l2_stall\000cpu_core\000cache\000This event is deprecated. Refer to new event L1D_PEND_MISS.L2_STALLS. Unit: cpu_core \000event=0x48,period=1000003,umask=0x4\000\00010\000\000 */
{ 1108364 }, /* l1d_pend_miss.l2_stalls\000cpu_core\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources. Unit: cpu_core \000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1111558 }, /* l1d_pend_miss.pending\000cpu_core\000cache\000Number of L1D misses that are outstanding. Unit: cpu_core \000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1113017 }, /* l1d_pend_miss.pending_cycles\000cpu_core\000cache\000Cycles with L1D load Misses outstanding. Unit: cpu_core \000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1129403 }, /* l2_lines_in.all\000cpu_core\000cache\000L2 cache lines filling L2. Unit: cpu_core \000event=0x25,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1138477 }, /* l2_lines_out.useless_hwpf\000cpu_core\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses. Unit: cpu_core \000event=0x26,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000 */
{ 1150207 }, /* l2_request.all\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_RQSTS.REFERENCES]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.REFERENCES]\000 */
{ 1152057 }, /* l2_request.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_RQSTS.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000 */
{ 1157584 }, /* l2_rqsts.all_code_rd\000cpu_core\000cache\000L2 code requests. Unit: cpu_core \000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1159075 }, /* l2_rqsts.all_demand_data_rd\000cpu_core\000cache\000Demand Data Read access L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1159993 }, /* l2_rqsts.all_demand_miss\000cpu_core\000cache\000Demand requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1160987 }, /* l2_rqsts.all_hwpf\000cpu_core\000cache\000L2_RQSTS.ALL_HWPF. Unit: cpu_core \000event=0x24,period=200003,umask=0xf0\000\00000\000\000 */
{ 1162694 }, /* l2_rqsts.all_rfo\000cpu_core\000cache\000RFO requests to L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163734 }, /* l2_rqsts.code_rd_hit\000cpu_core\000cache\000L2 cache hits when fetching instructions, code reads. Unit: cpu_core \000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164662 }, /* l2_rqsts.code_rd_miss\000cpu_core\000cache\000L2 cache misses when fetching instructions. Unit: cpu_core \000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165833 }, /* l2_rqsts.demand_data_rd_hit\000cpu_core\000cache\000Demand Data Read requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1167001 }, /* l2_rqsts.demand_data_rd_miss\000cpu_core\000cache\000Demand Data Read miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1167613 }, /* l2_rqsts.hwpf_miss\000cpu_core\000cache\000L2_RQSTS.HWPF_MISS. Unit: cpu_core \000event=0x24,period=200003,umask=0x30\000\00000\000\000 */
{ 1170555 }, /* l2_rqsts.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_REQUEST.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000 */
{ 1173430 }, /* l2_rqsts.references\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_REQUEST.ALL]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.ALL]\000 */
{ 1174463 }, /* l2_rqsts.rfo_hit\000cpu_core\000cache\000RFO requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1175400 }, /* l2_rqsts.rfo_miss\000cpu_core\000cache\000RFO requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177375 }, /* l2_rqsts.swpf_hit\000cpu_core\000cache\000SW prefetch requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177879 }, /* l2_rqsts.swpf_miss\000cpu_core\000cache\000SW prefetch requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1249567 }, /* longest_lat_cache.miss\000cpu_atom\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1250061 }, /* longest_lat_cache.miss\000cpu_core\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1253409 }, /* longest_lat_cache.reference\000cpu_atom\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1253906 }, /* longest_lat_cache.reference\000cpu_core\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1303672 }, /* mem_bound_stalls.ifetch\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000 */
{ 1304436 }, /* mem_bound_stalls.ifetch_dram_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000 */
{ 1305158 }, /* mem_bound_stalls.ifetch_l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000 */
{ 1305922 }, /* mem_bound_stalls.ifetch_llc_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M. Unit: cpu_atom \000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1306543 }, /* mem_bound_stalls.load\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x7\000\00000\000\000 */
{ 1306950 }, /* mem_bound_stalls.load_dram_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000event=0x34,period=200003,umask=0x4\000\00000\000\000 */
{ 1307335 }, /* mem_bound_stalls.load_l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=200003,umask=0x1\000\00000\000\000 */
{ 1307862 }, /* mem_bound_stalls.load_llc_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M. Unit: cpu_atom \000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1310969 }, /* mem_inst_retired.all_loads\000cpu_core\000cache\000Retired load instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311792 }, /* mem_inst_retired.all_stores\000cpu_core\000cache\000Retired store instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312558 }, /* mem_inst_retired.any\000cpu_core\000cache\000All retired memory instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315828 }, /* mem_inst_retired.lock_loads\000cpu_core\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316426 }, /* mem_inst_retired.split_loads\000cpu_core\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1317068 }, /* mem_inst_retired.split_stores\000cpu_core\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318345 }, /* mem_inst_retired.stlb_miss_loads\000cpu_core\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318979 }, /* mem_inst_retired.stlb_miss_stores\000cpu_core\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1319707 }, /* mem_load_completed.l1_miss_any\000cpu_core\000cache\000Completed demand load uops that miss the L1 d-cache. Unit: cpu_core \000event=0x43,period=1000003,umask=0xfd\000\00000\000Number of completed demand load requests that missed the L1 data cache including shadow misses (FB hits, merge to an ongoing L1D miss)\000 */
{ 1320891 }, /* mem_load_l3_hit_retired.xsnp_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1322213 }, /* mem_load_l3_hit_retired.xsnp_hit\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1323495 }, /* mem_load_l3_hit_retired.xsnp_hitm\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1324489 }, /* mem_load_l3_hit_retired.xsnp_miss\000cpu_core\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1325784 }, /* mem_load_l3_hit_retired.xsnp_no_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326886 }, /* mem_load_l3_hit_retired.xsnp_none\000cpu_core\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327606 }, /* mem_load_l3_miss_retired.local_dram\000cpu_core\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1331574 }, /* mem_load_misc_retired.uc\000cpu_core\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1333255 }, /* mem_load_retired.fb_hit\000cpu_core\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1334781 }, /* mem_load_retired.l1_hit\000cpu_core\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335820 }, /* mem_load_retired.l1_miss\000cpu_core\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1337106 }, /* mem_load_retired.l2_hit\000cpu_core\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1338102 }, /* mem_load_retired.l2_miss\000cpu_core\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1339025 }, /* mem_load_retired.l3_hit\000cpu_core\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339968 }, /* mem_load_retired.l3_miss\000cpu_core\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1353437 }, /* mem_load_uops_retired.dram_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x80\000\00000\000\000 */
{ 1361203 }, /* mem_load_uops_retired.l2_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x2\000\00000\000\000 */
{ 1364118 }, /* mem_load_uops_retired.l3_hit\000cpu_atom\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x4\000\00000\000\000 */
{ 1367461 }, /* mem_scheduler_block.all\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked for any of the following reasons:  load buffer, store buffer or RSV full. Unit: cpu_atom \000event=0x4,period=20003,umask=0x7\000\00000\000\000 */
{ 1367836 }, /* mem_scheduler_block.ld_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a load buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x2\000\00000\000\000 */
{ 1368167 }, /* mem_scheduler_block.rsv\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to an RSV full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x4\000\00000\000\000 */
{ 1368499 }, /* mem_scheduler_block.st_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a store buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x1\000\00000\000\000 */
{ 1368913 }, /* mem_store_retired.l2_hit\000cpu_core\000cache\000MEM_STORE_RETIRED.L2_HIT. Unit: cpu_core \000event=0x44,period=200003,umask=0x1\000\00000\000\000 */
{ 1387792 }, /* mem_uop_retired.any\000cpu_core\000cache\000Retired memory uops for any access. Unit: cpu_core \000event=0xe5,period=1000003,umask=0x3\000\00000\000Number of retired micro-operations (uops) for load or store memory accesses\000 */
{ 1390962 }, /* mem_uops_retired.all_loads\000cpu_atom\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000 */
{ 1393426 }, /* mem_uops_retired.all_stores\000cpu_atom\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000 */
{ 1399401 }, /* mem_uops_retired.load_latency_gt_128\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1401408 }, /* mem_uops_retired.load_latency_gt_16\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1404043 }, /* mem_uops_retired.load_latency_gt_256\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1406051 }, /* mem_uops_retired.load_latency_gt_32\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1408047 }, /* mem_uops_retired.load_latency_gt_4\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1410055 }, /* mem_uops_retired.load_latency_gt_512\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1412063 }, /* mem_uops_retired.load_latency_gt_64\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1414059 }, /* mem_uops_retired.load_latency_gt_8\000cpu_atom\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1419232 }, /* mem_uops_retired.split_loads\000cpu_atom\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x41\000\00000\000\000 */
{ 1424574 }, /* mem_uops_retired.store_latency\000cpu_atom\000cache\000Counts the number of stores uops retired. Counts with or without PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x6\000\00000\000Counts the number of stores uops retired. Counts with or without PEBS enabled. If PEBS is enabled and a PEBS record is generated, will populate PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1552436 }, /* ocr.demand_data_rd.l3_hit\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 1546532 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1548072 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1548348 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches which forwarded the unmodified data to the requesting core. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1549784 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000cpu_atom\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1550049 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1581683 }, /* ocr.demand_rfo.l3_hit\000cpu_atom\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 1578184 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000cpu_atom\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1578520 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1746968 }, /* offcore_requests.all_requests\000cpu_core\000cache\000OFFCORE_REQUESTS.ALL_REQUESTS. Unit: cpu_core \000event=0x21,period=100003,umask=0x80\000\00000\000\000 */
{ 1747690 }, /* offcore_requests.data_rd\000cpu_core\000cache\000Demand and prefetch data reads. Unit: cpu_core \000event=0x21,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1750835 }, /* offcore_requests.demand_data_rd\000cpu_core\000cache\000Demand Data Read requests sent to uncore. Unit: cpu_core \000event=0x21,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1757489 }, /* offcore_requests_outstanding.all_data_rd\000cpu_core\000cache\000This event is deprecated. Refer to new event OFFCORE_REQUESTS_OUTSTANDING.DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,period=1000003,umask=0x8\000\00010\000\000 */
{ 1761143 }, /* offcore_requests_outstanding.cycles_with_data_rd\000cpu_core\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,cmask=1,period=1000003,umask=0x8\000\00000\000\000 */
{ 1764582 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000cpu_core\000cache\000Cycles where at least 1 outstanding demand data read request is pending. Unit: cpu_core \000event=0x20,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1767790 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000cpu_core\000cache\000For every cycle where the core is waiting on at least 1 outstanding Demand RFO request, increments by 1. Unit: cpu_core \000event=0x20,cmask=1,period=1000003,umask=0x4\000\00000\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO\000 */
{ 1768876 }, /* offcore_requests_outstanding.data_rd\000cpu_core\000cache\000OFFCORE_REQUESTS_OUTSTANDING.DATA_RD  Spec update: ADL038. Unit: cpu_core \000event=0x20,period=1000003,umask=0x8\000\00000\000\000 */
{ 1775034 }, /* offcore_requests_outstanding.demand_data_rd\000cpu_core\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending. Unit: cpu_core \000event=0x20,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 2531144 }, /* sq_misc.bus_lock\000cpu_core\000cache\000Counts bus locks, accounts for cache line split locks and UC locks. Unit: cpu_core \000event=0x2c,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2537587 }, /* sw_prefetch_access.nta\000cpu_core\000cache\000Number of PREFETCHNTA instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2538239 }, /* sw_prefetch_access.prefetchw\000cpu_core\000cache\000Number of PREFETCHW instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538877 }, /* sw_prefetch_access.t0\000cpu_core\000cache\000Number of PREFETCHT0 instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539589 }, /* sw_prefetch_access.t1_t2\000cpu_core\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed. Unit: cpu_core \000event=0x40,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 2568325 }, /* topdown_fe_bound.icache\000cpu_atom\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x20\000\00000\000\000 */
{ 469445 }, /* arith.fpdiv_active\000cpu_core\000floating point\000ARITH.FPDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 472431 }, /* assists.fp\000cpu_core\000floating point\000Counts all microcode FP assists. Unit: cpu_core \000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 472999 }, /* assists.sse_avx_mix\000cpu_core\000floating point\000ASSISTS.SSE_AVX_MIX. Unit: cpu_core \000event=0xc1,period=1000003,umask=0x10\000\00000\000\000 */
{ 853719 }, /* fp_arith_dispatched.port_0\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_0. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x1\000\00000\000\000 */
{ 853966 }, /* fp_arith_dispatched.port_1\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_1. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x2\000\00000\000\000 */
{ 854213 }, /* fp_arith_dispatched.port_5\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_5. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x4\000\00000\000\000 */
{ 857340 }, /* fp_arith_inst_retired.128b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 861484 }, /* fp_arith_inst_retired.128b_packed_single\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 865542 }, /* fp_arith_inst_retired.256b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 869687 }, /* fp_arith_inst_retired.256b_packed_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 874503 }, /* fp_arith_inst_retired.4_flops\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 889239 }, /* fp_arith_inst_retired.scalar\000cpu_core\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element. Unit: cpu_core \000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 892915 }, /* fp_arith_inst_retired.scalar_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 896651 }, /* fp_arith_inst_retired.scalar_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898730 }, /* fp_arith_inst_retired.vector\000cpu_core\000floating point\000Number of any Vector retired FP arithmetic instructions. Unit: cpu_core \000event=0xc7,period=1000003,umask=0xfc\000\00000\000Number of any Vector retired FP arithmetic instructions.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 1292564 }, /* machine_clears.fp_assist\000cpu_atom\000floating point\000Counts the number of floating point operations retired that required microcode assist. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000 */
{ 6229268 }, /* uops_retired.fpdiv\000cpu_atom\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x8\000\00000\000\000 */
{ 477358 }, /* baclears.any\000cpu_atom\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches. Unit: cpu_atom \000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 478394 }, /* baclears.any\000cpu_core\000frontend\000Clears due to Unknown Branches. Unit: cpu_core \000event=0x60,period=100003,umask=0x1\000\00000\000Number of times the front-end is resteered when it finds a branch instruction in a fetch line. This is called Unknown Branch which occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 776818 }, /* decode.lcp\000cpu_core\000frontend\000Stalls caused by changing prefix length of the instruction. Unit: cpu_core \000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk\000 */
{ 777470 }, /* decode.ms_busy\000cpu_core\000frontend\000Cycles the Microcode Sequencer is busy. Unit: cpu_core \000event=0x87,period=500009,umask=0x2\000\00000\000\000 */
{ 785927 }, /* dsb2mite_switches.penalty_cycles\000cpu_core\000frontend\000DSB-to-MITE switch true penalty cycles. Unit: cpu_core \000event=0x61,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 941034 }, /* frontend_retired.any_dsb_miss\000cpu_core\000frontend\000Retired Instructions who experienced DSB miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941725 }, /* frontend_retired.dsb_miss\000cpu_core\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942633 }, /* frontend_retired.itlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943625 }, /* frontend_retired.l1i_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944639 }, /* frontend_retired.l2_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 950597 }, /* frontend_retired.latency_ge_1\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 946154 }, /* frontend_retired.latency_ge_128\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 948519 }, /* frontend_retired.latency_ge_16\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 954631 }, /* frontend_retired.latency_ge_2\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 952614 }, /* frontend_retired.latency_ge_256\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955952 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 959031 }, /* frontend_retired.latency_ge_32\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 961206 }, /* frontend_retired.latency_ge_4\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 963415 }, /* frontend_retired.latency_ge_512\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 965628 }, /* frontend_retired.latency_ge_64\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967978 }, /* frontend_retired.latency_ge_8\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969294 }, /* frontend_retired.ms_flows\000cpu_core\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x8\000\00000\000\000 */
{ 969872 }, /* frontend_retired.stlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 970307 }, /* frontend_retired.unknown_branch\000cpu_core\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x1,frontend=0x17\000\00000\000\000 */
{ 984744 }, /* icache.accesses\000cpu_atom\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line. Unit: cpu_atom \000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 991975 }, /* icache.misses\000cpu_atom\000frontend\000Counts the number of instruction cache misses. Unit: cpu_atom \000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 995558 }, /* icache_data.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. Unit: cpu_core \000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The decode pipeline works at a 32 Byte granularity\000 */
{ 996965 }, /* icache_tag.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. Unit: cpu_core \000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss\000 */
{ 1004194 }, /* idq.dsb_cycles_any\000cpu_core\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1005608 }, /* idq.dsb_cycles_ok\000cpu_core\000frontend\000Cycles DSB is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1007298 }, /* idq.dsb_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010489 }, /* idq.mite_cycles_any\000cpu_core\000frontend\000Cycles MITE is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1011572 }, /* idq.mite_cycles_ok\000cpu_core\000frontend\000Cycles MITE is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1013334 }, /* idq.mite_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1017370 }, /* idq.ms_cycles_any\000cpu_core\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x20\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024670 }, /* idq.ms_switches\000cpu_core\000frontend\000Number of switches from DSB or MITE to the MS. Unit: cpu_core \000event=0x79,cmask=1,edge=1,period=100003,umask=0x20\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1027291 }, /* idq.ms_uops\000cpu_core\000frontend\000Uops delivered to IDQ while MS is busy. Unit: cpu_core \000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS)\000 */
{ 1033407 }, /* idq_uops_not_delivered.core\000cpu_core\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036114 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000cpu_core\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,cmask=6,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1037389 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000cpu_core\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled. Unit: cpu_core \000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 757847 }, /* cycle_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 1204325 }, /* ld_head.any_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to any number of reasons, including an L1 miss, WCB full, pagewalk, store address block or store data block, on a load that retires. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xff\000\00000\000\000 */
{ 1205362 }, /* ld_head.l1_bound_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to a core bound stall including a store address match, a DTLB miss or a page walk that detains the load from retiring. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xf4\000\00000\000\000 */
{ 1205865 }, /* ld_head.l1_miss_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DL1 miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x81\000\00000\000\000 */
{ 1206460 }, /* ld_head.other_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xc0\000\00000\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases such as pipeline conflicts, fences, etc\000 */
{ 1207054 }, /* ld_head.pgwalk_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a pagewalk. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xa0\000\00000\000\000 */
{ 1207483 }, /* ld_head.st_addr_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a store address match. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x84\000\00000\000\000 */
{ 1297502 }, /* machine_clears.memory_ordering\000cpu_atom\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x2\000\00000\000\000 */
{ 1297800 }, /* machine_clears.memory_ordering\000cpu_core\000memory\000Number of machine clears due to memory ordering conflicts. Unit: cpu_core \000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1370486 }, /* mem_trans_retired.load_latency_gt_128\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372426 }, /* mem_trans_retired.load_latency_gt_16\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374372 }, /* mem_trans_retired.load_latency_gt_256\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376317 }, /* mem_trans_retired.load_latency_gt_32\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378247 }, /* mem_trans_retired.load_latency_gt_4\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380190 }, /* mem_trans_retired.load_latency_gt_512\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382125 }, /* mem_trans_retired.load_latency_gt_64\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1384048 }, /* mem_trans_retired.load_latency_gt_8\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1385440 }, /* mem_trans_retired.store_sample\000cpu_core\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000 */
{ 1425503 }, /* memory_activity.cycles_l1d_miss\000cpu_core\000memory\000Cycles while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0x47,cmask=2,period=1000003,umask=0x2\000\00000\000\000 */
{ 1425824 }, /* memory_activity.stalls_l1d_miss\000cpu_core\000memory\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0x47,cmask=3,period=1000003,umask=0x3\000\00000\000\000 */
{ 1426316 }, /* memory_activity.stalls_l2_miss\000cpu_core\000memory\000Execution stalls while L2 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=5,period=1000003,umask=0x5\000\00000\000Execution stalls while L2 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1426969 }, /* memory_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=9,period=1000003,umask=0x9\000\00000\000Execution stalls while L3 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1560332 }, /* ocr.demand_data_rd.l3_miss\000cpu_atom\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000 */
{ 1560521 }, /* ocr.demand_data_rd.l3_miss\000cpu_core\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1561305 }, /* ocr.demand_data_rd.l3_miss_local\000cpu_atom\000memory\000Counts demand data reads that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000 */
{ 1590246 }, /* ocr.demand_rfo.l3_miss\000cpu_atom\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000 */
{ 1590506 }, /* ocr.demand_rfo.l3_miss\000cpu_core\000memory\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000 */
{ 1591571 }, /* ocr.demand_rfo.l3_miss_local\000cpu_atom\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000 */
{ 1752737 }, /* offcore_requests.l3_miss_demand_data_rd\000cpu_core\000memory\000Counts demand data read requests that miss the L3 cache. Unit: cpu_core \000event=0x21,period=100003,umask=0x10\000\00000\000\000 */
{ 1779584 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000cpu_core\000memory\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache. Unit: cpu_core \000event=0x20,period=2000003,umask=0x10\000\00000\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known by the requesting core to have missed the L3 cache\000 */
{ 472598 }, /* assists.hardware\000cpu_core\000other\000ASSISTS.HARDWARE. Unit: cpu_core \000event=0xc1,period=100003,umask=0x4\000\00000\000\000 */
{ 472790 }, /* assists.page_fault\000cpu_core\000other\000ASSISTS.PAGE_FAULT. Unit: cpu_core \000event=0xc1,period=1000003,umask=0x8\000\00000\000\000 */
{ 571607 }, /* core_power.license_1\000cpu_core\000other\000CORE_POWER.LICENSE_1. Unit: cpu_core \000event=0x28,period=200003,umask=0x2\000\00000\000\000 */
{ 571721 }, /* core_power.license_2\000cpu_core\000other\000CORE_POWER.LICENSE_2. Unit: cpu_core \000event=0x28,period=200003,umask=0x4\000\00000\000\000 */
{ 571835 }, /* core_power.license_3\000cpu_core\000other\000CORE_POWER.LICENSE_3. Unit: cpu_core \000event=0x28,period=200003,umask=0x8\000\00000\000\000 */
{ 1514167 }, /* ocr.corewb_m.any_response\000cpu_atom\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 1542944 }, /* ocr.demand_data_rd.any_response\000cpu_atom\000other\000Counts demand data reads that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543124 }, /* ocr.demand_data_rd.any_response\000cpu_core\000other\000Counts demand data reads that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543922 }, /* ocr.demand_data_rd.dram\000cpu_core\000other\000Counts demand data reads that were supplied by DRAM. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1573015 }, /* ocr.demand_rfo.any_response\000cpu_atom\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1573266 }, /* ocr.demand_rfo.any_response\000cpu_core\000other\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1738716 }, /* ocr.streaming_wr.any_response\000cpu_atom\000other\000Counts streaming stores that have any type of response. Unit: cpu_atom \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1738893 }, /* ocr.streaming_wr.any_response\000cpu_core\000other\000Counts streaming stores that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2508798 }, /* rs.empty\000cpu_core\000other\000Cycles when Reservation Station (RS) is empty for the thread. Unit: cpu_core \000event=0xa5,period=1000003,umask=0x7\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into starvation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2509501 }, /* rs.empty_count\000cpu_core\000other\000Counts end of periods where the Reservation Station (RS) was empty. Unit: cpu_core \000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2510010 }, /* rs_empty.count\000cpu_core\000other\000This event is deprecated. Refer to new event RS.EMPTY_COUNT. Unit: cpu_core \000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00010\000\000 */
{ 2510296 }, /* rs_empty.cycles\000cpu_core\000other\000This event is deprecated. Refer to new event RS.EMPTY. Unit: cpu_core \000event=0xa5,period=1000003,umask=0x7\000\00010\000\000 */
{ 6243662 }, /* xq.full_cycles\000cpu_core\000other\000Cycles the uncore cannot take further requests. Unit: cpu_core \000event=0x2d,cmask=1,period=1000003,umask=0x1\000\00000\000number of cycles when the thread is active and the uncore cannot take any further requests (for example prefetches, loads or stores initiated by the Core that miss the L2 cache)\000 */
{ 467764 }, /* arith.div_active\000cpu_core\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 468710 }, /* arith.divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.DIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00010\000\000 */
{ 469170 }, /* arith.fp_divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.FPDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00010\000\000 */
{ 470852 }, /* arith.idiv_active\000cpu_core\000pipeline\000This event counts the cycles the integer divider is busy. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00000\000\000 */
{ 471158 }, /* arith.int_divider_active\000cpu_core\000pipeline\000This event is deprecated. Refer to new event ARITH.IDIV_ACTIVE. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00010\000\000 */
{ 471982 }, /* assists.any\000cpu_core\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware. Unit: cpu_core \000event=0xc1,period=100003,umask=0x1b\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware. Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 498699 }, /* br_inst_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 499133 }, /* br_inst_retired.all_branches\000cpu_core\000pipeline\000All branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502747 }, /* br_inst_retired.call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_CALL (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf9\000\00010\000\000 */
{ 503659 }, /* br_inst_retired.cond\000cpu_atom\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0x7e\000\00000\000\000 */
{ 503904 }, /* br_inst_retired.cond\000cpu_core\000pipeline\000Conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504526 }, /* br_inst_retired.cond_ntaken\000cpu_core\000pipeline\000Not taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 505131 }, /* br_inst_retired.cond_taken\000cpu_atom\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfe\000\00000\000\000 */
{ 505336 }, /* br_inst_retired.cond_taken\000cpu_core\000pipeline\000Taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 509150 }, /* br_inst_retired.far_branch\000cpu_atom\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 509393 }, /* br_inst_retired.far_branch\000cpu_core\000pipeline\000Far branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 510931 }, /* br_inst_retired.ind_call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT_CALL (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfb\000\00010\000\000 */
{ 511574 }, /* br_inst_retired.indirect\000cpu_atom\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xeb\000\00000\000\000 */
{ 511781 }, /* br_inst_retired.indirect\000cpu_core\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 512240 }, /* br_inst_retired.indirect_call\000cpu_atom\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfb\000\00000\000\000 */
{ 514053 }, /* br_inst_retired.jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0x7e\000\00010\000\000 */
{ 516104 }, /* br_inst_retired.near_call\000cpu_atom\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 516281 }, /* br_inst_retired.near_call\000cpu_core\000pipeline\000Direct and indirect near call instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 518551 }, /* br_inst_retired.near_return\000cpu_atom\000pipeline\000Counts the number of near RET branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf7\000\00000\000\000 */
{ 518729 }, /* br_inst_retired.near_return\000cpu_core\000pipeline\000Return instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 520003 }, /* br_inst_retired.near_taken\000cpu_core\000pipeline\000Taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 521864 }, /* br_inst_retired.non_return_ind\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xeb\000\00010\000\000 */
{ 524165 }, /* br_inst_retired.rel_call\000cpu_atom\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfd\000\00000\000\000 */
{ 525627 }, /* br_inst_retired.return\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_RETURN (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf7\000\00010\000\000 */
{ 527595 }, /* br_inst_retired.taken_jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND_TAKEN (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xfe\000\00010\000\000 */
{ 539295 }, /* br_misp_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 540131 }, /* br_misp_retired.all_branches\000cpu_core\000pipeline\000All mispredicted branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542973 }, /* br_misp_retired.cond\000cpu_atom\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 543179 }, /* br_misp_retired.cond\000cpu_core\000pipeline\000Mispredicted conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 544359 }, /* br_misp_retired.cond_ntaken\000cpu_core\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545727 }, /* br_misp_retired.cond_taken\000cpu_atom\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfe\000\00000\000\000 */
{ 545945 }, /* br_misp_retired.cond_taken\000cpu_core\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 548787 }, /* br_misp_retired.ind_call\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT_CALL (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfb\000\00010\000\000 */
{ 549816 }, /* br_misp_retired.indirect\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 550036 }, /* br_misp_retired.indirect\000cpu_core\000pipeline\000Miss-predicted near indirect branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc5,period=100003,umask=0x80\000\00000\000Counts miss-predicted near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 551327 }, /* br_misp_retired.indirect_call\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 551530 }, /* br_misp_retired.indirect_call\000cpu_core\000pipeline\000Mispredicted indirect CALL retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 554161 }, /* br_misp_retired.jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0x7e\000\00010\000\000 */
{ 556494 }, /* br_misp_retired.near_taken\000cpu_core\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 559248 }, /* br_misp_retired.non_return_ind\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xeb\000\00010\000\000 */
{ 560776 }, /* br_misp_retired.ret\000cpu_core\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event). Unit: cpu_core \000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 562583 }, /* br_misp_retired.return\000cpu_atom\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 564728 }, /* br_misp_retired.taken_jcc\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND_TAKEN (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfe\000\00010\000\000 */
{ 610039 }, /* cpu_clk_unhalted.c01\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x10\000\00000\000Counts core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000 */
{ 610806 }, /* cpu_clk_unhalted.c02\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x20\000\00000\000Counts core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000 */
{ 611518 }, /* cpu_clk_unhalted.c0_wait\000cpu_core\000pipeline\000Core clocks when the thread is in the C0.1 or C0.2 or running a PAUSE in C0 ACPI state. Unit: cpu_core \000event=0xec,period=2000003,umask=0x70\000\00000\000Counts core clocks when the thread is in the C0.1 or C0.2 power saving optimized states (TPAUSE or UMWAIT instructions) or running the PAUSE instruction\000 */
{ 614130 }, /* cpu_clk_unhalted.core\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event). Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000 */
{ 616233 }, /* cpu_clk_unhalted.core_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 617223 }, /* cpu_clk_unhalted.distributed\000cpu_core\000pipeline\000Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 618529 }, /* cpu_clk_unhalted.one_thread_active\000cpu_core\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted. Unit: cpu_core \000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 618917 }, /* cpu_clk_unhalted.pause\000cpu_core\000pipeline\000CPU_CLK_UNHALTED.PAUSE. Unit: cpu_core \000event=0xec,period=2000003,umask=0x40\000\00000\000\000 */
{ 619163 }, /* cpu_clk_unhalted.pause_inst\000cpu_core\000pipeline\000CPU_CLK_UNHALTED.PAUSE_INST. Unit: cpu_core \000event=0xec,cmask=1,edge=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 621589 }, /* cpu_clk_unhalted.ref_distributed\000cpu_core\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 632135 }, /* cpu_clk_unhalted.ref_tsc\000cpu_atom\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event). Unit: cpu_atom \000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 632803 }, /* cpu_clk_unhalted.ref_tsc\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 636170 }, /* cpu_clk_unhalted.ref_tsc_p\000cpu_atom\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. Unit: cpu_atom \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 636697 }, /* cpu_clk_unhalted.ref_tsc_p\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 644718 }, /* cpu_clk_unhalted.thread\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event). Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1\000 */
{ 645324 }, /* cpu_clk_unhalted.thread\000cpu_core\000pipeline\000Core cycles when the thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 648446 }, /* cpu_clk_unhalted.thread_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 648920 }, /* cpu_clk_unhalted.thread_p\000cpu_core\000pipeline\000Thread cycles when thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 749020 }, /* cycle_activity.cycles_l1d_miss\000cpu_core\000pipeline\000Cycles while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750584 }, /* cycle_activity.cycles_l2_miss\000cpu_core\000pipeline\000Cycles while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 753325 }, /* cycle_activity.cycles_mem_any\000cpu_core\000pipeline\000Cycles while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754780 }, /* cycle_activity.stalls_l1d_miss\000cpu_core\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 756263 }, /* cycle_activity.stalls_l2_miss\000cpu_core\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 759422 }, /* cycle_activity.stalls_total\000cpu_core\000pipeline\000Total execution stalls. Unit: cpu_core \000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 845109 }, /* exe_activity.1_ports_util\000cpu_core\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845686 }, /* exe_activity.2_ports_util\000cpu_core\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846244 }, /* exe_activity.3_ports_util\000cpu_core\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846780 }, /* exe_activity.4_ports_util\000cpu_core\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847497 }, /* exe_activity.bound_on_loads\000cpu_core\000pipeline\000Execution stalls while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000\000 */
{ 848069 }, /* exe_activity.bound_on_stores\000cpu_core\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall. Unit: cpu_core \000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 849014 }, /* exe_activity.exe_bound_0_ports\000cpu_core\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load. Unit: cpu_core \000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000 */
{ 1043723 }, /* inst_decoded.decoders\000cpu_core\000pipeline\000Instruction decoders utilized in a cycle. Unit: cpu_core \000event=0x75,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1050909 }, /* inst_retired.any\000cpu_atom\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000 */
{ 1051541 }, /* inst_retired.any\000cpu_core\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1056482 }, /* inst_retired.any_p\000cpu_atom\000pipeline\000Counts the total number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000 */
{ 1056980 }, /* inst_retired.any_p\000cpu_core\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057610 }, /* inst_retired.macro_fused\000cpu_core\000pipeline\000INST_RETIRED.MACRO_FUSED. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x10\000\00000\000\000 */
{ 1058437 }, /* inst_retired.nop\000cpu_core\000pipeline\000Retired NOP instructions. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions\000 */
{ 1061466 }, /* inst_retired.prec_dist\000cpu_core\000pipeline\000Precise instruction retired with PEBS precise-distribution (Precise event). Unit: cpu_core \000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a precise distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR++) feature to fix bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1062417 }, /* inst_retired.rep_iteration\000cpu_core\000pipeline\000Iterations of Repeat string retired instructions. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x8\000\00000\000Number of iterations of Repeat (REP) string retired instructions such as MOVS, CMPS, and SCAS. Each has a byte, word, and doubleword version and string instructions can be repeated using a repetition prefix, REP, that allows their architectural execution to be repeated a number of times as specified by the RCX register. Note the number of iterations is implementation-dependent\000 */
{ 1066343 }, /* int_misc.clear_resteer_cycles\000cpu_core\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path. Unit: cpu_core \000event=0xad,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1067321 }, /* int_misc.clears_count\000cpu_core\000pipeline\000Clears speculative count. Unit: cpu_core \000event=0xad,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1070519 }, /* int_misc.recovery_cycles\000cpu_core\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread. Unit: cpu_core \000event=0xad,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072553 }, /* int_misc.unknown_branch_cycles\000cpu_core\000pipeline\000INT_MISC.UNKNOWN_BRANCH_CYCLES. Unit: cpu_core \000event=0xad,period=1000003,umask=0x40,frontend=0x7\000\00000\000\000 */
{ 1073132 }, /* int_misc.uop_dropping\000cpu_core\000pipeline\000TMA slots where uops got dropped. Unit: cpu_core \000event=0xad,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1073469 }, /* int_vec_retired.128bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.128BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x13\000\00000\000\000 */
{ 1073690 }, /* int_vec_retired.256bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.256BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xac\000\00000\000\000 */
{ 1074028 }, /* int_vec_retired.add_128\000cpu_core\000pipeline\000integer ADD, SUB, SAD 128-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x3\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 128-bit vector instructions\000 */
{ 1074483 }, /* int_vec_retired.add_256\000cpu_core\000pipeline\000integer ADD, SUB, SAD 256-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xc\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 256-bit vector instructions\000 */
{ 1074823 }, /* int_vec_retired.mul_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.MUL_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x80\000\00000\000\000 */
{ 1075050 }, /* int_vec_retired.shuffles\000cpu_core\000pipeline\000INT_VEC_RETIRED.SHUFFLES. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x40\000\00000\000\000 */
{ 1075279 }, /* int_vec_retired.vnni_128\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_128. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x10\000\00000\000\000 */
{ 1075508 }, /* int_vec_retired.vnni_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x20\000\00000\000\000 */
{ 1190588 }, /* ld_blocks.4k_alias\000cpu_atom\000pipeline\000This event is deprecated. Refer to new event LD_BLOCKS.ADDRESS_ALIAS (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x4\000\00010\000\000 */
{ 1191280 }, /* ld_blocks.address_alias\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1191573 }, /* ld_blocks.address_alias\000cpu_core\000pipeline\000False dependencies in MOB due to partial compare on address. Unit: cpu_core \000event=0x3,period=100003,umask=0x4\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000 */
{ 1193358 }, /* ld_blocks.data_unknown\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x1\000\00000\000\000 */
{ 1195369 }, /* ld_blocks.no_sr\000cpu_core\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use. Unit: cpu_core \000event=0x3,period=100003,umask=0x88\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1200660 }, /* ld_blocks.store_forward\000cpu_core\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded. Unit: cpu_core \000event=0x3,period=100003,umask=0x82\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1231657 }, /* load_hit_prefetch.swpf\000cpu_core\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch. Unit: cpu_core \000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1284548 }, /* lsd.cycles_active\000cpu_core\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder. Unit: cpu_core \000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285612 }, /* lsd.cycles_ok\000cpu_core\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder. Unit: cpu_core \000event=0xa8,cmask=6,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286583 }, /* lsd.uops\000cpu_core\000pipeline\000Number of Uops delivered by the LSD. Unit: cpu_core \000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1289143 }, /* machine_clears.count\000cpu_core\000pipeline\000Number of machine clears (nukes) of any type. Unit: cpu_core \000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1290829 }, /* machine_clears.disambiguation\000cpu_atom\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x8\000\00000\000\000 */
{ 1298295 }, /* machine_clears.mrn_nuke\000cpu_atom\000pipeline\000Counts the number of machines clears due to memory renaming. Unit: cpu_atom \000event=0xc3,period=1000003,umask=0x80\000\00000\000\000 */
{ 1299052 }, /* machine_clears.page_fault\000cpu_atom\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x20\000\00000\000\000 */
{ 1299627 }, /* machine_clears.slow\000cpu_atom\000pipeline\000Counts the number of machine clears that flush the pipeline and restart the machine with the use of microcode due to SMC, MEMORY_ORDERING, FP_ASSISTS, PAGE_FAULT, DISAMBIGUATION, and FPC_VIRTUAL_TRAP. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x6f\000\00000\000\000 */
{ 1302278 }, /* machine_clears.smc\000cpu_atom\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x1\000\00000\000\000 */
{ 1302501 }, /* machine_clears.smc\000cpu_core\000pipeline\000Self-modifying code (SMC) detected. Unit: cpu_core \000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431272 }, /* misc2_retired.lfence\000cpu_core\000pipeline\000LFENCE instructions retired. Unit: cpu_core \000event=0xe0,period=400009,umask=0x20\000\00000\000number of LFENCE retired instructions\000 */
{ 1432117 }, /* misc_retired.lbr_inserts\000cpu_core\000pipeline\000Increments whenever there is an update to the LBR array. Unit: cpu_core \000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 2505879 }, /* resource_stalls.sb\000cpu_core\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync). Unit: cpu_core \000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506369 }, /* resource_stalls.scoreboard\000cpu_core\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations. Unit: cpu_core \000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2522348 }, /* serialization.non_c01_ms_scb\000cpu_atom\000pipeline\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. Unit: cpu_atom \000event=0x75,period=200003,umask=0x2\000\00000\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. The most commonly executed instruction with an MS scoreboard is PAUSE\000 */
{ 2544697 }, /* topdown.backend_bound_slots\000cpu_core\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x2\000\00000\000Number of slots in TMA method where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2546169 }, /* topdown.bad_spec_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculations. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x4\000\00000\000Number of slots of TMA method that were wasted due to incorrect speculation. It covers all types of control-flow or data-related mis-speculations\000 */
{ 2547291 }, /* topdown.br_mispredict_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of specualtive operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548278 }, /* topdown.memory_bound_slots\000cpu_core\000pipeline\000TOPDOWN.MEMORY_BOUND_SLOTS. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x10\000\00000\000\000 */
{ 2549042 }, /* topdown.slots\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event. Unit: cpu_core \000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2550166 }, /* topdown.slots_p\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 2554123 }, /* topdown_bad_speculation.all\000cpu_atom\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2555519 }, /* topdown_bad_speculation.fastnuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2556376 }, /* topdown_bad_speculation.machine_clears\000cpu_atom\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x3\000\00000\000\000 */
{ 2556887 }, /* topdown_bad_speculation.mispredict\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x4\000\00000\000\000 */
{ 2557460 }, /* topdown_bad_speculation.nuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to a machine clear (nuke). Unit: cpu_atom \000event=0x73,period=1000003,umask=0x1\000\00000\000\000 */
{ 2558146 }, /* topdown_be_bound.all\000cpu_atom\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000event=0x74,period=1000003\000\00000\000\000 */
{ 2558553 }, /* topdown_be_bound.alloc_restrictions\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x1\000\00000\000\000 */
{ 2559274 }, /* topdown_be_bound.mem_scheduler\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x2\000\00000\000\000 */
{ 2559876 }, /* topdown_be_bound.non_mem_scheduler\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x8\000\00000\000\000 */
{ 2560774 }, /* topdown_be_bound.register\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x20\000\00000\000\000 */
{ 2561253 }, /* topdown_be_bound.reorder_buffer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x40\000\00000\000\000 */
{ 2561995 }, /* topdown_be_bound.serialization\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x10\000\00000\000\000 */
{ 2562872 }, /* topdown_fe_bound.all\000cpu_atom\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls. Unit: cpu_atom \000event=0x71,period=1000003\000\00000\000\000 */
{ 2563611 }, /* topdown_fe_bound.branch_detect\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 2564742 }, /* topdown_fe_bound.branch_resteer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 2565722 }, /* topdown_fe_bound.cisc\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS). Unit: cpu_atom \000event=0x71,period=1000003,umask=0x1\000\00000\000\000 */
{ 2566327 }, /* topdown_fe_bound.decode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8\000\00000\000\000 */
{ 2566799 }, /* topdown_fe_bound.frontend_bandwidth\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8d\000\00000\000\000 */
{ 2567354 }, /* topdown_fe_bound.frontend_latency\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to a latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x72\000\00000\000\000 */
{ 2568858 }, /* topdown_fe_bound.itlb\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000 */
{ 2569843 }, /* topdown_fe_bound.other\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x80\000\00000\000\000 */
{ 2570478 }, /* topdown_fe_bound.predecode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x4\000\00000\000\000 */
{ 2571156 }, /* topdown_retiring.all\000cpu_atom\000pipeline\000Counts the total number of consumed retirement slots (Precise event). Unit: cpu_atom \000event=0xc2,period=1000003\000\00000\000\000 */
{ 6178833 }, /* uops_decoded.dec0_uops\000cpu_core\000pipeline\000UOPS_DECODED.DEC0_UOPS. Unit: cpu_core \000event=0x76,period=1000003,umask=0x1\000\00000\000\000 */
{ 6179893 }, /* uops_dispatched.port_0\000cpu_core\000pipeline\000Uops executed on port 0. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x1\000\00000\000Number of uops dispatch to execution  port 0\000 */
{ 6180437 }, /* uops_dispatched.port_1\000cpu_core\000pipeline\000Uops executed on port 1. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x2\000\00000\000Number of uops dispatch to execution  port 1\000 */
{ 6181022 }, /* uops_dispatched.port_2_3_10\000cpu_core\000pipeline\000Uops executed on ports 2, 3 and 10. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x4\000\00000\000Number of uops dispatch to execution ports 2, 3 and 10\000 */
{ 6181624 }, /* uops_dispatched.port_4_9\000cpu_core\000pipeline\000Uops executed on ports 4 and 9. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x10\000\00000\000Number of uops dispatch to execution ports 4 and 9\000 */
{ 6182204 }, /* uops_dispatched.port_5_11\000cpu_core\000pipeline\000Uops executed on ports 5 and 11. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x20\000\00000\000Number of uops dispatch to execution ports 5 and 11\000 */
{ 6182769 }, /* uops_dispatched.port_6\000cpu_core\000pipeline\000Uops executed on port 6. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x40\000\00000\000Number of uops dispatch to execution  port 6\000 */
{ 6183347 }, /* uops_dispatched.port_7_8\000cpu_core\000pipeline\000Uops executed on ports 7 and 8. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x80\000\00000\000Number of uops dispatch to execution  ports 7 and 8\000 */
{ 6194788 }, /* uops_executed.core_cycles_ge_1\000cpu_core\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195889 }, /* uops_executed.core_cycles_ge_2\000cpu_core\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196992 }, /* uops_executed.core_cycles_ge_3\000cpu_core\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6198095 }, /* uops_executed.core_cycles_ge_4\000cpu_core\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200192 }, /* uops_executed.cycles_ge_1\000cpu_core\000pipeline\000Cycles where at least 1 uop was executed per-thread. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201247 }, /* uops_executed.cycles_ge_2\000cpu_core\000pipeline\000Cycles where at least 2 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202318 }, /* uops_executed.cycles_ge_3\000cpu_core\000pipeline\000Cycles where at least 3 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203391 }, /* uops_executed.cycles_ge_4\000cpu_core\000pipeline\000Cycles where at least 4 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6206224 }, /* uops_executed.stall_cycles\000cpu_core\000pipeline\000This event is deprecated. Refer to new event UOPS_EXECUTED.STALLS. Unit: cpu_core \000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00010\000\000 */
{ 6206666 }, /* uops_executed.stalls\000cpu_core\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread. Unit: cpu_core \000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207515 }, /* uops_executed.thread\000cpu_core\000pipeline\000Counts the number of uops to be executed per-thread each cycle. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207824 }, /* uops_executed.x87\000cpu_core\000pipeline\000Counts the number of x87 uops dispatched. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6215795 }, /* uops_issued.any\000cpu_core\000pipeline\000Uops that RAT issues to RS. Unit: cpu_core \000event=0xae,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6227549 }, /* uops_retired.all\000cpu_atom\000pipeline\000Counts the total number of uops retired (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003\000\00000\000\000 */
{ 6228454 }, /* uops_retired.cycles\000cpu_core\000pipeline\000Cycles with retired uop(s). Unit: cpu_core \000event=0xc2,cmask=1,period=1000003,umask=0x2\000\00000\000Counts cycles where at least one uop has retired\000 */
{ 6229986 }, /* uops_retired.heavy\000cpu_core\000pipeline\000Retired uops except the last uop of each instruction. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of retired micro-operations (uops) except the last uop of each instruction. An instruction that is decoded into less than two uops does not contribute to the count\000 */
{ 6230863 }, /* uops_retired.idiv\000cpu_atom\000pipeline\000Counts the number of integer divide uops retired (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x10\000\00000\000\000 */
{ 6232567 }, /* uops_retired.ms\000cpu_atom\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000 */
{ 6233266 }, /* uops_retired.ms\000cpu_core\000pipeline\000UOPS_RETIRED.MS. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x4,frontend=0x8\000\00000\000\000 */
{ 6237112 }, /* uops_retired.slots\000cpu_core\000pipeline\000Retirement slots used. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6239040 }, /* uops_retired.stall_cycles\000cpu_core\000pipeline\000This event is deprecated. Refer to new event UOPS_RETIRED.STALLS. Unit: cpu_core \000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00010\000\000 */
{ 6239606 }, /* uops_retired.stalls\000cpu_core\000pipeline\000Cycles without actually retired uops. Unit: cpu_core \000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6241387 }, /* uops_retired.x87\000cpu_atom\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 2582567 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of requests allocated in Coherency Tracker. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2583135 }, /* unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2583633 }, /* unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000 */
{ 2583852 }, /* unc_arb_dat_requests.rd\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_REQ_TRK_REQUEST.DRD. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2584025 }, /* unc_arb_ifa_occupancy.all\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_DAT_OCCUPANCY.ALL. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2584198 }, /* unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_OCCUPANCY.RD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2584862 }, /* unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_REQUESTS.RD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2586544 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2588966 }, /* unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_OCCUPANCY.DRD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2589625 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Counts the number of coherent and in-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591214 }, /* unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_REQUEST.DRD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 5378499 }, /* unc_m_act_count_rd\000uncore_imc\000uncore memory\000ACT command for a read request sent to DRAM. Unit: uncore_imc \000event=0x24\000\00001\000\000 */
{ 5378622 }, /* unc_m_act_count_total\000uncore_imc\000uncore memory\000ACT command sent to DRAM. Unit: uncore_imc \000event=0x26\000\00001\000\000 */
{ 5378729 }, /* unc_m_act_count_wr\000uncore_imc\000uncore memory\000ACT command for a write request sent to DRAM. Unit: uncore_imc \000event=0x25\000\00001\000\000 */
{ 5393002 }, /* unc_m_cas_count_rd\000uncore_imc\000uncore memory\000Read CAS command sent to DRAM. Unit: uncore_imc \000event=0x22\000\00001\000\000 */
{ 5393111 }, /* unc_m_cas_count_wr\000uncore_imc\000uncore memory\000Write CAS command sent to DRAM. Unit: uncore_imc \000event=0x23\000\00001\000\000 */
{ 5395194 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Number of clocks. Unit: uncore_imc \000event=0x1\000\00001\000\000 */
{ 5396212 }, /* unc_m_dram_page_empty_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Empty. Unit: uncore_imc \000event=0x1d\000\00001\000\000 */
{ 5396345 }, /* unc_m_dram_page_empty_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Empty. Unit: uncore_imc \000event=0x20\000\00001\000\000 */
{ 5396479 }, /* unc_m_dram_page_hit_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Hit. Unit: uncore_imc \000event=0x1c\000\00001\000\000 */
{ 5396608 }, /* unc_m_dram_page_hit_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Hit. Unit: uncore_imc \000event=0x1f\000\00001\000\000 */
{ 5396738 }, /* unc_m_dram_page_miss_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Miss. Unit: uncore_imc \000event=0x1e\000\00001\000\000 */
{ 5396869 }, /* unc_m_dram_page_miss_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Miss. Unit: uncore_imc \000event=0x21\000\00001\000\000 */
{ 5398515 }, /* unc_m_dram_thermal_hot\000uncore_imc\000uncore memory\000Any Rank at Hot state. Unit: uncore_imc \000event=0x19\000\00001\000\000 */
{ 5398620 }, /* unc_m_dram_thermal_warm\000uncore_imc\000uncore memory\000Any Rank at Warm state. Unit: uncore_imc \000event=0x1a\000\00001\000\000 */
{ 5445969 }, /* unc_m_pre_count_idle\000uncore_imc\000uncore memory\000PRE command sent to DRAM due to page table idle timer expiration. Unit: uncore_imc \000event=0x28\000\00001\000\000 */
{ 5446115 }, /* unc_m_pre_count_page_miss\000uncore_imc\000uncore memory\000PRE command sent to DRAM for a read/write request. Unit: uncore_imc \000event=0x27\000\00001\000\000 */
{ 5448702 }, /* unc_m_prefetch_rd\000uncore_imc\000uncore memory\000Incoming read prefetch request from IA. Unit: uncore_imc \000event=0xa\000\00001\000\000 */
{ 5533656 }, /* unc_m_vc0_requests_rd\000uncore_imc\000uncore memory\000Incoming VC0 read request. Unit: uncore_imc \000event=0x2\000\00001\000\000 */
{ 5533763 }, /* unc_m_vc0_requests_wr\000uncore_imc\000uncore memory\000Incoming VC0 write request. Unit: uncore_imc \000event=0x3\000\00001\000\000 */
{ 5533871 }, /* unc_m_vc1_requests_rd\000uncore_imc\000uncore memory\000Incoming VC1 read request. Unit: uncore_imc \000event=0x4\000\00001\000\000 */
{ 5533978 }, /* unc_m_vc1_requests_wr\000uncore_imc\000uncore memory\000Incoming VC1 write request. Unit: uncore_imc \000event=0x5\000\00001\000\000 */
{ 5608104 }, /* unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B read  request entering the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read request entering the Memory Controller 0 to DRAM (sum of all channels)\000 */
{ 5610027 }, /* unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B write request entering the Memory Controller 0 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 5611083 }, /* unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B read request entering the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read entering the Memory Controller 1 to DRAM (sum of all channels)\000 */
{ 5612997 }, /* unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B write request entering the Memory Controller 1 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 3540559 }, /* unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 791804 }, /* dtlb_load_misses.stlb_hit\000cpu_core\000virtual memory\000Loads that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x12,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793668 }, /* dtlb_load_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load. Unit: cpu_core \000event=0x12,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 796289 }, /* dtlb_load_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size. Unit: cpu_atom \000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000 */
{ 796895 }, /* dtlb_load_misses.walk_completed\000cpu_core\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 799203 }, /* dtlb_load_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 1G page. Unit: cpu_core \000event=0x12,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802900 }, /* dtlb_load_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page. Unit: cpu_core \000event=0x12,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805730 }, /* dtlb_load_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 4K page. Unit: cpu_core \000event=0x12,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 809250 }, /* dtlb_load_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle. Unit: cpu_core \000event=0x12,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813841 }, /* dtlb_store_misses.stlb_hit\000cpu_core\000virtual memory\000Stores that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x13,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815698 }, /* dtlb_store_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. Unit: cpu_core \000event=0x13,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818622 }, /* dtlb_store_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size. Unit: cpu_atom \000event=0x49,period=2000003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 819030 }, /* dtlb_store_misses.walk_completed\000cpu_core\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 821337 }, /* dtlb_store_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 1G page. Unit: cpu_core \000event=0x13,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 824814 }, /* dtlb_store_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page. Unit: cpu_core \000event=0x13,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 827875 }, /* dtlb_store_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 4K page. Unit: cpu_core \000event=0x13,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 831097 }, /* dtlb_store_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle. Unit: cpu_core \000event=0x13,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1080403 }, /* itlb_misses.miss_caused_walk\000cpu_atom\000virtual memory\000Counts the number of page walks initiated by a instruction fetch that missed the first and second level TLBs. Unit: cpu_atom \000event=0x85,period=1000003,umask=0x1\000\00000\000\000 */
{ 1081905 }, /* itlb_misses.pde_cache_miss\000cpu_atom\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x80\000\00000\000\000 */
{ 1084095 }, /* itlb_misses.stlb_hit\000cpu_core\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB. Unit: cpu_core \000event=0x11,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085949 }, /* itlb_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. Unit: cpu_core \000event=0x11,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1088173 }, /* itlb_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size. Unit: cpu_atom \000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1088594 }, /* itlb_misses.walk_completed\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1093006 }, /* itlb_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M). Unit: cpu_core \000event=0x11,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1095351 }, /* itlb_misses.walk_completed_4k\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K). Unit: cpu_core \000event=0x11,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1098940 }, /* itlb_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle. Unit: cpu_core \000event=0x11,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 1204848 }, /* ld_head.dtlb_miss_at_ret\000cpu_atom\000virtual memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DTLB miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x90\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__alderlake[] = {
{ 3582 }, /* \000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000 */
{ 3686 }, /* \000C1_Core_Residency\000Power\000cstate_core@c1\\-residency@ / TSC\000\000C1 residency percent per core\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 4490 }, /* \000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000 */
{ 4591 }, /* \000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
{ 582876 }, /* cpu_atom\000tma_alloc_restriction\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.ALLOC_RESTRICTIONS / tma_info_core_slots\000tma_alloc_restriction > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to certain allocation restrictions. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 583180 }, /* cpu_atom\000tma_backend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_BE_BOUND.ALL / tma_info_core_slots\000tma_backend_bound > 0.1\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.   The rest of these subevents count backend stalls, in cycles, due to an outstanding request which is memory bound vs core bound.   The subevents are not slot based events and therefore can not be precisely added or subtracted from the Backend_Bound_Aux subevents which are slot based\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 583997 }, /* cpu_atom\000tma_backend_bound_aux\000Default;TopdownL1;tma_L1_group\000tma_backend_bound\000tma_backend_bound_aux > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that UOPS must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.  All of these subevents count backend stalls, in slots, due to a resource limitation.   These are not cycle based events and therefore can not be precisely added or subtracted from the Backend_Bound subevents which are cycle based.  These subevents are supplementary to Backend_Bound and can be used to analyze results from a resource perspective at allocation\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 584873 }, /* cpu_atom\000tma_bad_speculation\000Default;TopdownL1;tma_L1_group\000(tma_info_core_slots - (cpu_atom@TOPDOWN_FE_BOUND.ALL@ + cpu_atom@TOPDOWN_BE_BOUND.ALL@ + cpu_atom@TOPDOWN_RETIRING.ALL@)) / tma_info_core_slots\000tma_bad_speculation > 0.15\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ). Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 585895 }, /* cpu_atom\000tma_base\000TopdownL2;tma_L2_group;tma_retiring_group\000(cpu_atom@TOPDOWN_RETIRING.ALL@ - cpu_atom@UOPS_RETIRED.MS@) / tma_info_core_slots\000tma_base > 0.6\000Counts the number of uops that are not from the microsequencer. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 586153 }, /* cpu_atom\000tma_branch_detect\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_DETECT / tma_info_core_slots\000tma_branch_detect > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Unit: cpu_atom \000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000100%\000\000\000\00000 */
{ 586905 }, /* cpu_atom\000tma_branch_mispredicts\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MISPREDICT / tma_info_core_slots\000tma_branch_mispredicts > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to branch mispredicts. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 587208 }, /* cpu_atom\000tma_branch_resteer\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_RESTEER / tma_info_core_slots\000tma_branch_resteer > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 587555 }, /* cpu_atom\000tma_cisc\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.CISC / tma_info_core_slots\000tma_cisc > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to the microcode sequencer (MS). Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 587820 }, /* cpu_atom\000tma_core_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1\000Counts the number of cycles due to backend bound stalls that are core execution bound and not attributed to outstanding demand load or store stalls. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 588142 }, /* cpu_atom\000tma_decode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.DECODE / tma_info_core_slots\000tma_decode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to decode stalls. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 588398 }, /* cpu_atom\000tma_disambiguation\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.DISAMBIGUATION@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_disambiguation > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory disambiguation. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 588705 }, /* cpu_atom\000tma_dram_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_DRAM_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_DRAM_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_dram_bound > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM). Unit: cpu_atom \000\000100%\000\000\000\00001 */
{ 589174 }, /* cpu_atom\000tma_fast_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.FASTNUKE / tma_info_core_slots\000tma_fast_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear classified as a fast nuke due to memory ordering, memory disambiguation and memory renaming. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 589536 }, /* cpu_atom\000tma_fetch_bandwidth\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_BANDWIDTH / tma_info_core_slots\000tma_fetch_bandwidth > 0.1\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 589901 }, /* cpu_atom\000tma_fetch_latency\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_LATENCY / tma_info_core_slots\000tma_fetch_latency > 0.15\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 590261 }, /* cpu_atom\000tma_fp_assist\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.FP_ASSIST@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_fp_assist > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to FP assists. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 590542 }, /* cpu_atom\000tma_fpdiv_uops\000TopdownL3;tma_L3_group;tma_base_group\000UOPS_RETIRED.FPDIV / tma_info_core_slots\000tma_fpdiv_uops > 0.2\000Counts the number of floating point divide operations per uop. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 590756 }, /* cpu_atom\000tma_frontend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_FE_BOUND.ALL / tma_info_core_slots\000tma_frontend_bound > 0.2\000Counts the number of issue slots  that were not consumed by the backend due to frontend stalls. Unit: cpu_atom \000\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 591032 }, /* cpu_atom\000tma_icache_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ICACHE / tma_info_core_slots\000tma_icache_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to instruction cache misses. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 591311 }, /* cpu_atom\000tma_info_core_clks\000\000cpu_atom@CPU_CLK_UNHALTED.CORE@\000\000Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591396 }, /* cpu_atom\000tma_info_core_clks_p\000\000cpu_atom@CPU_CLK_UNHALTED.CORE_P@\000\000Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591485 }, /* cpu_atom\000tma_info_core_cpi\000\000tma_info_core_clks / INST_RETIRED.ANY\000\000Cycles Per Instruction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591599 }, /* cpu_atom\000tma_info_core_ipc\000\000INST_RETIRED.ANY / tma_info_core_clks\000\000Instructions Per Cycle. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591713 }, /* cpu_atom\000tma_info_core_slots\000\0005 * tma_info_core_clks\000\000Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591790 }, /* cpu_atom\000tma_info_core_upi\000\000UOPS_RETIRED.ALL / INST_RETIRED.ANY\000\000Uops Per Instruction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 591900 }, /* cpu_atom\000tma_info_frontend_inst_miss_cost_dramhit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_DRAM_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in DRAM. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 592119 }, /* cpu_atom\000tma_info_frontend_inst_miss_cost_l2hit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_L2_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in the L2. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 592336 }, /* cpu_atom\000tma_info_frontend_inst_miss_cost_l3hit_percent\000\000100 * cpu_atom@MEM_BOUND_STALLS.IFETCH_LLC_HIT@ / cpu_atom@MEM_BOUND_STALLS.IFETCH@\000\000Percent of instruction miss cost that hit in the L3. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 592554 }, /* cpu_atom\000tma_info_inst_mix_branch_mispredict_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.ALL_BRANCHES\000\000Ratio of all branches which mispredict. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 592730 }, /* cpu_atom\000tma_info_inst_mix_branch_mispredict_to_unknown_branch_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BACLEARS.ANY\000\000Ratio between Mispredicted branches and unknown branches. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 592926 }, /* cpu_atom\000tma_info_inst_mix_fpdiv_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.FPDIV@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are FPDiv uops. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593093 }, /* cpu_atom\000tma_info_inst_mix_idiv_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.IDIV@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are IDiv uops. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593257 }, /* cpu_atom\000tma_info_inst_mix_ipbranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurance rate). Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593434 }, /* cpu_atom\000tma_info_inst_mix_ipcall\000\000INST_RETIRED.ANY / BR_INST_RETIRED.CALL\000\000Instruction per (near) call (lower number means higher occurance rate). Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593605 }, /* cpu_atom\000tma_info_inst_mix_ipfarbranch\000\000INST_RETIRED.ANY / (cpu_atom@BR_INST_RETIRED.FAR_BRANCH@ / 2)\000\000Instructions per Far Branch. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593760 }, /* cpu_atom\000tma_info_inst_mix_ipload\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000\000Instructions per Load. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 593888 }, /* cpu_atom\000tma_info_inst_mix_ipmisp_cond_ntaken\000\000INST_RETIRED.ANY / (cpu_atom@BR_MISP_RETIRED.COND@ - cpu_atom@BR_MISP_RETIRED.COND_TAKEN@)\000\000Instructions per retired conditional Branch Misprediction where the branch was not taken. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594140 }, /* cpu_atom\000tma_info_inst_mix_ipmisp_cond_taken\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000\000Instructions per retired conditional Branch Misprediction where the branch was taken. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594342 }, /* cpu_atom\000tma_info_inst_mix_ipmisp_indirect\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000\000Instructions per retired indirect call or jump Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594523 }, /* cpu_atom\000tma_info_inst_mix_ipmisp_ret\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.RETURN\000\000Instructions per retired return Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594682 }, /* cpu_atom\000tma_info_inst_mix_ipmispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Instructions per retired Branch Misprediction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594842 }, /* cpu_atom\000tma_info_inst_mix_ipstore\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000\000Instructions per Store. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 594973 }, /* cpu_atom\000tma_info_inst_mix_microcode_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.MS@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are ucode ops. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 595140 }, /* cpu_atom\000tma_info_inst_mix_x87_uop_ratio\000\000100 * cpu_atom@UOPS_RETIRED.X87@ / UOPS_RETIRED.ALL\000\000Percentage of all uops which are x87 uops. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 595301 }, /* cpu_atom\000tma_info_l1_bound_address_alias_blocks\000\000100 * cpu_atom@LD_BLOCKS.4K_ALIAS@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a address aliasing block. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 595511 }, /* cpu_atom\000tma_info_l1_bound_load_splits\000\000100 * cpu_atom@MEM_UOPS_RETIRED.SPLIT_LOADS@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads that are splits. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 595708 }, /* cpu_atom\000tma_info_l1_bound_store_fwd_blocks\000\000100 * cpu_atom@LD_BLOCKS.DATA_UNKNOWN@ / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a store forward or unknown store address block. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 595940 }, /* cpu_atom\000tma_info_memory_cycles_per_demand_load_dram_hit\000\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_LOAD_UOPS_RETIRED.DRAM_HIT\000\000Cycle cost per DRAM hit. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596111 }, /* cpu_atom\000tma_info_memory_cycles_per_demand_load_l2_hit\000\000MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_LOAD_UOPS_RETIRED.L2_HIT\000\000Cycle cost per L2 hit. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596274 }, /* cpu_atom\000tma_info_memory_cycles_per_demand_load_l3_hit\000\000MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_LOAD_UOPS_RETIRED.L3_HIT\000\000Cycle cost per LLC hit. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596439 }, /* cpu_atom\000tma_info_memory_memloadpki\000\0001e3 * cpu_atom@MEM_UOPS_RETIRED.ALL_LOADS@ / INST_RETIRED.ANY\000\000load ops retired per 1000 instruction. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596601 }, /* cpu_atom\000tma_info_system_cpu_utilization\000\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596723 }, /* cpu_atom\000tma_info_system_kernel_utilization\000Summary\000cpu_atom@CPU_CLK_UNHALTED.CORE@k / CPU_CLK_UNHALTED.CORE\000\000Fraction of cycles spent in Kernel mode. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 596897 }, /* cpu_atom\000tma_info_system_turbo_utilization\000Power\000tma_info_core_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency. Unit: cpu_atom \000\000\000\000\000\00000 */
{ 597074 }, /* cpu_atom\000tma_itlb_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ITLB / tma_info_core_slots\000tma_itlb_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 597371 }, /* cpu_atom\000tma_l1_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000LD_HEAD.L1_BOUND_AT_RET / tma_info_core_clks\000tma_l1_bound > 0.1\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a load block. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 597644 }, /* cpu_atom\000tma_l2_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_L2_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_L2_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_l2_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 Cache. Unit: cpu_atom \000\000100%\000\000\000\00001 */
{ 598087 }, /* cpu_atom\000tma_l3_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_atom@MEM_BOUND_STALLS.LOAD_LLC_HIT@ / tma_info_core_clks - max((cpu_atom@MEM_BOUND_STALLS.LOAD@ - cpu_atom@LD_HEAD.L1_MISS_AT_RET@) / tma_info_core_clks, 0) * cpu_atom@MEM_BOUND_STALLS.LOAD_LLC_HIT@ / cpu_atom@MEM_BOUND_STALLS.LOAD@\000tma_l3_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 598574 }, /* cpu_atom\000tma_ld_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * cpu_atom@MEM_SCHEDULER_BLOCK.LD_BUF@ / MEM_SCHEDULER_BLOCK.ALL\000tma_ld_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to load buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 598902 }, /* cpu_atom\000tma_machine_clears\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MACHINE_CLEARS / tma_info_core_slots\000tma_machine_clears > 0.05\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 599304 }, /* cpu_atom\000tma_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.MEM_SCHEDULER / tma_info_core_slots\000tma_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 599637 }, /* cpu_atom\000tma_memory_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000min(cpu_atom@TOPDOWN_BE_BOUND.ALL@ / tma_info_core_slots, cpu_atom@LD_HEAD.ANY_AT_RET@ / tma_info_core_clks + tma_store_bound)\000tma_memory_bound > 0.2\000Counts the number of cycles the core is stalled due to stores or loads. Unit: cpu_atom \000\000100%\000\000TopdownL2\000\00000 */
{ 599968 }, /* cpu_atom\000tma_memory_ordering\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.MEMORY_ORDERING@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_memory_ordering > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory ordering. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 600272 }, /* cpu_atom\000tma_ms_uops\000TopdownL2;tma_L2_group;tma_retiring_group\000UOPS_RETIRED.MS / tma_info_core_slots\000tma_ms_uops > 0.05\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS). Unit: cpu_atom \000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows\000100%\000\000TopdownL2\000\00000 */
{ 600711 }, /* cpu_atom\000tma_non_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.NON_MEM_SCHEDULER / tma_info_core_slots\000tma_non_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 601137 }, /* cpu_atom\000tma_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.NUKE / tma_info_core_slots\000tma_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear (slow nuke). Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 601405 }, /* cpu_atom\000tma_other_fb\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.OTHER / tma_info_core_slots\000tma_other_fb > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to other common frontend stalls not categorized. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 601695 }, /* cpu_atom\000tma_other_l1\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.OTHER_AT_RET / tma_info_core_clks\000tma_other_l1 > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a number of other load blocks. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 601979 }, /* cpu_atom\000tma_other_load_store\000TopdownL3;tma_L3_group;tma_memory_bound_group\000max(0, tma_memory_bound - (tma_store_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_dram_bound))\000tma_other_load_store > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hits in the L2, LLC, DRAM or MMIO (Non-DRAM) but could not be correctly attributed or cycles in which the load miss is waiting on a request buffer. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 602444 }, /* cpu_atom\000tma_other_ret\000TopdownL3;tma_L3_group;tma_base_group\000(cpu_atom@TOPDOWN_RETIRING.ALL@ - cpu_atom@UOPS_RETIRED.MS@ - cpu_atom@UOPS_RETIRED.FPDIV@) / tma_info_core_slots\000tma_other_ret > 0.3\000Counts the number of uops retired excluding ms and fp div uops. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 602730 }, /* cpu_atom\000tma_page_fault\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.PAGE_FAULT@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_page_fault > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to page faults. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 603015 }, /* cpu_atom\000tma_predecode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.PREDECODE / tma_info_core_slots\000tma_predecode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to wrong predecodes. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 603283 }, /* cpu_atom\000tma_register\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REGISTER / tma_info_core_slots\000tma_register > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls). Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 603596 }, /* cpu_atom\000tma_reorder_buffer\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REORDER_BUFFER / tma_info_core_slots\000tma_reorder_buffer > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the reorder buffer being full (ROB stalls). Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 603901 }, /* cpu_atom\000tma_resource_bound\000TopdownL2;tma_L2_group;tma_backend_bound_aux_group\000tma_backend_bound\000tma_resource_bound > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls. Unit: cpu_atom \000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count\000100%\000\000TopdownL2\000\00000 */
{ 604412 }, /* cpu_atom\000tma_retiring\000Default;TopdownL1;tma_L1_group\000TOPDOWN_RETIRING.ALL / tma_info_core_slots\000tma_retiring > 0.75\000Counts the numer of issue slots  that result in retirement slots. Unit: cpu_atom \000\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 604647 }, /* cpu_atom\000tma_rsv\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * cpu_atom@MEM_SCHEDULER_BLOCK.RSV@ / MEM_SCHEDULER_BLOCK.ALL\000tma_rsv > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to RSV full relative. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 604961 }, /* cpu_atom\000tma_serialization\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.SERIALIZATION / tma_info_core_slots\000tma_serialization > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS). Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 605320 }, /* cpu_atom\000tma_smc\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (cpu_atom@MACHINE_CLEARS.SMC@ / cpu_atom@MACHINE_CLEARS.SLOW@)\000tma_smc > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to SMC. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 605576 }, /* cpu_atom\000tma_st_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_store_bound\000tma_st_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to store buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 605838 }, /* cpu_atom\000tma_stlb_hit\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.DTLB_MISS_AT_RET / tma_info_core_clks\000tma_stlb_hit > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a first level TLB miss. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 606119 }, /* cpu_atom\000tma_stlb_miss\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.PGWALK_AT_RET / tma_info_core_clks\000tma_stlb_miss > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a second level TLB miss requiring a page walk. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 606422 }, /* cpu_atom\000tma_store_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000tma_mem_scheduler * (cpu_atom@MEM_SCHEDULER_BLOCK.ST_BUF@ / cpu_atom@MEM_SCHEDULER_BLOCK.ALL@)\000tma_store_bound > 0.1\000Counts the number of cycles the core is stalled due to store buffer full. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 606711 }, /* cpu_atom\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.ST_ADDR_AT_RET / tma_info_core_clks\000tma_store_fwd_blk > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a store forward block. Unit: cpu_atom \000\000100%\000\000\000\00000 */
{ 649905 }, /* cpu_core\000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(cpu_core@UOPS_DISPATCHED.PORT_0@ + cpu_core@UOPS_DISPATCHED.PORT_1@ + cpu_core@UOPS_DISPATCHED.PORT_5_11@ + cpu_core@UOPS_DISPATCHED.PORT_6@) / (5 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 650325 }, /* cpu_core\000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * cpu_core@ASSISTS.ANY\\,umask\\=0x1B@ / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Unit: cpu_core \000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 651409 }, /* cpu_core\000tma_avx_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00063 * cpu_core@ASSISTS.SSE_AVX_MIX@ / tma_info_thread_slots\000tma_avx_assists > 0.1\000This metric estimates fraction of slots the CPU retired uops as a result of handing SSE to AVX* or AVX* to SSE transition Assists. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 651718 }, /* cpu_core\000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-be\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Unit: cpu_core \000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 652820 }, /* cpu_core\000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations. Unit: cpu_core \000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 653555 }, /* cpu_core\000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000cpu_core@topdown\\-br\\-mispredict@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction. Unit: cpu_core \000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000 */
{ 654495 }, /* cpu_core\000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 655276 }, /* cpu_core\000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. Unit: cpu_core \000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources. Sample with: FRONTEND_RETIRED.MS_FLOWS\000100%\000\000\000\00000 */
{ 656059 }, /* cpu_core\000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - tma_branch_mispredicts / tma_bad_speculation) * cpu_core@INT_MISC.CLEAR_RESTEER_CYCLES@ / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 656795 }, /* cpu_core\000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(25 * tma_info_system_average_frequency * (cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD@ * (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ / (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ + cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD@))) + 24 * tma_info_system_average_frequency * cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS@) * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Unit: cpu_core \000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 658185 }, /* cpu_core\000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck. Unit: cpu_core \000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000 */
{ 658959 }, /* cpu_core\000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00024 * tma_info_system_average_frequency * (cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD@ + cpu_core@MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD@ * (1 - cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ / (cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM@ + cpu_core@OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD@))) * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Unit: cpu_core \000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 660187 }, /* cpu_core\000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu_core@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu_core@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Unit: cpu_core \000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 660777 }, /* cpu_core\000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIV_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active. Unit: cpu_core \000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 661349 }, /* cpu_core\000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000cpu_core@MEMORY_ACTIVITY.STALLS_L3_MISS@ / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Unit: cpu_core \000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 661910 }, /* cpu_core\000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@IDQ.DSB_CYCLES_ANY@ - cpu_core@IDQ.DSB_CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline. Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 662588 }, /* cpu_core\000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 663596 }, /* cpu_core\000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu_core@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + cpu_core@DTLB_LOAD_MISSES.WALK_ACTIVE@, max(cpu_core@CYCLE_ACTIVITY.CYCLES_MEM_ANY@ - cpu_core@MEMORY_ACTIVITY.CYCLES_L1D_MISS@, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. Unit: cpu_core \000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 664822 }, /* cpu_core\000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu_core@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + cpu_core@DTLB_STORE_MISSES.WALK_ACTIVE@) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses. Unit: cpu_core \000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 665796 }, /* cpu_core\000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00028 * tma_info_system_average_frequency * cpu_core@OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM@ / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. Unit: cpu_core \000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 666626 }, /* cpu_core\000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. Unit: cpu_core \000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 667489 }, /* cpu_core\000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues. Unit: cpu_core \000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 668462 }, /* cpu_core\000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000cpu_core@topdown\\-fetch\\-lat@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) - cpu_core@INT_MISC.UOP_DROPPING@ / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues. Unit: cpu_core \000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 669328 }, /* cpu_core\000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000max(0, tma_heavy_operations - tma_microcode_sequencer)\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 669981 }, /* cpu_core\000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Unit: cpu_core \000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 670507 }, /* cpu_core\000tma_fp_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00030 * cpu_core@ASSISTS.FP@ / tma_info_thread_slots\000tma_fp_assists > 0.1\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. Unit: cpu_core \000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. FP Assist may apply when working with very small floating point values (so-called Denormals)\000100%\000\000\000\00000 */
{ 671008 }, /* cpu_core\000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. Unit: cpu_core \000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 671738 }, /* cpu_core\000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. Unit: cpu_core \000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 672545 }, /* cpu_core\000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. Unit: cpu_core \000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 673368 }, /* cpu_core\000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. Unit: cpu_core \000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 674191 }, /* cpu_core\000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-fe\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) - cpu_core@INT_MISC.UOP_DROPPING@ / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Unit: cpu_core \000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 675472 }, /* cpu_core\000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@INST_RETIRED.MACRO_FUSED@ / (tma_retiring * tma_info_thread_slots)\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000 */
{ 676121 }, /* cpu_core\000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000cpu_core@topdown\\-heavy\\-ops@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences. Sample with: UOPS_RETIRED.HEAVY\000100%\000\000TopdownL2\000\00000 */
{ 676887 }, /* cpu_core\000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_DATA.STALLS / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 677394 }, /* cpu_core\000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Unit: cpu_core \000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 678070 }, /* cpu_core\000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 678364 }, /* cpu_core\000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 678651 }, /* cpu_core\000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000cpu_core@BR_MISP_RETIRED.INDIRECT_CALL\\,umask\\=0x80@ / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 678971 }, /* cpu_core\000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 679226 }, /* cpu_core\000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 679519 }, /* cpu_core\000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts. Unit: cpu_core \000\000\000\000\000\00001 */
{ 679864 }, /* cpu_core\000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Unit: cpu_core \000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 680514 }, /* cpu_core\000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Unit: cpu_core \000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 680982 }, /* cpu_core\000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Unit: cpu_core \000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 681638 }, /* cpu_core\000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((cpu_core@BR_INST_RETIRED.COND@ + 3 * cpu_core@BR_INST_RETIRED.NEAR_CALL@ + (cpu_core@BR_INST_RETIRED.NEAR_TAKEN@ - cpu_core@BR_INST_RETIRED.COND_TAKEN@ - 2 * cpu_core@BR_INST_RETIRED.NEAR_CALL@)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Unit: cpu_core \000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 682261 }, /* cpu_core\000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks. Unit: cpu_core \000\000\000\000\000\00001 */
{ 682687 }, /* cpu_core\000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Unit: cpu_core \000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 683646 }, /* cpu_core\000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Unit: cpu_core \000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 684501 }, /* cpu_core\000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Unit: cpu_core \000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 685371 }, /* cpu_core\000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks. Unit: cpu_core \000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 685943 }, /* cpu_core\000tma_info_branches_callret\000Bad;Branches\000(cpu_core@BR_INST_RETIRED.NEAR_CALL@ + cpu_core@BR_INST_RETIRED.NEAR_RETURN@) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET. Unit: cpu_core \000\000\000\000\000\00000 */
{ 686167 }, /* cpu_core\000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals. Unit: cpu_core \000\000\000\000\000\00000 */
{ 686364 }, /* cpu_core\000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals. Unit: cpu_core \000\000\000\000\000\00000 */
{ 686556 }, /* cpu_core\000tma_info_branches_jump\000Bad;Branches\000(cpu_core@BR_INST_RETIRED.NEAR_TAKEN@ - cpu_core@BR_INST_RETIRED.COND_TAKEN@ - 2 * cpu_core@BR_INST_RETIRED.NEAR_CALL@) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps. Unit: cpu_core \000\000\000\000\000\00000 */
{ 686848 }, /* cpu_core\000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group). Unit: cpu_core \000\000\000\000\000\00000 */
{ 687144 }, /* cpu_core\000tma_info_core_core_clks\000SMT\000cpu_core@CPU_CLK_UNHALTED.DISTRIBUTED@\000\000Core actual clocks when any Logical Processor is active on the Physical Core. Unit: cpu_core \000\000\000\000\000\00000 */
{ 687322 }, /* cpu_core\000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core). Unit: cpu_core \000\000\000\000\000\00000 */
{ 687512 }, /* cpu_core\000tma_info_core_flopc\000Flops;Ret\000(cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle. Unit: cpu_core \000\000\000\000\000\00001 */
{ 687960 }, /* cpu_core\000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu_core@FP_ARITH_DISPATCHED.PORT_0@ + cpu_core@FP_ARITH_DISPATCHED.PORT_1@ + cpu_core@FP_ARITH_DISPATCHED.PORT_5@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Unit: cpu_core \000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 688573 }, /* cpu_core\000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu_core@UOPS_EXECUTED.CORE_CYCLES_GE_1@ / 2 if #SMT_on else cpu_core@UOPS_EXECUTED.CORE_CYCLES_GE_1@)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core. Unit: cpu_core \000\000\000\000\000\00000 */
{ 688880 }, /* cpu_core\000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / cpu_core@UOPS_ISSUED.ANY@\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 6 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Unit: cpu_core \000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 689348 }, /* cpu_core\000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu_core@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details. Unit: cpu_core \000\000\000\000\000\00000 */
{ 689639 }, /* cpu_core\000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu_core@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something. Unit: cpu_core \000\000\000\000\000\00000 */
{ 689835 }, /* cpu_core\000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_DATA.STALLS / cpu_core@ICACHE_DATA.STALLS\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses. Unit: cpu_core \000\000\000\000\000\00000 */
{ 690041 }, /* cpu_core\000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 690292 }, /* cpu_core\000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 690523 }, /* cpu_core\000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * cpu_core@FRONTEND_RETIRED.L2_MISS@ / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction. Unit: cpu_core \000\000\000\000\000\00000 */
{ 690711 }, /* cpu_core\000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * cpu_core@L2_RQSTS.CODE_RD_MISS@ / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction. Unit: cpu_core \000\000\000\000\000\00000 */
{ 690907 }, /* cpu_core\000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / cpu_core@UOPS_ISSUED.ANY@\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache). Unit: cpu_core \000\000\000\000\000\00000 */
{ 691094 }, /* cpu_core\000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch. Unit: cpu_core \000\000\000\000\000\00000 */
{ 691269 }, /* cpu_core\000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000cpu_core@INST_RETIRED.ANY@\000\000Total number of retired Instructions. Unit: cpu_core \000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 691498 }, /* cpu_core\000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 691991 }, /* cpu_core\000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 692491 }, /* cpu_core\000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 692985 }, /* cpu_core\000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 693437 }, /* cpu_core\000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). Unit: cpu_core \000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 693889 }, /* cpu_core\000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 694117 }, /* cpu_core\000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 694341 }, /* cpu_core\000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 694875 }, /* cpu_core\000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 695082 }, /* cpu_core\000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 695293 }, /* cpu_core\000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu_core@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate). Unit: cpu_core \000\000\000\000\000\00000 */
{ 695584 }, /* cpu_core\000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 13\000Instruction per taken branch. Unit: cpu_core \000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 695945 }, /* cpu_core\000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@L1D.REPLACEMENT@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 696153 }, /* cpu_core\000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@L2_LINES_IN.ALL@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 696355 }, /* cpu_core\000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * cpu_core@OFFCORE_REQUESTS.ALL_REQUESTS@ / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 696583 }, /* cpu_core\000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * cpu_core@LONGEST_LAT_CACHE.MISS@ / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 696792 }, /* cpu_core\000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries). Unit: cpu_core \000\000\000\000\000\00000 */
{ 697053 }, /* cpu_core\000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 697253 }, /* cpu_core\000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.ALL_DEMAND_DATA_RD@ / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative). Unit: cpu_core \000\000\000\000\000\00000 */
{ 697481 }, /* cpu_core\000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (cpu_core@L2_RQSTS.REFERENCES@ - cpu_core@L2_RQSTS.MISS@) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative). Unit: cpu_core \000\000\000\000\000\00000 */
{ 697722 }, /* cpu_core\000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.DEMAND_DATA_RD_HIT@ / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative). Unit: cpu_core \000\000\000\000\000\00000 */
{ 697944 }, /* cpu_core\000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L2_MISS@ / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 698152 }, /* cpu_core\000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * cpu_core@L2_RQSTS.MISS@ / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative). Unit: cpu_core \000\000\000\000\000\00000 */
{ 698383 }, /* cpu_core\000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * cpu_core@L2_RQSTS.DEMAND_DATA_RD_MISS@ / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative). Unit: cpu_core \000\000\000\000\000\00000 */
{ 698622 }, /* cpu_core\000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * cpu_core@MEM_LOAD_RETIRED.L3_MISS@ / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 698822 }, /* cpu_core\000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / MEM_LOAD_COMPLETED.L1_MISS_ANY\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles). Unit: cpu_core \000\000\000\000\000\00000 */
{ 699062 }, /* cpu_core\000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Unit: cpu_core \000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 699419 }, /* cpu_core\000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 699637 }, /* cpu_core\000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 699856 }, /* cpu_core\000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu_core@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 700094 }, /* cpu_core\000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.L3_MISS_DEMAND_DATA_RD / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads. Unit: cpu_core \000\000\000\000\000\00000 */
{ 700329 }, /* cpu_core\000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 700530 }, /* cpu_core\000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 700724 }, /* cpu_core\000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 700932 }, /* cpu_core\000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 701126 }, /* cpu_core\000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * cpu_core@ITLB_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000 */
{ 701391 }, /* cpu_core\000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * cpu_core@DTLB_LOAD_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000 */
{ 701666 }, /* cpu_core\000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(cpu_core@ITLB_MISSES.WALK_PENDING@ + cpu_core@DTLB_LOAD_MISSES.WALK_PENDING@ + cpu_core@DTLB_STORE_MISSES.WALK_PENDING@) / (4 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses. Unit: cpu_core \000\000\000\000\000\00000 */
{ 702065 }, /* cpu_core\000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * cpu_core@DTLB_STORE_MISSES.WALK_COMPLETED@ / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk). Unit: cpu_core \000\000\000\000\000\00000 */
{ 702343 }, /* cpu_core\000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu_core@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread. Unit: cpu_core \000\000\000\000\000\00000 */
{ 702593 }, /* cpu_core\000tma_info_pipeline_ipassist\000Pipeline;Ret;Retire\000INST_RETIRED.ANY / cpu_core@ASSISTS.ANY\\,umask\\=0x1B@\000tma_info_pipeline_ipassist < 100e3\000Instructions per a microcode Assist invocation. Unit: cpu_core \000Instructions per a microcode Assist invocation. See Assists tree node for details (lower number means higher occurrence rate)\000\000\000\000\00000 */
{ 702934 }, /* cpu_core\000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu_core@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired. Unit: cpu_core \000\000\000\000\000\00001 */
{ 703160 }, /* cpu_core\000tma_info_pipeline_strings_cycles\000Pipeline;Ret\000INST_RETIRED.REP_ITERATION / cpu_core@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000tma_info_pipeline_strings_cycles > 0.1\000Estimated fraction of retirement-cycles dealing with repeat instructions. Unit: cpu_core \000\000\000\000\000\00000 */
{ 703419 }, /* cpu_core\000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 703620 }, /* cpu_core\000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization. Unit: cpu_core \000\000\000\000\000\00000 */
{ 703753 }, /* cpu_core\000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Unit: cpu_core \000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 704178 }, /* cpu_core\000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu_core@FP_ARITH_INST_RETIRED.SCALAR_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.SCALAR_DOUBLE@ + 2 * cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE@ + 4 * (cpu_core@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE@ + cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE@) + 8 * cpu_core@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE@) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second. Unit: cpu_core \000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 704795 }, /* cpu_core\000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / cpu_core@BR_INST_RETIRED.FAR_BRANCH@u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]. Unit: cpu_core \000\000\000\000\000\00000 */
{ 705139 }, /* cpu_core\000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / cpu_core@INST_RETIRED.ANY_P@k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode. Unit: cpu_core \000\000\000\000\000\00000 */
{ 705328 }, /* cpu_core\000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode. Unit: cpu_core \000\000\000\000\000\00000 */
{ 705561 }, /* cpu_core\000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / cpu_core@UNC_ARB_DAT_OCCUPANCY.RD\\,cmask\\=1@\000\000Average number of parallel data read requests to external memory. Unit: cpu_core \000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 705896 }, /* cpu_core\000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\000(UNC_ARB_TRK_OCCUPANCY.RD + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.RD\000\000Average latency of data read request to external memory (in nanoseconds). Unit: cpu_core \000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 706286 }, /* cpu_core\000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles). Unit: cpu_core \000\000\000\000\000\00000 */
{ 706516 }, /* cpu_core\000tma_info_system_smt_2t_utilization\000SMT\000(1 - cpu_core@CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE@ / cpu_core@CPU_CLK_UNHALTED.REF_DISTRIBUTED@ if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active. Unit: cpu_core \000\000\000\000\000\00000 */
{ 706773 }, /* cpu_core\000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket. Unit: cpu_core \000\000\000\000\000\00000 */
{ 706916 }, /* cpu_core\000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency. Unit: cpu_core \000\000\000\000\000\00000 */
{ 707095 }, /* cpu_core\000tma_info_thread_clks\000Pipeline\000cpu_core@CPU_CLK_UNHALTED.THREAD@\000\000Per-Logical Processor actual clocks when the Logical Processor is active. Unit: cpu_core \000\000\000\000\000\00000 */
{ 707266 }, /* cpu_core\000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor). Unit: cpu_core \000\000\000\000\000\00000 */
{ 707404 }, /* cpu_core\000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops. Unit: cpu_core \000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 707708 }, /* cpu_core\000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor). Unit: cpu_core \000\000\000\000\000\00000 */
{ 707861 }, /* cpu_core\000tma_info_thread_slots\000TmaL1;tma_L1_group\000cpu_core@TOPDOWN.SLOTS@\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward). Unit: cpu_core \000\000\000\000\000\00000 */
{ 708050 }, /* cpu_core\000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (cpu_core@TOPDOWN.SLOTS@ / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor. Unit: cpu_core \000\000\000\000\000\00000 */
{ 708288 }, /* cpu_core\000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction. Unit: cpu_core \000\000\000\000\000\00000 */
{ 708469 }, /* cpu_core\000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 9\000Instruction per taken branch. Unit: cpu_core \000\000\000\000\000\00000 */
{ 708664 }, /* cpu_core\000tma_int_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_int_vector_128b + tma_int_vector_256b + tma_shuffles\000tma_int_operations > 0.1 & tma_light_operations > 0.6\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Unit: cpu_core \000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Vector/Matrix Int operations and shuffles are counted. Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain\000100%\000\000\000\00000 */
{ 709231 }, /* cpu_core\000tma_int_vector_128b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(cpu_core@INT_VEC_RETIRED.ADD_128@ + cpu_core@INT_VEC_RETIRED.VNNI_128@) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_128b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Unit: cpu_core \000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 710044 }, /* cpu_core\000tma_int_vector_256b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(cpu_core@INT_VEC_RETIRED.ADD_256@ + cpu_core@INT_VEC_RETIRED.MUL_256@ + cpu_core@INT_VEC_RETIRED.VNNI_256@) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_256b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Unit: cpu_core \000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 710893 }, /* cpu_core\000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_TAG.STALLS / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 711411 }, /* cpu_core\000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L1D_MISS@) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache. Unit: cpu_core \000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 712541 }, /* cpu_core\000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(cpu_core@MEMORY_ACTIVITY.STALLS_L1D_MISS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L2_MISS@) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads. Unit: cpu_core \000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 713163 }, /* cpu_core\000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(cpu_core@MEMORY_ACTIVITY.STALLS_L2_MISS@ - cpu_core@MEMORY_ACTIVITY.STALLS_L3_MISS@) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core. Unit: cpu_core \000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 713850 }, /* cpu_core\000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0009 * tma_info_system_average_frequency * cpu_core@MEM_LOAD_RETIRED.L3_HIT@ * (1 + cpu_core@MEM_LOAD_RETIRED.FB_HIT@ / cpu_core@MEM_LOAD_RETIRED.L1_MISS@ / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited). Unit: cpu_core \000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 714867 }, /* cpu_core\000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DECODE.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Unit: cpu_core \000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 715547 }, /* cpu_core\000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 716461 }, /* cpu_core\000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3_10 / (3 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00000 */
{ 716914 }, /* cpu_core\000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB). Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 717338 }, /* cpu_core\000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 717765 }, /* cpu_core\000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ - cpu_core@L2_RQSTS.ALL_RFO@) + cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@ * (10 * cpu_core@L2_RQSTS.RFO_HIT@ + min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO@))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Unit: cpu_core \000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 718717 }, /* cpu_core\000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@LSD.CYCLES_ACTIVE@ - cpu_core@LSD.CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit. Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000 */
{ 719463 }, /* cpu_core\000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears. Unit: cpu_core \000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000 */
{ 720395 }, /* cpu_core\000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM). Unit: cpu_core \000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 721571 }, /* cpu_core\000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD@) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM). Unit: cpu_core \000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 722383 }, /* cpu_core\000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000cpu_core@topdown\\-mem\\-bound@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck. Unit: cpu_core \000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000 */
{ 723331 }, /* cpu_core\000tma_memory_fence\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00013 * cpu_core@MISC2_RETIRED.LFENCE@ / tma_info_thread_clks\000tma_memory_fence > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to LFENCE Instructions. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 723763 }, /* cpu_core\000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@MEM_UOP_RETIRED.ANY@ / (tma_retiring * tma_info_thread_slots)\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses. Unit: cpu_core \000\000100%\000\000\000\00001 */
{ 724160 }, /* cpu_core\000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.MS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit. Unit: cpu_core \000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 724989 }, /* cpu_core\000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000tma_branch_mispredicts / tma_bad_speculation * cpu_core@INT_MISC.CLEAR_RESTEER_CYCLES@ / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 725808 }, /* cpu_core\000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(cpu_core@IDQ.MITE_CYCLES_ANY@ - cpu_core@IDQ.MITE_CYCLES_OK@) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). Unit: cpu_core \000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 726635 }, /* cpu_core\000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000160 * cpu_core@ASSISTS.SSE_AVX_MIX@ / tma_info_thread_clks\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Unit: cpu_core \000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 727182 }, /* cpu_core\000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * cpu_core@UOPS_RETIRED.MS\\,cmask\\=1\\,edge@ / (tma_retiring * tma_info_thread_slots / cpu_core@UOPS_ISSUED.ANY@) / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Unit: cpu_core \000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: FRONTEND_RETIRED.MS_FLOWS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 728541 }, /* cpu_core\000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (cpu_core@BR_INST_RETIRED.ALL_BRANCHES@ - cpu_core@INST_RETIRED.MACRO_FUSED@) / (tma_retiring * tma_info_thread_slots)\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000 */
{ 729212 }, /* cpu_core\000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * cpu_core@INST_RETIRED.NOP@ / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Unit: cpu_core \000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 729797 }, /* cpu_core\000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_int_operations + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. Unit: cpu_core \000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 730436 }, /* cpu_core\000tma_page_faults\000TopdownL5;tma_L5_group;tma_assists_group\00099 * cpu_core@ASSISTS.PAGE_FAULT@ / tma_info_thread_slots\000tma_page_faults > 0.05\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. Unit: cpu_core \000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. A Page Fault may apply on first application access to a memory page. Note operating system handling of page faults accounts for the majority of its cost\000100%\000\000\000\00000 */
{ 730972 }, /* cpu_core\000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 731655 }, /* cpu_core\000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 732262 }, /* cpu_core\000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 732933 }, /* cpu_core\000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu_core@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@) + (cpu_core@EXE_ACTIVITY.1_PORTS_UTIL@ + tma_retiring * cpu_core@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@)) / tma_info_thread_clks if cpu_core@ARITH.DIV_ACTIVE@ < cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@ else (cpu_core@EXE_ACTIVITY.1_PORTS_UTIL@ + tma_retiring * cpu_core@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related). Unit: cpu_core \000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 734284 }, /* cpu_core\000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu_core@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (cpu_core@CYCLE_ACTIVITY.STALLS_TOTAL@ - cpu_core@EXE_ACTIVITY.BOUND_ON_LOADS@) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 735096 }, /* cpu_core\000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 736233 }, /* cpu_core\000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 737276 }, /* cpu_core\000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Unit: cpu_core \000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 737958 }, /* cpu_core\000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000cpu_core@topdown\\-retiring@ / (cpu_core@topdown\\-fe\\-bound@ + cpu_core@topdown\\-bad\\-spec@ + cpu_core@topdown\\-retiring@ + cpu_core@topdown\\-be\\-bound@) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Unit: cpu_core \000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 739062 }, /* cpu_core\000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Unit: cpu_core \000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 739789 }, /* cpu_core\000tma_shuffles\000HPC;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group\000INT_VEC_RETIRED.SHUFFLES / (tma_retiring * tma_info_thread_slots)\000tma_shuffles > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents Shuffle (cross \"vector lane\" data transfers) uops fraction the CPU has retired. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 740145 }, /* cpu_core\000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000CPU_CLK_UNHALTED.PAUSE / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: CPU_CLK_UNHALTED.PAUSE_INST\000100%\000\000\000\00000 */
{ 740688 }, /* cpu_core\000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu_core@LD_BLOCKS.NO_SR@ / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Unit: cpu_core \000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 741262 }, /* cpu_core\000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses. Unit: cpu_core \000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 741780 }, /* cpu_core\000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(cpu_core@XQ.FULL_CYCLES@ + cpu_core@L1D_PEND_MISS.L2_STALLS@) / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Unit: cpu_core \000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 742526 }, /* cpu_core\000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Unit: cpu_core \000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 743299 }, /* cpu_core\000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * cpu_core@LD_BLOCKS.STORE_FORWARD@ / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. Unit: cpu_core \000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 744286 }, /* cpu_core\000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(cpu_core@MEM_STORE_RETIRED.L2_HIT@ * 10 * (1 - cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@) + (1 - cpu_core@MEM_INST_RETIRED.LOCK_LOADS@ / cpu_core@MEM_INST_RETIRED.ALL_STORES@) * min(cpu_core@CPU_CLK_UNHALTED.THREAD@, cpu_core@OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO@)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Unit: cpu_core \000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 745288 }, /* cpu_core\000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(cpu_core@UOPS_DISPATCHED.PORT_4_9@ + cpu_core@UOPS_DISPATCHED.PORT_7_8@) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Unit: cpu_core \000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 745788 }, /* cpu_core\000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB). Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 746202 }, /* cpu_core\000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk. Unit: cpu_core \000\000100%\000\000\000\00000 */
{ 746623 }, /* cpu_core\000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * cpu_core@OCR.STREAMING_WR.ANY_RESPONSE@ / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Unit: cpu_core \000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 747513 }, /* cpu_core\000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000INT_MISC.UNKNOWN_BRANCH_CYCLES / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. Unit: cpu_core \000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000 */
{ 748190 }, /* cpu_core\000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * cpu_core@UOPS_EXECUTED.X87@ / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage. Unit: cpu_core \000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__alderlaken[] = {
{ 1248632 }, /* longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1252437 }, /* longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1303294 }, /* mem_bound_stalls.ifetch\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000 */
{ 1304075 }, /* mem_bound_stalls.ifetch_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000 */
{ 1304822 }, /* mem_bound_stalls.ifetch_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache\000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000 */
{ 1305519 }, /* mem_bound_stalls.ifetch_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1306350 }, /* mem_bound_stalls.load\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x7\000\00000\000\000 */
{ 1306761 }, /* mem_bound_stalls.load_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x4\000\00000\000\000 */
{ 1307164 }, /* mem_bound_stalls.load_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache\000event=0x34,period=200003,umask=0x1\000\00000\000\000 */
{ 1307531 }, /* mem_bound_stalls.load_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1352752 }, /* mem_load_uops_retired.dram_hit\000\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x80\000\00000\000\000 */
{ 1359677 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000\000 */
{ 1362932 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x4\000\00000\000\000 */
{ 1367269 }, /* mem_scheduler_block.all\000\000cache\000Counts the number of cycles that uops are blocked for any of the following reasons:  load buffer, store buffer or RSV full\000event=0x4,period=20003,umask=0x7\000\00000\000\000 */
{ 1367678 }, /* mem_scheduler_block.ld_buf\000\000cache\000Counts the number of cycles that uops are blocked due to a load buffer full condition\000event=0x4,period=20003,umask=0x2\000\00000\000\000 */
{ 1368019 }, /* mem_scheduler_block.rsv\000\000cache\000Counts the number of cycles that uops are blocked due to an RSV full condition\000event=0x4,period=20003,umask=0x4\000\00000\000\000 */
{ 1368340 }, /* mem_scheduler_block.st_buf\000\000cache\000Counts the number of cycles that uops are blocked due to a store buffer full condition\000event=0x4,period=20003,umask=0x1\000\00000\000\000 */
{ 1389608 }, /* mem_uops_retired.all_loads\000\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000 */
{ 1392234 }, /* mem_uops_retired.all_stores\000\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000 */
{ 1398395 }, /* mem_uops_retired.load_latency_gt_128\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 128 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1400406 }, /* mem_uops_retired.load_latency_gt_16\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 16 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1403035 }, /* mem_uops_retired.load_latency_gt_256\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 256 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1405049 }, /* mem_uops_retired.load_latency_gt_32\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 32 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1407051 }, /* mem_uops_retired.load_latency_gt_4\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 4 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1409047 }, /* mem_uops_retired.load_latency_gt_512\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 512 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1411061 }, /* mem_uops_retired.load_latency_gt_64\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 64 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1413063 }, /* mem_uops_retired.load_latency_gt_8\000\000cache\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000Counts the number of tagged loads with an instruction latency that exceeds or equals the threshold of 8 cycles as defined in MEC_CR_PEBS_LD_LAT_THRESHOLD (3F6H). Only counts with PEBS enabled. If a PEBS record is generated, will populate the PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1417334 }, /* mem_uops_retired.split_loads\000\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x41\000\00000\000\000 */
{ 1423892 }, /* mem_uops_retired.store_latency\000\000cache\000Counts the number of stores uops retired. Counts with or without PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x6\000\00000\000Counts the number of stores uops retired. Counts with or without PEBS enabled. If PEBS is enabled and a PEBS record is generated, will populate PEBS Latency and PEBS Data Source fields accordingly  Supports address when precise (Must be precise)\000 */
{ 1552100 }, /* ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 1546082 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1547304 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1549344 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1580886 }, /* ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 1576915 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2567930 }, /* topdown_fe_bound.icache\000\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses\000event=0x71,period=1000003,umask=0x20\000\00000\000\000 */
{ 1291322 }, /* machine_clears.fp_assist\000\000floating point\000Counts the number of floating point operations retired that required microcode assist\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000 */
{ 6228633 }, /* uops_retired.fpdiv\000\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event)\000event=0xc2,period=2000003,umask=0x8\000\00000\000\000 */
{ 475317 }, /* baclears.any\000\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 983063 }, /* icache.accesses\000\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line\000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 989052 }, /* icache.misses\000\000frontend\000Counts the number of instruction cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 1204035 }, /* ld_head.any_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to any number of reasons, including an L1 miss, WCB full, pagewalk, store address block or store data block, on a load that retires\000event=0x5,period=1000003,umask=0xff\000\00000\000\000 */
{ 1205081 }, /* ld_head.l1_bound_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to a core bound stall including a store address match, a DTLB miss or a page walk that detains the load from retiring\000event=0x5,period=1000003,umask=0xf4\000\00000\000\000 */
{ 1205668 }, /* ld_head.l1_miss_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DL1 miss\000event=0x5,period=1000003,umask=0x81\000\00000\000\000 */
{ 1206087 }, /* ld_head.other_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases\000event=0x5,period=1000003,umask=0xc0\000\00000\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases such as pipeline conflicts, fences, etc\000 */
{ 1206858 }, /* ld_head.pgwalk_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a pagewalk\000event=0x5,period=1000003,umask=0xa0\000\00000\000\000 */
{ 1207275 }, /* ld_head.st_addr_at_ret\000\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a store address match\000event=0x5,period=1000003,umask=0x84\000\00000\000\000 */
{ 1295858 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation\000event=0xc3,period=20003,umask=0x2\000\00000\000\000 */
{ 1559441 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000 */
{ 1560710 }, /* ocr.demand_data_rd.l3_miss_local\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000 */
{ 1588991 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000 */
{ 1591015 }, /* ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400002\000\00000\000\000 */
{ 1513803 }, /* ocr.corewb_m.any_response\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1572074 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 497910 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 502588 }, /* br_inst_retired.call\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_CALL (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00010\000\000 */
{ 503439 }, /* br_inst_retired.cond\000\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000 */
{ 504744 }, /* br_inst_retired.cond_taken\000\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000 */
{ 507645 }, /* br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 510764 }, /* br_inst_retired.ind_call\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT_CALL (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00010\000\000 */
{ 511123 }, /* br_inst_retired.indirect\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000 */
{ 512075 }, /* br_inst_retired.indirect_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000 */
{ 513900 }, /* br_inst_retired.jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00010\000\000 */
{ 514650 }, /* br_inst_retired.near_call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 517359 }, /* br_inst_retired.near_return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000 */
{ 521696 }, /* br_inst_retired.non_return_ind\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.INDIRECT (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00010\000\000 */
{ 523776 }, /* br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000\000 */
{ 525464 }, /* br_inst_retired.return\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.NEAR_RETURN (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00010\000\000 */
{ 527430 }, /* br_inst_retired.taken_jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_INST_RETIRED.COND_TAKEN (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00010\000\000 */
{ 538105 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 542361 }, /* br_misp_retired.cond\000\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 545045 }, /* br_misp_retired.cond_taken\000\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000 */
{ 548620 }, /* br_misp_retired.ind_call\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT_CALL (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00010\000\000 */
{ 549322 }, /* br_misp_retired.indirect\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 550360 }, /* br_misp_retired.indirect_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 554008 }, /* br_misp_retired.jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00010\000\000 */
{ 559080 }, /* br_misp_retired.non_return_ind\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.INDIRECT (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00010\000\000 */
{ 562117 }, /* br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 564563 }, /* br_misp_retired.taken_jcc\000\000pipeline\000This event is deprecated. Refer to new event BR_MISP_RETIRED.COND_TAKEN (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00010\000\000 */
{ 612440 }, /* cpu_clk_unhalted.core\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000 */
{ 615598 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 622318 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 634226 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 643347 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1\000 */
{ 646643 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 1044203 }, /* inst_retired.any\000\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000 */
{ 1052183 }, /* inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000 */
{ 1190434 }, /* ld_blocks.4k_alias\000\000pipeline\000This event is deprecated. Refer to new event LD_BLOCKS.ADDRESS_ALIAS (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00010\000\000 */
{ 1190767 }, /* ld_blocks.address_alias\000\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1192607 }, /* ld_blocks.data_unknown\000\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event)\000event=0x3,period=1000003,umask=0x1\000\00000\000\000 */
{ 1289828 }, /* machine_clears.disambiguation\000\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU\000event=0xc3,period=20003,umask=0x8\000\00000\000\000 */
{ 1298159 }, /* machine_clears.mrn_nuke\000\000pipeline\000Counts the number of machines clears due to memory renaming\000event=0xc3,period=1000003,umask=0x80\000\00000\000\000 */
{ 1298456 }, /* machine_clears.page_fault\000\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs\000event=0xc3,period=20003,umask=0x20\000\00000\000\000 */
{ 1299357 }, /* machine_clears.slow\000\000pipeline\000Counts the number of machine clears that flush the pipeline and restart the machine with the use of microcode due to SMC, MEMORY_ORDERING, FP_ASSISTS, PAGE_FAULT, DISAMBIGUATION, and FPC_VIRTUAL_TRAP\000event=0xc3,period=20003,umask=0x6f\000\00000\000\000 */
{ 1299922 }, /* machine_clears.smc\000\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page\000event=0xc3,period=20003,umask=0x1\000\00000\000\000 */
{ 2521813 }, /* serialization.non_c01_ms_scb\000\000pipeline\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires\000event=0x75,period=200003,umask=0x2\000\00000\000Counts the number of issue slots not consumed by the backend due to a micro-sequencer (MS) scoreboard, which stalls the front-end from issuing from the UROM until a specified older uop retires. The most commonly executed instruction with an MS scoreboard is PAUSE\000 */
{ 2552383 }, /* topdown_bad_speculation.all\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2555005 }, /* topdown_bad_speculation.fastnuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears\000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2556085 }, /* topdown_bad_speculation.machine_clears\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000event=0x73,period=1000003,umask=0x3\000\00000\000\000 */
{ 2556692 }, /* topdown_bad_speculation.mispredict\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts\000event=0x73,period=1000003,umask=0x4\000\00000\000\000 */
{ 2557267 }, /* topdown_bad_speculation.nuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to a machine clear (nuke)\000event=0x73,period=1000003,umask=0x1\000\00000\000\000 */
{ 2557813 }, /* topdown_be_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls\000event=0x74,period=1000003\000\00000\000\000 */
{ 2558344 }, /* topdown_be_bound.alloc_restrictions\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions\000event=0x74,period=1000003,umask=0x1\000\00000\000\000 */
{ 2559028 }, /* topdown_be_bound.mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x2\000\00000\000\000 */
{ 2559545 }, /* topdown_be_bound.non_mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x8\000\00000\000\000 */
{ 2560232 }, /* topdown_be_bound.register\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000event=0x74,period=1000003,umask=0x20\000\00000\000\000 */
{ 2561036 }, /* topdown_be_bound.reorder_buffer\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000event=0x74,period=1000003,umask=0x40\000\00000\000\000 */
{ 2561495 }, /* topdown_be_bound.serialization\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000event=0x74,period=1000003,umask=0x10\000\00000\000\000 */
{ 2562536 }, /* topdown_fe_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls\000event=0x71,period=1000003\000\00000\000\000 */
{ 2563071 }, /* topdown_fe_bound.branch_detect\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS\000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 2564383 }, /* topdown_fe_bound.branch_resteer\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS\000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 2565335 }, /* topdown_fe_bound.cisc\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS)\000event=0x71,period=1000003,umask=0x1\000\00000\000\000 */
{ 2565941 }, /* topdown_fe_bound.decode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls\000event=0x71,period=1000003,umask=0x8\000\00000\000\000 */
{ 2566533 }, /* topdown_fe_bound.frontend_bandwidth\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000event=0x71,period=1000003,umask=0x8d\000\00000\000\000 */
{ 2567090 }, /* topdown_fe_bound.frontend_latency\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to a latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses\000event=0x71,period=1000003,umask=0x72\000\00000\000\000 */
{ 2568540 }, /* topdown_fe_bound.itlb\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses\000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000 */
{ 2569631 }, /* topdown_fe_bound.other\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized\000event=0x71,period=1000003,umask=0x80\000\00000\000\000 */
{ 2570080 }, /* topdown_fe_bound.predecode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes\000event=0x71,period=1000003,umask=0x4\000\00000\000\000 */
{ 2570845 }, /* topdown_retiring.all\000\000pipeline\000Counts the total number of consumed retirement slots (Precise event)\000event=0xc2,period=1000003\000\00000\000\000 */
{ 6226738 }, /* uops_retired.all\000\000pipeline\000Counts the total number of uops retired (Precise event)\000event=0xc2,period=2000003\000\00000\000\000 */
{ 6230315 }, /* uops_retired.idiv\000\000pipeline\000Counts the number of integer divide uops retired (Precise event)\000event=0xc2,period=2000003,umask=0x10\000\00000\000\000 */
{ 6231578 }, /* uops_retired.ms\000\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000 */
{ 6241237 }, /* uops_retired.x87\000\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 2582567 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of requests allocated in Coherency Tracker. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2586544 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2589625 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Counts the number of coherent and in-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 5378499 }, /* unc_m_act_count_rd\000uncore_imc\000uncore memory\000ACT command for a read request sent to DRAM. Unit: uncore_imc \000event=0x24\000\00001\000\000 */
{ 5378622 }, /* unc_m_act_count_total\000uncore_imc\000uncore memory\000ACT command sent to DRAM. Unit: uncore_imc \000event=0x26\000\00001\000\000 */
{ 5378729 }, /* unc_m_act_count_wr\000uncore_imc\000uncore memory\000ACT command for a write request sent to DRAM. Unit: uncore_imc \000event=0x25\000\00001\000\000 */
{ 5393002 }, /* unc_m_cas_count_rd\000uncore_imc\000uncore memory\000Read CAS command sent to DRAM. Unit: uncore_imc \000event=0x22\000\00001\000\000 */
{ 5393111 }, /* unc_m_cas_count_wr\000uncore_imc\000uncore memory\000Write CAS command sent to DRAM. Unit: uncore_imc \000event=0x23\000\00001\000\000 */
{ 5395194 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Number of clocks. Unit: uncore_imc \000event=0x1\000\00001\000\000 */
{ 5396212 }, /* unc_m_dram_page_empty_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Empty. Unit: uncore_imc \000event=0x1d\000\00001\000\000 */
{ 5396345 }, /* unc_m_dram_page_empty_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Empty. Unit: uncore_imc \000event=0x20\000\00001\000\000 */
{ 5396479 }, /* unc_m_dram_page_hit_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Hit. Unit: uncore_imc \000event=0x1c\000\00001\000\000 */
{ 5396608 }, /* unc_m_dram_page_hit_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Hit. Unit: uncore_imc \000event=0x1f\000\00001\000\000 */
{ 5396738 }, /* unc_m_dram_page_miss_rd\000uncore_imc\000uncore memory\000incoming read request page status is Page Miss. Unit: uncore_imc \000event=0x1e\000\00001\000\000 */
{ 5396869 }, /* unc_m_dram_page_miss_wr\000uncore_imc\000uncore memory\000incoming write request page status is Page Miss. Unit: uncore_imc \000event=0x21\000\00001\000\000 */
{ 5398515 }, /* unc_m_dram_thermal_hot\000uncore_imc\000uncore memory\000Any Rank at Hot state. Unit: uncore_imc \000event=0x19\000\00001\000\000 */
{ 5398620 }, /* unc_m_dram_thermal_warm\000uncore_imc\000uncore memory\000Any Rank at Warm state. Unit: uncore_imc \000event=0x1a\000\00001\000\000 */
{ 5445969 }, /* unc_m_pre_count_idle\000uncore_imc\000uncore memory\000PRE command sent to DRAM due to page table idle timer expiration. Unit: uncore_imc \000event=0x28\000\00001\000\000 */
{ 5446115 }, /* unc_m_pre_count_page_miss\000uncore_imc\000uncore memory\000PRE command sent to DRAM for a read/write request. Unit: uncore_imc \000event=0x27\000\00001\000\000 */
{ 5448702 }, /* unc_m_prefetch_rd\000uncore_imc\000uncore memory\000Incoming read prefetch request from IA. Unit: uncore_imc \000event=0xa\000\00001\000\000 */
{ 5533656 }, /* unc_m_vc0_requests_rd\000uncore_imc\000uncore memory\000Incoming VC0 read request. Unit: uncore_imc \000event=0x2\000\00001\000\000 */
{ 5533763 }, /* unc_m_vc0_requests_wr\000uncore_imc\000uncore memory\000Incoming VC0 write request. Unit: uncore_imc \000event=0x3\000\00001\000\000 */
{ 5533871 }, /* unc_m_vc1_requests_rd\000uncore_imc\000uncore memory\000Incoming VC1 read request. Unit: uncore_imc \000event=0x4\000\00001\000\000 */
{ 5533978 }, /* unc_m_vc1_requests_wr\000uncore_imc\000uncore memory\000Incoming VC1 write request. Unit: uncore_imc \000event=0x5\000\00001\000\000 */
{ 5608104 }, /* unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B read  request entering the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read request entering the Memory Controller 0 to DRAM (sum of all channels)\000 */
{ 5610027 }, /* unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B write request entering the Memory Controller 0 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 5611083 }, /* unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B read request entering the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000Counts every 64B read entering the Memory Controller 1 to DRAM (sum of all channels)\000 */
{ 5612997 }, /* unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B write request entering the Memory Controller 1 to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 3540559 }, /* unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 794124 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size\000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000 */
{ 816146 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size\000event=0x49,period=2000003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1080208 }, /* itlb_misses.miss_caused_walk\000\000virtual memory\000Counts the number of page walks initiated by a instruction fetch that missed the first and second level TLBs\000event=0x85,period=1000003,umask=0x1\000\00000\000\000 */
{ 1081713 }, /* itlb_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache\000event=0x85,period=2000003,umask=0x80\000\00000\000\000 */
{ 1086987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1204640 }, /* ld_head.dtlb_miss_at_ret\000\000virtual memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DTLB miss\000event=0x5,period=1000003,umask=0x90\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__alderlaken[] = {
{ 3582 }, /* \000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000 */
{ 3686 }, /* \000C1_Core_Residency\000Power\000cstate_core@c1\\-residency@ / TSC\000\000C1 residency percent per core\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 4490 }, /* \000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000 */
{ 4591 }, /* \000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 50173 }, /* \000tma_alloc_restriction\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.ALLOC_RESTRICTIONS / tma_info_core_slots\000tma_alloc_restriction > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to certain allocation restrictions\000\000100%\000\000\000\00000 */
{ 60282 }, /* \000tma_backend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_BE_BOUND.ALL / tma_info_core_slots\000tma_backend_bound > 0.1\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.   The rest of these subevents count backend stalls, in cycles, due to an outstanding request which is memory bound vs core bound.   The subevents are not slot based events and therefore can not be precisely added or subtracted from the Backend_Bound_Aux subevents which are slot based\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 63873 }, /* \000tma_backend_bound_aux\000Default;TopdownL1;tma_L1_group\000tma_backend_bound\000tma_backend_bound_aux > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that UOPS must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count.  All of these subevents count backend stalls, in slots, due to a resource limitation.   These are not cycle based events and therefore can not be precisely added or subtracted from the Backend_Bound subevents which are cycle based.  These subevents are supplementary to Backend_Bound and can be used to analyze results from a resource perspective at allocation\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 65434 }, /* \000tma_bad_speculation\000Default;TopdownL1;tma_L1_group\000(tma_info_core_slots - (TOPDOWN_FE_BOUND.ALL + TOPDOWN_BE_BOUND.ALL + TOPDOWN_RETIRING.ALL)) / tma_info_core_slots\000tma_bad_speculation > 0.15\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ). Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 67170 }, /* \000tma_base\000TopdownL2;tma_L2_group;tma_retiring_group\000(TOPDOWN_RETIRING.ALL - UOPS_RETIRED.MS) / tma_info_core_slots\000tma_base > 0.6\000Counts the number of uops that are not from the microsequencer\000\000100%\000\000TopdownL2\000\00000 */
{ 67383 }, /* \000tma_branch_detect\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_DETECT / tma_info_core_slots\000tma_branch_detect > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend\000Counts the number of issue slots  that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000100%\000\000\000\00000 */
{ 72606 }, /* \000tma_branch_mispredicts\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MISPREDICT / tma_info_core_slots\000tma_branch_mispredicts > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to branch mispredicts\000\000100%\000\000TopdownL2\000\00000 */
{ 72884 }, /* \000tma_branch_resteer\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.BRANCH_RESTEER / tma_info_core_slots\000tma_branch_resteer > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000\000100%\000\000\000\00000 */
{ 74739 }, /* \000tma_cisc\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.CISC / tma_info_core_slots\000tma_cisc > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to the microcode sequencer (MS)\000\000100%\000\000\000\00000 */
{ 99571 }, /* \000tma_core_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1\000Counts the number of cycles due to backend bound stalls that are core execution bound and not attributed to outstanding demand load or store stalls\000\000100%\000\000TopdownL2\000\00000 */
{ 113433 }, /* \000tma_decode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.DECODE / tma_info_core_slots\000tma_decode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to decode stalls\000\000100%\000\000\000\00000 */
{ 115329 }, /* \000tma_disambiguation\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.DISAMBIGUATION / MACHINE_CLEARS.SLOW)\000tma_disambiguation > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory disambiguation\000\000100%\000\000\000\00000 */
{ 123623 }, /* \000tma_dram_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_BOUND_STALLS.LOAD\000tma_dram_bound > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000\000100%\000\000\000\00001 */
{ 153359 }, /* \000tma_fast_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.FASTNUKE / tma_info_core_slots\000tma_fast_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear classified as a fast nuke due to memory ordering, memory disambiguation and memory renaming\000\000100%\000\000\000\00000 */
{ 162460 }, /* \000tma_fetch_bandwidth\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_BANDWIDTH / tma_info_core_slots\000tma_fetch_bandwidth > 0.1\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000\000100%\000\000TopdownL2\000\00000 */
{ 166384 }, /* \000tma_fetch_latency\000TopdownL2;tma_L2_group;tma_frontend_bound_group\000TOPDOWN_FE_BOUND.FRONTEND_LATENCY / tma_info_core_slots\000tma_fetch_latency > 0.15\000Counts the number of issue slots  that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations\000\000100%\000\000TopdownL2\000\00000 */
{ 170133 }, /* \000tma_fp_assist\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.FP_ASSIST / MACHINE_CLEARS.SLOW)\000tma_fp_assist > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to FP assists\000\000100%\000\000\000\00000 */
{ 186081 }, /* \000tma_fpdiv_uops\000TopdownL3;tma_L3_group;tma_base_group\000UOPS_RETIRED.FPDIV / tma_info_core_slots\000tma_fpdiv_uops > 0.2\000Counts the number of floating point divide operations per uop\000\000100%\000\000\000\00000 */
{ 187466 }, /* \000tma_frontend_bound\000Default;TopdownL1;tma_L1_group\000TOPDOWN_FE_BOUND.ALL / tma_info_core_slots\000tma_frontend_bound > 0.2\000Counts the number of issue slots  that were not consumed by the backend due to frontend stalls\000\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 196200 }, /* \000tma_icache_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ICACHE / tma_info_core_slots\000tma_icache_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 217520 }, /* \000tma_info_core_clks\000\000CPU_CLK_UNHALTED.CORE\000\000\000\000\000\000\000\00000 */
{ 217572 }, /* \000tma_info_core_clks_p\000\000CPU_CLK_UNHALTED.CORE_P\000\000\000\000\000\000\000\00000 */
{ 218245 }, /* \000tma_info_core_cpi\000\000tma_info_core_clks / INST_RETIRED.ANY\000\000Cycles Per Instruction\000\000\000\000\000\00000 */
{ 224339 }, /* \000tma_info_core_ipc\000\000INST_RETIRED.ANY / tma_info_core_clks\000\000Instructions Per Cycle\000\000\000\000\000\00000 */
{ 224644 }, /* \000tma_info_core_slots\000\0005 * tma_info_core_clks\000\000\000\000\000\000\000\00000 */
{ 224698 }, /* \000tma_info_core_upi\000\000UOPS_RETIRED.ALL / INST_RETIRED.ANY\000\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 228181 }, /* \000tma_info_frontend_inst_miss_cost_dramhit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_DRAM_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in DRAM\000\000\000\000\000\00000 */
{ 228355 }, /* \000tma_info_frontend_inst_miss_cost_l2hit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_L2_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in the L2\000\000\000\000\000\00000 */
{ 228527 }, /* \000tma_info_frontend_inst_miss_cost_l3hit_percent\000\000100 * MEM_BOUND_STALLS.IFETCH_LLC_HIT / MEM_BOUND_STALLS.IFETCH\000\000Percent of instruction miss cost that hit in the L3\000\000\000\000\000\00000 */
{ 229748 }, /* \000tma_info_inst_mix_branch_mispredict_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.ALL_BRANCHES\000\000Ratio of all branches which mispredict\000\000\000\000\000\00000 */
{ 229899 }, /* \000tma_info_inst_mix_branch_mispredict_to_unknown_branch_ratio\000\000BR_MISP_RETIRED.ALL_BRANCHES / BACLEARS.ANY\000\000Ratio between Mispredicted branches and unknown branches\000\000\000\000\000\00000 */
{ 230070 }, /* \000tma_info_inst_mix_fpdiv_uop_ratio\000\000100 * UOPS_RETIRED.FPDIV / UOPS_RETIRED.ALL\000\000Percentage of all uops which are FPDiv uops\000\000\000\000\000\00000 */
{ 230202 }, /* \000tma_info_inst_mix_idiv_uop_ratio\000\000100 * UOPS_RETIRED.IDIV / UOPS_RETIRED.ALL\000\000Percentage of all uops which are IDiv uops\000\000\000\000\000\00000 */
{ 237917 }, /* \000tma_info_inst_mix_ipbranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurance rate)\000\000\000\000\000\00000 */
{ 238268 }, /* \000tma_info_inst_mix_ipcall\000\000INST_RETIRED.ANY / BR_INST_RETIRED.CALL\000\000Instruction per (near) call (lower number means higher occurance rate)\000\000\000\000\000\00000 */
{ 238414 }, /* \000tma_info_inst_mix_ipfarbranch\000\000INST_RETIRED.ANY / (BR_INST_RETIRED.FAR_BRANCH / 2)\000\000Instructions per Far Branch\000\000\000\000\000\00000 */
{ 241013 }, /* \000tma_info_inst_mix_ipload\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000\000Instructions per Load\000\000\000\000\000\00000 */
{ 241116 }, /* \000tma_info_inst_mix_ipmisp_cond_ntaken\000\000INST_RETIRED.ANY / (BR_MISP_RETIRED.COND - BR_MISP_RETIRED.COND_TAKEN)\000\000Instructions per retired conditional Branch Misprediction where the branch was not taken\000\000\000\000\000\00000 */
{ 241323 }, /* \000tma_info_inst_mix_ipmisp_cond_taken\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000\000Instructions per retired conditional Branch Misprediction where the branch was taken\000\000\000\000\000\00000 */
{ 241500 }, /* \000tma_info_inst_mix_ipmisp_indirect\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000\000Instructions per retired indirect call or jump Branch Misprediction\000\000\000\000\000\00000 */
{ 241656 }, /* \000tma_info_inst_mix_ipmisp_ret\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.RETURN\000\000Instructions per retired return Branch Misprediction\000\000\000\000\000\00000 */
{ 241790 }, /* \000tma_info_inst_mix_ipmispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Instructions per retired Branch Misprediction\000\000\000\000\000\00000 */
{ 242297 }, /* \000tma_info_inst_mix_ipstore\000\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000\000Instructions per Store\000\000\000\000\000\00000 */
{ 243975 }, /* \000tma_info_inst_mix_microcode_uop_ratio\000\000100 * UOPS_RETIRED.MS / UOPS_RETIRED.ALL\000\000Percentage of all uops which are ucode ops\000\000\000\000\000\00000 */
{ 244107 }, /* \000tma_info_inst_mix_x87_uop_ratio\000\000100 * UOPS_RETIRED.X87 / UOPS_RETIRED.ALL\000\000Percentage of all uops which are x87 uops\000\000\000\000\000\00000 */
{ 244233 }, /* \000tma_info_l1_bound_address_alias_blocks\000\000100 * LD_BLOCKS.4K_ALIAS / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a address aliasing block\000\000\000\000\000\00000 */
{ 244408 }, /* \000tma_info_l1_bound_load_splits\000\000100 * MEM_UOPS_RETIRED.SPLIT_LOADS / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads that are splits\000\000\000\000\000\00000 */
{ 244570 }, /* \000tma_info_l1_bound_store_fwd_blocks\000\000100 * LD_BLOCKS.DATA_UNKNOWN / MEM_UOPS_RETIRED.ALL_LOADS\000\000Percentage of total non-speculative loads with a store forward or unknown store address block\000\000\000\000\000\00000 */
{ 245946 }, /* \000tma_info_memory_cycles_per_demand_load_dram_hit\000\000MEM_BOUND_STALLS.LOAD_DRAM_HIT / MEM_LOAD_UOPS_RETIRED.DRAM_HIT\000\000Cycle cost per DRAM hit\000\000\000\000\000\00000 */
{ 246092 }, /* \000tma_info_memory_cycles_per_demand_load_l2_hit\000\000MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_LOAD_UOPS_RETIRED.L2_HIT\000\000Cycle cost per L2 hit\000\000\000\000\000\00000 */
{ 246230 }, /* \000tma_info_memory_cycles_per_demand_load_l3_hit\000\000MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_LOAD_UOPS_RETIRED.L3_HIT\000\000Cycle cost per LLC hit\000\000\000\000\000\00000 */
{ 249773 }, /* \000tma_info_memory_memloadpki\000\0001e3 * MEM_UOPS_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000load ops retired per 1000 instruction\000\000\000\000\000\00000 */
{ 257114 }, /* \000tma_info_system_cpu_utilization\000\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 264902 }, /* \000tma_info_system_kernel_utilization\000Summary\000cpu@CPU_CLK_UNHALTED.CORE@k / CPU_CLK_UNHALTED.CORE\000\000Fraction of cycles spent in Kernel mode\000\000\000\000\000\00000 */
{ 275747 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_core_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 284396 }, /* \000tma_itlb_misses\000TopdownL3;tma_L3_group;tma_fetch_latency_group\000TOPDOWN_FE_BOUND.ITLB / tma_info_core_slots\000tma_itlb_misses > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000\000100%\000\000\000\00000 */
{ 289070 }, /* \000tma_l1_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000LD_HEAD.L1_BOUND_AT_RET / tma_info_core_clks\000tma_l1_bound > 0.1\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a load block\000\000100%\000\000\000\00000 */
{ 293205 }, /* \000tma_l2_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_L2_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_L2_HIT / MEM_BOUND_STALLS.LOAD\000tma_l2_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 Cache\000\000100%\000\000\000\00001 */
{ 298425 }, /* \000tma_l3_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_BOUND_STALLS.LOAD_LLC_HIT / tma_info_core_clks - max((MEM_BOUND_STALLS.LOAD - LD_HEAD.L1_MISS_AT_RET) / tma_info_core_clks, 0) * MEM_BOUND_STALLS.LOAD_LLC_HIT / MEM_BOUND_STALLS.LOAD\000tma_l3_bound > 0.1\000Counts the number of cycles a core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000\000100%\000\000\000\00000 */
{ 312934 }, /* \000tma_ld_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * MEM_SCHEDULER_BLOCK.LD_BUF / MEM_SCHEDULER_BLOCK.ALL\000tma_ld_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to load buffer full\000\000100%\000\000\000\00000 */
{ 332460 }, /* \000tma_machine_clears\000TopdownL2;tma_L2_group;tma_bad_speculation_group\000TOPDOWN_BAD_SPECULATION.MACHINE_CLEARS / tma_info_core_slots\000tma_machine_clears > 0.05\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000\000100%\000\000TopdownL2\000\00000 */
{ 339885 }, /* \000tma_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.MEM_SCHEDULER / tma_info_core_slots\000tma_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000\000100%\000\000\000\00000 */
{ 347826 }, /* \000tma_memory_bound\000TopdownL2;tma_L2_group;tma_backend_bound_group\000min(tma_backend_bound, LD_HEAD.ANY_AT_RET / tma_info_core_clks + tma_store_bound)\000tma_memory_bound > 0.2\000Counts the number of cycles the core is stalled due to stores or loads\000\000100%\000\000TopdownL2\000\00000 */
{ 349528 }, /* \000tma_memory_ordering\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.MEMORY_ORDERING / MACHINE_CLEARS.SLOW)\000tma_memory_ordering > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to memory ordering\000\000100%\000\000\000\00000 */
{ 364554 }, /* \000tma_ms_uops\000TopdownL2;tma_L2_group;tma_retiring_group\000UOPS_RETIRED.MS / tma_info_core_slots\000tma_ms_uops > 0.05\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS)\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows\000100%\000\000TopdownL2\000\00000 */
{ 366207 }, /* \000tma_non_mem_scheduler\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.NON_MEM_SCHEDULER / tma_info_core_slots\000tma_non_mem_scheduler > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000\000100%\000\000\000\00000 */
{ 367695 }, /* \000tma_nuke\000TopdownL3;tma_L3_group;tma_machine_clears_group\000TOPDOWN_BAD_SPECULATION.NUKE / tma_info_core_slots\000tma_nuke > 0.05\000Counts the number of issue slots  that were not consumed by the backend due to a machine clear (slow nuke)\000\000100%\000\000\000\00000 */
{ 367938 }, /* \000tma_other_fb\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.OTHER / tma_info_core_slots\000tma_other_fb > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to other common frontend stalls not categorized\000\000100%\000\000\000\00000 */
{ 368203 }, /* \000tma_other_l1\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.OTHER_AT_RET / tma_info_core_clks\000tma_other_l1 > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a number of other load blocks\000\000100%\000\000\000\00000 */
{ 370238 }, /* \000tma_other_load_store\000TopdownL3;tma_L3_group;tma_memory_bound_group\000max(0, tma_memory_bound - (tma_store_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_dram_bound))\000tma_other_load_store > 0.1\000Counts the number of cycles the core is stalled due to a demand load miss which hits in the L2, LLC, DRAM or MMIO (Non-DRAM) but could not be correctly attributed or cycles in which the load miss is waiting on a request buffer\000\000100%\000\000\000\00000 */
{ 370678 }, /* \000tma_other_ret\000TopdownL3;tma_L3_group;tma_base_group\000(TOPDOWN_RETIRING.ALL - UOPS_RETIRED.MS - UOPS_RETIRED.FPDIV) / tma_info_core_slots\000tma_other_ret > 0.3\000Counts the number of uops retired excluding ms and fp div uops\000\000100%\000\000\000\00000 */
{ 370909 }, /* \000tma_page_fault\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.PAGE_FAULT / MACHINE_CLEARS.SLOW)\000tma_page_fault > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to page faults\000\000100%\000\000\000\00000 */
{ 420009 }, /* \000tma_predecode\000TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000TOPDOWN_FE_BOUND.PREDECODE / tma_info_core_slots\000tma_predecode > 0.05\000Counts the number of issue slots  that were not delivered by the frontend due to wrong predecodes\000\000100%\000\000\000\00000 */
{ 420252 }, /* \000tma_register\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REGISTER / tma_info_core_slots\000tma_register > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000\000100%\000\000\000\00000 */
{ 431523 }, /* \000tma_reorder_buffer\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.REORDER_BUFFER / tma_info_core_slots\000tma_reorder_buffer > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000\000100%\000\000\000\00000 */
{ 431803 }, /* \000tma_resource_bound\000TopdownL2;tma_L2_group;tma_backend_bound_aux_group\000tma_backend_bound\000tma_resource_bound > 0.2\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls\000Counts the total number of issue slots  that were not consumed by the backend due to backend stalls.  Note that uops must be available for consumption in order for this event to count.  If a uop is not available (IQ is empty), this event will not count\000100%\000\000TopdownL2\000\00000 */
{ 433318 }, /* \000tma_retiring\000Default;TopdownL1;tma_L1_group\000TOPDOWN_RETIRING.ALL / tma_info_core_slots\000tma_retiring > 0.75\000Counts the numer of issue slots  that result in retirement slots\000\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 435381 }, /* \000tma_rsv\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_mem_scheduler * MEM_SCHEDULER_BLOCK.RSV / MEM_SCHEDULER_BLOCK.ALL\000tma_rsv > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to RSV full relative\000\000100%\000\000\000\00000 */
{ 435660 }, /* \000tma_serialization\000TopdownL3;tma_L3_group;tma_resource_bound_group\000TOPDOWN_BE_BOUND.SERIALIZATION / tma_info_core_slots\000tma_serialization > 0.1\000Counts the number of issue slots  that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000\000100%\000\000\000\00000 */
{ 439817 }, /* \000tma_smc\000TopdownL4;tma_L4_group;tma_nuke_group\000tma_nuke * (MACHINE_CLEARS.SMC / MACHINE_CLEARS.SLOW)\000tma_smc > 0.02\000Counts the number of machine clears relative to the number of nuke slots due to SMC\000\000100%\000\000\000\00000 */
{ 447012 }, /* \000tma_st_buffer\000TopdownL4;tma_L4_group;tma_mem_scheduler_group\000tma_store_bound\000tma_st_buffer > 0.05\000Counts the number of cycles, relative to the number of mem_scheduler slots, in which uops are blocked due to store buffer full\000\000100%\000\000\000\00000 */
{ 447249 }, /* \000tma_stlb_hit\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.DTLB_MISS_AT_RET / tma_info_core_clks\000tma_stlb_hit > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a first level TLB miss\000\000100%\000\000\000\00000 */
{ 447505 }, /* \000tma_stlb_miss\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.PGWALK_AT_RET / tma_info_core_clks\000tma_stlb_miss > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a second level TLB miss requiring a page walk\000\000100%\000\000\000\00000 */
{ 450007 }, /* \000tma_store_bound\000TopdownL3;tma_L3_group;tma_memory_bound_group\000tma_mem_scheduler * (MEM_SCHEDULER_BLOCK.ST_BUF / MEM_SCHEDULER_BLOCK.ALL)\000tma_store_bound > 0.1\000Counts the number of cycles the core is stalled due to store buffer full\000\000100%\000\000\000\00000 */
{ 451203 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_HEAD.ST_ADDR_AT_RET / tma_info_core_clks\000tma_store_fwd_blk > 0.05\000Counts the number of cycles that the oldest load of the load buffer is stalled at retirement due to a store forward block\000\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__amdzen1[] = {
{ 1153075 }, /* l2_request_g1.all_no_prefetch\000\000cache\000\000event=0x60,umask=0xf9\000\00000\000\000 */
{ 481008 }, /* bp_de_redirect\000\000branch\000Decoder Overrides Existing Branch Prediction (speculative)\000event=0x91\000\00000\000\000 */
{ 481229 }, /* bp_dyn_ind_pred\000\000branch\000Dynamic Indirect Predictions\000event=0x8e\000\00000\000Indirect Branch Prediction for potential multi-target branch (speculative)\000 */
{ 481645 }, /* bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000 */
{ 483416 }, /* bp_l1_tlb_fetch_hit\000\000branch\000The number of instruction fetches that hit in the L1 ITLB\000event=0x94\000\00000\000\000 */
{ 486559 }, /* bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000 */
{ 483518 }, /* bp_l1_tlb_miss_l2_hit\000\000cache\000The number of instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000 */
{ 483645 }, /* bp_l1_tlb_miss_l2_miss\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs\000event=0x85\000\00000\000\000 */
{ 486833 }, /* bp_snp_re_sync\000\000cache\000The number of pipeline restarts caused by invalidating probes that hit on the instruction stream currently being executed. This would happen if the active instruction stream was being modified by another processor in an MP system - typically a highly unlikely event\000event=0x86\000\00000\000\000 */
{ 487207 }, /* bp_tlb_rel\000\000cache\000The number of ITLB reload requests\000event=0x99\000\00000\000\000 */
{ 979583 }, /* ic_cache_fill_l2\000\000cache\000The number of 64 byte instruction cache line was fulfilled from the L2 cache\000event=0x82\000\00000\000\000 */
{ 979993 }, /* ic_cache_fill_sys\000\000cache\000The number of 64 byte instruction cache line fulfilled from system memory or another cache\000event=0x83\000\00000\000\000 */
{ 980125 }, /* ic_cache_inval.fill_invalidated\000\000cache\000IC line invalidated due to overwriting fill response. The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x01\000\00000\000\000 */
{ 980400 }, /* ic_cache_inval.l2_invalidating_probe\000\000cache\000IC line invalidated due to L2 invalidating probe (external or LS). The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x02\000\00000\000\000 */
{ 980693 }, /* ic_fetch_stall.ic_stall_any\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle for any reason (nothing valid in pipe ICM1)\000event=0x87,umask=0x04\000\00000\000\000 */
{ 980867 }, /* ic_fetch_stall.ic_stall_back_pressure\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to back-pressure\000event=0x87,umask=0x01\000\00000\000\000 */
{ 981057 }, /* ic_fetch_stall.ic_stall_dq_empty\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to DQ empty\000event=0x87,umask=0x02\000\00000\000\000 */
{ 981237 }, /* ic_fw32\000\000cache\000The number of 32B fetch windows transferred from IC pipe to DE instruction decoder (includes non-cacheable and cacheable fill responses)\000event=0x80\000\00000\000\000 */
{ 981405 }, /* ic_fw32_miss\000\000cache\000The number of 32B fetch windows tried to read the L1 IC and missed in the full tag\000event=0x81\000\00000\000\000 */
{ 1116951 }, /* l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache requests in L2\000event=0x64,umask=0x07\000\00000\000\000 */
{ 1117282 }, /* l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request hit in L2 and Data cache request hit in L2 (all types)\000event=0x64,umask=0xf6\000\00000\000\000 */
{ 1117664 }, /* l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2 and Data cache request miss in L2 (all types)\000event=0x64,umask=0x09\000\00000\000\000 */
{ 1118069 }, /* l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit clean line in L2\000event=0x64,umask=0x02\000\00000\000\000 */
{ 1118609 }, /* l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000 */
{ 1119176 }, /* l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1119879 }, /* l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache request miss in L2 (all types)\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1120222 }, /* l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000 */
{ 1120763 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit on shared line in L2\000event=0x64,umask=0x20\000\00000\000\000 */
{ 1121305 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit in L2\000event=0x64,umask=0x40\000\00000\000\000 */
{ 1121647 }, /* l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000 */
{ 1124209 }, /* l2_fill_pending.l2_fill_busy\000\000cache\000Cycles with fill pending from L2. Total cycles spent with one or more fill requests in flight from L2\000event=0x6d,umask=0x01\000\00000\000\000 */
{ 1126302 }, /* l2_latency.l2_cycles_waiting_on_fills\000\000cache\000Total cycles spent waiting for L2 fills to complete from L3 or memory, divided by four. Event counts are for both threads. To calculate average latency, the number of fills from both threads must be used\000event=0x62,umask=0x01\000\00000\000\000 */
{ 1141845 }, /* l2_pf_hit_l2\000\000cache\000L2 prefetch hit in L2. Use l2_cache_hits_from_l2_hwpf instead\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1144140 }, /* l2_pf_miss_l2_hit_l3\000\000cache\000L2 prefetcher hits in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit the L3\000event=0x71,umask=0xff\000\00000\000\000 */
{ 1146349 }, /* l2_pf_miss_l2_l3\000\000cache\000L2 prefetcher misses in L3. All L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches\000event=0x72,umask=0xff\000\00000\000\000 */
{ 1153140 }, /* l2_request_g1.cacheable_ic_read\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1153385 }, /* l2_request_g1.change_to_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache state change requests. Request change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000 */
{ 1153887 }, /* l2_request_g1.group2\000\000cache\000Miscellaneous events covered in more detail by l2_request_g2 (PMCx061)\000event=0x60,umask=0x01\000\00000\000\000 */
{ 1154013 }, /* l2_request_g1.l2_hw_pf\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). L2 Prefetcher. All prefetches accepted by L2 pipeline, hit or miss. Types of PF and L2 hit/miss broken out in a separate perfmon event\000event=0x60,umask=0x02\000\00000\000\000 */
{ 1154396 }, /* l2_request_g1.ls_rd_blk_c_s\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000 */
{ 1154633 }, /* l2_request_g1.prefetch_l2_cmd\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). PrefetchL2Cmd\000event=0x60,umask=0x04\000\00000\000\000 */
{ 1154866 }, /* l2_request_g1.rd_blk_l\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache reads (including hardware and software prefetch)\000event=0x60,umask=0x80\000\00000\000\000 */
{ 1155163 }, /* l2_request_g1.rd_blk_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache stores\000event=0x60,umask=0x40\000\00000\000\000 */
{ 1155378 }, /* l2_request_g2.bus_locks_originator\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus locks\000event=0x61,umask=0x02\000\00000\000\000 */
{ 1155501 }, /* l2_request_g2.bus_locks_responses\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus lock response\000event=0x61,umask=0x01\000\00000\000\000 */
{ 1155631 }, /* l2_request_g2.group1\000\000cache\000Miscellaneous events covered in more detail by l2_request_g1 (PMCx060)\000event=0x61,umask=0x80\000\00000\000\000 */
{ 1155757 }, /* l2_request_g2.ic_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized\000event=0x61,umask=0x10\000\00000\000\000 */
{ 1155890 }, /* l2_request_g2.ic_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized non-cacheable\000event=0x61,umask=0x08\000\00000\000\000 */
{ 1156040 }, /* l2_request_g2.ls_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized\000event=0x61,umask=0x40\000\00000\000\000 */
{ 1156166 }, /* l2_request_g2.ls_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized non-cacheable\000event=0x61,umask=0x20\000\00000\000\000 */
{ 1156309 }, /* l2_request_g2.smc_inval\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Self-modifying code invalidates\000event=0x61,umask=0x04\000\00000\000\000 */
{ 1184186 }, /* l2_wcb_req.cl_zero\000\000cache\000LS to L2 WCB cache line zeroing requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) cache line zeroing requests\000event=0x63,umask=0x01\000\00000\000\000 */
{ 1184365 }, /* l2_wcb_req.wcb_close\000\000cache\000LS to L2 WCB close requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) close requests\000event=0x63,umask=0x20\000\00000\000\000 */
{ 1184520 }, /* l2_wcb_req.wcb_write\000\000cache\000LS to L2 WCB write requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) write requests\000event=0x63,umask=0x40\000\00000\000\000 */
{ 1184675 }, /* l2_wcb_req.zero_byte_store\000\000cache\000LS to L2 WCB zero byte store requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) zero byte store requests\000event=0x63,umask=0x04\000\00000\000\000 */
{ 1186252 }, /* l3_comb_clstr_state.other_l3_miss_typs\000amd_l3\000cache\000Other L3 Miss Request Types. Unit: amd_l3 \000event=0x6,umask=0xfe\000\00000\000\000 */
{ 1186373 }, /* l3_comb_clstr_state.request_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x6,umask=0x01\000\00000\000\000 */
{ 1186748 }, /* l3_lookup_state.all_l3_req_typs\000amd_l3\000cache\000All L3 Request Types. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187260 }, /* l3_request_g1.caching_l3_cache_accesses\000amd_l3\000cache\000Caching: L3 cache accesses. Unit: amd_l3 \000event=0x1,umask=0x80\000\00000\000\000 */
{ 6242650 }, /* xi_ccx_sdp_req1.all_l3_miss_req_typs\000amd_l3\000cache\000All L3 Miss Request Types. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x9a,umask=0x3f\000\00000\000\000 */
{ 6243018 }, /* xi_sys_fill_latency\000amd_l3\000cache\000L3 Cache Miss Latency. Total cycles for all transactions divided by 16. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x90,umask=0x00\000\00000\000\000 */
{ 835353 }, /* ex_div_busy\000\000core\000Div Cycles Busy count\000event=0xd3\000\00000\000\000 */
{ 835480 }, /* ex_div_count\000\000core\000Div Op Count\000event=0xd4\000\00000\000\000 */
{ 836541 }, /* ex_ret_brn\000\000core\000Retired Branch Instructions\000event=0xc2\000\00000\000The number of branch instructions retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 836953 }, /* ex_ret_brn_far\000\000core\000Retired Far Control Transfers\000event=0xc6\000\00000\000The number of far control transfers retired including far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts. Far control transfers are not subject to branch prediction\000 */
{ 837724 }, /* ex_ret_brn_ind_misp\000\000core\000Retired Indirect Branch Instructions Mispredicted\000event=0xca\000\00000\000\000 */
{ 837897 }, /* ex_ret_brn_misp\000\000core\000Retired Branch Instructions Mispredicted\000event=0xc3\000\00000\000The number of branch instructions retired, of any type, that were not correctly predicted. This includes those for which prediction is not attempted (far control transfers, exceptions and interrupts)\000 */
{ 838319 }, /* ex_ret_brn_resync\000\000core\000Retired Branch Resyncs\000event=0xc7\000\00000\000The number of resync branches. These reflect pipeline restarts due to certain microcode assists and events such as writes to the active instruction stream, among other things. Each occurrence reflects a restart penalty similar to a branch mispredict. This is relatively rare\000 */
{ 838816 }, /* ex_ret_brn_tkn\000\000core\000Retired Taken Branch Instructions\000event=0xc4\000\00000\000The number of taken branches that were retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 839124 }, /* ex_ret_brn_tkn_misp\000\000core\000Retired Taken Branch Instructions Mispredicted\000event=0xc5\000\00000\000The number of retired taken branch instructions that were mispredicted\000 */
{ 839359 }, /* ex_ret_cond\000\000core\000Retired Conditional Branch Instructions\000event=0xd1\000\00000\000\000 */
{ 839771 }, /* ex_ret_cops\000\000core\000Retired Uops\000event=0xc1\000\00000\000The number of uOps retired. This includes all processor activity (instructions, exceptions, interrupts, microcode assists, etc.). The number of events logged per cycle can vary from 0 to 4\000 */
{ 840193 }, /* ex_ret_fus_brnch_inst\000\000core\000The number of fused retired branch instructions retired per cycle. The number of events logged per cycle can vary from 0 to 3\000event=0x1d0\000\00000\000\000 */
{ 840714 }, /* ex_ret_instr\000\000core\000Retired Instructions\000event=0xc0\000\00000\000\000 */
{ 840826 }, /* ex_ret_mmx_fp_instr.mmx_instr\000\000core\000MMX instructions\000event=0xcb,umask=0x02\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. MMX instructions\000 */
{ 841217 }, /* ex_ret_mmx_fp_instr.sse_instr\000\000core\000SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000event=0xcb,umask=0x04\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000 */
{ 842134 }, /* ex_ret_mmx_fp_instr.x87_instr\000\000core\000x87 instructions\000event=0xcb,umask=0x01\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. x87 instructions\000 */
{ 842982 }, /* ex_ret_near_ret\000\000core\000Retired Near Returns\000event=0xc8\000\00000\000The number of near return instructions (RET or RET Iw) retired\000 */
{ 843278 }, /* ex_ret_near_ret_mispred\000\000core\000Retired Near Returns Mispredicted\000event=0xc9\000\00000\000The number of near returns retired that were not correctly predicted by the return address predictor. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction\000 */
{ 844063 }, /* ex_tagged_ibs_ops.ibs_count_rollover\000\000core\000Tagged IBS Ops. Number of times an op could not be tagged by IBS because of a previous tagged op that has not retired\000event=0x1cf,umask=0x04\000\00000\000\000 */
{ 844337 }, /* ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000 */
{ 844550 }, /* ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000 */
{ 779893 }, /* dram_channel_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780073 }, /* dram_channel_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x47,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780254 }, /* dram_channel_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x87,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780435 }, /* dram_channel_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780616 }, /* dram_channel_data_controller_4\000amd_df\000data fabric\000Unit: amd_df \000event=0x107,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780798 }, /* dram_channel_data_controller_5\000amd_df\000data fabric\000Unit: amd_df \000event=0x147,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780980 }, /* dram_channel_data_controller_6\000amd_df\000data fabric\000Unit: amd_df \000event=0x187,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 781162 }, /* dram_channel_data_controller_7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1c7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 2488348 }, /* remote_outbound_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7c7,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 0\000 */
{ 2488525 }, /* remote_outbound_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x807,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 1\000 */
{ 2488702 }, /* remote_outbound_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x847,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 2\000 */
{ 2488879 }, /* remote_outbound_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0x887,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 3\000 */
{ 911195 }, /* fp_num_mov_elim_scal_op.opt_potential\000\000floating point\000Number of Ops that are candidates for optimization (have Z-bit either set or pass)\000event=0x4,umask=0x04\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of Ops that are candidates for optimization (have Z-bit either set or pass)\000 */
{ 911851 }, /* fp_num_mov_elim_scal_op.optimized\000\000floating point\000Number of Scalar Ops optimized\000event=0x4,umask=0x08\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of Scalar Ops optimized\000 */
{ 912393 }, /* fp_num_mov_elim_scal_op.sse_mov_ops\000\000floating point\000Number of SSE Move Ops\000event=0x4,umask=0x01\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of SSE Move Ops\000 */
{ 912937 }, /* fp_num_mov_elim_scal_op.sse_mov_ops_elim\000\000floating point\000Number of SSE Move Ops eliminated\000event=0x4,umask=0x02\000\00000\000This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes. Number of SSE Move Ops eliminated\000 */
{ 921918 }, /* fp_ret_sse_avx_ops.all\000\000floating point\000All FLOPS\000event=0x3,umask=0xff\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000 */
{ 923271 }, /* fp_ret_sse_avx_ops.dp_add_sub_flops\000\000floating point\000Double precision add/subtract FLOPS\000event=0x3,umask=0x10\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision add/subtract FLOPS\000 */
{ 923579 }, /* fp_ret_sse_avx_ops.dp_div_flops\000\000floating point\000Double precision divide/square root FLOPS\000event=0x3,umask=0x40\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision divide/square root FLOPS\000 */
{ 923895 }, /* fp_ret_sse_avx_ops.dp_mult_add_flops\000\000floating point\000Double precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000event=0x3,umask=0x80\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000 */
{ 924268 }, /* fp_ret_sse_avx_ops.dp_mult_flops\000\000floating point\000Double precision multiply FLOPS\000event=0x3,umask=0x20\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Double precision multiply FLOPS\000 */
{ 926283 }, /* fp_ret_sse_avx_ops.sp_add_sub_flops\000\000floating point\000Single-precision add/subtract FLOPS\000event=0x3,umask=0x01\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision add/subtract FLOPS\000 */
{ 926591 }, /* fp_ret_sse_avx_ops.sp_div_flops\000\000floating point\000Single-precision divide/square root FLOPS\000event=0x3,umask=0x04\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision divide/square root FLOPS\000 */
{ 926907 }, /* fp_ret_sse_avx_ops.sp_mult_add_flops\000\000floating point\000Single precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000event=0x3,umask=0x08\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single precision multiply-add FLOPS. Multiply-add counts as 2 FLOPS\000 */
{ 927280 }, /* fp_ret_sse_avx_ops.sp_mult_flops\000\000floating point\000Single-precision multiply FLOPS\000event=0x3,umask=0x02\000\00000\000This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15. Single-precision multiply FLOPS\000 */
{ 928486 }, /* fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE bottom-executing uOps retired\000event=0x5,umask=0x01\000\00000\000The number of serializing Ops retired. SSE bottom-executing uOps retired\000 */
{ 928938 }, /* fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000event=0x5,umask=0x02\000\00000\000The number of serializing Ops retired. SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000 */
{ 930080 }, /* fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing uOps retired\000event=0x5,umask=0x04\000\00000\000The number of serializing Ops retired. x87 bottom-executing uOps retired\000 */
{ 930650 }, /* fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits\000event=0x5,umask=0x08\000\00000\000The number of serializing Ops retired. x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits\000 */
{ 930948 }, /* fp_retx87_fp_ops.add_sub_ops\000\000floating point\000Add/subtract Ops\000event=0x2,umask=0x01\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Add/subtract Ops\000 */
{ 931168 }, /* fp_retx87_fp_ops.all\000\000floating point\000All Ops\000event=0x2,umask=0x07\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8\000 */
{ 931353 }, /* fp_retx87_fp_ops.div_sqr_r_ops\000\000floating point\000Divide and square root Ops\000event=0x2,umask=0x04\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Divide and square root Ops\000 */
{ 931595 }, /* fp_retx87_fp_ops.mul_ops\000\000floating point\000Multiply Ops\000event=0x2,umask=0x02\000\00000\000The number of x87 floating-point Ops that have retired. The number of events logged per cycle can vary from 0 to 8. Multiply Ops\000 */
{ 931803 }, /* fp_sched_empty\000\000floating point\000This is a speculative event. The number of cycles in which the FPU scheduler is empty. Note that some Ops like FP loads bypass the scheduler\000event=0x1\000\00000\000\000 */
{ 934526 }, /* fpu_pipe_assignment.dual\000\000floating point\000Total number multi-pipe uOps assigned to all pipes\000event=0,umask=0xf0\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to all pipes\000 */
{ 931990 }, /* fpu_pipe_assignment.dual0\000\000floating point\000Total number multi-pipe uOps assigned to pipe 0\000event=0,umask=0x10\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 0\000 */
{ 932624 }, /* fpu_pipe_assignment.dual1\000\000floating point\000Total number multi-pipe uOps assigned to pipe 1\000event=0,umask=0x20\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 1\000 */
{ 933258 }, /* fpu_pipe_assignment.dual2\000\000floating point\000Total number multi-pipe uOps assigned to pipe 2\000event=0,umask=0x40\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 2\000 */
{ 933892 }, /* fpu_pipe_assignment.dual3\000\000floating point\000Total number multi-pipe uOps assigned to pipe 3\000event=0,umask=0x80\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number multi-pipe uOps assigned to pipe 3\000 */
{ 939877 }, /* fpu_pipe_assignment.total\000\000floating point\000Total number uOps assigned to all fpu pipes\000event=0,umask=0x0f\000\00000\000The number of operations (uOps) and dual-pipe uOps dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to all pipes\000 */
{ 935165 }, /* fpu_pipe_assignment.total0\000\000floating point\000Total number of fp uOps  on pipe 0\000event=0,umask=0x01\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 0\000 */
{ 935757 }, /* fpu_pipe_assignment.total1\000\000floating point\000Total number of fp uOps on pipe 1\000event=0,umask=0x02\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 1\000 */
{ 936942 }, /* fpu_pipe_assignment.total2\000\000floating point\000Total number of fp uOps on pipe 2\000event=0,umask=0x04\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 2\000 */
{ 938127 }, /* fpu_pipe_assignment.total3\000\000floating point\000Total number of fp uOps on pipe 3\000event=0,umask=0x08\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one-cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 3\000 */
{ 1259210 }, /* ls_dc_accesses\000\000memory\000The number of accesses to the data cache for load and store references. This may include certain microcode scratchpad accesses, although these are generally rare. Each increment represents an eight-byte access, although the instruction may only be accessing a portion of that. This event is a speculative event\000event=0x40\000\00000\000\000 */
{ 1259560 }, /* ls_dispatch.ld_dispatch\000\000memory\000Counts the number of loads dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000 */
{ 1260167 }, /* ls_dispatch.ld_st_dispatch\000\000memory\000Counts the number of operations dispatched to the LS unit. Unit Masks ADDed. Load-op-Stores\000event=0x29,umask=0x04\000\00000\000\000 */
{ 1260910 }, /* ls_dispatch.store_dispatch\000\000memory\000Counts the number of stores dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000 */
{ 1266648 }, /* ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a DC hit\000event=0x52,umask=0x01\000\00000\000\000 */
{ 1267080 }, /* ls_inef_sw_pref.mab_mch_cnt\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a match on an already-allocated miss request buffer\000event=0x52,umask=0x02\000\00000\000\000 */
{ 1267709 }, /* ls_l1_d_tlb_miss.all\000\000memory\000L1 DTLB Miss or Reload off all sizes\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1268178 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB Reload of a page of 1G size\000event=0x45,umask=0x08\000\00000\000\000 */
{ 1268406 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss of a page of 1G size\000event=0x45,umask=0x80\000\00000\000\000 */
{ 1269085 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB Reload of a page of 2M size\000event=0x45,umask=0x04\000\00000\000\000 */
{ 1269313 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss of a page of 2M size\000event=0x45,umask=0x40\000\00000\000\000 */
{ 1269857 }, /* ls_l1_d_tlb_miss.tlb_reload_32k_l2_hit\000\000memory\000L1 DTLB Reload of a page of 32K size\000event=0x45,umask=0x02\000\00000\000\000 */
{ 1269968 }, /* ls_l1_d_tlb_miss.tlb_reload_32k_l2_miss\000\000memory\000L1 DTLB Miss of a page of 32K size\000event=0x45,umask=0x20\000\00000\000\000 */
{ 1270213 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB Reload of a page of 4K size\000event=0x45,umask=0x01\000\00000\000\000 */
{ 1270441 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss of a page of 4K size\000event=0x45,umask=0x10\000\00000\000\000 */
{ 1272081 }, /* ls_locks.bus_lock\000\000memory\000Bus lock when a locked operations crosses a cache boundary or is done on an uncacheable memory type\000event=0x25,umask=0x01\000\00000\000\000 */
{ 1273345 }, /* ls_mab_alloc.dc_prefetcher\000\000memory\000LS MAB allocates by type - DC prefetcher\000event=0x41,umask=0x08\000\00000\000\000 */
{ 1274182 }, /* ls_mab_alloc.loads\000\000memory\000LS MAB allocates by type - loads\000event=0x41,umask=0x01\000\00000\000\000 */
{ 1274357 }, /* ls_mab_alloc.stores\000\000memory\000LS MAB allocates by type - stores\000event=0x41,umask=0x02\000\00000\000\000 */
{ 1274446 }, /* ls_misal_accesses\000\000memory\000Misaligned loads\000event=0x47\000\00000\000\000 */
{ 1274987 }, /* ls_not_halted_cyc\000\000memory\000Cycles not in Halt\000event=0x76\000\00000\000\000 */
{ 1275285 }, /* ls_pref_instr_disp.load_prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched. Prefetch, Prefetch_T0_T1_T2\000event=0x4b,umask=0x01\000\00000\000\000 */
{ 1276288 }, /* ls_pref_instr_disp.prefetch_nta\000\000memory\000Software Prefetch Instructions (PREFETCHNTA instruction) Dispatched\000event=0x4b,umask=0x04\000\00000\000\000 */
{ 1277094 }, /* ls_pref_instr_disp.store_prefetch_w\000\000memory\000Software Prefetch Instructions (3DNow PREFETCHW instruction) Dispatched\000event=0x4b,umask=0x02\000\00000\000\000 */
{ 1279391 }, /* ls_stlf\000\000memory\000Number of STLF hits\000event=0x35\000\00000\000\000 */
{ 1282357 }, /* ls_tablewalker.dc_type0\000\000memory\000Total Page Table Walks DC Type 0\000event=0x46,umask=0x01\000\00000\000\000 */
{ 1282449 }, /* ls_tablewalker.dc_type1\000\000memory\000Total Page Table Walks DC Type 1\000event=0x46,umask=0x02\000\00000\000\000 */
{ 1282541 }, /* ls_tablewalker.dside\000\000memory\000Total Page Table Walks on D-side\000event=0x46,umask=0x03\000\00000\000\000 */
{ 1282630 }, /* ls_tablewalker.ic_type0\000\000memory\000Total Page Table Walks IC Type 0\000event=0x46,umask=0x04\000\00000\000\000 */
{ 1282722 }, /* ls_tablewalker.ic_type1\000\000memory\000Total Page Table Walks IC Type 1\000event=0x46,umask=0x08\000\00000\000\000 */
{ 1282814 }, /* ls_tablewalker.iside\000\000memory\000Total Page Table Walks on I-side\000event=0x46,umask=0x0c\000\00000\000\000 */
{ 763465 }, /* de_dis_dispatch_token_stalls0.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x20\000\00000\000\000 */
{ 763659 }, /* de_dis_dispatch_token_stalls0.alsq1_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 1 Tokens unavailable\000event=0xaf,umask=0x01\000\00000\000\000 */
{ 763856 }, /* de_dis_dispatch_token_stalls0.alsq2_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 2 Tokens unavailable\000event=0xaf,umask=0x02\000\00000\000\000 */
{ 764053 }, /* de_dis_dispatch_token_stalls0.alsq3_0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 3_0 Tokens unavailable\000event=0xaf,umask=0x08\000\00000\000\000 */
{ 764446 }, /* de_dis_dispatch_token_stalls0.alsq3_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 3 Tokens unavailable\000event=0xaf,umask=0x04\000\00000\000\000 */
{ 764841 }, /* de_dis_dispatch_token_stalls0.alu_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALU tokens total unavailable\000event=0xaf,umask=0x10\000\00000\000\000 */
{ 765237 }, /* de_dis_dispatch_token_stalls0.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. RETIRE Tokens unavailable\000event=0xaf,umask=0x40\000\00000\000\000 */
{ 981632 }, /* ic_oc_mode_switch.ic_oc_mode_switch\000\000other\000OC Mode Switch. IC to OC mode switch\000event=0x28a,umask=0x01\000\00000\000\000 */
{ 981848 }, /* ic_oc_mode_switch.oc_ic_mode_switch\000\000other\000OC Mode Switch. OC to IC mode switch\000event=0x28a,umask=0x02\000\00000\000\000 */
{ 466489 }, /* all_dc_accesses\000\000recommended\000All L1 Data Cache Accesses\000event=0x29,umask=0x07\000\00000\000\000 */
{ 466572 }, /* all_tlbs_flushed\000\000recommended\000All TLBs Flushed\000event=0x78,umask=0xdf\000\00000\000\000 */
{ 1099832 }, /* l1_dtlb_misses\000\000recommended\000L1 DTLB Misses\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1115189 }, /* l2_cache_accesses_from_dc_misses\000\000recommended\000L2 Cache Accesses from L1 Data Cache Misses (including prefetch)\000event=0x60,umask=0xc8\000\00000\000\000 */
{ 1115465 }, /* l2_cache_accesses_from_ic_misses\000\000recommended\000L2 Cache Accesses from L1 Instruction Cache Misses (including prefetch)\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1115610 }, /* l2_cache_hits_from_dc_misses\000\000recommended\000L2 Cache Hits from L1 Data Cache Misses\000event=0x64,umask=0x70\000\00000\000\000 */
{ 1115828 }, /* l2_cache_hits_from_ic_misses\000\000recommended\000L2 Cache Hits from L1 Instruction Cache Misses\000event=0x64,umask=0x06\000\00000\000\000 */
{ 1116044 }, /* l2_cache_hits_from_l2_hwpf\000\000recommended\000L2 Cache Hits from L2 HWPF\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1116138 }, /* l2_cache_misses_from_dc_misses\000\000recommended\000L2 Cache Misses from L1 Data Cache Misses\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1116251 }, /* l2_cache_misses_from_ic_miss\000\000recommended\000L2 Cache Misses from L1 Instruction Cache Misses\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1124121 }, /* l2_dtlb_misses\000\000recommended\000L2 DTLB Misses & Data page walks\000event=0x45,umask=0xf0\000\00000\000\000 */
{ 1124926 }, /* l2_itlb_misses\000\000recommended\000L2 ITLB Misses & Instruction page walks\000event=0x85,umask=0x07\000\00000\000\000 */
{ 1185976 }, /* l3_accesses\000amd_l3\000recommended\000L3 Accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187040 }, /* l3_misses\000amd_l3\000recommended\000L3 Misses (includes Chg2X). Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000 */
{ 2536007 }, /* sse_avx_stalls\000\000recommended\000Mixed SSE/AVX Stalls\000event=0xe,umask=0x0e\000\00000\000\000 */
{ 6183632 }, /* uops_dispatched\000\000recommended\000Micro-ops Dispatched\000event=0xaa,umask=0x03\000\00000\000\000 */
{ 6241737 }, /* uops_retired\000\000recommended\000Micro-ops Retired\000event=0xc1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__amdzen1[] = {
{ 6782 }, /* \000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Accesses\000\000\000\000\000\00000 */
{ 7199 }, /* \000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2\000\000All L2 Cache Hits\000\000\000\000\000\00000 */
{ 7302 }, /* \000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Misses\000\000\000\000\000\00000 */
{ 7580 }, /* \000all_remote_links_outbound\000data_fabric\000remote_outbound_data_controller_0 + remote_outbound_data_controller_1 + remote_outbound_data_controller_2 + remote_outbound_data_controller_3\000\000Approximate: Outbound data bytes for all Remote Links for a node (die)\000\0003e-5MiB\000\000\000\00000 */
{ 9223 }, /* \000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-Time Branch Misprediction Ratio (Non-Speculative)\000\000100%\000\000\000\00000 */
{ 16418 }, /* \000ic_fetch_miss_ratio\000l2_cache\000d_ratio(l2_cache_req_stat.ic_access_in_l2, bp_l1_tlb_fetch_hit + bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_miss)\000\000L1 Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000 */
{ 22730 }, /* \000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000 */
{ 24041 }, /* \000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Accesses from L2 HWPF\000\000\000\000\000\00000 */
{ 25073 }, /* \000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Misses from L2 HWPF\000\000\000\000\000\00000 */
{ 27117 }, /* \000l3_read_miss_latency\000l3_cache\000xi_sys_fill_latency * 16 / xi_ccx_sdp_req1.all_l3_miss_req_typs\000\000Average L3 Read Miss Latency (in core clocks)\000\0001core clocks\000\000\000\00000 */
{ 40023 }, /* \000nps1_die_to_dram\000data_fabric\000dram_channel_data_controller_0 + dram_channel_data_controller_1 + dram_channel_data_controller_2 + dram_channel_data_controller_3 + dram_channel_data_controller_4 + dram_channel_data_controller_5 + dram_channel_data_controller_6 + dram_channel_data_controller_7\000\000Approximate: Combined DRAM B/bytes of all channels on a NPS1 node (die)\000\0006.1e-5MiB\000\000\000\00001 */
};

static const struct compact_pmu_event pmu_events__amdzen2[] = {
{ 1153075 }, /* l2_request_g1.all_no_prefetch\000\000cache\000\000event=0x60,umask=0xf9\000\00000\000\000 */
{ 481008 }, /* bp_de_redirect\000\000branch\000Decoder Overrides Existing Branch Prediction (speculative)\000event=0x91\000\00000\000\000 */
{ 481229 }, /* bp_dyn_ind_pred\000\000branch\000Dynamic Indirect Predictions\000event=0x8e\000\00000\000Indirect Branch Prediction for potential multi-target branch (speculative)\000 */
{ 481705 }, /* bp_l1_btb_correct\000\000branch\000L1 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8a\000\00000\000\000 */
{ 483303 }, /* bp_l1_tlb_fetch_hit\000\000branch\000The number of instruction fetches that hit in the L1 ITLB\000event=0x94,umask=0xff\000\00000\000\000 */
{ 481934 }, /* bp_l1_tlb_fetch_hit.if1g\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 1GB page\000event=0x94,umask=0x04\000\00000\000\000 */
{ 482361 }, /* bp_l1_tlb_fetch_hit.if2m\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 2MB page\000event=0x94,umask=0x02\000\00000\000\000 */
{ 482788 }, /* bp_l1_tlb_fetch_hit.if4k\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. Instruction fetches to a 4KB page\000event=0x94,umask=0x01\000\00000\000\000 */
{ 486619 }, /* bp_l2_btb_correct\000\000branch\000L2 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8b\000\00000\000\000 */
{ 487137 }, /* bp_tlb_rel\000\000branch\000The number of ITLB reload requests\000event=0x99\000\00000\000\000 */
{ 483518 }, /* bp_l1_tlb_miss_l2_hit\000\000cache\000The number of instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000 */
{ 486427 }, /* bp_l1_tlb_miss_l2_tlb_miss\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs\000event=0x85,umask=0xff\000\00000\000\000 */
{ 484715 }, /* bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 1GB page\000event=0x85,umask=0x04\000\00000\000\000 */
{ 485286 }, /* bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 2MB page\000event=0x85,umask=0x02\000\00000\000\000 */
{ 485857 }, /* bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs. Instruction fetches to a 4KB page\000event=0x85,umask=0x01\000\00000\000\000 */
{ 486833 }, /* bp_snp_re_sync\000\000cache\000The number of pipeline restarts caused by invalidating probes that hit on the instruction stream currently being executed. This would happen if the active instruction stream was being modified by another processor in an MP system - typically a highly unlikely event\000event=0x86\000\00000\000\000 */
{ 979583 }, /* ic_cache_fill_l2\000\000cache\000The number of 64 byte instruction cache line was fulfilled from the L2 cache\000event=0x82\000\00000\000\000 */
{ 979993 }, /* ic_cache_fill_sys\000\000cache\000The number of 64 byte instruction cache line fulfilled from system memory or another cache\000event=0x83\000\00000\000\000 */
{ 980125 }, /* ic_cache_inval.fill_invalidated\000\000cache\000IC line invalidated due to overwriting fill response. The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x01\000\00000\000\000 */
{ 980400 }, /* ic_cache_inval.l2_invalidating_probe\000\000cache\000IC line invalidated due to L2 invalidating probe (external or LS). The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x02\000\00000\000\000 */
{ 980693 }, /* ic_fetch_stall.ic_stall_any\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle for any reason (nothing valid in pipe ICM1)\000event=0x87,umask=0x04\000\00000\000\000 */
{ 980867 }, /* ic_fetch_stall.ic_stall_back_pressure\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to back-pressure\000event=0x87,umask=0x01\000\00000\000\000 */
{ 981057 }, /* ic_fetch_stall.ic_stall_dq_empty\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to DQ empty\000event=0x87,umask=0x02\000\00000\000\000 */
{ 981237 }, /* ic_fw32\000\000cache\000The number of 32B fetch windows transferred from IC pipe to DE instruction decoder (includes non-cacheable and cacheable fill responses)\000event=0x80\000\00000\000\000 */
{ 981405 }, /* ic_fw32_miss\000\000cache\000The number of 32B fetch windows tried to read the L1 IC and missed in the full tag\000event=0x81\000\00000\000\000 */
{ 981524 }, /* ic_oc_mode_switch.ic_oc_mode_switch\000\000cache\000OC Mode Switch. IC to OC mode switch\000event=0x28a,umask=0x01\000\00000\000\000 */
{ 981740 }, /* ic_oc_mode_switch.oc_ic_mode_switch\000\000cache\000OC Mode Switch. OC to IC mode switch\000event=0x28a,umask=0x02\000\00000\000\000 */
{ 1116951 }, /* l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache requests in L2\000event=0x64,umask=0x07\000\00000\000\000 */
{ 1117282 }, /* l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request hit in L2 and Data cache request hit in L2 (all types)\000event=0x64,umask=0xf6\000\00000\000\000 */
{ 1117664 }, /* l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2 and Data cache request miss in L2 (all types)\000event=0x64,umask=0x09\000\00000\000\000 */
{ 1118069 }, /* l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit clean line in L2\000event=0x64,umask=0x02\000\00000\000\000 */
{ 1118609 }, /* l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000 */
{ 1119176 }, /* l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1119879 }, /* l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache request miss in L2 (all types)\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1120222 }, /* l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000 */
{ 1120763 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit on shared line in L2\000event=0x64,umask=0x20\000\00000\000\000 */
{ 1121305 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit in L2\000event=0x64,umask=0x40\000\00000\000\000 */
{ 1121647 }, /* l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000 */
{ 1124209 }, /* l2_fill_pending.l2_fill_busy\000\000cache\000Cycles with fill pending from L2. Total cycles spent with one or more fill requests in flight from L2\000event=0x6d,umask=0x01\000\00000\000\000 */
{ 1126302 }, /* l2_latency.l2_cycles_waiting_on_fills\000\000cache\000Total cycles spent waiting for L2 fills to complete from L3 or memory, divided by four. Event counts are for both threads. To calculate average latency, the number of fills from both threads must be used\000event=0x62,umask=0x01\000\00000\000\000 */
{ 1141845 }, /* l2_pf_hit_l2\000\000cache\000L2 prefetch hit in L2. Use l2_cache_hits_from_l2_hwpf instead\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1144140 }, /* l2_pf_miss_l2_hit_l3\000\000cache\000L2 prefetcher hits in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit the L3\000event=0x71,umask=0xff\000\00000\000\000 */
{ 1146349 }, /* l2_pf_miss_l2_l3\000\000cache\000L2 prefetcher misses in L3. All L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches\000event=0x72,umask=0xff\000\00000\000\000 */
{ 1153140 }, /* l2_request_g1.cacheable_ic_read\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1153385 }, /* l2_request_g1.change_to_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache state change requests. Request change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000 */
{ 1153887 }, /* l2_request_g1.group2\000\000cache\000Miscellaneous events covered in more detail by l2_request_g2 (PMCx061)\000event=0x60,umask=0x01\000\00000\000\000 */
{ 1154013 }, /* l2_request_g1.l2_hw_pf\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). L2 Prefetcher. All prefetches accepted by L2 pipeline, hit or miss. Types of PF and L2 hit/miss broken out in a separate perfmon event\000event=0x60,umask=0x02\000\00000\000\000 */
{ 1154396 }, /* l2_request_g1.ls_rd_blk_c_s\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000 */
{ 1154633 }, /* l2_request_g1.prefetch_l2_cmd\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). PrefetchL2Cmd\000event=0x60,umask=0x04\000\00000\000\000 */
{ 1154866 }, /* l2_request_g1.rd_blk_l\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache reads (including hardware and software prefetch)\000event=0x60,umask=0x80\000\00000\000\000 */
{ 1155163 }, /* l2_request_g1.rd_blk_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache stores\000event=0x60,umask=0x40\000\00000\000\000 */
{ 1155378 }, /* l2_request_g2.bus_locks_originator\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus locks\000event=0x61,umask=0x02\000\00000\000\000 */
{ 1155501 }, /* l2_request_g2.bus_locks_responses\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus lock response\000event=0x61,umask=0x01\000\00000\000\000 */
{ 1155631 }, /* l2_request_g2.group1\000\000cache\000Miscellaneous events covered in more detail by l2_request_g1 (PMCx060)\000event=0x61,umask=0x80\000\00000\000\000 */
{ 1155757 }, /* l2_request_g2.ic_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized\000event=0x61,umask=0x10\000\00000\000\000 */
{ 1155890 }, /* l2_request_g2.ic_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized non-cacheable\000event=0x61,umask=0x08\000\00000\000\000 */
{ 1156040 }, /* l2_request_g2.ls_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized\000event=0x61,umask=0x40\000\00000\000\000 */
{ 1156166 }, /* l2_request_g2.ls_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized non-cacheable\000event=0x61,umask=0x20\000\00000\000\000 */
{ 1156309 }, /* l2_request_g2.smc_inval\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Self-modifying code invalidates\000event=0x61,umask=0x04\000\00000\000\000 */
{ 1184186 }, /* l2_wcb_req.cl_zero\000\000cache\000LS to L2 WCB cache line zeroing requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) cache line zeroing requests\000event=0x63,umask=0x01\000\00000\000\000 */
{ 1184365 }, /* l2_wcb_req.wcb_close\000\000cache\000LS to L2 WCB close requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) close requests\000event=0x63,umask=0x20\000\00000\000\000 */
{ 1184520 }, /* l2_wcb_req.wcb_write\000\000cache\000LS to L2 WCB write requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) write requests\000event=0x63,umask=0x40\000\00000\000\000 */
{ 1184675 }, /* l2_wcb_req.zero_byte_store\000\000cache\000LS to L2 WCB zero byte store requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) zero byte store requests\000event=0x63,umask=0x04\000\00000\000\000 */
{ 1186252 }, /* l3_comb_clstr_state.other_l3_miss_typs\000amd_l3\000cache\000Other L3 Miss Request Types. Unit: amd_l3 \000event=0x6,umask=0xfe\000\00000\000\000 */
{ 1186373 }, /* l3_comb_clstr_state.request_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x6,umask=0x01\000\00000\000\000 */
{ 1186748 }, /* l3_lookup_state.all_l3_req_typs\000amd_l3\000cache\000All L3 Request Types. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187260 }, /* l3_request_g1.caching_l3_cache_accesses\000amd_l3\000cache\000Caching: L3 cache accesses. Unit: amd_l3 \000event=0x1,umask=0x80\000\00000\000\000 */
{ 6242650 }, /* xi_ccx_sdp_req1.all_l3_miss_req_typs\000amd_l3\000cache\000All L3 Miss Request Types. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x9a,umask=0x3f\000\00000\000\000 */
{ 6243018 }, /* xi_sys_fill_latency\000amd_l3\000cache\000L3 Cache Miss Latency. Total cycles for all transactions divided by 16. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x90,umask=0x00\000\00000\000\000 */
{ 835353 }, /* ex_div_busy\000\000core\000Div Cycles Busy count\000event=0xd3\000\00000\000\000 */
{ 835480 }, /* ex_div_count\000\000core\000Div Op Count\000event=0xd4\000\00000\000\000 */
{ 836541 }, /* ex_ret_brn\000\000core\000Retired Branch Instructions\000event=0xc2\000\00000\000The number of branch instructions retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 836953 }, /* ex_ret_brn_far\000\000core\000Retired Far Control Transfers\000event=0xc6\000\00000\000The number of far control transfers retired including far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts. Far control transfers are not subject to branch prediction\000 */
{ 837724 }, /* ex_ret_brn_ind_misp\000\000core\000Retired Indirect Branch Instructions Mispredicted\000event=0xca\000\00000\000\000 */
{ 837897 }, /* ex_ret_brn_misp\000\000core\000Retired Branch Instructions Mispredicted\000event=0xc3\000\00000\000The number of branch instructions retired, of any type, that were not correctly predicted. This includes those for which prediction is not attempted (far control transfers, exceptions and interrupts)\000 */
{ 838319 }, /* ex_ret_brn_resync\000\000core\000Retired Branch Resyncs\000event=0xc7\000\00000\000The number of resync branches. These reflect pipeline restarts due to certain microcode assists and events such as writes to the active instruction stream, among other things. Each occurrence reflects a restart penalty similar to a branch mispredict. This is relatively rare\000 */
{ 838816 }, /* ex_ret_brn_tkn\000\000core\000Retired Taken Branch Instructions\000event=0xc4\000\00000\000The number of taken branches that were retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 839124 }, /* ex_ret_brn_tkn_misp\000\000core\000Retired Taken Branch Instructions Mispredicted\000event=0xc5\000\00000\000The number of retired taken branch instructions that were mispredicted\000 */
{ 839359 }, /* ex_ret_cond\000\000core\000Retired Conditional Branch Instructions\000event=0xd1\000\00000\000\000 */
{ 839433 }, /* ex_ret_cond_misp\000\000core\000Retired Conditional Branch Instructions Mispredicted\000event=0xd2\000\00000\000\000 */
{ 839525 }, /* ex_ret_cops\000\000core\000Retired Uops\000event=0xc1\000\00000\000The number of micro-ops retired. This count includes all processor activity (instructions, exceptions, interrupts, microcode assists, etc.). The number of events logged per cycle can vary from 0 to 8\000 */
{ 840006 }, /* ex_ret_fus_brnch_inst\000\000core\000Retired Fused Instructions. The number of fuse-branch instructions retired per cycle. The number of events logged per cycle can vary from 0-8\000event=0x1d0\000\00000\000\000 */
{ 840714 }, /* ex_ret_instr\000\000core\000Retired Instructions\000event=0xc0\000\00000\000\000 */
{ 840826 }, /* ex_ret_mmx_fp_instr.mmx_instr\000\000core\000MMX instructions\000event=0xcb,umask=0x02\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. MMX instructions\000 */
{ 841217 }, /* ex_ret_mmx_fp_instr.sse_instr\000\000core\000SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000event=0xcb,umask=0x04\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000 */
{ 842134 }, /* ex_ret_mmx_fp_instr.x87_instr\000\000core\000x87 instructions\000event=0xcb,umask=0x01\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. x87 instructions\000 */
{ 842982 }, /* ex_ret_near_ret\000\000core\000Retired Near Returns\000event=0xc8\000\00000\000The number of near return instructions (RET or RET Iw) retired\000 */
{ 843278 }, /* ex_ret_near_ret_mispred\000\000core\000Retired Near Returns Mispredicted\000event=0xc9\000\00000\000The number of near returns retired that were not correctly predicted by the return address predictor. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction\000 */
{ 844063 }, /* ex_tagged_ibs_ops.ibs_count_rollover\000\000core\000Tagged IBS Ops. Number of times an op could not be tagged by IBS because of a previous tagged op that has not retired\000event=0x1cf,umask=0x04\000\00000\000\000 */
{ 844337 }, /* ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000 */
{ 844550 }, /* ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000 */
{ 779893 }, /* dram_channel_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780073 }, /* dram_channel_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x47,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780254 }, /* dram_channel_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x87,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780435 }, /* dram_channel_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780616 }, /* dram_channel_data_controller_4\000amd_df\000data fabric\000Unit: amd_df \000event=0x107,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780798 }, /* dram_channel_data_controller_5\000amd_df\000data fabric\000Unit: amd_df \000event=0x147,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780980 }, /* dram_channel_data_controller_6\000amd_df\000data fabric\000Unit: amd_df \000event=0x187,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 781162 }, /* dram_channel_data_controller_7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1c7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 2488348 }, /* remote_outbound_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7c7,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 0\000 */
{ 2488525 }, /* remote_outbound_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x807,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 1\000 */
{ 2488702 }, /* remote_outbound_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x847,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 2\000 */
{ 2488879 }, /* remote_outbound_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0x887,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 3\000 */
{ 909554 }, /* fp_disp_faults.x87_fill_fault\000\000floating point\000Floating Point Dispatch Faults. x87 fill fault\000event=0xe,umask=0x01\000\00000\000\000 */
{ 909790 }, /* fp_disp_faults.xmm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. XMM fill fault\000event=0xe,umask=0x02\000\00000\000\000 */
{ 910026 }, /* fp_disp_faults.ymm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM fill fault\000event=0xe,umask=0x04\000\00000\000\000 */
{ 910262 }, /* fp_disp_faults.ymm_spill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM spill fault\000event=0xe,umask=0x08\000\00000\000\000 */
{ 910880 }, /* fp_num_mov_elim_scal_op.opt_potential\000\000floating point\000Number of Ops that are candidates for optimization (have Z-bit either set or pass). This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x04\000\00000\000\000 */
{ 911592 }, /* fp_num_mov_elim_scal_op.optimized\000\000floating point\000Number of Scalar Ops optimized. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x08\000\00000\000\000 */
{ 912140 }, /* fp_num_mov_elim_scal_op.sse_mov_ops\000\000floating point\000Number of SSE Move Ops. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x01\000\00000\000\000 */
{ 912668 }, /* fp_num_mov_elim_scal_op.sse_mov_ops_elim\000\000floating point\000Number of SSE Move Ops eliminated. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x02\000\00000\000\000 */
{ 920867 }, /* fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Add/subtract FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x01\000\00000\000\000 */
{ 921684 }, /* fp_ret_sse_avx_ops.all\000\000floating point\000All FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0xff\000\00000\000\000 */
{ 922448 }, /* fp_ret_sse_avx_ops.div_flops\000\000floating point\000Divide/square root FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x04\000\00000\000\000 */
{ 925043 }, /* fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Multiply-add FLOPS. Multiply-add counts as 2 FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x08\000\00000\000\000 */
{ 925491 }, /* fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Multiply FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0x02\000\00000\000\000 */
{ 928340 }, /* fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE bottom-executing uOps retired. The number of serializing Ops retired\000event=0x5,umask=0x08\000\00000\000\000 */
{ 929399 }, /* fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000The number of serializing Ops retired. SSE control word mispredict traps due to mispredictions in RC, FTZ or DAZ, or changes in mask bits\000event=0x5,umask=0x04\000\00000\000\000 */
{ 929934 }, /* fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing uOps retired. The number of serializing Ops retired\000event=0x5,umask=0x02\000\00000\000\000 */
{ 930444 }, /* fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits. The number of serializing Ops retired\000event=0x5,umask=0x01\000\00000\000\000 */
{ 939310 }, /* fpu_pipe_assignment.total\000\000floating point\000Total number of fp uOps\000event=0,umask=0x0f\000\00000\000Total number of fp uOps. The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS\000 */
{ 935165 }, /* fpu_pipe_assignment.total0\000\000floating point\000Total number of fp uOps  on pipe 0\000event=0,umask=0x01\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 0\000 */
{ 936348 }, /* fpu_pipe_assignment.total1\000\000floating point\000Total number uOps assigned to pipe 1\000event=0,umask=0x02\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 1\000 */
{ 937533 }, /* fpu_pipe_assignment.total2\000\000floating point\000Total number uOps assigned to pipe 2\000event=0,umask=0x04\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 2\000 */
{ 938717 }, /* fpu_pipe_assignment.total3\000\000floating point\000Total number uOps assigned to pipe 3\000event=0,umask=0x08\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one-cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 3\000 */
{ 1257725 }, /* ls_bad_status2.stli_other\000\000memory\000Non-forwardable conflict; used to reduce STLI's via software. All reasons. Store To Load Interlock (STLI) are loads that were unable to complete because of a possible match with an older store, and the older store could not do STLF for some reason\000event=0x24,umask=0x02\000\00000\000Store-to-load conflicts: A load was unable to complete due to a non-forwardable conflict with an older store. Most commonly, a load's address range partially but not completely overlaps with an uncompleted older store. Software can avoid this problem by using same-size and same-alignment loads and stores when accessing the same data. Vector/SIMD code is particularly susceptible to this problem; software should construct wide vector stores by manipulating vector elements in registers using shuffle/blend/swap instructions prior to storing to memory, instead of using narrow element-by-element stores\000 */
{ 1258802 }, /* ls_dc_accesses\000\000memory\000Number of accesses to the dcache for load/store references\000event=0x40\000\00000\000The number of accesses to the data cache for load and store references. This may include certain microcode scratchpad accesses, although these are generally rare. Each increment represents an eight-byte access, although the instruction may only be accessing a portion of that. This event is a speculative event\000 */
{ 1259878 }, /* ls_dispatch.ld_dispatch\000\000memory\000Number of loads dispatched. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000 */
{ 1260321 }, /* ls_dispatch.ld_st_dispatch\000\000memory\000Dispatch of a single op that performs a load from and store to the same memory address. Number of single ops that do load/store to an address\000event=0x29,umask=0x04\000\00000\000\000 */
{ 1261366 }, /* ls_dispatch.store_dispatch\000\000memory\000Number of stores dispatched. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000 */
{ 1263543 }, /* ls_hw_pf_dc_fill.ls_mabresp_lcl_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From another cache (home node local)\000event=0x5a,umask=0x02\000\00000\000\000 */
{ 1263704 }, /* ls_hw_pf_dc_fill.ls_mabresp_lcl_dram\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM (home node local)\000event=0x5a,umask=0x08\000\00000\000\000 */
{ 1263855 }, /* ls_hw_pf_dc_fill.ls_mabresp_lcl_l2\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. Local L2 hit\000event=0x5a,umask=0x01\000\00000\000\000 */
{ 1263989 }, /* ls_hw_pf_dc_fill.ls_mabresp_rmt_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From another cache (home node remote)\000event=0x5a,umask=0x10\000\00000\000\000 */
{ 1264151 }, /* ls_hw_pf_dc_fill.ls_mabresp_rmt_dram\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM (home node remote)\000event=0x5a,umask=0x40\000\00000\000\000 */
{ 1266648 }, /* ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a DC hit\000event=0x52,umask=0x01\000\00000\000\000 */
{ 1267080 }, /* ls_inef_sw_pref.mab_mch_cnt\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a match on an already-allocated miss request buffer\000event=0x52,umask=0x02\000\00000\000\000 */
{ 1267445 }, /* ls_int_taken\000\000memory\000Number of interrupts taken\000event=0x2c\000\00000\000\000 */
{ 1267623 }, /* ls_l1_d_tlb_miss.all\000\000memory\000All L1 DTLB Misses or Reloads\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1268043 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that hit in the L2 TLB\000event=0x45,umask=0x08\000\00000\000\000 */
{ 1268658 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that miss in the L2 TLB\000event=0x45,umask=0x80\000\00000\000\000 */
{ 1268950 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that hit in the L2 TLB\000event=0x45,umask=0x04\000\00000\000\000 */
{ 1269565 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that miss in the L2 TLB\000event=0x45,umask=0x40\000\00000\000\000 */
{ 1270078 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that hit in the L2 TLB\000event=0x45,umask=0x01\000\00000\000\000 */
{ 1270549 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that miss the L2 TLB\000event=0x45,umask=0x10\000\00000\000\000 */
{ 1270974 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB Miss. DTLB reload hit a coalesced page\000event=0x45,umask=0x02\000\00000\000\000 */
{ 1271457 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB Miss. DTLB reload coalesced page miss\000event=0x45,umask=0x20\000\00000\000\000 */
{ 1272234 }, /* ls_locks.bus_lock\000\000memory\000Retired lock instructions. Bus lock when a locked operations crosses a cache boundary or is done on an uncacheable memory type. Comparable to legacy bus lock\000event=0x25,umask=0x01\000\00000\000\000 */
{ 1272555 }, /* ls_locks.non_spec_lock\000\000memory\000Retired lock instructions. Non-speculative lock succeeded\000event=0x25,umask=0x02\000\00000\000\000 */
{ 1272671 }, /* ls_locks.spec_lock_hi_spec\000\000memory\000Retired lock instructions. High speculative cacheable lock speculation succeeded\000event=0x25,umask=0x08\000\00000\000\000 */
{ 1272814 }, /* ls_locks.spec_lock_lo_spec\000\000memory\000Retired lock instructions. Low speculative cacheable lock speculation succeeded\000event=0x25,umask=0x04\000\00000\000\000 */
{ 1273243 }, /* ls_mab_alloc.dc_prefetcher\000\000memory\000LS MAB Allocates by Type. DC prefetcher\000event=0x41,umask=0x08\000\00000\000\000 */
{ 1274096 }, /* ls_mab_alloc.loads\000\000memory\000LS MAB Allocates by Type. Loads\000event=0x41,umask=0x01\000\00000\000\000 */
{ 1274269 }, /* ls_mab_alloc.stores\000\000memory\000LS MAB Allocates by Type. Stores\000event=0x41,umask=0x02\000\00000\000\000 */
{ 1274446 }, /* ls_misal_accesses\000\000memory\000Misaligned loads\000event=0x47\000\00000\000\000 */
{ 1274987 }, /* ls_not_halted_cyc\000\000memory\000Cycles not in Halt\000event=0x76\000\00000\000\000 */
{ 1277237 }, /* ls_pref_instr_disp\000\000memory\000Software Prefetch Instructions Dispatched (Speculative)\000event=0x4b,umask=0xff\000\00000\000\000 */
{ 1275879 }, /* ls_pref_instr_disp.prefetch\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). Prefetch_T0_T1_T2. PrefetchT0, T1 and T2 instructions. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x01\000\00000\000\000 */
{ 1276423 }, /* ls_pref_instr_disp.prefetch_nta\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchNTA instruction. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x04\000\00000\000\000 */
{ 1276950 }, /* ls_pref_instr_disp.prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). See docAPM3 PREFETCHW\000event=0x4b,umask=0x02\000\00000\000\000 */
{ 1277347 }, /* ls_rdtsc\000\000memory\000Number of reads of the TSC (RDTSC instructions). The count is speculative\000event=0x2d\000\00000\000\000 */
{ 1277454 }, /* ls_refills_from_sys.ls_mabresp_lcl_cache\000\000memory\000Demand Data Cache Fills by Data Source. Hit in cache; local CCX (not Local L2), or Remote CCX and the address's Home Node is on this thread's die\000event=0x43,umask=0x02\000\00000\000\000 */
{ 1277676 }, /* ls_refills_from_sys.ls_mabresp_lcl_dram\000\000memory\000Demand Data Cache Fills by Data Source. DRAM or IO from this thread's die\000event=0x43,umask=0x08\000\00000\000\000 */
{ 1277825 }, /* ls_refills_from_sys.ls_mabresp_lcl_l2\000\000memory\000Demand Data Cache Fills by Data Source. Local L2 hit\000event=0x43,umask=0x01\000\00000\000\000 */
{ 1277951 }, /* ls_refills_from_sys.ls_mabresp_rmt_cache\000\000memory\000Demand Data Cache Fills by Data Source. Hit in cache; Remote CCX and the address's Home Node is on a different die\000event=0x43,umask=0x10\000\00000\000\000 */
{ 1278142 }, /* ls_refills_from_sys.ls_mabresp_rmt_dram\000\000memory\000Demand Data Cache Fills by Data Source. DRAM or IO from different die\000event=0x43,umask=0x40\000\00000\000\000 */
{ 1278354 }, /* ls_ret_cl_flush\000\000memory\000Number of retired CLFLUSH instructions\000event=0x26\000\00000\000\000 */
{ 1278611 }, /* ls_ret_cpuid\000\000memory\000Number of retired CPUID instructions\000event=0x27\000\00000\000\000 */
{ 1278878 }, /* ls_smi_rx\000\000memory\000Number of SMIs received\000event=0x2b\000\00000\000\000 */
{ 1279084 }, /* ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000A non-cacheable store and the non-cacheable commit buffer is full\000event=0x37\000\00000\000\000 */
{ 1279391 }, /* ls_stlf\000\000memory\000Number of STLF hits\000event=0x35\000\00000\000\000 */
{ 1279509 }, /* ls_sw_pf_dc_fill.ls_mabresp_lcl_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From another cache (home node local)\000event=0x59,umask=0x02\000\00000\000\000 */
{ 1279670 }, /* ls_sw_pf_dc_fill.ls_mabresp_lcl_dram\000\000memory\000Software Prefetch Data Cache Fills by Data Source. DRAM or IO from this thread's die.  From DRAM (home node local)\000event=0x59,umask=0x08\000\00000\000\000 */
{ 1279857 }, /* ls_sw_pf_dc_fill.ls_mabresp_lcl_l2\000\000memory\000Software Prefetch Data Cache Fills by Data Source. Local L2 hit\000event=0x59,umask=0x01\000\00000\000\000 */
{ 1279991 }, /* ls_sw_pf_dc_fill.ls_mabresp_rmt_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From another cache (home node remote)\000event=0x59,umask=0x10\000\00000\000\000 */
{ 1280153 }, /* ls_sw_pf_dc_fill.ls_mabresp_rmt_dram\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM (home node remote)\000event=0x59,umask=0x40\000\00000\000\000 */
{ 1282357 }, /* ls_tablewalker.dc_type0\000\000memory\000Total Page Table Walks DC Type 0\000event=0x46,umask=0x01\000\00000\000\000 */
{ 1282449 }, /* ls_tablewalker.dc_type1\000\000memory\000Total Page Table Walks DC Type 1\000event=0x46,umask=0x02\000\00000\000\000 */
{ 1282541 }, /* ls_tablewalker.dside\000\000memory\000Total Page Table Walks on D-side\000event=0x46,umask=0x03\000\00000\000\000 */
{ 1282630 }, /* ls_tablewalker.ic_type0\000\000memory\000Total Page Table Walks IC Type 0\000event=0x46,umask=0x04\000\00000\000\000 */
{ 1282722 }, /* ls_tablewalker.ic_type1\000\000memory\000Total Page Table Walks IC Type 1\000event=0x46,umask=0x08\000\00000\000\000 */
{ 1282814 }, /* ls_tablewalker.iside\000\000memory\000Total Page Table Walks on I-side\000event=0x46,umask=0x0c\000\00000\000\000 */
{ 1283135 }, /* ls_tlb_flush\000\000memory\000All TLB Flushes\000event=0x78\000\00000\000\000 */
{ 763271 }, /* de_dis_dispatch_token_stalls0.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x10\000\00000\000\000 */
{ 763659 }, /* de_dis_dispatch_token_stalls0.alsq1_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 1 Tokens unavailable\000event=0xaf,umask=0x01\000\00000\000\000 */
{ 763856 }, /* de_dis_dispatch_token_stalls0.alsq2_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ 2 Tokens unavailable\000event=0xaf,umask=0x02\000\00000\000\000 */
{ 764254 }, /* de_dis_dispatch_token_stalls0.alsq3_0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALSQ3_0_TokenStall\000event=0xaf,umask=0x04\000\00000\000\000 */
{ 764643 }, /* de_dis_dispatch_token_stalls0.alu_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. ALU tokens total unavailable\000event=0xaf,umask=0x08\000\00000\000\000 */
{ 765039 }, /* de_dis_dispatch_token_stalls0.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. RETIRE Tokens unavailable\000event=0xaf,umask=0x20\000\00000\000\000 */
{ 765435 }, /* de_dis_dispatch_token_stalls0.sc_agu_dispatch_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. SC AGU dispatch stall\000event=0xaf,umask=0x40\000\00000\000\000 */
{ 766105 }, /* de_dis_dispatch_token_stalls1.fp_misc_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. FP Miscellaneous resource unavailable. Applies to the recovery of mispredicts with FP ops\000event=0xae,umask=0x80\000\00000\000\000 */
{ 766756 }, /* de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Floating point register file resource stall. Applies to all FP ops that have a destination register\000event=0xae,umask=0x20\000\00000\000\000 */
{ 767550 }, /* de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. FP scheduler resource stall. Applies to ops that use the FP scheduler\000event=0xae,umask=0x40\000\00000\000\000 */
{ 768551 }, /* de_dis_dispatch_token_stalls1.int_phy_reg_file_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Integer Physical Register File resource stall. Applies to all ops that have an integer destination register\000event=0xae,umask=0x01\000\00000\000\000 */
{ 768841 }, /* de_dis_dispatch_token_stalls1.int_sched_misc_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Integer Scheduler miscellaneous resource stall\000event=0xae,umask=0x08\000\00000\000\000 */
{ 769566 }, /* de_dis_dispatch_token_stalls1.load_queue_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Load queue resource stall. Applies to all ops with load semantics\000event=0xae,umask=0x02\000\00000\000\000 */
{ 770312 }, /* de_dis_dispatch_token_stalls1.store_queue_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Store queue resource stall. Applies to all ops with store semantics\000event=0xae,umask=0x04\000\00000\000\000 */
{ 770557 }, /* de_dis_dispatch_token_stalls1.taken_branch_buffer_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Taken branch buffer resource stall\000event=0xae,umask=0x10\000\00000\000\000 */
{ 773615 }, /* de_dis_uop_queue_empty_di0\000\000other\000Cycles where the Micro-Op Queue is empty\000event=0xa9\000\00000\000\000 */
{ 773936 }, /* de_dis_uops_from_decoder\000\000other\000Ops dispatched from either the decoders, OpCache or both\000event=0xaa,umask=0xff\000\00000\000\000 */
{ 773706 }, /* de_dis_uops_from_decoder.decoder_dispatched\000\000other\000Count of dispatched Ops from Decoder\000event=0xaa,umask=0x01\000\00000\000\000 */
{ 773821 }, /* de_dis_uops_from_decoder.opcache_dispatched\000\000other\000Count of dispatched Ops from OpCache\000event=0xaa,umask=0x02\000\00000\000\000 */
{ 466489 }, /* all_dc_accesses\000\000recommended\000All L1 Data Cache Accesses\000event=0x29,umask=0x07\000\00000\000\000 */
{ 466572 }, /* all_tlbs_flushed\000\000recommended\000All TLBs Flushed\000event=0x78,umask=0xdf\000\00000\000\000 */
{ 1099832 }, /* l1_dtlb_misses\000\000recommended\000L1 DTLB Misses\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1115189 }, /* l2_cache_accesses_from_dc_misses\000\000recommended\000L2 Cache Accesses from L1 Data Cache Misses (including prefetch)\000event=0x60,umask=0xc8\000\00000\000\000 */
{ 1115465 }, /* l2_cache_accesses_from_ic_misses\000\000recommended\000L2 Cache Accesses from L1 Instruction Cache Misses (including prefetch)\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1115610 }, /* l2_cache_hits_from_dc_misses\000\000recommended\000L2 Cache Hits from L1 Data Cache Misses\000event=0x64,umask=0x70\000\00000\000\000 */
{ 1115828 }, /* l2_cache_hits_from_ic_misses\000\000recommended\000L2 Cache Hits from L1 Instruction Cache Misses\000event=0x64,umask=0x06\000\00000\000\000 */
{ 1116044 }, /* l2_cache_hits_from_l2_hwpf\000\000recommended\000L2 Cache Hits from L2 HWPF\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1116138 }, /* l2_cache_misses_from_dc_misses\000\000recommended\000L2 Cache Misses from L1 Data Cache Misses\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1116251 }, /* l2_cache_misses_from_ic_miss\000\000recommended\000L2 Cache Misses from L1 Instruction Cache Misses\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1124121 }, /* l2_dtlb_misses\000\000recommended\000L2 DTLB Misses & Data page walks\000event=0x45,umask=0xf0\000\00000\000\000 */
{ 1124926 }, /* l2_itlb_misses\000\000recommended\000L2 ITLB Misses & Instruction page walks\000event=0x85,umask=0x07\000\00000\000\000 */
{ 1185976 }, /* l3_accesses\000amd_l3\000recommended\000L3 Accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187040 }, /* l3_misses\000amd_l3\000recommended\000L3 Misses (includes Chg2X). Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000 */
{ 2536007 }, /* sse_avx_stalls\000\000recommended\000Mixed SSE/AVX Stalls\000event=0xe,umask=0x0e\000\00000\000\000 */
{ 6183632 }, /* uops_dispatched\000\000recommended\000Micro-ops Dispatched\000event=0xaa,umask=0x03\000\00000\000\000 */
{ 6241737 }, /* uops_retired\000\000recommended\000Micro-ops Retired\000event=0xc1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__amdzen2[] = {
{ 6782 }, /* \000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Accesses\000\000\000\000\000\00000 */
{ 7199 }, /* \000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2\000\000All L2 Cache Hits\000\000\000\000\000\00000 */
{ 7302 }, /* \000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Misses\000\000\000\000\000\00000 */
{ 7580 }, /* \000all_remote_links_outbound\000data_fabric\000remote_outbound_data_controller_0 + remote_outbound_data_controller_1 + remote_outbound_data_controller_2 + remote_outbound_data_controller_3\000\000Approximate: Outbound data bytes for all Remote Links for a node (die)\000\0003e-5MiB\000\000\000\00000 */
{ 9223 }, /* \000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-Time Branch Misprediction Ratio (Non-Speculative)\000\000100%\000\000\000\00000 */
{ 16617 }, /* \000ic_fetch_miss_ratio\000l2_cache\000d_ratio(l2_cache_req_stat.ic_access_in_l2, bp_l1_tlb_fetch_hit + bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_tlb_miss)\000\000L1 Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000 */
{ 22820 }, /* \000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_hit + bp_l1_tlb_miss_l2_tlb_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000 */
{ 24041 }, /* \000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Accesses from L2 HWPF\000\000\000\000\000\00000 */
{ 25073 }, /* \000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Misses from L2 HWPF\000\000\000\000\000\00000 */
{ 27117 }, /* \000l3_read_miss_latency\000l3_cache\000xi_sys_fill_latency * 16 / xi_ccx_sdp_req1.all_l3_miss_req_typs\000\000Average L3 Read Miss Latency (in core clocks)\000\0001core clocks\000\000\000\00000 */
{ 40023 }, /* \000nps1_die_to_dram\000data_fabric\000dram_channel_data_controller_0 + dram_channel_data_controller_1 + dram_channel_data_controller_2 + dram_channel_data_controller_3 + dram_channel_data_controller_4 + dram_channel_data_controller_5 + dram_channel_data_controller_6 + dram_channel_data_controller_7\000\000Approximate: Combined DRAM B/bytes of all channels on a NPS1 node (die)\000\0006.1e-5MiB\000\000\000\00001 */
};

static const struct compact_pmu_event pmu_events__amdzen3[] = {
{ 1153075 }, /* l2_request_g1.all_no_prefetch\000\000cache\000\000event=0x60,umask=0xf9\000\00000\000\000 */
{ 480878 }, /* bp_de_redirect\000\000branch\000Decode Redirects\000event=0x91\000\00000\000The number of times the instruction decoder overrides the predicted target\000 */
{ 481372 }, /* bp_dyn_ind_pred\000\000branch\000Dynamic Indirect Predictions\000event=0x8e\000\00000\000The number of times a branch used the indirect predictor to make a prediction\000 */
{ 481705 }, /* bp_l1_btb_correct\000\000branch\000L1 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8a\000\00000\000\000 */
{ 483303 }, /* bp_l1_tlb_fetch_hit\000\000branch\000The number of instruction fetches that hit in the L1 ITLB\000event=0x94,umask=0xff\000\00000\000\000 */
{ 482087 }, /* bp_l1_tlb_fetch_hit.if1g\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instruction TLB hit (1G page size)\000event=0x94,umask=0x04\000\00000\000\000 */
{ 482514 }, /* bp_l1_tlb_fetch_hit.if2m\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instruction TLB hit (2M page size)\000event=0x94,umask=0x02\000\00000\000\000 */
{ 482941 }, /* bp_l1_tlb_fetch_hit.if4k\000\000branch\000The number of instruction fetches that hit in the L1 ITLB. L1 Instrcution TLB hit (4K or 16K page size)\000event=0x94,umask=0x01\000\00000\000\000 */
{ 486619 }, /* bp_l2_btb_correct\000\000branch\000L2 Branch Prediction Overrides Existing Prediction (speculative)\000event=0x8b\000\00000\000\000 */
{ 487137 }, /* bp_tlb_rel\000\000branch\000The number of ITLB reload requests\000event=0x99\000\00000\000\000 */
{ 483762 }, /* bp_l1_tlb_miss_l2_tlb_hit\000\000cache\000L1 ITLB Miss, L2 ITLB Hit. The number of instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000 */
{ 486427 }, /* bp_l1_tlb_miss_l2_tlb_miss\000\000cache\000The number of instruction fetches that miss in both the L1 and L2 TLBs\000event=0x85,umask=0xff\000\00000\000\000 */
{ 484214 }, /* bp_l1_tlb_miss_l2_tlb_miss.coalesced_4k\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for >4K Coalesced page\000event=0x85,umask=0x08\000\00000\000\000 */
{ 484887 }, /* bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for 1G page\000event=0x85,umask=0x04\000\00000\000\000 */
{ 485458 }, /* bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk for 2M page\000event=0x85,umask=0x02\000\00000\000\000 */
{ 486029 }, /* bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000cache\000The number of valid fills into the ITLB originating from the LS Page-Table Walker. Tablewalk requests are issued for L1-ITLB and L2-ITLB misses. Walk to 4K page\000event=0x85,umask=0x01\000\00000\000\000 */
{ 486833 }, /* bp_snp_re_sync\000\000cache\000The number of pipeline restarts caused by invalidating probes that hit on the instruction stream currently being executed. This would happen if the active instruction stream was being modified by another processor in an MP system - typically a highly unlikely event\000event=0x86\000\00000\000\000 */
{ 979328 }, /* ic_cache_fill_l2\000\000cache\000Instruction Cache Refills from L2. The number of 64 byte instruction cache line was fulfilled from the L2 cache\000event=0x82\000\00000\000\000 */
{ 979700 }, /* ic_cache_fill_sys\000\000cache\000Instruction Cache Refills from System. The number of 64 byte instruction cache line fulfilled from system memory or another cache\000event=0x83\000\00000\000\000 */
{ 980125 }, /* ic_cache_inval.fill_invalidated\000\000cache\000IC line invalidated due to overwriting fill response. The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x01\000\00000\000\000 */
{ 980400 }, /* ic_cache_inval.l2_invalidating_probe\000\000cache\000IC line invalidated due to L2 invalidating probe (external or LS). The number of instruction cache lines invalidated. A non-SMC event is CMC (cross modifying code), either from the other thread of the core or another core\000event=0x8c,umask=0x02\000\00000\000\000 */
{ 980693 }, /* ic_fetch_stall.ic_stall_any\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle for any reason (nothing valid in pipe ICM1)\000event=0x87,umask=0x04\000\00000\000\000 */
{ 980867 }, /* ic_fetch_stall.ic_stall_back_pressure\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to back-pressure\000event=0x87,umask=0x01\000\00000\000\000 */
{ 981057 }, /* ic_fetch_stall.ic_stall_dq_empty\000\000cache\000Instruction Pipe Stall. IC pipe was stalled during this clock cycle (including IC to OC fetches) due to DQ empty\000event=0x87,umask=0x02\000\00000\000\000 */
{ 981237 }, /* ic_fw32\000\000cache\000The number of 32B fetch windows transferred from IC pipe to DE instruction decoder (includes non-cacheable and cacheable fill responses)\000event=0x80\000\00000\000\000 */
{ 981405 }, /* ic_fw32_miss\000\000cache\000The number of 32B fetch windows tried to read the L1 IC and missed in the full tag\000event=0x81\000\00000\000\000 */
{ 981524 }, /* ic_oc_mode_switch.ic_oc_mode_switch\000\000cache\000OC Mode Switch. IC to OC mode switch\000event=0x28a,umask=0x01\000\00000\000\000 */
{ 981740 }, /* ic_oc_mode_switch.oc_ic_mode_switch\000\000cache\000OC Mode Switch. OC to IC mode switch\000event=0x28a,umask=0x02\000\00000\000\000 */
{ 981956 }, /* ic_tag_hit_miss.all_instruction_cache_accesses\000\000cache\000All Instruction Cache Accesses. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x1f\000\00000\000\000 */
{ 982242 }, /* ic_tag_hit_miss.instruction_cache_hit\000\000cache\000Instruction Cache Hit. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x07\000\00000\000\000 */
{ 982484 }, /* ic_tag_hit_miss.instruction_cache_miss\000\000cache\000Instruction Cache Miss. Counts various IC tag related hit and miss events\000event=0x18e,umask=0x18\000\00000\000\000 */
{ 1116951 }, /* l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache requests in L2\000event=0x64,umask=0x07\000\00000\000\000 */
{ 1117282 }, /* l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request hit in L2 and Data cache request hit in L2 (all types)\000event=0x64,umask=0xf6\000\00000\000\000 */
{ 1117664 }, /* l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2 and Data cache request miss in L2 (all types)\000event=0x64,umask=0x09\000\00000\000\000 */
{ 1118246 }, /* l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit non-modifiable line in L2\000event=0x64,umask=0x02\000\00000\000\000 */
{ 1118609 }, /* l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000 */
{ 1118960 }, /* l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Instruction cache request miss in L2. Use l2_cache_misses_from_ic_miss instead\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1119657 }, /* l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache request miss in L2 (all types). Use l2_cache_misses_from_dc_misses instead\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1120222 }, /* l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000 */
{ 1120575 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit non-modifiable line in L2\000event=0x64,umask=0x20\000\00000\000\000 */
{ 1121125 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache read hit in L2. Modifiable\000event=0x64,umask=0x40\000\00000\000\000 */
{ 1121647 }, /* l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cacheable request access status (not including L2 Prefetch). Data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000 */
{ 1124209 }, /* l2_fill_pending.l2_fill_busy\000\000cache\000Cycles with fill pending from L2. Total cycles spent with one or more fill requests in flight from L2\000event=0x6d,umask=0x01\000\00000\000\000 */
{ 1126302 }, /* l2_latency.l2_cycles_waiting_on_fills\000\000cache\000Total cycles spent waiting for L2 fills to complete from L3 or memory, divided by four. Event counts are for both threads. To calculate average latency, the number of fills from both threads must be used\000event=0x62,umask=0x01\000\00000\000\000 */
{ 1141845 }, /* l2_pf_hit_l2\000\000cache\000L2 prefetch hit in L2. Use l2_cache_hits_from_l2_hwpf instead\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1144140 }, /* l2_pf_miss_l2_hit_l3\000\000cache\000L2 prefetcher hits in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit the L3\000event=0x71,umask=0xff\000\00000\000\000 */
{ 1146510 }, /* l2_pf_miss_l2_l3\000\000cache\000L2 prefetcher misses in L3. Counts all L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches\000event=0x72,umask=0xff\000\00000\000\000 */
{ 1153140 }, /* l2_request_g1.cacheable_ic_read\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1153385 }, /* l2_request_g1.change_to_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache state change requests. Request change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000 */
{ 1153887 }, /* l2_request_g1.group2\000\000cache\000Miscellaneous events covered in more detail by l2_request_g2 (PMCx061)\000event=0x60,umask=0x01\000\00000\000\000 */
{ 1154013 }, /* l2_request_g1.l2_hw_pf\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). L2 Prefetcher. All prefetches accepted by L2 pipeline, hit or miss. Types of PF and L2 hit/miss broken out in a separate perfmon event\000event=0x60,umask=0x02\000\00000\000\000 */
{ 1154396 }, /* l2_request_g1.ls_rd_blk_c_s\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000 */
{ 1154633 }, /* l2_request_g1.prefetch_l2_cmd\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). PrefetchL2Cmd\000event=0x60,umask=0x04\000\00000\000\000 */
{ 1154866 }, /* l2_request_g1.rd_blk_l\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache reads (including hardware and software prefetch)\000event=0x60,umask=0x80\000\00000\000\000 */
{ 1155163 }, /* l2_request_g1.rd_blk_x\000\000cache\000All L2 Cache Requests (Breakdown 1 - Common). Data cache stores\000event=0x60,umask=0x40\000\00000\000\000 */
{ 1155378 }, /* l2_request_g2.bus_locks_originator\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus locks\000event=0x61,umask=0x02\000\00000\000\000 */
{ 1155501 }, /* l2_request_g2.bus_locks_responses\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Bus lock response\000event=0x61,umask=0x01\000\00000\000\000 */
{ 1155631 }, /* l2_request_g2.group1\000\000cache\000Miscellaneous events covered in more detail by l2_request_g1 (PMCx060)\000event=0x61,umask=0x80\000\00000\000\000 */
{ 1155757 }, /* l2_request_g2.ic_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized\000event=0x61,umask=0x10\000\00000\000\000 */
{ 1155890 }, /* l2_request_g2.ic_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Instruction cache read sized non-cacheable\000event=0x61,umask=0x08\000\00000\000\000 */
{ 1156040 }, /* l2_request_g2.ls_rd_sized\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized\000event=0x61,umask=0x40\000\00000\000\000 */
{ 1156166 }, /* l2_request_g2.ls_rd_sized_nc\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Data cache read sized non-cacheable\000event=0x61,umask=0x20\000\00000\000\000 */
{ 1156309 }, /* l2_request_g2.smc_inval\000\000cache\000All L2 Cache Requests (Breakdown 2 - Rare). Self-modifying code invalidates\000event=0x61,umask=0x04\000\00000\000\000 */
{ 1184186 }, /* l2_wcb_req.cl_zero\000\000cache\000LS to L2 WCB cache line zeroing requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) cache line zeroing requests\000event=0x63,umask=0x01\000\00000\000\000 */
{ 1184365 }, /* l2_wcb_req.wcb_close\000\000cache\000LS to L2 WCB close requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) close requests\000event=0x63,umask=0x20\000\00000\000\000 */
{ 1184520 }, /* l2_wcb_req.wcb_write\000\000cache\000LS to L2 WCB write requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) write requests\000event=0x63,umask=0x40\000\00000\000\000 */
{ 1184675 }, /* l2_wcb_req.zero_byte_store\000\000cache\000LS to L2 WCB zero byte store requests. LS (Load/Store unit) to L2 WCB (Write Combining Buffer) zero byte store requests\000event=0x63,umask=0x04\000\00000\000\000 */
{ 1186252 }, /* l3_comb_clstr_state.other_l3_miss_typs\000amd_l3\000cache\000Other L3 Miss Request Types. Unit: amd_l3 \000event=0x6,umask=0xfe\000\00000\000\000 */
{ 1186373 }, /* l3_comb_clstr_state.request_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x6,umask=0x01\000\00000\000\000 */
{ 1186618 }, /* l3_lookup_state.all_l3_req_typs\000amd_l3\000cache\000All L3 Request Types. All L3 cache Requests. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187260 }, /* l3_request_g1.caching_l3_cache_accesses\000amd_l3\000cache\000Caching: L3 cache accesses. Unit: amd_l3 \000event=0x1,umask=0x80\000\00000\000\000 */
{ 2461244 }, /* op_cache_hit_miss.all_op_cache_accesses\000\000cache\000All Op Cache accesses. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x07\000\00000\000\000 */
{ 2461490 }, /* op_cache_hit_miss.op_cache_hit\000\000cache\000Op Cache Hit. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x03\000\00000\000\000 */
{ 2461692 }, /* op_cache_hit_miss.op_cache_miss\000\000cache\000Op Cache Miss. Counts Op Cache micro-tag hit/miss events\000event=0x28f,umask=0x04\000\00000\000\000 */
{ 6242802 }, /* xi_ccx_sdp_req1\000amd_l3\000cache\000L3 Misses by Request Type. Ignores SliceID, EnAllSlices, CoreID, EnAllCores and ThreadMask. Requires unit mask 0xFF to engage event for counting. Unit: amd_l3 \000event=0x9a,umask=0xff\000\00000\000\000 */
{ 6243198 }, /* xi_sys_fill_latency\000amd_l3\000cache\000L3 Cache Miss Latency. Total cycles for all transactions divided by 16. Ignores SliceMask and ThreadMask. Unit: amd_l3 \000event=0x90\000\00000\000\000 */
{ 835353 }, /* ex_div_busy\000\000core\000Div Cycles Busy count\000event=0xd3\000\00000\000\000 */
{ 835480 }, /* ex_div_count\000\000core\000Div Op Count\000event=0xd4\000\00000\000\000 */
{ 836541 }, /* ex_ret_brn\000\000core\000Retired Branch Instructions\000event=0xc2\000\00000\000The number of branch instructions retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 836953 }, /* ex_ret_brn_far\000\000core\000Retired Far Control Transfers\000event=0xc6\000\00000\000The number of far control transfers retired including far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts. Far control transfers are not subject to branch prediction\000 */
{ 837421 }, /* ex_ret_brn_ind_misp\000\000core\000Retired Indirect Branch Instructions Mispredicted\000event=0xca\000\00000\000The number of indirect branches retired that were not correctly predicted. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction. Note that only EX mispredicts are counted\000 */
{ 838175 }, /* ex_ret_brn_misp\000\000core\000Retired Branch Instructions Mispredicted\000event=0xc3\000\00000\000The number of retired branch instructions, that were mispredicted\000 */
{ 838319 }, /* ex_ret_brn_resync\000\000core\000Retired Branch Resyncs\000event=0xc7\000\00000\000The number of resync branches. These reflect pipeline restarts due to certain microcode assists and events such as writes to the active instruction stream, among other things. Each occurrence reflects a restart penalty similar to a branch mispredict. This is relatively rare\000 */
{ 838816 }, /* ex_ret_brn_tkn\000\000core\000Retired Taken Branch Instructions\000event=0xc4\000\00000\000The number of taken branches that were retired. This includes all types of architectural control flow changes, including exceptions and interrupts\000 */
{ 839124 }, /* ex_ret_brn_tkn_misp\000\000core\000Retired Taken Branch Instructions Mispredicted\000event=0xc5\000\00000\000The number of retired taken branch instructions that were mispredicted\000 */
{ 839359 }, /* ex_ret_cond\000\000core\000Retired Conditional Branch Instructions\000event=0xd1\000\00000\000\000 */
{ 840364 }, /* ex_ret_fused_instr\000\000core\000Counts retired Fused Instructions\000event=0x1d0\000\00000\000\000 */
{ 840592 }, /* ex_ret_ind_brch_instr\000\000core\000Retired Indirect Branch Instructions. The number of indirect branches retired\000event=0xcc\000\00000\000\000 */
{ 840714 }, /* ex_ret_instr\000\000core\000Retired Instructions\000event=0xc0\000\00000\000\000 */
{ 840826 }, /* ex_ret_mmx_fp_instr.mmx_instr\000\000core\000MMX instructions\000event=0xcb,umask=0x02\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. MMX instructions\000 */
{ 841710 }, /* ex_ret_mmx_fp_instr.sse_instr\000\000core\000SSE instructions (SSE, SSE2, SSE3, SSSE3, SSE4A, SSE41, SSE42, AVX)\000event=0xcb,umask=0x04\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS\000 */
{ 842134 }, /* ex_ret_mmx_fp_instr.x87_instr\000\000core\000x87 instructions\000event=0xcb,umask=0x01\000\00000\000The number of MMX, SSE or x87 instructions retired. The UnitMask allows the selection of the individual classes of instructions as given in the table. Each increment represents one complete instruction. Since this event includes non-numeric instructions it is not suitable for measuring MFLOPS. x87 instructions\000 */
{ 842653 }, /* ex_ret_msprd_brnch_instr_dir_msmtch\000\000core\000Retired Mispredicted Branch Instructions due to Direction Mismatch\000event=0x1c7\000\00000\000The number of retired conditional branch instructions that were not correctly predicted because of a branch direction mismatch\000 */
{ 842982 }, /* ex_ret_near_ret\000\000core\000Retired Near Returns\000event=0xc8\000\00000\000The number of near return instructions (RET or RET Iw) retired\000 */
{ 843278 }, /* ex_ret_near_ret_mispred\000\000core\000Retired Near Returns Mispredicted\000event=0xc9\000\00000\000The number of near returns retired that were not correctly predicted by the return address predictor. Each such mispredict incurs the same penalty as a mispredicted conditional branch instruction\000 */
{ 843553 }, /* ex_ret_ops\000\000core\000Retired Ops. Use macro_ops_retired instead\000event=0xc1\000\00000\000The number of macro-ops retired\000 */
{ 844063 }, /* ex_tagged_ibs_ops.ibs_count_rollover\000\000core\000Tagged IBS Ops. Number of times an op could not be tagged by IBS because of a previous tagged op that has not retired\000event=0x1cf,umask=0x04\000\00000\000\000 */
{ 844337 }, /* ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000 */
{ 844550 }, /* ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Tagged IBS Ops. Number of Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000 */
{ 779893 }, /* dram_channel_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780073 }, /* dram_channel_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x47,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780254 }, /* dram_channel_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x87,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780435 }, /* dram_channel_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780616 }, /* dram_channel_data_controller_4\000amd_df\000data fabric\000Unit: amd_df \000event=0x107,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780798 }, /* dram_channel_data_controller_5\000amd_df\000data fabric\000Unit: amd_df \000event=0x147,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 780980 }, /* dram_channel_data_controller_6\000amd_df\000data fabric\000Unit: amd_df \000event=0x187,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 781162 }, /* dram_channel_data_controller_7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1c7,umask=0x38\000\00001\000DRAM Channel Controller Request Types: Requests with Data (64B): DRAM Channel Controller 0\000 */
{ 2488348 }, /* remote_outbound_data_controller_0\000amd_df\000data fabric\000Unit: amd_df \000event=0x7c7,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 0\000 */
{ 2488525 }, /* remote_outbound_data_controller_1\000amd_df\000data fabric\000Unit: amd_df \000event=0x807,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 1\000 */
{ 2488702 }, /* remote_outbound_data_controller_2\000amd_df\000data fabric\000Unit: amd_df \000event=0x847,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 2\000 */
{ 2488879 }, /* remote_outbound_data_controller_3\000amd_df\000data fabric\000Unit: amd_df \000event=0x887,umask=0x02\000\00001\000Remote Link Controller Outbound Packet Types: Data (32B): Remote Link Controller 3\000 */
{ 909554 }, /* fp_disp_faults.x87_fill_fault\000\000floating point\000Floating Point Dispatch Faults. x87 fill fault\000event=0xe,umask=0x01\000\00000\000\000 */
{ 909790 }, /* fp_disp_faults.xmm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. XMM fill fault\000event=0xe,umask=0x02\000\00000\000\000 */
{ 910026 }, /* fp_disp_faults.ymm_fill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM fill fault\000event=0xe,umask=0x04\000\00000\000\000 */
{ 910262 }, /* fp_disp_faults.ymm_spill_fault\000\000floating point\000Floating Point Dispatch Faults. YMM spill fault\000event=0xe,umask=0x08\000\00000\000\000 */
{ 910880 }, /* fp_num_mov_elim_scal_op.opt_potential\000\000floating point\000Number of Ops that are candidates for optimization (have Z-bit either set or pass). This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x04\000\00000\000\000 */
{ 911592 }, /* fp_num_mov_elim_scal_op.optimized\000\000floating point\000Number of Scalar Ops optimized. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x08\000\00000\000\000 */
{ 912140 }, /* fp_num_mov_elim_scal_op.sse_mov_ops\000\000floating point\000Number of SSE Move Ops. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x01\000\00000\000\000 */
{ 912668 }, /* fp_num_mov_elim_scal_op.sse_mov_ops_elim\000\000floating point\000Number of SSE Move Ops eliminated. This is a dispatch based speculative event, and is useful for measuring the effectiveness of the Move elimination and Scalar code optimization schemes\000event=0x4,umask=0x02\000\00000\000\000 */
{ 921120 }, /* fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Add/subtract FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x01\000\00000\000\000 */
{ 921684 }, /* fp_ret_sse_avx_ops.all\000\000floating point\000All FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPS. The number of events logged per cycle can vary from 0 to 64. This event can count above 15\000event=0x3,umask=0xff\000\00000\000\000 */
{ 922703 }, /* fp_ret_sse_avx_ops.div_flops\000\000floating point\000Divide/square root FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x04\000\00000\000\000 */
{ 924565 }, /* fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Multiply-Accumulate FLOPs. Each MAC operation is counted as 2 FLOPS. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x08\000\00000\000\000 */
{ 925737 }, /* fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Multiply FLOPs. This is a retire-based event. The number of retired SSE/AVX FLOPs. The number of events logged per cycle can vary from 0 to 64. This event requires the use of the MergeEvent since it can count above 15 events per cycle. See 2.1.17.3 [Large Increment per Cycle Events]. It does not provide a useful count without the use of the MergeEvent\000event=0x3,umask=0x02\000\00000\000\000 */
{ 928665 }, /* fp_retired_ser_ops.sse_bot_ret\000\000floating point\000SSE/AVX bottom-executing ops retired. The number of serializing Ops retired\000event=0x5,umask=0x08\000\00000\000\000 */
{ 929248 }, /* fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000SSE/AVX control word mispredict traps. The number of serializing Ops retired\000event=0x5,umask=0x04\000\00000\000\000 */
{ 929789 }, /* fp_retired_ser_ops.x87_bot_ret\000\000floating point\000x87 bottom-executing ops retired. The number of serializing Ops retired\000event=0x5,umask=0x02\000\00000\000\000 */
{ 930444 }, /* fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000x87 control word mispredict traps due to mispredictions in RC or PC, or changes in mask bits. The number of serializing Ops retired\000event=0x5,umask=0x01\000\00000\000\000 */
{ 939310 }, /* fpu_pipe_assignment.total\000\000floating point\000Total number of fp uOps\000event=0,umask=0x0f\000\00000\000Total number of fp uOps. The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS\000 */
{ 935165 }, /* fpu_pipe_assignment.total0\000\000floating point\000Total number of fp uOps  on pipe 0\000event=0,umask=0x01\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 0\000 */
{ 936348 }, /* fpu_pipe_assignment.total1\000\000floating point\000Total number uOps assigned to pipe 1\000event=0,umask=0x02\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 1\000 */
{ 937533 }, /* fpu_pipe_assignment.total2\000\000floating point\000Total number uOps assigned to pipe 2\000event=0,umask=0x04\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one- cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 2\000 */
{ 938717 }, /* fpu_pipe_assignment.total3\000\000floating point\000Total number uOps assigned to pipe 3\000event=0,umask=0x08\000\00000\000The number of operations (uOps) dispatched to each of the 4 FPU execution pipelines. This event reflects how busy the FPU pipelines are and may be used for workload characterization. This includes all operations performed by x87, MMX, and SSE instructions, including moves. Each increment represents a one-cycle dispatch event. This event is a speculative event. Since this event includes non-numeric operations it is not suitable for measuring MFLOPS. Total number uOps assigned to pipe 3\000 */
{ 1254540 }, /* ls_alloc_mab_count\000\000memory\000Count of Allocated Mabs\000event=0x5f\000\00000\000This event counts the in-flight L1 data cache misses (allocated Miss Address Buffers) divided by 4 and rounded down each cycle unless used with the MergeEvent functionality. If the MergeEvent is used, it counts the exact number of outstanding L1 data cache misses. See 2.1.17.3 [Large Increment per Cycle Events]\000 */
{ 1255768 }, /* ls_any_fills_from_sys.ext_cache_local\000\000memory\000Any Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x44,umask=0x04\000\00000\000\000 */
{ 1255919 }, /* ls_any_fills_from_sys.ext_cache_remote\000\000memory\000Any Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x44,umask=0x10\000\00000\000\000 */
{ 1256427 }, /* ls_any_fills_from_sys.int_cache\000\000memory\000Any Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x44,umask=0x02\000\00000\000\000 */
{ 1256567 }, /* ls_any_fills_from_sys.lcl_l2\000\000memory\000Any Data Cache Fills by Data Source. From Local L2 to the core\000event=0x44,umask=0x01\000\00000\000\000 */
{ 1257096 }, /* ls_any_fills_from_sys.mem_io_local\000\000memory\000Any Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x44,umask=0x08\000\00000\000\000 */
{ 1257242 }, /* ls_any_fills_from_sys.mem_io_remote\000\000memory\000Any Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x44,umask=0x40\000\00000\000\000 */
{ 1257725 }, /* ls_bad_status2.stli_other\000\000memory\000Non-forwardable conflict; used to reduce STLI's via software. All reasons. Store To Load Interlock (STLI) are loads that were unable to complete because of a possible match with an older store, and the older store could not do STLF for some reason\000event=0x24,umask=0x02\000\00000\000Store-to-load conflicts: A load was unable to complete due to a non-forwardable conflict with an older store. Most commonly, a load's address range partially but not completely overlaps with an uncompleted older store. Software can avoid this problem by using same-size and same-alignment loads and stores when accessing the same data. Vector/SIMD code is particularly susceptible to this problem; software should construct wide vector stores by manipulating vector elements in registers using shuffle/blend/swap instructions prior to storing to memory, instead of using narrow element-by-element stores\000 */
{ 1258802 }, /* ls_dc_accesses\000\000memory\000Number of accesses to the dcache for load/store references\000event=0x40\000\00000\000The number of accesses to the data cache for load and store references. This may include certain microcode scratchpad accesses, although these are generally rare. Each increment represents an eight-byte access, although the instruction may only be accessing a portion of that. This event is a speculative event\000 */
{ 1259690 }, /* ls_dispatch.ld_dispatch\000\000memory\000Dispatch of a single op that performs a memory load. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x01\000\00000\000\000 */
{ 1260525 }, /* ls_dispatch.ld_st_dispatch\000\000memory\000Load-op-Store Dispatch. Dispatch of a single op that performs a load from and store to the same memory address. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x04\000\00000\000\000 */
{ 1261044 }, /* ls_dispatch.store_dispatch\000\000memory\000Dispatch of a single op that performs a memory store. Counts the number of operations dispatched to the LS unit. Unit Masks ADDed\000event=0x29,umask=0x02\000\00000\000\000 */
{ 1262082 }, /* ls_dmnd_fills_from_sys.ext_cache_local\000\000memory\000Demand Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x43,umask=0x04\000\00000\000\000 */
{ 1262237 }, /* ls_dmnd_fills_from_sys.ext_cache_remote\000\000memory\000Demand Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x43,umask=0x10\000\00000\000\000 */
{ 1262548 }, /* ls_dmnd_fills_from_sys.int_cache\000\000memory\000Demand Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x43,umask=0x02\000\00000\000\000 */
{ 1262692 }, /* ls_dmnd_fills_from_sys.lcl_l2\000\000memory\000Demand Data Cache Fills by Data Source. From Local L2 to the core\000event=0x43,umask=0x01\000\00000\000\000 */
{ 1263076 }, /* ls_dmnd_fills_from_sys.mem_io_local\000\000memory\000Demand Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x43,umask=0x08\000\00000\000\000 */
{ 1263226 }, /* ls_dmnd_fills_from_sys.mem_io_remote\000\000memory\000Demand Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x43,umask=0x40\000\00000\000\000 */
{ 1264876 }, /* ls_hw_pf_dc_fills.ext_cache_local\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x5a,umask=0x04\000\00000\000\000 */
{ 1265037 }, /* ls_hw_pf_dc_fills.ext_cache_remote\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x5a,umask=0x10\000\00000\000\000 */
{ 1265360 }, /* ls_hw_pf_dc_fills.int_cache\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x5a,umask=0x02\000\00000\000\000 */
{ 1265510 }, /* ls_hw_pf_dc_fills.lcl_l2\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From Local L2 to the core\000event=0x5a,umask=0x01\000\00000\000\000 */
{ 1265912 }, /* ls_hw_pf_dc_fills.mem_io_local\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x5a,umask=0x08\000\00000\000\000 */
{ 1266068 }, /* ls_hw_pf_dc_fills.mem_io_remote\000\000memory\000Hardware Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x5a,umask=0x40\000\00000\000\000 */
{ 1266648 }, /* ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a DC hit\000event=0x52,umask=0x01\000\00000\000\000 */
{ 1267080 }, /* ls_inef_sw_pref.mab_mch_cnt\000\000memory\000The number of software prefetches that did not fetch data outside of the processor core. Software PREFETCH instruction saw a match on an already-allocated miss request buffer\000event=0x52,umask=0x02\000\00000\000\000 */
{ 1267370 }, /* ls_int_taken\000\000memory\000Counts the number of interrupts taken\000event=0x2c\000\00000\000\000 */
{ 1267509 }, /* ls_l1_d_tlb_miss.all\000\000memory\000All L1 DTLB Misses or Reloads. Use l1_dtlb_misses instead\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1268043 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that hit in the L2 TLB\000event=0x45,umask=0x08\000\00000\000\000 */
{ 1268514 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 1G page that also missed in the L2 TLB\000event=0x45,umask=0x80\000\00000\000\000 */
{ 1268950 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that hit in the L2 TLB\000event=0x45,umask=0x04\000\00000\000\000 */
{ 1269421 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 2M page that also missed in the L2 TLB\000event=0x45,umask=0x40\000\00000\000\000 */
{ 1270078 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that hit in the L2 TLB\000event=0x45,umask=0x01\000\00000\000\000 */
{ 1270683 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB Miss. DTLB reload to a 4K page that missed the L2 TLB\000event=0x45,umask=0x10\000\00000\000\000 */
{ 1271103 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB Miss. DTLB reload to a coalesced page that hit in the L2 TLB\000event=0x45,umask=0x02\000\00000\000\000 */
{ 1271586 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB Miss. DTLB reload coalesced page that also missed in the L2 TLB\000event=0x45,umask=0x20\000\00000\000\000 */
{ 1272445 }, /* ls_locks.bus_lock\000\000memory\000Retired lock instructions. Comparable to legacy bus lock\000event=0x25,umask=0x01\000\00000\000\000 */
{ 1272555 }, /* ls_locks.non_spec_lock\000\000memory\000Retired lock instructions. Non-speculative lock succeeded\000event=0x25,umask=0x02\000\00000\000\000 */
{ 1272671 }, /* ls_locks.spec_lock_hi_spec\000\000memory\000Retired lock instructions. High speculative cacheable lock speculation succeeded\000event=0x25,umask=0x08\000\00000\000\000 */
{ 1272814 }, /* ls_locks.spec_lock_lo_spec\000\000memory\000Retired lock instructions. Low speculative cacheable lock speculation succeeded\000event=0x25,umask=0x04\000\00000\000\000 */
{ 1273118 }, /* ls_mab_alloc.all_allocations\000\000memory\000All Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x7f\000\00000\000\000 */
{ 1273243 }, /* ls_mab_alloc.dc_prefetcher\000\000memory\000LS MAB Allocates by Type. DC prefetcher\000event=0x41,umask=0x08\000\00000\000\000 */
{ 1273633 }, /* ls_mab_alloc.hardware_prefetcher_allocations\000\000memory\000Hardware Prefetcher Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x40\000\00000\000\000 */
{ 1273957 }, /* ls_mab_alloc.load_store_allocations\000\000memory\000Load Store Allocations. Counts when a LS pipe allocates a MAB entry\000event=0x41,umask=0x3f\000\00000\000\000 */
{ 1274096 }, /* ls_mab_alloc.loads\000\000memory\000LS MAB Allocates by Type. Loads\000event=0x41,umask=0x01\000\00000\000\000 */
{ 1274269 }, /* ls_mab_alloc.stores\000\000memory\000LS MAB Allocates by Type. Stores\000event=0x41,umask=0x02\000\00000\000\000 */
{ 1274597 }, /* ls_misal_loads.ma4k\000\000memory\000The number of 4KB misaligned (i.e., page crossing) loads\000event=0x47,umask=0x02\000\00000\000\000 */
{ 1274806 }, /* ls_misal_loads.ma64\000\000memory\000The number of 64B misaligned (i.e., cacheline crossing) loads\000event=0x47,umask=0x01\000\00000\000\000 */
{ 1274987 }, /* ls_not_halted_cyc\000\000memory\000Cycles not in Halt\000event=0x76\000\00000\000\000 */
{ 1277237 }, /* ls_pref_instr_disp\000\000memory\000Software Prefetch Instructions Dispatched (Speculative)\000event=0x4b,umask=0xff\000\00000\000\000 */
{ 1275697 }, /* ls_pref_instr_disp.prefetch\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchT0, T1 and T2 instructions. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x01\000\00000\000\000 */
{ 1276423 }, /* ls_pref_instr_disp.prefetch_nta\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchNTA instruction. See docAPM3 PREFETCHlevel\000event=0x4b,umask=0x04\000\00000\000\000 */
{ 1276783 }, /* ls_pref_instr_disp.prefetch_w\000\000memory\000Software Prefetch Instructions Dispatched (Speculative). PrefetchW instruction. See docAPM3 PREFETCHW\000event=0x4b,umask=0x02\000\00000\000\000 */
{ 1277347 }, /* ls_rdtsc\000\000memory\000Number of reads of the TSC (RDTSC instructions). The count is speculative\000event=0x2d\000\00000\000\000 */
{ 1278433 }, /* ls_ret_cl_flush\000\000memory\000The number of retired CLFLUSH instructions. This is a non-speculative event\000event=0x26\000\00000\000\000 */
{ 1278685 }, /* ls_ret_cpuid\000\000memory\000The number of CPUID instructions retired\000event=0x27\000\00000\000\000 */
{ 1278809 }, /* ls_smi_rx\000\000memory\000Counts the number of SMIs received\000event=0x2b\000\00000\000\000 */
{ 1278936 }, /* ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000A non-cacheable store and the non-cacheable commit buffer is full\000event=0x37,umask=0x01\000\00000\000\000 */
{ 1279391 }, /* ls_stlf\000\000memory\000Number of STLF hits\000event=0x35\000\00000\000\000 */
{ 1280878 }, /* ls_sw_pf_dc_fills.ext_cache_local\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From cache of different CCX in same node\000event=0x59,umask=0x04\000\00000\000\000 */
{ 1281039 }, /* ls_sw_pf_dc_fills.ext_cache_remote\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From CCX Cache in different Node\000event=0x59,umask=0x10\000\00000\000\000 */
{ 1281341 }, /* ls_sw_pf_dc_fills.int_cache\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From L3 or different L2 in same CCX\000event=0x59,umask=0x02\000\00000\000\000 */
{ 1281491 }, /* ls_sw_pf_dc_fills.lcl_l2\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From Local L2 to the core\000event=0x59,umask=0x01\000\00000\000\000 */
{ 1281893 }, /* ls_sw_pf_dc_fills.mem_io_local\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in same node\000event=0x59,umask=0x08\000\00000\000\000 */
{ 1282049 }, /* ls_sw_pf_dc_fills.mem_io_remote\000\000memory\000Software Prefetch Data Cache Fills by Data Source. From DRAM or IO connected in different Node\000event=0x59,umask=0x40\000\00000\000\000 */
{ 1282357 }, /* ls_tablewalker.dc_type0\000\000memory\000Total Page Table Walks DC Type 0\000event=0x46,umask=0x01\000\00000\000\000 */
{ 1282449 }, /* ls_tablewalker.dc_type1\000\000memory\000Total Page Table Walks DC Type 1\000event=0x46,umask=0x02\000\00000\000\000 */
{ 1282541 }, /* ls_tablewalker.dside\000\000memory\000Total Page Table Walks on D-side\000event=0x46,umask=0x03\000\00000\000\000 */
{ 1282630 }, /* ls_tablewalker.ic_type0\000\000memory\000Total Page Table Walks IC Type 0\000event=0x46,umask=0x04\000\00000\000\000 */
{ 1282722 }, /* ls_tablewalker.ic_type1\000\000memory\000Total Page Table Walks IC Type 1\000event=0x46,umask=0x08\000\00000\000\000 */
{ 1282814 }, /* ls_tablewalker.iside\000\000memory\000Total Page Table Walks on I-side\000event=0x46,umask=0x0c\000\00000\000\000 */
{ 1282971 }, /* ls_tlb_flush.all_tlb_flushes\000\000memory\000All TLB Flushes. Requires unit mask 0xFF to engage event for counting. Use all_tlbs_flushed instead\000event=0x78,umask=0xff\000\00000\000\000 */
{ 762975 }, /* de_dis_cops_from_decoder.disp_op_type.any_fp_dispatch\000\000other\000Any FP dispatch. Types of Oops Dispatched from Decoder\000event=0xab,umask=0x04\000\00000\000\000 */
{ 763118 }, /* de_dis_cops_from_decoder.disp_op_type.any_integer_dispatch\000\000other\000Any Integer dispatch. Types of Oops Dispatched from Decoder\000event=0xab,umask=0x08\000\00000\000\000 */
{ 765632 }, /* de_dis_dispatch_token_stalls1.fp_flush_recovery_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. FP Flush recovery stall\000event=0xae,umask=0x80\000\00000\000\000 */
{ 766367 }, /* de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Floating point register file resource stall. Applies to all FP ops that have a destination register\000event=0xae,umask=0x20\000\00000\000\000 */
{ 767196 }, /* de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. FP scheduler resource stall. Applies to ops that use the FP scheduler\000event=0xae,umask=0x40\000\00000\000\000 */
{ 767946 }, /* de_dis_dispatch_token_stalls1.int_phy_reg_file_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Integer Physical Register File resource stall. Integer Physical Register File, applies to all ops that have an integer destination register\000event=0xae,umask=0x01\000\00000\000\000 */
{ 768841 }, /* de_dis_dispatch_token_stalls1.int_sched_misc_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Integer Scheduler miscellaneous resource stall\000event=0xae,umask=0x08\000\00000\000\000 */
{ 769068 }, /* de_dis_dispatch_token_stalls1.load_queue_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Load Queue resource stall. Applies to all ops with load semantics\000event=0xae,umask=0x02\000\00000\000\000 */
{ 769808 }, /* de_dis_dispatch_token_stalls1.store_queue_rsrc_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Store Queue resource stall. Applies to all ops with store semantics\000event=0xae,umask=0x04\000\00000\000\000 */
{ 770776 }, /* de_dis_dispatch_token_stalls1.taken_brnch_buffer_rsrc\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a Token Stall. Also counts cycles when the thread is not selected to dispatch but would have been stalled due to a Token Stall. Taken branch buffer resource stall\000event=0xae,umask=0x10\000\00000\000\000 */
{ 771257 }, /* de_dis_dispatch_token_stalls2.agsq_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. AGSQ Tokens unavailable\000event=0xaf,umask=0x10\000\00000\000\000 */
{ 771451 }, /* de_dis_dispatch_token_stalls2.int_sch0_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 0 available\000event=0xaf,umask=0x01\000\00000\000\000 */
{ 771834 }, /* de_dis_dispatch_token_stalls2.int_sch1_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 1 available\000event=0xaf,umask=0x02\000\00000\000\000 */
{ 772217 }, /* de_dis_dispatch_token_stalls2.int_sch2_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 2 available\000event=0xaf,umask=0x04\000\00000\000\000 */
{ 772600 }, /* de_dis_dispatch_token_stalls2.int_sch3_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. No tokens for Integer Scheduler Queue 3 available\000event=0xaf,umask=0x08\000\00000\000\000 */
{ 772983 }, /* de_dis_dispatch_token_stalls2.retire_token_stall\000\000other\000Cycles where a dispatch group is valid but does not get dispatched due to a token stall. Insufficient Retire Queue tokens available\000event=0xaf,umask=0x20\000\00000\000\000 */
{ 773615 }, /* de_dis_uop_queue_empty_di0\000\000other\000Cycles where the Micro-Op Queue is empty\000event=0xa9\000\00000\000\000 */
{ 466310 }, /* all_data_cache_accesses\000\000recommended\000All L1 Data Cache Accesses\000event=0x29,umask=0x07\000\00000\000\000 */
{ 466646 }, /* all_tlbs_flushed\000\000recommended\000All TLBs Flushed\000event=0x78,umask=0xff\000\00000\000\000 */
{ 1099271 }, /* l1_data_cache_fills_all\000\000recommended\000L1 Data Cache Fills: All\000event=0x44,umask=0xff\000\00000\000\000 */
{ 1099360 }, /* l1_data_cache_fills_from_external_ccx_cache\000\000recommended\000L1 Data Cache Fills: From External CCX Cache\000event=0x44,umask=0x14\000\00000\000\000 */
{ 1099489 }, /* l1_data_cache_fills_from_memory\000\000recommended\000L1 Data Cache Fills: From Memory\000event=0x44,umask=0x48\000\00000\000\000 */
{ 1099594 }, /* l1_data_cache_fills_from_remote_node\000\000recommended\000L1 Data Cache Fills: From Remote Node\000event=0x44,umask=0x50\000\00000\000\000 */
{ 1099709 }, /* l1_data_cache_fills_from_within_same_ccx\000\000recommended\000L1 Data Cache Fills: From within same CCX\000event=0x44,umask=0x03\000\00000\000\000 */
{ 1099832 }, /* l1_dtlb_misses\000\000recommended\000L1 DTLB Misses\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1115327 }, /* l2_cache_accesses_from_dc_misses\000\000recommended\000L2 Cache Accesses from L1 Data Cache Misses (including prefetch)\000event=0x60,umask=0xe8\000\00000\000\000 */
{ 1115465 }, /* l2_cache_accesses_from_ic_misses\000\000recommended\000L2 Cache Accesses from L1 Instruction Cache Misses (including prefetch)\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1115719 }, /* l2_cache_hits_from_dc_misses\000\000recommended\000L2 Cache Hits from L1 Data Cache Misses\000event=0x64,umask=0xf0\000\00000\000\000 */
{ 1115828 }, /* l2_cache_hits_from_ic_misses\000\000recommended\000L2 Cache Hits from L1 Instruction Cache Misses\000event=0x64,umask=0x06\000\00000\000\000 */
{ 1115944 }, /* l2_cache_hits_from_l2_hwpf\000\000recommended\000L2 Cache Hits from L2 Cache HWPF\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1116138 }, /* l2_cache_misses_from_dc_misses\000\000recommended\000L2 Cache Misses from L1 Data Cache Misses\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1116251 }, /* l2_cache_misses_from_ic_miss\000\000recommended\000L2 Cache Misses from L1 Instruction Cache Misses\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1124121 }, /* l2_dtlb_misses\000\000recommended\000L2 DTLB Misses & Data page walks\000event=0x45,umask=0xf0\000\00000\000\000 */
{ 1124926 }, /* l2_itlb_misses\000\000recommended\000L2 ITLB Misses & Instruction page walks\000event=0x85,umask=0x07\000\00000\000\000 */
{ 1186060 }, /* l3_cache_accesses\000amd_l3\000recommended\000L3 Cache Accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1187137 }, /* l3_misses\000amd_l3\000recommended\000L3 Misses (includes cacheline state change requests). Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000 */
{ 1303229 }, /* macro_ops_retired\000\000recommended\000Macro-ops Retired\000event=0xc1\000\00000\000\000 */
{ 2536007 }, /* sse_avx_stalls\000\000recommended\000Mixed SSE/AVX Stalls\000event=0xe,umask=0x0e\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__amdzen3[] = {
{ 6782 }, /* \000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Accesses\000\000\000\000\000\00000 */
{ 7199 }, /* \000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2\000\000All L2 Cache Hits\000\000\000\000\000\00000 */
{ 7302 }, /* \000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000All L2 Cache Misses\000\000\000\000\000\00000 */
{ 7580 }, /* \000all_remote_links_outbound\000data_fabric\000remote_outbound_data_controller_0 + remote_outbound_data_controller_1 + remote_outbound_data_controller_2 + remote_outbound_data_controller_3\000\000Approximate: Outbound data bytes for all Remote Links for a node (die)\000\0003e-5MiB\000\000\000\00000 */
{ 9223 }, /* \000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-Time Branch Misprediction Ratio (Non-Speculative)\000\000100%\000\000\000\00000 */
{ 16239 }, /* \000ic_fetch_miss_ratio\000l2_cache\000d_ratio(ic_tag_hit_miss.instruction_cache_miss, ic_tag_hit_miss.all_instruction_cache_accesses)\000\000Instruction Cache (32B) Fetch Miss Ratio\000\000100%\000\000\000\00000 */
{ 23027 }, /* \000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_hit + bp_l1_tlb_miss_l2_tlb_miss\000\000L1 ITLB Misses\000\000\000\000\000\00000 */
{ 24041 }, /* \000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2 + l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Accesses from L2 HWPF\000\000\000\000\000\00000 */
{ 24951 }, /* \000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3 + l2_pf_miss_l2_l3\000\000L2 Cache Misses from L2 Cache HWPF\000\000\000\000\000\00000 */
{ 27278 }, /* \000l3_read_miss_latency\000l3_cache\000xi_sys_fill_latency * 16 / xi_ccx_sdp_req1\000\000Average L3 Read Miss Latency (in core clocks)\000\0001core clocks\000\000\000\00000 */
{ 39048 }, /* \000macro_ops_dispatched\000decoder\000de_dis_cops_from_decoder.disp_op_type.any_integer_dispatch + de_dis_cops_from_decoder.disp_op_type.any_fp_dispatch\000\000Macro-ops Dispatched\000\000\000\000\000\00000 */
{ 40023 }, /* \000nps1_die_to_dram\000data_fabric\000dram_channel_data_controller_0 + dram_channel_data_controller_1 + dram_channel_data_controller_2 + dram_channel_data_controller_3 + dram_channel_data_controller_4 + dram_channel_data_controller_5 + dram_channel_data_controller_6 + dram_channel_data_controller_7\000\000Approximate: Combined DRAM B/bytes of all channels on a NPS1 node (die)\000\0006.1e-5MiB\000\000\000\00001 */
{ 42996 }, /* \000op_cache_fetch_miss_ratio\000l2_cache\000d_ratio(op_cache_hit_miss.op_cache_miss, op_cache_hit_miss.all_op_cache_accesses)\000\000Op Cache (64B) Fetch Miss Ratio\000\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__amdzen4[] = {
{ 1266397 }, /* ls_inef_sw_pref.all\000\000cache\000\000event=0x52,umask=0x03\000\00000\000\000 */
{ 481106 }, /* bp_de_redirect\000\000branch\000Instruction decoder corrects the predicted target and resteers the branch predictor\000event=0x91\000\00000\000\000 */
{ 481518 }, /* bp_dyn_ind_pred\000\000branch\000Dynamic indirect predictions (branch used the indirect predictor to make a prediction)\000event=0x8e\000\00000\000\000 */
{ 486726 }, /* bp_l2_btb_correct\000\000branch\000L2 branch prediction overrides existing prediction (speculative)\000event=0x8b\000\00000\000\000 */
{ 836391 }, /* ex_ret_brn\000\000branch\000Retired branch instructions (all types of architectural control flow changes, including exceptions and interrupts)\000event=0xc2\000\00000\000\000 */
{ 836743 }, /* ex_ret_brn_far\000\000branch\000Retired far control transfers (far call/jump/return, IRET, SYSCALL and SYSRET, plus exceptions and interrupts). Far control transfers are not subject to branch prediction\000event=0xc6\000\00000\000\000 */
{ 837212 }, /* ex_ret_brn_ind_misp\000\000branch\000Retired indirect branch instructions mispredicted (only EX mispredicts). Each misprediction incurs the same penalty as a mispredicted conditional branch instruction\000event=0xca\000\00000\000\000 */
{ 837816 }, /* ex_ret_brn_misp\000\000branch\000Retired branch instructions mispredicted\000event=0xc3\000\00000\000\000 */
{ 838656 }, /* ex_ret_brn_tkn\000\000branch\000Retired taken branch instructions (all types of architectural control flow changes, including exceptions and interrupts)\000event=0xc4\000\00000\000\000 */
{ 839033 }, /* ex_ret_brn_tkn_misp\000\000branch\000Retired taken branch instructions mispredicted\000event=0xc5\000\00000\000\000 */
{ 839283 }, /* ex_ret_cond\000\000branch\000Retired conditional branch instructions\000event=0xd1\000\00000\000\000 */
{ 840509 }, /* ex_ret_ind_brch_instr\000\000branch\000Retired indirect branch instructions\000event=0xcc\000\00000\000\000 */
{ 842525 }, /* ex_ret_msprd_brnch_instr_dir_msmtch\000\000branch\000Retired branch instructions mispredicted due to direction mismatch\000event=0x1c7\000\00000\000\000 */
{ 842905 }, /* ex_ret_near_ret\000\000branch\000Retired near returns (RET or RET Iw)\000event=0xc8\000\00000\000\000 */
{ 843103 }, /* ex_ret_near_ret_mispred\000\000branch\000Retired near returns mispredicted. Each misprediction incurs the same penalty as a mispredicted conditional branch instruction\000event=0xc9\000\00000\000\000 */
{ 843847 }, /* ex_ret_uncond_brnch_instr\000\000branch\000Retired unconditional branch instructions\000event=0x1c9\000\00000\000\000 */
{ 843940 }, /* ex_ret_uncond_brnch_instr_mispred\000\000branch\000Retired unconditional indirect branch instructions mispredicted\000event=0x1c8\000\00000\000\000 */
{ 979480 }, /* ic_cache_fill_l2\000\000cache\000Instruction cache lines (64 bytes) fulfilled from the L2 cache\000event=0x82\000\00000\000\000 */
{ 979871 }, /* ic_cache_fill_sys\000\000cache\000Instruction cache lines (64 bytes) fulfilled from system memory or another cache\000event=0x83\000\00000\000\000 */
{ 982120 }, /* ic_tag_hit_miss.all_instruction_cache_accesses\000\000cache\000Instruction cache accesses of all types\000event=0x18e,umask=0x1f\000\00000\000\000 */
{ 982388 }, /* ic_tag_hit_miss.instruction_cache_hit\000\000cache\000Instruction cache hits\000event=0x18e,umask=0x07\000\00000\000\000 */
{ 982632 }, /* ic_tag_hit_miss.instruction_cache_miss\000\000cache\000Instruction cache misses\000event=0x18e,umask=0x18\000\00000\000\000 */
{ 1116369 }, /* l2_cache_req_stat.all\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache access\000event=0x64,umask=0xff\000\00000\000\000 */
{ 1116517 }, /* l2_cache_req_stat.dc_access_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data cache access\000event=0x64,umask=0xf8\000\00000\000\000 */
{ 1116661 }, /* l2_cache_req_stat.dc_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data cache hits\000event=0x64,umask=0xf0\000\00000\000\000 */
{ 1116800 }, /* l2_cache_req_stat.ic_access_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for instruction cache access\000event=0x64,umask=0x07\000\00000\000\000 */
{ 1117124 }, /* l2_cache_req_stat.ic_dc_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache hits\000event=0x64,umask=0xf6\000\00000\000\000 */
{ 1117503 }, /* l2_cache_req_stat.ic_dc_miss_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for data and instruction cache misses\000event=0x64,umask=0x09\000\00000\000\000 */
{ 1117888 }, /* l2_cache_req_stat.ic_fill_hit_s\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache hit non-modifiable line in L2\000event=0x64,umask=0x02\000\00000\000\000 */
{ 1118432 }, /* l2_cache_req_stat.ic_fill_hit_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache hit modifiable line in L2\000event=0x64,umask=0x04\000\00000\000\000 */
{ 1118791 }, /* l2_cache_req_stat.ic_fill_miss\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: instruction cache request miss in L2\000event=0x64,umask=0x01\000\00000\000\000 */
{ 1119350 }, /* l2_cache_req_stat.ic_hit_in_l2\000\000cache\000Core to L2 cache requests (not including L2 prefetch) for instruction cache hits\000event=0x64,umask=0x06\000\00000\000\000 */
{ 1119496 }, /* l2_cache_req_stat.ls_rd_blk_c\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache request miss in L2\000event=0x64,umask=0x08\000\00000\000\000 */
{ 1120057 }, /* l2_cache_req_stat.ls_rd_blk_cs\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache shared read hit in L2\000event=0x64,umask=0x80\000\00000\000\000 */
{ 1120392 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_s\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache read hit non-modifiable line in L2\000event=0x64,umask=0x20\000\00000\000\000 */
{ 1120946 }, /* l2_cache_req_stat.ls_rd_blk_l_hit_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache read hit modifiable line in L2\000event=0x64,umask=0x40\000\00000\000\000 */
{ 1121473 }, /* l2_cache_req_stat.ls_rd_blk_x\000\000cache\000Core to L2 cache requests (not including L2 prefetch) with status: data cache store or state change hit in L2\000event=0x64,umask=0x10\000\00000\000\000 */
{ 1139932 }, /* l2_pf_hit_l2.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of all types\000event=0x70,umask=0xff\000\00000\000\000 */
{ 1140064 }, /* l2_pf_hit_l2.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x70,umask=0x80\000\00000\000\000 */
{ 1140379 }, /* l2_pf_hit_l2.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x70,umask=0x20\000\00000\000\000 */
{ 1140571 }, /* l2_pf_hit_l2.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x70,umask=0x40\000\00000\000\000 */
{ 1140810 }, /* l2_pf_hit_l2.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x70,umask=0x08\000\00000\000\000 */
{ 1141013 }, /* l2_pf_hit_l2.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2NextLine (fetch the next line into L2 cache)\000event=0x70,umask=0x02\000\00000\000\000 */
{ 1141196 }, /* l2_pf_hit_l2.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x70,umask=0x01\000\00000\000\000 */
{ 1141388 }, /* l2_pf_hit_l2.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2Stride (fetch additional lines into L2 cache when each access is at a constant distance from the previous)\000event=0x70,umask=0x10\000\00000\000\000 */
{ 1141630 }, /* l2_pf_hit_l2.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which hit in the L2 cache of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x70,umask=0x04\000\00000\000\000 */
{ 1141954 }, /* l2_pf_miss_l2_hit_l3.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache cache of all types\000event=0x71,umask=0xff\000\00000\000\000 */
{ 1142122 }, /* l2_pf_miss_l2_hit_l3.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x71,umask=0x80\000\00000\000\000 */
{ 1142467 }, /* l2_pf_miss_l2_hit_l3.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x71,umask=0x20\000\00000\000\000 */
{ 1142689 }, /* l2_pf_miss_l2_hit_l3.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x71,umask=0x40\000\00000\000\000 */
{ 1142958 }, /* l2_pf_miss_l2_hit_l3.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x71,umask=0x08\000\00000\000\000 */
{ 1143191 }, /* l2_pf_miss_l2_hit_l3.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2NextLine (fetch the next line into L2 cache)\000event=0x71,umask=0x02\000\00000\000\000 */
{ 1143404 }, /* l2_pf_miss_l2_hit_l3.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x71,umask=0x01\000\00000\000\000 */
{ 1143626 }, /* l2_pf_miss_l2_hit_l3.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2Stride (fetch additional lines into L2 cache when each access is a constant distance from the previous)\000event=0x71,umask=0x10\000\00000\000\000 */
{ 1143895 }, /* l2_pf_miss_l2_hit_l3.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 cache and hit in the L3 cache of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x71,umask=0x04\000\00000\000\000 */
{ 1144313 }, /* l2_pf_miss_l2_l3.all\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of all types\000event=0x72,umask=0xff\000\00000\000\000 */
{ 1144459 }, /* l2_pf_miss_l2_l3.l1_region\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Region (fetch additional lines into L1 cache when the data access for a given instruction tends to be followed by a consistent pattern of other accesses within a localized region)\000event=0x72,umask=0x80\000\00000\000\000 */
{ 1144788 }, /* l2_pf_miss_l2_l3.l1_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Stream (fetch additional sequential lines into L1 cache)\000event=0x72,umask=0x20\000\00000\000\000 */
{ 1144994 }, /* l2_pf_miss_l2_l3.l1_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L1Stride (fetch additional lines into L1 cache when each access is a constant distance from the previous)\000event=0x72,umask=0x40\000\00000\000\000 */
{ 1145247 }, /* l2_pf_miss_l2_l3.l2_burst\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Burst (aggressively fetch additional sequential lines into L2 cache)\000event=0x72,umask=0x08\000\00000\000\000 */
{ 1145464 }, /* l2_pf_miss_l2_l3.l2_next_line\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2NextLine (fetch the next line into L2 cache)\000event=0x72,umask=0x02\000\00000\000\000 */
{ 1145661 }, /* l2_pf_miss_l2_l3.l2_stream\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Stream (fetch additional sequential lines into L2 cache)\000event=0x72,umask=0x01\000\00000\000\000 */
{ 1145867 }, /* l2_pf_miss_l2_l3.l2_stride\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2Stride (fetch additional lines into L2 cache when each access is a constant distance from the previous)\000event=0x72,umask=0x10\000\00000\000\000 */
{ 1146120 }, /* l2_pf_miss_l2_l3.l2_up_down\000\000cache\000L2 prefetches accepted by the L2 pipeline which miss the L2 and the L3 caches of type L2UpDown (fetch the next or previous line into L2 cache for all memory accesses)\000event=0x72,umask=0x04\000\00000\000\000 */
{ 1152738 }, /* l2_request_g1.all\000\000cache\000L2 cache requests of all types\000event=0x60,umask=0xff\000\00000\000\000 */
{ 1152821 }, /* l2_request_g1.all_dc\000\000cache\000L2 cache requests of common types from L1 data cache (including prefetches)\000event=0x60,umask=0xe8\000\00000\000\000 */
{ 1152952 }, /* l2_request_g1.all_no_prefetch\000\000cache\000L2 cache requests of common types not including prefetches\000event=0x60,umask=0xf9\000\00000\000\000 */
{ 1153276 }, /* l2_request_g1.cacheable_ic_read\000\000cache\000L2 cache requests: instruction cache reads\000event=0x60,umask=0x10\000\00000\000\000 */
{ 1153580 }, /* l2_request_g1.change_to_x\000\000cache\000L2 cache requests: data cache state change to writable, check L2 for current state\000event=0x60,umask=0x08\000\00000\000\000 */
{ 1153723 }, /* l2_request_g1.group2\000\000cache\000L2 cache requests of non-cacheable type (non-cached data and instructions reads, self-modifying code checks)\000event=0x60,umask=0x01\000\00000\000\000 */
{ 1154251 }, /* l2_request_g1.l2_hw_pf\000\000cache\000L2 cache requests: from hardware prefetchers to prefetch directly into L2 (hit or miss)\000event=0x60,umask=0x02\000\00000\000\000 */
{ 1154528 }, /* l2_request_g1.ls_rd_blk_c_s\000\000cache\000L2 cache requests: data cache shared reads\000event=0x60,umask=0x20\000\00000\000\000 */
{ 1154757 }, /* l2_request_g1.prefetch_l2_cmd\000\000cache\000L2 cache requests: prefetch directly into L2\000event=0x60,umask=0x04\000\00000\000\000 */
{ 1155029 }, /* l2_request_g1.rd_blk_l\000\000cache\000L2 cache requests: data cache reads including hardware and software prefetch\000event=0x60,umask=0x80\000\00000\000\000 */
{ 1155284 }, /* l2_request_g1.rd_blk_x\000\000cache\000L2 cache requests: data cache stores\000event=0x60,umask=0x40\000\00000\000\000 */
{ 1186476 }, /* l3_lookup_state.all_coherent_accesses_to_l3\000amd_l3\000cache\000L3 cache requests for all coherent accesses. Unit: amd_l3 \000event=0x4,umask=0xff\000\00000\000\000 */
{ 1186855 }, /* l3_lookup_state.l3_hit\000amd_l3\000cache\000L3 cache hits. Unit: amd_l3 \000event=0x4,umask=0xfe\000\00000\000\000 */
{ 1186946 }, /* l3_lookup_state.l3_miss\000amd_l3\000cache\000L3 cache misses. Unit: amd_l3 \000event=0x4,umask=0x01\000\00000\000\000 */
{ 1187381 }, /* l3_xi_sampled_latency.all\000amd_l3\000cache\000Average sampled latency from all data sources. Unit: amd_l3 \000event=0xac,umask=0x3f\000\00000\000\000 */
{ 1187508 }, /* l3_xi_sampled_latency.dram_far\000amd_l3\000cache\000Average sampled latency when data is sourced from DRAM in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x02\000\00000\000\000 */
{ 1187674 }, /* l3_xi_sampled_latency.dram_near\000amd_l3\000cache\000Average sampled latency when data is sourced from DRAM in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x01\000\00000\000\000 */
{ 1187838 }, /* l3_xi_sampled_latency.ext_far\000amd_l3\000cache\000Average sampled latency when data is sourced from extension memory (CXL) in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x20\000\00000\000\000 */
{ 1188021 }, /* l3_xi_sampled_latency.ext_near\000amd_l3\000cache\000Average sampled latency when data is sourced from extension memory (CXL) in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x10\000\00000\000\000 */
{ 1188202 }, /* l3_xi_sampled_latency.far_cache\000amd_l3\000cache\000Average sampled latency when data is sourced from another CCX's cache when the address was in a different NUMA node. Unit: amd_l3 \000event=0xac,umask=0x08\000\00000\000\000 */
{ 1188405 }, /* l3_xi_sampled_latency.near_cache\000amd_l3\000cache\000Average sampled latency when data is sourced from another CCX's cache when the address was in the same NUMA node. Unit: amd_l3 \000event=0xac,umask=0x04\000\00000\000\000 */
{ 1188606 }, /* l3_xi_sampled_latency_requests.all\000amd_l3\000cache\000L3 cache fill requests sourced from all data sources. Unit: amd_l3 \000event=0xad,umask=0x3f\000\00000\000\000 */
{ 1188749 }, /* l3_xi_sampled_latency_requests.dram_far\000amd_l3\000cache\000L3 cache fill requests sourced from DRAM in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x02\000\00000\000\000 */
{ 1188910 }, /* l3_xi_sampled_latency_requests.dram_near\000amd_l3\000cache\000L3 cache fill requests sourced from DRAM in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x01\000\00000\000\000 */
{ 1189069 }, /* l3_xi_sampled_latency_requests.ext_far\000amd_l3\000cache\000L3 cache fill requests sourced from extension memory (CXL) in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x20\000\00000\000\000 */
{ 1189247 }, /* l3_xi_sampled_latency_requests.ext_near\000amd_l3\000cache\000L3 cache fill requests sourced from extension memory (CXL) in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x10\000\00000\000\000 */
{ 1189423 }, /* l3_xi_sampled_latency_requests.far_cache\000amd_l3\000cache\000L3 cache fill requests sourced from another CCX's cache when the address was in a different NUMA node. Unit: amd_l3 \000event=0xad,umask=0x08\000\00000\000\000 */
{ 1189621 }, /* l3_xi_sampled_latency_requests.near_cache\000amd_l3\000cache\000L3 cache fill requests sourced from another CCX's cache when the address was in the same NUMA node. Unit: amd_l3 \000event=0xad,umask=0x04\000\00000\000\000 */
{ 1254413 }, /* ls_alloc_mab_count\000\000cache\000In-flight L1 data cache misses i.e. Miss Address Buffer (MAB) allocations each cycle\000event=0x5f\000\00000\000\000 */
{ 1254919 }, /* ls_any_fills_from_sys.all\000\000cache\000Any data cache fills from all types of data sources\000event=0x44,umask=0xff\000\00000\000\000 */
{ 1255031 }, /* ls_any_fills_from_sys.all_dram_io\000\000cache\000Any data cache fills from either DRAM or MMIO in any NUMA node (same or different socket)\000event=0x44,umask=0x48\000\00000\000\000 */
{ 1255189 }, /* ls_any_fills_from_sys.alternate_memories\000\000cache\000Any data cache fills from extension memory\000event=0x44,umask=0x80\000\00000\000\000 */
{ 1255307 }, /* ls_any_fills_from_sys.dram_io_all\000\000cache\000Any data cache fills from either DRAM or MMIO in any NUMA node (same or different socket)\000event=0x44,umask=0x48\000\00000\000\000 */
{ 1255465 }, /* ls_any_fills_from_sys.dram_io_far\000\000cache\000Any data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x44,umask=0x40\000\00000\000\000 */
{ 1255631 }, /* ls_any_fills_from_sys.dram_io_near\000\000cache\000Any data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x44,umask=0x08\000\00000\000\000 */
{ 1256063 }, /* ls_any_fills_from_sys.far_all\000\000cache\000Any data cache fills from either cache of another CCX, DRAM or MMIO when the address was in a different NUMA node (same or different socket)\000event=0x44,umask=0x50\000\00000\000\000 */
{ 1256268 }, /* ls_any_fills_from_sys.far_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x44,umask=0x10\000\00000\000\000 */
{ 1256694 }, /* ls_any_fills_from_sys.local_all\000\000cache\000Any data cache fills from local L2 cache or L3 cache or different L2 cache in the same CCX\000event=0x44,umask=0x03\000\00000\000\000 */
{ 1256851 }, /* ls_any_fills_from_sys.local_ccx\000\000cache\000Any data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x44,umask=0x02\000\00000\000\000 */
{ 1256990 }, /* ls_any_fills_from_sys.local_l2\000\000cache\000Any data cache fills from local L2 cache\000event=0x44,umask=0x01\000\00000\000\000 */
{ 1257394 }, /* ls_any_fills_from_sys.near_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x44,umask=0x04\000\00000\000\000 */
{ 1257551 }, /* ls_any_fills_from_sys.remote_cache\000\000cache\000Any data cache fills from cache of another CCX when the address was in the same or a different NUMA node\000event=0x44,umask=0x14\000\00000\000\000 */
{ 1261533 }, /* ls_dmnd_fills_from_sys.all\000\000cache\000Demand data cache fills from all types of data sources\000event=0x43,umask=0xff\000\00000\000\000 */
{ 1261649 }, /* ls_dmnd_fills_from_sys.alternate_memories\000\000cache\000Demand data cache fills from extension memory\000event=0x43,umask=0x80\000\00000\000\000 */
{ 1261771 }, /* ls_dmnd_fills_from_sys.dram_io_far\000\000cache\000Demand data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x43,umask=0x40\000\00000\000\000 */
{ 1261941 }, /* ls_dmnd_fills_from_sys.dram_io_near\000\000cache\000Demand data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x43,umask=0x08\000\00000\000\000 */
{ 1262385 }, /* ls_dmnd_fills_from_sys.far_cache\000\000cache\000Demand data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x43,umask=0x10\000\00000\000\000 */
{ 1262823 }, /* ls_dmnd_fills_from_sys.local_ccx\000\000cache\000Demand data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x43,umask=0x02\000\00000\000\000 */
{ 1262966 }, /* ls_dmnd_fills_from_sys.local_l2\000\000cache\000Demand data cache fills from local L2 cache\000event=0x43,umask=0x01\000\00000\000\000 */
{ 1263382 }, /* ls_dmnd_fills_from_sys.near_cache\000\000cache\000Demand data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x43,umask=0x04\000\00000\000\000 */
{ 1264303 }, /* ls_hw_pf_dc_fills.all\000\000cache\000Hardware prefetch data cache fills from all types of data sources\000event=0x5a,umask=0xdf\000\00000\000\000 */
{ 1264425 }, /* ls_hw_pf_dc_fills.alternate_memories\000\000cache\000Hardware prefetch data cache fills from extension memory\000event=0x5a,umask=0x80\000\00000\000\000 */
{ 1264553 }, /* ls_hw_pf_dc_fills.dram_io_far\000\000cache\000Hardware prefetch data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x5a,umask=0x40\000\00000\000\000 */
{ 1264729 }, /* ls_hw_pf_dc_fills.dram_io_near\000\000cache\000Hardware prefetch data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x5a,umask=0x08\000\00000\000\000 */
{ 1265191 }, /* ls_hw_pf_dc_fills.far_cache\000\000cache\000Hardware prefetch data cache fills from cache of another CCX when the address was in a different NUMA node\000event=0x5a,umask=0x10\000\00000\000\000 */
{ 1265647 }, /* ls_hw_pf_dc_fills.local_ccx\000\000cache\000Hardware prefetch data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x5a,umask=0x02\000\00000\000\000 */
{ 1265796 }, /* ls_hw_pf_dc_fills.local_l2\000\000cache\000Hardware prefetch data cache fills from local L2 cache\000event=0x5a,umask=0x01\000\00000\000\000 */
{ 1266230 }, /* ls_hw_pf_dc_fills.near_cache\000\000cache\000Hardware prefetch data cache fills from cache of another CCX when the address was in the same NUMA node\000event=0x5a,umask=0x04\000\00000\000\000 */
{ 1266452 }, /* ls_inef_sw_pref.data_pipe_sw_pf_dc_hit\000\000cache\000Software prefetches that did not fetch data outside of the processor core as the PREFETCH instruction saw a data cache hit\000event=0x52,umask=0x01\000\00000\000\000 */
{ 1266854 }, /* ls_inef_sw_pref.mab_mch_cnt\000\000cache\000Software prefetches that did not fetch data outside of the processor core as the PREFETCH instruction saw a match on an already allocated Miss Address Buffer (MAB)\000event=0x52,umask=0x02\000\00000\000\000 */
{ 1272956 }, /* ls_mab_alloc.all_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for all types of allocations\000event=0x41,umask=0x7f\000\00000\000\000 */
{ 1273448 }, /* ls_mab_alloc.hardware_prefetcher_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for hardware prefetcher allocations\000event=0x41,umask=0x40\000\00000\000\000 */
{ 1273790 }, /* ls_mab_alloc.load_store_allocations\000\000cache\000Miss Address Buffer (MAB) entries allocated by a Load-Store (LS) pipe for load-store allocations\000event=0x41,umask=0x3f\000\00000\000\000 */
{ 1275159 }, /* ls_pref_instr_disp.all\000\000cache\000Software prefetch instructions dispatched (speculative) of all types\000event=0x4b,umask=0x07\000\00000\000\000 */
{ 1275426 }, /* ls_pref_instr_disp.prefetch\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchT0 (move data to all cache levels), T1 (move data to all cache levels except L1) and T2 (move data to all cache levels except L1 and L2)\000event=0x4b,umask=0x01\000\00000\000\000 */
{ 1276080 }, /* ls_pref_instr_disp.prefetch_nta\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchNTA (move data with minimum cache pollution i.e. non-temporal access)\000event=0x4b,umask=0x04\000\00000\000\000 */
{ 1276598 }, /* ls_pref_instr_disp.prefetch_w\000\000cache\000Software prefetch instructions dispatched (speculative) of type PrefetchW (move data to L1 cache and mark it modifiable)\000event=0x4b,umask=0x02\000\00000\000\000 */
{ 1280305 }, /* ls_sw_pf_dc_fills.all\000\000cache\000Software prefetch data cache fills from all types of data sources\000event=0x59,umask=0xdf\000\00000\000\000 */
{ 1280427 }, /* ls_sw_pf_dc_fills.alternate_memories\000\000cache\000Software prefetch data cache fills from extension memory\000event=0x59,umask=0x80\000\00000\000\000 */
{ 1280555 }, /* ls_sw_pf_dc_fills.dram_io_far\000\000cache\000Software prefetch data cache fills from either DRAM or MMIO in a different NUMA node (same or different socket)\000event=0x59,umask=0x40\000\00000\000\000 */
{ 1280731 }, /* ls_sw_pf_dc_fills.dram_io_near\000\000cache\000Software prefetch data cache fills from either DRAM or MMIO in the same NUMA node\000event=0x59,umask=0x08\000\00000\000\000 */
{ 1281193 }, /* ls_sw_pf_dc_fills.far_cache\000\000cache\000Software prefetch data cache fills from cache of another CCX in a different NUMA node\000event=0x59,umask=0x10\000\00000\000\000 */
{ 1281628 }, /* ls_sw_pf_dc_fills.local_ccx\000\000cache\000Software prefetch data cache fills from L3 cache or different L2 cache in the same CCX\000event=0x59,umask=0x02\000\00000\000\000 */
{ 1281777 }, /* ls_sw_pf_dc_fills.local_l2\000\000cache\000Software prefetch data cache fills from local L2 cache\000event=0x59,umask=0x01\000\00000\000\000 */
{ 1282211 }, /* ls_sw_pf_dc_fills.near_cache\000\000cache\000Software prefetch data cache fills from cache of another CCX in the same NUMA node\000event=0x59,umask=0x04\000\00000\000\000 */
{ 2461384 }, /* op_cache_hit_miss.all_op_cache_accesses\000\000cache\000Op cache accesses of all types\000event=0x28f,umask=0x07\000\00000\000\000 */
{ 2461612 }, /* op_cache_hit_miss.op_cache_hit\000\000cache\000Op cache hits\000event=0x28f,umask=0x03\000\00000\000\000 */
{ 2461816 }, /* op_cache_hit_miss.op_cache_miss\000\000cache\000Op cache misses\000event=0x28f,umask=0x04\000\00000\000\000 */
{ 835409 }, /* ex_div_busy\000\000core\000Number of cycles the divider is busy\000event=0xd3\000\00000\000\000 */
{ 835528 }, /* ex_div_count\000\000core\000Divide ops executed\000event=0xd4\000\00000\000\000 */
{ 835583 }, /* ex_no_retire.all\000\000core\000Cycles with no retire for any reason\000event=0xd6,umask=0x1b\000\00000\000\000 */
{ 835670 }, /* ex_no_retire.empty\000\000core\000Cycles with no retire due  to the lack of valid ops in the retire queue (may be caused by front-end bottlenecks or pipeline redirects)\000event=0xd6,umask=0x01\000\00000\000\000 */
{ 835857 }, /* ex_no_retire.load_not_complete\000\000core\000Cycles with no retire while the oldest op is waiting for load data\000event=0xd6,umask=0xa2\000\00000\000\000 */
{ 835988 }, /* ex_no_retire.not_complete\000\000core\000Cycles with no retire while the oldest op is waiting to be executed\000event=0xd6,umask=0x02\000\00000\000\000 */
{ 836115 }, /* ex_no_retire.other\000\000core\000Cycles with no retire caused by other reasons (retire breaks, traps, faults, etc.)\000event=0xd6,umask=0x08\000\00000\000\000 */
{ 836250 }, /* ex_no_retire.thread_not_selected\000\000core\000Cycles with no retire because thread arbitration did not select the thread\000event=0xd6,umask=0x10\000\00000\000\000 */
{ 840440 }, /* ex_ret_fused_instr\000\000core\000Retired fused instructions\000event=0x1d0\000\00000\000\000 */
{ 840770 }, /* ex_ret_instr\000\000core\000Retired instructions\000event=0xc0\000\00000\000\000 */
{ 843660 }, /* ex_ret_ops\000\000core\000Retired macro-ops\000event=0xc1\000\00000\000\000 */
{ 843711 }, /* ex_ret_ucode_instr\000\000core\000Retired microcoded instructions\000event=0x1c1\000\00000\000\000 */
{ 843785 }, /* ex_ret_ucode_ops\000\000core\000Retired microcode ops\000event=0x1c2\000\00000\000\000 */
{ 844252 }, /* ex_tagged_ibs_ops.ibs_tagged_ops\000\000core\000Ops tagged by IBS\000event=0x1cf,umask=0x01\000\00000\000\000 */
{ 844448 }, /* ex_tagged_ibs_ops.ibs_tagged_ops_ret\000\000core\000Ops tagged by IBS that retired\000event=0x1cf,umask=0x02\000\00000\000\000 */
{ 1267318 }, /* ls_int_taken\000\000core\000Interrupts taken\000event=0x2c\000\00000\000\000 */
{ 1271980 }, /* ls_locks.bus_lock\000\000core\000Retired Lock instructions which caused a bus lock\000event=0x25,umask=0x01\000\00000\000\000 */
{ 1274923 }, /* ls_not_halted_cyc\000\000core\000Core cycles not in halt\000event=0x76\000\00000\000\000 */
{ 1275048 }, /* ls_not_halted_p0_cyc.p0_freq_cyc\000\000core\000Reference cycles (P0 frequency) not in halt \000event=0x120,umask=0x1\000\00000\000\000 */
{ 1278287 }, /* ls_ret_cl_flush\000\000core\000Retired CLFLUSH instructions\000event=0x26\000\00000\000\000 */
{ 1278549 }, /* ls_ret_cpuid\000\000core\000Retired CPUID instructions\000event=0x27\000\00000\000\000 */
{ 1278763 }, /* ls_smi_rx\000\000core\000SMIs received\000event=0x2b\000\00000\000\000 */
{ 1232166 }, /* local_processor_read_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 0\000 */
{ 1232682 }, /* local_processor_read_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 1\000 */
{ 1232336 }, /* local_processor_read_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 10\000 */
{ 1232509 }, /* local_processor_read_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 11\000 */
{ 1232852 }, /* local_processor_read_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 2\000 */
{ 1233022 }, /* local_processor_read_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 3\000 */
{ 1233192 }, /* local_processor_read_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 4\000 */
{ 1233363 }, /* local_processor_read_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 5\000 */
{ 1233534 }, /* local_processor_read_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 6\000 */
{ 1233705 }, /* local_processor_read_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 7\000 */
{ 1233876 }, /* local_processor_read_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 8\000 */
{ 1234047 }, /* local_processor_read_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local processor at Coherent Station (CS) 9\000 */
{ 1234218 }, /* local_processor_write_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 0\000 */
{ 1234740 }, /* local_processor_write_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 1\000 */
{ 1234390 }, /* local_processor_write_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 10\000 */
{ 1234565 }, /* local_processor_write_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 11\000 */
{ 1234912 }, /* local_processor_write_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 2\000 */
{ 1235084 }, /* local_processor_write_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 3\000 */
{ 1235256 }, /* local_processor_write_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 4\000 */
{ 1235429 }, /* local_processor_write_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 5\000 */
{ 1235602 }, /* local_processor_write_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 6\000 */
{ 1235775 }, /* local_processor_write_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 7\000 */
{ 1235948 }, /* local_processor_write_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 8\000 */
{ 1236121 }, /* local_processor_write_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local processor at Coherent Station (CS) 9\000 */
{ 1236294 }, /* local_socket_inf0_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 0\000 */
{ 1236489 }, /* local_socket_inf0_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 1\000 */
{ 1236684 }, /* local_socket_inf0_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 2\000 */
{ 1236879 }, /* local_socket_inf0_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 3\000 */
{ 1237074 }, /* local_socket_inf0_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 4\000 */
{ 1237269 }, /* local_socket_inf0_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 5\000 */
{ 1237464 }, /* local_socket_inf0_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 6\000 */
{ 1237659 }, /* local_socket_inf0_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 0 for local socket inbound data to CPU Moderator (CCM) 7\000 */
{ 1237854 }, /* local_socket_inf0_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 0\000 */
{ 1238053 }, /* local_socket_inf0_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 1\000 */
{ 1238252 }, /* local_socket_inf0_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 2\000 */
{ 1238451 }, /* local_socket_inf0_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 3\000 */
{ 1238650 }, /* local_socket_inf0_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 4\000 */
{ 1238849 }, /* local_socket_inf0_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 5\000 */
{ 1239048 }, /* local_socket_inf0_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 6\000 */
{ 1239247 }, /* local_socket_inf0_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 0 for local socket outbound data from CPU Moderator (CCM) 7\000 */
{ 1239446 }, /* local_socket_inf1_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 0\000 */
{ 1239641 }, /* local_socket_inf1_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 1\000 */
{ 1239836 }, /* local_socket_inf1_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 2\000 */
{ 1240031 }, /* local_socket_inf1_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 3\000 */
{ 1240226 }, /* local_socket_inf1_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 4\000 */
{ 1240421 }, /* local_socket_inf1_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 5\000 */
{ 1240616 }, /* local_socket_inf1_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 6\000 */
{ 1240811 }, /* local_socket_inf1_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0x7fe\000\00001\000Data beats (32 bytes) at interface 1 for local socket inbound data to CPU Moderator (CCM) 7\000 */
{ 1241006 }, /* local_socket_inf1_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 0\000 */
{ 1241205 }, /* local_socket_inf1_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 1\000 */
{ 1241404 }, /* local_socket_inf1_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 2\000 */
{ 1241603 }, /* local_socket_inf1_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 3\000 */
{ 1241802 }, /* local_socket_inf1_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 4\000 */
{ 1242001 }, /* local_socket_inf1_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 5\000 */
{ 1242200 }, /* local_socket_inf1_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 6\000 */
{ 1242399 }, /* local_socket_inf1_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0x7ff\000\00001\000Data beats (64 bytes) at interface 1 for local socket outbound data from CPU Moderator (CCM) 7\000 */
{ 1242598 }, /* local_socket_outbound_data_beats_link0\000amd_df\000data fabric\000Unit: amd_df \000event=0xb5f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 0\000 */
{ 1242781 }, /* local_socket_outbound_data_beats_link1\000amd_df\000data fabric\000Unit: amd_df \000event=0xb9f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 1\000 */
{ 1242964 }, /* local_socket_outbound_data_beats_link2\000amd_df\000data fabric\000Unit: amd_df \000event=0xbdf,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 2\000 */
{ 1243147 }, /* local_socket_outbound_data_beats_link3\000amd_df\000data fabric\000Unit: amd_df \000event=0xc1f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 3\000 */
{ 1243330 }, /* local_socket_outbound_data_beats_link4\000amd_df\000data fabric\000Unit: amd_df \000event=0xc5f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 4\000 */
{ 1243513 }, /* local_socket_outbound_data_beats_link5\000amd_df\000data fabric\000Unit: amd_df \000event=0xc9f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 5\000 */
{ 1243696 }, /* local_socket_outbound_data_beats_link6\000amd_df\000data fabric\000Unit: amd_df \000event=0xcdf,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 6\000 */
{ 1243879 }, /* local_socket_outbound_data_beats_link7\000amd_df\000data fabric\000Unit: amd_df \000event=0xd1f,umask=0xf3e\000\00001\000Data beats (64 bytes) for local socket outbound data from inter-socket xGMI link 7\000 */
{ 1244062 }, /* local_socket_upstream_read_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 0\000 */
{ 1244242 }, /* local_socket_upstream_read_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 1\000 */
{ 1244422 }, /* local_socket_upstream_read_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 2\000 */
{ 1244602 }, /* local_socket_upstream_read_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0x7fe\000\00001\000Read data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 3\000 */
{ 1244782 }, /* local_socket_upstream_write_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 0\000 */
{ 1244964 }, /* local_socket_upstream_write_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 1\000 */
{ 1245146 }, /* local_socket_upstream_write_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 2\000 */
{ 1245328 }, /* local_socket_upstream_write_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0x7ff\000\00001\000Write data beats (64 bytes) for local socket upstream DMA at IO Moderator (IOM) 3\000 */
{ 2489056 }, /* remote_processor_read_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 0\000 */
{ 2489578 }, /* remote_processor_read_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 1\000 */
{ 2489228 }, /* remote_processor_read_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 10\000 */
{ 2489403 }, /* remote_processor_read_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 11\000 */
{ 2489750 }, /* remote_processor_read_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 2\000 */
{ 2489922 }, /* remote_processor_read_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 3\000 */
{ 2490094 }, /* remote_processor_read_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 4\000 */
{ 2490267 }, /* remote_processor_read_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 5\000 */
{ 2490440 }, /* remote_processor_read_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 6\000 */
{ 2490613 }, /* remote_processor_read_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 7\000 */
{ 2490786 }, /* remote_processor_read_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 8\000 */
{ 2490959 }, /* remote_processor_read_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote processor at Coherent Station (CS) 9\000 */
{ 2491132 }, /* remote_processor_write_data_beats_cs0\000amd_df\000data fabric\000Unit: amd_df \000event=0x1f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 0\000 */
{ 2491660 }, /* remote_processor_write_data_beats_cs1\000amd_df\000data fabric\000Unit: amd_df \000event=0x5f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 1\000 */
{ 2491306 }, /* remote_processor_write_data_beats_cs10\000amd_df\000data fabric\000Unit: amd_df \000event=0x29f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 10\000 */
{ 2491483 }, /* remote_processor_write_data_beats_cs11\000amd_df\000data fabric\000Unit: amd_df \000event=0x2df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 11\000 */
{ 2491834 }, /* remote_processor_write_data_beats_cs2\000amd_df\000data fabric\000Unit: amd_df \000event=0x9f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 2\000 */
{ 2492008 }, /* remote_processor_write_data_beats_cs3\000amd_df\000data fabric\000Unit: amd_df \000event=0xdf,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 3\000 */
{ 2492182 }, /* remote_processor_write_data_beats_cs4\000amd_df\000data fabric\000Unit: amd_df \000event=0x11f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 4\000 */
{ 2492357 }, /* remote_processor_write_data_beats_cs5\000amd_df\000data fabric\000Unit: amd_df \000event=0x15f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 5\000 */
{ 2492532 }, /* remote_processor_write_data_beats_cs6\000amd_df\000data fabric\000Unit: amd_df \000event=0x19f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 6\000 */
{ 2492707 }, /* remote_processor_write_data_beats_cs7\000amd_df\000data fabric\000Unit: amd_df \000event=0x1df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 7\000 */
{ 2492882 }, /* remote_processor_write_data_beats_cs8\000amd_df\000data fabric\000Unit: amd_df \000event=0x21f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 8\000 */
{ 2493057 }, /* remote_processor_write_data_beats_cs9\000amd_df\000data fabric\000Unit: amd_df \000event=0x25f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote processor at Coherent Station (CS) 9\000 */
{ 2493232 }, /* remote_socket_inf0_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 0\000 */
{ 2493429 }, /* remote_socket_inf0_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 1\000 */
{ 2493626 }, /* remote_socket_inf0_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 2\000 */
{ 2493823 }, /* remote_socket_inf0_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 3\000 */
{ 2494020 }, /* remote_socket_inf0_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 4\000 */
{ 2494217 }, /* remote_socket_inf0_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 5\000 */
{ 2494414 }, /* remote_socket_inf0_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 6\000 */
{ 2494611 }, /* remote_socket_inf0_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 0 for remote socket inbound data to CPU Moderator (CCM) 7\000 */
{ 2494808 }, /* remote_socket_inf0_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 0\000 */
{ 2495009 }, /* remote_socket_inf0_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 1\000 */
{ 2495210 }, /* remote_socket_inf0_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 2\000 */
{ 2495411 }, /* remote_socket_inf0_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4de,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 3\000 */
{ 2495612 }, /* remote_socket_inf0_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 4\000 */
{ 2495813 }, /* remote_socket_inf0_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 5\000 */
{ 2496014 }, /* remote_socket_inf0_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59e,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 6\000 */
{ 2496215 }, /* remote_socket_inf0_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5de,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 0 for remote socket outbound data from CPU Moderator (CCM) 7\000 */
{ 2496416 }, /* remote_socket_inf1_inbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 0\000 */
{ 2496613 }, /* remote_socket_inf1_inbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 1\000 */
{ 2496810 }, /* remote_socket_inf1_inbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 2\000 */
{ 2497007 }, /* remote_socket_inf1_inbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 3\000 */
{ 2497204 }, /* remote_socket_inf1_inbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 4\000 */
{ 2497401 }, /* remote_socket_inf1_inbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 5\000 */
{ 2497598 }, /* remote_socket_inf1_inbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 6\000 */
{ 2497795 }, /* remote_socket_inf1_inbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0xbfe\000\00001\000Data beats (32 bytes) at interface 1 for remote socket inbound data to CPU Moderator (CCM) 7\000 */
{ 2497992 }, /* remote_socket_inf1_outbound_data_beats_ccm0\000amd_df\000data fabric\000Unit: amd_df \000event=0x41f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 0\000 */
{ 2498193 }, /* remote_socket_inf1_outbound_data_beats_ccm1\000amd_df\000data fabric\000Unit: amd_df \000event=0x45f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 1\000 */
{ 2498394 }, /* remote_socket_inf1_outbound_data_beats_ccm2\000amd_df\000data fabric\000Unit: amd_df \000event=0x49f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 2\000 */
{ 2498595 }, /* remote_socket_inf1_outbound_data_beats_ccm3\000amd_df\000data fabric\000Unit: amd_df \000event=0x4df,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 3\000 */
{ 2498796 }, /* remote_socket_inf1_outbound_data_beats_ccm4\000amd_df\000data fabric\000Unit: amd_df \000event=0x51f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 4\000 */
{ 2498997 }, /* remote_socket_inf1_outbound_data_beats_ccm5\000amd_df\000data fabric\000Unit: amd_df \000event=0x55f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 5\000 */
{ 2499198 }, /* remote_socket_inf1_outbound_data_beats_ccm6\000amd_df\000data fabric\000Unit: amd_df \000event=0x59f,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 6\000 */
{ 2499399 }, /* remote_socket_inf1_outbound_data_beats_ccm7\000amd_df\000data fabric\000Unit: amd_df \000event=0x5df,umask=0xbff\000\00001\000Data beats (64 bytes) at interface 1 for remote socket outbound data from CPU Moderator (CCM) 7\000 */
{ 2499600 }, /* remote_socket_upstream_read_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 0\000 */
{ 2499782 }, /* remote_socket_upstream_read_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 1\000 */
{ 2499964 }, /* remote_socket_upstream_read_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 2\000 */
{ 2500146 }, /* remote_socket_upstream_read_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0xbfe\000\00001\000Read data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 3\000 */
{ 2500328 }, /* remote_socket_upstream_write_beats_iom0\000amd_df\000data fabric\000Unit: amd_df \000event=0x81f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 0\000 */
{ 2500512 }, /* remote_socket_upstream_write_beats_iom1\000amd_df\000data fabric\000Unit: amd_df \000event=0x85f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 1\000 */
{ 2500696 }, /* remote_socket_upstream_write_beats_iom2\000amd_df\000data fabric\000Unit: amd_df \000event=0x89f,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 2\000 */
{ 2500880 }, /* remote_socket_upstream_write_beats_iom3\000amd_df\000data fabric\000Unit: amd_df \000event=0x8df,umask=0xbff\000\00001\000Write data beats (64 bytes) for remote socket upstream DMA at IO Moderator (IOM) 3\000 */
{ 909316 }, /* fp_disp_faults.all\000\000floating point\000Floating-point dispatch faults of all types\000event=0xe,umask=0x0f\000\00000\000\000 */
{ 909421 }, /* fp_disp_faults.sse_avx_all\000\000floating point\000Floating-point dispatch faults of all types for SSE and AVX ops\000event=0xe,umask=0x0e\000\00000\000\000 */
{ 909673 }, /* fp_disp_faults.x87_fill_fault\000\000floating point\000Floating-point dispatch faults for x87 fills\000event=0xe,umask=0x01\000\00000\000\000 */
{ 909909 }, /* fp_disp_faults.xmm_fill_fault\000\000floating point\000Floating-point dispatch faults for XMM fills\000event=0xe,umask=0x02\000\00000\000\000 */
{ 910145 }, /* fp_disp_faults.ymm_fill_fault\000\000floating point\000Floating-point dispatch faults for YMM fills\000event=0xe,umask=0x04\000\00000\000\000 */
{ 910383 }, /* fp_disp_faults.ymm_spill_fault\000\000floating point\000Floating-point dispatch faults for YMM spills\000event=0xe,umask=0x08\000\00000\000\000 */
{ 913239 }, /* fp_ops_retired_by_type.all\000\000floating point\000Retired floating-point ops of all types\000event=0xa,umask=0xff\000\00000\000\000 */
{ 913348 }, /* fp_ops_retired_by_type.scalar_add\000\000floating point\000Retired scalar floating-point add ops\000event=0xa,umask=0x01\000\00000\000\000 */
{ 913462 }, /* fp_ops_retired_by_type.scalar_all\000\000floating point\000Retired scalar floating-point ops of all types\000event=0xa,umask=0x0f\000\00000\000\000 */
{ 913585 }, /* fp_ops_retired_by_type.scalar_blend\000\000floating point\000Retired scalar floating-point blend ops\000event=0xa,umask=0x09\000\00000\000\000 */
{ 913703 }, /* fp_ops_retired_by_type.scalar_cmp\000\000floating point\000Retired scalar floating-point compare ops\000event=0xa,umask=0x07\000\00000\000\000 */
{ 913821 }, /* fp_ops_retired_by_type.scalar_cvt\000\000floating point\000Retired scalar floating-point convert ops\000event=0xa,umask=0x08\000\00000\000\000 */
{ 913939 }, /* fp_ops_retired_by_type.scalar_div\000\000floating point\000Retired scalar floating-point divide ops\000event=0xa,umask=0x05\000\00000\000\000 */
{ 914056 }, /* fp_ops_retired_by_type.scalar_mac\000\000floating point\000Retired scalar floating-point multiply-accumulate ops\000event=0xa,umask=0x04\000\00000\000\000 */
{ 914186 }, /* fp_ops_retired_by_type.scalar_mul\000\000floating point\000Retired scalar floating-point multiply ops\000event=0xa,umask=0x03\000\00000\000\000 */
{ 914305 }, /* fp_ops_retired_by_type.scalar_other\000\000floating point\000Retired scalar floating-point ops of other types\000event=0xa,umask=0x0e\000\00000\000\000 */
{ 914432 }, /* fp_ops_retired_by_type.scalar_sqrt\000\000floating point\000Retired scalar floating-point square root ops\000event=0xa,umask=0x06\000\00000\000\000 */
{ 914555 }, /* fp_ops_retired_by_type.scalar_sub\000\000floating point\000Retired scalar floating-point subtract ops\000event=0xa,umask=0x02\000\00000\000\000 */
{ 914674 }, /* fp_ops_retired_by_type.vector_add\000\000floating point\000Retired vector floating-point add ops\000event=0xa,umask=0x10\000\00000\000\000 */
{ 914788 }, /* fp_ops_retired_by_type.vector_all\000\000floating point\000Retired vector floating-point ops of all types\000event=0xa,umask=0xf0\000\00000\000\000 */
{ 914911 }, /* fp_ops_retired_by_type.vector_blend\000\000floating point\000Retired vector floating-point blend ops\000event=0xa,umask=0x90\000\00000\000\000 */
{ 915029 }, /* fp_ops_retired_by_type.vector_cmp\000\000floating point\000Retired vector floating-point compare ops\000event=0xa,umask=0x70\000\00000\000\000 */
{ 915147 }, /* fp_ops_retired_by_type.vector_cvt\000\000floating point\000Retired vector floating-point convert ops\000event=0xa,umask=0x80\000\00000\000\000 */
{ 915265 }, /* fp_ops_retired_by_type.vector_div\000\000floating point\000Retired vector floating-point divide ops\000event=0xa,umask=0x50\000\00000\000\000 */
{ 915382 }, /* fp_ops_retired_by_type.vector_logical\000\000floating point\000Retired vector floating-point logical ops\000event=0xa,umask=0xd0\000\00000\000\000 */
{ 915504 }, /* fp_ops_retired_by_type.vector_mac\000\000floating point\000Retired vector floating-point multiply-accumulate ops\000event=0xa,umask=0x40\000\00000\000\000 */
{ 915634 }, /* fp_ops_retired_by_type.vector_mul\000\000floating point\000Retired vector floating-point multiply ops\000event=0xa,umask=0x30\000\00000\000\000 */
{ 915753 }, /* fp_ops_retired_by_type.vector_other\000\000floating point\000Retired vector floating-point ops of other types\000event=0xa,umask=0xe0\000\00000\000\000 */
{ 915880 }, /* fp_ops_retired_by_type.vector_shuffle\000\000floating point\000Retired vector floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xa,umask=0xb0\000\00000\000\000 */
{ 916141 }, /* fp_ops_retired_by_type.vector_sqrt\000\000floating point\000Retired vector floating-point square root ops\000event=0xa,umask=0x60\000\00000\000\000 */
{ 916264 }, /* fp_ops_retired_by_type.vector_sub\000\000floating point\000Retired vector floating-point subtract ops\000event=0xa,umask=0x20\000\00000\000\000 */
{ 916383 }, /* fp_ops_retired_by_width.all\000\000floating point\000Retired floating-point ops of all widths\000event=0x8,umask=0x3f\000\00000\000\000 */
{ 916494 }, /* fp_ops_retired_by_width.mmx_uops_retired\000\000floating point\000Retired MMX floating-point ops\000event=0x8,umask=0x02\000\00000\000\000 */
{ 916608 }, /* fp_ops_retired_by_width.pack_128_uops_retired\000\000floating point\000Retired packed 128-bit floating-point ops\000event=0x8,umask=0x08\000\00000\000\000 */
{ 916738 }, /* fp_ops_retired_by_width.pack_256_uops_retired\000\000floating point\000Retired packed 256-bit floating-point ops\000event=0x8,umask=0x10\000\00000\000\000 */
{ 916868 }, /* fp_ops_retired_by_width.pack_512_uops_retired\000\000floating point\000Retired packed 512-bit floating-point ops\000event=0x8,umask=0x20\000\00000\000\000 */
{ 916998 }, /* fp_ops_retired_by_width.scalar_uops_retired\000\000floating point\000Retired scalar floating-point ops\000event=0x8,umask=0x04\000\00000\000\000 */
{ 917118 }, /* fp_ops_retired_by_width.x87_uops_retired\000\000floating point\000Retired x87 floating-point ops\000event=0x8,umask=0x01\000\00000\000\000 */
{ 917232 }, /* fp_pack_ops_retired.all\000\000floating point\000Retired packed floating-point ops of all types\000event=0xc,umask=0xff\000\00000\000\000 */
{ 917345 }, /* fp_pack_ops_retired.fp128_add\000\000floating point\000Retired 128-bit packed floating-point add ops\000event=0xc,umask=0x01\000\00000\000\000 */
{ 917463 }, /* fp_pack_ops_retired.fp128_all\000\000floating point\000Retired 128-bit packed floating-point ops of all types\000event=0xc,umask=0x0f\000\00000\000\000 */
{ 917590 }, /* fp_pack_ops_retired.fp128_blend\000\000floating point\000Retired 128-bit packed floating-point blend ops\000event=0xc,umask=0x09\000\00000\000\000 */
{ 917712 }, /* fp_pack_ops_retired.fp128_cmp\000\000floating point\000Retired 128-bit packed floating-point compare ops\000event=0xc,umask=0x07\000\00000\000\000 */
{ 917834 }, /* fp_pack_ops_retired.fp128_cvt\000\000floating point\000Retired 128-bit packed floating-point convert ops\000event=0xc,umask=0x08\000\00000\000\000 */
{ 917956 }, /* fp_pack_ops_retired.fp128_div\000\000floating point\000Retired 128-bit packed floating-point divide ops\000event=0xc,umask=0x05\000\00000\000\000 */
{ 918077 }, /* fp_pack_ops_retired.fp128_logical\000\000floating point\000Retired 128-bit packed floating-point logical ops\000event=0xc,umask=0x0d\000\00000\000\000 */
{ 918203 }, /* fp_pack_ops_retired.fp128_mac\000\000floating point\000Retired 128-bit packed floating-point multiply-accumulate ops\000event=0xc,umask=0x04\000\00000\000\000 */
{ 918337 }, /* fp_pack_ops_retired.fp128_mul\000\000floating point\000Retired 128-bit packed floating-point multiply ops\000event=0xc,umask=0x03\000\00000\000\000 */
{ 918460 }, /* fp_pack_ops_retired.fp128_other\000\000floating point\000Retired 128-bit packed floating-point ops of other types\000event=0xc,umask=0x0e\000\00000\000\000 */
{ 918591 }, /* fp_pack_ops_retired.fp128_shuffle\000\000floating point\000Retired 128-bit packed floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xc,umask=0x0b\000\00000\000\000 */
{ 918856 }, /* fp_pack_ops_retired.fp128_sqrt\000\000floating point\000Retired 128-bit packed floating-point square root ops\000event=0xc,umask=0x06\000\00000\000\000 */
{ 918983 }, /* fp_pack_ops_retired.fp128_sub\000\000floating point\000Retired 128-bit packed floating-point subtract ops\000event=0xc,umask=0x02\000\00000\000\000 */
{ 919106 }, /* fp_pack_ops_retired.fp256_add\000\000floating point\000Retired 256-bit packed floating-point add ops\000event=0xc,umask=0x10\000\00000\000\000 */
{ 919224 }, /* fp_pack_ops_retired.fp256_all\000\000floating point\000Retired 256-bit packed floating-point ops of all types\000event=0xc,umask=0xf0\000\00000\000\000 */
{ 919351 }, /* fp_pack_ops_retired.fp256_blend\000\000floating point\000Retired 256-bit packed floating-point blend ops\000event=0xc,umask=0x90\000\00000\000\000 */
{ 919473 }, /* fp_pack_ops_retired.fp256_cmp\000\000floating point\000Retired 256-bit packed floating-point compare ops\000event=0xc,umask=0x70\000\00000\000\000 */
{ 919595 }, /* fp_pack_ops_retired.fp256_cvt\000\000floating point\000Retired 256-bit packed floating-point convert ops\000event=0xc,umask=0x80\000\00000\000\000 */
{ 919717 }, /* fp_pack_ops_retired.fp256_div\000\000floating point\000Retired 256-bit packed floating-point divide ops\000event=0xc,umask=0x50\000\00000\000\000 */
{ 919838 }, /* fp_pack_ops_retired.fp256_logical\000\000floating point\000Retired 256-bit packed floating-point logical ops\000event=0xc,umask=0xd0\000\00000\000\000 */
{ 919964 }, /* fp_pack_ops_retired.fp256_mac\000\000floating point\000Retired 256-bit packed floating-point multiply-accumulate ops\000event=0xc,umask=0x40\000\00000\000\000 */
{ 920098 }, /* fp_pack_ops_retired.fp256_mul\000\000floating point\000Retired 256-bit packed floating-point multiply ops\000event=0xc,umask=0x30\000\00000\000\000 */
{ 920221 }, /* fp_pack_ops_retired.fp256_other\000\000floating point\000Retired 256-bit packed floating-point ops of other types\000event=0xc,umask=0xe0\000\00000\000\000 */
{ 920352 }, /* fp_pack_ops_retired.fp256_shuffle\000\000floating point\000Retired 256-bit packed floating-point shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xc,umask=0xb0\000\00000\000\000 */
{ 920617 }, /* fp_pack_ops_retired.fp256_sqrt\000\000floating point\000Retired 256-bit packed floating-point square root ops\000event=0xc,umask=0x60\000\00000\000\000 */
{ 920744 }, /* fp_pack_ops_retired.fp256_sub\000\000floating point\000Retired 256-bit packed floating-point subtract ops\000event=0xc,umask=0x20\000\00000\000\000 */
{ 921553 }, /* fp_ret_sse_avx_ops.add_sub_flops\000\000floating point\000Retired SSE and AVX floating-point add and subtract ops\000event=0x3,umask=0x01\000\00000\000\000 */
{ 922150 }, /* fp_ret_sse_avx_ops.all\000\000floating point\000Retired SSE and AVX floating-point ops of all types\000event=0x3,umask=0x1f\000\00000\000\000 */
{ 922267 }, /* fp_ret_sse_avx_ops.bfloat_mac_flops\000\000floating point\000Retired SSE and AVX floating-point bfloat multiply-accumulate ops (each operation is counted as 2 ops)\000event=0x3,umask=0x10\000\00000\000\000 */
{ 923138 }, /* fp_ret_sse_avx_ops.div_flops\000\000floating point\000Retired SSE and AVX floating-point divide and square root ops\000event=0x3,umask=0x04\000\00000\000\000 */
{ 925324 }, /* fp_ret_sse_avx_ops.mac_flops\000\000floating point\000Retired SSE and AVX floating-point multiply-accumulate ops (each operation is counted as 2 ops)\000event=0x3,umask=0x08\000\00000\000\000 */
{ 926163 }, /* fp_ret_sse_avx_ops.mult_flops\000\000floating point\000Retired SSE and AVX floating-point multiply ops\000event=0x3,umask=0x02\000\00000\000\000 */
{ 927577 }, /* fp_ret_x87_fp_ops.add_sub_ops\000\000floating point\000Retired x87 floating-point add and subtract ops\000event=0x2,umask=0x01\000\00000\000\000 */
{ 927697 }, /* fp_ret_x87_fp_ops.all\000\000floating point\000Retired x87 floating-point ops of all types\000event=0x2,umask=0x07\000\00000\000\000 */
{ 927805 }, /* fp_ret_x87_fp_ops.div_sqrt_ops\000\000floating point\000Retired x87 floating-point divide and square root ops\000event=0x2,umask=0x04\000\00000\000\000 */
{ 927932 }, /* fp_ret_x87_fp_ops.mul_ops\000\000floating point\000Retired x87 floating-point multiply ops\000event=0x2,umask=0x02\000\00000\000\000 */
{ 928040 }, /* fp_retired_ser_ops.all\000\000floating point\000Retired SSE and AVX serializing ops of all types\000event=0x5,umask=0x0f\000\00000\000\000 */
{ 928154 }, /* fp_retired_ser_ops.sse_bot_ret\000\000floating point\000Retired SSE and AVX bottom-executing ops. Bottom-executing ops wait for all older ops to retire before executing\000event=0x5,umask=0x08\000\00000\000\000 */
{ 928814 }, /* fp_retired_ser_ops.sse_ctrl_ret\000\000floating point\000Retired SSE and AVX control word mispredict traps\000event=0x5,umask=0x04\000\00000\000\000 */
{ 929611 }, /* fp_retired_ser_ops.x87_bot_ret\000\000floating point\000Retired x87 bottom-executing ops. Bottom-executing ops wait for all older ops to retire before executing\000event=0x5,umask=0x02\000\00000\000\000 */
{ 930259 }, /* fp_retired_ser_ops.x87_ctrl_ret\000\000floating point\000Retired x87 control word mispredict traps due to mispredictions in RC or PC, or changes in exception mask bits\000event=0x5,umask=0x01\000\00000\000\000 */
{ 2464512 }, /* packed_int_op_type.all\000\000floating point\000Retired packed integer ops of all types\000event=0xd,umask=0xff\000\00000\000\000 */
{ 2464617 }, /* packed_int_op_type.int128_add\000\000floating point\000Retired 128-bit packed integer add ops\000event=0xd,umask=0x01\000\00000\000\000 */
{ 2464728 }, /* packed_int_op_type.int128_aes\000\000floating point\000Retired 128-bit packed integer AES ops\000event=0xd,umask=0x05\000\00000\000\000 */
{ 2464839 }, /* packed_int_op_type.int128_all\000\000floating point\000Retired 128-bit packed integer ops of all types\000event=0xd,umask=0x0f\000\00000\000\000 */
{ 2464959 }, /* packed_int_op_type.int128_clm\000\000floating point\000Retired 128-bit packed integer CLM ops\000event=0xd,umask=0x08\000\00000\000\000 */
{ 2465070 }, /* packed_int_op_type.int128_cmp\000\000floating point\000Retired 128-bit packed integer compare ops\000event=0xd,umask=0x07\000\00000\000\000 */
{ 2465185 }, /* packed_int_op_type.int128_logical\000\000floating point\000Retired 128-bit packed integer logical ops\000event=0xd,umask=0x0d\000\00000\000\000 */
{ 2465304 }, /* packed_int_op_type.int128_mac\000\000floating point\000Retired 128-bit packed integer multiply-accumulate ops\000event=0xd,umask=0x04\000\00000\000\000 */
{ 2465431 }, /* packed_int_op_type.int128_mov\000\000floating point\000Retired 128-bit packed integer MOV ops\000event=0xd,umask=0x0a\000\00000\000\000 */
{ 2465542 }, /* packed_int_op_type.int128_mul\000\000floating point\000Retired 128-bit packed integer multiply ops\000event=0xd,umask=0x03\000\00000\000\000 */
{ 2465658 }, /* packed_int_op_type.int128_other\000\000floating point\000Retired 128-bit packed integer ops of other types\000event=0xd,umask=0x0e\000\00000\000\000 */
{ 2465782 }, /* packed_int_op_type.int128_pack\000\000floating point\000Retired 128-bit packed integer pack ops\000event=0xd,umask=0x0c\000\00000\000\000 */
{ 2465895 }, /* packed_int_op_type.int128_sha\000\000floating point\000Retired 128-bit packed integer SHA ops\000event=0xd,umask=0x06\000\00000\000\000 */
{ 2466006 }, /* packed_int_op_type.int128_shift\000\000floating point\000Retired 128-bit packed integer shift ops\000event=0xd,umask=0x09\000\00000\000\000 */
{ 2466121 }, /* packed_int_op_type.int128_shuffle\000\000floating point\000Retired 128-bit packed integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xd,umask=0x0b\000\00000\000\000 */
{ 2466379 }, /* packed_int_op_type.int128_sub\000\000floating point\000Retired 128-bit packed integer subtract ops\000event=0xd,umask=0x02\000\00000\000\000 */
{ 2466495 }, /* packed_int_op_type.int256_add\000\000floating point\000Retired 256-bit packed integer add ops\000event=0xd,umask=0x10\000\00000\000\000 */
{ 2466606 }, /* packed_int_op_type.int256_all\000\000floating point\000Retired 256-bit packed integer ops of all types\000event=0xd,umask=0xf0\000\00000\000\000 */
{ 2466726 }, /* packed_int_op_type.int256_cmp\000\000floating point\000Retired 256-bit packed integer compare ops\000event=0xd,umask=0x70\000\00000\000\000 */
{ 2466841 }, /* packed_int_op_type.int256_logical\000\000floating point\000Retired 256-bit packed integer logical ops\000event=0xd,umask=0xd0\000\00000\000\000 */
{ 2466960 }, /* packed_int_op_type.int256_mac\000\000floating point\000Retired 256-bit packed integer multiply-accumulate ops\000event=0xd,umask=0x40\000\00000\000\000 */
{ 2467087 }, /* packed_int_op_type.int256_mov\000\000floating point\000Retired 256-bit packed integer MOV ops\000event=0xd,umask=0xa0\000\00000\000\000 */
{ 2467198 }, /* packed_int_op_type.int256_mul\000\000floating point\000Retired 256-bit packed integer multiply ops\000event=0xd,umask=0x30\000\00000\000\000 */
{ 2467314 }, /* packed_int_op_type.int256_other\000\000floating point\000Retired 256-bit packed integer ops of other types\000event=0xd,umask=0xe0\000\00000\000\000 */
{ 2467438 }, /* packed_int_op_type.int256_pack\000\000floating point\000Retired 256-bit packed integer pack ops\000event=0xd,umask=0xc0\000\00000\000\000 */
{ 2467551 }, /* packed_int_op_type.int256_shift\000\000floating point\000Retired 256-bit packed integer shift ops\000event=0xd,umask=0x90\000\00000\000\000 */
{ 2467666 }, /* packed_int_op_type.int256_shuffle\000\000floating point\000Retired 256-bit packed integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xd,umask=0xb0\000\00000\000\000 */
{ 2467924 }, /* packed_int_op_type.int256_sub\000\000floating point\000Retired 256-bit packed integer subtract ops\000event=0xd,umask=0x20\000\00000\000\000 */
{ 2532634 }, /* sse_avx_ops_retired.all\000\000floating point\000Retired SSE, AVX and MMX integer ops of all types\000event=0xb,umask=0xff\000\00000\000\000 */
{ 2532750 }, /* sse_avx_ops_retired.mmx_add\000\000floating point\000Retired MMX integer add\000event=0xb,umask=0x01\000\00000\000\000 */
{ 2532844 }, /* sse_avx_ops_retired.mmx_all\000\000floating point\000Retired MMX integer ops of all types\000event=0xb,umask=0x0f\000\00000\000\000 */
{ 2532951 }, /* sse_avx_ops_retired.mmx_cmp\000\000floating point\000Retired MMX integer compare ops\000event=0xb,umask=0x07\000\00000\000\000 */
{ 2533053 }, /* sse_avx_ops_retired.mmx_logical\000\000floating point\000Retired MMX integer logical ops\000event=0xb,umask=0x0d\000\00000\000\000 */
{ 2533159 }, /* sse_avx_ops_retired.mmx_mac\000\000floating point\000Retired MMX integer multiply-accumulate ops\000event=0xb,umask=0x04\000\00000\000\000 */
{ 2533273 }, /* sse_avx_ops_retired.mmx_mov\000\000floating point\000Retired MMX integer MOV ops\000event=0xb,umask=0x0a\000\00000\000\000 */
{ 2533371 }, /* sse_avx_ops_retired.mmx_mul\000\000floating point\000Retired MMX integer multiply ops\000event=0xb,umask=0x03\000\00000\000\000 */
{ 2533474 }, /* sse_avx_ops_retired.mmx_other\000\000floating point\000Retired MMX integer multiply ops of other types\000event=0xb,umask=0x0e\000\00000\000\000 */
{ 2533594 }, /* sse_avx_ops_retired.mmx_pack\000\000floating point\000Retired MMX integer pack ops\000event=0xb,umask=0x0c\000\00000\000\000 */
{ 2533694 }, /* sse_avx_ops_retired.mmx_shift\000\000floating point\000Retired MMX integer shift ops\000event=0xb,umask=0x09\000\00000\000\000 */
{ 2533796 }, /* sse_avx_ops_retired.mmx_shuffle\000\000floating point\000Retired MMX integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xb,umask=0x0b\000\00000\000\000 */
{ 2534041 }, /* sse_avx_ops_retired.mmx_sub\000\000floating point\000Retired MMX integer subtract ops\000event=0xb,umask=0x02\000\00000\000\000 */
{ 2534144 }, /* sse_avx_ops_retired.sse_avx_add\000\000floating point\000Retired SSE and AVX integer add ops\000event=0xb,umask=0x10\000\00000\000\000 */
{ 2534254 }, /* sse_avx_ops_retired.sse_avx_aes\000\000floating point\000Retired SSE and AVX integer AES ops\000event=0xb,umask=0x50\000\00000\000\000 */
{ 2534364 }, /* sse_avx_ops_retired.sse_avx_all\000\000floating point\000Retired SSE and AVX integer ops of all types\000event=0xb,umask=0xf0\000\00000\000\000 */
{ 2534483 }, /* sse_avx_ops_retired.sse_avx_clm\000\000floating point\000Retired SSE and AVX integer CLM ops\000event=0xb,umask=0x80\000\00000\000\000 */
{ 2534593 }, /* sse_avx_ops_retired.sse_avx_cmp\000\000floating point\000Retired SSE and AVX integer compare ops\000event=0xb,umask=0x70\000\00000\000\000 */
{ 2534707 }, /* sse_avx_ops_retired.sse_avx_logical\000\000floating point\000Retired SSE and AVX integer logical ops\000event=0xb,umask=0xd0\000\00000\000\000 */
{ 2534825 }, /* sse_avx_ops_retired.sse_avx_mac\000\000floating point\000Retired SSE and AVX integer multiply-accumulate ops\000event=0xb,umask=0x40\000\00000\000\000 */
{ 2534951 }, /* sse_avx_ops_retired.sse_avx_mov\000\000floating point\000Retired SSE and AVX integer MOV ops\000event=0xb,umask=0xa0\000\00000\000\000 */
{ 2535061 }, /* sse_avx_ops_retired.sse_avx_mul\000\000floating point\000Retired SSE and AVX integer multiply ops\000event=0xb,umask=0x30\000\00000\000\000 */
{ 2535176 }, /* sse_avx_ops_retired.sse_avx_other\000\000floating point\000Retired SSE and AVX integer ops of other types\000event=0xb,umask=0xe0\000\00000\000\000 */
{ 2535299 }, /* sse_avx_ops_retired.sse_avx_pack\000\000floating point\000Retired SSE and AVX integer pack ops\000event=0xb,umask=0xc0\000\00000\000\000 */
{ 2535411 }, /* sse_avx_ops_retired.sse_avx_sha\000\000floating point\000Retired SSE and AVX integer SHA ops\000event=0xb,umask=0x60\000\00000\000\000 */
{ 2535521 }, /* sse_avx_ops_retired.sse_avx_shift\000\000floating point\000Retired SSE and AVX integer shift ops\000event=0xb,umask=0x90\000\00000\000\000 */
{ 2535635 }, /* sse_avx_ops_retired.sse_avx_shuffle\000\000floating point\000Retired SSE and AVX integer shuffle ops (may include instructions not necessarily thought of as including shuffles e.g. horizontal add, dot product, and certain MOV instructions)\000event=0xb,umask=0xb0\000\00000\000\000 */
{ 2535892 }, /* sse_avx_ops_retired.sse_avx_sub\000\000floating point\000Retired SSE and AVX integer subtract ops\000event=0xb,umask=0x20\000\00000\000\000 */
{ 481812 }, /* bp_l1_tlb_fetch_hit.all\000\000memory\000Instruction fetches that hit in the L1 ITLB for all page sizes\000event=0x94,umask=0x07\000\00000\000\000 */
{ 482244 }, /* bp_l1_tlb_fetch_hit.if1g\000\000memory\000Instruction fetches that hit in the L1 ITLB for 1G pages\000event=0x94,umask=0x04\000\00000\000\000 */
{ 482671 }, /* bp_l1_tlb_fetch_hit.if2m\000\000memory\000Instruction fetches that hit in the L1 ITLB for 2M pages\000event=0x94,umask=0x02\000\00000\000\000 */
{ 483105 }, /* bp_l1_tlb_fetch_hit.if4k\000\000memory\000Instruction fetches that hit in the L1 ITLB for 4k or coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x94,umask=0x01\000\00000\000\000 */
{ 483920 }, /* bp_l1_tlb_miss_l2_tlb_hit\000\000memory\000Instruction fetches that miss in the L1 ITLB but hit in the L2 ITLB\000event=0x84\000\00000\000\000 */
{ 484038 }, /* bp_l1_tlb_miss_l2_tlb_miss.all\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for all page sizes\000event=0x85,umask=0x0f\000\00000\000\000 */
{ 484461 }, /* bp_l1_tlb_miss_l2_tlb_miss.coalesced_4k\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x85,umask=0x08\000\00000\000\000 */
{ 485115 }, /* bp_l1_tlb_miss_l2_tlb_miss.if1g\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 1G pages\000event=0x85,umask=0x04\000\00000\000\000 */
{ 485686 }, /* bp_l1_tlb_miss_l2_tlb_miss.if2m\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 2M pages\000event=0x85,umask=0x02\000\00000\000\000 */
{ 486256 }, /* bp_l1_tlb_miss_l2_tlb_miss.if4k\000\000memory\000Instruction fetches that miss in both the L1 and L2 ITLBs (page-table walks are requested) for 4k pages\000event=0x85,umask=0x01\000\00000\000\000 */
{ 1258637 }, /* ls_bad_status2.stli_other\000\000memory\000Store-to-load conflicts (load unable to complete due to a non-forwardable conflict with an older store)\000event=0x24,umask=0x02\000\00000\000\000 */
{ 1260041 }, /* ls_dispatch.ld_dispatch\000\000memory\000Number of memory load operations dispatched to the load-store unit\000event=0x29,umask=0x01\000\00000\000\000 */
{ 1260775 }, /* ls_dispatch.ld_st_dispatch\000\000memory\000Number of memory load-store operations dispatched to the load-store unit\000event=0x29,umask=0x04\000\00000\000\000 */
{ 1261236 }, /* ls_dispatch.store_dispatch\000\000memory\000Number of memory store operations dispatched to the load-store unit\000event=0x29,umask=0x02\000\00000\000\000 */
{ 1267802 }, /* ls_l1_d_tlb_miss.all\000\000memory\000L1 DTLB misses for all page sizes\000event=0x45,umask=0xff\000\00000\000\000 */
{ 1267892 }, /* ls_l1_d_tlb_miss.all_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for all page sizes\000event=0x45,umask=0xf0\000\00000\000\000 */
{ 1268287 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 1G pages\000event=0x45,umask=0x08\000\00000\000\000 */
{ 1268795 }, /* ls_l1_d_tlb_miss.tlb_reload_1g_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 1G pages\000event=0x45,umask=0x80\000\00000\000\000 */
{ 1269194 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 2M pages\000event=0x45,umask=0x04\000\00000\000\000 */
{ 1269702 }, /* ls_l1_d_tlb_miss.tlb_reload_2m_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 2M pages\000event=0x45,umask=0x40\000\00000\000\000 */
{ 1270322 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for 4k pages\000event=0x45,umask=0x01\000\00000\000\000 */
{ 1270819 }, /* ls_l1_d_tlb_miss.tlb_reload_4k_l2_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for 4k pages\000event=0x45,umask=0x10\000\00000\000\000 */
{ 1271254 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_hit\000\000memory\000L1 DTLB misses with L2 DTLB hits for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x45,umask=0x02\000\00000\000\000 */
{ 1271741 }, /* ls_l1_d_tlb_miss.tlb_reload_coalesced_page_miss\000\000memory\000L1 DTLB misses with L2 DTLB misses (page-table walks are requested) for coalesced pages. A coalesced page is a 16k page created from four adjacent 4k pages\000event=0x45,umask=0x20\000\00000\000\000 */
{ 1274505 }, /* ls_misal_loads.ma4k\000\000memory\0004kB misaligned (page crossing) loads\000event=0x47,umask=0x02\000\00000\000\000 */
{ 1274709 }, /* ls_misal_loads.ma64\000\000memory\00064B misaligned (cacheline crossing) loads\000event=0x47,umask=0x01\000\00000\000\000 */
{ 1279221 }, /* ls_st_commit_cancel2.st_commit_cancel_wcb_full\000\000memory\000Non-cacheable store commits cancelled due to the non-cacheable commit buffer being full\000event=0x37,umask=0x01\000\00000\000\000 */
{ 1279443 }, /* ls_stlf\000\000memory\000Store-to-load-forward (STLF) hits\000event=0x35\000\00000\000\000 */
{ 1282903 }, /* ls_tlb_flush.all\000\000memory\000All TLB Flushes\000event=0x78,umask=0xff\000\00000\000\000 */
{ 765946 }, /* de_dis_dispatch_token_stalls1.fp_flush_recovery_stall\000\000other\000Number of cycles dispatch is stalled for floating-point flush recovery\000event=0xae,umask=0x80\000\00000\000\000 */
{ 767032 }, /* de_dis_dispatch_token_stalls1.fp_reg_file_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for floating-point register file tokens\000event=0xae,umask=0x20\000\00000\000\000 */
{ 767791 }, /* de_dis_dispatch_token_stalls1.fp_sch_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for floating-point scheduler tokens\000event=0xae,umask=0x40\000\00000\000\000 */
{ 768380 }, /* de_dis_dispatch_token_stalls1.int_phy_reg_file_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for integer physical register file tokens\000event=0xae,umask=0x01\000\00000\000\000 */
{ 769422 }, /* de_dis_dispatch_token_stalls1.load_queue_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for Load queue token\000event=0xae,umask=0x02\000\00000\000\000 */
{ 770165 }, /* de_dis_dispatch_token_stalls1.store_queue_rsrc_stall\000\000other\000Number of cycles dispatch is stalled for store queue tokens\000event=0xae,umask=0x04\000\00000\000\000 */
{ 771101 }, /* de_dis_dispatch_token_stalls1.taken_brnch_buffer_rsrc\000\000other\000Number of cycles dispatch is stalled for taken branch buffer tokens\000event=0xae,umask=0x10\000\00000\000\000 */
{ 771675 }, /* de_dis_dispatch_token_stalls2.int_sch0_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 0 tokens\000event=0xaf,umask=0x01\000\00000\000\000 */
{ 772058 }, /* de_dis_dispatch_token_stalls2.int_sch1_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 1 tokens\000event=0xaf,umask=0x02\000\00000\000\000 */
{ 772441 }, /* de_dis_dispatch_token_stalls2.int_sch2_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 2 tokens\000event=0xaf,umask=0x04\000\00000\000\000 */
{ 772824 }, /* de_dis_dispatch_token_stalls2.int_sch3_token_stall\000\000other\000Number of cycles dispatch is stalled for integer scheduler queue 3 tokens\000event=0xaf,umask=0x08\000\00000\000\000 */
{ 773198 }, /* de_dis_dispatch_token_stalls2.retire_token_stall\000\000other\000Number of cycles dispatch is stalled for retire queue tokens\000event=0xaf,umask=0x20\000\00000\000\000 */
{ 773342 }, /* de_dis_ops_from_decoder.any_fp_dispatch\000\000other\000Number of ops dispatched to the floating-point unit\000event=0xab,umask=0x04\000\00000\000\000 */
{ 773468 }, /* de_dis_ops_from_decoder.disp_op_type.any_integer_dispatch\000\000other\000Number of ops dispatched to the integer execution unit\000event=0xab,umask=0x08\000\00000\000\000 */
{ 774052 }, /* de_no_dispatch_per_slot.backend_stalls\000\000other\000In each cycle counts ops unable to dispatch because of back-end stalls\000event=0x1a0,umask=0x1e\000\00000\000\000 */
{ 774197 }, /* de_no_dispatch_per_slot.no_ops_from_frontend\000\000other\000In each cycle counts dispatch slots left empty because the front-end did not supply ops\000event=0x1a0,umask=0x01\000\00000\000\000 */
{ 774365 }, /* de_no_dispatch_per_slot.smt_contention\000\000other\000In each cycle counts ops unable to dispatch because the dispatch cycle was granted to the other SMT thread\000event=0x1a0,umask=0x60\000\00000\000\000 */
{ 774546 }, /* de_op_queue_empty\000\000other\000Cycles when the op queue is empty. Such cycles indicate that the front-end is not delivering instructions fast enough\000event=0xa9\000\00000\000\000 */
{ 774705 }, /* de_src_op_disp.all\000\000other\000Ops dispatched from any source\000event=0xaa,umask=0x07\000\00000\000\000 */
{ 774789 }, /* de_src_op_disp.decoder\000\000other\000Ops fetched from instruction cache and dispatched\000event=0xaa,umask=0x01\000\00000\000\000 */
{ 774896 }, /* de_src_op_disp.loop_buffer\000\000other\000Ops dispatched from loop buffer\000event=0xaa,umask=0x04\000\00000\000\000 */
{ 774989 }, /* de_src_op_disp.op_cache\000\000other\000Ops fetched from op cache and dispatched\000event=0xaa,umask=0x02\000\00000\000\000 */
{ 2507183 }, /* resyncs_or_nc_redirects\000\000other\000Pipeline restarts not caused by branch mispredicts\000event=0x96\000\00000\000\000 */
{ 466401 }, /* all_data_cache_accesses\000\000recommended\000All data cache accesses\000event=0x29,umask=0x07\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__amdzen4[] = {
{ 6689 }, /* \000all_l1_data_cache_fills\000l1_dcache\000ls_any_fills_from_sys.all\000\000All L1 data cache fills\000\000\000\000\000\00000 */
{ 6931 }, /* \000all_l2_cache_accesses\000l2_cache\000l2_request_g1.all_no_prefetch + l2_pf_hit_l2.all + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000All L2 cache accesses\000\000\000\000\000\00000 */
{ 7092 }, /* \000all_l2_cache_hits\000l2_cache\000l2_cache_req_stat.ic_dc_hit_in_l2 + l2_pf_hit_l2.all\000\000All L2 cache hits\000\000\000\000\000\00000 */
{ 7437 }, /* \000all_l2_cache_misses\000l2_cache\000l2_cache_req_stat.ic_dc_miss_in_l2 + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000All L2 cache misses\000\000\000\000\000\00000 */
{ 7847 }, /* \000all_tlbs_flushed\000tlb\000ls_tlb_flush.all\000\000All TLBs flushed\000\000\000\000\000\00000 */
{ 7911 }, /* \000backend_bound\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.backend_stalls, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of backend stalls\000\000100%\000\000\000\00000 */
{ 8093 }, /* \000backend_bound_cpu\000PipelineL2;backend_bound_group\000backend_bound * (1 - d_ratio(ex_no_retire.load_not_complete, ex_no_retire.not_complete))\000\000Fraction of dispatch slots that remained unused because of stalls not related to the memory subsystem\000\000100%\000\000\000\00000 */
{ 8346 }, /* \000backend_bound_memory\000PipelineL2;backend_bound_group\000backend_bound * d_ratio(ex_no_retire.load_not_complete, ex_no_retire.not_complete)\000\000Fraction of dispatch slots that remained unused because of stalls due to the memory subsystem\000\000100%\000\000\000\00000 */
{ 8588 }, /* \000bad_speculation\000PipelineL1\000d_ratio(de_src_op_disp.all - ex_ret_ops, total_dispatch_slots)\000\000Fraction of dispatched ops that did not retire\000\000100%\000\000\000\00000 */
{ 8738 }, /* \000bad_speculation_mispredicts\000PipelineL2;bad_speculation_group\000d_ratio(bad_speculation * ex_ret_brn_misp, ex_ret_brn_misp + resyncs_or_nc_redirects)\000\000Fraction of dispatched ops that were flushed due to branch mispredicts\000\000100%\000\000\000\00000 */
{ 8969 }, /* \000bad_speculation_pipeline_restarts\000PipelineL2;bad_speculation_group\000d_ratio(bad_speculation * resyncs_or_nc_redirects, ex_ret_brn_misp + resyncs_or_nc_redirects)\000\000Fraction of dispatched ops that were flushed due to pipeline restarts (resyncs)\000\000100%\000\000\000\00000 */
{ 9378 }, /* \000branch_misprediction_ratio\000branch_prediction\000d_ratio(ex_ret_brn_misp, ex_ret_brn)\000\000Execution-time branch misprediction ratio (non-speculative)\000\000100%\000\000\000\00000 */
{ 10112 }, /* \000dram_read_data_for_local_processor\000data_fabric\000local_processor_read_data_beats_cs0 + local_processor_read_data_beats_cs1 + local_processor_read_data_beats_cs2 + local_processor_read_data_beats_cs3 + local_processor_read_data_beats_cs4 + local_processor_read_data_beats_cs5 + local_processor_read_data_beats_cs6 + local_processor_read_data_beats_cs7 + local_processor_read_data_beats_cs8 + local_processor_read_data_beats_cs9 + local_processor_read_data_beats_cs10 + local_processor_read_data_beats_cs11\000\000DRAM read data for local processor\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 10676 }, /* \000dram_read_data_for_remote_processor\000data_fabric\000remote_processor_read_data_beats_cs0 + remote_processor_read_data_beats_cs1 + remote_processor_read_data_beats_cs2 + remote_processor_read_data_beats_cs3 + remote_processor_read_data_beats_cs4 + remote_processor_read_data_beats_cs5 + remote_processor_read_data_beats_cs6 + remote_processor_read_data_beats_cs7 + remote_processor_read_data_beats_cs8 + remote_processor_read_data_beats_cs9 + remote_processor_read_data_beats_cs10 + remote_processor_read_data_beats_cs11\000\000DRAM read data for remote processor\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 11254 }, /* \000dram_write_data_for_local_processor\000data_fabric\000local_processor_write_data_beats_cs0 + local_processor_write_data_beats_cs1 + local_processor_write_data_beats_cs2 + local_processor_write_data_beats_cs3 + local_processor_write_data_beats_cs4 + local_processor_write_data_beats_cs5 + local_processor_write_data_beats_cs6 + local_processor_write_data_beats_cs7 + local_processor_write_data_beats_cs8 + local_processor_write_data_beats_cs9 + local_processor_write_data_beats_cs10 + local_processor_write_data_beats_cs11\000\000DRAM write data for local processor\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 11832 }, /* \000dram_write_data_for_remote_processor\000data_fabric\000remote_processor_write_data_beats_cs0 + remote_processor_write_data_beats_cs1 + remote_processor_write_data_beats_cs2 + remote_processor_write_data_beats_cs3 + remote_processor_write_data_beats_cs4 + remote_processor_write_data_beats_cs5 + remote_processor_write_data_beats_cs6 + remote_processor_write_data_beats_cs7 + remote_processor_write_data_beats_cs8 + remote_processor_write_data_beats_cs9 + remote_processor_write_data_beats_cs10 + remote_processor_write_data_beats_cs11\000\000DRAM write data for remote processor\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 15100 }, /* \000frontend_bound\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.no_ops_from_frontend, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because the frontend did not supply enough instructions/ops\000\000100%\000\000\000\00000 */
{ 15323 }, /* \000frontend_bound_bandwidth\000PipelineL2;frontend_bound_group\000d_ratio(de_no_dispatch_per_slot.no_ops_from_frontend - 6 * cpu@de_no_dispatch_per_slot.no_ops_from_frontend\\,cmask\\=0x6@, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of a bandwidth bottleneck in the frontend (such as decode or op cache fetch bandwidth)\000\000100%\000\000\000\00000 */
{ 15680 }, /* \000frontend_bound_latency\000PipelineL2;frontend_bound_group\000d_ratio(6 * cpu@de_no_dispatch_per_slot.no_ops_from_frontend\\,cmask\\=0x6@, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because of a latency bottleneck in the frontend (such as instruction cache or TLB misses)\000\000100%\000\000\000\00000 */
{ 15983 }, /* \000ic_fetch_miss_ratio\000\000d_ratio(ic_tag_hit_miss.instruction_cache_miss, ic_tag_hit_miss.all_instruction_cache_accesses)\000\000Instruction cache miss ratio for all fetches. An instruction cache miss will not be counted by this metric if it is an OC hit\000\000100%\000\000\000\00000 */
{ 20906 }, /* \000l1_data_cache_fills_from_different_ccx\000l1_dcache\000ls_any_fills_from_sys.remote_cache\000\000L1 data cache fills from another CCX cache in any NUMA node\000\000\000\000\000\00000 */
{ 21059 }, /* \000l1_data_cache_fills_from_memory\000l1_dcache\000ls_any_fills_from_sys.dram_io_all\000\000L1 data cache fills from DRAM or MMIO in any NUMA node\000\000\000\000\000\00000 */
{ 21199 }, /* \000l1_data_cache_fills_from_remote_node\000l1_dcache\000ls_any_fills_from_sys.far_all\000\000L1 data cache fills from a different NUMA node\000\000\000\000\000\00000 */
{ 21332 }, /* \000l1_data_cache_fills_from_same_ccx\000l1_dcache\000ls_any_fills_from_sys.local_all\000\000L1 data cache fills from within the same CCX\000\000\000\000\000\00000 */
{ 21462 }, /* \000l1_demand_data_cache_fills_from_far_cache\000l1_dcache\000ls_dmnd_fills_from_sys.far_cache\000\000L1 demand data cache fills from another CCX cache in a different NUMA node\000\000\000\000\000\00000 */
{ 21631 }, /* \000l1_demand_data_cache_fills_from_far_memory\000l1_dcache\000ls_dmnd_fills_from_sys.dram_io_far\000\000L1 demand data cache fills from DRAM or MMIO in a different NUMA node\000\000\000\000\000\00000 */
{ 21798 }, /* \000l1_demand_data_cache_fills_from_local_l2\000l1_dcache\000ls_dmnd_fills_from_sys.local_l2\000\000L1 demand data cache fills from local L2 cache\000\000\000\000\000\00000 */
{ 21937 }, /* \000l1_demand_data_cache_fills_from_near_cache\000l1_dcache\000ls_dmnd_fills_from_sys.near_cache\000\000L1 demand data cache fills from another CCX cache in the same NUMA node\000\000\000\000\000\00000 */
{ 22105 }, /* \000l1_demand_data_cache_fills_from_near_memory\000l1_dcache\000ls_dmnd_fills_from_sys.dram_io_near\000\000L1 demand data cache fills from DRAM or MMIO in the same NUMA node\000\000\000\000\000\00000 */
{ 22271 }, /* \000l1_demand_data_cache_fills_from_same_ccx\000l1_dcache\000ls_dmnd_fills_from_sys.local_ccx\000\000L1 demand data cache fills from within the same CCX\000\000\000\000\000\00000 */
{ 22416 }, /* \000l1_dtlb_misses\000tlb\000ls_l1_d_tlb_miss.all\000\000L1 data TLB misses\000\000\000\000\000\00000 */
{ 22914 }, /* \000l1_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_hit + bp_l1_tlb_miss_l2_tlb_miss.all\000\000L1 instruction TLB misses\000\000\000\000\000\00000 */
{ 23743 }, /* \000l2_cache_accesses_from_l1_dc_misses\000l2_cache\000l2_request_g1.all_dc\000\000L2 cache accesses from L1 data cache misses (including prefetch)\000\000\000\000\000\00000 */
{ 23883 }, /* \000l2_cache_accesses_from_l1_ic_misses\000l2_cache\000l2_request_g1.cacheable_ic_read\000\000L2 cache accesses from L1 instruction cache misses (including prefetch)\000\000\000\000\000\00000 */
{ 24176 }, /* \000l2_cache_accesses_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2.all + l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000L2 cache accesses from L2 cache hardware prefetcher\000\000\000\000\000\00000 */
{ 24344 }, /* \000l2_cache_hits_from_l1_dc_miss\000l2_cache\000l2_cache_req_stat.dc_hit_in_l2\000\000L2 cache hits from L1 data cache misses\000\000\000\000\000\00000 */
{ 24463 }, /* \000l2_cache_hits_from_l1_ic_miss\000l2_cache\000l2_cache_req_stat.ic_hit_in_l2\000\000L2 cache hits from L1 instruction cache misses\000\000\000\000\000\00000 */
{ 24589 }, /* \000l2_cache_hits_from_l2_hwpf\000l2_cache\000l2_pf_hit_l2.all\000\000L2 cache hits from L2 cache hardware prefetcher\000\000\000\000\000\00000 */
{ 24699 }, /* \000l2_cache_misses_from_l1_dc_miss\000l2_cache\000l2_cache_req_stat.ls_rd_blk_c\000\000L2 cache misses from L1 data cache misses\000\000\000\000\000\00000 */
{ 24821 }, /* \000l2_cache_misses_from_l1_ic_miss\000l2_cache\000l2_cache_req_stat.ic_fill_miss\000\000L2 cache misses from L1 instruction cache misses\000\000\000\000\000\00000 */
{ 25189 }, /* \000l2_cache_misses_from_l2_hwpf\000l2_cache\000l2_pf_miss_l2_hit_l3.all + l2_pf_miss_l2_l3.all\000\000L2 cache misses from L2 cache hardware prefetcher\000\000\000\000\000\00000 */
{ 26348 }, /* \000l2_dtlb_misses\000tlb\000ls_l1_d_tlb_miss.all_l2_miss\000\000L2 data TLB misses and data page walks\000\000\000\000\000\00000 */
{ 26444 }, /* \000l2_itlb_misses\000tlb\000bp_l1_tlb_miss_l2_tlb_miss.all\000\000L2 instruction TLB misses and instruction page walks\000\000\000\000\000\00000 */
{ 26748 }, /* \000l3_cache_accesses\000l3_cache\000l3_lookup_state.all_coherent_accesses_to_l3\000\000L3 cache accesses\000\000\000\000\000\00000 */
{ 26846 }, /* \000l3_misses\000l3_cache\000l3_lookup_state.l3_miss\000\000L3 misses (including cacheline state change requests)\000\000\000\000\000\00000 */
{ 26952 }, /* \000l3_read_miss_latency\000l3_cache\000l3_xi_sampled_latency.all * 10 / l3_xi_sampled_latency_requests.all\000\000Average L3 read miss latency (in core clocks)\000\0001core clocks\000\000\000\00000 */
{ 36378 }, /* \000local_socket_inbound_data_to_cpu\000data_fabric\000local_socket_inf0_inbound_data_beats_ccm0 + local_socket_inf1_inbound_data_beats_ccm0 + local_socket_inf0_inbound_data_beats_ccm1 + local_socket_inf1_inbound_data_beats_ccm1 + local_socket_inf0_inbound_data_beats_ccm2 + local_socket_inf1_inbound_data_beats_ccm2 + local_socket_inf0_inbound_data_beats_ccm3 + local_socket_inf1_inbound_data_beats_ccm3 + local_socket_inf0_inbound_data_beats_ccm4 + local_socket_inf1_inbound_data_beats_ccm4 + local_socket_inf0_inbound_data_beats_ccm5 + local_socket_inf1_inbound_data_beats_ccm5 + local_socket_inf0_inbound_data_beats_ccm6 + local_socket_inf1_inbound_data_beats_ccm6 + local_socket_inf0_inbound_data_beats_ccm7 + local_socket_inf1_inbound_data_beats_ccm7\000\000Local socket inbound data to the CPU (e.g. read data)\000\0003.0517578125e-5MiB\000\000\000\00000 */
{ 37206 }, /* \000local_socket_outbound_data_from_all_links\000data_fabric\000local_socket_outbound_data_beats_link0 + local_socket_outbound_data_beats_link1 + local_socket_outbound_data_beats_link2 + local_socket_outbound_data_beats_link3 + local_socket_outbound_data_beats_link4 + local_socket_outbound_data_beats_link5 + local_socket_outbound_data_beats_link6 + local_socket_outbound_data_beats_link7\000\000Outbound data from all links (local socket)\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 37656 }, /* \000local_socket_outbound_data_from_cpu\000data_fabric\000local_socket_inf0_outbound_data_beats_ccm0 + local_socket_inf1_outbound_data_beats_ccm0 + local_socket_inf0_outbound_data_beats_ccm1 + local_socket_inf1_outbound_data_beats_ccm1 + local_socket_inf0_outbound_data_beats_ccm2 + local_socket_inf1_outbound_data_beats_ccm2 + local_socket_inf0_outbound_data_beats_ccm3 + local_socket_inf1_outbound_data_beats_ccm3 + local_socket_inf0_outbound_data_beats_ccm4 + local_socket_inf1_outbound_data_beats_ccm4 + local_socket_inf0_outbound_data_beats_ccm5 + local_socket_inf1_outbound_data_beats_ccm5 + local_socket_inf0_outbound_data_beats_ccm6 + local_socket_inf1_outbound_data_beats_ccm6 + local_socket_inf0_outbound_data_beats_ccm7 + local_socket_inf1_outbound_data_beats_ccm7\000\000Local socket outbound data from the CPU (e.g. write data)\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 38506 }, /* \000local_socket_upstream_dma_read_data\000data_fabric\000local_socket_upstream_read_beats_iom0 + local_socket_upstream_read_beats_iom1 + local_socket_upstream_read_beats_iom2 + local_socket_upstream_read_beats_iom3\000\000Local socket upstream DMA read data\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 38774 }, /* \000local_socket_upstream_dma_write_data\000data_fabric\000local_socket_upstream_write_beats_iom0 + local_socket_upstream_write_beats_iom1 + local_socket_upstream_write_beats_iom2 + local_socket_upstream_write_beats_iom3\000\000Local socket upstream DMA write data\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 39222 }, /* \000macro_ops_dispatched\000decoder\000de_src_op_disp.all\000\000Macro-ops dispatched\000\000\000\000\000\00000 */
{ 39300 }, /* \000macro_ops_retired\000\000ex_ret_ops\000\000Macro-ops retired\000\000\000\000\000\00000 */
{ 42838 }, /* \000op_cache_fetch_miss_ratio\000\000d_ratio(op_cache_hit_miss.op_cache_miss, op_cache_hit_miss.all_op_cache_accesses)\000\000Op cache miss ratio for all fetches\000\000100%\000\000\000\00000 */
{ 45778 }, /* \000remote_socket_inbound_data_to_cpu\000data_fabric\000remote_socket_inf0_inbound_data_beats_ccm0 + remote_socket_inf1_inbound_data_beats_ccm0 + remote_socket_inf0_inbound_data_beats_ccm1 + remote_socket_inf1_inbound_data_beats_ccm1 + remote_socket_inf0_inbound_data_beats_ccm2 + remote_socket_inf1_inbound_data_beats_ccm2 + remote_socket_inf0_inbound_data_beats_ccm3 + remote_socket_inf1_inbound_data_beats_ccm3 + remote_socket_inf0_inbound_data_beats_ccm4 + remote_socket_inf1_inbound_data_beats_ccm4 + remote_socket_inf0_inbound_data_beats_ccm5 + remote_socket_inf1_inbound_data_beats_ccm5 + remote_socket_inf0_inbound_data_beats_ccm6 + remote_socket_inf1_inbound_data_beats_ccm6 + remote_socket_inf0_inbound_data_beats_ccm7 + remote_socket_inf1_inbound_data_beats_ccm7\000\000Remote socket inbound data to the CPU (e.g. read data)\000\0003.0517578125e-5MiB\000\000\000\00000 */
{ 46624 }, /* \000remote_socket_outbound_data_from_cpu\000data_fabric\000remote_socket_inf0_outbound_data_beats_ccm0 + remote_socket_inf1_outbound_data_beats_ccm0 + remote_socket_inf0_outbound_data_beats_ccm1 + remote_socket_inf1_outbound_data_beats_ccm1 + remote_socket_inf0_outbound_data_beats_ccm2 + remote_socket_inf1_outbound_data_beats_ccm2 + remote_socket_inf0_outbound_data_beats_ccm3 + remote_socket_inf1_outbound_data_beats_ccm3 + remote_socket_inf0_outbound_data_beats_ccm4 + remote_socket_inf1_outbound_data_beats_ccm4 + remote_socket_inf0_outbound_data_beats_ccm5 + remote_socket_inf1_outbound_data_beats_ccm5 + remote_socket_inf0_outbound_data_beats_ccm6 + remote_socket_inf1_outbound_data_beats_ccm6 + remote_socket_inf0_outbound_data_beats_ccm7 + remote_socket_inf1_outbound_data_beats_ccm7\000\000Remote socket outbound data from the CPU (e.g. write data)\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 47492 }, /* \000remote_socket_upstream_dma_read_data\000data_fabric\000remote_socket_upstream_read_beats_iom0 + remote_socket_upstream_read_beats_iom1 + remote_socket_upstream_read_beats_iom2 + remote_socket_upstream_read_beats_iom3\000\000Remote socket upstream DMA read data\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 47766 }, /* \000remote_socket_upstream_dma_write_data\000data_fabric\000remote_socket_upstream_write_beats_iom0 + remote_socket_upstream_write_beats_iom1 + remote_socket_upstream_write_beats_iom2 + remote_socket_upstream_write_beats_iom3\000\000Remote socket upstream DMA write data\000\0006.103515625e-5MiB\000\000\000\00000 */
{ 48046 }, /* \000retiring\000PipelineL1\000d_ratio(ex_ret_ops, total_dispatch_slots)\000\000Fraction of dispatch slots used by ops that retired\000\000100%\000\000\000\00000 */
{ 48173 }, /* \000retiring_fastpath\000PipelineL2;retiring_group\000retiring * (1 - d_ratio(ex_ret_ucode_ops, ex_ret_ops))\000\000Fraction of dispatch slots used by fastpath ops that retired\000\000100%\000\000\000\00000 */
{ 48346 }, /* \000retiring_microcode\000PipelineL2;retiring_group\000retiring * d_ratio(ex_ret_ucode_ops, ex_ret_ops)\000\000Fraction of dispatch slots used by microcode ops that retired\000\000100%\000\000\000\00000 */
{ 48738 }, /* \000smt_contention\000PipelineL1\000d_ratio(de_no_dispatch_per_slot.smt_contention, total_dispatch_slots)\000\000Fraction of dispatch slots that remained unused because the other thread was selected\000\000100%\000\000\000\00000 */
{ 48933 }, /* \000sse_avx_stalls\000\000fp_disp_faults.sse_avx_all\000\000Mixed SSE/AVX stalls\000\000\000\000\000\00000 */
{ 464511 }, /* \000total_dispatch_slots\000\0006 * ls_not_halted_cyc\000\000Total dispatch slots (upto 6 instructions can be dispatched in each cycle)\000\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__bonnell[] = {
{ 1102871 }, /* l1d_cache.all_cache_ref\000\000cache\000L1 Data Cacheable reads and writes\000event=0x40,period=2000000,umask=0xa3\000\00000\000\000 */
{ 1102979 }, /* l1d_cache.all_ref\000\000cache\000L1 Data reads and writes\000event=0x40,period=2000000,umask=0x83\000\00000\000\000 */
{ 1103071 }, /* l1d_cache.evict\000\000cache\000Modified cache lines evicted from the L1 data cache\000event=0x40,period=200000,umask=0x10\000\00000\000\000 */
{ 1103187 }, /* l1d_cache.ld\000\000cache\000L1 Cacheable Data Reads\000event=0x40,period=2000000,umask=0xa1\000\00000\000\000 */
{ 1103273 }, /* l1d_cache.repl\000\000cache\000L1 Data line replacements\000event=0x40,period=200000,umask=0x8\000\00000\000\000 */
{ 1103361 }, /* l1d_cache.replm\000\000cache\000Modified cache lines allocated in the L1 data cache\000event=0x40,period=200000,umask=0x48\000\00000\000\000 */
{ 1103477 }, /* l1d_cache.st\000\000cache\000L1 Cacheable Data Writes\000event=0x40,period=2000000,umask=0xa2\000\00000\000\000 */
{ 1115097 }, /* l2_ads.self\000\000cache\000Cycles L2 address bus is in use\000event=0x21,period=200000,umask=0x40\000\00000\000\000 */
{ 1123003 }, /* l2_data_rqsts.self.e_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x44\000\00000\000\000 */
{ 1123119 }, /* l2_data_rqsts.self.i_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x41\000\00000\000\000 */
{ 1123235 }, /* l2_data_rqsts.self.m_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x48\000\00000\000\000 */
{ 1123351 }, /* l2_data_rqsts.self.mesi\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x4f\000\00000\000\000 */
{ 1123464 }, /* l2_data_rqsts.self.s_state\000\000cache\000All data requests from the L1 data cache\000event=0x2c,period=200000,umask=0x42\000\00000\000\000 */
{ 1123580 }, /* l2_dbus_busy.self\000\000cache\000Cycles the L2 cache data bus is busy\000event=0x22,period=200000,umask=0x40\000\00000\000\000 */
{ 1123683 }, /* l2_dbus_busy_rd.self\000\000cache\000Cycles the L2 transfers data to the core\000event=0x23,period=200000,umask=0x40\000\00000\000\000 */
{ 1124374 }, /* l2_ifetch.self.e_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x44\000\00000\000\000 */
{ 1124485 }, /* l2_ifetch.self.i_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x41\000\00000\000\000 */
{ 1124596 }, /* l2_ifetch.self.m_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x48\000\00000\000\000 */
{ 1124707 }, /* l2_ifetch.self.mesi\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x4f\000\00000\000\000 */
{ 1124815 }, /* l2_ifetch.self.s_state\000\000cache\000L2 cacheable instruction fetch requests\000event=0x28,period=200000,umask=0x42\000\00000\000\000 */
{ 1126578 }, /* l2_ld.self.any.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x74\000\00000\000\000 */
{ 1126664 }, /* l2_ld.self.any.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x71\000\00000\000\000 */
{ 1126750 }, /* l2_ld.self.any.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x78\000\00000\000\000 */
{ 1126836 }, /* l2_ld.self.any.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x7f\000\00000\000\000 */
{ 1126919 }, /* l2_ld.self.any.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x72\000\00000\000\000 */
{ 1127005 }, /* l2_ld.self.demand.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x44\000\00000\000\000 */
{ 1127094 }, /* l2_ld.self.demand.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x41\000\00000\000\000 */
{ 1127183 }, /* l2_ld.self.demand.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x48\000\00000\000\000 */
{ 1127272 }, /* l2_ld.self.demand.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x4f\000\00000\000\000 */
{ 1127358 }, /* l2_ld.self.demand.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x42\000\00000\000\000 */
{ 1127447 }, /* l2_ld.self.prefetch.e_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x54\000\00000\000\000 */
{ 1127538 }, /* l2_ld.self.prefetch.i_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x51\000\00000\000\000 */
{ 1127629 }, /* l2_ld.self.prefetch.m_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x58\000\00000\000\000 */
{ 1127720 }, /* l2_ld.self.prefetch.mesi\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x5f\000\00000\000\000 */
{ 1127808 }, /* l2_ld.self.prefetch.s_state\000\000cache\000L2 cache reads\000event=0x29,period=200000,umask=0x52\000\00000\000\000 */
{ 1127899 }, /* l2_ld_ifetch.self.e_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x44\000\00000\000\000 */
{ 1128027 }, /* l2_ld_ifetch.self.i_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x41\000\00000\000\000 */
{ 1128155 }, /* l2_ld_ifetch.self.m_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x48\000\00000\000\000 */
{ 1128283 }, /* l2_ld_ifetch.self.mesi\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x4f\000\00000\000\000 */
{ 1128408 }, /* l2_ld_ifetch.self.s_state\000\000cache\000All read requests from L1 instruction and data caches\000event=0x2d,period=200000,umask=0x42\000\00000\000\000 */
{ 1131307 }, /* l2_lines_in.self.any\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x70\000\00000\000\000 */
{ 1131392 }, /* l2_lines_in.self.demand\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1131480 }, /* l2_lines_in.self.prefetch\000\000cache\000L2 cache misses\000event=0x24,period=200000,umask=0x50\000\00000\000\000 */
{ 1135878 }, /* l2_lines_out.self.any\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x70\000\00000\000\000 */
{ 1135971 }, /* l2_lines_out.self.demand\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1136067 }, /* l2_lines_out.self.prefetch\000\000cache\000L2 cache lines evicted\000event=0x26,period=200000,umask=0x50\000\00000\000\000 */
{ 1138950 }, /* l2_lock.self.e_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x44\000\00000\000\000 */
{ 1139038 }, /* l2_lock.self.i_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x41\000\00000\000\000 */
{ 1139126 }, /* l2_lock.self.m_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x48\000\00000\000\000 */
{ 1139214 }, /* l2_lock.self.mesi\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x4f\000\00000\000\000 */
{ 1139299 }, /* l2_lock.self.s_state\000\000cache\000L2 locked accesses\000event=0x2b,period=200000,umask=0x42\000\00000\000\000 */
{ 1139387 }, /* l2_m_lines_in.self\000\000cache\000L2 cache line modifications\000event=0x25,period=200000,umask=0x40\000\00000\000\000 */
{ 1139482 }, /* l2_m_lines_out.self.any\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x70\000\00000\000\000 */
{ 1139595 }, /* l2_m_lines_out.self.demand\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x40\000\00000\000\000 */
{ 1139711 }, /* l2_m_lines_out.self.prefetch\000\000cache\000Modified lines evicted from the L2 cache\000event=0x27,period=200000,umask=0x50\000\00000\000\000 */
{ 1139829 }, /* l2_no_req.self\000\000cache\000Cycles no L2 cache requests are pending\000event=0x32,period=200000,umask=0x40\000\00000\000\000 */
{ 1146678 }, /* l2_reject_busq.self.any.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x74\000\00000\000\000 */
{ 1146785 }, /* l2_reject_busq.self.any.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x71\000\00000\000\000 */
{ 1146892 }, /* l2_reject_busq.self.any.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x78\000\00000\000\000 */
{ 1146999 }, /* l2_reject_busq.self.any.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x7f\000\00000\000\000 */
{ 1147103 }, /* l2_reject_busq.self.any.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x72\000\00000\000\000 */
{ 1147210 }, /* l2_reject_busq.self.demand.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x44\000\00000\000\000 */
{ 1147320 }, /* l2_reject_busq.self.demand.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x41\000\00000\000\000 */
{ 1147430 }, /* l2_reject_busq.self.demand.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x48\000\00000\000\000 */
{ 1147540 }, /* l2_reject_busq.self.demand.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x4f\000\00000\000\000 */
{ 1147647 }, /* l2_reject_busq.self.demand.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x42\000\00000\000\000 */
{ 1147757 }, /* l2_reject_busq.self.prefetch.e_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x54\000\00000\000\000 */
{ 1147869 }, /* l2_reject_busq.self.prefetch.i_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x51\000\00000\000\000 */
{ 1147981 }, /* l2_reject_busq.self.prefetch.m_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x58\000\00000\000\000 */
{ 1148093 }, /* l2_reject_busq.self.prefetch.mesi\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x5f\000\00000\000\000 */
{ 1148202 }, /* l2_reject_busq.self.prefetch.s_state\000\000cache\000Rejected L2 cache requests\000event=0x30,period=200000,umask=0x52\000\00000\000\000 */
{ 1175663 }, /* l2_rqsts.self.any.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x74\000\00000\000\000 */
{ 1175755 }, /* l2_rqsts.self.any.i_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x71\000\00000\000\000 */
{ 1175847 }, /* l2_rqsts.self.any.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x78\000\00000\000\000 */
{ 1175939 }, /* l2_rqsts.self.any.mesi\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x7f\000\00000\000\000 */
{ 1176028 }, /* l2_rqsts.self.any.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x72\000\00000\000\000 */
{ 1176120 }, /* l2_rqsts.self.demand.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x44\000\00000\000\000 */
{ 1176215 }, /* l2_rqsts.self.demand.i_state\000\000cache\000L2 cache demand requests from this core that missed the L2\000event=0x2e,period=200000,umask=0x41\000\00000\000\000 */
{ 1176351 }, /* l2_rqsts.self.demand.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x48\000\00000\000\000 */
{ 1176446 }, /* l2_rqsts.self.demand.mesi\000\000cache\000L2 cache demand requests from this core\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1176560 }, /* l2_rqsts.self.demand.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x42\000\00000\000\000 */
{ 1176655 }, /* l2_rqsts.self.prefetch.e_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x54\000\00000\000\000 */
{ 1176752 }, /* l2_rqsts.self.prefetch.i_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x51\000\00000\000\000 */
{ 1176849 }, /* l2_rqsts.self.prefetch.m_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x58\000\00000\000\000 */
{ 1176946 }, /* l2_rqsts.self.prefetch.mesi\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x5f\000\00000\000\000 */
{ 1177040 }, /* l2_rqsts.self.prefetch.s_state\000\000cache\000L2 cache requests\000event=0x2e,period=200000,umask=0x52\000\00000\000\000 */
{ 1178145 }, /* l2_st.self.e_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x44\000\00000\000\000 */
{ 1178230 }, /* l2_st.self.i_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x41\000\00000\000\000 */
{ 1178315 }, /* l2_st.self.m_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x48\000\00000\000\000 */
{ 1178400 }, /* l2_st.self.mesi\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x4f\000\00000\000\000 */
{ 1178482 }, /* l2_st.self.s_state\000\000cache\000L2 store requests\000event=0x2a,period=200000,umask=0x42\000\00000\000\000 */
{ 1336983 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (precise event)\000event=0xcb,period=200000,umask=0x1\000\00000\000\000 */
{ 1337994 }, /* mem_load_retired.l2_miss\000\000cache\000Retired loads that miss the L2 cache\000event=0xcb,period=10000,umask=0x2\000\00000\000\000 */
{ 902626 }, /* fp_assist.ar\000\000floating point\000Floating point assists for retired operations\000event=0x11,period=10000,umask=0x81\000\00000\000\000 */
{ 903020 }, /* fp_assist.s\000\000floating point\000Floating point assists\000event=0x11,period=10000,umask=0x1\000\00000\000\000 */
{ 2522908 }, /* simd_assist\000\000floating point\000SIMD assists invoked\000event=0xcd,period=100000\000\00000\000\000 */
{ 2522987 }, /* simd_comp_inst_retired.packed_single\000\000floating point\000Retired computational Streaming SIMD Extensions (SSE) packed-single instructions\000event=0xca,period=2000000,umask=0x1\000\00000\000\000 */
{ 2523162 }, /* simd_comp_inst_retired.scalar_double\000\000floating point\000Retired computational Streaming SIMD Extensions 2 (SSE2) scalar-double instructions\000event=0xca,period=2000000,umask=0x8\000\00000\000\000 */
{ 2523340 }, /* simd_comp_inst_retired.scalar_single\000\000floating point\000Retired computational Streaming SIMD Extensions (SSE) scalar-single instructions\000event=0xca,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524281 }, /* simd_inst_retired.packed_single\000\000floating point\000Retired Streaming SIMD Extensions (SSE) packed-single instructions\000event=0xc7,period=2000000,umask=0x1\000\00000\000\000 */
{ 2524437 }, /* simd_inst_retired.scalar_double\000\000floating point\000Retired Streaming SIMD Extensions 2 (SSE2) scalar-double instructions\000event=0xc7,period=2000000,umask=0x8\000\00000\000\000 */
{ 2524596 }, /* simd_inst_retired.scalar_single\000\000floating point\000Retired Streaming SIMD Extensions (SSE) scalar-single instructions\000event=0xc7,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524752 }, /* simd_inst_retired.vector\000\000floating point\000Retired Streaming SIMD Extensions 2 (SSE2) vector instructions\000event=0xc7,period=2000000,umask=0x10\000\00000\000\000 */
{ 2524898 }, /* simd_instr_retired\000\000floating point\000SIMD Instructions retired\000event=0xce,period=2000000\000\00000\000\000 */
{ 2526675 }, /* simd_sat_instr_retired\000\000floating point\000Saturated arithmetic instructions retired\000event=0xcf,period=2000000\000\00000\000\000 */
{ 2526787 }, /* simd_sat_uop_exec.ar\000\000floating point\000SIMD saturated arithmetic micro-ops retired\000event=0xb1,period=2000000,umask=0x80\000\00000\000\000 */
{ 2526910 }, /* simd_sat_uop_exec.s\000\000floating point\000SIMD saturated arithmetic micro-ops executed\000event=0xb1,period=2000000\000\00000\000\000 */
{ 2527022 }, /* simd_uop_type_exec.arithmetic.ar\000\000floating point\000SIMD packed arithmetic micro-ops retired\000event=0xb3,period=2000000,umask=0xa0\000\00000\000\000 */
{ 2527154 }, /* simd_uop_type_exec.arithmetic.s\000\000floating point\000SIMD packed arithmetic micro-ops executed\000event=0xb3,period=2000000,umask=0x20\000\00000\000\000 */
{ 2527286 }, /* simd_uop_type_exec.logical.ar\000\000floating point\000SIMD packed logical micro-ops retired\000event=0xb3,period=2000000,umask=0x90\000\00000\000\000 */
{ 2527412 }, /* simd_uop_type_exec.logical.s\000\000floating point\000SIMD packed logical micro-ops executed\000event=0xb3,period=2000000,umask=0x10\000\00000\000\000 */
{ 2527538 }, /* simd_uop_type_exec.mul.ar\000\000floating point\000SIMD packed multiply micro-ops retired\000event=0xb3,period=2000000,umask=0x81\000\00000\000\000 */
{ 2527661 }, /* simd_uop_type_exec.mul.s\000\000floating point\000SIMD packed multiply micro-ops executed\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000 */
{ 2527783 }, /* simd_uop_type_exec.pack.ar\000\000floating point\000SIMD packed micro-ops retired\000event=0xb3,period=2000000,umask=0x84\000\00000\000\000 */
{ 2527898 }, /* simd_uop_type_exec.pack.s\000\000floating point\000SIMD packed micro-ops executed\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000 */
{ 2528012 }, /* simd_uop_type_exec.shift.ar\000\000floating point\000SIMD packed shift micro-ops retired\000event=0xb3,period=2000000,umask=0x82\000\00000\000\000 */
{ 2528134 }, /* simd_uop_type_exec.shift.s\000\000floating point\000SIMD packed shift micro-ops executed\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000 */
{ 2528255 }, /* simd_uop_type_exec.unpack.ar\000\000floating point\000SIMD unpacked micro-ops retired\000event=0xb3,period=2000000,umask=0x88\000\00000\000\000 */
{ 2528374 }, /* simd_uop_type_exec.unpack.s\000\000floating point\000SIMD unpacked micro-ops executed\000event=0xb3,period=2000000,umask=0x8\000\00000\000\000 */
{ 2528492 }, /* simd_uops_exec.ar\000\000floating point\000SIMD micro-ops retired (excluding stores) (Must be precise)\000event=0xb0,period=2000000,umask=0x80\000\00000\000\000 */
{ 2528628 }, /* simd_uops_exec.s\000\000floating point\000SIMD micro-ops executed (excluding stores)\000event=0xb0,period=2000000\000\00000\000\000 */
{ 6242156 }, /* x87_comp_ops_exe.any.ar\000\000floating point\000Floating point computational micro-ops retired (Must be precise)\000event=0x10,period=2000000,umask=0x81\000\00000\000\000 */
{ 6242303 }, /* x87_comp_ops_exe.any.s\000\000floating point\000Floating point computational micro-ops executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 6242431 }, /* x87_comp_ops_exe.fxch.ar\000\000floating point\000FXCH uops retired (Must be precise)\000event=0x10,period=2000000,umask=0x82\000\00000\000\000 */
{ 6242550 }, /* x87_comp_ops_exe.fxch.s\000\000floating point\000FXCH uops executed\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 474875 }, /* baclears.any\000\000frontend\000BACLEARS asserted\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 761938 }, /* cycles_icache_mem_stalled.icache_mem_stalled\000\000frontend\000Cycles during which instruction fetches are  stalled\000event=0x86,period=2000000,umask=0x1\000\00000\000\000 */
{ 778383 }, /* decode_stall.iq_full\000\000frontend\000Decode stall due to IQ full\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 778483 }, /* decode_stall.pfb_empty\000\000frontend\000Decode stall due to PFB empty\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 983624 }, /* icache.accesses\000\000frontend\000Instruction fetches\000event=0x80,period=200000,umask=0x3\000\00000\000\000 */
{ 985964 }, /* icache.hit\000\000frontend\000Icache hit\000event=0x80,period=200000,umask=0x1\000\00000\000\000 */
{ 989566 }, /* icache.misses\000\000frontend\000Icache miss\000event=0x80,period=200000,umask=0x2\000\00000\000\000 */
{ 1302701 }, /* macro_insts.all_decoded\000\000frontend\000All Instructions decoded\000event=0xaa,period=2000000,umask=0x3\000\00000\000\000 */
{ 1302801 }, /* macro_insts.cisc_decoded\000\000frontend\000CISC macro instructions decoded\000event=0xaa,period=2000000,umask=0x2\000\00000\000\000 */
{ 1303113 }, /* macro_insts.non_cisc_decoded\000\000frontend\000Non-CISC nacro instructions decoded\000event=0xaa,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178100 }, /* uops.ms_cycles\000\000frontend\000This event counts the cycles where 1 or more uops are issued by the micro-sequencer (MS), including microcode assists and inserted flows, and written to the IQ\000event=0xa9,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1427427 }, /* misalign_mem_ref.bubble\000\000memory\000Nonzero segbase 1 bubble\000event=0x5,period=200000,umask=0x97\000\00000\000\000 */
{ 1427524 }, /* misalign_mem_ref.ld_bubble\000\000memory\000Nonzero segbase load 1 bubble\000event=0x5,period=200000,umask=0x91\000\00000\000\000 */
{ 1427734 }, /* misalign_mem_ref.ld_split\000\000memory\000Load splits\000event=0x5,period=200000,umask=0x9\000\00000\000\000 */
{ 1427629 }, /* misalign_mem_ref.ld_split.ar\000\000memory\000Load splits (At Retirement)\000event=0x5,period=200000,umask=0x89\000\00000\000\000 */
{ 1428936 }, /* misalign_mem_ref.rmw_bubble\000\000memory\000Nonzero segbase ld-op-st 1 bubble\000event=0x5,period=200000,umask=0x94\000\00000\000\000 */
{ 1429046 }, /* misalign_mem_ref.rmw_split\000\000memory\000ld-op-st splits\000event=0x5,period=200000,umask=0x8c\000\00000\000\000 */
{ 1429275 }, /* misalign_mem_ref.split\000\000memory\000Memory references that cross an 8-byte boundary\000event=0x5,period=200000,umask=0xf\000\00000\000\000 */
{ 1429137 }, /* misalign_mem_ref.split.ar\000\000memory\000Memory references that cross an 8-byte boundary (At Retirement)\000event=0x5,period=200000,umask=0x8f\000\00000\000\000 */
{ 1429393 }, /* misalign_mem_ref.st_bubble\000\000memory\000Nonzero segbase store 1 bubble\000event=0x5,period=200000,umask=0x92\000\00000\000\000 */
{ 1429605 }, /* misalign_mem_ref.st_split\000\000memory\000Store splits\000event=0x5,period=200000,umask=0xa\000\00000\000\000 */
{ 1429499 }, /* misalign_mem_ref.st_split.ar\000\000memory\000Store splits (Ar Retirement)\000event=0x5,period=200000,umask=0x8a\000\00000\000\000 */
{ 2479806 }, /* prefetch.hw_prefetch\000\000memory\000L1 hardware prefetch request\000event=0x7,period=2000000,umask=0x10\000\00000\000\000 */
{ 2479905 }, /* prefetch.prefetchnta\000\000memory\000Streaming SIMD Extensions (SSE) Prefetch NTA instructions executed\000event=0x7,period=200000,umask=0x88\000\00000\000\000 */
{ 2480041 }, /* prefetch.prefetcht0\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT0 instructions executed\000event=0x7,period=200000,umask=0x81\000\00000\000\000 */
{ 2480174 }, /* prefetch.prefetcht1\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT1 instructions executed\000event=0x7,period=200000,umask=0x82\000\00000\000\000 */
{ 2480307 }, /* prefetch.prefetcht2\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT2 instructions executed\000event=0x7,period=200000,umask=0x84\000\00000\000\000 */
{ 2480540 }, /* prefetch.software_prefetch\000\000memory\000Any Software prefetch\000event=0x7,period=200000,umask=0xf\000\00000\000\000 */
{ 2480440 }, /* prefetch.software_prefetch.ar\000\000memory\000Any Software prefetch\000event=0x7,period=200000,umask=0x8f\000\00000\000\000 */
{ 2480636 }, /* prefetch.sw_l2\000\000memory\000Streaming SIMD Extensions (SSE) PrefetchT1 and PrefetchT2 instructions executed\000event=0x7,period=200000,umask=0x86\000\00000\000\000 */
{ 565760 }, /* bus_bnr_drv.all_agents\000\000other\000Number of Bus Not Ready signals asserted\000event=0x61,period=200000,umask=0x20\000\00000\000\000 */
{ 565872 }, /* bus_bnr_drv.this_agent\000\000other\000Number of Bus Not Ready signals asserted\000event=0x61,period=200000\000\00000\000\000 */
{ 565973 }, /* bus_data_rcv.self\000\000other\000Bus cycles while processor receives data\000event=0x64,period=200000,umask=0x40\000\00000\000\000 */
{ 566080 }, /* bus_drdy_clocks.all_agents\000\000other\000Bus cycles when data is sent on the bus\000event=0x62,period=200000,umask=0x20\000\00000\000\000 */
{ 566195 }, /* bus_drdy_clocks.this_agent\000\000other\000Bus cycles when data is sent on the bus\000event=0x62,period=200000\000\00000\000\000 */
{ 566299 }, /* bus_hit_drv.all_agents\000\000other\000HIT signal asserted\000event=0x7a,period=200000,umask=0x20\000\00000\000\000 */
{ 566390 }, /* bus_hit_drv.this_agent\000\000other\000HIT signal asserted\000event=0x7a,period=200000\000\00000\000\000 */
{ 566470 }, /* bus_hitm_drv.all_agents\000\000other\000HITM signal asserted\000event=0x7b,period=200000,umask=0x20\000\00000\000\000 */
{ 566563 }, /* bus_hitm_drv.this_agent\000\000other\000HITM signal asserted\000event=0x7b,period=200000\000\00000\000\000 */
{ 566645 }, /* bus_io_wait.self\000\000other\000IO requests waiting in the bus queue\000event=0x7f,period=200000,umask=0x40\000\00000\000\000 */
{ 568051 }, /* bus_lock_clocks.all_agents\000\000other\000Bus cycles when a LOCK signal is asserted\000event=0x63,period=200000,umask=0xe0\000\00000\000\000 */
{ 568168 }, /* bus_lock_clocks.self\000\000other\000Bus cycles when a LOCK signal is asserted\000event=0x63,period=200000,umask=0x40\000\00000\000\000 */
{ 568279 }, /* bus_request_outstanding.all_agents\000\000other\000Outstanding cacheable data read bus requests duration\000event=0x60,period=200000,umask=0xe0\000\00000\000\000 */
{ 568416 }, /* bus_request_outstanding.self\000\000other\000Outstanding cacheable data read bus requests duration\000event=0x60,period=200000,umask=0x40\000\00000\000\000 */
{ 568547 }, /* bus_trans_any.all_agents\000\000other\000All bus transactions\000event=0x70,period=200000,umask=0xe0\000\00000\000\000 */
{ 568641 }, /* bus_trans_any.self\000\000other\000All bus transactions\000event=0x70,period=200000,umask=0x40\000\00000\000\000 */
{ 568729 }, /* bus_trans_brd.all_agents\000\000other\000Burst read bus transactions\000event=0x65,period=200000,umask=0xe0\000\00000\000\000 */
{ 568830 }, /* bus_trans_brd.self\000\000other\000Burst read bus transactions\000event=0x65,period=200000,umask=0x40\000\00000\000\000 */
{ 568925 }, /* bus_trans_burst.all_agents\000\000other\000Burst (full cache-line) bus transactions\000event=0x6e,period=200000,umask=0xe0\000\00000\000\000 */
{ 569041 }, /* bus_trans_burst.self\000\000other\000Burst (full cache-line) bus transactions\000event=0x6e,period=200000,umask=0x40\000\00000\000\000 */
{ 569151 }, /* bus_trans_def.all_agents\000\000other\000Deferred bus transactions\000event=0x6d,period=200000,umask=0xe0\000\00000\000\000 */
{ 569250 }, /* bus_trans_def.self\000\000other\000Deferred bus transactions\000event=0x6d,period=200000,umask=0x40\000\00000\000\000 */
{ 569343 }, /* bus_trans_ifetch.all_agents\000\000other\000Instruction-fetch bus transactions\000event=0x68,period=200000,umask=0xe0\000\00000\000\000 */
{ 569454 }, /* bus_trans_ifetch.self\000\000other\000Instruction-fetch bus transactions\000event=0x68,period=200000,umask=0x40\000\00000\000\000 */
{ 569559 }, /* bus_trans_inval.all_agents\000\000other\000Invalidate bus transactions\000event=0x69,period=200000,umask=0xe0\000\00000\000\000 */
{ 569662 }, /* bus_trans_inval.self\000\000other\000Invalidate bus transactions\000event=0x69,period=200000,umask=0x40\000\00000\000\000 */
{ 569759 }, /* bus_trans_io.all_agents\000\000other\000IO bus transactions\000event=0x6c,period=200000,umask=0xe0\000\00000\000\000 */
{ 569851 }, /* bus_trans_io.self\000\000other\000IO bus transactions\000event=0x6c,period=200000,umask=0x40\000\00000\000\000 */
{ 569937 }, /* bus_trans_mem.all_agents\000\000other\000Memory bus transactions\000event=0x6f,period=200000,umask=0xe0\000\00000\000\000 */
{ 570034 }, /* bus_trans_mem.self\000\000other\000Memory bus transactions\000event=0x6f,period=200000,umask=0x40\000\00000\000\000 */
{ 570125 }, /* bus_trans_p.all_agents\000\000other\000Partial bus transactions\000event=0x6b,period=200000,umask=0xe0\000\00000\000\000 */
{ 570221 }, /* bus_trans_p.self\000\000other\000Partial bus transactions\000event=0x6b,period=200000,umask=0x40\000\00000\000\000 */
{ 570311 }, /* bus_trans_pwr.all_agents\000\000other\000Partial write bus transaction\000event=0x6a,period=200000,umask=0xe0\000\00000\000\000 */
{ 570414 }, /* bus_trans_pwr.self\000\000other\000Partial write bus transaction\000event=0x6a,period=200000,umask=0x40\000\00000\000\000 */
{ 570511 }, /* bus_trans_rfo.all_agents\000\000other\000RFO bus transactions\000event=0x66,period=200000,umask=0xe0\000\00000\000\000 */
{ 570605 }, /* bus_trans_rfo.self\000\000other\000RFO bus transactions\000event=0x66,period=200000,umask=0x40\000\00000\000\000 */
{ 570693 }, /* bus_trans_wb.all_agents\000\000other\000Explicit writeback bus transactions\000event=0x67,period=200000,umask=0xe0\000\00000\000\000 */
{ 570801 }, /* bus_trans_wb.self\000\000other\000Explicit writeback bus transactions\000event=0x67,period=200000,umask=0x40\000\00000\000\000 */
{ 570903 }, /* busq_empty.self\000\000other\000Bus queue is empty\000event=0x7d,period=200000,umask=0x40\000\00000\000\000 */
{ 762087 }, /* cycles_int_masked.cycles_int_masked\000\000other\000Cycles during which interrupts are disabled\000event=0xc6,period=2000000,umask=0x1\000\00000\000\000 */
{ 762215 }, /* cycles_int_masked.cycles_int_pending_and_masked\000\000other\000Cycles during which interrupts are pending and disabled\000event=0xc6,period=2000000,umask=0x2\000\00000\000\000 */
{ 778587 }, /* dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\00000\000\000 */
{ 831500 }, /* eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000\000\00000\000\000 */
{ 849387 }, /* ext_snoop.all_agents.any\000\000other\000External snoops\000event=0x77,period=200000,umask=0x2b\000\00000\000\000 */
{ 849476 }, /* ext_snoop.all_agents.clean\000\000other\000External snoops\000event=0x77,period=200000,umask=0x21\000\00000\000\000 */
{ 849567 }, /* ext_snoop.all_agents.hit\000\000other\000External snoops\000event=0x77,period=200000,umask=0x22\000\00000\000\000 */
{ 849656 }, /* ext_snoop.all_agents.hitm\000\000other\000External snoops\000event=0x77,period=200000,umask=0x28\000\00000\000\000 */
{ 849746 }, /* ext_snoop.this_agent.any\000\000other\000External snoops\000event=0x77,period=200000,umask=0xb\000\00000\000\000 */
{ 849834 }, /* ext_snoop.this_agent.clean\000\000other\000External snoops\000event=0x77,period=200000,umask=0x1\000\00000\000\000 */
{ 849924 }, /* ext_snoop.this_agent.hit\000\000other\000External snoops\000event=0x77,period=200000,umask=0x2\000\00000\000\000 */
{ 850012 }, /* ext_snoop.this_agent.hitm\000\000other\000External snoops\000event=0x77,period=200000,umask=0x8\000\00000\000\000 */
{ 976697 }, /* hw_int_rcv\000\000other\000Hardware interrupts received\000event=0xc8,period=200000\000\00000\000\000 */
{ 2521354 }, /* segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\00000\000\000 */
{ 2529027 }, /* snoop_stall_drv.all_agents\000\000other\000Bus stalled for snoops\000event=0x7e,period=200000,umask=0xe0\000\00000\000\000 */
{ 2529125 }, /* snoop_stall_drv.self\000\000other\000Bus stalled for snoops\000event=0x7e,period=200000,umask=0x40\000\00000\000\000 */
{ 2540049 }, /* thermal_trip\000\000other\000Number of thermal trips\000event=0x3b,period=200000,umask=0xc0\000\00000\000\000 */
{ 480803 }, /* bogus_br\000\000pipeline\000Bogus branches\000event=0xe4,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 501394 }, /* br_inst_retired.any\000\000pipeline\000Retired branch instructions\000event=0xc4,period=2000000\000\00000\000\000 */
{ 501294 }, /* br_inst_retired.any1\000\000pipeline\000Retired branch instructions\000event=0xc4,period=2000000,umask=0xf\000\00000\000\000 */
{ 514231 }, /* br_inst_retired.mispred\000\000pipeline\000Retired mispredicted branch instructions (precise event) (Precise event)\000event=0xc5,period=200000\000\00000\000\000 */
{ 514368 }, /* br_inst_retired.mispred_not_taken\000\000pipeline\000Retired branch instructions that were mispredicted not-taken\000event=0xc4,period=200000,umask=0x2\000\00000\000\000 */
{ 514513 }, /* br_inst_retired.mispred_taken\000\000pipeline\000Retired branch instructions that were mispredicted taken\000event=0xc4,period=200000,umask=0x8\000\00000\000\000 */
{ 522727 }, /* br_inst_retired.pred_not_taken\000\000pipeline\000Retired branch instructions that were predicted not-taken\000event=0xc4,period=2000000,umask=0x1\000\00000\000\000 */
{ 522867 }, /* br_inst_retired.pred_taken\000\000pipeline\000Retired branch instructions that were predicted taken\000event=0xc4,period=2000000,umask=0x4\000\00000\000\000 */
{ 525815 }, /* br_inst_retired.taken\000\000pipeline\000Retired taken branch instructions\000event=0xc4,period=2000000,umask=0xc\000\00000\000\000 */
{ 527785 }, /* br_inst_type_retired.cond\000\000pipeline\000All macro conditional branch instructions\000event=0x88,period=2000000,umask=0x1\000\00000\000\000 */
{ 527904 }, /* br_inst_type_retired.cond_taken\000\000pipeline\000Only taken macro conditional branch instructions\000event=0x88,period=2000000,umask=0x41\000\00000\000\000 */
{ 528037 }, /* br_inst_type_retired.dir_call\000\000pipeline\000All non-indirect calls\000event=0x88,period=2000000,umask=0x10\000\00000\000\000 */
{ 528142 }, /* br_inst_type_retired.ind\000\000pipeline\000All indirect branches that are not calls\000event=0x88,period=2000000,umask=0x4\000\00000\000\000 */
{ 528259 }, /* br_inst_type_retired.ind_call\000\000pipeline\000All indirect calls, including both register and memory indirect\000event=0x88,period=2000000,umask=0x20\000\00000\000\000 */
{ 528405 }, /* br_inst_type_retired.ret\000\000pipeline\000All indirect branches that have a return mnemonic\000event=0x88,period=2000000,umask=0x8\000\00000\000\000 */
{ 528531 }, /* br_inst_type_retired.uncond\000\000pipeline\000All macro unconditional branch instructions, excluding calls and indirects\000event=0x88,period=2000000,umask=0x2\000\00000\000\000 */
{ 564918 }, /* br_missp_type_retired.cond\000\000pipeline\000Mispredicted cond branch instructions retired\000event=0x89,period=200000,umask=0x1\000\00000\000\000 */
{ 565041 }, /* br_missp_type_retired.cond_taken\000\000pipeline\000Mispredicted and taken cond branch instructions retired\000event=0x89,period=200000,umask=0x11\000\00000\000\000 */
{ 565181 }, /* br_missp_type_retired.ind\000\000pipeline\000Mispredicted ind branches that are not calls\000event=0x89,period=200000,umask=0x2\000\00000\000\000 */
{ 565302 }, /* br_missp_type_retired.ind_call\000\000pipeline\000Mispredicted indirect calls, including both register and memory indirect\000event=0x89,period=200000,umask=0x8\000\00000\000\000 */
{ 565456 }, /* br_missp_type_retired.return\000\000pipeline\000Mispredicted return branches\000event=0x89,period=200000,umask=0x4\000\00000\000\000 */
{ 609562 }, /* cpu_clk_unhalted.bus\000\000pipeline\000Bus cycles when core is not halted\000event=0x3c,period=200000,umask=0x1\000\00000\000\000 */
{ 612341 }, /* cpu_clk_unhalted.core\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000\000 */
{ 614730 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000000\000\00000\000\000 */
{ 620801 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 467277 }, /* cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 778720 }, /* div.ar\000\000pipeline\000Divide operations retired\000event=0x13,period=2000000,umask=0x81\000\00000\000\000 */
{ 778805 }, /* div.s\000\000pipeline\000Divide operations executed\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1049836 }, /* inst_retired.any\000\000pipeline\000Instructions retired\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053692 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (precise event) (Must be precise)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1300409 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200000,umask=0x1\000\00000\000\000 */
{ 1436250 }, /* mul.ar\000\000pipeline\000Multiply operations retired\000event=0x12,period=2000000,umask=0x81\000\00000\000\000 */
{ 1436337 }, /* mul.s\000\000pipeline\000Multiply operations executed\000event=0x12,period=2000000,umask=0x1\000\00000\000\000 */
{ 2488004 }, /* reissue.any\000\000pipeline\000Micro-op reissues for any cause\000event=0x3,period=200000,umask=0x7f\000\00000\000\000 */
{ 2487891 }, /* reissue.any.ar\000\000pipeline\000Micro-op reissues for any cause (At Retirement)\000event=0x3,period=200000,umask=0xff\000\00000\000\000 */
{ 2488233 }, /* reissue.overlap_store\000\000pipeline\000Micro-op reissues on a store-load collision\000event=0x3,period=200000,umask=0x1\000\00000\000\000 */
{ 2488098 }, /* reissue.overlap_store.ar\000\000pipeline\000Micro-op reissues on a store-load collision (At Retirement)\000event=0x3,period=200000,umask=0x81\000\00000\000\000 */
{ 2501913 }, /* resource_stalls.div_busy\000\000pipeline\000Cycles issue is stalled due to div busy\000event=0xdc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2536958 }, /* store_forwards.any\000\000pipeline\000All store forwards\000event=0x2,period=200000,umask=0x83\000\00000\000\000 */
{ 2537046 }, /* store_forwards.good\000\000pipeline\000Good store forwards\000event=0x2,period=200000,umask=0x81\000\00000\000\000 */
{ 6227688 }, /* uops_retired.any\000\000pipeline\000Micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000 */
{ 6239221 }, /* uops_retired.stalled_cycles\000\000pipeline\000Cycles no micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000 */
{ 6239505 }, /* uops_retired.stalls\000\000pipeline\000Periods no micro-ops retired\000event=0xc2,period=2000000,umask=0x10\000\00000\000\000 */
{ 762367 }, /* data_tlb_misses.dtlb_miss\000\000virtual memory\000Memory accesses that missed the DTLB\000event=0x8,period=200000,umask=0x7\000\00000\000\000 */
{ 762485 }, /* data_tlb_misses.dtlb_miss_ld\000\000virtual memory\000DTLB misses due to load operations\000event=0x8,period=200000,umask=0x5\000\00000\000\000 */
{ 762604 }, /* data_tlb_misses.dtlb_miss_st\000\000virtual memory\000DTLB misses due to store operations\000event=0x8,period=200000,umask=0x6\000\00000\000\000 */
{ 762724 }, /* data_tlb_misses.l0_dtlb_miss_ld\000\000virtual memory\000L0 DTLB misses due to load operations\000event=0x8,period=200000,umask=0x9\000\00000\000\000 */
{ 762849 }, /* data_tlb_misses.l0_dtlb_miss_st\000\000virtual memory\000L0 DTLB misses due to store operations\000event=0x8,period=200000,umask=0xa\000\00000\000\000 */
{ 1077697 }, /* itlb.flush\000\000virtual memory\000ITLB flushes\000event=0x82,period=200000,umask=0x4\000\00000\000\000 */
{ 1077777 }, /* itlb.hit\000\000virtual memory\000ITLB hits\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1079465 }, /* itlb.misses\000\000virtual memory\000ITLB misses (Must be precise)\000event=0x82,period=200000,umask=0x2\000\00000\000\000 */
{ 1332089 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (precise event) (Precise event)\000event=0xcb,period=200000,umask=0x4\000\00000\000\000 */
{ 2472408 }, /* page_walks.cycles\000\000virtual memory\000Duration of page-walks in core cycles\000event=0xc,period=2000000,umask=0x3\000\00000\000\000 */
{ 2473301 }, /* page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side only page walks\000event=0xc,period=2000000,umask=0x1\000\00000\000\000 */
{ 2474446 }, /* page_walks.d_side_walks\000\000virtual memory\000Number of D-side only page walks\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
{ 2474889 }, /* page_walks.i_side_cycles\000\000virtual memory\000Duration of I-Side page walks\000event=0xc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2475981 }, /* page_walks.i_side_walks\000\000virtual memory\000Number of I-Side page walks\000event=0xc,period=200000,umask=0x2\000\00000\000\000 */
{ 2476500 }, /* page_walks.walks\000\000virtual memory\000Number of page-walks executed\000event=0xc,period=200000,umask=0x3\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__broadwell[] = {
{ 1101501 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1110022 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand; from the demand Hit FB, if it is allocated by hardware or software prefetch.\nNote: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112707 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1123947 }, /* l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000This event counts the number of WB requests that hit L2 cache\000 */
{ 1129220 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1129900 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000This event counts the number of L2 cache lines in the Exclusive state filling the L2. Counting does not cover rejects\000 */
{ 1130448 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000This event counts the number of L2 cache lines in the Invalidate state filling the L2. Counting does not cover rejects\000 */
{ 1130896 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000This event counts the number of L2 cache lines in the Shared state filling the L2. Counting does not cover rejects\000 */
{ 1132063 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000\000 */
{ 1157444 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000This event counts the total number of L2 code requests\000 */
{ 1158790 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000This event counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159885 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000\000 */
{ 1160630 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000\000 */
{ 1161474 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000This event counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162439 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000This event counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163612 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000\000 */
{ 1164549 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166774 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000This event counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1168158 }, /* l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that hit L2 cache. L3 prefetch new types\000 */
{ 1168537 }, /* l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that miss L2 cache\000 */
{ 1169474 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000\000 */
{ 1172732 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000\000 */
{ 1174367 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000\000 */
{ 1175046 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000\000 */
{ 1179588 }, /* l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000This event counts L2 or L3 HW prefetches that access L2 cache including rejects\000 */
{ 1180048 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000This event counts transactions that access the L2 pipe including snoops, pagewalks, and so on\000 */
{ 1180627 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000This event counts the number of L2 cache accesses when fetching instructions\000 */
{ 1181249 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000This event counts Demand Data Read requests that access L2 cache, including rejects\000 */
{ 1181703 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000This event counts L1D writebacks that access L2 cache\000 */
{ 1182096 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000This event counts L2 fill requests that access L2 cache\000 */
{ 1182628 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000This event counts L2 writebacks that access L2 cache\000 */
{ 1183167 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000This event counts Read for Ownership (RFO) requests that access L2 cache\000 */
{ 1245649 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000This event counts the number of cycles when the L1D is locked. It is a superset of the 0x1 mask (BUS_LOCK_CLOCKS.BUS_LOCK_DURATION)\000 */
{ 1247290 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts core-originated cacheable demand requests that miss the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1251000 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts core-originated cacheable demand requests that refer to the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1341691 }, /* mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops which data sources were L3 hit and a cross-core snoop hit in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1342388 }, /* mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops which data sources were HitM responses from a core on same socket (shared L3)  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343042 }, /* mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000This event counts retired load uops which data sources were L3 Hit and a cross-core snoop missed in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343756 }, /* mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1344433 }, /* mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uop whose Data Source was: local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000 */
{ 1353644 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000This event counts retired load uops which data sources were load uops missed L1 but hit a fill buffer due to a preceding miss to the same cache line with the data not ready.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load  Supports address when precise (Precise event)\000 */
{ 1356844 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000This event counts retired load uops which data sources were hits in the nearest-level (L1) cache.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load. This event also counts SW prefetches independent of the actual data source  Supports address when precise (Precise event)\000 */
{ 1358647 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were misses in the nearest-level (L1) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1360141 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000This event counts retired load uops which data sources were hits in the mid-level (L2) cache  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1361888 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000This event counts retired load uops which data sources were misses in the mid-level (L2) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1363119 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops which data sources were data hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1364330 }, /* mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: BDM100, BDE70 (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1390113 }, /* mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1392489 }, /* mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise (Precise event)\000 */
{ 1415479 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000This event counts load uops with locked access retired to the architected path  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1417829 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1419597 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1421539 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000This event counts load uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1422607 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000This event counts store uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1745359 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000This event counts the demand and prefetch data reads. All Core Data Reads include cacheable Demands and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746038 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000This event counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, and so on\000 */
{ 1748542 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000This event counts both cacheable and non-cacheable code read requests\000 */
{ 1750433 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000This event counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751556 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000This event counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753800 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000This event counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.\nNote: Writeback pending FIFO has six entries\000 */
{ 1754992 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x8\000\00000\000This event counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1757948 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1762576 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)  Spec update: BDM76\000 */
{ 1766481 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1770828 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,period=2000003,umask=0x2\000\00000\000This event counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1773190 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,period=2000003,umask=0x1\000\00000\000This event counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.\nNote: A prefetch promoted to Demand is counted from the promotion point  Spec update: BDM76\000 */
{ 1775673 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1776605 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 2460294 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000 */
{ 1784348 }, /* offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10091\000\00000\000\000 */
{ 1785209 }, /* offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0091\000\00000\000\000 */
{ 1787816 }, /* offcore_response.all_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000 */
{ 1788374 }, /* offcore_response.all_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000 */
{ 1788533 }, /* offcore_response.all_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0091\000\00000\000\000 */
{ 1789052 }, /* offcore_response.all_data_rd.l3_hit.snoop_none\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0091\000\00000\000\000 */
{ 1789405 }, /* offcore_response.all_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0091\000\00000\000\000 */
{ 1809561 }, /* offcore_response.all_data_rd.supplier_none.any_snoop\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020091\000\00000\000\000 */
{ 1810839 }, /* offcore_response.all_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020091\000\00000\000\000 */
{ 1811010 }, /* offcore_response.all_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020091\000\00000\000\000 */
{ 1811176 }, /* offcore_response.all_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020091\000\00000\000\000 */
{ 1811723 }, /* offcore_response.all_data_rd.supplier_none.snoop_none\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020091\000\00000\000\000 */
{ 1812097 }, /* offcore_response.all_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020091\000\00000\000\000 */
{ 1813026 }, /* offcore_response.all_pf_code_rd.any_response\000\000cache\000Counts all prefetch code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10240\000\00000\000\000 */
{ 1813192 }, /* offcore_response.all_pf_code_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0240\000\00000\000\000 */
{ 1813344 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0240\000\00000\000\000 */
{ 1813502 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0240\000\00000\000\000 */
{ 1813655 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0240\000\00000\000\000 */
{ 1813965 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0240\000\00000\000\000 */
{ 1814116 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0240\000\00000\000\000 */
{ 1817512 }, /* offcore_response.all_pf_code_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020240\000\00000\000\000 */
{ 1817671 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020240\000\00000\000\000 */
{ 1817836 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020240\000\00000\000\000 */
{ 1817996 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020240\000\00000\000\000 */
{ 1818320 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020240\000\00000\000\000 */
{ 1818478 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020240\000\00000\000\000 */
{ 1818643 }, /* offcore_response.all_pf_data_rd.any_response\000\000cache\000Counts all prefetch data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10090\000\00000\000\000 */
{ 1819340 }, /* offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0090\000\00000\000\000 */
{ 1821413 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0090\000\00000\000\000 */
{ 1821977 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0090\000\00000\000\000 */
{ 1822130 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0090\000\00000\000\000 */
{ 1822643 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0090\000\00000\000\000 */
{ 1822996 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0090\000\00000\000\000 */
{ 1840649 }, /* offcore_response.all_pf_data_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020090\000\00000\000\000 */
{ 1841951 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020090\000\00000\000\000 */
{ 1842116 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020090\000\00000\000\000 */
{ 1842276 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020090\000\00000\000\000 */
{ 1842817 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020090\000\00000\000\000 */
{ 1843191 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020090\000\00000\000\000 */
{ 1843356 }, /* offcore_response.all_pf_rfo.any_response\000\000cache\000Counts prefetch RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000 */
{ 1844003 }, /* offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000 */
{ 1845980 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000 */
{ 1846514 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_hitm\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000 */
{ 1846653 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00000\000\000 */
{ 1847130 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_none\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00000\000\000 */
{ 1847461 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000 */
{ 1863963 }, /* offcore_response.all_pf_rfo.supplier_none.any_snoop\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00000\000\000 */
{ 1865211 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00000\000\000 */
{ 1865362 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_hitm\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00000\000\000 */
{ 1865508 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_miss\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00000\000\000 */
{ 1866013 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_none\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00000\000\000 */
{ 1866365 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00000\000\000 */
{ 1889466 }, /* offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000 */
{ 1890440 }, /* offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000 */
{ 1892947 }, /* offcore_response.all_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1893479 }, /* offcore_response.all_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 1893628 }, /* offcore_response.all_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00000\000\000 */
{ 1894119 }, /* offcore_response.all_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00000\000\000 */
{ 1894454 }, /* offcore_response.all_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000 */
{ 1912306 }, /* offcore_response.all_rfo.supplier_none.any_snoop\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00000\000\000 */
{ 1913534 }, /* offcore_response.all_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00000\000\000 */
{ 1913695 }, /* offcore_response.all_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00000\000\000 */
{ 1913851 }, /* offcore_response.all_rfo.supplier_none.snoop_miss\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00000\000\000 */
{ 1914370 }, /* offcore_response.all_rfo.supplier_none.snoop_none\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00000\000\000 */
{ 1914726 }, /* offcore_response.all_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00000\000\000 */
{ 1999950 }, /* offcore_response.corewb.any_response\000\000cache\000Counts writebacks (modified to exclusive) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 2004941 }, /* offcore_response.corewb.l3_hit.any_snoop\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0008\000\00000\000\000 */
{ 2005096 }, /* offcore_response.corewb.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0008\000\00000\000\000 */
{ 2005257 }, /* offcore_response.corewb.l3_hit.snoop_hitm\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0008\000\00000\000\000 */
{ 2005413 }, /* offcore_response.corewb.l3_hit.snoop_miss\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0008\000\00000\000\000 */
{ 2005729 }, /* offcore_response.corewb.l3_hit.snoop_none\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0008\000\00000\000\000 */
{ 2005883 }, /* offcore_response.corewb.l3_hit.snoop_not_needed\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0008\000\00000\000\000 */
{ 2011811 }, /* offcore_response.corewb.supplier_none.any_snoop\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020008\000\00000\000\000 */
{ 2011973 }, /* offcore_response.corewb.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020008\000\00000\000\000 */
{ 2012141 }, /* offcore_response.corewb.supplier_none.snoop_hitm\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020008\000\00000\000\000 */
{ 2012304 }, /* offcore_response.corewb.supplier_none.snoop_miss\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020008\000\00000\000\000 */
{ 2012634 }, /* offcore_response.corewb.supplier_none.snoop_none\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020008\000\00000\000\000 */
{ 2012795 }, /* offcore_response.corewb.supplier_none.snoop_not_needed\000\000cache\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020008\000\00000\000\000 */
{ 2025436 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 2035144 }, /* offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000 */
{ 2038039 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 2038752 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 2039053 }, /* offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 2039867 }, /* offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00000\000\000 */
{ 2040374 }, /* offcore_response.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 2069039 }, /* offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00000\000\000 */
{ 2070496 }, /* offcore_response.demand_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00000\000\000 */
{ 2070659 }, /* offcore_response.demand_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00000\000\000 */
{ 2070817 }, /* offcore_response.demand_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00000\000\000 */
{ 2071354 }, /* offcore_response.demand_code_rd.supplier_none.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00000\000\000 */
{ 2071726 }, /* offcore_response.demand_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00000\000\000 */
{ 2080490 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 2089062 }, /* offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 2091925 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 2092630 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 2092923 }, /* offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 2093721 }, /* offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00000\000\000 */
{ 2094220 }, /* offcore_response.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 2126921 }, /* offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00000\000\000 */
{ 2128370 }, /* offcore_response.demand_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00000\000\000 */
{ 2128529 }, /* offcore_response.demand_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00000\000\000 */
{ 2128683 }, /* offcore_response.demand_data_rd.supplier_none.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00000\000\000 */
{ 2129212 }, /* offcore_response.demand_data_rd.supplier_none.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00000\000\000 */
{ 2129580 }, /* offcore_response.demand_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00000\000\000 */
{ 2137583 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand data writes (RFOs) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 2147840 }, /* offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 2150727 }, /* offcore_response.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 2151432 }, /* offcore_response.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2151741 }, /* offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 2152563 }, /* offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00000\000\000 */
{ 2153070 }, /* offcore_response.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 2195738 }, /* offcore_response.other.any_response\000\000cache\000Counts any other requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 2196654 }, /* offcore_response.other.l3_hit.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00000\000\000 */
{ 2198057 }, /* offcore_response.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000 */
{ 2198541 }, /* offcore_response.other.l3_hit.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00000\000\000 */
{ 2198818 }, /* offcore_response.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000 */
{ 2199566 }, /* offcore_response.other.l3_hit.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00000\000\000 */
{ 2200031 }, /* offcore_response.other.l3_hit.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000 */
{ 2223500 }, /* offcore_response.other.supplier_none.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00000\000\000 */
{ 2224843 }, /* offcore_response.other.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00000\000\000 */
{ 2224994 }, /* offcore_response.other.supplier_none.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00000\000\000 */
{ 2225140 }, /* offcore_response.other.supplier_none.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00000\000\000 */
{ 2225635 }, /* offcore_response.other.supplier_none.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00000\000\000 */
{ 2225977 }, /* offcore_response.other.supplier_none.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00000\000\000 */
{ 2290044 }, /* offcore_response.pf_l2_code_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000 */
{ 2293899 }, /* offcore_response.pf_l2_code_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000 */
{ 2294080 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0040\000\00000\000\000 */
{ 2294267 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0040\000\00000\000\000 */
{ 2294449 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0040\000\00000\000\000 */
{ 2294817 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0040\000\00000\000\000 */
{ 2294997 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0040\000\00000\000\000 */
{ 2300450 }, /* offcore_response.pf_l2_code_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020040\000\00000\000\000 */
{ 2300638 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020040\000\00000\000\000 */
{ 2300832 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020040\000\00000\000\000 */
{ 2301021 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020040\000\00000\000\000 */
{ 2301403 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020040\000\00000\000\000 */
{ 2301590 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020040\000\00000\000\000 */
{ 2302250 }, /* offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 2308068 }, /* offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000 */
{ 2310207 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 2310786 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 2310958 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 2311507 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00000\000\000 */
{ 2311877 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 2332200 }, /* offcore_response.pf_l2_data_rd.supplier_none.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00000\000\000 */
{ 2333511 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00000\000\000 */
{ 2333695 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00000\000\000 */
{ 2333874 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00000\000\000 */
{ 2334451 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00000\000\000 */
{ 2334842 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00000\000\000 */
{ 2335232 }, /* offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 2344666 }, /* offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000 */
{ 2346741 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 2347298 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 2347464 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 2347993 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00000\000\000 */
{ 2348349 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 2367400 }, /* offcore_response.pf_l2_rfo.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00000\000\000 */
{ 2368665 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00000\000\000 */
{ 2368843 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00000\000\000 */
{ 2369016 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00000\000\000 */
{ 2369573 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00000\000\000 */
{ 2369950 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00000\000\000 */
{ 2370338 }, /* offcore_response.pf_l3_code_rd.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10200\000\00000\000\000 */
{ 2370723 }, /* offcore_response.pf_l3_code_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000 */
{ 2370900 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0200\000\00000\000\000 */
{ 2371083 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0200\000\00000\000\000 */
{ 2371261 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0200\000\00000\000\000 */
{ 2371621 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0200\000\00000\000\000 */
{ 2371797 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0200\000\00000\000\000 */
{ 2374251 }, /* offcore_response.pf_l3_code_rd.supplier_none.any_snoop\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020200\000\00000\000\000 */
{ 2374435 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020200\000\00000\000\000 */
{ 2374625 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020200\000\00000\000\000 */
{ 2374810 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020200\000\00000\000\000 */
{ 2375184 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_none\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020200\000\00000\000\000 */
{ 2375367 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020200\000\00000\000\000 */
{ 2375557 }, /* offcore_response.pf_l3_data_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000 */
{ 2376537 }, /* offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000 */
{ 2378716 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000 */
{ 2379305 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000 */
{ 2379487 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00000\000\000 */
{ 2380056 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00000\000\000 */
{ 2380436 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000 */
{ 2396870 }, /* offcore_response.pf_l3_data_rd.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00000\000\000 */
{ 2398191 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00000\000\000 */
{ 2398385 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00000\000\000 */
{ 2398574 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00000\000\000 */
{ 2399171 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00000\000\000 */
{ 2399572 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00000\000\000 */
{ 2399766 }, /* offcore_response.pf_l3_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000 */
{ 2400698 }, /* offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 2402797 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000 */
{ 2403360 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000 */
{ 2403532 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00000\000\000 */
{ 2404073 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00000\000\000 */
{ 2404435 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000 */
{ 2420231 }, /* offcore_response.pf_l3_rfo.supplier_none.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00000\000\000 */
{ 2421502 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00000\000\000 */
{ 2421686 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00000\000\000 */
{ 2421865 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00000\000\000 */
{ 2422434 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00000\000\000 */
{ 2422817 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00000\000\000 */
{ 2531841 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000This event counts the number of split locks in the super queue\000 */
{ 856247 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 859272 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 864472 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 868573 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 8 calculations per element\000event=0xc7,period=2000003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 873279 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 884623 }, /* fp_arith_inst_retired.double\000\000floating point\000Number of SSE/AVX computational double precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000006,umask=0x15\000\00000\000\000 */
{ 885097 }, /* fp_arith_inst_retired.packed\000\000floating point\000Number of SSE/AVX computational packed floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* packed double and single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000004,umask=0x3c\000\00000\000\000 */
{ 888236 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below. Each count represents 1 computation operation.   Applies to SSE* and AVX* scalar double and single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891938 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 895654 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 897672 }, /* fp_arith_inst_retired.single\000\000floating point\000Number of SSE/AVX computational single precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000005,umask=0x2a\000\00000\000\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 902217 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000This event counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 903279 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000This event counts any input SSE* FP assist - invalid operation, denormal operand, dividing by zero, SNaN operand. Counting includes only cases involving penalties that required micro-code assist intervention\000 */
{ 903905 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000This event counts the number of SSE* floating point (FP) micro-code assist (numeric overflow/underflow) when the output value (destination register) is invalid. Counting covers only cases involving penalties that require micro-code assist intervention\000 */
{ 904567 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000This event counts x87 floating point (FP) micro-code assist (invalid operation, denormal operand, SNaN operand) when the input value (one of the source operands to an FP instruction) is invalid\000 */
{ 905158 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000This event counts the number of x87 floating point (FP) micro-code assist (numeric overflow/underflow, inexact result) when the output value (destination register) is invalid\000 */
{ 1433783 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000 */
{ 1434178 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000 */
{ 2463149 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x8\000\00000\000This event counts the number of transitions from AVX-256 to legacy SSE when penalty is applicable  Spec update: BDM30\000 */
{ 2463904 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x10\000\00000\000This event counts the number of transitions from legacy SSE to AVX-256 when penalty is applicable  Spec update: BDM30\000 */
{ 6177315 }, /* uop_dispatches_cancelled.simd_prf\000\000floating point\000Micro-op dispatches cancelled due to insufficient SIMD physical register file read ports\000event=0xa0,period=2000003,umask=0x3\000\00000\000This event counts the number of micro-operations cancelled after they were dispatched from the scheduler to the execution units when the total number of physical register read ports across all dispatch ports exceeds the read bandwidth of the physical register file.  The SIMD_PRF subevent applies to the following instructions: VDPPS, DPPS, VPCMPESTRI, PCMPESTRI, VPCMPESTRM, PCMPESTRM, VFMADD*, VFMADDSUB*, VFMSUB*, VMSUBADD*, VFNMADD*, VFNMSUB*.  See the Broadwell Optimization Guide for more information\000 */
{ 477106 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000 */
{ 784188 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. \nMM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.\nPenalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 986506 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000This event counts the number of both cacheable and noncacheable Instruction Cache, Streaming Buffer and Victim Cache Reads including UC fetches\000 */
{ 987766 }, /* icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000This event counts cycles during which the demand fetch waits for data (wfdM104H) from L2 or iSB (opportunistic hit)\000 */
{ 990635 }, /* icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes UC accesses\000 */
{ 998477 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 999553 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1000587 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001838 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles  uops were delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002978 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1006821 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1007899 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000This counts the number of cycles that the instruction decoder queue is empty and can indicate that the application may be bound in the front end.  It does not determine whether there are uops being delivered to the Alloc stage since uops can be delivered by bypass skipping the Instruction Decode Queue (IDQ) when it is empty\000 */
{ 1008613 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1009676 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ\000 */
{ 1012842 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1015992 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1018545 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000This event counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1019936 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000This event counts the number of deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1021234 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000This event counts the number of uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1022867 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000This event counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026055 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts the total number of uops delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1032672 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when:\n a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread;\n b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions); \n c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034662 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038680 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when less than 1 uop is  delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >=3\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 970645 }, /* hle_retired.aborted\000\000memory\000Number of times HLE abort was triggered (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 972603 }, /* hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000Number of times an HLE abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 973088 }, /* hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an HLE abort\000 */
{ 973430 }, /* hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an HLE abort\000 */
{ 973961 }, /* hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times HLE caused a fault\000 */
{ 974144 }, /* hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times HLE aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 975396 }, /* hle_retired.commit\000\000memory\000Number of times HLE commit succeeded\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976477 }, /* hle_retired.start\000\000memory\000Number of times we entered an HLE region; does not count nested transactions\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region\n does not count nested transactions\000 */
{ 1294861 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:\n1. memory disambiguation,\n2. external snoop, or\n3. cross SMT-HW-thread snoop (stores) hitting load buffer\000 */
{ 1369873 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1371816 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1373759 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1375705 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1377639 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads with latency value being above four  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1379577 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1381517 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1383441 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads with latency value being above eight  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1428587 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000This event counts speculative cache-line split load uops dispatched to the L1 cache\000 */
{ 1430771 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000This event counts speculative cache line split store-address (STA) uops dispatched to the L1 cache\000 */
{ 1788888 }, /* offcore_response.all_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0091\000\00000\000\000 */
{ 1797950 }, /* offcore_response.all_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000091\000\00000\000\000 */
{ 1798116 }, /* offcore_response.all_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000091\000\00000\000\000 */
{ 1798714 }, /* offcore_response.all_data_rd.l3_miss.snoop_none\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000091\000\00000\000\000 */
{ 1799072 }, /* offcore_response.all_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000091\000\00000\000\000 */
{ 1799238 }, /* offcore_response.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000091\000\00000\000\000 */
{ 1800577 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000091\000\00000\000\000 */
{ 1800754 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000091\000\00000\000\000 */
{ 1800926 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000091\000\00000\000\000 */
{ 1801800 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000091\000\00000\000\000 */
{ 1801976 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000091\000\00000\000\000 */
{ 1802367 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000091\000\00000\000\000 */
{ 1811552 }, /* offcore_response.all_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020091\000\00000\000\000 */
{ 1813807 }, /* offcore_response.all_pf_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0240\000\00000\000\000 */
{ 1814274 }, /* offcore_response.all_pf_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000240\000\00000\000\000 */
{ 1814434 }, /* offcore_response.all_pf_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000240\000\00000\000\000 */
{ 1814588 }, /* offcore_response.all_pf_code_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000240\000\00000\000\000 */
{ 1814741 }, /* offcore_response.all_pf_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000240\000\00000\000\000 */
{ 1814901 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000240\000\00000\000\000 */
{ 1815066 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000240\000\00000\000\000 */
{ 1815237 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000240\000\00000\000\000 */
{ 1815403 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000240\000\00000\000\000 */
{ 1815568 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000240\000\00000\000\000 */
{ 1815738 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000240\000\00000\000\000 */
{ 1815902 }, /* offcore_response.all_pf_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000240\000\00000\000\000 */
{ 1818155 }, /* offcore_response.all_pf_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020240\000\00000\000\000 */
{ 1822485 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0090\000\00000\000\000 */
{ 1831336 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000090\000\00000\000\000 */
{ 1831496 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000090\000\00000\000\000 */
{ 1832088 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000090\000\00000\000\000 */
{ 1832446 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000090\000\00000\000\000 */
{ 1832606 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000090\000\00000\000\000 */
{ 1833969 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000090\000\00000\000\000 */
{ 1834140 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000090\000\00000\000\000 */
{ 1834306 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000090\000\00000\000\000 */
{ 1835180 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000090\000\00000\000\000 */
{ 1835350 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000090\000\00000\000\000 */
{ 1835741 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000090\000\00000\000\000 */
{ 1842652 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020090\000\00000\000\000 */
{ 1846986 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0120\000\00000\000\000 */
{ 1855465 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00000\000\000 */
{ 1855611 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00000\000\000 */
{ 1856167 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_none\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00000\000\000 */
{ 1856503 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00000\000\000 */
{ 1856649 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00000\000\000 */
{ 1857958 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00000\000\000 */
{ 1858115 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00000\000\000 */
{ 1858267 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00000\000\000 */
{ 1859097 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000120\000\00000\000\000 */
{ 1859253 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00000\000\000 */
{ 1859622 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00000\000\000 */
{ 1865862 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020120\000\00000\000\000 */
{ 1893965 }, /* offcore_response.all_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0122\000\00000\000\000 */
{ 1902659 }, /* offcore_response.all_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00000\000\000 */
{ 1902815 }, /* offcore_response.all_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00000\000\000 */
{ 1903385 }, /* offcore_response.all_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00000\000\000 */
{ 1903725 }, /* offcore_response.all_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00000\000\000 */
{ 1903881 }, /* offcore_response.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00000\000\000 */
{ 1905170 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00000\000\000 */
{ 1905337 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00000\000\000 */
{ 1905499 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00000\000\000 */
{ 1906337 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000122\000\00000\000\000 */
{ 1906503 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00000\000\000 */
{ 1906876 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00000\000\000 */
{ 1914209 }, /* offcore_response.all_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all demand & prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020122\000\00000\000\000 */
{ 2005568 }, /* offcore_response.corewb.l3_hit.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0008\000\00000\000\000 */
{ 2006044 }, /* offcore_response.corewb.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000008\000\00000\000\000 */
{ 2006207 }, /* offcore_response.corewb.l3_miss.snoop_miss\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000008\000\00000\000\000 */
{ 2006364 }, /* offcore_response.corewb.l3_miss.snoop_none\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000008\000\00000\000\000 */
{ 2006520 }, /* offcore_response.corewb.l3_miss.snoop_not_needed\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000008\000\00000\000\000 */
{ 2006683 }, /* offcore_response.corewb.l3_miss_local_dram.any_snoop\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000008\000\00000\000\000 */
{ 2006851 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000008\000\00000\000\000 */
{ 2007025 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000008\000\00000\000\000 */
{ 2007194 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_miss\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000008\000\00000\000\000 */
{ 2007362 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000008\000\00000\000\000 */
{ 2007535 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_none\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000008\000\00000\000\000 */
{ 2007702 }, /* offcore_response.corewb.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000008\000\00000\000\000 */
{ 2012466 }, /* offcore_response.corewb.supplier_none.snoop_non_dram\000\000memory\000Counts writebacks (modified to exclusive)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020008\000\00000\000\000 */
{ 2039562 }, /* offcore_response.demand_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0004\000\00000\000\000 */
{ 2053069 }, /* offcore_response.demand_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00000\000\000 */
{ 2053538 }, /* offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00000\000\000 */
{ 2054435 }, /* offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00000\000\000 */
{ 2054942 }, /* offcore_response.demand_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00000\000\000 */
{ 2055406 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00000\000\000 */
{ 2056930 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00000\000\000 */
{ 2057099 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00000\000\000 */
{ 2057263 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00000\000\000 */
{ 2058133 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000004\000\00000\000\000 */
{ 2058301 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00000\000\000 */
{ 2058690 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000 */
{ 2071191 }, /* offcore_response.demand_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020004\000\00000\000\000 */
{ 2093424 }, /* offcore_response.demand_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0001\000\00000\000\000 */
{ 2106787 }, /* offcore_response.demand_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00000\000\000 */
{ 2107244 }, /* offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00000\000\000 */
{ 2108125 }, /* offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00000\000\000 */
{ 2108624 }, /* offcore_response.demand_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00000\000\000 */
{ 2109076 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00000\000\000 */
{ 2110592 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00000\000\000 */
{ 2110757 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00000\000\000 */
{ 2110917 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00000\000\000 */
{ 2111779 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000001\000\00000\000\000 */
{ 2111943 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00000\000\000 */
{ 2112328 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 2129053 }, /* offcore_response.demand_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020001\000\00000\000\000 */
{ 2152250 }, /* offcore_response.demand_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0002\000\00000\000\000 */
{ 2165613 }, /* offcore_response.demand_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00000\000\000 */
{ 2166094 }, /* offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00000\000\000 */
{ 2166999 }, /* offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00000\000\000 */
{ 2167506 }, /* offcore_response.demand_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00000\000\000 */
{ 2167982 }, /* offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00000\000\000 */
{ 2199285 }, /* offcore_response.other.l3_hit.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C8000\000\00000\000\000 */
{ 2210764 }, /* offcore_response.other.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00000\000\000 */
{ 2211197 }, /* offcore_response.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00000\000\000 */
{ 2211810 }, /* offcore_response.other.l3_miss.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00000\000\000 */
{ 2212275 }, /* offcore_response.other.l3_miss.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00000\000\000 */
{ 2212703 }, /* offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00000\000\000 */
{ 2214113 }, /* offcore_response.other.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00000\000\000 */
{ 2214270 }, /* offcore_response.other.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00000\000\000 */
{ 2214422 }, /* offcore_response.other.l3_miss_local_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00000\000\000 */
{ 2215013 }, /* offcore_response.other.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004008000\000\00000\000\000 */
{ 2215169 }, /* offcore_response.other.l3_miss_local_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00000\000\000 */
{ 2215528 }, /* offcore_response.other.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00000\000\000 */
{ 2225484 }, /* offcore_response.other.supplier_none.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000028000\000\00000\000\000 */
{ 2294630 }, /* offcore_response.pf_l2_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0040\000\00000\000\000 */
{ 2295385 }, /* offcore_response.pf_l2_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000040\000\00000\000\000 */
{ 2295574 }, /* offcore_response.pf_l2_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000040\000\00000\000\000 */
{ 2295757 }, /* offcore_response.pf_l2_code_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000040\000\00000\000\000 */
{ 2295939 }, /* offcore_response.pf_l2_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000040\000\00000\000\000 */
{ 2296128 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000040\000\00000\000\000 */
{ 2296322 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000040\000\00000\000\000 */
{ 2296522 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000040\000\00000\000\000 */
{ 2296717 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000040\000\00000\000\000 */
{ 2296911 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000040\000\00000\000\000 */
{ 2297110 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000040\000\00000\000\000 */
{ 2297303 }, /* offcore_response.pf_l2_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000040\000\00000\000\000 */
{ 2301209 }, /* offcore_response.pf_l2_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020040\000\00000\000\000 */
{ 2311330 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0010\000\00000\000\000 */
{ 2320414 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00000\000\000 */
{ 2320593 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00000\000\000 */
{ 2321221 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00000\000\000 */
{ 2321596 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00000\000\000 */
{ 2321775 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00000\000\000 */
{ 2323147 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00000\000\000 */
{ 2323337 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00000\000\000 */
{ 2323522 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00000\000\000 */
{ 2324430 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000010\000\00000\000\000 */
{ 2324619 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00000\000\000 */
{ 2325027 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00000\000\000 */
{ 2334267 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020010\000\00000\000\000 */
{ 2347822 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0020\000\00000\000\000 */
{ 2356576 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00000\000\000 */
{ 2356749 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00000\000\000 */
{ 2357357 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00000\000\000 */
{ 2357718 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00000\000\000 */
{ 2357891 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00000\000\000 */
{ 2359217 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00000\000\000 */
{ 2359401 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00000\000\000 */
{ 2359580 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00000\000\000 */
{ 2360460 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000020\000\00000\000\000 */
{ 2360643 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00000\000\000 */
{ 2361037 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00000\000\000 */
{ 2369395 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020020\000\00000\000\000 */
{ 2371438 }, /* offcore_response.pf_l3_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0200\000\00000\000\000 */
{ 2372177 }, /* offcore_response.pf_l3_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000200\000\00000\000\000 */
{ 2372362 }, /* offcore_response.pf_l3_code_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000200\000\00000\000\000 */
{ 2372541 }, /* offcore_response.pf_l3_code_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000200\000\00000\000\000 */
{ 2372719 }, /* offcore_response.pf_l3_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000200\000\00000\000\000 */
{ 2372904 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000200\000\00000\000\000 */
{ 2373094 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000200\000\00000\000\000 */
{ 2373290 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000200\000\00000\000\000 */
{ 2373481 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000200\000\00000\000\000 */
{ 2373671 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000200\000\00000\000\000 */
{ 2373866 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000200\000\00000\000\000 */
{ 2374055 }, /* offcore_response.pf_l3_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000200\000\00000\000\000 */
{ 2374994 }, /* offcore_response.pf_l3_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts prefetch (that bring data to LLC only) code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020200\000\00000\000\000 */
{ 2379869 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0080\000\00000\000\000 */
{ 2389023 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00000\000\000 */
{ 2389212 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00000\000\000 */
{ 2389860 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00000\000\000 */
{ 2390245 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00000\000\000 */
{ 2390434 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00000\000\000 */
{ 2391816 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00000\000\000 */
{ 2392016 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00000\000\000 */
{ 2392211 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00000\000\000 */
{ 2393139 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000080\000\00000\000\000 */
{ 2393338 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00000\000\000 */
{ 2393756 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00000\000\000 */
{ 2398977 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020080\000\00000\000\000 */
{ 2403896 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20003C0100\000\00000\000\000 */
{ 2412692 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00000\000\000 */
{ 2412871 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00000\000\000 */
{ 2413491 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00000\000\000 */
{ 2413858 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00000\000\000 */
{ 2414037 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00000\000\000 */
{ 2415369 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00000\000\000 */
{ 2415559 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00000\000\000 */
{ 2415744 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00000\000\000 */
{ 2416636 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000100\000\00000\000\000 */
{ 2416825 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00000\000\000 */
{ 2417225 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00000\000\000 */
{ 2422250 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020100\000\00000\000\000 */
{ 2514606 }, /* rtm_retired.aborted\000\000memory\000Number of times RTM abort was triggered (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered  (Precise event)\000 */
{ 2516981 }, /* rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 2517574 }, /* rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an RTM abort\000 */
{ 2518004 }, /* rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an RTM abort\000 */
{ 2518535 }, /* rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times a RTM caused a fault\000 */
{ 2518720 }, /* rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times RTM aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 2519870 }, /* rtm_retired.commit\000\000memory\000Number of times RTM commit succeeded\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520951 }, /* rtm_retired.start\000\000memory\000Number of times we entered an RTM region; does not count nested transactions\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region\n does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571663 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by  a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573943 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000 */
{ 2574626 }, /* tx_mem.abort_capacity_write\000\000memory\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000event=0x54,period=2000003,umask=0x2\000\00000\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000 */
{ 2575413 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a TSX line had a cache conflict\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576232 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577423 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2578428 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2580470 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2581333 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times we could not allocate Lock Buffer\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 581115 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000This event counts the unhalted core cycles during which the thread is in the ring 0 privileged mode\000 */
{ 581987 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000This event counts when there is a transition from ring 1,2 or 3 to ring0\000 */
{ 582369 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000This event counts unhalted core cycles during which the thread is in rings 1, 2, or 3\000 */
{ 1246210 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000This event counts cycles in which the L1 and L2 are locked due to a UC lock or split lock. A lock is asserted in case of locked memory access, due to noncacheable memory, locked operation that spans two cache lines, or a page walk from the noncacheable page table. L1D and L2 locks have a very high performance penalty and it is highly recommended to avoid such access\000 */
{ 470283 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000This event counts the number of the divide operations executed. Uses edge-detect and a cmask value of 1 on ARITH.FPU_DIV_ACTIVE to get the number of the divide operations executed\000 */
{ 487863 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired branch instructions\000 */
{ 488352 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired macro-conditional branch instructions\000 */
{ 488962 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000This event counts both taken and not taken speculative and retired macro-unconditional branch instructions, excluding calls and indirects\000 */
{ 489591 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000This event counts both taken and not taken speculative and retired direct near calls\000 */
{ 490163 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 490613 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000This event counts both taken and not taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 492015 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000This event counts not taken macro-conditional branch instructions\000 */
{ 492721 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions\000 */
{ 493361 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions excluding calls and indirect branches\000 */
{ 494026 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000This event counts taken speculative and retired direct near calls\000 */
{ 494609 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 495234 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000This event counts taken speculative and retired indirect calls including both register and memory indirect\000 */
{ 495836 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 496588 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000This event counts all (macro) branch instructions retired\000 */
{ 499782 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS)  Spec update: BDW98 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: BDW98 (Must be precise)\000 */
{ 505778 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired (Precise event)\000 */
{ 507863 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: BDW98\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: BDW98\000 */
{ 515440 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 516700 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000 */
{ 518100 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired (Precise event)\000 */
{ 519528 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired (Precise event)\000 */
{ 522442 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 529473 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 530230 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken mispredicted indirect branches excluding calls and returns\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532040 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000This event counts not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 532898 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 533722 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired mispredicted indirect branches excluding calls and returns\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 534796 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired mispredicted indirect branches that have a return mnemonic\000 */
{ 536938 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000This event counts all mispredicted macro branch instructions retired\000 */
{ 541717 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 555802 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 559925 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This event counts mispredicted return instructions retired (Precise event)\000 */
{ 607340 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 607860 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000This is a fixed-frequency event programmed to general counters. It counts when the core is unhalted at 100 Mhz\000 */
{ 608968 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 618202 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 629105 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. \nNote: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  This event is clocked by base clock (100 Mhz) on Sandy Bridge. The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638482 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000 */
{ 639739 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 642083 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 749189 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request missing the L1 data cache\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 750752 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Counts number of cycles the CPU has at least one pending  demand* load request missing the L2 cache\000 */
{ 752207 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request (that is cycles with non-completed load waiting for its data from memory subsystem)\000 */
{ 753182 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 753743 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Counts number of cycles nothing is executed on any execution port\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755503 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request missing the L1 data cache\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 757144 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand* load request missing the L2 cache.(as a footprint) * includes also L1 HW prefetch requests that may or may not be required by demands\000 */
{ 758459 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request\000 */
{ 759049 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 1042438 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts stalls occurred due to changing prefix length (66, 67 or REX.W when they change the length of the decoded instruction). Occurrences counting is proportional to the number of prefixes in a 16B-line. This may result in the following penalties: three-cycle penalty for each LCP in a 16-byte chunk\000 */
{ 1048616 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. \nNotes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. \nCounting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1054178 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: BDM61\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: BDM61\000 */
{ 1059091 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: BDM11, BDM55 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000This is a precise version (that is, uses PEBS) of the event that counts instructions retired  Spec update: BDM11, BDM55 (Must be precise)\000 */
{ 1063776 }, /* inst_retired.x87\000\000pipeline\000FP operations  retired. X87 FP operations that have no exceptions:\000event=0xc0,period=2000003,umask=0x2\000\00000\000This event counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000 */
{ 1067840 }, /* int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x8\000\00000\000This event counts the number of cycles during which Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the current thread. This also includes the cycles during which the Allocator is serving another thread\000 */
{ 1068279 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Cycles checkpoints in Resource Allocation Table (RAT) are recovering from JEClear or machine clear\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1195150 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000 */
{ 1195965 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts how many times the load operation got the true Block-on-Store blocking code preventing store forwarding. This includes cases when:\n - preceding store conflicts with the load (incomplete overlap);\n - store forwarding is impossible due to u-arch limitations;\n - preceding lock RMW operations are not forwarded;\n - store has the no-forward bit set (uncacheable/page-split/masked stores);\n - all-blocking stores are used (mostly, fences and port I/O);\nand others.\nThe most common case is a load blocked due to its address range overlapping with a preceding smaller uncompleted store. Note: This event does not take into account cases of out-of-SW-control (for example, SbTailHit), unknown physical STA, and cases of blocking loads on store due to being non-WB memory type or a lock. These cases are covered by other events.\nSee the table of not supported store forwards in the Optimization Guide\000 */
{ 1203346 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000This event counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229339 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the hardware prefetch\000 */
{ 1230455 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by asm inspection of the nearby instructions\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1289455 }, /* machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000This event counts both thread-specific (TS) and all-thread (AT) nukes\000 */
{ 1293258 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000 */
{ 1301798 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1433006 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000 */
{ 1433396 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000 */
{ 2462319 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000\000 */
{ 2501664 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000This event counts resource-related stall cycles\000 */
{ 2503004 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000This event counts ROB full stall cycles. This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2503458 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000This event counts stall cycles caused by absence of eligible entries in the reservation station (RS). This may result from RS overflow, or from RS deallocation because of the RS array Write Port allocation scheme (each RS entry has two write ports instead of four. As a result, empty entries could not be used, although RS is not really full). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2505380 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts stall cycles caused by the store buffer (SB) overflow (excluding draining from synch). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2507440 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000This event counts cases of saving new LBR records by hardware. This assumes proper enabling of LBRs and takes into account LBR filtering done by the LBR_SELECT register\000 */
{ 2511321 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the reservation station (RS) is empty for the thread.\nNote: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6184272 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185554 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186860 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6188158 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189481 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190770 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191751 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192398 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198933 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200909 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6201977 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203050 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203994 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 6205620 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6208183 }, /* uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6208438 }, /* uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6208760 }, /* uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6209015 }, /* uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6209337 }, /* uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6209592 }, /* uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6209916 }, /* uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6210171 }, /* uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6210496 }, /* uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6210752 }, /* uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6211076 }, /* uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6211332 }, /* uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6211656 }, /* uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6211912 }, /* uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6212236 }, /* uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6212492 }, /* uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6214583 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS)\000 */
{ 6217174 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops being allocated. Such uops considered perf sensitive\n added by GSR u-arch\000 */
{ 6217915 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6220169 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6225615 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts all actually retired uops. Counting increments by two for micro-fused uops, and by one for macro-fused and other uops. Maximal increment value for one cycle is eight (Precise event)\000 */
{ 6234066 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used (Precise event)\000 */
{ 6238392 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240195 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2784623 }, /* unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000L3 Lookup any request that access cache and found line in E or S-state\000 */
{ 2785035 }, /* unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000L3 Lookup any request that access cache and found line in I-state\000 */
{ 2785430 }, /* unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000L3 Lookup any request that access cache and found line in M-state\000 */
{ 2785825 }, /* unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000L3 Lookup any request that access cache and found line in MESI-state\000 */
{ 2786963 }, /* unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000L3 Lookup read request that access cache and found line in E or S-state\000 */
{ 2787380 }, /* unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000L3 Lookup read request that access cache and found line in I-state\000 */
{ 2787780 }, /* unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000L3 Lookup read request that access cache and found line in M-state\000 */
{ 2788180 }, /* unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000L3 Lookup read request that access cache and found line in any MESI-state\000 */
{ 2788607 }, /* unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000L3 Lookup write request that access cache and found line in E or S-state\000 */
{ 2789198 }, /* unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000L3 Lookup write request that access cache and found line in M-state\000 */
{ 2789603 }, /* unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000L3 Lookup write request that access cache and found line in MESI-state\000 */
{ 2790402 }, /* unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000 */
{ 2791012 }, /* unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000 */
{ 2791246 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000 */
{ 2791854 }, /* unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000 */
{ 2582380 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop, Core aperture, etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2585861 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all Core outgoing valid entries. Such entry is defined as valid from its allocation till first of IDI0 or DRS0 messages is sent out. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2587799 }, /* unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC.;. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000 */
{ 2588388 }, /* unc_arb_trk_occupancy.drd_direct\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries that are in DirectData mode. Such entry is defined as valid when it is allocated till data sent to Core (first chunk, IDI0). Applicable for IA Cores' requests in normal case. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000Each cycle count number of valid coherent Data Read entries that are in DirectData mode. Such entry is defined as valid when it is allocated till data sent to Core (first chunk, IDI0). Applicable for IA Cores' requests in normal case\000 */
{ 2589836 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of Core outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2590583 }, /* unc_arb_trk_requests.drd_direct\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read entries allocated in DirectData mode. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000Number of Core coherent Data Read entries allocated in DirectData mode\000 */
{ 2591875 }, /* unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Number of Writes allocated - any write transactions: full/partials writes and evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000 */
{ 3540382 }, /* unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000This 48-bit fixed counter counts the UCLK cycles\000 */
{ 788035 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x8,period=100003,umask=0x1\000\00000\000This event counts load misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 790726 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000\000 */
{ 792298 }, /* dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000\000 */
{ 792704 }, /* dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000\000 */
{ 794649 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size  Spec update: BDM69\000event=0x8,period=100003,umask=0xe\000\00000\000\000 */
{ 797668 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x8\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 800344 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 803676 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x2\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 806216 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 810390 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 812771 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000\000 */
{ 814338 }, /* dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000\000 */
{ 814749 }, /* dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000\000 */
{ 816911 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0xe\000\00000\000\000 */
{ 820829 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (1G)  Spec update: BDM69\000event=0x49,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 824198 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)  Spec update: BDM69\000event=0x49,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 827282 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x49,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 828248 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 833208 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000This event counts cycles for an extended page table walk. The Extended Page directory cache differs from standard TLB caches by the operating system that use it. Virtual machine operating systems use the extended page directory cache, while guest operating systems use the standard TLB caches\000 */
{ 1078539 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000This event counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080623 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 1083626 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000\000 */
{ 1084532 }, /* itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000\000 */
{ 1084832 }, /* itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1087487 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0xe\000\00000\000\000 */
{ 1089713 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x85,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1090540 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)  Spec update: BDM69\000event=0x85,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1093387 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x85,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1095831 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 2468040 }, /* page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x11\000\00000\000\000 */
{ 2468379 }, /* page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x12\000\00000\000\000 */
{ 2468709 }, /* page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x14\000\00000\000\000 */
{ 2469093 }, /* page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x18\000\00000\000\000 */
{ 2470830 }, /* page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x21\000\00000\000\000 */
{ 2471169 }, /* page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x22\000\00000\000\000 */
{ 2471499 }, /* page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x24\000\00000\000\000 */
{ 2540692 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000This event counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541489 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000This event counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, and so on)\000 */
};

static const struct compact_pmu_event pmu_metrics__broadwell[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51523 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 78615 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000MACHINE_CLEARS.COUNT * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 91007 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 103058 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 118981 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 133795 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_LOAD_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 142011 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_STORE_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 150914 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 155428 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165040 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 176343 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194575 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 197756 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 218790 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 221371 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 224070 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 231407 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239076 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248732 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 254949 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * (DTLB_STORE_MISSES.WALK_COMPLETED + DTLB_LOAD_MISSES.WALK_COMPLETED + ITLB_MISSES.WALK_COMPLETED)) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257611 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 260736 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267776 }, /* \000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000 */
{ 271339 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 282859 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * ITLB_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 285754 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 289893 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 295561 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 302819 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 316428 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 334406 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 344458 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + RESOURCE_STALLS.SB) / (CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 353132 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379171 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382050 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 386530 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 389567 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 395006 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 400762 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (CYCLE_ACTIVITY.STALLS_TOTAL - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 405006 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 410836 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418342 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 442148 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 460655 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000tma_branch_resteers - tma_mispredicts_resteers - tma_clears_resteers\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 461970 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__broadwellde[] = {
{ 1101501 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1110022 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand; from the demand Hit FB, if it is allocated by hardware or software prefetch.\nNote: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112707 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1123947 }, /* l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000This event counts the number of WB requests that hit L2 cache\000 */
{ 1129220 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1129900 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000This event counts the number of L2 cache lines in the Exclusive state filling the L2. Counting does not cover rejects\000 */
{ 1130448 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000This event counts the number of L2 cache lines in the Invalidate state filling the L2. Counting does not cover rejects\000 */
{ 1130896 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000This event counts the number of L2 cache lines in the Shared state filling the L2. Counting does not cover rejects\000 */
{ 1132063 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000\000 */
{ 1157444 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000This event counts the total number of L2 code requests\000 */
{ 1158790 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000This event counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159885 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000\000 */
{ 1160630 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000\000 */
{ 1161474 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000This event counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162439 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000This event counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163612 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000\000 */
{ 1164549 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166774 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000This event counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1168158 }, /* l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that hit L2 cache. L3 prefetch new types\000 */
{ 1168537 }, /* l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that miss L2 cache\000 */
{ 1169474 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000\000 */
{ 1172732 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000\000 */
{ 1174367 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000\000 */
{ 1175046 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000\000 */
{ 1179588 }, /* l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000This event counts L2 or L3 HW prefetches that access L2 cache including rejects\000 */
{ 1180048 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000This event counts transactions that access the L2 pipe including snoops, pagewalks, and so on\000 */
{ 1180627 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000This event counts the number of L2 cache accesses when fetching instructions\000 */
{ 1181249 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000This event counts Demand Data Read requests that access L2 cache, including rejects\000 */
{ 1181703 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000This event counts L1D writebacks that access L2 cache\000 */
{ 1182096 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000This event counts L2 fill requests that access L2 cache\000 */
{ 1182628 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000This event counts L2 writebacks that access L2 cache\000 */
{ 1183167 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000This event counts Read for Ownership (RFO) requests that access L2 cache\000 */
{ 1245649 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000This event counts the number of cycles when the L1D is locked. It is a superset of the 0x1 mask (BUS_LOCK_CLOCKS.BUS_LOCK_DURATION)\000 */
{ 1247290 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts core-originated cacheable demand requests that miss the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1251000 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts core-originated cacheable demand requests that refer to the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1341691 }, /* mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops which data sources were L3 hit and a cross-core snoop hit in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1342388 }, /* mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops which data sources were HitM responses from a core on same socket (shared L3)  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343042 }, /* mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000This event counts retired load uops which data sources were L3 Hit and a cross-core snoop missed in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343756 }, /* mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1344433 }, /* mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uop whose Data Source was: local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000 */
{ 1345280 }, /* mem_load_uops_l3_miss_retired.remote_dram\000\000cache\000Retired load uop whose Data Source was: remote DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000\000 */
{ 1345795 }, /* mem_load_uops_l3_miss_retired.remote_fwd\000\000cache\000Retired load uop whose Data Source was: forwarded from remote cache  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x20\000\00000\000\000 */
{ 1346245 }, /* mem_load_uops_l3_miss_retired.remote_hitm\000\000cache\000Retired load uop whose Data Source was: Remote cache HITM  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000\000 */
{ 1353644 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000This event counts retired load uops which data sources were load uops missed L1 but hit a fill buffer due to a preceding miss to the same cache line with the data not ready.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load  Supports address when precise (Precise event)\000 */
{ 1356844 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000This event counts retired load uops which data sources were hits in the nearest-level (L1) cache.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load. This event also counts SW prefetches independent of the actual data source  Supports address when precise (Precise event)\000 */
{ 1358647 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were misses in the nearest-level (L1) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1360141 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000This event counts retired load uops which data sources were hits in the mid-level (L2) cache  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1361888 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000This event counts retired load uops which data sources were misses in the mid-level (L2) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1363119 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops which data sources were data hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1364330 }, /* mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: BDM100, BDE70 (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1390113 }, /* mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1392489 }, /* mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise (Precise event)\000 */
{ 1415479 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000This event counts load uops with locked access retired to the architected path  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1417829 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1419597 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1421539 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000This event counts load uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1422607 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000This event counts store uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1745359 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000This event counts the demand and prefetch data reads. All Core Data Reads include cacheable Demands and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746038 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000This event counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, and so on\000 */
{ 1748542 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000This event counts both cacheable and non-cacheable code read requests\000 */
{ 1750433 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000This event counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751556 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000This event counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753800 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000This event counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.\nNote: Writeback pending FIFO has six entries\000 */
{ 1754992 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x8\000\00000\000This event counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1757948 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1762576 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)  Spec update: BDM76\000 */
{ 1766481 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1770828 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,period=2000003,umask=0x2\000\00000\000This event counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1773190 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,period=2000003,umask=0x1\000\00000\000This event counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.\nNote: A prefetch promoted to Demand is counted from the promotion point  Spec update: BDM76\000 */
{ 1775673 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1776605 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 2460294 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000 */
{ 2531841 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000This event counts the number of split locks in the super queue\000 */
{ 856247 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 859272 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 864472 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 868573 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 8 calculations per element\000event=0xc7,period=2000003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 873279 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 884623 }, /* fp_arith_inst_retired.double\000\000floating point\000Number of SSE/AVX computational double precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000006,umask=0x15\000\00000\000\000 */
{ 885097 }, /* fp_arith_inst_retired.packed\000\000floating point\000Number of SSE/AVX computational packed floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* packed double and single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000004,umask=0x3c\000\00000\000\000 */
{ 888236 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below. Each count represents 1 computation operation.   Applies to SSE* and AVX* scalar double and single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891938 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 895654 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 897672 }, /* fp_arith_inst_retired.single\000\000floating point\000Number of SSE/AVX computational single precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000005,umask=0x2a\000\00000\000\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 902217 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000This event counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 903279 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000This event counts any input SSE* FP assist - invalid operation, denormal operand, dividing by zero, SNaN operand. Counting includes only cases involving penalties that required micro-code assist intervention\000 */
{ 903905 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000This event counts the number of SSE* floating point (FP) micro-code assist (numeric overflow/underflow) when the output value (destination register) is invalid. Counting covers only cases involving penalties that require micro-code assist intervention\000 */
{ 904567 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000This event counts x87 floating point (FP) micro-code assist (invalid operation, denormal operand, SNaN operand) when the input value (one of the source operands to an FP instruction) is invalid\000 */
{ 905158 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000This event counts the number of x87 floating point (FP) micro-code assist (numeric overflow/underflow, inexact result) when the output value (destination register) is invalid\000 */
{ 1433783 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000 */
{ 1434178 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000 */
{ 2463149 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x8\000\00000\000This event counts the number of transitions from AVX-256 to legacy SSE when penalty is applicable  Spec update: BDM30\000 */
{ 2463904 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x10\000\00000\000This event counts the number of transitions from legacy SSE to AVX-256 when penalty is applicable  Spec update: BDM30\000 */
{ 6177315 }, /* uop_dispatches_cancelled.simd_prf\000\000floating point\000Micro-op dispatches cancelled due to insufficient SIMD physical register file read ports\000event=0xa0,period=2000003,umask=0x3\000\00000\000This event counts the number of micro-operations cancelled after they were dispatched from the scheduler to the execution units when the total number of physical register read ports across all dispatch ports exceeds the read bandwidth of the physical register file.  The SIMD_PRF subevent applies to the following instructions: VDPPS, DPPS, VPCMPESTRI, PCMPESTRI, VPCMPESTRM, PCMPESTRM, VFMADD*, VFMADDSUB*, VFMSUB*, VMSUBADD*, VFNMADD*, VFNMSUB*.  See the Broadwell Optimization Guide for more information\000 */
{ 477106 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000 */
{ 784188 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. \nMM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.\nPenalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 986506 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000This event counts the number of both cacheable and noncacheable Instruction Cache, Streaming Buffer and Victim Cache Reads including UC fetches\000 */
{ 987766 }, /* icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000This event counts cycles during which the demand fetch waits for data (wfdM104H) from L2 or iSB (opportunistic hit)\000 */
{ 990635 }, /* icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes UC accesses\000 */
{ 998477 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 999553 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1000587 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001838 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles  uops were delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002978 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1006821 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1007899 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000This counts the number of cycles that the instruction decoder queue is empty and can indicate that the application may be bound in the front end.  It does not determine whether there are uops being delivered to the Alloc stage since uops can be delivered by bypass skipping the Instruction Decode Queue (IDQ) when it is empty\000 */
{ 1008613 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1009676 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ\000 */
{ 1012842 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1015992 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1018545 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000This event counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1019936 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000This event counts the number of deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1021234 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000This event counts the number of uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1022867 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000This event counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026055 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts the total number of uops delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1032672 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when:\n a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread;\n b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions); \n c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034662 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038680 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when less than 1 uop is  delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >=3\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 970645 }, /* hle_retired.aborted\000\000memory\000Number of times HLE abort was triggered (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 972603 }, /* hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000Number of times an HLE abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 973088 }, /* hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an HLE abort\000 */
{ 973430 }, /* hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an HLE abort\000 */
{ 973961 }, /* hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times HLE caused a fault\000 */
{ 974144 }, /* hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times HLE aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 975396 }, /* hle_retired.commit\000\000memory\000Number of times HLE commit succeeded\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976477 }, /* hle_retired.start\000\000memory\000Number of times we entered an HLE region; does not count nested transactions\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region\n does not count nested transactions\000 */
{ 1294861 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:\n1. memory disambiguation,\n2. external snoop, or\n3. cross SMT-HW-thread snoop (stores) hitting load buffer\000 */
{ 1369873 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1371816 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1373759 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1375705 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1377639 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads with latency value being above four  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1379577 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1381517 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1383441 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads with latency value being above eight  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1428587 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000This event counts speculative cache-line split load uops dispatched to the L1 cache\000 */
{ 1430771 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000This event counts speculative cache line split store-address (STA) uops dispatched to the L1 cache\000 */
{ 2514606 }, /* rtm_retired.aborted\000\000memory\000Number of times RTM abort was triggered (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered  (Precise event)\000 */
{ 2516981 }, /* rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 2517574 }, /* rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an RTM abort\000 */
{ 2518004 }, /* rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an RTM abort\000 */
{ 2518535 }, /* rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times a RTM caused a fault\000 */
{ 2518720 }, /* rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times RTM aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 2519870 }, /* rtm_retired.commit\000\000memory\000Number of times RTM commit succeeded\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520951 }, /* rtm_retired.start\000\000memory\000Number of times we entered an RTM region; does not count nested transactions\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region\n does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571663 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by  a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573943 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000 */
{ 2574626 }, /* tx_mem.abort_capacity_write\000\000memory\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000event=0x54,period=2000003,umask=0x2\000\00000\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000 */
{ 2575413 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a TSX line had a cache conflict\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576232 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577423 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2578428 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2580470 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2581333 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times we could not allocate Lock Buffer\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 581115 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000This event counts the unhalted core cycles during which the thread is in the ring 0 privileged mode\000 */
{ 581987 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000This event counts when there is a transition from ring 1,2 or 3 to ring0\000 */
{ 582369 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000This event counts unhalted core cycles during which the thread is in rings 1, 2, or 3\000 */
{ 1246210 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000This event counts cycles in which the L1 and L2 are locked due to a UC lock or split lock. A lock is asserted in case of locked memory access, due to noncacheable memory, locked operation that spans two cache lines, or a page walk from the noncacheable page table. L1D and L2 locks have a very high performance penalty and it is highly recommended to avoid such access\000 */
{ 470283 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000This event counts the number of the divide operations executed. Uses edge-detect and a cmask value of 1 on ARITH.FPU_DIV_ACTIVE to get the number of the divide operations executed\000 */
{ 487863 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired branch instructions\000 */
{ 488352 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired macro-conditional branch instructions\000 */
{ 488962 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000This event counts both taken and not taken speculative and retired macro-unconditional branch instructions, excluding calls and indirects\000 */
{ 489591 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000This event counts both taken and not taken speculative and retired direct near calls\000 */
{ 490163 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 490613 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000This event counts both taken and not taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 492015 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000This event counts not taken macro-conditional branch instructions\000 */
{ 492721 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions\000 */
{ 493361 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions excluding calls and indirect branches\000 */
{ 494026 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000This event counts taken speculative and retired direct near calls\000 */
{ 494609 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 495234 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000This event counts taken speculative and retired indirect calls including both register and memory indirect\000 */
{ 495836 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 496588 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000This event counts all (macro) branch instructions retired\000 */
{ 499782 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS)  Spec update: BDW98 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: BDW98 (Must be precise)\000 */
{ 505778 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired (Precise event)\000 */
{ 507863 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: BDW98\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: BDW98\000 */
{ 515440 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 516700 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000 */
{ 518100 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired (Precise event)\000 */
{ 519528 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired (Precise event)\000 */
{ 522442 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 529473 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 530230 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken mispredicted indirect branches excluding calls and returns\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532040 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000This event counts not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 532898 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 533722 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired mispredicted indirect branches excluding calls and returns\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 534796 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired mispredicted indirect branches that have a return mnemonic\000 */
{ 536938 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000This event counts all mispredicted macro branch instructions retired\000 */
{ 541717 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 555802 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 559925 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This event counts mispredicted return instructions retired (Precise event)\000 */
{ 607340 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 607860 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000This is a fixed-frequency event programmed to general counters. It counts when the core is unhalted at 100 Mhz\000 */
{ 608968 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 618202 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 629105 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. \nNote: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  This event is clocked by base clock (100 Mhz) on Sandy Bridge. The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638482 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000 */
{ 639739 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 642083 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 749189 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request missing the L1 data cache\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 750752 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Counts number of cycles the CPU has at least one pending  demand* load request missing the L2 cache\000 */
{ 752207 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request (that is cycles with non-completed load waiting for its data from memory subsystem)\000 */
{ 753182 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 753743 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Counts number of cycles nothing is executed on any execution port\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755503 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request missing the L1 data cache\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 757144 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand* load request missing the L2 cache.(as a footprint) * includes also L1 HW prefetch requests that may or may not be required by demands\000 */
{ 758459 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request\000 */
{ 759049 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 1042438 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts stalls occurred due to changing prefix length (66, 67 or REX.W when they change the length of the decoded instruction). Occurrences counting is proportional to the number of prefixes in a 16B-line. This may result in the following penalties: three-cycle penalty for each LCP in a 16-byte chunk\000 */
{ 1048616 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. \nNotes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. \nCounting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1054178 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: BDM61\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: BDM61\000 */
{ 1059091 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: BDM11, BDM55 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000This is a precise version (that is, uses PEBS) of the event that counts instructions retired  Spec update: BDM11, BDM55 (Must be precise)\000 */
{ 1063776 }, /* inst_retired.x87\000\000pipeline\000FP operations  retired. X87 FP operations that have no exceptions:\000event=0xc0,period=2000003,umask=0x2\000\00000\000This event counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000 */
{ 1067840 }, /* int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x8\000\00000\000This event counts the number of cycles during which Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the current thread. This also includes the cycles during which the Allocator is serving another thread\000 */
{ 1068279 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Cycles checkpoints in Resource Allocation Table (RAT) are recovering from JEClear or machine clear\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1195150 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000 */
{ 1195965 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts how many times the load operation got the true Block-on-Store blocking code preventing store forwarding. This includes cases when:\n - preceding store conflicts with the load (incomplete overlap);\n - store forwarding is impossible due to u-arch limitations;\n - preceding lock RMW operations are not forwarded;\n - store has the no-forward bit set (uncacheable/page-split/masked stores);\n - all-blocking stores are used (mostly, fences and port I/O);\nand others.\nThe most common case is a load blocked due to its address range overlapping with a preceding smaller uncompleted store. Note: This event does not take into account cases of out-of-SW-control (for example, SbTailHit), unknown physical STA, and cases of blocking loads on store due to being non-WB memory type or a lock. These cases are covered by other events.\nSee the table of not supported store forwards in the Optimization Guide\000 */
{ 1203346 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000This event counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229339 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the hardware prefetch\000 */
{ 1230455 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by asm inspection of the nearby instructions\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1289455 }, /* machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000This event counts both thread-specific (TS) and all-thread (AT) nukes\000 */
{ 1293258 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000 */
{ 1301798 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1433006 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000 */
{ 1433396 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000 */
{ 2462319 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000\000 */
{ 2501664 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000This event counts resource-related stall cycles\000 */
{ 2503004 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000This event counts ROB full stall cycles. This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2503458 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000This event counts stall cycles caused by absence of eligible entries in the reservation station (RS). This may result from RS overflow, or from RS deallocation because of the RS array Write Port allocation scheme (each RS entry has two write ports instead of four. As a result, empty entries could not be used, although RS is not really full). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2505380 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts stall cycles caused by the store buffer (SB) overflow (excluding draining from synch). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2507440 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000This event counts cases of saving new LBR records by hardware. This assumes proper enabling of LBRs and takes into account LBR filtering done by the LBR_SELECT register\000 */
{ 2511321 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the reservation station (RS) is empty for the thread.\nNote: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6184272 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185554 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186860 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6188158 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189481 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190770 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191751 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192398 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198933 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200909 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6201977 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203050 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203994 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 6205620 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6208183 }, /* uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6208438 }, /* uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6208760 }, /* uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6209015 }, /* uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6209337 }, /* uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6209592 }, /* uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6209916 }, /* uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6210171 }, /* uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6210496 }, /* uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6210752 }, /* uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6211076 }, /* uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6211332 }, /* uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6211656 }, /* uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6211912 }, /* uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6212236 }, /* uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6212492 }, /* uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6214583 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS)\000 */
{ 6217174 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops being allocated. Such uops considered perf sensitive\n added by GSR u-arch\000 */
{ 6217915 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6220169 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6225615 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts all actually retired uops. Counting increments by two for micro-fused uops, and by one for macro-fused and other uops. Maximal increment value for one cycle is eight (Precise event)\000 */
{ 6234066 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used (Precise event)\000 */
{ 6238392 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240195 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2592068 }, /* unc_c_bounce_control\000uncore_cbox\000uncore cache\000Bounce Control. Unit: uncore_cbox \000event=0xa\000\00001\000\000 */
{ 2592164 }, /* unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000 */
{ 2592390 }, /* unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2592888 }, /* unc_c_fast_asserted\000uncore_cbox\000uncore cache\000FaST wire asserted. Unit: uncore_cbox \000event=0x9\000\00001\000Counts the number of cycles either the local distress or incoming distress signals are asserted.  Incoming distress includes both up and dn\000 */
{ 2594837 }, /* unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000Cache Lookups; Any Request. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2596894 }, /* unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2598632 }, /* unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2599997 }, /* unc_c_llc_lookup.read\000uncore_cbox\000uncore cache\000Cache Lookups; Any Read Request. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2602045 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2604174 }, /* unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2605021 }, /* unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605435 }, /* unc_c_llc_victims.f_state\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605831 }, /* unc_c_llc_victims.i_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606246 }, /* unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cbox \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606927 }, /* unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x10\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607378 }, /* unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2608914 }, /* unc_c_misc.cvzero_prefetch_miss\000uncore_cbox\000uncore cache\000Cbo Misc; DRd hitting non-M with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609091 }, /* unc_c_misc.cvzero_prefetch_victim\000uncore_cbox\000uncore cache\000Cbo Misc; Clean Victim with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609265 }, /* unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo.; Number of times that an RFO hit in S state.  This is useful for determining if it might be good for a workload to use RspIWB instead of RspSWB\000 */
{ 2609694 }, /* unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2610173 }, /* unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610303 }, /* unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2610806 }, /* unc_c_qlru.age0\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 0. Unit: uncore_cbox \000event=0x3c,umask=0x1\000\00001\000How often age was set to 0\000 */
{ 2610940 }, /* unc_c_qlru.age1\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 1. Unit: uncore_cbox \000event=0x3c,umask=0x2\000\00001\000How often age was set to 1\000 */
{ 2611074 }, /* unc_c_qlru.age2\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 2. Unit: uncore_cbox \000event=0x3c,umask=0x4\000\00001\000How often age was set to 2\000 */
{ 2611208 }, /* unc_c_qlru.age3\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 3. Unit: uncore_cbox \000event=0x3c,umask=0x8\000\00001\000How often age was set to 3\000 */
{ 2611342 }, /* unc_c_qlru.lru_decrement\000uncore_cbox\000uncore cache\000LRU Queue; LRU Bits Decremented. Unit: uncore_cbox \000event=0x3c,umask=0x10\000\00001\000How often all LRU bits were decremented by 1\000 */
{ 2611515 }, /* unc_c_qlru.victim_non_zero\000uncore_cbox\000uncore cache\000LRU Queue; Non-0 Aged Victim. Unit: uncore_cbox \000event=0x3c,umask=0x20\000\00001\000How often we picked a victim that had a non-zero age\000 */
{ 2611695 }, /* unc_c_ring_ad_used.all\000uncore_cbox\000uncore cache\000AD Ring In Use; All. Unit: uncore_cbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2614219 }, /* unc_c_ring_ad_used.ccw\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2615899 }, /* unc_c_ring_ad_used.cw\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2619251 }, /* unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2621906 }, /* unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2630783 }, /* unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2633422 }, /* unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2639753 }, /* unc_c_ring_ak_used.all\000uncore_cbox\000uncore cache\000AK Ring In Use; All. Unit: uncore_cbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2642271 }, /* unc_c_ring_ak_used.ccw\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2643947 }, /* unc_c_ring_ak_used.cw\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2646455 }, /* unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2649104 }, /* unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2657128 }, /* unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2659761 }, /* unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2666078 }, /* unc_c_ring_bl_used.all\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2668598 }, /* unc_c_ring_bl_used.ccw\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2670274 }, /* unc_c_ring_bl_used.cw\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2673638 }, /* unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2676286 }, /* unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2684309 }, /* unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2686941 }, /* unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2692409 }, /* unc_c_ring_bounces.ad\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AD. Unit: uncore_cbox \000event=0x5,umask=0x1\000\00001\000\000 */
{ 2692700 }, /* unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AK. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2693360 }, /* unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; BL. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2694014 }, /* unc_c_ring_bounces.iv\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x10\000\00001\000\000 */
{ 2694538 }, /* unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2696543 }, /* unc_c_ring_iv_used.dn\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2697651 }, /* unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters for Down polarity\000 */
{ 2699143 }, /* unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2700611 }, /* unc_c_ring_sink_starved.ad\000uncore_cbox\000uncore cache\000AD. Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 2701137 }, /* unc_c_ring_sink_starved.ak\000uncore_cbox\000uncore cache\000AK. Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 2701462 }, /* unc_c_ring_sink_starved.bl\000uncore_cbox\000uncore cache\000BL. Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 2701787 }, /* unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000IV. Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 2702209 }, /* unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Number of cycles the Cbo is actively throttling traffic onto the Ring in order to limit bounce traffic. Unit: uncore_cbox \000event=0x7\000\00001\000\000 */
{ 2702621 }, /* unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IPQ is externally startved and therefore we are blocking the IRQ\000 */
{ 2703192 }, /* unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IRQ is externally starved and therefore we are blocking the IPQ\000 */
{ 2704016 }, /* unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; Number of times that the ISMQ Bid\000 */
{ 2704767 }, /* unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; PRQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2705019 }, /* unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705208 }, /* unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705397 }, /* unc_c_rxr_inserts.irq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706013 }, /* unc_c_rxr_inserts.prq\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706203 }, /* unc_c_rxr_inserts.prq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2707348 }, /* unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IPQ in Internal Starvation\000 */
{ 2707983 }, /* unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IRQ in Internal Starvation\000 */
{ 2708618 }, /* unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the ISMQ in Internal Starvation\000 */
{ 2709258 }, /* unc_c_rxr_int_starved.prq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; PRQ. Unit: uncore_cbox \000event=0x14,umask=0x10\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2709554 }, /* unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from an address conflicts.  Address conflicts out of the IPQ should be rare.  They will generally only occur if two different sockets are sending requests to the same address at the same time.  This is a true conflict case, unlike the IPQ Address Conflict which is commonly caused by prefetching characteristics\000 */
{ 2710465 }, /* unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject.  TOR rejects from the IPQ can be caused by the Egress being full or Address Conflicts\000 */
{ 2711119 }, /* unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from the Egress being full.  IPQ requests make use of the AD Egress for regular responses, the BL egress to forward data, and the AK egress to return credits\000 */
{ 2711860 }, /* unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2712110 }, /* unc_c_rxr_ipq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Probe Queue Retries; No AD Sbo Credits. Unit: uncore_cbox \000event=0x28,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2712488 }, /* unc_c_rxr_ipq_retry2.target\000uncore_cbox\000uncore cache\000Probe Queue Retries; Target Node Filter. Unit: uncore_cbox \000event=0x28,umask=0x40\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2712880 }, /* unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000Counts the number of times that a request from the IRQ was retried because of an address match in the TOR.  In order to maintain coherency, requests to the same address are not allowed to pass each other up in the Cbo.  Therefore, if there is an outstanding request to a given address, one cannot issue another request to that address until it is complete.  This comes up most commonly with prefetches.  Outstanding prefetches occasionally will not complete their memory fetch and a demand request to the same address will then sit in the IRQ and get retried until the prefetch fills the data into the LLC.  Therefore, it will not be uncommon to see this case in high bandwidth streaming workloads when the LLC Prefetcher in the core is enabled\000 */
{ 2713930 }, /* unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000Counts the number of IRQ retries that occur.  Requests from the IRQ are retried if they are rejected from the TOR pipeline for a variety of reasons.  Some of the most common reasons include if the Egress is full, there are no RTIDs, or there is a Physical Address match to another outstanding request\000 */
{ 2714504 }, /* unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000Counts the number of times that a request from the IRQ was retried because it failed to acquire an entry in the Egress.  The egress is the buffer that queues up for allocating onto the ring.  IRQ requests can make use of all four rings and all four Egresses.  If any of the queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2715154 }, /* unc_c_rxr_irq_retry.iio_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No IIO Credits. Unit: uncore_cbox \000event=0x32,umask=0x20\000\00001\000Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2715572 }, /* unc_c_rxr_irq_retry.nid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cbox \000event=0x32,umask=0x40\000\00001\000Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2715819 }, /* unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000Number of requests rejects because of lack of QPI Ingress credits.  These credits are required in order to send transactions to the QPI agent.  Please see the QPI_IGR_CREDITS events for more information\000 */
{ 2716321 }, /* unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000Counts the number of times that requests from the IRQ were retried because there were no RTIDs available.  RTIDs are required after a request misses the LLC and needs to send snoops and/or requests to memory.  If there are no RTIDs available, requests will queue up in the IRQ and retry until one becomes available.  Note that there are multiple RTID pools for the different sockets.  There may be cases where the local RTIDs are all used, but requests destined for remote memory can still acquire an RTID because there are remote RTIDs available.  This event does not provide any filtering for this case\000 */
{ 2717197 }, /* unc_c_rxr_irq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x1\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2717472 }, /* unc_c_rxr_irq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x2\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2717747 }, /* unc_c_rxr_irq_retry2.target\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x29,umask=0x40\000\00001\000Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2718036 }, /* unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the total number of times that a request from the ISMQ retried because of a TOR reject.  ISMQ requests generally will not need to retry (or at least ISMQ retries are less common than IRQ retries).  ISMQ requests will retry if they are not able to acquire a needed Egress credit to get onto the ring, or for cache evictions that need to acquire an RTID.  Most ISMQ requests already have an RTID, so eviction retries will be less common here\000 */
{ 2719237 }, /* unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by a lack of Egress credits. The egress is the buffer that queues up for allocating onto the ring.  If any of the Egress queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2720310 }, /* unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2721359 }, /* unc_c_rxr_ismq_retry.nid\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2721848 }, /* unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2722237 }, /* unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by no RTIDs.  M-state cache evictions are serviced through the ISMQ, and must acquire an RTID in order to write back to memory.  If no RTIDs are available, they will be retried\000 */
{ 2723261 }, /* unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2724209 }, /* unc_c_rxr_ismq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x1\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2724483 }, /* unc_c_rxr_ismq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x2\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2724757 }, /* unc_c_rxr_ismq_retry2.target\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x2a,umask=0x40\000\00001\000Counts the number of times that a request from the ISMQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2725045 }, /* unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725232 }, /* unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725419 }, /* unc_c_rxr_occupancy.irq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2726010 }, /* unc_c_rxr_occupancy.prq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; PRQ Rejects. Unit: uncore_cbox \000event=0x11,umask=0x20\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2727266 }, /* unc_c_sbo_credit_occupancy.ad\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For AD Ring. Unit: uncore_cbox \000event=0x3e,umask=0x1\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727511 }, /* unc_c_sbo_credit_occupancy.bl\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For BL Ring. Unit: uncore_cbox \000event=0x3e,umask=0x2\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727756 }, /* unc_c_sbo_credits_acquired.ad\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For AD Ring. Unit: uncore_cbox \000event=0x3d,umask=0x1\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728002 }, /* unc_c_sbo_credits_acquired.bl\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For BL Ring. Unit: uncore_cbox \000event=0x3d,umask=0x2\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728248 }, /* unc_c_tor_inserts.all\000uncore_cbox\000uncore cache\000TOR Inserts; All. Unit: uncore_cbox \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR.    This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2730237 }, /* unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Eviction transactions inserted into the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2733765 }, /* unc_c_tor_inserts.local\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x28\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2734438 }, /* unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2736634 }, /* unc_c_tor_inserts.miss_local\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x2a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2737323 }, /* unc_c_tor_inserts.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x23\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode, inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2738662 }, /* unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 2739324 }, /* unc_c_tor_inserts.miss_remote\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x8a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2740025 }, /* unc_c_tor_inserts.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x83\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2741368 }, /* unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched (matches an RTID destination) transactions inserted into the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.  In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2742799 }, /* unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched eviction transactions inserted into the TOR\000 */
{ 2744068 }, /* unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched miss requests that were inserted into the TOR\000 */
{ 2745352 }, /* unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2746645 }, /* unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2747919 }, /* unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched write transactions inserted into the TOR\000 */
{ 2749165 }, /* unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2750908 }, /* unc_c_tor_inserts.remote\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x88\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2751593 }, /* unc_c_tor_inserts.remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x81\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2753157 }, /* unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Write transactions inserted into the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2754718 }, /* unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All valid TOR entries.  This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2756725 }, /* unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding eviction transactions in the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2760047 }, /* unc_c_tor_occupancy.local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x28\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2760639 }, /* unc_c_tor_occupancy.local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by locally HOMed memory\000 */
{ 2762159 }, /* unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding miss requests in the TOR.  'Miss' means the allocation requires an RTID.  This generally means that the request was sent to memory or MMIO\000 */
{ 2762925 }, /* unc_c_tor_occupancy.miss_local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x2a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2763522 }, /* unc_c_tor_occupancy.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x23\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by locally HOMed memory\000 */
{ 2764905 }, /* unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2765643 }, /* unc_c_tor_occupancy.miss_remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x8a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2766241 }, /* unc_c_tor_occupancy.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x83\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2767627 }, /* unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of NID matched outstanding requests in the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2769062 }, /* unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding NID matched eviction transactions in the TOR \000 */
{ 2770367 }, /* unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID\000 */
{ 2771677 }, /* unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID and an opcode\000 */
{ 2773010 }, /* unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match a NID and an opcode\000 */
{ 2773675 }, /* unc_c_tor_occupancy.nid_wb\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x50\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); NID matched write transactions int the TOR\000 */
{ 2774944 }, /* unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2776134 }, /* unc_c_tor_occupancy.remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x88\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2776727 }, /* unc_c_tor_occupancy.remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x81\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2777486 }, /* unc_c_tor_occupancy.wb\000uncore_cbox\000uncore cache\000TOR Occupancy; Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Write transactions in the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2778213 }, /* unc_c_txr_ads_used.ad\000uncore_cbox\000uncore cache\000Onto AD Ring. Unit: uncore_cbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 2778318 }, /* unc_c_txr_ads_used.ak\000uncore_cbox\000uncore cache\000Onto AK Ring. Unit: uncore_cbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 2778423 }, /* unc_c_txr_ads_used.bl\000uncore_cbox\000uncore cache\000Onto BL Ring. Unit: uncore_cbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 2778606 }, /* unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 2779216 }, /* unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 2779791 }, /* unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 2780383 }, /* unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AK ring.  This is commonly used for snoop responses coming from the core and destined for a Cachebo\000 */
{ 2781004 }, /* unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 2781612 }, /* unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 2782210 }, /* unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 2782790 }, /* unc_c_txr_starved.ad_core\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AD Ring (to core). Unit: uncore_cbox \000event=0x3,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the core AD egress spent in starvation\000 */
{ 2783391 }, /* unc_c_txr_starved.ak_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both AK egresses spent in starvation\000 */
{ 2783979 }, /* unc_c_txr_starved.bl_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both BL egresses spent in starvation\000 */
{ 2784301 }, /* unc_c_txr_starved.iv\000uncore_cbox\000uncore cache\000Injection Starvation; Onto IV Ring. Unit: uncore_cbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the cachebo IV egress spent in starvation\000 */
{ 3579343 }, /* unc_h_bt_cycles_ne\000uncore_ha\000uncore cache\000BT Cycles Not Empty. Unit: uncore_ha \000event=0x42\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3582625 }, /* unc_h_bt_to_ht_not_issued.incoming_bl_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x4\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3582923 }, /* unc_h_bt_to_ht_not_issued.incoming_snp_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Snoop Hazard. Unit: uncore_ha \000event=0x51,umask=0x2\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming snoop hazard\000 */
{ 3583221 }, /* unc_h_bt_to_ht_not_issued.rspackcflt_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x8\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3583518 }, /* unc_h_bt_to_ht_not_issued.wbmdata_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x10\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3584345 }, /* unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass\000 */
{ 3585130 }, /* unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the bypass\000 */
{ 3587414 }, /* unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000 */
{ 3592593 }, /* unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000 */
{ 3592735 }, /* unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000 */
{ 3592913 }, /* unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000 */
{ 3593093 }, /* unc_h_directory_lat_opt\000uncore_ha\000uncore cache\000Directory Lat Opt Return. Unit: uncore_ha \000event=0x41\000\00001\000Directory Latency Optimization Data Return Path Taken. When directory mode is enabled and the directory returned for a read is Dir=I, then data can be returned using a faster path if certain conditions are met (credits, free pipeline, etc)\000 */
{ 3593702 }, /* unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that did not have to send any snoops because the directory bit was clear\000 */
{ 3594878 }, /* unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that had to send one or more snoops because the directory bit was set\000 */
{ 3596877 }, /* unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3597179 }, /* unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory clears.  This occurs when snoops were sent and all returned with RspI\000 */
{ 3599011 }, /* unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory sets.  This occurs when a remote read transaction requests memory, bringing it to a remote cache\000 */
{ 3612982 }, /* unc_h_hitme_hit.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is AckCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x4\000\00001\000\000 */
{ 3613133 }, /* unc_h_hitme_hit.all\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; All Requests. Unit: uncore_ha \000event=0x71,umask=0xff\000\00001\000\000 */
{ 3613272 }, /* unc_h_hitme_hit.allocs\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x70\000\00001\000\000 */
{ 3613413 }, /* unc_h_hitme_hit.evicts\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x42\000\00001\000\000 */
{ 3613716 }, /* unc_h_hitme_hit.hom\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; HOM Requests. Unit: uncore_ha \000event=0x71,umask=0xf\000\00001\000\000 */
{ 3613854 }, /* unc_h_hitme_hit.invals\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Invalidations. Unit: uncore_ha \000event=0x71,umask=0x26\000\00001\000\000 */
{ 3613997 }, /* unc_h_hitme_hit.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x71,umask=0x1\000\00001\000\000 */
{ 3614200 }, /* unc_h_hitme_hit.rsp\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x80\000\00001\000\000 */
{ 3614384 }, /* unc_h_hitme_hit.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x71,umask=0x20\000\00001\000\000 */
{ 3614567 }, /* unc_h_hitme_hit.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x71,umask=0x10\000\00001\000\000 */
{ 3614752 }, /* unc_h_hitme_hit.rspfwds\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x71,umask=0x40\000\00001\000\000 */
{ 3615246 }, /* unc_h_hitme_hit.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x71,umask=0x8\000\00001\000\000 */
{ 3615402 }, /* unc_h_hitme_hit.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI. Unit: uncore_ha \000event=0x71,umask=0x2\000\00001\000\000 */
{ 3615716 }, /* unc_h_hitme_hit_pv_bits_set.ackcnfltwbi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is AckCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x4\000\00001\000\000 */
{ 3615896 }, /* unc_h_hitme_hit_pv_bits_set.all\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; All Requests. Unit: uncore_ha \000event=0x72,umask=0xff\000\00001\000\000 */
{ 3616064 }, /* unc_h_hitme_hit_pv_bits_set.hom\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; HOM Requests. Unit: uncore_ha \000event=0x72,umask=0xf\000\00001\000\000 */
{ 3616231 }, /* unc_h_hitme_hit_pv_bits_set.read_or_invitoe\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x72,umask=0x1\000\00001\000\000 */
{ 3616463 }, /* unc_h_hitme_hit_pv_bits_set.rsp\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x80\000\00001\000\000 */
{ 3616676 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_local\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x72,umask=0x20\000\00001\000\000 */
{ 3616888 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_remote\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x72,umask=0x10\000\00001\000\000 */
{ 3617102 }, /* unc_h_hitme_hit_pv_bits_set.rspfwds\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x72,umask=0x40\000\00001\000\000 */
{ 3617287 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoe_or_s\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x72,umask=0x8\000\00001\000\000 */
{ 3617472 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoI. Unit: uncore_ha \000event=0x72,umask=0x2\000\00001\000\000 */
{ 3617642 }, /* unc_h_hitme_lookup.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is AckCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x4\000\00001\000\000 */
{ 3617806 }, /* unc_h_hitme_lookup.all\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; All Requests. Unit: uncore_ha \000event=0x70,umask=0xff\000\00001\000\000 */
{ 3617958 }, /* unc_h_hitme_lookup.allocs\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Allocations. Unit: uncore_ha \000event=0x70,umask=0x70\000\00001\000\000 */
{ 3618112 }, /* unc_h_hitme_lookup.hom\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; HOM Requests. Unit: uncore_ha \000event=0x70,umask=0xf\000\00001\000\000 */
{ 3618263 }, /* unc_h_hitme_lookup.invals\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Invalidations. Unit: uncore_ha \000event=0x70,umask=0x26\000\00001\000\000 */
{ 3618583 }, /* unc_h_hitme_lookup.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x70,umask=0x1\000\00001\000\000 */
{ 3618799 }, /* unc_h_hitme_lookup.rsp\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x80\000\00001\000\000 */
{ 3618996 }, /* unc_h_hitme_lookup.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x70,umask=0x20\000\00001\000\000 */
{ 3619192 }, /* unc_h_hitme_lookup.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x70,umask=0x10\000\00001\000\000 */
{ 3619390 }, /* unc_h_hitme_lookup.rspfwds\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x70,umask=0x40\000\00001\000\000 */
{ 3619559 }, /* unc_h_hitme_lookup.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x70,umask=0x8\000\00001\000\000 */
{ 3619728 }, /* unc_h_hitme_lookup.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoI. Unit: uncore_ha \000event=0x70,umask=0x2\000\00001\000\000 */
{ 3627792 }, /* unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628119 }, /* unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628446 }, /* unc_h_igr_no_credit_cycles.ad_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628774 }, /* unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629101 }, /* unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629428 }, /* unc_h_igr_no_credit_cycles.bl_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629756 }, /* unc_h_imc_reads.normal\000uncore_ha\000uncore cache\000HA to iMC Normal Priority Reads Issued; Normal Priority. Unit: uncore_ha \000event=0x17,umask=0x1\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 3630382 }, /* unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000 */
{ 3630468 }, /* unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3630784 }, /* unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631110 }, /* unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631438 }, /* unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631765 }, /* unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3649797 }, /* unc_h_iot_backpressure.hub\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x2\000\00001\000\000 */
{ 3649908 }, /* unc_h_iot_backpressure.sat\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x1\000\00001\000\000 */
{ 3650019 }, /* unc_h_iot_cts_east_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650171 }, /* unc_h_iot_cts_east_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650323 }, /* unc_h_iot_cts_hi.cts2\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650470 }, /* unc_h_iot_cts_hi.cts3\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650617 }, /* unc_h_iot_cts_west_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650769 }, /* unc_h_iot_cts_west_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3652460 }, /* unc_h_osb.cancelled\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Cancelled. Unit: uncore_ha \000event=0x53,umask=0x10\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB.; OSB Snoop broadcast cancelled due to D2C or Other. OSB cancel is counted when OSB local read is not allowed even when the transaction in local InItoE. It also counts D2C OSB cancel, but also includes the cases were D2C was not set in the first place for the transaction coming from the ring\000 */
{ 3653009 }, /* unc_h_osb.invitoe_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local InvItoE. Unit: uncore_ha \000event=0x53,umask=0x4\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653272 }, /* unc_h_osb.reads_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local Reads. Unit: uncore_ha \000event=0x53,umask=0x2\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653531 }, /* unc_h_osb.reads_local_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Reads Local -  Useful. Unit: uncore_ha \000event=0x53,umask=0x20\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653808 }, /* unc_h_osb.remote\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote. Unit: uncore_ha \000event=0x53,umask=0x8\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654057 }, /* unc_h_osb.remote_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote - Useful. Unit: uncore_ha \000event=0x53,umask=0x40\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654449 }, /* unc_h_osb_edr.all\000uncore_ha\000uncore cache\000OSB Early Data Return; All. Unit: uncore_ha \000event=0x54,umask=0x1\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654695 }, /* unc_h_osb_edr.reads_local_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local  I. Unit: uncore_ha \000event=0x54,umask=0x2\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654965 }, /* unc_h_osb_edr.reads_local_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local S. Unit: uncore_ha \000event=0x54,umask=0x8\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655234 }, /* unc_h_osb_edr.reads_remote_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote I. Unit: uncore_ha \000event=0x54,umask=0x4\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655505 }, /* unc_h_osb_edr.reads_remote_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote S. Unit: uncore_ha \000event=0x54,umask=0x10\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3657030 }, /* unc_h_requests.invitoe_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x10\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from the local socket\000 */
{ 3657584 }, /* unc_h_requests.invitoe_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x20\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from remote sockets\000 */
{ 3658081 }, /* unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming ead requests.  This is a good proxy for LLC Read Misses (including RFOs)\000 */
{ 3658883 }, /* unc_h_requests.reads_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Reads. Unit: uncore_ha \000event=0x1,umask=0x1\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the local socket.  This is a good proxy for LLC Read Misses (including RFOs) from the local socket\000 */
{ 3659475 }, /* unc_h_requests.reads_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Reads. Unit: uncore_ha \000event=0x1,umask=0x2\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the remote socket.  This is a good proxy for LLC Read Misses (including RFOs) from the remote socket\000 */
{ 3660059 }, /* unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming write requests\000 */
{ 3660809 }, /* unc_h_requests.writes_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Writes. Unit: uncore_ha \000event=0x1,umask=0x4\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from the local socket\000 */
{ 3661316 }, /* unc_h_requests.writes_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Writes. Unit: uncore_ha \000event=0x1,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from remote sockets\000 */
{ 3661687 }, /* unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3662382 }, /* unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3663162 }, /* unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3666081 }, /* unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3666420 }, /* unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3667177 }, /* unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3669673 }, /* unc_h_ring_ak_used.all\000uncore_ha\000uncore cache\000HA AK Ring in Use; All. Unit: uncore_ha \000event=0x3f,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3670007 }, /* unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3670702 }, /* unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3671482 }, /* unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3674401 }, /* unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3674740 }, /* unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3675497 }, /* unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3677993 }, /* unc_h_ring_bl_used.all\000uncore_ha\000uncore cache\000HA BL Ring in Use; All. Unit: uncore_ha \000event=0x40,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3678327 }, /* unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3679022 }, /* unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3679802 }, /* unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3682721 }, /* unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3683060 }, /* unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3683817 }, /* unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3693072 }, /* unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3694856 }, /* unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3696640 }, /* unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3698424 }, /* unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3700168 }, /* unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3701870 }, /* unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3703572 }, /* unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3705274 }, /* unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3733425 }, /* unc_h_sbo0_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733616 }, /* unc_h_sbo0_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733807 }, /* unc_h_sbo0_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x68,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3733999 }, /* unc_h_sbo0_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x68,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3734191 }, /* unc_h_sbo1_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734382 }, /* unc_h_sbo1_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734573 }, /* unc_h_sbo1_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x69,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3734765 }, /* unc_h_sbo1_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x69,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3736413 }, /* unc_h_snoop_cycles_ne.all\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; All Requests. Unit: uncore_ha \000event=0x8,umask=0x3\000\00001\000Counts cycles when one or more snoops are outstanding.; Tracked for snoops from both local and remote sockets\000 */
{ 3736659 }, /* unc_h_snoop_cycles_ne.local\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Local Requests. Unit: uncore_ha \000event=0x8,umask=0x1\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from the local socket\000 */
{ 3736919 }, /* unc_h_snoop_cycles_ne.remote\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Remote Requests. Unit: uncore_ha \000event=0x8,umask=0x2\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from remote sockets\000 */
{ 3737179 }, /* unc_h_snoop_occupancy.local\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Local Requests. Unit: uncore_ha \000event=0x9,umask=0x1\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from the local socket\000 */
{ 3737841 }, /* unc_h_snoop_occupancy.remote\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Remote Requests. Unit: uncore_ha \000event=0x9,umask=0x2\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from remote sockets\000 */
{ 3739531 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*Fwd*WB. Unit: uncore_ha \000event=0x21,umask=0x20\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3740517 }, /* unc_h_snoop_resp.rsp_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*WB. Unit: uncore_ha \000event=0x21,umask=0x10\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3741525 }, /* unc_h_snoop_resp.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received; RSPCNFLCT*. Unit: uncore_ha \000event=0x21,umask=0x40\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3742665 }, /* unc_h_snoop_resp.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received; RspI. Unit: uncore_ha \000event=0x21,umask=0x1\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3744395 }, /* unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspIFwd. Unit: uncore_ha \000event=0x21,umask=0x4\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3746136 }, /* unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received; RspS. Unit: uncore_ha \000event=0x21,umask=0x2\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3748619 }, /* unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspSFwd. Unit: uncore_ha \000event=0x21,umask=0x8\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3750143 }, /* unc_h_snoops_rsp_after_data.local\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Local Requests. Unit: uncore_ha \000event=0xa,umask=0x1\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from the local socket\000 */
{ 3750440 }, /* unc_h_snoops_rsp_after_data.remote\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Remote Requests. Unit: uncore_ha \000event=0xa,umask=0x2\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from remote sockets\000 */
{ 3751926 }, /* unc_h_snp_resp_recv_local.other\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Other. Unit: uncore_ha \000event=0x60,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for all other snoop responses\000 */
{ 3752158 }, /* unc_h_snp_resp_recv_local.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_ha \000event=0x60,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3752627 }, /* unc_h_snp_resp_recv_local.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_ha \000event=0x60,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3753011 }, /* unc_h_snp_resp_recv_local.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_ha \000event=0x60,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3753465 }, /* unc_h_snp_resp_recv_local.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_ha \000event=0x60,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3753887 }, /* unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3754721 }, /* unc_h_snp_resp_recv_local.rspxfwdxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_ha \000event=0x60,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3755195 }, /* unc_h_snp_resp_recv_local.rspxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_ha \000event=0x60,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3757116 }, /* unc_h_stall_no_sbo_credit.sbo0_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757360 }, /* unc_h_stall_no_sbo_credit.sbo0_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757604 }, /* unc_h_stall_no_sbo_credit.sbo1_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757848 }, /* unc_h_stall_no_sbo_credit.sbo1_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3763538 }, /* unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 0\000 */
{ 3765043 }, /* unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 1\000 */
{ 3766548 }, /* unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 2\000 */
{ 3768053 }, /* unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 3\000 */
{ 3769559 }, /* unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 4\000 */
{ 3771066 }, /* unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 5\000 */
{ 3772573 }, /* unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 6\000 */
{ 3774080 }, /* unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 7\000 */
{ 3775589 }, /* unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 10\000 */
{ 3777101 }, /* unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 11\000 */
{ 3778611 }, /* unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 8\000 */
{ 3780118 }, /* unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 9\000 */
{ 3793272 }, /* unc_h_tracker_cycles_full.all\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles Completely Used. Unit: uncore_ha \000event=0x2,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the HA tracker pool (HT) is completely used including reserved HT entries.  It will not return valid count when BT is disabled\000 */
{ 3794203 }, /* unc_h_tracker_cycles_full.gp\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles GP Completely Used. Unit: uncore_ha \000event=0x2,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the general purpose (GP) HA tracker pool (HT) is completely used.  It will not return valid count when BT is disabled\000 */
{ 3795127 }, /* unc_h_tracker_cycles_ne.all\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; All Requests. Unit: uncore_ha \000event=0x3,umask=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Requests coming from both local and remote sockets\000 */
{ 3796110 }, /* unc_h_tracker_cycles_ne.local\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Local Requests. Unit: uncore_ha \000event=0x3,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from the local socket\000 */
{ 3797110 }, /* unc_h_tracker_cycles_ne.remote\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Remote Requests. Unit: uncore_ha \000event=0x3,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from remote sockets\000 */
{ 3799550 }, /* unc_h_tracker_occupancy.invitoe_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x40\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800176 }, /* unc_h_tracker_occupancy.invitoe_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x80\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800804 }, /* unc_h_tracker_occupancy.reads_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Read Requests. Unit: uncore_ha \000event=0x4,umask=0x4\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3801424 }, /* unc_h_tracker_occupancy.reads_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Read Requests. Unit: uncore_ha \000event=0x4,umask=0x8\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802046 }, /* unc_h_tracker_occupancy.writes_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Write Requests. Unit: uncore_ha \000event=0x4,umask=0x10\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802669 }, /* unc_h_tracker_occupancy.writes_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Write Requests. Unit: uncore_ha \000event=0x4,umask=0x20\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3803294 }, /* unc_h_tracker_pending_occupancy.local\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Local Requests. Unit: uncore_ha \000event=0x5,umask=0x1\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from the local socket\000 */
{ 3803895 }, /* unc_h_tracker_pending_occupancy.remote\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Remote Requests. Unit: uncore_ha \000event=0x5,umask=0x2\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from remote sockets\000 */
{ 3804496 }, /* unc_h_txr_ad.hom\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x4\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details.; Filter for outbound NDR transactions sent on the AD ring.  NDR stands for non-data response and is generally used for completions that do not include data.  AD NDR is used for transactions to remote sockets\000 */
{ 3805581 }, /* unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000AD Egress Full; Cycles full from both schedulers\000 */
{ 3805861 }, /* unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3806176 }, /* unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3806491 }, /* unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000AD Egress Not Empty; Cycles full from both schedulers\000 */
{ 3806782 }, /* unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000AD Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3807113 }, /* unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000AD Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3807443 }, /* unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000AD Egress Allocations; Allocations from both schedulers\000 */
{ 3807736 }, /* unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3808063 }, /* unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3809300 }, /* unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000AK Egress Full; Cycles full from both schedulers\000 */
{ 3809580 }, /* unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3809895 }, /* unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3810210 }, /* unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000AK Egress Not Empty; Cycles full from both schedulers\000 */
{ 3810501 }, /* unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000AK Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3810832 }, /* unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000AK Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3811162 }, /* unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000AK Egress Allocations; Allocations from both schedulers\000 */
{ 3811455 }, /* unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3811782 }, /* unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3813194 }, /* unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to the cache\000 */
{ 3813726 }, /* unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent directly to the requesting core\000 */
{ 3814273 }, /* unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to a remote socket over QPI\000 */
{ 3814812 }, /* unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000BL Egress Full; Cycles full from both schedulers\000 */
{ 3815092 }, /* unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3815407 }, /* unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3815722 }, /* unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000BL Egress Not Empty; Cycles full from both schedulers\000 */
{ 3816013 }, /* unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000BL Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3816344 }, /* unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000BL Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3816674 }, /* unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000BL Egress Allocations; Allocations from both schedulers\000 */
{ 3816967 }, /* unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3817294 }, /* unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3826497 }, /* unc_h_txr_starved.ak\000uncore_ha\000uncore cache\000Injection Starvation; For AK Ring. Unit: uncore_ha \000event=0x6d,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3826759 }, /* unc_h_txr_starved.bl\000uncore_ha\000uncore cache\000Injection Starvation; For BL Ring. Unit: uncore_ha \000event=0x6d,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3843414 }, /* unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3845224 }, /* unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3847034 }, /* unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3848844 }, /* unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3850614 }, /* unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3852342 }, /* unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3854070 }, /* unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3855798 }, /* unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3871403 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3873716 }, /* unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3876751 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000 */
{ 3877660 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878039 }, /* unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878409 }, /* unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878795 }, /* unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879191 }, /* unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879386 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIItoM. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3880060 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000Coherent Ops; RFO. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3881086 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3883149 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x10\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary\000 */
{ 3883756 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x4\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary\000 */
{ 3884348 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x8\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary\000 */
{ 3884906 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Counts Timeouts - Set 0 : Fastpath Rejects\000 */
{ 3885359 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Counts Timeouts - Set 0 : Fastpath Requests\000 */
{ 3885844 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x20\000\00001\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary\000 */
{ 3886416 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x40\000\00001\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary\000 */
{ 3886820 }, /* unc_i_misc0.pf_timeout\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch TimeOut. Unit: uncore_irp \000event=0x14,umask=0x80\000\00001\000Indicates the fetch for a previous prefetch wasn't accepted by the prefetch.   This happens in the case of a prefetch TimeOut\000 */
{ 3887372 }, /* unc_i_misc1.data_throttle\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Data Throttled. Unit: uncore_irp \000event=0x15,umask=0x80\000\00001\000IRP throttled switch data\000 */
{ 3887762 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1. Unit: uncore_irp \000event=0x15,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888414 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x15,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3889079 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x15,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889739 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890405 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891075 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x15,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891747 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3895230 }, /* unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895678 }, /* unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_CYCLES_FULL. Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896298 }, /* unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896614 }, /* unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_OCCUPANCY. Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897234 }, /* unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_CYCLES_FULL. Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897854 }, /* unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898170 }, /* unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_OCCUPANCY. Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898790 }, /* unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_CYCLES_FULL. Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899410 }, /* unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899726 }, /* unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_OCCUPANCY. Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3901893 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x17,umask=0x4\000\00001\000Snoop Responses : Hit E or S\000 */
{ 3902294 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Snoop Responses : Hit I\000 */
{ 3902684 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x17,umask=0x8\000\00001\000Snoop Responses : Hit M\000 */
{ 3903070 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Snoop Responses : Miss\000 */
{ 3903467 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x17,umask=0x10\000\00001\000Snoop Responses : SnpCode\000 */
{ 3903874 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x17,umask=0x20\000\00001\000Snoop Responses : SnpData\000 */
{ 3904277 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x17,umask=0x40\000\00001\000Snoop Responses : SnpInv\000 */
{ 3907099 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x16,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000 */
{ 3908632 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x16,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000 */
{ 3910563 }, /* unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x16,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3913028 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3913535 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Write Prefetches. Unit: uncore_irp \000event=0x16,umask=0x8\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of write prefetches\000 */
{ 3917521 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests\000 */
{ 3921293 }, /* unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3921548 }, /* unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3921798 }, /* unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3921985 }, /* unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3922172 }, /* unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 6074014 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076954 }, /* unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077187 }, /* unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077419 }, /* unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077656 }, /* unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6081974 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6082839 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000 */
{ 6083291 }, /* unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6083494 }, /* unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6083890 }, /* unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084282 }, /* unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084686 }, /* unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6085090 }, /* unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores; PREQ, PSMI, P2U, Thermal, PCUSMI, PMI\000 */
{ 6085499 }, /* unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085682 }, /* unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 5850201 }, /* unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5850571 }, /* unc_r2_iio_credit.isoch_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x4\000\00001\000\000 */
{ 5850701 }, /* unc_r2_iio_credit.isoch_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x8\000\00001\000\000 */
{ 5850831 }, /* unc_r2_iio_credit.prq_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 5850957 }, /* unc_r2_iio_credit.prq_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 5851083 }, /* unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5852294 }, /* unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5853507 }, /* unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5856769 }, /* unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5857982 }, /* unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5859197 }, /* unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5860412 }, /* unc_r2_ring_ad_used.all\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; All. Unit: uncore_r2pcie \000event=0x7,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5860751 }, /* unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5861456 }, /* unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5862246 }, /* unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5865200 }, /* unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5865544 }, /* unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5866311 }, /* unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5868837 }, /* unc_r2_ring_ak_bounces.dn\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Dn. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869035 }, /* unc_r2_ring_ak_bounces.up\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Up. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869233 }, /* unc_r2_ring_ak_used.all\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; All. Unit: uncore_r2pcie \000event=0x8,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5869572 }, /* unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5870277 }, /* unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5871067 }, /* unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5874021 }, /* unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5874365 }, /* unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5875132 }, /* unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5877658 }, /* unc_r2_ring_bl_used.all\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; All. Unit: uncore_r2pcie \000event=0x9,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5877997 }, /* unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5878702 }, /* unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5879492 }, /* unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5882446 }, /* unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5882790 }, /* unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5883557 }, /* unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5886083 }, /* unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5887540 }, /* unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5889079 }, /* unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5890495 }, /* unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5891469 }, /* unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5892443 }, /* unc_r2_rxr_inserts.ncb\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCB. Unit: uncore_r2pcie \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5892923 }, /* unc_r2_rxr_inserts.ncs\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCS. Unit: uncore_r2pcie \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5893403 }, /* unc_r2_rxr_occupancy.drs\000uncore_r2pcie\000uncore io\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r2pcie \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given R2PCIe Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the R2PCIe Ingress Not Empty event to calculate average occupancy or the R2PCIe Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5893855 }, /* unc_r2_sbo0_credit_occupancy.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894052 }, /* unc_r2_sbo0_credit_occupancy.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894249 }, /* unc_r2_sbo0_credits_acquired.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894447 }, /* unc_r2_sbo0_credits_acquired.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894645 }, /* unc_r2_stall_no_sbo_credit.sbo0_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5894895 }, /* unc_r2_stall_no_sbo_credit.sbo0_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895145 }, /* unc_r2_stall_no_sbo_credit.sbo1_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895395 }, /* unc_r2_stall_no_sbo_credit.sbo1_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895645 }, /* unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AD Egress Queue\000 */
{ 5896035 }, /* unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AK Egress Queue\000 */
{ 5896425 }, /* unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; BL Egress Queue\000 */
{ 5896815 }, /* unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AD Egress Queue\000 */
{ 5897859 }, /* unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AK Egress Queue\000 */
{ 5898903 }, /* unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; BL Egress Queue\000 */
{ 5900823 }, /* unc_r2_txr_nack_cw.dn_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5900976 }, /* unc_r2_txr_nack_cw.dn_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5901129 }, /* unc_r2_txr_nack_cw.dn_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901282 }, /* unc_r2_txr_nack_cw.up_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901435 }, /* unc_r2_txr_nack_cw.up_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000 */
{ 5901581 }, /* unc_r2_txr_nack_cw.up_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5376386 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377260 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5380151 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5382226 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 5385713 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5386574 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5386724 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the number of underfill reads that are issued by the memory controller.  This will generally be about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ.  While it is possible for underfills to be issed in both WMM and RMM, this event counts both\000 */
{ 5388684 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5389726 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5391708 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392506 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5395982 }, /* unc_m_dclockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417303 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430087 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5430855 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5439445 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of page misses.  This does not include explicit precharge commands sent with CAS commands in Auto-Precharge mode.  This does not include PRE commands sent as a result of the page close counter expiration\000 */
{ 5442207 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5444600 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449351 }, /* unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5449781 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5451793 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5450047 }, /* unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5450338 }, /* unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5450629 }, /* unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5450920 }, /* unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5451211 }, /* unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5451502 }, /* unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5452206 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5452619 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5453160 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5453574 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5453988 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5454274 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5454688 }, /* unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5454974 }, /* unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5455260 }, /* unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5455604 }, /* unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5455948 }, /* unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5456295 }, /* unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5456645 }, /* unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5457075 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5459087 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5457341 }, /* unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5457632 }, /* unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5457923 }, /* unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5458214 }, /* unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5458505 }, /* unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5458796 }, /* unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5459500 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5459913 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5460454 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5460868 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5461282 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5461568 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5461982 }, /* unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5462268 }, /* unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5462554 }, /* unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5462898 }, /* unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5463242 }, /* unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5463589 }, /* unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5464200 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5471646 }, /* unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5472076 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5474088 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5472342 }, /* unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5472633 }, /* unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5472924 }, /* unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5473215 }, /* unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5473506 }, /* unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5473797 }, /* unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5474501 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5474914 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5475455 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5475869 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5476283 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5476569 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5476983 }, /* unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5477269 }, /* unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5477555 }, /* unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5477899 }, /* unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5478243 }, /* unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5478590 }, /* unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5478940 }, /* unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5479370 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5481382 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5479636 }, /* unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5479927 }, /* unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5480218 }, /* unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5480509 }, /* unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5480800 }, /* unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5481091 }, /* unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5481795 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5482208 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5482749 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5483163 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5483577 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5483863 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5484277 }, /* unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5484563 }, /* unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5484849 }, /* unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5485193 }, /* unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5485537 }, /* unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5485884 }, /* unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5486234 }, /* unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5486664 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5488676 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5486930 }, /* unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5487221 }, /* unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5487512 }, /* unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5487803 }, /* unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5488094 }, /* unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5488385 }, /* unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5489089 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5489502 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5490043 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5490457 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5490871 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5491157 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5491571 }, /* unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5491857 }, /* unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5492143 }, /* unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5492487 }, /* unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5492831 }, /* unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5493178 }, /* unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5493528 }, /* unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5493958 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5495970 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5494224 }, /* unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5494515 }, /* unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5494806 }, /* unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5495097 }, /* unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5495388 }, /* unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5495679 }, /* unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5496383 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5496796 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5497337 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5497751 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5498165 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5498451 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5498865 }, /* unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5499151 }, /* unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5499437 }, /* unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5499781 }, /* unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5500125 }, /* unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5500472 }, /* unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5508571 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5534086 }, /* unc_m_vmse_mxb_wr_occupancy\000uncore_imc\000uncore memory\000VMSE MXB write buffer occupancy. Unit: uncore_imc \000event=0x91\000\00001\000\000 */
{ 5534206 }, /* unc_m_vmse_wr_push.rmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in RMM. Unit: uncore_imc \000event=0x90,umask=0x2\000\00001\000\000 */
{ 5534350 }, /* unc_m_vmse_wr_push.wmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in WMM. Unit: uncore_imc \000event=0x90,umask=0x1\000\00001\000\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5534994 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5540700 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556495 }, /* unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5556925 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5558937 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5557191 }, /* unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5557482 }, /* unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5557773 }, /* unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5558064 }, /* unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5558355 }, /* unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5558646 }, /* unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5559350 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5559763 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5560304 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5560718 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5561132 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5561418 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5561832 }, /* unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5562118 }, /* unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5562404 }, /* unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5562748 }, /* unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5563092 }, /* unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5563439 }, /* unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5563789 }, /* unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5564219 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5566231 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5564485 }, /* unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5564776 }, /* unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5565067 }, /* unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5565358 }, /* unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5565649 }, /* unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5565940 }, /* unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5566644 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5567057 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5567598 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5568012 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5568426 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5568712 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5569126 }, /* unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5569412 }, /* unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5569698 }, /* unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5570042 }, /* unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5570386 }, /* unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5570733 }, /* unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5578641 }, /* unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5579071 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5581083 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5579337 }, /* unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5579628 }, /* unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5579919 }, /* unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5580210 }, /* unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5580501 }, /* unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5580792 }, /* unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5581496 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5581909 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5582450 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5582864 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5583278 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5583564 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5583978 }, /* unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5584264 }, /* unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5584550 }, /* unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5584894 }, /* unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5585238 }, /* unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5585585 }, /* unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5585935 }, /* unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5586365 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5588377 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5586631 }, /* unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5586922 }, /* unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5587213 }, /* unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5587504 }, /* unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5587795 }, /* unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5588086 }, /* unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5588790 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5589203 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5589744 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5590158 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5590572 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5590858 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5591272 }, /* unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5591558 }, /* unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5591844 }, /* unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5592188 }, /* unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5592532 }, /* unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5592879 }, /* unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5593229 }, /* unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5593659 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5595671 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5593925 }, /* unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5594216 }, /* unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5594507 }, /* unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5594798 }, /* unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5595089 }, /* unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5595380 }, /* unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5596084 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5596497 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5597038 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5597452 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5597866 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5598152 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5598566 }, /* unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5598852 }, /* unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5599138 }, /* unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5599482 }, /* unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5599826 }, /* unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5600173 }, /* unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5600523 }, /* unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5600953 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5602965 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5601219 }, /* unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5601510 }, /* unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5601801 }, /* unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5602092 }, /* unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5602383 }, /* unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5602674 }, /* unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5603378 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5603791 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5604332 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5604746 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5605160 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5605446 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5605860 }, /* unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5606146 }, /* unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5606432 }, /* unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5606776 }, /* unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5607120 }, /* unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5607467 }, /* unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5641706 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5642773 }, /* unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x60\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643193 }, /* unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643614 }, /* unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644035 }, /* unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644456 }, /* unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644877 }, /* unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645086 }, /* unc_p_core15_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6f\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645295 }, /* unc_p_core16_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645504 }, /* unc_p_core17_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646130 }, /* unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646755 }, /* unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647173 }, /* unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647798 }, /* unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x64\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648423 }, /* unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x65\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649048 }, /* unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x66\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649673 }, /* unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x67\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650298 }, /* unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x68\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650716 }, /* unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x69\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5656797 }, /* unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x30\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659691 }, /* unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x31\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657159 }, /* unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3a\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657522 }, /* unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3b\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657885 }, /* unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3c\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658248 }, /* unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3d\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658611 }, /* unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658791 }, /* unc_p_demotions_core15\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658971 }, /* unc_p_demotions_core16\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659151 }, /* unc_p_demotions_core17\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660230 }, /* unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x32\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660769 }, /* unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x33\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661308 }, /* unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x34\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661847 }, /* unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x35\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662386 }, /* unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x36\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662925 }, /* unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x37\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663285 }, /* unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x38\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663645 }, /* unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x39\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668753 }, /* unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670355 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673025 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5675706 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676395 }, /* unc_p_pkg_residency_c1e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C1E. Unit: uncore_pcu \000event=0x4e\000\00001\000Counts the number of cycles when the package was in C1E.  This event can be used in conjunction with edge detect to count C1E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676727 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677425 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678114 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678803 }, /* unc_p_pkg_residency_c7_cycles\000uncore_pcu\000uncore power\000Package C7 State Residency. Unit: uncore_pcu \000event=0x2e\000\00001\000Counts the number of cycles when the package was in C7.  This event can be used in conjunction with edge detect to count C7 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685850 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5686659 }, /* unc_p_ufs_transitions_ring_gv\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_RING_GV. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 788035 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x8,period=100003,umask=0x1\000\00000\000This event counts load misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 790726 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000\000 */
{ 792298 }, /* dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000\000 */
{ 792704 }, /* dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000\000 */
{ 794649 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size  Spec update: BDM69\000event=0x8,period=100003,umask=0xe\000\00000\000\000 */
{ 797668 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x8\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 800344 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 803676 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x2\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 806216 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 810390 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 812771 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000\000 */
{ 814338 }, /* dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000\000 */
{ 814749 }, /* dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000\000 */
{ 816911 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0xe\000\00000\000\000 */
{ 820829 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (1G)  Spec update: BDM69\000event=0x49,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 824198 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)  Spec update: BDM69\000event=0x49,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 827282 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x49,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 828248 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 833208 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000This event counts cycles for an extended page table walk. The Extended Page directory cache differs from standard TLB caches by the operating system that use it. Virtual machine operating systems use the extended page directory cache, while guest operating systems use the standard TLB caches\000 */
{ 1078539 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000This event counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080623 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 1083626 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000\000 */
{ 1084532 }, /* itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000\000 */
{ 1084832 }, /* itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1087487 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0xe\000\00000\000\000 */
{ 1089713 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x85,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1090540 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)  Spec update: BDM69\000event=0x85,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1093387 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x85,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1095831 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 2468040 }, /* page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x11\000\00000\000\000 */
{ 2468379 }, /* page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x12\000\00000\000\000 */
{ 2468709 }, /* page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x14\000\00000\000\000 */
{ 2469093 }, /* page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x18\000\00000\000\000 */
{ 2470830 }, /* page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x21\000\00000\000\000 */
{ 2471169 }, /* page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x22\000\00000\000\000 */
{ 2471499 }, /* page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x24\000\00000\000\000 */
{ 2540692 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000This event counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541489 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000This event counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, and so on)\000 */
};

static const struct compact_pmu_event pmu_metrics__broadwellde[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51523 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 54742 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 61074 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71807 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 79280 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000MACHINE_CLEARS.COUNT * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 89451 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 104182 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 117244 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 118350 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 128710 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 132703 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_LOAD_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 141077 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_STORE_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 155428 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 161551 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 164336 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 176343 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 187717 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194092 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197756 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 218790 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 221371 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 224070 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 231407 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239076 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248732 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 254949 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * (DTLB_STORE_MISSES.WALK_COMPLETED + DTLB_LOAD_MISSES.WALK_COMPLETED + ITLB_MISSES.WALK_COMPLETED)) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 259745 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (arb@event\\=0x81\\,umask\\=0x1@ + arb@event\\=0x84\\,umask\\=0x1@) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 260736 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 282280 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * ITLB_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 289318 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 294855 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 301728 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 316945 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00002 */
{ 326649 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 334406 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 344458 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + RESOURCE_STALLS.SB) / (CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 351433 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 353858 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost\000100%\000\000\000\00000 */
{ 356236 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 378550 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 381505 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383564 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000\000100%\000\000\000\00000 */
{ 384298 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000\000100%\000\000\000\00000 */
{ 384578 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 385958 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 388958 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 391176 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000\000100%\000\000\000\00000 */
{ 395006 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 400762 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (CYCLE_ACTIVITY.STALLS_TOTAL - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 406224 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 412962 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 417616 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 434458 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 441070 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 442687 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 448531 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456422 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 461303 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000tma_branch_resteers - tma_mispredicts_resteers - tma_clears_resteers\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000 */
{ 461970 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__broadwellx[] = {
{ 1101501 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1110022 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand; from the demand Hit FB, if it is allocated by hardware or software prefetch.\nNote: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112707 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1123947 }, /* l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000This event counts the number of WB requests that hit L2 cache\000 */
{ 1129220 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1129900 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000This event counts the number of L2 cache lines in the Exclusive state filling the L2. Counting does not cover rejects\000 */
{ 1130448 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000This event counts the number of L2 cache lines in the Invalidate state filling the L2. Counting does not cover rejects\000 */
{ 1130896 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000This event counts the number of L2 cache lines in the Shared state filling the L2. Counting does not cover rejects\000 */
{ 1132063 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000\000 */
{ 1157444 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000This event counts the total number of L2 code requests\000 */
{ 1158790 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000This event counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159885 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000\000 */
{ 1160630 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000\000 */
{ 1161474 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000This event counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162439 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000This event counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163612 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000\000 */
{ 1164549 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166774 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000This event counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1168158 }, /* l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that hit L2 cache. L3 prefetch new types\000 */
{ 1168537 }, /* l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000This event counts the number of requests from the L2 hardware prefetchers that miss L2 cache\000 */
{ 1169474 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000\000 */
{ 1172732 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000\000 */
{ 1174367 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000\000 */
{ 1175046 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000\000 */
{ 1179588 }, /* l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000This event counts L2 or L3 HW prefetches that access L2 cache including rejects\000 */
{ 1180048 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000This event counts transactions that access the L2 pipe including snoops, pagewalks, and so on\000 */
{ 1180627 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000This event counts the number of L2 cache accesses when fetching instructions\000 */
{ 1181249 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000This event counts Demand Data Read requests that access L2 cache, including rejects\000 */
{ 1181703 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000This event counts L1D writebacks that access L2 cache\000 */
{ 1182096 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000This event counts L2 fill requests that access L2 cache\000 */
{ 1182628 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000This event counts L2 writebacks that access L2 cache\000 */
{ 1183167 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000This event counts Read for Ownership (RFO) requests that access L2 cache\000 */
{ 1245649 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000This event counts the number of cycles when the L1D is locked. It is a superset of the 0x1 mask (BUS_LOCK_CLOCKS.BUS_LOCK_DURATION)\000 */
{ 1247290 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts core-originated cacheable demand requests that miss the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1251000 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts core-originated cacheable demand requests that refer to the last level cache (LLC). Demand requests include loads, RFOs, and hardware prefetches from L1D, and instruction fetches from IFU\000 */
{ 1341691 }, /* mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops which data sources were L3 hit and a cross-core snoop hit in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1342388 }, /* mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops which data sources were HitM responses from a core on same socket (shared L3)  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343042 }, /* mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000This event counts retired load uops which data sources were L3 Hit and a cross-core snoop missed in the on-pkg core cache  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1343756 }, /* mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1344433 }, /* mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uop whose Data Source was: local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70, BDM100 (Precise event)\000 */
{ 1345280 }, /* mem_load_uops_l3_miss_retired.remote_dram\000\000cache\000Retired load uop whose Data Source was: remote DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000\000 */
{ 1345795 }, /* mem_load_uops_l3_miss_retired.remote_fwd\000\000cache\000Retired load uop whose Data Source was: forwarded from remote cache  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x20\000\00000\000\000 */
{ 1346245 }, /* mem_load_uops_l3_miss_retired.remote_hitm\000\000cache\000Retired load uop whose Data Source was: Remote cache HITM  Supports address when precise.  Spec update: BDE70 (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000\000 */
{ 1353644 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000This event counts retired load uops which data sources were load uops missed L1 but hit a fill buffer due to a preceding miss to the same cache line with the data not ready.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load  Supports address when precise (Precise event)\000 */
{ 1356844 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000This event counts retired load uops which data sources were hits in the nearest-level (L1) cache.\nNote: Only two data-sources of L1/FB are applicable for AVX-256bit  even though the corresponding AVX load could be serviced by a deeper level in the memory hierarchy. Data source is reported for the Low-half load. This event also counts SW prefetches independent of the actual data source  Supports address when precise (Precise event)\000 */
{ 1358647 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000This event counts retired load uops which data sources were misses in the nearest-level (L1) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1360141 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000This event counts retired load uops which data sources were hits in the mid-level (L2) cache  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1361888 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000This event counts retired load uops which data sources were misses in the mid-level (L2) cache. Counting excludes unknown and UC data source  Supports address when precise (Precise event)\000 */
{ 1363119 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops which data sources were data hits in the last-level (L3) cache without snoops required  Supports address when precise.  Spec update: BDM100 (Precise event)\000 */
{ 1364330 }, /* mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: BDM100, BDE70 (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1390113 }, /* mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1392489 }, /* mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise (Precise event)\000 */
{ 1415479 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: BDM35 (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000This event counts load uops with locked access retired to the architected path  Supports address when precise.  Spec update: BDM35 (Precise event)\000 */
{ 1417829 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1419597 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K)  Supports address when precise (Precise event)\000 */
{ 1421539 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000This event counts load uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1422607 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000This event counts store uops with true STLB miss retired to the architected path. True STLB miss is an uop triggering page walk that gets completed without blocks, and later gets retired. This page walk can end up with or without a fault  Supports address when precise (Precise event)\000 */
{ 1745359 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000This event counts the demand and prefetch data reads. All Core Data Reads include cacheable Demands and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746038 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000This event counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, and so on\000 */
{ 1748542 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000This event counts both cacheable and non-cacheable code read requests\000 */
{ 1750433 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000This event counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751556 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000This event counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753800 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000This event counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.\nNote: Writeback pending FIFO has six entries\000 */
{ 1754992 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x8\000\00000\000This event counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1757948 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1762576 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000This event counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)  Spec update: BDM76\000 */
{ 1766481 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1770828 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: BDM76\000event=0x60,period=2000003,umask=0x2\000\00000\000This event counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The Offcore outstanding state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 1773190 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,period=2000003,umask=0x1\000\00000\000This event counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.\nNote: A prefetch promoted to Demand is counted from the promotion point  Spec update: BDM76\000 */
{ 1775673 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: BDM76\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1776605 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: BDM76\000event=0x60,period=2000003,umask=0x4\000\00000\000This event counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS  Spec update: BDM76\000 */
{ 2460294 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000 */
{ 1781819 }, /* offcore_response.all_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0244\000\00000\000\000 */
{ 1804906 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000 */
{ 1805448 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000 */
{ 1880911 }, /* offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000 */
{ 1881756 }, /* offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000 */
{ 1889149 }, /* offcore_response.all_requests.llc_hit.any_response\000\000cache\000Counts all requests hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8FFF\000\00000\000\000 */
{ 1909321 }, /* offcore_response.all_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1909843 }, /* offcore_response.all_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 2175048 }, /* offcore_response.demand_rfo.llc_hit.any_response\000\000cache\000Counts all demand data writes (RFOs) hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 2175932 }, /* offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2423919 }, /* offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000 */
{ 2428628 }, /* offcore_response.pf_llc_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 2531841 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000This event counts the number of split locks in the super queue\000 */
{ 856247 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 859272 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 864472 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 4 calculations per element\000event=0xc7,period=2000003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 868573 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 8 calculations per element\000event=0xc7,period=2000003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 873279 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 884623 }, /* fp_arith_inst_retired.double\000\000floating point\000Number of SSE/AVX computational double precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000006,umask=0x15\000\00000\000\000 */
{ 885097 }, /* fp_arith_inst_retired.packed\000\000floating point\000Number of SSE/AVX computational packed floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* packed double and single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000004,umask=0x3c\000\00000\000\000 */
{ 888236 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below. Each count represents 1 computation operation.   Applies to SSE* and AVX* scalar double and single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891938 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 895654 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 897672 }, /* fp_arith_inst_retired.single\000\000floating point\000Number of SSE/AVX computational single precision floating-point instructions retired; some instructions will count twice as noted below. Applies to SSE* and AVX* scalar and packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=2000005,umask=0x2a\000\00000\000\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 902217 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000This event counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 903279 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000This event counts any input SSE* FP assist - invalid operation, denormal operand, dividing by zero, SNaN operand. Counting includes only cases involving penalties that required micro-code assist intervention\000 */
{ 903905 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000This event counts the number of SSE* floating point (FP) micro-code assist (numeric overflow/underflow) when the output value (destination register) is invalid. Counting covers only cases involving penalties that require micro-code assist intervention\000 */
{ 904567 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000This event counts x87 floating point (FP) micro-code assist (invalid operation, denormal operand, SNaN operand) when the input value (one of the source operands to an FP instruction) is invalid\000 */
{ 905158 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000This event counts the number of x87 floating point (FP) micro-code assist (numeric overflow/underflow, inexact result) when the output value (destination register) is invalid\000 */
{ 1433783 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000 */
{ 1434178 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000 */
{ 2463149 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x8\000\00000\000This event counts the number of transitions from AVX-256 to legacy SSE when penalty is applicable  Spec update: BDM30\000 */
{ 2463904 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: BDM30\000event=0xc1,period=100003,umask=0x10\000\00000\000This event counts the number of transitions from legacy SSE to AVX-256 when penalty is applicable  Spec update: BDM30\000 */
{ 6177315 }, /* uop_dispatches_cancelled.simd_prf\000\000floating point\000Micro-op dispatches cancelled due to insufficient SIMD physical register file read ports\000event=0xa0,period=2000003,umask=0x3\000\00000\000This event counts the number of micro-operations cancelled after they were dispatched from the scheduler to the execution units when the total number of physical register read ports across all dispatch ports exceeds the read bandwidth of the physical register file.  The SIMD_PRF subevent applies to the following instructions: VDPPS, DPPS, VPCMPESTRI, PCMPESTRI, VPCMPESTRM, PCMPESTRM, VFMADD*, VFMADDSUB*, VFMSUB*, VMSUBADD*, VFNMADD*, VFNMSUB*.  See the Broadwell Optimization Guide for more information\000 */
{ 477106 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000 */
{ 784188 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. \nMM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.\nPenalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 986506 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000This event counts the number of both cacheable and noncacheable Instruction Cache, Streaming Buffer and Victim Cache Reads including UC fetches\000 */
{ 987766 }, /* icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000This event counts cycles during which the demand fetch waits for data (wfdM104H) from L2 or iSB (opportunistic hit)\000 */
{ 990635 }, /* icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes UC accesses\000 */
{ 998477 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 999553 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000This event counts the number of cycles  uops were  delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1000587 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles 4  uops were  delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001838 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000This event counts the number of cycles  uops were delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002978 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1006821 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may bypass the IDQ\000 */
{ 1007899 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000This counts the number of cycles that the instruction decoder queue is empty and can indicate that the application may be bound in the front end.  It does not determine whether there are uops being delivered to the Alloc stage since uops can be delivered by bypass skipping the Instruction Decode Queue (IDQ) when it is empty\000 */
{ 1008613 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1009676 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ\000 */
{ 1012842 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000This event counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may bypass the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1015992 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1018545 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000This event counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1019936 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000This event counts the number of deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1021234 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000This event counts the number of uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1022867 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000This event counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026055 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts the total number of uops delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may bypass the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1032672 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when:\n a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread;\n b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions); \n c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034662 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038680 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles when less than 1 uop is  delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >=3\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 970645 }, /* hle_retired.aborted\000\000memory\000Number of times HLE abort was triggered (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 972603 }, /* hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000Number of times an HLE abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 973088 }, /* hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an HLE abort\000 */
{ 973430 }, /* hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an HLE abort\000 */
{ 973961 }, /* hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times HLE caused a fault\000 */
{ 974144 }, /* hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times HLE aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 975396 }, /* hle_retired.commit\000\000memory\000Number of times HLE commit succeeded\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976477 }, /* hle_retired.start\000\000memory\000Number of times we entered an HLE region; does not count nested transactions\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region\n does not count nested transactions\000 */
{ 1294861 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:\n1. memory disambiguation,\n2. external snoop, or\n3. cross SMT-HW-thread snoop (stores) hitting load buffer\000 */
{ 1369873 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1371816 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1373759 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1375705 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1377639 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads with latency value being above four  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1379577 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1381517 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1383441 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads with latency value being above eight  Supports address when precise.  Spec update: BDM100, BDM35 (Must be precise)\000 */
{ 1428587 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000This event counts speculative cache-line split load uops dispatched to the L1 cache\000 */
{ 1430771 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000This event counts speculative cache line split store-address (STA) uops dispatched to the L1 cache\000 */
{ 1782904 }, /* offcore_response.all_code_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00244\000\00000\000\000 */
{ 1783685 }, /* offcore_response.all_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000244\000\00000\000\000 */
{ 1806759 }, /* offcore_response.all_data_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00091\000\00000\000\000 */
{ 1807540 }, /* offcore_response.all_data_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000091\000\00000\000\000 */
{ 1807754 }, /* offcore_response.all_data_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63BC00091\000\00000\000\000 */
{ 1808425 }, /* offcore_response.all_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87FC00091\000\00000\000\000 */
{ 1808664 }, /* offcore_response.all_data_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00091\000\00000\000\000 */
{ 1883723 }, /* offcore_response.all_reads.llc_miss.any_response\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC007F7\000\00000\000\000 */
{ 1884539 }, /* offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00000\000\000 */
{ 1884989 }, /* offcore_response.all_reads.llc_miss.remote_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63BC007F7\000\00000\000\000 */
{ 1885687 }, /* offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87FC007F7\000\00000\000\000 */
{ 1886173 }, /* offcore_response.all_reads.llc_miss.remote_hitm\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00000\000\000 */
{ 1889306 }, /* offcore_response.all_requests.llc_miss.any_response\000\000memory\000Counts all requests miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC08FFF\000\00000\000\000 */
{ 1910890 }, /* offcore_response.all_rfo.llc_miss.any_response\000\000memory\000Counts all demand & prefetch RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00122\000\00000\000\000 */
{ 1911459 }, /* offcore_response.all_rfo.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000 */
{ 2178287 }, /* offcore_response.demand_rfo.llc_miss.any_response\000\000memory\000Counts all demand data writes (RFOs) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000 */
{ 2178869 }, /* offcore_response.demand_rfo.llc_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000 */
{ 2425507 }, /* offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00200\000\00000\000\000 */
{ 2430157 }, /* offcore_response.pf_llc_rfo.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00100\000\00000\000\000 */
{ 2514606 }, /* rtm_retired.aborted\000\000memory\000Number of times RTM abort was triggered (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered  (Precise event)\000 */
{ 2516981 }, /* rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM abort was attributed to a Memory condition (See TSX_Memory event for additional details)\000 */
{ 2517574 }, /* rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000Number of times the TSX watchdog signaled an RTM abort\000 */
{ 2518004 }, /* rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times a disallowed operation caused an RTM abort\000 */
{ 2518535 }, /* rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times a RTM caused a fault\000 */
{ 2518720 }, /* rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times RTM aborted and was not due to the abort conditions in subevents 3-6\000 */
{ 2519870 }, /* rtm_retired.commit\000\000memory\000Number of times RTM commit succeeded\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520951 }, /* rtm_retired.start\000\000memory\000Number of times we entered an RTM region; does not count nested transactions\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region\n does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571663 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by  a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573943 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000 */
{ 2574626 }, /* tx_mem.abort_capacity_write\000\000memory\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000event=0x54,period=2000003,umask=0x2\000\00000\000Number of times a TSX Abort was triggered due to an evicted line caused by a transaction overflow\000 */
{ 2575413 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a TSX line had a cache conflict\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576232 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577423 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2578428 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2580470 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2581333 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times we could not allocate Lock Buffer\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 581115 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000This event counts the unhalted core cycles during which the thread is in the ring 0 privileged mode\000 */
{ 581987 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000This event counts when there is a transition from ring 1,2 or 3 to ring0\000 */
{ 582369 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000This event counts unhalted core cycles during which the thread is in rings 1, 2, or 3\000 */
{ 1246210 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000This event counts cycles in which the L1 and L2 are locked due to a UC lock or split lock. A lock is asserted in case of locked memory access, due to noncacheable memory, locked operation that spans two cache lines, or a page walk from the noncacheable page table. L1D and L2 locks have a very high performance penalty and it is highly recommended to avoid such access\000 */
{ 470283 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000This event counts the number of the divide operations executed. Uses edge-detect and a cmask value of 1 on ARITH.FPU_DIV_ACTIVE to get the number of the divide operations executed\000 */
{ 487863 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired branch instructions\000 */
{ 488352 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired macro-conditional branch instructions\000 */
{ 488962 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000This event counts both taken and not taken speculative and retired macro-unconditional branch instructions, excluding calls and indirects\000 */
{ 489591 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000This event counts both taken and not taken speculative and retired direct near calls\000 */
{ 490163 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 490613 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000This event counts both taken and not taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 492015 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000This event counts not taken macro-conditional branch instructions\000 */
{ 492721 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions\000 */
{ 493361 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000This event counts taken speculative and retired macro-conditional branch instructions excluding calls and indirect branches\000 */
{ 494026 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000This event counts taken speculative and retired direct near calls\000 */
{ 494609 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired indirect branches excluding calls and return branches\000 */
{ 495234 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000This event counts taken speculative and retired indirect calls including both register and memory indirect\000 */
{ 495836 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired indirect branches that have a return mnemonic\000 */
{ 496588 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000This event counts all (macro) branch instructions retired\000 */
{ 499782 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS)  Spec update: BDW98 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: BDW98 (Must be precise)\000 */
{ 505778 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired (Precise event)\000 */
{ 507863 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: BDW98\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: BDW98\000 */
{ 515440 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 516700 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000 */
{ 518100 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired (Precise event)\000 */
{ 519528 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired (Precise event)\000 */
{ 522442 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 529473 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000This event counts both taken and not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 530230 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000This event counts both taken and not taken mispredicted indirect branches excluding calls and returns\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532040 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000This event counts not taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 532898 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000This event counts taken speculative and retired mispredicted macro conditional branch instructions\000 */
{ 533722 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000This event counts taken speculative and retired mispredicted indirect branches excluding calls and returns\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 534796 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000This event counts taken speculative and retired mispredicted indirect branches that have a return mnemonic\000 */
{ 536938 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000This event counts all mispredicted macro branch instructions retired\000 */
{ 541717 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 555802 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 559925 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This event counts mispredicted return instructions retired (Precise event)\000 */
{ 607340 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 607860 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000This is a fixed-frequency event programmed to general counters. It counts when the core is unhalted at 100 Mhz\000 */
{ 608968 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 618202 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 629105 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. \nNote: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  This event is clocked by base clock (100 Mhz) on Sandy Bridge. The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638482 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000 */
{ 639739 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000\000 */
{ 642083 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 749189 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request missing the L1 data cache\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 750752 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Counts number of cycles the CPU has at least one pending  demand* load request missing the L2 cache\000 */
{ 752207 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Counts number of cycles the CPU has at least one pending  demand load request (that is cycles with non-completed load waiting for its data from memory subsystem)\000 */
{ 753182 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 753743 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Counts number of cycles nothing is executed on any execution port\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755503 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request missing the L1 data cache\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 757144 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand* load request missing the L2 cache.(as a footprint) * includes also L1 HW prefetch requests that may or may not be required by demands\000 */
{ 758459 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000Counts number of cycles nothing is executed on any execution port, while there was at least one pending demand load request\000 */
{ 759049 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 1042438 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts stalls occurred due to changing prefix length (66, 67 or REX.W when they change the length of the decoded instruction). Occurrences counting is proportional to the number of prefixes in a 16B-line. This may result in the following penalties: three-cycle penalty for each LCP in a 16-byte chunk\000 */
{ 1048616 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. \nNotes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. \nCounting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1054178 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: BDM61\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: BDM61\000 */
{ 1059091 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: BDM11, BDM55 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000This is a precise version (that is, uses PEBS) of the event that counts instructions retired  Spec update: BDM11, BDM55 (Must be precise)\000 */
{ 1063776 }, /* inst_retired.x87\000\000pipeline\000FP operations  retired. X87 FP operations that have no exceptions:\000event=0xc0,period=2000003,umask=0x2\000\00000\000This event counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000 */
{ 1067840 }, /* int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x8\000\00000\000This event counts the number of cycles during which Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the current thread. This also includes the cycles during which the Allocator is serving another thread\000 */
{ 1068279 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Cycles checkpoints in Resource Allocation Table (RAT) are recovering from JEClear or machine clear\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1195150 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000 */
{ 1195965 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts how many times the load operation got the true Block-on-Store blocking code preventing store forwarding. This includes cases when:\n - preceding store conflicts with the load (incomplete overlap);\n - store forwarding is impossible due to u-arch limitations;\n - preceding lock RMW operations are not forwarded;\n - store has the no-forward bit set (uncacheable/page-split/masked stores);\n - all-blocking stores are used (mostly, fences and port I/O);\nand others.\nThe most common case is a load blocked due to its address range overlapping with a preceding smaller uncompleted store. Note: This event does not take into account cases of out-of-SW-control (for example, SbTailHit), unknown physical STA, and cases of blocking loads on store due to being non-WB memory type or a lock. These cases are covered by other events.\nSee the table of not supported store forwards in the Optimization Guide\000 */
{ 1203346 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000This event counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229339 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the hardware prefetch\000 */
{ 1230455 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000This event counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by asm inspection of the nearby instructions\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1289455 }, /* machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000This event counts both thread-specific (TS) and all-thread (AT) nukes\000 */
{ 1293258 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000 */
{ 1301798 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1433006 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000 */
{ 1433396 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000 */
{ 2462319 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000\000 */
{ 2501664 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000This event counts resource-related stall cycles\000 */
{ 2503004 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000This event counts ROB full stall cycles. This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2503458 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000This event counts stall cycles caused by absence of eligible entries in the reservation station (RS). This may result from RS overflow, or from RS deallocation because of the RS array Write Port allocation scheme (each RS entry has two write ports instead of four. As a result, empty entries could not be used, although RS is not really full). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2505380 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts stall cycles caused by the store buffer (SB) overflow (excluding draining from synch). This counts cycles that the pipeline backend blocked uop delivery from the front end\000 */
{ 2507440 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000This event counts cases of saving new LBR records by hardware. This assumes proper enabling of LBRs and takes into account LBR filtering done by the LBR_SELECT register\000 */
{ 2511321 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the reservation station (RS) is empty for the thread.\nNote: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6184272 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185554 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186860 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6188158 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189481 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190770 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191751 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192398 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198933 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200909 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6201977 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203050 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 6203994 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 6205620 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6208183 }, /* uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 0\000 */
{ 6208438 }, /* uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6208760 }, /* uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 1\000 */
{ 6209015 }, /* uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6209337 }, /* uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 2\000 */
{ 6209592 }, /* uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6209916 }, /* uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 3\000 */
{ 6210171 }, /* uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6210496 }, /* uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 4\000 */
{ 6210752 }, /* uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6211076 }, /* uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 5\000 */
{ 6211332 }, /* uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6211656 }, /* uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 6\000 */
{ 6211912 }, /* uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6212236 }, /* uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000This event counts, on the per-thread basis, cycles during which uops are dispatched from the Reservation Station (RS) to port 7\000 */
{ 6212492 }, /* uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6214583 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS)\000 */
{ 6217174 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops being allocated. Such uops considered perf sensitive\n added by GSR u-arch\000 */
{ 6217915 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6220169 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6225615 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts all actually retired uops. Counting increments by two for micro-fused uops, and by one for macro-fused and other uops. Maximal increment value for one cycle is eight (Precise event)\000 */
{ 6234066 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used (Precise event)\000 */
{ 6238392 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240195 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 1207716 }, /* llc_misses.code_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for code reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x191\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1208449 }, /* llc_misses.data_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for data reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x192\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1209182 }, /* llc_misses.data_read\000uncore_cbox\000uncore cache\000LLC misses - demand and prefetch data reads - excludes LLC prefetches. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x182\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1212098 }, /* llc_misses.mmio_read\000uncore_cbox\000uncore cache\000MMIO reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1213639 }, /* llc_misses.mmio_write\000uncore_cbox\000uncore cache\000MMIO writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x18f,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1215186 }, /* llc_misses.pcie_non_snoop_write\000uncore_cbox\000uncore cache\000PCIe write misses (full cache line). Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1215939 }, /* llc_misses.pcie_read\000uncore_cbox\000uncore cache\000LLC misses for PCIe read current. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1217854 }, /* llc_misses.pcie_write\000uncore_cbox\000uncore cache\000ItoM write misses (as part of fast string memcpy stores) + PCIe full line writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1219820 }, /* llc_misses.rfo_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for RFO. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x190\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1220545 }, /* llc_misses.uncacheable\000uncore_cbox\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1222170 }, /* llc_references.code_llc_prefetch\000uncore_cbox\000uncore cache\000L2 demand and L2 prefetch code references to LLC. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x181\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1222951 }, /* llc_references.pcie_ns_partial_write\000uncore_cbox\000uncore cache\000PCIe writes (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x180,filter_tid=0x3e\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1223729 }, /* llc_references.pcie_read\000uncore_cbox\000uncore cache\000PCIe read current. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1224471 }, /* llc_references.pcie_write\000uncore_cbox\000uncore cache\000PCIe write references (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1225252 }, /* llc_references.streaming_full\000uncore_cbox\000uncore cache\000Streaming stores (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18c\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1226918 }, /* llc_references.streaming_partial\000uncore_cbox\000uncore cache\000Streaming stores (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18d\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2592068 }, /* unc_c_bounce_control\000uncore_cbox\000uncore cache\000Bounce Control. Unit: uncore_cbox \000event=0xa\000\00001\000\000 */
{ 2592164 }, /* unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000 */
{ 2592390 }, /* unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2592888 }, /* unc_c_fast_asserted\000uncore_cbox\000uncore cache\000FaST wire asserted. Unit: uncore_cbox \000event=0x9\000\00001\000Counts the number of cycles either the local distress or incoming distress signals are asserted.  Incoming distress includes both up and dn\000 */
{ 2593371 }, /* unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000All LLC Misses (code+ data rd + data wr - including demand and prefetch). Unit: uncore_cbox \000event=0x34,umask=0x11,filter_state=0x1\000\0000164Bytes\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2596894 }, /* unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2598632 }, /* unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2599997 }, /* unc_c_llc_lookup.read\000uncore_cbox\000uncore cache\000Cache Lookups; Any Read Request. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2602045 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2604174 }, /* unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2605021 }, /* unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605435 }, /* unc_c_llc_victims.f_state\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605831 }, /* unc_c_llc_victims.i_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606492 }, /* unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000M line evictions from LLC (writebacks to memory). Unit: uncore_cbox \000event=0x37,umask=0x1\000\0000164Bytes\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606927 }, /* unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x10\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607378 }, /* unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2608914 }, /* unc_c_misc.cvzero_prefetch_miss\000uncore_cbox\000uncore cache\000Cbo Misc; DRd hitting non-M with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609091 }, /* unc_c_misc.cvzero_prefetch_victim\000uncore_cbox\000uncore cache\000Cbo Misc; Clean Victim with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609265 }, /* unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo.; Number of times that an RFO hit in S state.  This is useful for determining if it might be good for a workload to use RspIWB instead of RspSWB\000 */
{ 2609694 }, /* unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2610173 }, /* unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610303 }, /* unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2610806 }, /* unc_c_qlru.age0\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 0. Unit: uncore_cbox \000event=0x3c,umask=0x1\000\00001\000How often age was set to 0\000 */
{ 2610940 }, /* unc_c_qlru.age1\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 1. Unit: uncore_cbox \000event=0x3c,umask=0x2\000\00001\000How often age was set to 1\000 */
{ 2611074 }, /* unc_c_qlru.age2\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 2. Unit: uncore_cbox \000event=0x3c,umask=0x4\000\00001\000How often age was set to 2\000 */
{ 2611208 }, /* unc_c_qlru.age3\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 3. Unit: uncore_cbox \000event=0x3c,umask=0x8\000\00001\000How often age was set to 3\000 */
{ 2611342 }, /* unc_c_qlru.lru_decrement\000uncore_cbox\000uncore cache\000LRU Queue; LRU Bits Decremented. Unit: uncore_cbox \000event=0x3c,umask=0x10\000\00001\000How often all LRU bits were decremented by 1\000 */
{ 2611515 }, /* unc_c_qlru.victim_non_zero\000uncore_cbox\000uncore cache\000LRU Queue; Non-0 Aged Victim. Unit: uncore_cbox \000event=0x3c,umask=0x20\000\00001\000How often we picked a victim that had a non-zero age\000 */
{ 2611695 }, /* unc_c_ring_ad_used.all\000uncore_cbox\000uncore cache\000AD Ring In Use; All. Unit: uncore_cbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2616734 }, /* unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX-- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2619251 }, /* unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2621906 }, /* unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2629113 }, /* unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2630783 }, /* unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2633422 }, /* unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2639753 }, /* unc_c_ring_ak_used.all\000uncore_cbox\000uncore cache\000AK Ring In Use; All. Unit: uncore_cbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2644780 }, /* unc_c_ring_ak_used.down\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2646455 }, /* unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2649104 }, /* unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2656295 }, /* unc_c_ring_ak_used.up\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2657128 }, /* unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2659761 }, /* unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2666078 }, /* unc_c_ring_bl_used.all\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2671107 }, /* unc_c_ring_bl_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2673638 }, /* unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2676286 }, /* unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2682624 }, /* unc_c_ring_bl_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2684309 }, /* unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2686941 }, /* unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2692409 }, /* unc_c_ring_bounces.ad\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AD. Unit: uncore_cbox \000event=0x5,umask=0x1\000\00001\000\000 */
{ 2692700 }, /* unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AK. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2693360 }, /* unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; BL. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2694014 }, /* unc_c_ring_bounces.iv\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x10\000\00001\000\000 */
{ 2694538 }, /* unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2696543 }, /* unc_c_ring_iv_used.dn\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2697651 }, /* unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters for Down polarity\000 */
{ 2699143 }, /* unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in BDX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2700611 }, /* unc_c_ring_sink_starved.ad\000uncore_cbox\000uncore cache\000AD. Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 2701137 }, /* unc_c_ring_sink_starved.ak\000uncore_cbox\000uncore cache\000AK. Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 2701462 }, /* unc_c_ring_sink_starved.bl\000uncore_cbox\000uncore cache\000BL. Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 2701787 }, /* unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000IV. Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 2702209 }, /* unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Number of cycles the Cbo is actively throttling traffic onto the Ring in order to limit bounce traffic. Unit: uncore_cbox \000event=0x7\000\00001\000\000 */
{ 2702621 }, /* unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IPQ is externally startved and therefore we are blocking the IRQ\000 */
{ 2703192 }, /* unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IRQ is externally starved and therefore we are blocking the IPQ\000 */
{ 2704016 }, /* unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; Number of times that the ISMQ Bid\000 */
{ 2704767 }, /* unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; PRQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2705019 }, /* unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705208 }, /* unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705397 }, /* unc_c_rxr_inserts.irq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706013 }, /* unc_c_rxr_inserts.prq\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706203 }, /* unc_c_rxr_inserts.prq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2707348 }, /* unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IPQ in Internal Starvation\000 */
{ 2707983 }, /* unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IRQ in Internal Starvation\000 */
{ 2708618 }, /* unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the ISMQ in Internal Starvation\000 */
{ 2709258 }, /* unc_c_rxr_int_starved.prq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; PRQ. Unit: uncore_cbox \000event=0x14,umask=0x10\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2709554 }, /* unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from an address conflicts.  Address conflicts out of the IPQ should be rare.  They will generally only occur if two different sockets are sending requests to the same address at the same time.  This is a true conflict case, unlike the IPQ Address Conflict which is commonly caused by prefetching characteristics\000 */
{ 2710465 }, /* unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject.  TOR rejects from the IPQ can be caused by the Egress being full or Address Conflicts\000 */
{ 2711119 }, /* unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from the Egress being full.  IPQ requests make use of the AD Egress for regular responses, the BL egress to forward data, and the AK egress to return credits\000 */
{ 2711860 }, /* unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2712110 }, /* unc_c_rxr_ipq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Probe Queue Retries; No AD Sbo Credits. Unit: uncore_cbox \000event=0x28,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2712488 }, /* unc_c_rxr_ipq_retry2.target\000uncore_cbox\000uncore cache\000Probe Queue Retries; Target Node Filter. Unit: uncore_cbox \000event=0x28,umask=0x40\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2712880 }, /* unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000Counts the number of times that a request from the IRQ was retried because of an address match in the TOR.  In order to maintain coherency, requests to the same address are not allowed to pass each other up in the Cbo.  Therefore, if there is an outstanding request to a given address, one cannot issue another request to that address until it is complete.  This comes up most commonly with prefetches.  Outstanding prefetches occasionally will not complete their memory fetch and a demand request to the same address will then sit in the IRQ and get retried until the prefetch fills the data into the LLC.  Therefore, it will not be uncommon to see this case in high bandwidth streaming workloads when the LLC Prefetcher in the core is enabled\000 */
{ 2713930 }, /* unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000Counts the number of IRQ retries that occur.  Requests from the IRQ are retried if they are rejected from the TOR pipeline for a variety of reasons.  Some of the most common reasons include if the Egress is full, there are no RTIDs, or there is a Physical Address match to another outstanding request\000 */
{ 2714504 }, /* unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000Counts the number of times that a request from the IRQ was retried because it failed to acquire an entry in the Egress.  The egress is the buffer that queues up for allocating onto the ring.  IRQ requests can make use of all four rings and all four Egresses.  If any of the queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2715154 }, /* unc_c_rxr_irq_retry.iio_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No IIO Credits. Unit: uncore_cbox \000event=0x32,umask=0x20\000\00001\000Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2715572 }, /* unc_c_rxr_irq_retry.nid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cbox \000event=0x32,umask=0x40\000\00001\000Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2715819 }, /* unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000Number of requests rejects because of lack of QPI Ingress credits.  These credits are required in order to send transactions to the QPI agent.  Please see the QPI_IGR_CREDITS events for more information\000 */
{ 2716321 }, /* unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000Counts the number of times that requests from the IRQ were retried because there were no RTIDs available.  RTIDs are required after a request misses the LLC and needs to send snoops and/or requests to memory.  If there are no RTIDs available, requests will queue up in the IRQ and retry until one becomes available.  Note that there are multiple RTID pools for the different sockets.  There may be cases where the local RTIDs are all used, but requests destined for remote memory can still acquire an RTID because there are remote RTIDs available.  This event does not provide any filtering for this case\000 */
{ 2717197 }, /* unc_c_rxr_irq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x1\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2717472 }, /* unc_c_rxr_irq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x2\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2717747 }, /* unc_c_rxr_irq_retry2.target\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x29,umask=0x40\000\00001\000Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2718036 }, /* unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the total number of times that a request from the ISMQ retried because of a TOR reject.  ISMQ requests generally will not need to retry (or at least ISMQ retries are less common than IRQ retries).  ISMQ requests will retry if they are not able to acquire a needed Egress credit to get onto the ring, or for cache evictions that need to acquire an RTID.  Most ISMQ requests already have an RTID, so eviction retries will be less common here\000 */
{ 2719237 }, /* unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by a lack of Egress credits. The egress is the buffer that queues up for allocating onto the ring.  If any of the Egress queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2720310 }, /* unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2721359 }, /* unc_c_rxr_ismq_retry.nid\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2721848 }, /* unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2722237 }, /* unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by no RTIDs.  M-state cache evictions are serviced through the ISMQ, and must acquire an RTID in order to write back to memory.  If no RTIDs are available, they will be retried\000 */
{ 2723261 }, /* unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2724209 }, /* unc_c_rxr_ismq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x1\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2724483 }, /* unc_c_rxr_ismq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x2\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2724757 }, /* unc_c_rxr_ismq_retry2.target\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x2a,umask=0x40\000\00001\000Counts the number of times that a request from the ISMQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2725045 }, /* unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725232 }, /* unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725419 }, /* unc_c_rxr_occupancy.irq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2726010 }, /* unc_c_rxr_occupancy.prq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; PRQ Rejects. Unit: uncore_cbox \000event=0x11,umask=0x20\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2727266 }, /* unc_c_sbo_credit_occupancy.ad\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For AD Ring. Unit: uncore_cbox \000event=0x3e,umask=0x1\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727511 }, /* unc_c_sbo_credit_occupancy.bl\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For BL Ring. Unit: uncore_cbox \000event=0x3e,umask=0x2\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727756 }, /* unc_c_sbo_credits_acquired.ad\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For AD Ring. Unit: uncore_cbox \000event=0x3d,umask=0x1\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728002 }, /* unc_c_sbo_credits_acquired.bl\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For BL Ring. Unit: uncore_cbox \000event=0x3d,umask=0x2\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728248 }, /* unc_c_tor_inserts.all\000uncore_cbox\000uncore cache\000TOR Inserts; All. Unit: uncore_cbox \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR.    This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2730237 }, /* unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Eviction transactions inserted into the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2733765 }, /* unc_c_tor_inserts.local\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x28\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2734438 }, /* unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2736634 }, /* unc_c_tor_inserts.miss_local\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x2a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2737323 }, /* unc_c_tor_inserts.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x23\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode, inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2738662 }, /* unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 2739324 }, /* unc_c_tor_inserts.miss_remote\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x8a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2740025 }, /* unc_c_tor_inserts.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x83\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2741368 }, /* unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched (matches an RTID destination) transactions inserted into the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.  In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2742799 }, /* unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched eviction transactions inserted into the TOR\000 */
{ 2744068 }, /* unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched miss requests that were inserted into the TOR\000 */
{ 2745352 }, /* unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2746645 }, /* unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2747919 }, /* unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched write transactions inserted into the TOR\000 */
{ 2749165 }, /* unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2750908 }, /* unc_c_tor_inserts.remote\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x88\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2751593 }, /* unc_c_tor_inserts.remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x81\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2753157 }, /* unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Write transactions inserted into the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2754718 }, /* unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All valid TOR entries.  This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2756725 }, /* unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding eviction transactions in the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2758758 }, /* unc_c_tor_occupancy.llc_data_read\000uncore_cbox\000uncore cache\000Occupancy counter for LLC data reads (demand and L2 prefetch). Derived from unc_c_tor_occupancy.miss_opcode. Unit: uncore_cbox \000event=0x36,umask=0x3,filter_opc=0x182\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2760047 }, /* unc_c_tor_occupancy.local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x28\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2760639 }, /* unc_c_tor_occupancy.local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by locally HOMed memory\000 */
{ 2762159 }, /* unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding miss requests in the TOR.  'Miss' means the allocation requires an RTID.  This generally means that the request was sent to memory or MMIO\000 */
{ 2762925 }, /* unc_c_tor_occupancy.miss_local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x2a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2763522 }, /* unc_c_tor_occupancy.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x23\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by locally HOMed memory\000 */
{ 2764905 }, /* unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2765643 }, /* unc_c_tor_occupancy.miss_remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x8a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2766241 }, /* unc_c_tor_occupancy.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x83\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2767627 }, /* unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of NID matched outstanding requests in the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2769062 }, /* unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding NID matched eviction transactions in the TOR \000 */
{ 2770367 }, /* unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID\000 */
{ 2771677 }, /* unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID and an opcode\000 */
{ 2773010 }, /* unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match a NID and an opcode\000 */
{ 2773675 }, /* unc_c_tor_occupancy.nid_wb\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x50\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); NID matched write transactions int the TOR\000 */
{ 2774944 }, /* unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2776134 }, /* unc_c_tor_occupancy.remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x88\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2776727 }, /* unc_c_tor_occupancy.remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x81\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2777486 }, /* unc_c_tor_occupancy.wb\000uncore_cbox\000uncore cache\000TOR Occupancy; Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Write transactions in the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2778213 }, /* unc_c_txr_ads_used.ad\000uncore_cbox\000uncore cache\000Onto AD Ring. Unit: uncore_cbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 2778318 }, /* unc_c_txr_ads_used.ak\000uncore_cbox\000uncore cache\000Onto AK Ring. Unit: uncore_cbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 2778423 }, /* unc_c_txr_ads_used.bl\000uncore_cbox\000uncore cache\000Onto BL Ring. Unit: uncore_cbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 2778606 }, /* unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 2779216 }, /* unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 2779791 }, /* unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 2780383 }, /* unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AK ring.  This is commonly used for snoop responses coming from the core and destined for a Cachebo\000 */
{ 2781004 }, /* unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 2781612 }, /* unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 2782210 }, /* unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 2782790 }, /* unc_c_txr_starved.ad_core\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AD Ring (to core). Unit: uncore_cbox \000event=0x3,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the core AD egress spent in starvation\000 */
{ 2783391 }, /* unc_c_txr_starved.ak_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both AK egresses spent in starvation\000 */
{ 2783979 }, /* unc_c_txr_starved.bl_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both BL egresses spent in starvation\000 */
{ 2784301 }, /* unc_c_txr_starved.iv\000uncore_cbox\000uncore cache\000Injection Starvation; Onto IV Ring. Unit: uncore_cbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the cachebo IV egress spent in starvation\000 */
{ 3579343 }, /* unc_h_bt_cycles_ne\000uncore_ha\000uncore cache\000BT Cycles Not Empty. Unit: uncore_ha \000event=0x42\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3582625 }, /* unc_h_bt_to_ht_not_issued.incoming_bl_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x4\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3582923 }, /* unc_h_bt_to_ht_not_issued.incoming_snp_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Snoop Hazard. Unit: uncore_ha \000event=0x51,umask=0x2\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming snoop hazard\000 */
{ 3583221 }, /* unc_h_bt_to_ht_not_issued.rspackcflt_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x8\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3583518 }, /* unc_h_bt_to_ht_not_issued.wbmdata_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x10\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3584345 }, /* unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass\000 */
{ 3585130 }, /* unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the bypass\000 */
{ 3587414 }, /* unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000 */
{ 3592593 }, /* unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000 */
{ 3592735 }, /* unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000 */
{ 3592913 }, /* unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000 */
{ 3593093 }, /* unc_h_directory_lat_opt\000uncore_ha\000uncore cache\000Directory Lat Opt Return. Unit: uncore_ha \000event=0x41\000\00001\000Directory Latency Optimization Data Return Path Taken. When directory mode is enabled and the directory returned for a read is Dir=I, then data can be returned using a faster path if certain conditions are met (credits, free pipeline, etc)\000 */
{ 3593702 }, /* unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that did not have to send any snoops because the directory bit was clear\000 */
{ 3594878 }, /* unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that had to send one or more snoops because the directory bit was set\000 */
{ 3596877 }, /* unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3597179 }, /* unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory clears.  This occurs when snoops were sent and all returned with RspI\000 */
{ 3599011 }, /* unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory sets.  This occurs when a remote read transaction requests memory, bringing it to a remote cache\000 */
{ 3612982 }, /* unc_h_hitme_hit.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is AckCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x4\000\00001\000\000 */
{ 3613133 }, /* unc_h_hitme_hit.all\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; All Requests. Unit: uncore_ha \000event=0x71,umask=0xff\000\00001\000\000 */
{ 3613272 }, /* unc_h_hitme_hit.allocs\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x70\000\00001\000\000 */
{ 3613413 }, /* unc_h_hitme_hit.evicts\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x42\000\00001\000\000 */
{ 3613716 }, /* unc_h_hitme_hit.hom\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; HOM Requests. Unit: uncore_ha \000event=0x71,umask=0xf\000\00001\000\000 */
{ 3613854 }, /* unc_h_hitme_hit.invals\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Invalidations. Unit: uncore_ha \000event=0x71,umask=0x26\000\00001\000\000 */
{ 3613997 }, /* unc_h_hitme_hit.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x71,umask=0x1\000\00001\000\000 */
{ 3614200 }, /* unc_h_hitme_hit.rsp\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x80\000\00001\000\000 */
{ 3614384 }, /* unc_h_hitme_hit.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x71,umask=0x20\000\00001\000\000 */
{ 3614567 }, /* unc_h_hitme_hit.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x71,umask=0x10\000\00001\000\000 */
{ 3614752 }, /* unc_h_hitme_hit.rspfwds\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x71,umask=0x40\000\00001\000\000 */
{ 3615246 }, /* unc_h_hitme_hit.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x71,umask=0x8\000\00001\000\000 */
{ 3615402 }, /* unc_h_hitme_hit.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI. Unit: uncore_ha \000event=0x71,umask=0x2\000\00001\000\000 */
{ 3615716 }, /* unc_h_hitme_hit_pv_bits_set.ackcnfltwbi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is AckCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x4\000\00001\000\000 */
{ 3615896 }, /* unc_h_hitme_hit_pv_bits_set.all\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; All Requests. Unit: uncore_ha \000event=0x72,umask=0xff\000\00001\000\000 */
{ 3616064 }, /* unc_h_hitme_hit_pv_bits_set.hom\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; HOM Requests. Unit: uncore_ha \000event=0x72,umask=0xf\000\00001\000\000 */
{ 3616231 }, /* unc_h_hitme_hit_pv_bits_set.read_or_invitoe\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x72,umask=0x1\000\00001\000\000 */
{ 3616463 }, /* unc_h_hitme_hit_pv_bits_set.rsp\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x80\000\00001\000\000 */
{ 3616676 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_local\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x72,umask=0x20\000\00001\000\000 */
{ 3616888 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_remote\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x72,umask=0x10\000\00001\000\000 */
{ 3617102 }, /* unc_h_hitme_hit_pv_bits_set.rspfwds\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x72,umask=0x40\000\00001\000\000 */
{ 3617287 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoe_or_s\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x72,umask=0x8\000\00001\000\000 */
{ 3617472 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoI. Unit: uncore_ha \000event=0x72,umask=0x2\000\00001\000\000 */
{ 3617642 }, /* unc_h_hitme_lookup.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is AckCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x4\000\00001\000\000 */
{ 3617806 }, /* unc_h_hitme_lookup.all\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; All Requests. Unit: uncore_ha \000event=0x70,umask=0xff\000\00001\000\000 */
{ 3617958 }, /* unc_h_hitme_lookup.allocs\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Allocations. Unit: uncore_ha \000event=0x70,umask=0x70\000\00001\000\000 */
{ 3618112 }, /* unc_h_hitme_lookup.hom\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; HOM Requests. Unit: uncore_ha \000event=0x70,umask=0xf\000\00001\000\000 */
{ 3618263 }, /* unc_h_hitme_lookup.invals\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Invalidations. Unit: uncore_ha \000event=0x70,umask=0x26\000\00001\000\000 */
{ 3618583 }, /* unc_h_hitme_lookup.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x70,umask=0x1\000\00001\000\000 */
{ 3618799 }, /* unc_h_hitme_lookup.rsp\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x80\000\00001\000\000 */
{ 3618996 }, /* unc_h_hitme_lookup.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x70,umask=0x20\000\00001\000\000 */
{ 3619192 }, /* unc_h_hitme_lookup.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x70,umask=0x10\000\00001\000\000 */
{ 3619390 }, /* unc_h_hitme_lookup.rspfwds\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x70,umask=0x40\000\00001\000\000 */
{ 3619559 }, /* unc_h_hitme_lookup.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x70,umask=0x8\000\00001\000\000 */
{ 3619728 }, /* unc_h_hitme_lookup.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoI. Unit: uncore_ha \000event=0x70,umask=0x2\000\00001\000\000 */
{ 3627792 }, /* unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628119 }, /* unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628446 }, /* unc_h_igr_no_credit_cycles.ad_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628774 }, /* unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629101 }, /* unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629428 }, /* unc_h_igr_no_credit_cycles.bl_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629756 }, /* unc_h_imc_reads.normal\000uncore_ha\000uncore cache\000HA to iMC Normal Priority Reads Issued; Normal Priority. Unit: uncore_ha \000event=0x17,umask=0x1\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 3630382 }, /* unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000 */
{ 3630468 }, /* unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3630784 }, /* unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631110 }, /* unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631438 }, /* unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631765 }, /* unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3649797 }, /* unc_h_iot_backpressure.hub\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x2\000\00001\000\000 */
{ 3649908 }, /* unc_h_iot_backpressure.sat\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x1\000\00001\000\000 */
{ 3650019 }, /* unc_h_iot_cts_east_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650171 }, /* unc_h_iot_cts_east_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650323 }, /* unc_h_iot_cts_hi.cts2\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650470 }, /* unc_h_iot_cts_hi.cts3\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650617 }, /* unc_h_iot_cts_west_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650769 }, /* unc_h_iot_cts_west_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3652460 }, /* unc_h_osb.cancelled\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Cancelled. Unit: uncore_ha \000event=0x53,umask=0x10\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB.; OSB Snoop broadcast cancelled due to D2C or Other. OSB cancel is counted when OSB local read is not allowed even when the transaction in local InItoE. It also counts D2C OSB cancel, but also includes the cases were D2C was not set in the first place for the transaction coming from the ring\000 */
{ 3653009 }, /* unc_h_osb.invitoe_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local InvItoE. Unit: uncore_ha \000event=0x53,umask=0x4\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653272 }, /* unc_h_osb.reads_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local Reads. Unit: uncore_ha \000event=0x53,umask=0x2\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653531 }, /* unc_h_osb.reads_local_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Reads Local -  Useful. Unit: uncore_ha \000event=0x53,umask=0x20\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653808 }, /* unc_h_osb.remote\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote. Unit: uncore_ha \000event=0x53,umask=0x8\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654057 }, /* unc_h_osb.remote_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote - Useful. Unit: uncore_ha \000event=0x53,umask=0x40\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654449 }, /* unc_h_osb_edr.all\000uncore_ha\000uncore cache\000OSB Early Data Return; All. Unit: uncore_ha \000event=0x54,umask=0x1\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654695 }, /* unc_h_osb_edr.reads_local_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local  I. Unit: uncore_ha \000event=0x54,umask=0x2\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654965 }, /* unc_h_osb_edr.reads_local_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local S. Unit: uncore_ha \000event=0x54,umask=0x8\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655234 }, /* unc_h_osb_edr.reads_remote_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote I. Unit: uncore_ha \000event=0x54,umask=0x4\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655505 }, /* unc_h_osb_edr.reads_remote_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote S. Unit: uncore_ha \000event=0x54,umask=0x10\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3657030 }, /* unc_h_requests.invitoe_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x10\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from the local socket\000 */
{ 3657584 }, /* unc_h_requests.invitoe_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x20\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from remote sockets\000 */
{ 3658081 }, /* unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming ead requests.  This is a good proxy for LLC Read Misses (including RFOs)\000 */
{ 3658883 }, /* unc_h_requests.reads_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Reads. Unit: uncore_ha \000event=0x1,umask=0x1\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the local socket.  This is a good proxy for LLC Read Misses (including RFOs) from the local socket\000 */
{ 3659475 }, /* unc_h_requests.reads_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Reads. Unit: uncore_ha \000event=0x1,umask=0x2\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the remote socket.  This is a good proxy for LLC Read Misses (including RFOs) from the remote socket\000 */
{ 3660059 }, /* unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming write requests\000 */
{ 3660809 }, /* unc_h_requests.writes_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Writes. Unit: uncore_ha \000event=0x1,umask=0x4\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from the local socket\000 */
{ 3661316 }, /* unc_h_requests.writes_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Writes. Unit: uncore_ha \000event=0x1,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from remote sockets\000 */
{ 3661687 }, /* unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3662382 }, /* unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3663162 }, /* unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3666081 }, /* unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3666420 }, /* unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3667177 }, /* unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3669673 }, /* unc_h_ring_ak_used.all\000uncore_ha\000uncore cache\000HA AK Ring in Use; All. Unit: uncore_ha \000event=0x3f,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3670007 }, /* unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3670702 }, /* unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3671482 }, /* unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3674401 }, /* unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3674740 }, /* unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3675497 }, /* unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3677993 }, /* unc_h_ring_bl_used.all\000uncore_ha\000uncore cache\000HA BL Ring in Use; All. Unit: uncore_ha \000event=0x40,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3678327 }, /* unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3679022 }, /* unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3679802 }, /* unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3682721 }, /* unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3683060 }, /* unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3683817 }, /* unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3693072 }, /* unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3694856 }, /* unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3696640 }, /* unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3698424 }, /* unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3700168 }, /* unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3701870 }, /* unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3703572 }, /* unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3705274 }, /* unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3733425 }, /* unc_h_sbo0_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733616 }, /* unc_h_sbo0_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733807 }, /* unc_h_sbo0_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x68,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3733999 }, /* unc_h_sbo0_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x68,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3734191 }, /* unc_h_sbo1_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734382 }, /* unc_h_sbo1_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734573 }, /* unc_h_sbo1_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x69,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3734765 }, /* unc_h_sbo1_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x69,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3736413 }, /* unc_h_snoop_cycles_ne.all\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; All Requests. Unit: uncore_ha \000event=0x8,umask=0x3\000\00001\000Counts cycles when one or more snoops are outstanding.; Tracked for snoops from both local and remote sockets\000 */
{ 3736659 }, /* unc_h_snoop_cycles_ne.local\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Local Requests. Unit: uncore_ha \000event=0x8,umask=0x1\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from the local socket\000 */
{ 3736919 }, /* unc_h_snoop_cycles_ne.remote\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Remote Requests. Unit: uncore_ha \000event=0x8,umask=0x2\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from remote sockets\000 */
{ 3737179 }, /* unc_h_snoop_occupancy.local\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Local Requests. Unit: uncore_ha \000event=0x9,umask=0x1\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from the local socket\000 */
{ 3737841 }, /* unc_h_snoop_occupancy.remote\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Remote Requests. Unit: uncore_ha \000event=0x9,umask=0x2\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from remote sockets\000 */
{ 3738676 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000M line forwarded from remote cache along with writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x20\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3740517 }, /* unc_h_snoop_resp.rsp_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*WB. Unit: uncore_ha \000event=0x21,umask=0x10\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3741525 }, /* unc_h_snoop_resp.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received; RSPCNFLCT*. Unit: uncore_ha \000event=0x21,umask=0x40\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3742665 }, /* unc_h_snoop_resp.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received; RspI. Unit: uncore_ha \000event=0x21,umask=0x1\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3743560 }, /* unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000M line forwarded from remote cache with no writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x4\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3745354 }, /* unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Shared line response from remote cache. Unit: uncore_ha \000event=0x21,umask=0x2\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3747069 }, /* unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Shared line forwarded from remote cache. Unit: uncore_ha \000event=0x21,umask=0x8\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3750143 }, /* unc_h_snoops_rsp_after_data.local\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Local Requests. Unit: uncore_ha \000event=0xa,umask=0x1\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from the local socket\000 */
{ 3750440 }, /* unc_h_snoops_rsp_after_data.remote\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Remote Requests. Unit: uncore_ha \000event=0xa,umask=0x2\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from remote sockets\000 */
{ 3751926 }, /* unc_h_snp_resp_recv_local.other\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Other. Unit: uncore_ha \000event=0x60,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for all other snoop responses\000 */
{ 3752158 }, /* unc_h_snp_resp_recv_local.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_ha \000event=0x60,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3752627 }, /* unc_h_snp_resp_recv_local.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_ha \000event=0x60,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3753011 }, /* unc_h_snp_resp_recv_local.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_ha \000event=0x60,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3753465 }, /* unc_h_snp_resp_recv_local.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_ha \000event=0x60,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3753887 }, /* unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3754721 }, /* unc_h_snp_resp_recv_local.rspxfwdxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_ha \000event=0x60,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3755195 }, /* unc_h_snp_resp_recv_local.rspxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_ha \000event=0x60,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3757116 }, /* unc_h_stall_no_sbo_credit.sbo0_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757360 }, /* unc_h_stall_no_sbo_credit.sbo0_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757604 }, /* unc_h_stall_no_sbo_credit.sbo1_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757848 }, /* unc_h_stall_no_sbo_credit.sbo1_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3763538 }, /* unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 0\000 */
{ 3765043 }, /* unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 1\000 */
{ 3766548 }, /* unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 2\000 */
{ 3768053 }, /* unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 3\000 */
{ 3769559 }, /* unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 4\000 */
{ 3771066 }, /* unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 5\000 */
{ 3772573 }, /* unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 6\000 */
{ 3774080 }, /* unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 7\000 */
{ 3775589 }, /* unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 10\000 */
{ 3777101 }, /* unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 11\000 */
{ 3778611 }, /* unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 8\000 */
{ 3780118 }, /* unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 9\000 */
{ 3793272 }, /* unc_h_tracker_cycles_full.all\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles Completely Used. Unit: uncore_ha \000event=0x2,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the HA tracker pool (HT) is completely used including reserved HT entries.  It will not return valid count when BT is disabled\000 */
{ 3794203 }, /* unc_h_tracker_cycles_full.gp\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles GP Completely Used. Unit: uncore_ha \000event=0x2,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the general purpose (GP) HA tracker pool (HT) is completely used.  It will not return valid count when BT is disabled\000 */
{ 3795127 }, /* unc_h_tracker_cycles_ne.all\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; All Requests. Unit: uncore_ha \000event=0x3,umask=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Requests coming from both local and remote sockets\000 */
{ 3796110 }, /* unc_h_tracker_cycles_ne.local\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Local Requests. Unit: uncore_ha \000event=0x3,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from the local socket\000 */
{ 3797110 }, /* unc_h_tracker_cycles_ne.remote\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Remote Requests. Unit: uncore_ha \000event=0x3,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from remote sockets\000 */
{ 3799550 }, /* unc_h_tracker_occupancy.invitoe_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x40\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800176 }, /* unc_h_tracker_occupancy.invitoe_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x80\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800804 }, /* unc_h_tracker_occupancy.reads_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Read Requests. Unit: uncore_ha \000event=0x4,umask=0x4\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3801424 }, /* unc_h_tracker_occupancy.reads_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Read Requests. Unit: uncore_ha \000event=0x4,umask=0x8\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802046 }, /* unc_h_tracker_occupancy.writes_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Write Requests. Unit: uncore_ha \000event=0x4,umask=0x10\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802669 }, /* unc_h_tracker_occupancy.writes_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Write Requests. Unit: uncore_ha \000event=0x4,umask=0x20\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3803294 }, /* unc_h_tracker_pending_occupancy.local\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Local Requests. Unit: uncore_ha \000event=0x5,umask=0x1\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from the local socket\000 */
{ 3803895 }, /* unc_h_tracker_pending_occupancy.remote\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Remote Requests. Unit: uncore_ha \000event=0x5,umask=0x2\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from remote sockets\000 */
{ 3804496 }, /* unc_h_txr_ad.hom\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x4\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details.; Filter for outbound NDR transactions sent on the AD ring.  NDR stands for non-data response and is generally used for completions that do not include data.  AD NDR is used for transactions to remote sockets\000 */
{ 3805581 }, /* unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000AD Egress Full; Cycles full from both schedulers\000 */
{ 3805861 }, /* unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3806176 }, /* unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3806491 }, /* unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000AD Egress Not Empty; Cycles full from both schedulers\000 */
{ 3806782 }, /* unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000AD Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3807113 }, /* unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000AD Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3807443 }, /* unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000AD Egress Allocations; Allocations from both schedulers\000 */
{ 3807736 }, /* unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3808063 }, /* unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3809300 }, /* unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000AK Egress Full; Cycles full from both schedulers\000 */
{ 3809580 }, /* unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3809895 }, /* unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3810210 }, /* unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000AK Egress Not Empty; Cycles full from both schedulers\000 */
{ 3810501 }, /* unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000AK Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3810832 }, /* unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000AK Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3811162 }, /* unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000AK Egress Allocations; Allocations from both schedulers\000 */
{ 3811455 }, /* unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3811782 }, /* unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3813194 }, /* unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to the cache\000 */
{ 3813726 }, /* unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent directly to the requesting core\000 */
{ 3814273 }, /* unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to a remote socket over QPI\000 */
{ 3814812 }, /* unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000BL Egress Full; Cycles full from both schedulers\000 */
{ 3815092 }, /* unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3815407 }, /* unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3815722 }, /* unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000BL Egress Not Empty; Cycles full from both schedulers\000 */
{ 3816013 }, /* unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000BL Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3816344 }, /* unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000BL Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3816674 }, /* unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000BL Egress Allocations; Allocations from both schedulers\000 */
{ 3816967 }, /* unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3817294 }, /* unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3826497 }, /* unc_h_txr_starved.ak\000uncore_ha\000uncore cache\000Injection Starvation; For AK Ring. Unit: uncore_ha \000event=0x6d,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3826759 }, /* unc_h_txr_starved.bl\000uncore_ha\000uncore cache\000Injection Starvation; For BL Ring. Unit: uncore_ha \000event=0x6d,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3843414 }, /* unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3845224 }, /* unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3847034 }, /* unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3848844 }, /* unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3850614 }, /* unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3852342 }, /* unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3854070 }, /* unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3855798 }, /* unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 2480779 }, /* qpi_ctl_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of non data (control) flits transmitted . Derived from unc_q_txl_flits_g0.non_data. Unit: uncore_qpi \000event=0,umask=0x4\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 2482340 }, /* qpi_data_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of data flits transmitted . Derived from unc_q_txl_flits_g0.data. Unit: uncore_qpi \000event=0,umask=0x2\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 3871403 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3873716 }, /* unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3876751 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000 */
{ 3877660 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878039 }, /* unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878409 }, /* unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878795 }, /* unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879191 }, /* unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879386 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIItoM. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3880060 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000Coherent Ops; RFO. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3881086 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3883149 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x10\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary\000 */
{ 3883756 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x4\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary\000 */
{ 3884348 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x8\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary\000 */
{ 3884906 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Counts Timeouts - Set 0 : Fastpath Rejects\000 */
{ 3885359 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Counts Timeouts - Set 0 : Fastpath Requests\000 */
{ 3885844 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x20\000\00001\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary\000 */
{ 3886416 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x40\000\00001\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary\000 */
{ 3886820 }, /* unc_i_misc0.pf_timeout\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch TimeOut. Unit: uncore_irp \000event=0x14,umask=0x80\000\00001\000Indicates the fetch for a previous prefetch wasn't accepted by the prefetch.   This happens in the case of a prefetch TimeOut\000 */
{ 3887372 }, /* unc_i_misc1.data_throttle\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Data Throttled. Unit: uncore_irp \000event=0x15,umask=0x80\000\00001\000IRP throttled switch data\000 */
{ 3887762 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1. Unit: uncore_irp \000event=0x15,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888414 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x15,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3889079 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x15,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889739 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890405 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891075 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x15,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891747 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3895230 }, /* unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895678 }, /* unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_CYCLES_FULL. Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896298 }, /* unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896614 }, /* unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_OCCUPANCY. Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897234 }, /* unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_CYCLES_FULL. Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897854 }, /* unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898170 }, /* unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_OCCUPANCY. Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898790 }, /* unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_CYCLES_FULL. Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899410 }, /* unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899726 }, /* unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_OCCUPANCY. Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3901893 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x17,umask=0x4\000\00001\000Snoop Responses : Hit E or S\000 */
{ 3902294 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Snoop Responses : Hit I\000 */
{ 3902684 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x17,umask=0x8\000\00001\000Snoop Responses : Hit M\000 */
{ 3903070 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Snoop Responses : Miss\000 */
{ 3903467 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x17,umask=0x10\000\00001\000Snoop Responses : SnpCode\000 */
{ 3903874 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x17,umask=0x20\000\00001\000Snoop Responses : SnpData\000 */
{ 3904277 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x17,umask=0x40\000\00001\000Snoop Responses : SnpInv\000 */
{ 3907099 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x16,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000 */
{ 3908632 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x16,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000 */
{ 3910563 }, /* unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x16,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3913028 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3913535 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Write Prefetches. Unit: uncore_irp \000event=0x16,umask=0x8\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of write prefetches\000 */
{ 3917521 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests\000 */
{ 3921293 }, /* unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3921548 }, /* unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3921798 }, /* unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3921985 }, /* unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3922172 }, /* unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 5688420 }, /* unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/4th the GT/s speed of the QPI link.  For example, a 4GT/s link will have qfclk or 1GHz.  BDX does not support dynamic link speeds, so this frequency is fixed\000 */
{ 5689710 }, /* unc_q_cto_count\000uncore_qpi\000uncore interconnect\000Count of CTO Events. Unit: uncore_qpi \000event=0x38\000\00001\000Counts the number of CTO (cluster trigger outs) events that were asserted across the two slots.  If both slots trigger in a given cycle, the event will increment by 2.  You can use edge detect to count the number of cases when both events triggered\000 */
{ 5690060 }, /* unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits.  Had there been enough credits, the spawn would have worked as the RBT bit was set and the RBT tag matched\000 */
{ 5691288 }, /* unc_q_direct2core.failure_credits_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x20\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and there weren't enough Egress credits.   The valid bit was set\000 */
{ 5691945 }, /* unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits AND the RBT bit was not set, but the RBT tag matched\000 */
{ 5693134 }, /* unc_q_direct2core.failure_credits_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss, Invalid. Unit: uncore_qpi \000event=0x13,umask=0x80\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match, the valid bit was not set and there weren't enough Egress credits\000 */
{ 5693806 }, /* unc_q_direct2core.failure_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x10\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match although the valid bit was set and there were enough Egress credits\000 */
{ 5694968 }, /* unc_q_direct2core.failure_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the route-back table (RBT) specified that the transaction should not trigger a direct2core transaction.  This is common for IO transactions.  There were enough Egress credits and the RBT tag matched but the valid bit was not set\000 */
{ 5695749 }, /* unc_q_direct2core.failure_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss and Invalid. Unit: uncore_qpi \000event=0x13,umask=0x40\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and the valid bit was not set although there were enough Egress credits\000 */
{ 5696913 }, /* unc_q_direct2core.success_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn was successful.  There were sufficient credits, the RBT valid bit was set and there was an RBT tag match.  The message was marked to spawn direct2core\000 */
{ 5697587 }, /* unc_q_l1_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L1. Unit: uncore_qpi \000event=0x12\000\00001\000Number of QPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a QPI link.  Use edge detect to count the number of instances when the QPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 5701151 }, /* unc_q_rxl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xf\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5701702 }, /* unc_q_rxl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0x10\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5702372 }, /* unc_q_rxl_bypassed\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x9\000\00001\000Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 5702855 }, /* unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during link initialization\000 */
{ 5704884 }, /* unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000UNC_Q_RxL_CRC_ERRORS.NORMAL_OP. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000\000 */
{ 5705021 }, /* unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the DRS message class\000 */
{ 5705718 }, /* unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the HOM message class\000 */
{ 5706415 }, /* unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCB message class\000 */
{ 5707112 }, /* unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCS message class\000 */
{ 5707809 }, /* unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NDR message class\000 */
{ 5708508 }, /* unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the SNP message class\000 */
{ 5709207 }, /* unc_q_rxl_credits_consumed_vn1.drs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x39,umask=0x1\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the DRS message class\000 */
{ 5709575 }, /* unc_q_rxl_credits_consumed_vn1.hom\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x39,umask=0x8\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the HOM message class\000 */
{ 5709943 }, /* unc_q_rxl_credits_consumed_vn1.ncb\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x39,umask=0x2\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCB message class\000 */
{ 5710311 }, /* unc_q_rxl_credits_consumed_vn1.ncs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x39,umask=0x4\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCS message class\000 */
{ 5710679 }, /* unc_q_rxl_credits_consumed_vn1.ndr\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x39,umask=0x20\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NDR message class\000 */
{ 5711048 }, /* unc_q_rxl_credits_consumed_vn1.snp\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x39,umask=0x10\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the SNP message class\000 */
{ 5711417 }, /* unc_q_rxl_credits_consumed_vna\000uncore_qpi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_qpi \000event=0x1d\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5711727 }, /* unc_q_rxl_cycles_ne\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty. Unit: uncore_qpi \000event=0xa\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy\000 */
{ 5712262 }, /* unc_q_rxl_cycles_ne_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN0. Unit: uncore_qpi \000event=0xf,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5712861 }, /* unc_q_rxl_cycles_ne_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN1. Unit: uncore_qpi \000event=0xf,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5713460 }, /* unc_q_rxl_cycles_ne_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN0. Unit: uncore_qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714060 }, /* unc_q_rxl_cycles_ne_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN1. Unit: uncore_qpi \000event=0x12,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714660 }, /* unc_q_rxl_cycles_ne_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN0. Unit: uncore_qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715260 }, /* unc_q_rxl_cycles_ne_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN1. Unit: uncore_qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715860 }, /* unc_q_rxl_cycles_ne_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN0. Unit: uncore_qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5716460 }, /* unc_q_rxl_cycles_ne_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN1. Unit: uncore_qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5717060 }, /* unc_q_rxl_cycles_ne_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN0. Unit: uncore_qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5717660 }, /* unc_q_rxl_cycles_ne_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN1. Unit: uncore_qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5718260 }, /* unc_q_rxl_cycles_ne_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN0. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5718860 }, /* unc_q_rxl_cycles_ne_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN1. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5723528 }, /* unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of flits received over QPI that do not hold protocol payload.  When QPI is not in a power saving state, it continuously transmits flits across the link.  When there are no protocol flits to send, it will send IDLE and NULL flits  across.  These flits sometimes do carry a payload, such as credit returns, but are generally not considered part of the QPI bandwidth\000 */
{ 5729146 }, /* unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data\000 */
{ 5731892 }, /* unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5734688 }, /* unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5737511 }, /* unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits received over QPI on the home channel\000 */
{ 5740071 }, /* unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits received over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5742745 }, /* unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request received over QPI on the home channel.  This basically counts the number of remote memory requests received over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5745489 }, /* unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits received over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are received on the home channel\000 */
{ 5748168 }, /* unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5750790 }, /* unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5753552 }, /* unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5756302 }, /* unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits received over QPI.    This includes extended headers\000 */
{ 5758922 }, /* unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5761696 }, /* unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5763199 }, /* unc_q_rxl_inserts\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x8\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5763737 }, /* unc_q_rxl_inserts_drs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN0. Unit: uncore_qpi \000event=0x9,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5764339 }, /* unc_q_rxl_inserts_drs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN1. Unit: uncore_qpi \000event=0x9,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5765520 }, /* unc_q_rxl_inserts_hom.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN0. Unit: uncore_qpi \000event=0xc,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5766122 }, /* unc_q_rxl_inserts_hom.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN1. Unit: uncore_qpi \000event=0xc,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5767303 }, /* unc_q_rxl_inserts_ncb.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN0. Unit: uncore_qpi \000event=0xa,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5767905 }, /* unc_q_rxl_inserts_ncb.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN1. Unit: uncore_qpi \000event=0xa,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5769086 }, /* unc_q_rxl_inserts_ncs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN0. Unit: uncore_qpi \000event=0xb,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5769688 }, /* unc_q_rxl_inserts_ncs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN1. Unit: uncore_qpi \000event=0xb,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5770869 }, /* unc_q_rxl_inserts_ndr.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN0. Unit: uncore_qpi \000event=0xe,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5771471 }, /* unc_q_rxl_inserts_ndr.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN1. Unit: uncore_qpi \000event=0xe,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5772652 }, /* unc_q_rxl_inserts_snp.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN0. Unit: uncore_qpi \000event=0xd,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5773254 }, /* unc_q_rxl_inserts_snp.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN1. Unit: uncore_qpi \000event=0xd,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5774435 }, /* unc_q_rxl_occupancy\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - All Packets. Unit: uncore_qpi \000event=0xb\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 5775035 }, /* unc_q_rxl_occupancy_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x15,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5775686 }, /* unc_q_rxl_occupancy_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x15,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5776965 }, /* unc_q_rxl_occupancy_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x18,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5777616 }, /* unc_q_rxl_occupancy_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x18,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5778895 }, /* unc_q_rxl_occupancy_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x16,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5779546 }, /* unc_q_rxl_occupancy_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x16,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5780825 }, /* unc_q_rxl_occupancy_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x17,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5781476 }, /* unc_q_rxl_occupancy_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x17,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5782755 }, /* unc_q_rxl_occupancy_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN0. Unit: uncore_qpi \000event=0x1a,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5783406 }, /* unc_q_rxl_occupancy_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN1. Unit: uncore_qpi \000event=0x1a,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5784685 }, /* unc_q_rxl_occupancy_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x19,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5785336 }, /* unc_q_rxl_occupancy_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x19,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5788063 }, /* unc_q_rxl_stalls_vn0.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788473 }, /* unc_q_rxl_stalls_vn0.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788883 }, /* unc_q_rxl_stalls_vn0.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789293 }, /* unc_q_rxl_stalls_vn0.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789703 }, /* unc_q_rxl_stalls_vn0.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790114 }, /* unc_q_rxl_stalls_vn0.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790525 }, /* unc_q_rxl_stalls_vn0.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet because there were insufficient BGF credits.  For details on a message class granularity, use the Egress Credit Occupancy events\000 */
{ 5790893 }, /* unc_q_rxl_stalls_vn0.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled because a GV transition (frequency transition) was taking place\000 */
{ 5791163 }, /* unc_q_rxl_stalls_vn1.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - HOM. Unit: uncore_qpi \000event=0x3a,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791574 }, /* unc_q_rxl_stalls_vn1.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - DRS. Unit: uncore_qpi \000event=0x3a,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791985 }, /* unc_q_rxl_stalls_vn1.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - SNP. Unit: uncore_qpi \000event=0x3a,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792396 }, /* unc_q_rxl_stalls_vn1.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NDR. Unit: uncore_qpi \000event=0x3a,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792807 }, /* unc_q_rxl_stalls_vn1.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCS. Unit: uncore_qpi \000event=0x3a,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793219 }, /* unc_q_rxl_stalls_vn1.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCB. Unit: uncore_qpi \000event=0x3a,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793631 }, /* unc_q_txl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xc\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5794182 }, /* unc_q_txl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0xd\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5794851 }, /* unc_q_txl_bypassed\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x5\000\00001\000Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the QPI Link. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5795291 }, /* unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is almost full, we block some but not all packets\000 */
{ 5795874 }, /* unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is totally full, we are not allowed to send any packets\000 */
{ 5796435 }, /* unc_q_txl_cycles_ne\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Cycles not Empty. Unit: uncore_qpi \000event=0x6\000\00001\000Counts the number of cycles when the TxQ is not empty. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5798047 }, /* unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 5802153 }, /* unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 5804958 }, /* unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency\000 */
{ 5807622 }, /* unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5810436 }, /* unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5813277 }, /* unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits transmitted over QPI on the home channel\000 */
{ 5815852 }, /* unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits transmitted over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5818541 }, /* unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request transmitted over QPI on the home channel.  This basically counts the number of remote memory requests transmitted over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5821303 }, /* unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits transmitted over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are transmitted on the home channel\000 */
{ 5824009 }, /* unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5826654 }, /* unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5829432 }, /* unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5832198 }, /* unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits transmitted over QPI.    This includes extended headers\000 */
{ 5834837 }, /* unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5837630 }, /* unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5839144 }, /* unc_q_txl_inserts\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x4\000\00001\000Number of allocations into the QPI Tx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5839647 }, /* unc_q_txl_occupancy\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_qpi \000event=0x7\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 5840151 }, /* unc_q_txr_ad_hom_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x26,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840446 }, /* unc_q_txr_ad_hom_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x26,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840741 }, /* unc_q_txr_ad_hom_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN0. Unit: uncore_qpi \000event=0x22,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841076 }, /* unc_q_txr_ad_hom_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN1. Unit: uncore_qpi \000event=0x22,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841411 }, /* unc_q_txr_ad_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x28,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5841709 }, /* unc_q_txr_ad_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x28,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5842007 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x24,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842342 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x24,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842677 }, /* unc_q_txr_ad_snp_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x27,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5842974 }, /* unc_q_txr_ad_snp_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x27,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843271 }, /* unc_q_txr_ad_snp_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN0. Unit: uncore_qpi \000event=0x23,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843608 }, /* unc_q_txr_ad_snp_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN1. Unit: uncore_qpi \000event=0x23,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5844509 }, /* unc_q_txr_ak_ndr_credit_acquired\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x29\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000 */
{ 5845408 }, /* unc_q_txr_ak_ndr_credit_occupancy\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x25\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000 */
{ 5845705 }, /* unc_q_txr_bl_drs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x2a,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5845978 }, /* unc_q_txr_bl_drs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x2a,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846251 }, /* unc_q_txr_bl_drs_credit_acquired.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for Shared VN. Unit: uncore_qpi \000event=0x2a,umask=0x4\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846533 }, /* unc_q_txr_bl_drs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN0. Unit: uncore_qpi \000event=0x1f,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5846847 }, /* unc_q_txr_bl_drs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN1. Unit: uncore_qpi \000event=0x1f,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847161 }, /* unc_q_txr_bl_drs_credit_occupancy.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for Shared VN. Unit: uncore_qpi \000event=0x1f,umask=0x4\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847484 }, /* unc_q_txr_bl_ncb_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x2b,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5847757 }, /* unc_q_txr_bl_ncb_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x2b,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5848030 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN0. Unit: uncore_qpi \000event=0x20,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848344 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN1. Unit: uncore_qpi \000event=0x20,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848658 }, /* unc_q_txr_bl_ncs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x2c,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5848931 }, /* unc_q_txr_bl_ncs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x2c,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5849204 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN0. Unit: uncore_qpi \000event=0x21,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849518 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN1. Unit: uncore_qpi \000event=0x21,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849832 }, /* unc_q_vna_credit_return_occupancy\000uncore_qpi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_qpi \000event=0x1b\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 5850059 }, /* unc_q_vna_credit_returns\000uncore_qpi\000uncore interconnect\000VNA Credits Returned. Unit: uncore_qpi \000event=0x1c\000\00001\000Number of VNA credits returned\000 */
{ 5902377 }, /* unc_r3_c_hi_ad_credits_empty.cbo10\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 10\000 */
{ 5902817 }, /* unc_r3_c_hi_ad_credits_empty.cbo11\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 11\000 */
{ 5903257 }, /* unc_r3_c_hi_ad_credits_empty.cbo12\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 12\000 */
{ 5903699 }, /* unc_r3_c_hi_ad_credits_empty.cbo13\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 13\000 */
{ 5904365 }, /* unc_r3_c_hi_ad_credits_empty.cbo14_16\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 14&16\000 */
{ 5904592 }, /* unc_r3_c_hi_ad_credits_empty.cbo8\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 8\000 */
{ 5905028 }, /* unc_r3_c_hi_ad_credits_empty.cbo9\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 9\000 */
{ 5905464 }, /* unc_r3_c_hi_ad_credits_empty.cbo_15_17\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 15&17\000 */
{ 5905692 }, /* unc_r3_c_lo_ad_credits_empty.cbo0\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 0\000 */
{ 5906126 }, /* unc_r3_c_lo_ad_credits_empty.cbo1\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 1\000 */
{ 5906560 }, /* unc_r3_c_lo_ad_credits_empty.cbo2\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 2\000 */
{ 5906994 }, /* unc_r3_c_lo_ad_credits_empty.cbo3\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 3\000 */
{ 5907428 }, /* unc_r3_c_lo_ad_credits_empty.cbo4\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 4\000 */
{ 5907864 }, /* unc_r3_c_lo_ad_credits_empty.cbo5\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 5\000 */
{ 5908300 }, /* unc_r3_c_lo_ad_credits_empty.cbo6\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 6\000 */
{ 5908736 }, /* unc_r3_c_lo_ad_credits_empty.cbo7\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 7\000 */
{ 5909172 }, /* unc_r3_clockticks\000uncore_r3qpi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_r3qpi \000event=0x1\000\00001\000Counts the number of uclks in the QPI uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the QPI Agent is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5909550 }, /* unc_r3_ha_r2_bl_credits_empty.ha0\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x1\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA0\000 */
{ 5909958 }, /* unc_r3_ha_r2_bl_credits_empty.ha1\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x2\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA1\000 */
{ 5910366 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncb\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x4\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCB Messages\000 */
{ 5910804 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncs\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x8\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCS Messages\000 */
{ 5916510 }, /* unc_r3_iot_backpressure.hub\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x2\000\00001\000\000 */
{ 5916634 }, /* unc_r3_iot_backpressure.sat\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x1\000\00001\000\000 */
{ 5916758 }, /* unc_r3_iot_cts_hi.cts2\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5916918 }, /* unc_r3_iot_cts_hi.cts3\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917078 }, /* unc_r3_iot_cts_lo.cts0\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917238 }, /* unc_r3_iot_cts_lo.cts1\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917398 }, /* unc_r3_qpi0_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x2\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 HOM Messages\000 */
{ 5917814 }, /* unc_r3_qpi0_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x8\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 NDR Messages\000 */
{ 5918230 }, /* unc_r3_qpi0_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x4\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 SNP Messages\000 */
{ 5918646 }, /* unc_r3_qpi0_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x10\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 HOM Messages\000 */
{ 5919064 }, /* unc_r3_qpi0_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x40\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 NDR Messages\000 */
{ 5919482 }, /* unc_r3_qpi0_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x20\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 SNP Messages\000 */
{ 5919900 }, /* unc_r3_qpi0_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x1\000\00001\000No credits available to send to QPI0 on the AD Ring; VNA\000 */
{ 5920906 }, /* unc_r3_qpi0_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x10\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 HOM Messages\000 */
{ 5921324 }, /* unc_r3_qpi0_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x40\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 NDR Messages\000 */
{ 5921742 }, /* unc_r3_qpi0_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x20\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 SNP Messages\000 */
{ 5922160 }, /* unc_r3_qpi0_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x1\000\00001\000No credits available to send to QPI0 on the BL Ring; VNA\000 */
{ 5923375 }, /* unc_r3_qpi1_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x10\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 HOM Messages\000 */
{ 5923793 }, /* unc_r3_qpi1_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x40\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 NDR Messages\000 */
{ 5924211 }, /* unc_r3_qpi1_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x20\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 SNP Messages\000 */
{ 5924611 }, /* unc_r3_qpi1_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x1\000\00001\000No credits available to send to QPI1 on the AD Ring; VNA\000 */
{ 5925010 }, /* unc_r3_qpi1_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x2\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 HOM Messages\000 */
{ 5925426 }, /* unc_r3_qpi1_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x8\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 NDR Messages\000 */
{ 5925842 }, /* unc_r3_qpi1_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x4\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 SNP Messages\000 */
{ 5926259 }, /* unc_r3_qpi1_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x10\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 HOM Messages\000 */
{ 5926677 }, /* unc_r3_qpi1_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x40\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 NDR Messages\000 */
{ 5927095 }, /* unc_r3_qpi1_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x20\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 SNP Messages\000 */
{ 5927495 }, /* unc_r3_qpi1_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x1\000\00001\000No credits available to send to QPI1 on the BL Ring; VNA\000 */
{ 5927686 }, /* unc_r3_ring_ad_used.all\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; All. Unit: uncore_r3qpi \000event=0x7,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5928033 }, /* unc_r3_ring_ad_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5928754 }, /* unc_r3_ring_ad_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5929560 }, /* unc_r3_ring_ad_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5931641 }, /* unc_r3_ring_ad_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5931993 }, /* unc_r3_ring_ad_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5932776 }, /* unc_r3_ring_ad_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5934451 }, /* unc_r3_ring_ak_used.all\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; All. Unit: uncore_r3qpi \000event=0x8,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5934798 }, /* unc_r3_ring_ak_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5935893 }, /* unc_r3_ring_ak_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5936697 }, /* unc_r3_ring_ak_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5938406 }, /* unc_r3_ring_ak_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5939124 }, /* unc_r3_ring_ak_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5939905 }, /* unc_r3_ring_ak_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5941216 }, /* unc_r3_ring_bl_used.all\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; All. Unit: uncore_r3qpi \000event=0x9,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5941563 }, /* unc_r3_ring_bl_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5942284 }, /* unc_r3_ring_bl_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5943090 }, /* unc_r3_ring_bl_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5945171 }, /* unc_r3_ring_bl_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5945523 }, /* unc_r3_ring_bl_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5946306 }, /* unc_r3_ring_bl_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5949115 }, /* unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5950665 }, /* unc_r3_ring_iv_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5951017 }, /* unc_r3_ring_sink_starved.ak\000uncore_r3qpi\000uncore interconnect\000Ring Stop Starved; AK. Unit: uncore_r3qpi \000event=0xe,umask=0x2\000\00001\000Number of cycles the ringstop is in starvation (per ring)\000 */
{ 5952208 }, /* unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5954130 }, /* unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5955100 }, /* unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5956070 }, /* unc_r3_rxr_cycles_ne_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; DRS. Unit: uncore_r3qpi \000event=0x14,umask=0x8\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5956583 }, /* unc_r3_rxr_cycles_ne_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5957096 }, /* unc_r3_rxr_cycles_ne_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCB. Unit: uncore_r3qpi \000event=0x14,umask=0x10\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5957610 }, /* unc_r3_rxr_cycles_ne_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCS. Unit: uncore_r3qpi \000event=0x14,umask=0x20\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5958124 }, /* unc_r3_rxr_cycles_ne_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x14,umask=0x4\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5958637 }, /* unc_r3_rxr_cycles_ne_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5959150 }, /* unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5960086 }, /* unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5961022 }, /* unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5961960 }, /* unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5962898 }, /* unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5963834 }, /* unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5964770 }, /* unc_r3_rxr_inserts_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x15,umask=0x8\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5965266 }, /* unc_r3_rxr_inserts_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x15,umask=0x1\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5965762 }, /* unc_r3_rxr_inserts_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x15,umask=0x10\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5966259 }, /* unc_r3_rxr_inserts_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x15,umask=0x20\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5966756 }, /* unc_r3_rxr_inserts_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x15,umask=0x4\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5967252 }, /* unc_r3_rxr_inserts_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x15,umask=0x2\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5973044 }, /* unc_r3_rxr_occupancy_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5973518 }, /* unc_r3_rxr_occupancy_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; HOM Ingress Queue\000 */
{ 5973992 }, /* unc_r3_rxr_occupancy_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCB Ingress Queue\000 */
{ 5974467 }, /* unc_r3_rxr_occupancy_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCS Ingress Queue\000 */
{ 5974942 }, /* unc_r3_rxr_occupancy_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NDR Ingress Queue\000 */
{ 5975416 }, /* unc_r3_rxr_occupancy_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; SNP Ingress Queue\000 */
{ 5975890 }, /* unc_r3_sbo0_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5976095 }, /* unc_r3_sbo0_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5976300 }, /* unc_r3_sbo0_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5976506 }, /* unc_r3_sbo0_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5976712 }, /* unc_r3_sbo1_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 5976917 }, /* unc_r3_sbo1_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 5977122 }, /* unc_r3_sbo1_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 5977328 }, /* unc_r3_sbo1_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 5977534 }, /* unc_r3_stall_no_sbo_credit.sbo0_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5977792 }, /* unc_r3_stall_no_sbo_credit.sbo0_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978050 }, /* unc_r3_stall_no_sbo_credit.sbo1_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978308 }, /* unc_r3_stall_no_sbo_credit.sbo1_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978566 }, /* unc_r3_txr_nack.dn_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AD CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5978724 }, /* unc_r3_txr_nack.dn_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5978882 }, /* unc_r3_txr_nack.dn_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5979040 }, /* unc_r3_txr_nack.up_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5979198 }, /* unc_r3_txr_nack.up_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CW. Unit: uncore_r3qpi \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000 */
{ 5979349 }, /* unc_r3_txr_nack.up_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5980411 }, /* unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5982203 }, /* unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5983926 }, /* unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5985675 }, /* unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5987347 }, /* unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5989049 }, /* unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 5990780 }, /* unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5992862 }, /* unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5994875 }, /* unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5996914 }, /* unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5998876 }, /* unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6000868 }, /* unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6002889 }, /* unc_r3_vn1_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x8\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6003877 }, /* unc_r3_vn1_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x1\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6004796 }, /* unc_r3_vn1_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x10\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6005740 }, /* unc_r3_vn1_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x20\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6006607 }, /* unc_r3_vn1_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x4\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6007505 }, /* unc_r3_vn1_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x2\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6008432 }, /* unc_r3_vn1_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x8\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6009569 }, /* unc_r3_vn1_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x1\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6010637 }, /* unc_r3_vn1_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x10\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6011730 }, /* unc_r3_vn1_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x20\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6012746 }, /* unc_r3_vn1_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x4\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6013793 }, /* unc_r3_vn1_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x2\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6015739 }, /* unc_r3_vna_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x1\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6016691 }, /* unc_r3_vna_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x4\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6018440 }, /* unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6020284 }, /* unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6022059 }, /* unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6023860 }, /* unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Standard (NCS)\000 */
{ 6025555 }, /* unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6027309 }, /* unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6029092 }, /* unc_s_bounce_control\000uncore_sbox\000uncore interconnect\000Bounce Control. Unit: uncore_sbox \000event=0xa\000\00001\000\000 */
{ 6029195 }, /* unc_s_clockticks\000uncore_sbox\000uncore interconnect\000Uncore Clocks. Unit: uncore_sbox \000event=0\000\00001\000\000 */
{ 6029291 }, /* unc_s_fast_asserted\000uncore_sbox\000uncore interconnect\000FaST wire asserted. Unit: uncore_sbox \000event=0x9\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 6029530 }, /* unc_s_ring_ad_used.all\000uncore_sbox\000uncore interconnect\000AD Ring In Use; All. Unit: uncore_sbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6030374 }, /* unc_s_ring_ad_used.down\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down. Unit: uncore_sbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6031220 }, /* unc_s_ring_ad_used.down_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6033036 }, /* unc_s_ring_ad_used.down_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6034842 }, /* unc_s_ring_ad_used.up\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up. Unit: uncore_sbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6035684 }, /* unc_s_ring_ad_used.up_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6037484 }, /* unc_s_ring_ad_used.up_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6039278 }, /* unc_s_ring_ak_used.all\000uncore_sbox\000uncore interconnect\000AK Ring In Use; All. Unit: uncore_sbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6040121 }, /* unc_s_ring_ak_used.down\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down. Unit: uncore_sbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6040966 }, /* unc_s_ring_ak_used.down_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6042780 }, /* unc_s_ring_ak_used.down_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6044584 }, /* unc_s_ring_ak_used.up\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up. Unit: uncore_sbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6045425 }, /* unc_s_ring_ak_used.up_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6047223 }, /* unc_s_ring_ak_used.up_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6049015 }, /* unc_s_ring_bl_used.all\000uncore_sbox\000uncore interconnect\000BL Ring in Use; All. Unit: uncore_sbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6049858 }, /* unc_s_ring_bl_used.down\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down. Unit: uncore_sbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6050703 }, /* unc_s_ring_bl_used.down_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Event. Unit: uncore_sbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6052517 }, /* unc_s_ring_bl_used.down_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6054321 }, /* unc_s_ring_bl_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up. Unit: uncore_sbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6055162 }, /* unc_s_ring_bl_used.up_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Even. Unit: uncore_sbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6056960 }, /* unc_s_ring_bl_used.up_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in BDX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6058752 }, /* unc_s_ring_bounces.ad_cache\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring. Unit: uncore_sbox \000event=0x5,umask=0x1\000\00001\000\000 */
{ 6058906 }, /* unc_s_ring_bounces.ak_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_sbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 6059086 }, /* unc_s_ring_bounces.bl_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_sbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 6059264 }, /* unc_s_ring_bounces.iv_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_sbox \000event=0x5,umask=0x8\000\00001\000\000 */
{ 6059447 }, /* unc_s_ring_iv_used.dn\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 6060009 }, /* unc_s_ring_iv_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 6060571 }, /* unc_s_ring_sink_starved.ad_cache\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AD_CACHE. Unit: uncore_sbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 6060714 }, /* unc_s_ring_sink_starved.ak_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AK_CORE. Unit: uncore_sbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 6060855 }, /* unc_s_ring_sink_starved.bl_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.BL_CORE. Unit: uncore_sbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 6060996 }, /* unc_s_ring_sink_starved.iv_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.IV_CORE. Unit: uncore_sbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 6061137 }, /* unc_s_rxr_busy_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6061536 }, /* unc_s_rxr_busy_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x15,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6061935 }, /* unc_s_rxr_busy_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6062334 }, /* unc_s_rxr_busy_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x15,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6062733 }, /* unc_s_rxr_bypass.ad_bnc\000uncore_sbox\000uncore interconnect\000Bypass; AD - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x2\000\00001\000Bypass the Sbo Ingress\000 */
{ 6062878 }, /* unc_s_rxr_bypass.ad_crd\000uncore_sbox\000uncore interconnect\000Bypass; AD - Credits. Unit: uncore_sbox \000event=0x12,umask=0x1\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063023 }, /* unc_s_rxr_bypass.ak\000uncore_sbox\000uncore interconnect\000Bypass; AK. Unit: uncore_sbox \000event=0x12,umask=0x10\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063155 }, /* unc_s_rxr_bypass.bl_bnc\000uncore_sbox\000uncore interconnect\000Bypass; BL - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x8\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063300 }, /* unc_s_rxr_bypass.bl_crd\000uncore_sbox\000uncore interconnect\000Bypass; BL - Credits. Unit: uncore_sbox \000event=0x12,umask=0x4\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063445 }, /* unc_s_rxr_bypass.iv\000uncore_sbox\000uncore interconnect\000Bypass; IV. Unit: uncore_sbox \000event=0x12,umask=0x20\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063577 }, /* unc_s_rxr_crd_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6063942 }, /* unc_s_rxr_crd_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x14,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6064307 }, /* unc_s_rxr_crd_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; AK. Unit: uncore_sbox \000event=0x14,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6064659 }, /* unc_s_rxr_crd_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065024 }, /* unc_s_rxr_crd_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x14,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065389 }, /* unc_s_rxr_crd_starved.ifv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IVF Credit. Unit: uncore_sbox \000event=0x14,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065750 }, /* unc_s_rxr_crd_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IV. Unit: uncore_sbox \000event=0x14,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6066102 }, /* unc_s_rxr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x2\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066346 }, /* unc_s_rxr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x13,umask=0x1\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066590 }, /* unc_s_rxr_inserts.ak\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AK. Unit: uncore_sbox \000event=0x13,umask=0x10\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066821 }, /* unc_s_rxr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x8\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067065 }, /* unc_s_rxr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x13,umask=0x4\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067309 }, /* unc_s_rxr_inserts.iv\000uncore_sbox\000uncore interconnect\000Ingress Allocations; IV. Unit: uncore_sbox \000event=0x13,umask=0x20\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067540 }, /* unc_s_rxr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6067793 }, /* unc_s_rxr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x11,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068046 }, /* unc_s_rxr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AK. Unit: uncore_sbox \000event=0x11,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068286 }, /* unc_s_rxr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068539 }, /* unc_s_rxr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x11,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068792 }, /* unc_s_rxr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; IV. Unit: uncore_sbox \000event=0x11,umask=0x20\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6069032 }, /* unc_s_txr_ads_used.ad\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AD. Unit: uncore_sbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 6069153 }, /* unc_s_txr_ads_used.ak\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AK. Unit: uncore_sbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 6069274 }, /* unc_s_txr_ads_used.bl\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.BL. Unit: uncore_sbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 6069395 }, /* unc_s_txr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6069635 }, /* unc_s_txr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6069875 }, /* unc_s_txr_inserts.ak\000uncore_sbox\000uncore interconnect\000Egress Allocations; AK. Unit: uncore_sbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070102 }, /* unc_s_txr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070342 }, /* unc_s_txr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070582 }, /* unc_s_txr_inserts.iv\000uncore_sbox\000uncore interconnect\000Egress Allocations; IV. Unit: uncore_sbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070809 }, /* unc_s_txr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071057 }, /* unc_s_txr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x1,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071305 }, /* unc_s_txr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AK. Unit: uncore_sbox \000event=0x1,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071540 }, /* unc_s_txr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071788 }, /* unc_s_txr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x1,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6072036 }, /* unc_s_txr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Egress Occupancy; IV. Unit: uncore_sbox \000event=0x1,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6072271 }, /* unc_s_txr_starved.ad\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AD Ring. Unit: uncore_sbox \000event=0x3,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6072544 }, /* unc_s_txr_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AK Ring. Unit: uncore_sbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6072817 }, /* unc_s_txr_starved.bl\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto BL Ring. Unit: uncore_sbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6073090 }, /* unc_s_txr_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto IV Ring. Unit: uncore_sbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6073363 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000 */
{ 6074014 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076954 }, /* unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077187 }, /* unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077419 }, /* unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077656 }, /* unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6081974 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6082839 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000 */
{ 6083291 }, /* unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6083494 }, /* unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6083890 }, /* unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084282 }, /* unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084686 }, /* unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6085090 }, /* unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores; PREQ, PSMI, P2U, Thermal, PCUSMI, PMI\000 */
{ 6085499 }, /* unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085682 }, /* unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 5850201 }, /* unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5850571 }, /* unc_r2_iio_credit.isoch_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x4\000\00001\000\000 */
{ 5850701 }, /* unc_r2_iio_credit.isoch_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x8\000\00001\000\000 */
{ 5850831 }, /* unc_r2_iio_credit.prq_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 5850957 }, /* unc_r2_iio_credit.prq_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 5851083 }, /* unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5852294 }, /* unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5853507 }, /* unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5856769 }, /* unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5857982 }, /* unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5859197 }, /* unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5860412 }, /* unc_r2_ring_ad_used.all\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; All. Unit: uncore_r2pcie \000event=0x7,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5860751 }, /* unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5861456 }, /* unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5862246 }, /* unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5865200 }, /* unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5865544 }, /* unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5866311 }, /* unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5868837 }, /* unc_r2_ring_ak_bounces.dn\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Dn. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869035 }, /* unc_r2_ring_ak_bounces.up\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Up. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869233 }, /* unc_r2_ring_ak_used.all\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; All. Unit: uncore_r2pcie \000event=0x8,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5869572 }, /* unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5870277 }, /* unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5871067 }, /* unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5874021 }, /* unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5874365 }, /* unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5875132 }, /* unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5877658 }, /* unc_r2_ring_bl_used.all\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; All. Unit: uncore_r2pcie \000event=0x9,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5877997 }, /* unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5878702 }, /* unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5879492 }, /* unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5882446 }, /* unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5882790 }, /* unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5883557 }, /* unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5886083 }, /* unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5887540 }, /* unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5889079 }, /* unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5890495 }, /* unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5891469 }, /* unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5892443 }, /* unc_r2_rxr_inserts.ncb\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCB. Unit: uncore_r2pcie \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5892923 }, /* unc_r2_rxr_inserts.ncs\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCS. Unit: uncore_r2pcie \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5893403 }, /* unc_r2_rxr_occupancy.drs\000uncore_r2pcie\000uncore io\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r2pcie \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given R2PCIe Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the R2PCIe Ingress Not Empty event to calculate average occupancy or the R2PCIe Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5893855 }, /* unc_r2_sbo0_credit_occupancy.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894052 }, /* unc_r2_sbo0_credit_occupancy.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894249 }, /* unc_r2_sbo0_credits_acquired.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894447 }, /* unc_r2_sbo0_credits_acquired.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894645 }, /* unc_r2_stall_no_sbo_credit.sbo0_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5894895 }, /* unc_r2_stall_no_sbo_credit.sbo0_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895145 }, /* unc_r2_stall_no_sbo_credit.sbo1_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895395 }, /* unc_r2_stall_no_sbo_credit.sbo1_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895645 }, /* unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AD Egress Queue\000 */
{ 5896035 }, /* unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AK Egress Queue\000 */
{ 5896425 }, /* unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; BL Egress Queue\000 */
{ 5896815 }, /* unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AD Egress Queue\000 */
{ 5897859 }, /* unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AK Egress Queue\000 */
{ 5898903 }, /* unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; BL Egress Queue\000 */
{ 5900823 }, /* unc_r2_txr_nack_cw.dn_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5900976 }, /* unc_r2_txr_nack_cw.dn_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5901129 }, /* unc_r2_txr_nack_cw.dn_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901282 }, /* unc_r2_txr_nack_cw.up_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901435 }, /* unc_r2_txr_nack_cw.up_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000 */
{ 5901581 }, /* unc_r2_txr_nack_cw.up_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 1210502 }, /* llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 1211826 }, /* llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5376386 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377260 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5380151 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5382226 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 5385713 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5386574 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5386724 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the number of underfill reads that are issued by the memory controller.  This will generally be about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ.  While it is possible for underfills to be issed in both WMM and RMM, this event counts both\000 */
{ 5388684 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5389726 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5391708 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392506 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5394404 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using a dedicated 48-bit Fixed Counter. Unit: uncore_imc \000event=0xff\000\00001\000\000 */
{ 5395734 }, /* unc_m_clockticks_p\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using one of the programmable counters. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5396073 }, /* unc_m_dclockticks\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_CLOCKTICKS_P. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417303 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430087 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5430855 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5439445 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of page misses.  This does not include explicit precharge commands sent with CAS commands in Auto-Precharge mode.  This does not include PRE commands sent as a result of the page close counter expiration\000 */
{ 5442207 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5444600 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449351 }, /* unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5449781 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5451793 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5450047 }, /* unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5450338 }, /* unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5450629 }, /* unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5450920 }, /* unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5451211 }, /* unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5451502 }, /* unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5452206 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5452619 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5453160 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5453574 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5453988 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5454274 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5454688 }, /* unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5454974 }, /* unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5455260 }, /* unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5455604 }, /* unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5455948 }, /* unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5456295 }, /* unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5456645 }, /* unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5457075 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5459087 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5457341 }, /* unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5457632 }, /* unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5457923 }, /* unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5458214 }, /* unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5458505 }, /* unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5458796 }, /* unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5459500 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5459913 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5460454 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5460868 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5461282 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5461568 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5461982 }, /* unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5462268 }, /* unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5462554 }, /* unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5462898 }, /* unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5463242 }, /* unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5463589 }, /* unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5464200 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5471646 }, /* unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5472076 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5474088 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5472342 }, /* unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5472633 }, /* unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5472924 }, /* unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5473215 }, /* unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5473506 }, /* unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5473797 }, /* unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5474501 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5474914 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5475455 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5475869 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5476283 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5476569 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5476983 }, /* unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5477269 }, /* unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5477555 }, /* unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5477899 }, /* unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5478243 }, /* unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5478590 }, /* unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5478940 }, /* unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5479370 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5481382 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5479636 }, /* unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5479927 }, /* unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5480218 }, /* unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5480509 }, /* unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5480800 }, /* unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5481091 }, /* unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5481795 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5482208 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5482749 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5483163 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5483577 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5483863 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5484277 }, /* unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5484563 }, /* unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5484849 }, /* unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5485193 }, /* unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5485537 }, /* unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5485884 }, /* unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5486234 }, /* unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5486664 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5488676 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5486930 }, /* unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5487221 }, /* unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5487512 }, /* unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5487803 }, /* unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5488094 }, /* unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5488385 }, /* unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5489089 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5489502 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5490043 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5490457 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5490871 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5491157 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5491571 }, /* unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5491857 }, /* unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5492143 }, /* unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5492487 }, /* unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5492831 }, /* unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5493178 }, /* unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5493528 }, /* unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5493958 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5495970 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5494224 }, /* unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5494515 }, /* unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5494806 }, /* unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5495097 }, /* unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5495388 }, /* unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5495679 }, /* unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5496383 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5496796 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5497337 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5497751 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5498165 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5498451 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5498865 }, /* unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5499151 }, /* unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5499437 }, /* unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5499781 }, /* unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5500125 }, /* unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5500472 }, /* unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5508571 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5534086 }, /* unc_m_vmse_mxb_wr_occupancy\000uncore_imc\000uncore memory\000VMSE MXB write buffer occupancy. Unit: uncore_imc \000event=0x91\000\00001\000\000 */
{ 5534206 }, /* unc_m_vmse_wr_push.rmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in RMM. Unit: uncore_imc \000event=0x90,umask=0x2\000\00001\000\000 */
{ 5534350 }, /* unc_m_vmse_wr_push.wmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in WMM. Unit: uncore_imc \000event=0x90,umask=0x1\000\00001\000\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5534994 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5540700 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556495 }, /* unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5556925 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5558937 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5557191 }, /* unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5557482 }, /* unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5557773 }, /* unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5558064 }, /* unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5558355 }, /* unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5558646 }, /* unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5559350 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5559763 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5560304 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5560718 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5561132 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5561418 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5561832 }, /* unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5562118 }, /* unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5562404 }, /* unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5562748 }, /* unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5563092 }, /* unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5563439 }, /* unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5563789 }, /* unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5564219 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5566231 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5564485 }, /* unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5564776 }, /* unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5565067 }, /* unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5565358 }, /* unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5565649 }, /* unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5565940 }, /* unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5566644 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5567057 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5567598 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5568012 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5568426 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5568712 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5569126 }, /* unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5569412 }, /* unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5569698 }, /* unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5570042 }, /* unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5570386 }, /* unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5570733 }, /* unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5578641 }, /* unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5579071 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5581083 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5579337 }, /* unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5579628 }, /* unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5579919 }, /* unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5580210 }, /* unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5580501 }, /* unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5580792 }, /* unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5581496 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5581909 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5582450 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5582864 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5583278 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5583564 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5583978 }, /* unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5584264 }, /* unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5584550 }, /* unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5584894 }, /* unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5585238 }, /* unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5585585 }, /* unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5585935 }, /* unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5586365 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5588377 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5586631 }, /* unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5586922 }, /* unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5587213 }, /* unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5587504 }, /* unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5587795 }, /* unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5588086 }, /* unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5588790 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5589203 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5589744 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5590158 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5590572 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5590858 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5591272 }, /* unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5591558 }, /* unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5591844 }, /* unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5592188 }, /* unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5592532 }, /* unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5592879 }, /* unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5593229 }, /* unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5593659 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5595671 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5593925 }, /* unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5594216 }, /* unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5594507 }, /* unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5594798 }, /* unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5595089 }, /* unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5595380 }, /* unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5596084 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5596497 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5597038 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5597452 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5597866 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5598152 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5598566 }, /* unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5598852 }, /* unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5599138 }, /* unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5599482 }, /* unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5599826 }, /* unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5600173 }, /* unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5600523 }, /* unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5600953 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5602965 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5601219 }, /* unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5601510 }, /* unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5601801 }, /* unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5602092 }, /* unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5602383 }, /* unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5602674 }, /* unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5603378 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5603791 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5604332 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5604746 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5605160 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5605446 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5605860 }, /* unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5606146 }, /* unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5606432 }, /* unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5606776 }, /* unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5607120 }, /* unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5607467 }, /* unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5641706 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5642773 }, /* unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x60\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643193 }, /* unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643614 }, /* unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644035 }, /* unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644456 }, /* unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644877 }, /* unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645086 }, /* unc_p_core15_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6f\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645295 }, /* unc_p_core16_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645504 }, /* unc_p_core17_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646130 }, /* unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646755 }, /* unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647173 }, /* unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647798 }, /* unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x64\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648423 }, /* unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x65\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649048 }, /* unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x66\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649673 }, /* unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x67\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650298 }, /* unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x68\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650716 }, /* unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x69\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5656797 }, /* unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x30\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659691 }, /* unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x31\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657159 }, /* unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3a\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657522 }, /* unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3b\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657885 }, /* unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3c\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658248 }, /* unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3d\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658611 }, /* unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658791 }, /* unc_p_demotions_core15\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658971 }, /* unc_p_demotions_core16\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659151 }, /* unc_p_demotions_core17\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660230 }, /* unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x32\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660769 }, /* unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x33\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661308 }, /* unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x34\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661847 }, /* unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x35\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662386 }, /* unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x36\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662925 }, /* unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x37\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663285 }, /* unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x38\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663645 }, /* unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x39\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668753 }, /* unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670355 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673025 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5675706 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676395 }, /* unc_p_pkg_residency_c1e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C1E. Unit: uncore_pcu \000event=0x4e\000\00001\000Counts the number of cycles when the package was in C1E.  This event can be used in conjunction with edge detect to count C1E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676727 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677425 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678114 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678803 }, /* unc_p_pkg_residency_c7_cycles\000uncore_pcu\000uncore power\000Package C7 State Residency. Unit: uncore_pcu \000event=0x2e\000\00001\000Counts the number of cycles when the package was in C7.  This event can be used in conjunction with edge detect to count C7 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685850 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5686659 }, /* unc_p_ufs_transitions_ring_gv\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_RING_GV. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 788035 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x8,period=100003,umask=0x1\000\00000\000This event counts load misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 790726 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000\000 */
{ 792298 }, /* dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000\000 */
{ 792704 }, /* dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000\000 */
{ 794649 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size  Spec update: BDM69\000event=0x8,period=100003,umask=0xe\000\00000\000\000 */
{ 797668 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x8\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 800344 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 803676 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)  Spec update: BDM69\000event=0x8,period=2000003,umask=0x2\000\00000\000This event counts load misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 806216 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 810390 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 812771 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000\000 */
{ 814338 }, /* dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000\000 */
{ 814749 }, /* dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000\000 */
{ 816911 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0xe\000\00000\000\000 */
{ 820829 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (1G)  Spec update: BDM69\000event=0x49,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 824198 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)  Spec update: BDM69\000event=0x49,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 827282 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x49,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 828248 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 833208 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000This event counts cycles for an extended page table walk. The Extended Page directory cache differs from standard TLB caches by the operating system that use it. Virtual machine operating systems use the extended page directory cache, while guest operating systems use the standard TLB caches\000 */
{ 1078539 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000This event counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080623 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x1\000\00000\000This event counts store misses in all DTLB levels that cause page walks of any page size (4K/2M/4M/1G)  Spec update: BDM69\000 */
{ 1083626 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000\000 */
{ 1084532 }, /* itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000\000 */
{ 1084832 }, /* itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1087487 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0xe\000\00000\000\000 */
{ 1089713 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)  Spec update: BDM69\000event=0x85,period=100003,umask=0x8\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (1G  page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1090540 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)  Spec update: BDM69\000event=0x85,period=100003,umask=0x4\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (2M and 4M page sizes). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1093387 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)  Spec update: BDM69\000event=0x85,period=100003,umask=0x2\000\00000\000This event counts store misses in all DTLB levels that cause a completed page walk (4K page size). The page walk can end with or without a fault  Spec update: BDM69\000 */
{ 1095831 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks  Spec update: BDM69\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts the number of cycles while PMH is busy with the page walk  Spec update: BDM69\000 */
{ 2468040 }, /* page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x11\000\00000\000\000 */
{ 2468379 }, /* page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x12\000\00000\000\000 */
{ 2468709 }, /* page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x14\000\00000\000\000 */
{ 2469093 }, /* page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x18\000\00000\000\000 */
{ 2470830 }, /* page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x21\000\00000\000\000 */
{ 2471169 }, /* page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x22\000\00000\000\000 */
{ 2471499 }, /* page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: BDM69, BDM98\000event=0xbc,period=2000003,umask=0x24\000\00000\000\000 */
{ 2540692 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000This event counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541489 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000This event counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, and so on)\000 */
};

static const struct compact_pmu_event pmu_metrics__broadwellx[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 14264 }, /* \000dtlb_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14680 }, /* \000dtlb_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 17417 }, /* \000io_bandwidth_read\000\000cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x19e@ * 64 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000 */
{ 18522 }, /* \000io_bandwidth_write\000\000(cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x1c8\\,filter_tid\\=0x3e@ + cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x180\\,filter_tid\\=0x3e@) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19992 }, /* \000itlb_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 20492 }, /* \000itlb_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23335 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25728 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26145 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 27715 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x181@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x191@) / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28587 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 29730 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 31020 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 32657 }, /* \000llc_data_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x192@) / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 36195 }, /* \000loads_per_instr\000\000MEM_UOPS_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 40864 }, /* \000numa_reads_addressed_to_local_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 42080 }, /* \000numa_reads_addressed_to_remote_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43424 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43946 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44453 }, /* \000percent_uops_delivered_from_loop_stream_detector\000\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from loop stream detector(LSD) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44896 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 45620 }, /* \000qpi_data_transmit_bw\000\000UNC_Q_TxL_FLITS_G0.DATA * 8 / 1e6 / duration_time\000\000Intel(R) Quick Path Interconnect (QPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49192 }, /* \000stores_per_instr\000\000MEM_UOPS_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51523 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 78615 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000MACHINE_CLEARS.COUNT * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 87604 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 101792 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 118981 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 133795 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + cpu@DTLB_LOAD_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_LOAD_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 142011 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + cpu@DTLB_STORE_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * DTLB_STORE_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 145955 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(200 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_MISS.REMOTE_HITM + 60 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 155428 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165040 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 176343 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194575 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 197756 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 218790 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 221371 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 224070 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 231407 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239076 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248732 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 253106 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION + 7 * (DTLB_STORE_MISSES.WALK_COMPLETED + DTLB_LOAD_MISSES.WALK_COMPLETED + ITLB_MISSES.WALK_COMPLETED)) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258687 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 260736 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267423 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182\\,thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 270482 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_INSERTS.MISS_OPCODE@filter_opc\\=0x182@) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275234 }, /* \000tma_info_system_socket_clks\000SoC\000cbox_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 282859 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + cpu@ITLB_MISSES.WALK_DURATION\\,cmask\\=1@ + 7 * ITLB_MISSES.WALK_COMPLETED) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 285754 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 289893 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 295561 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_MISS / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 305980 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00041 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 316428 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 320002 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\000200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00001 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 334406 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 344458 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + RESOURCE_STALLS.SB) / (CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 353132 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES * tma_branch_resteers / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY)\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379171 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382050 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 386530 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 389567 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 395006 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(CYCLE_ACTIVITY.STALLS_TOTAL + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 400762 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (CYCLE_ACTIVITY.STALLS_TOTAL - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 405006 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 410836 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418342 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 421613 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 180 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00001 */
{ 429446 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000310 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00001 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 442148 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 460655 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000tma_branch_resteers - tma_mispredicts_resteers - tma_clears_resteers\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 461970 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 465652 }, /* \000uncore_frequency\000\000UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__cascadelakex[] = {
{ 1101122 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105725 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch\000event=0x48,period=2000003,umask=0x2\000\00000\000Number of times a request needed a FB (Fill Buffer) entry but there was no entry available for it. A request includes cacheable/uncacheable demands that are load, store or SW prefetch instructions\000 */
{ 1109275 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch.Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112533 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1133641 }, /* l2_lines_out.non_silent\000\000cache\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000 */
{ 1136410 }, /* l2_lines_out.silent\000\000cache\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared state. A non-threaded event\000event=0xf2,period=200003,umask=0x1\000\00000\000\000 */
{ 1138301 }, /* l2_lines_out.useless_hwpf\000\000cache\000Counts the number of lines that have been hardware prefetched but not used and now evicted by L2 cache\000event=0xf2,period=200003,umask=0x4\000\00000\000\000 */
{ 1138806 }, /* l2_lines_out.useless_pref\000\000cache\000This event is deprecated. Refer to new event L2_LINES_OUT.USELESS_HWPF\000event=0xf2,period=200003,umask=0x4\000\00010\000\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159743 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache\000 */
{ 1160496 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache\000 */
{ 1161655 }, /* l2_rqsts.all_pf\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1169217 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that miss L2 cache\000 */
{ 1170900 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000event=0x24,period=200003,umask=0xd8\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000 */
{ 1171454 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000event=0x24,period=200003,umask=0x38\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000 */
{ 1172527 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000All L2 requests\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1246868 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2. It does not include all misses to the L3  Spec update: SKL057\000 */
{ 1250569 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the  L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2.  It does not include all accesses to the L3  Spec update: SKL057\000 */
{ 1310641 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311557 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312305 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315660 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1321255 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1322617 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1323860 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1326191 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327262 }, /* mem_load_l3_miss_retired.local_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1328144 }, /* mem_load_l3_miss_retired.remote_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from remote dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x2\000\00000\000\000 */
{ 1328694 }, /* mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise\000 */
{ 1329165 }, /* mem_load_l3_miss_retired.remote_hitm\000\000cache\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000 */
{ 1329464 }, /* mem_load_l3_miss_retired.remote_pmm\000\000cache\000Retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000Counts retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000 */
{ 1331393 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000\000 */
{ 1332781 }, /* mem_load_retired.fb_hit\000\000cache\000Retired load instructions which data sources were load missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1334379 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335208 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336281 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337713 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338721 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339355 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1341019 }, /* mem_load_retired.local_pmm\000\000cache\000Retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x80\000\00000\000Counts retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000 */
{ 1443181 }, /* ocr.all_data_rd.l3_hit.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00000\000\000 */
{ 1443385 }, /* ocr.all_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00000\000\000 */
{ 1443624 }, /* ocr.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00000\000\000 */
{ 1443875 }, /* ocr.all_data_rd.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00000\000\000 */
{ 1444103 }, /* ocr.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00000\000\000 */
{ 1444330 }, /* ocr.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0491\000\00000\000\000 */
{ 1444485 }, /* ocr.all_data_rd.l3_hit.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0491\000\00000\000\000 */
{ 1444658 }, /* ocr.all_data_rd.l3_hit.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0491\000\00000\000\000 */
{ 1444830 }, /* ocr.all_data_rd.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080491\000\00000\000\000 */
{ 1445008 }, /* ocr.all_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080491\000\00000\000\000 */
{ 1445212 }, /* ocr.all_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080491\000\00000\000\000 */
{ 1445425 }, /* ocr.all_data_rd.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080491\000\00000\000\000 */
{ 1445621 }, /* ocr.all_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080491\000\00000\000\000 */
{ 1445816 }, /* ocr.all_data_rd.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080491\000\00000\000\000 */
{ 1445959 }, /* ocr.all_data_rd.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080491\000\00000\000\000 */
{ 1446101 }, /* ocr.all_data_rd.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200491\000\00000\000\000 */
{ 1446279 }, /* ocr.all_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200491\000\00000\000\000 */
{ 1446483 }, /* ocr.all_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200491\000\00000\000\000 */
{ 1446696 }, /* ocr.all_data_rd.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200491\000\00000\000\000 */
{ 1446892 }, /* ocr.all_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200491\000\00000\000\000 */
{ 1447087 }, /* ocr.all_data_rd.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200491\000\00000\000\000 */
{ 1447230 }, /* ocr.all_data_rd.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200491\000\00000\000\000 */
{ 1447372 }, /* ocr.all_data_rd.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040491\000\00000\000\000 */
{ 1447550 }, /* ocr.all_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040491\000\00000\000\000 */
{ 1447754 }, /* ocr.all_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040491\000\00000\000\000 */
{ 1447967 }, /* ocr.all_data_rd.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040491\000\00000\000\000 */
{ 1448163 }, /* ocr.all_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040491\000\00000\000\000 */
{ 1448358 }, /* ocr.all_data_rd.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040491\000\00000\000\000 */
{ 1448501 }, /* ocr.all_data_rd.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040491\000\00000\000\000 */
{ 1448643 }, /* ocr.all_data_rd.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP  OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100491\000\00000\000\000 */
{ 1448821 }, /* ocr.all_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100491\000\00000\000\000 */
{ 1449025 }, /* ocr.all_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100491\000\00000\000\000 */
{ 1449238 }, /* ocr.all_data_rd.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100491\000\00000\000\000 */
{ 1449434 }, /* ocr.all_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100491\000\00000\000\000 */
{ 1449629 }, /* ocr.all_data_rd.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100491\000\00000\000\000 */
{ 1449772 }, /* ocr.all_data_rd.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100491\000\00000\000\000 */
{ 1457509 }, /* ocr.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00000\000\000 */
{ 1457725 }, /* ocr.all_pf_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00000\000\000 */
{ 1457976 }, /* ocr.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00000\000\000 */
{ 1458239 }, /* ocr.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00000\000\000 */
{ 1458479 }, /* ocr.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00000\000\000 */
{ 1458718 }, /* ocr.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0490\000\00000\000\000 */
{ 1458879 }, /* ocr.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0490\000\00000\000\000 */
{ 1459061 }, /* ocr.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0490\000\00000\000\000 */
{ 1459242 }, /* ocr.all_pf_data_rd.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080490\000\00000\000\000 */
{ 1459429 }, /* ocr.all_pf_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080490\000\00000\000\000 */
{ 1459642 }, /* ocr.all_pf_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080490\000\00000\000\000 */
{ 1459864 }, /* ocr.all_pf_data_rd.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080490\000\00000\000\000 */
{ 1460069 }, /* ocr.all_pf_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080490\000\00000\000\000 */
{ 1460273 }, /* ocr.all_pf_data_rd.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080490\000\00000\000\000 */
{ 1460422 }, /* ocr.all_pf_data_rd.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080490\000\00000\000\000 */
{ 1460570 }, /* ocr.all_pf_data_rd.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200490\000\00000\000\000 */
{ 1460757 }, /* ocr.all_pf_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200490\000\00000\000\000 */
{ 1460970 }, /* ocr.all_pf_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200490\000\00000\000\000 */
{ 1461192 }, /* ocr.all_pf_data_rd.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200490\000\00000\000\000 */
{ 1461397 }, /* ocr.all_pf_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200490\000\00000\000\000 */
{ 1461601 }, /* ocr.all_pf_data_rd.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200490\000\00000\000\000 */
{ 1461750 }, /* ocr.all_pf_data_rd.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200490\000\00000\000\000 */
{ 1461898 }, /* ocr.all_pf_data_rd.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040490\000\00000\000\000 */
{ 1462085 }, /* ocr.all_pf_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040490\000\00000\000\000 */
{ 1462298 }, /* ocr.all_pf_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040490\000\00000\000\000 */
{ 1462520 }, /* ocr.all_pf_data_rd.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040490\000\00000\000\000 */
{ 1462725 }, /* ocr.all_pf_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040490\000\00000\000\000 */
{ 1462929 }, /* ocr.all_pf_data_rd.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040490\000\00000\000\000 */
{ 1463078 }, /* ocr.all_pf_data_rd.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040490\000\00000\000\000 */
{ 1463226 }, /* ocr.all_pf_data_rd.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100490\000\00000\000\000 */
{ 1463413 }, /* ocr.all_pf_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100490\000\00000\000\000 */
{ 1463626 }, /* ocr.all_pf_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100490\000\00000\000\000 */
{ 1463848 }, /* ocr.all_pf_data_rd.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100490\000\00000\000\000 */
{ 1464053 }, /* ocr.all_pf_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100490\000\00000\000\000 */
{ 1464257 }, /* ocr.all_pf_data_rd.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100490\000\00000\000\000 */
{ 1464406 }, /* ocr.all_pf_data_rd.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100490\000\00000\000\000 */
{ 1472453 }, /* ocr.all_pf_rfo.l3_hit.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000 */
{ 1472653 }, /* ocr.all_pf_rfo.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00000\000\000 */
{ 1472888 }, /* ocr.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000 */
{ 1473135 }, /* ocr.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000 */
{ 1473359 }, /* ocr.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000 */
{ 1473582 }, /* ocr.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0120\000\00000\000\000 */
{ 1473735 }, /* ocr.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00000\000\000 */
{ 1473905 }, /* ocr.all_pf_rfo.l3_hit.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00000\000\000 */
{ 1474074 }, /* ocr.all_pf_rfo.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080120\000\00000\000\000 */
{ 1474249 }, /* ocr.all_pf_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080120\000\00000\000\000 */
{ 1474450 }, /* ocr.all_pf_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080120\000\00000\000\000 */
{ 1474660 }, /* ocr.all_pf_rfo.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080120\000\00000\000\000 */
{ 1474853 }, /* ocr.all_pf_rfo.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080120\000\00000\000\000 */
{ 1475045 }, /* ocr.all_pf_rfo.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080120\000\00000\000\000 */
{ 1475186 }, /* ocr.all_pf_rfo.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080120\000\00000\000\000 */
{ 1475326 }, /* ocr.all_pf_rfo.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200120\000\00000\000\000 */
{ 1475501 }, /* ocr.all_pf_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200120\000\00000\000\000 */
{ 1475702 }, /* ocr.all_pf_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200120\000\00000\000\000 */
{ 1475912 }, /* ocr.all_pf_rfo.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200120\000\00000\000\000 */
{ 1476105 }, /* ocr.all_pf_rfo.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200120\000\00000\000\000 */
{ 1476297 }, /* ocr.all_pf_rfo.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200120\000\00000\000\000 */
{ 1476438 }, /* ocr.all_pf_rfo.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200120\000\00000\000\000 */
{ 1476578 }, /* ocr.all_pf_rfo.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040120\000\00000\000\000 */
{ 1476753 }, /* ocr.all_pf_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040120\000\00000\000\000 */
{ 1476954 }, /* ocr.all_pf_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040120\000\00000\000\000 */
{ 1477164 }, /* ocr.all_pf_rfo.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040120\000\00000\000\000 */
{ 1477357 }, /* ocr.all_pf_rfo.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040120\000\00000\000\000 */
{ 1477549 }, /* ocr.all_pf_rfo.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040120\000\00000\000\000 */
{ 1477690 }, /* ocr.all_pf_rfo.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040120\000\00000\000\000 */
{ 1477830 }, /* ocr.all_pf_rfo.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP  OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100120\000\00000\000\000 */
{ 1478005 }, /* ocr.all_pf_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100120\000\00000\000\000 */
{ 1478206 }, /* ocr.all_pf_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100120\000\00000\000\000 */
{ 1478416 }, /* ocr.all_pf_rfo.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100120\000\00000\000\000 */
{ 1478609 }, /* ocr.all_pf_rfo.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100120\000\00000\000\000 */
{ 1478801 }, /* ocr.all_pf_rfo.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100120\000\00000\000\000 */
{ 1478942 }, /* ocr.all_pf_rfo.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100120\000\00000\000\000 */
{ 1486563 }, /* ocr.all_reads.l3_hit.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT.ANY_SNOOP OCR.ALL_READS.L3_HIT.ANY_SNOOP OCR.ALL_READS.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C07F7\000\00000\000\000 */
{ 1486759 }, /* ocr.all_reads.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C07F7\000\00000\000\000 */
{ 1486990 }, /* ocr.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000 */
{ 1487233 }, /* ocr.all_reads.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000 */
{ 1487453 }, /* ocr.all_reads.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C07F7\000\00000\000\000 */
{ 1487672 }, /* ocr.all_reads.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C07F7\000\00000\000\000 */
{ 1487823 }, /* ocr.all_reads.l3_hit.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_MISS OCR.ALL_READS.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C07F7\000\00000\000\000 */
{ 1487990 }, /* ocr.all_reads.l3_hit.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT.SNOOP_NONE OCR.ALL_READS.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C07F7\000\00000\000\000 */
{ 1488156 }, /* ocr.all_reads.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_E.ANY_SNOOP  OCR.ALL_READS.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800807F7\000\00000\000\000 */
{ 1488328 }, /* ocr.all_reads.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000807F7\000\00000\000\000 */
{ 1488526 }, /* ocr.all_reads.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000807F7\000\00000\000\000 */
{ 1488733 }, /* ocr.all_reads.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000807F7\000\00000\000\000 */
{ 1488923 }, /* ocr.all_reads.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000807F7\000\00000\000\000 */
{ 1489112 }, /* ocr.all_reads.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000807F7\000\00000\000\000 */
{ 1489251 }, /* ocr.all_reads.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800807F7\000\00000\000\000 */
{ 1489389 }, /* ocr.all_reads.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_F.ANY_SNOOP  OCR.ALL_READS.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F802007F7\000\00000\000\000 */
{ 1489561 }, /* ocr.all_reads.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8002007F7\000\00000\000\000 */
{ 1489759 }, /* ocr.all_reads.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4002007F7\000\00000\000\000 */
{ 1489966 }, /* ocr.all_reads.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002007F7\000\00000\000\000 */
{ 1490156 }, /* ocr.all_reads.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002007F7\000\00000\000\000 */
{ 1490345 }, /* ocr.all_reads.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002007F7\000\00000\000\000 */
{ 1490484 }, /* ocr.all_reads.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802007F7\000\00000\000\000 */
{ 1490622 }, /* ocr.all_reads.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_M.ANY_SNOOP  OCR.ALL_READS.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800407F7\000\00000\000\000 */
{ 1490794 }, /* ocr.all_reads.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000407F7\000\00000\000\000 */
{ 1490992 }, /* ocr.all_reads.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000407F7\000\00000\000\000 */
{ 1491199 }, /* ocr.all_reads.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000407F7\000\00000\000\000 */
{ 1491389 }, /* ocr.all_reads.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000407F7\000\00000\000\000 */
{ 1491578 }, /* ocr.all_reads.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000407F7\000\00000\000\000 */
{ 1491717 }, /* ocr.all_reads.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800407F7\000\00000\000\000 */
{ 1491855 }, /* ocr.all_reads.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_READS.L3_HIT_S.ANY_SNOOP  OCR.ALL_READS.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F801007F7\000\00000\000\000 */
{ 1492027 }, /* ocr.all_reads.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8001007F7\000\00000\000\000 */
{ 1492225 }, /* ocr.all_reads.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001007F7\000\00000\000\000 */
{ 1492432 }, /* ocr.all_reads.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001007F7\000\00000\000\000 */
{ 1492622 }, /* ocr.all_reads.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001007F7\000\00000\000\000 */
{ 1492811 }, /* ocr.all_reads.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_READS.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001007F7\000\00000\000\000 */
{ 1492950 }, /* ocr.all_reads.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_READS.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801007F7\000\00000\000\000 */
{ 1500461 }, /* ocr.all_rfo.l3_hit.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT.ANY_SNOOP OCR.ALL_RFO.L3_HIT.ANY_SNOOP OCR.ALL_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000 */
{ 1500649 }, /* ocr.all_rfo.l3_hit.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00000\000\000 */
{ 1500872 }, /* ocr.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1501107 }, /* ocr.all_rfo.l3_hit.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 1501319 }, /* ocr.all_rfo.l3_hit.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000 */
{ 1501530 }, /* ocr.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0122\000\00000\000\000 */
{ 1501677 }, /* ocr.all_rfo.l3_hit.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_MISS OCR.ALL_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00000\000\000 */
{ 1501838 }, /* ocr.all_rfo.l3_hit.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT.SNOOP_NONE OCR.ALL_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00000\000\000 */
{ 1501998 }, /* ocr.all_rfo.l3_hit_e.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080122\000\00000\000\000 */
{ 1502164 }, /* ocr.all_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080122\000\00000\000\000 */
{ 1502356 }, /* ocr.all_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080122\000\00000\000\000 */
{ 1502557 }, /* ocr.all_rfo.l3_hit_e.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080122\000\00000\000\000 */
{ 1502741 }, /* ocr.all_rfo.l3_hit_e.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080122\000\00000\000\000 */
{ 1502924 }, /* ocr.all_rfo.l3_hit_e.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080122\000\00000\000\000 */
{ 1503059 }, /* ocr.all_rfo.l3_hit_e.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080122\000\00000\000\000 */
{ 1503193 }, /* ocr.all_rfo.l3_hit_f.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200122\000\00000\000\000 */
{ 1503359 }, /* ocr.all_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200122\000\00000\000\000 */
{ 1503551 }, /* ocr.all_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200122\000\00000\000\000 */
{ 1503752 }, /* ocr.all_rfo.l3_hit_f.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200122\000\00000\000\000 */
{ 1503936 }, /* ocr.all_rfo.l3_hit_f.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200122\000\00000\000\000 */
{ 1504119 }, /* ocr.all_rfo.l3_hit_f.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200122\000\00000\000\000 */
{ 1504254 }, /* ocr.all_rfo.l3_hit_f.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200122\000\00000\000\000 */
{ 1504388 }, /* ocr.all_rfo.l3_hit_m.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040122\000\00000\000\000 */
{ 1504554 }, /* ocr.all_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040122\000\00000\000\000 */
{ 1504746 }, /* ocr.all_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040122\000\00000\000\000 */
{ 1504947 }, /* ocr.all_rfo.l3_hit_m.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040122\000\00000\000\000 */
{ 1505131 }, /* ocr.all_rfo.l3_hit_m.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040122\000\00000\000\000 */
{ 1505314 }, /* ocr.all_rfo.l3_hit_m.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040122\000\00000\000\000 */
{ 1505449 }, /* ocr.all_rfo.l3_hit_m.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040122\000\00000\000\000 */
{ 1505583 }, /* ocr.all_rfo.l3_hit_s.any_snoop\000\000cache\000OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP  OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100122\000\00000\000\000 */
{ 1505749 }, /* ocr.all_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100122\000\00000\000\000 */
{ 1505941 }, /* ocr.all_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100122\000\00000\000\000 */
{ 1506142 }, /* ocr.all_rfo.l3_hit_s.hitm_other_core\000\000cache\000OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE  OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100122\000\00000\000\000 */
{ 1506326 }, /* ocr.all_rfo.l3_hit_s.no_snoop_needed\000\000cache\000OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100122\000\00000\000\000 */
{ 1506509 }, /* ocr.all_rfo.l3_hit_s.snoop_miss\000\000cache\000OCR.ALL_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100122\000\00000\000\000 */
{ 1506644 }, /* ocr.all_rfo.l3_hit_s.snoop_none\000\000cache\000OCR.ALL_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100122\000\00000\000\000 */
{ 1516771 }, /* ocr.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000 */
{ 1516980 }, /* ocr.demand_code_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000 */
{ 1517215 }, /* ocr.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 1517459 }, /* ocr.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1517686 }, /* ocr.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 1518478 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0004\000\00000\000\000 */
{ 1520057 }, /* ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 1520752 }, /* ocr.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00000\000\000 */
{ 1522394 }, /* ocr.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080004\000\00000\000\000 */
{ 1522572 }, /* ocr.demand_code_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080004\000\00000\000\000 */
{ 1522767 }, /* ocr.demand_code_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00000\000\000 */
{ 1522968 }, /* ocr.demand_code_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000 */
{ 1523158 }, /* ocr.demand_code_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00000\000\000 */
{ 1523347 }, /* ocr.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00000\000\000 */
{ 1523486 }, /* ocr.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00000\000\000 */
{ 1523624 }, /* ocr.demand_code_rd.l3_hit_f.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200004\000\00000\000\000 */
{ 1523802 }, /* ocr.demand_code_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200004\000\00000\000\000 */
{ 1523997 }, /* ocr.demand_code_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200004\000\00000\000\000 */
{ 1524198 }, /* ocr.demand_code_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200004\000\00000\000\000 */
{ 1524388 }, /* ocr.demand_code_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200004\000\00000\000\000 */
{ 1524577 }, /* ocr.demand_code_rd.l3_hit_f.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200004\000\00000\000\000 */
{ 1524716 }, /* ocr.demand_code_rd.l3_hit_f.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200004\000\00000\000\000 */
{ 1524854 }, /* ocr.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040004\000\00000\000\000 */
{ 1525032 }, /* ocr.demand_code_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040004\000\00000\000\000 */
{ 1525227 }, /* ocr.demand_code_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00000\000\000 */
{ 1525428 }, /* ocr.demand_code_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00000\000\000 */
{ 1525618 }, /* ocr.demand_code_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00000\000\000 */
{ 1525807 }, /* ocr.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00000\000\000 */
{ 1525946 }, /* ocr.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00000\000\000 */
{ 1526084 }, /* ocr.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100004\000\00000\000\000 */
{ 1526262 }, /* ocr.demand_code_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100004\000\00000\000\000 */
{ 1526457 }, /* ocr.demand_code_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00000\000\000 */
{ 1526658 }, /* ocr.demand_code_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00000\000\000 */
{ 1526848 }, /* ocr.demand_code_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00000\000\000 */
{ 1527037 }, /* ocr.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00000\000\000 */
{ 1527176 }, /* ocr.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00000\000\000 */
{ 1544282 }, /* ocr.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 1544487 }, /* ocr.demand_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1544718 }, /* ocr.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1544958 }, /* ocr.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1545181 }, /* ocr.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 1547555 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0001\000\00000\000\000 */
{ 1550314 }, /* ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 1550902 }, /* ocr.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00000\000\000 */
{ 1552619 }, /* ocr.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080001\000\00000\000\000 */
{ 1552793 }, /* ocr.demand_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080001\000\00000\000\000 */
{ 1552984 }, /* ocr.demand_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00000\000\000 */
{ 1553181 }, /* ocr.demand_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000 */
{ 1553367 }, /* ocr.demand_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00000\000\000 */
{ 1553552 }, /* ocr.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00000\000\000 */
{ 1553687 }, /* ocr.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00000\000\000 */
{ 1553821 }, /* ocr.demand_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200001\000\00000\000\000 */
{ 1553995 }, /* ocr.demand_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200001\000\00000\000\000 */
{ 1554186 }, /* ocr.demand_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200001\000\00000\000\000 */
{ 1554383 }, /* ocr.demand_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200001\000\00000\000\000 */
{ 1554569 }, /* ocr.demand_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200001\000\00000\000\000 */
{ 1554754 }, /* ocr.demand_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200001\000\00000\000\000 */
{ 1554889 }, /* ocr.demand_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200001\000\00000\000\000 */
{ 1555023 }, /* ocr.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040001\000\00000\000\000 */
{ 1555197 }, /* ocr.demand_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040001\000\00000\000\000 */
{ 1555388 }, /* ocr.demand_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00000\000\000 */
{ 1555585 }, /* ocr.demand_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00000\000\000 */
{ 1555771 }, /* ocr.demand_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00000\000\000 */
{ 1555956 }, /* ocr.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00000\000\000 */
{ 1556091 }, /* ocr.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00000\000\000 */
{ 1556225 }, /* ocr.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100001\000\00000\000\000 */
{ 1556399 }, /* ocr.demand_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100001\000\00000\000\000 */
{ 1556590 }, /* ocr.demand_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00000\000\000 */
{ 1556787 }, /* ocr.demand_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00000\000\000 */
{ 1556973 }, /* ocr.demand_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00000\000\000 */
{ 1557158 }, /* ocr.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00000\000\000 */
{ 1557293 }, /* ocr.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00000\000\000 */
{ 1574696 }, /* ocr.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 1574901 }, /* ocr.demand_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000 */
{ 1575132 }, /* ocr.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 1575372 }, /* ocr.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1575595 }, /* ocr.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 1576444 }, /* ocr.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0002\000\00000\000\000 */
{ 1578864 }, /* ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 1579620 }, /* ocr.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00000\000\000 */
{ 1581937 }, /* ocr.demand_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080002\000\00000\000\000 */
{ 1582115 }, /* ocr.demand_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080002\000\00000\000\000 */
{ 1582310 }, /* ocr.demand_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00000\000\000 */
{ 1582511 }, /* ocr.demand_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000 */
{ 1582701 }, /* ocr.demand_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00000\000\000 */
{ 1582890 }, /* ocr.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00000\000\000 */
{ 1583033 }, /* ocr.demand_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00000\000\000 */
{ 1583175 }, /* ocr.demand_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200002\000\00000\000\000 */
{ 1583353 }, /* ocr.demand_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200002\000\00000\000\000 */
{ 1583548 }, /* ocr.demand_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200002\000\00000\000\000 */
{ 1583749 }, /* ocr.demand_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200002\000\00000\000\000 */
{ 1583939 }, /* ocr.demand_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200002\000\00000\000\000 */
{ 1584128 }, /* ocr.demand_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200002\000\00000\000\000 */
{ 1584271 }, /* ocr.demand_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200002\000\00000\000\000 */
{ 1584413 }, /* ocr.demand_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040002\000\00000\000\000 */
{ 1584591 }, /* ocr.demand_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040002\000\00000\000\000 */
{ 1584786 }, /* ocr.demand_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00000\000\000 */
{ 1584987 }, /* ocr.demand_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000 */
{ 1585177 }, /* ocr.demand_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00000\000\000 */
{ 1585366 }, /* ocr.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00000\000\000 */
{ 1585509 }, /* ocr.demand_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00000\000\000 */
{ 1585651 }, /* ocr.demand_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100002\000\00000\000\000 */
{ 1585829 }, /* ocr.demand_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100002\000\00000\000\000 */
{ 1586024 }, /* ocr.demand_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00000\000\000 */
{ 1586225 }, /* ocr.demand_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00000\000\000 */
{ 1586415 }, /* ocr.demand_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00000\000\000 */
{ 1586604 }, /* ocr.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00000\000\000 */
{ 1586747 }, /* ocr.demand_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00000\000\000 */
{ 1625145 }, /* ocr.other.l3_hit.any_snoop\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.ANY_SNOOP OCR.OTHER.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00000\000\000 */
{ 1625324 }, /* ocr.other.l3_hit.hit_other_core_fwd\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C8000\000\00000\000\000 */
{ 1625529 }, /* ocr.other.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000 */
{ 1625743 }, /* ocr.other.l3_hit.hitm_other_core\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.HITM_OTHER_CORE OCR.OTHER.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00000\000\000 */
{ 1625940 }, /* ocr.other.l3_hit.no_snoop_needed\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000 */
{ 1626408 }, /* ocr.other.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C8000\000\00000\000\000 */
{ 1626541 }, /* ocr.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000 */
{ 1626948 }, /* ocr.other.l3_hit.snoop_none\000\000cache\000Counts any other requests OCR.OTHER.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00000\000\000 */
{ 1627580 }, /* ocr.other.l3_hit_e.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80088000\000\00000\000\000 */
{ 1627737 }, /* ocr.other.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800088000\000\00000\000\000 */
{ 1627911 }, /* ocr.other.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00000\000\000 */
{ 1628091 }, /* ocr.other.l3_hit_e.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000 */
{ 1628260 }, /* ocr.other.l3_hit_e.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00000\000\000 */
{ 1628428 }, /* ocr.other.l3_hit_e.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00000\000\000 */
{ 1628555 }, /* ocr.other.l3_hit_e.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00000\000\000 */
{ 1628681 }, /* ocr.other.l3_hit_f.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80208000\000\00000\000\000 */
{ 1628838 }, /* ocr.other.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800208000\000\00000\000\000 */
{ 1629012 }, /* ocr.other.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400208000\000\00000\000\000 */
{ 1629192 }, /* ocr.other.l3_hit_f.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000208000\000\00000\000\000 */
{ 1629361 }, /* ocr.other.l3_hit_f.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100208000\000\00000\000\000 */
{ 1629529 }, /* ocr.other.l3_hit_f.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200208000\000\00000\000\000 */
{ 1629656 }, /* ocr.other.l3_hit_f.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80208000\000\00000\000\000 */
{ 1629782 }, /* ocr.other.l3_hit_m.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80048000\000\00000\000\000 */
{ 1629939 }, /* ocr.other.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800048000\000\00000\000\000 */
{ 1630113 }, /* ocr.other.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00000\000\000 */
{ 1630293 }, /* ocr.other.l3_hit_m.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00000\000\000 */
{ 1630462 }, /* ocr.other.l3_hit_m.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00000\000\000 */
{ 1630630 }, /* ocr.other.l3_hit_m.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00000\000\000 */
{ 1630757 }, /* ocr.other.l3_hit_m.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00000\000\000 */
{ 1630883 }, /* ocr.other.l3_hit_s.any_snoop\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80108000\000\00000\000\000 */
{ 1631040 }, /* ocr.other.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800108000\000\00000\000\000 */
{ 1631214 }, /* ocr.other.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00000\000\000 */
{ 1631394 }, /* ocr.other.l3_hit_s.hitm_other_core\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00000\000\000 */
{ 1631563 }, /* ocr.other.l3_hit_s.no_snoop_needed\000\000cache\000Counts any other requests  OCR.OTHER.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00000\000\000 */
{ 1631731 }, /* ocr.other.l3_hit_s.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00000\000\000 */
{ 1631858 }, /* ocr.other.l3_hit_s.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00000\000\000 */
{ 1640578 }, /* ocr.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000 */
{ 1640834 }, /* ocr.pf_l1d_and_sw.l3_hit.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00000\000\000 */
{ 1641116 }, /* ocr.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00000\000\000 */
{ 1641407 }, /* ocr.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000 */
{ 1641681 }, /* ocr.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000 */
{ 1641954 }, /* ocr.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0400\000\00000\000\000 */
{ 1642148 }, /* ocr.pf_l1d_and_sw.l3_hit.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00000\000\000 */
{ 1642370 }, /* ocr.pf_l1d_and_sw.l3_hit.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0400\000\00000\000\000 */
{ 1642591 }, /* ocr.pf_l1d_and_sw.l3_hit_e.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080400\000\00000\000\000 */
{ 1642817 }, /* ocr.pf_l1d_and_sw.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080400\000\00000\000\000 */
{ 1643060 }, /* ocr.pf_l1d_and_sw.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080400\000\00000\000\000 */
{ 1643309 }, /* ocr.pf_l1d_and_sw.l3_hit_e.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080400\000\00000\000\000 */
{ 1643547 }, /* ocr.pf_l1d_and_sw.l3_hit_e.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080400\000\00000\000\000 */
{ 1643784 }, /* ocr.pf_l1d_and_sw.l3_hit_e.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080400\000\00000\000\000 */
{ 1643972 }, /* ocr.pf_l1d_and_sw.l3_hit_e.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080400\000\00000\000\000 */
{ 1644159 }, /* ocr.pf_l1d_and_sw.l3_hit_f.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200400\000\00000\000\000 */
{ 1644385 }, /* ocr.pf_l1d_and_sw.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200400\000\00000\000\000 */
{ 1644628 }, /* ocr.pf_l1d_and_sw.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200400\000\00000\000\000 */
{ 1644877 }, /* ocr.pf_l1d_and_sw.l3_hit_f.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200400\000\00000\000\000 */
{ 1645115 }, /* ocr.pf_l1d_and_sw.l3_hit_f.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200400\000\00000\000\000 */
{ 1645352 }, /* ocr.pf_l1d_and_sw.l3_hit_f.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200400\000\00000\000\000 */
{ 1645540 }, /* ocr.pf_l1d_and_sw.l3_hit_f.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200400\000\00000\000\000 */
{ 1645727 }, /* ocr.pf_l1d_and_sw.l3_hit_m.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040400\000\00000\000\000 */
{ 1645953 }, /* ocr.pf_l1d_and_sw.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040400\000\00000\000\000 */
{ 1646196 }, /* ocr.pf_l1d_and_sw.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040400\000\00000\000\000 */
{ 1646445 }, /* ocr.pf_l1d_and_sw.l3_hit_m.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040400\000\00000\000\000 */
{ 1646683 }, /* ocr.pf_l1d_and_sw.l3_hit_m.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040400\000\00000\000\000 */
{ 1646920 }, /* ocr.pf_l1d_and_sw.l3_hit_m.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040400\000\00000\000\000 */
{ 1647108 }, /* ocr.pf_l1d_and_sw.l3_hit_m.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040400\000\00000\000\000 */
{ 1647295 }, /* ocr.pf_l1d_and_sw.l3_hit_s.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100400\000\00000\000\000 */
{ 1647521 }, /* ocr.pf_l1d_and_sw.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100400\000\00000\000\000 */
{ 1647764 }, /* ocr.pf_l1d_and_sw.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100400\000\00000\000\000 */
{ 1648013 }, /* ocr.pf_l1d_and_sw.l3_hit_s.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100400\000\00000\000\000 */
{ 1648251 }, /* ocr.pf_l1d_and_sw.l3_hit_s.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100400\000\00000\000\000 */
{ 1648488 }, /* ocr.pf_l1d_and_sw.l3_hit_s.snoop_miss\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100400\000\00000\000\000 */
{ 1648676 }, /* ocr.pf_l1d_and_sw.l3_hit_s.snoop_none\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100400\000\00000\000\000 */
{ 1657717 }, /* ocr.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000 */
{ 1657945 }, /* ocr.pf_l2_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000 */
{ 1658199 }, /* ocr.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 1658462 }, /* ocr.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 1658708 }, /* ocr.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 1658953 }, /* ocr.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0010\000\00000\000\000 */
{ 1659119 }, /* ocr.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 1659313 }, /* ocr.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00000\000\000 */
{ 1659506 }, /* ocr.pf_l2_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080010\000\00000\000\000 */
{ 1659704 }, /* ocr.pf_l2_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080010\000\00000\000\000 */
{ 1659919 }, /* ocr.pf_l2_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080010\000\00000\000\000 */
{ 1660140 }, /* ocr.pf_l2_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080010\000\00000\000\000 */
{ 1660350 }, /* ocr.pf_l2_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080010\000\00000\000\000 */
{ 1660559 }, /* ocr.pf_l2_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080010\000\00000\000\000 */
{ 1660719 }, /* ocr.pf_l2_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080010\000\00000\000\000 */
{ 1660878 }, /* ocr.pf_l2_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200010\000\00000\000\000 */
{ 1661076 }, /* ocr.pf_l2_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200010\000\00000\000\000 */
{ 1661291 }, /* ocr.pf_l2_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200010\000\00000\000\000 */
{ 1661512 }, /* ocr.pf_l2_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200010\000\00000\000\000 */
{ 1661722 }, /* ocr.pf_l2_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200010\000\00000\000\000 */
{ 1661931 }, /* ocr.pf_l2_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200010\000\00000\000\000 */
{ 1662091 }, /* ocr.pf_l2_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200010\000\00000\000\000 */
{ 1662250 }, /* ocr.pf_l2_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040010\000\00000\000\000 */
{ 1662448 }, /* ocr.pf_l2_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040010\000\00000\000\000 */
{ 1662663 }, /* ocr.pf_l2_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040010\000\00000\000\000 */
{ 1662884 }, /* ocr.pf_l2_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040010\000\00000\000\000 */
{ 1663094 }, /* ocr.pf_l2_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040010\000\00000\000\000 */
{ 1663303 }, /* ocr.pf_l2_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040010\000\00000\000\000 */
{ 1663463 }, /* ocr.pf_l2_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040010\000\00000\000\000 */
{ 1663622 }, /* ocr.pf_l2_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100010\000\00000\000\000 */
{ 1663820 }, /* ocr.pf_l2_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100010\000\00000\000\000 */
{ 1664035 }, /* ocr.pf_l2_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100010\000\00000\000\000 */
{ 1664256 }, /* ocr.pf_l2_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100010\000\00000\000\000 */
{ 1664466 }, /* ocr.pf_l2_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100010\000\00000\000\000 */
{ 1664675 }, /* ocr.pf_l2_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100010\000\00000\000\000 */
{ 1664835 }, /* ocr.pf_l2_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100010\000\00000\000\000 */
{ 1672862 }, /* ocr.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000 */
{ 1673076 }, /* ocr.pf_l2_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000 */
{ 1673316 }, /* ocr.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 1673565 }, /* ocr.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 1673797 }, /* ocr.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 1674028 }, /* ocr.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0020\000\00000\000\000 */
{ 1674188 }, /* ocr.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 1674372 }, /* ocr.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00000\000\000 */
{ 1674555 }, /* ocr.pf_l2_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080020\000\00000\000\000 */
{ 1674743 }, /* ocr.pf_l2_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080020\000\00000\000\000 */
{ 1674948 }, /* ocr.pf_l2_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080020\000\00000\000\000 */
{ 1675159 }, /* ocr.pf_l2_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080020\000\00000\000\000 */
{ 1675359 }, /* ocr.pf_l2_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080020\000\00000\000\000 */
{ 1675558 }, /* ocr.pf_l2_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080020\000\00000\000\000 */
{ 1675712 }, /* ocr.pf_l2_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080020\000\00000\000\000 */
{ 1675865 }, /* ocr.pf_l2_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200020\000\00000\000\000 */
{ 1676053 }, /* ocr.pf_l2_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200020\000\00000\000\000 */
{ 1676258 }, /* ocr.pf_l2_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200020\000\00000\000\000 */
{ 1676469 }, /* ocr.pf_l2_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200020\000\00000\000\000 */
{ 1676669 }, /* ocr.pf_l2_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200020\000\00000\000\000 */
{ 1676868 }, /* ocr.pf_l2_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200020\000\00000\000\000 */
{ 1677022 }, /* ocr.pf_l2_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200020\000\00000\000\000 */
{ 1677175 }, /* ocr.pf_l2_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040020\000\00000\000\000 */
{ 1677363 }, /* ocr.pf_l2_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040020\000\00000\000\000 */
{ 1677568 }, /* ocr.pf_l2_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040020\000\00000\000\000 */
{ 1677779 }, /* ocr.pf_l2_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040020\000\00000\000\000 */
{ 1677979 }, /* ocr.pf_l2_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040020\000\00000\000\000 */
{ 1678178 }, /* ocr.pf_l2_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040020\000\00000\000\000 */
{ 1678332 }, /* ocr.pf_l2_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040020\000\00000\000\000 */
{ 1678485 }, /* ocr.pf_l2_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100020\000\00000\000\000 */
{ 1678673 }, /* ocr.pf_l2_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100020\000\00000\000\000 */
{ 1678878 }, /* ocr.pf_l2_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100020\000\00000\000\000 */
{ 1679089 }, /* ocr.pf_l2_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100020\000\00000\000\000 */
{ 1679289 }, /* ocr.pf_l2_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100020\000\00000\000\000 */
{ 1679488 }, /* ocr.pf_l2_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100020\000\00000\000\000 */
{ 1679642 }, /* ocr.pf_l2_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100020\000\00000\000\000 */
{ 1687333 }, /* ocr.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000 */
{ 1687571 }, /* ocr.pf_l3_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00000\000\000 */
{ 1687835 }, /* ocr.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000 */
{ 1688108 }, /* ocr.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000 */
{ 1688364 }, /* ocr.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000 */
{ 1688619 }, /* ocr.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0080\000\00000\000\000 */
{ 1688795 }, /* ocr.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00000\000\000 */
{ 1688999 }, /* ocr.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00000\000\000 */
{ 1689202 }, /* ocr.pf_l3_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080080\000\00000\000\000 */
{ 1689410 }, /* ocr.pf_l3_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080080\000\00000\000\000 */
{ 1689635 }, /* ocr.pf_l3_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080080\000\00000\000\000 */
{ 1689866 }, /* ocr.pf_l3_data_rd.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080080\000\00000\000\000 */
{ 1690086 }, /* ocr.pf_l3_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080080\000\00000\000\000 */
{ 1690305 }, /* ocr.pf_l3_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080080\000\00000\000\000 */
{ 1690475 }, /* ocr.pf_l3_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080080\000\00000\000\000 */
{ 1690644 }, /* ocr.pf_l3_data_rd.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200080\000\00000\000\000 */
{ 1690852 }, /* ocr.pf_l3_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200080\000\00000\000\000 */
{ 1691077 }, /* ocr.pf_l3_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200080\000\00000\000\000 */
{ 1691308 }, /* ocr.pf_l3_data_rd.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200080\000\00000\000\000 */
{ 1691528 }, /* ocr.pf_l3_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200080\000\00000\000\000 */
{ 1691747 }, /* ocr.pf_l3_data_rd.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200080\000\00000\000\000 */
{ 1691917 }, /* ocr.pf_l3_data_rd.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200080\000\00000\000\000 */
{ 1692086 }, /* ocr.pf_l3_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040080\000\00000\000\000 */
{ 1692294 }, /* ocr.pf_l3_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040080\000\00000\000\000 */
{ 1692519 }, /* ocr.pf_l3_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040080\000\00000\000\000 */
{ 1692750 }, /* ocr.pf_l3_data_rd.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040080\000\00000\000\000 */
{ 1692970 }, /* ocr.pf_l3_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040080\000\00000\000\000 */
{ 1693189 }, /* ocr.pf_l3_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040080\000\00000\000\000 */
{ 1693359 }, /* ocr.pf_l3_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040080\000\00000\000\000 */
{ 1693528 }, /* ocr.pf_l3_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100080\000\00000\000\000 */
{ 1693736 }, /* ocr.pf_l3_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100080\000\00000\000\000 */
{ 1693961 }, /* ocr.pf_l3_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100080\000\00000\000\000 */
{ 1694192 }, /* ocr.pf_l3_data_rd.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100080\000\00000\000\000 */
{ 1694412 }, /* ocr.pf_l3_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100080\000\00000\000\000 */
{ 1694631 }, /* ocr.pf_l3_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100080\000\00000\000\000 */
{ 1694801 }, /* ocr.pf_l3_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100080\000\00000\000\000 */
{ 1703194 }, /* ocr.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 1703414 }, /* ocr.pf_l3_rfo.l3_hit.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00000\000\000 */
{ 1703660 }, /* ocr.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000 */
{ 1703915 }, /* ocr.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000 */
{ 1704153 }, /* ocr.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000 */
{ 1704390 }, /* ocr.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0100\000\00000\000\000 */
{ 1704556 }, /* ocr.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00000\000\000 */
{ 1704746 }, /* ocr.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00000\000\000 */
{ 1704935 }, /* ocr.pf_l3_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080100\000\00000\000\000 */
{ 1705129 }, /* ocr.pf_l3_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080100\000\00000\000\000 */
{ 1705340 }, /* ocr.pf_l3_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080100\000\00000\000\000 */
{ 1705557 }, /* ocr.pf_l3_rfo.l3_hit_e.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080100\000\00000\000\000 */
{ 1705763 }, /* ocr.pf_l3_rfo.l3_hit_e.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080100\000\00000\000\000 */
{ 1705968 }, /* ocr.pf_l3_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080100\000\00000\000\000 */
{ 1706128 }, /* ocr.pf_l3_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080100\000\00000\000\000 */
{ 1706287 }, /* ocr.pf_l3_rfo.l3_hit_f.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200100\000\00000\000\000 */
{ 1706481 }, /* ocr.pf_l3_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200100\000\00000\000\000 */
{ 1706692 }, /* ocr.pf_l3_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200100\000\00000\000\000 */
{ 1706909 }, /* ocr.pf_l3_rfo.l3_hit_f.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200100\000\00000\000\000 */
{ 1707115 }, /* ocr.pf_l3_rfo.l3_hit_f.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200100\000\00000\000\000 */
{ 1707320 }, /* ocr.pf_l3_rfo.l3_hit_f.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200100\000\00000\000\000 */
{ 1707480 }, /* ocr.pf_l3_rfo.l3_hit_f.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200100\000\00000\000\000 */
{ 1707639 }, /* ocr.pf_l3_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040100\000\00000\000\000 */
{ 1707833 }, /* ocr.pf_l3_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040100\000\00000\000\000 */
{ 1708044 }, /* ocr.pf_l3_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040100\000\00000\000\000 */
{ 1708261 }, /* ocr.pf_l3_rfo.l3_hit_m.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040100\000\00000\000\000 */
{ 1708467 }, /* ocr.pf_l3_rfo.l3_hit_m.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040100\000\00000\000\000 */
{ 1708672 }, /* ocr.pf_l3_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040100\000\00000\000\000 */
{ 1708832 }, /* ocr.pf_l3_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040100\000\00000\000\000 */
{ 1708991 }, /* ocr.pf_l3_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100100\000\00000\000\000 */
{ 1709185 }, /* ocr.pf_l3_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100100\000\00000\000\000 */
{ 1709396 }, /* ocr.pf_l3_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100100\000\00000\000\000 */
{ 1709613 }, /* ocr.pf_l3_rfo.l3_hit_s.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100100\000\00000\000\000 */
{ 1709819 }, /* ocr.pf_l3_rfo.l3_hit_s.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100100\000\00000\000\000 */
{ 1710024 }, /* ocr.pf_l3_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100100\000\00000\000\000 */
{ 1710184 }, /* ocr.pf_l3_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100100\000\00000\000\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1745789 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000 */
{ 1748358 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code read requests\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753384 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.Note: Writeback pending FIFO has six entries\000 */
{ 1756367 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1759308 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1761343 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1763371 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)\000 */
{ 1765815 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1770345 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1774107 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.Note: A prefetch promoted to Demand is counted from the promotion point\000 */
{ 1776411 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777863 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1784849 }, /* offcore_response.all_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00010\000\000 */
{ 1785367 }, /* offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00010\000\000 */
{ 1785563 }, /* offcore_response.all_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00010\000\000 */
{ 1786326 }, /* offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00010\000\000 */
{ 1787092 }, /* offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00010\000\000 */
{ 1787609 }, /* offcore_response.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00010\000\000 */
{ 1788161 }, /* offcore_response.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0491\000\00010\000\000 */
{ 1788691 }, /* offcore_response.all_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0491\000\00010\000\000 */
{ 1789209 }, /* offcore_response.all_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0491\000\00010\000\000 */
{ 1789569 }, /* offcore_response.all_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080491\000\00010\000\000 */
{ 1789769 }, /* offcore_response.all_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080491\000\00010\000\000 */
{ 1789986 }, /* offcore_response.all_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080491\000\00010\000\000 */
{ 1790209 }, /* offcore_response.all_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080491\000\00010\000\000 */
{ 1790421 }, /* offcore_response.all_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080491\000\00010\000\000 */
{ 1790632 }, /* offcore_response.all_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080491\000\00010\000\000 */
{ 1790833 }, /* offcore_response.all_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080491\000\00010\000\000 */
{ 1791033 }, /* offcore_response.all_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200491\000\00010\000\000 */
{ 1791233 }, /* offcore_response.all_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200491\000\00010\000\000 */
{ 1791450 }, /* offcore_response.all_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200491\000\00010\000\000 */
{ 1791673 }, /* offcore_response.all_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200491\000\00010\000\000 */
{ 1791885 }, /* offcore_response.all_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200491\000\00010\000\000 */
{ 1792096 }, /* offcore_response.all_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200491\000\00010\000\000 */
{ 1792297 }, /* offcore_response.all_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200491\000\00010\000\000 */
{ 1792497 }, /* offcore_response.all_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040491\000\00010\000\000 */
{ 1792697 }, /* offcore_response.all_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040491\000\00010\000\000 */
{ 1792914 }, /* offcore_response.all_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040491\000\00010\000\000 */
{ 1793137 }, /* offcore_response.all_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040491\000\00010\000\000 */
{ 1793349 }, /* offcore_response.all_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040491\000\00010\000\000 */
{ 1793560 }, /* offcore_response.all_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040491\000\00010\000\000 */
{ 1793761 }, /* offcore_response.all_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040491\000\00010\000\000 */
{ 1793961 }, /* offcore_response.all_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100491\000\00010\000\000 */
{ 1794161 }, /* offcore_response.all_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100491\000\00010\000\000 */
{ 1794378 }, /* offcore_response.all_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100491\000\00010\000\000 */
{ 1794601 }, /* offcore_response.all_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100491\000\00010\000\000 */
{ 1794813 }, /* offcore_response.all_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100491\000\00010\000\000 */
{ 1795024 }, /* offcore_response.all_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100491\000\00010\000\000 */
{ 1795225 }, /* offcore_response.all_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100491\000\00010\000\000 */
{ 1808894 }, /* offcore_response.all_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400491\000\00010\000\000 */
{ 1809112 }, /* offcore_response.all_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400491\000\00010\000\000 */
{ 1809330 }, /* offcore_response.all_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400491\000\00010\000\000 */
{ 1809726 }, /* offcore_response.all_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020491\000\00010\000\000 */
{ 1809936 }, /* offcore_response.all_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020491\000\00010\000\000 */
{ 1810163 }, /* offcore_response.all_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020491\000\00010\000\000 */
{ 1810396 }, /* offcore_response.all_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020491\000\00010\000\000 */
{ 1810618 }, /* offcore_response.all_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020491\000\00010\000\000 */
{ 1811341 }, /* offcore_response.all_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020491\000\00010\000\000 */
{ 1811887 }, /* offcore_response.all_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020491\000\00010\000\000 */
{ 1818980 }, /* offcore_response.all_pf_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00010\000\000 */
{ 1819492 }, /* offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00010\000\000 */
{ 1819694 }, /* offcore_response.all_pf_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00010\000\000 */
{ 1820188 }, /* offcore_response.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00010\000\000 */
{ 1820683 }, /* offcore_response.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00010\000\000 */
{ 1821200 }, /* offcore_response.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00010\000\000 */
{ 1821758 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0490\000\00010\000\000 */
{ 1822282 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0490\000\00010\000\000 */
{ 1822794 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0490\000\00010\000\000 */
{ 1823154 }, /* offcore_response.all_pf_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080490\000\00010\000\000 */
{ 1823360 }, /* offcore_response.all_pf_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080490\000\00010\000\000 */
{ 1823583 }, /* offcore_response.all_pf_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080490\000\00010\000\000 */
{ 1823812 }, /* offcore_response.all_pf_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080490\000\00010\000\000 */
{ 1824030 }, /* offcore_response.all_pf_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080490\000\00010\000\000 */
{ 1824247 }, /* offcore_response.all_pf_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080490\000\00010\000\000 */
{ 1824454 }, /* offcore_response.all_pf_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080490\000\00010\000\000 */
{ 1824660 }, /* offcore_response.all_pf_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200490\000\00010\000\000 */
{ 1824866 }, /* offcore_response.all_pf_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200490\000\00010\000\000 */
{ 1825089 }, /* offcore_response.all_pf_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200490\000\00010\000\000 */
{ 1825318 }, /* offcore_response.all_pf_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200490\000\00010\000\000 */
{ 1825536 }, /* offcore_response.all_pf_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200490\000\00010\000\000 */
{ 1825753 }, /* offcore_response.all_pf_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200490\000\00010\000\000 */
{ 1825960 }, /* offcore_response.all_pf_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200490\000\00010\000\000 */
{ 1826166 }, /* offcore_response.all_pf_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040490\000\00010\000\000 */
{ 1826372 }, /* offcore_response.all_pf_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040490\000\00010\000\000 */
{ 1826595 }, /* offcore_response.all_pf_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040490\000\00010\000\000 */
{ 1826824 }, /* offcore_response.all_pf_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040490\000\00010\000\000 */
{ 1827042 }, /* offcore_response.all_pf_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040490\000\00010\000\000 */
{ 1827259 }, /* offcore_response.all_pf_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040490\000\00010\000\000 */
{ 1827466 }, /* offcore_response.all_pf_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040490\000\00010\000\000 */
{ 1827672 }, /* offcore_response.all_pf_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100490\000\00010\000\000 */
{ 1827878 }, /* offcore_response.all_pf_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100490\000\00010\000\000 */
{ 1828101 }, /* offcore_response.all_pf_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100490\000\00010\000\000 */
{ 1828330 }, /* offcore_response.all_pf_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100490\000\00010\000\000 */
{ 1828548 }, /* offcore_response.all_pf_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100490\000\00010\000\000 */
{ 1828765 }, /* offcore_response.all_pf_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100490\000\00010\000\000 */
{ 1828972 }, /* offcore_response.all_pf_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100490\000\00010\000\000 */
{ 1839964 }, /* offcore_response.all_pf_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400490\000\00010\000\000 */
{ 1840188 }, /* offcore_response.all_pf_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400490\000\00010\000\000 */
{ 1840412 }, /* offcore_response.all_pf_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400490\000\00010\000\000 */
{ 1840808 }, /* offcore_response.all_pf_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020490\000\00010\000\000 */
{ 1841024 }, /* offcore_response.all_pf_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020490\000\00010\000\000 */
{ 1841257 }, /* offcore_response.all_pf_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020490\000\00010\000\000 */
{ 1841496 }, /* offcore_response.all_pf_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020490\000\00010\000\000 */
{ 1841724 }, /* offcore_response.all_pf_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020490\000\00010\000\000 */
{ 1842435 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020490\000\00010\000\000 */
{ 1842975 }, /* offcore_response.all_pf_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020490\000\00010\000\000 */
{ 1843665 }, /* offcore_response.all_pf_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00010\000\000 */
{ 1844141 }, /* offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00010\000\000 */
{ 1844335 }, /* offcore_response.all_pf_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00010\000\000 */
{ 1844807 }, /* offcore_response.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00010\000\000 */
{ 1845280 }, /* offcore_response.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00010\000\000 */
{ 1845775 }, /* offcore_response.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00010\000\000 */
{ 1846303 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0120\000\00010\000\000 */
{ 1846791 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0120\000\00010\000\000 */
{ 1847267 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0120\000\00010\000\000 */
{ 1847605 }, /* offcore_response.all_pf_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080120\000\00010\000\000 */
{ 1847803 }, /* offcore_response.all_pf_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080120\000\00010\000\000 */
{ 1848018 }, /* offcore_response.all_pf_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080120\000\00010\000\000 */
{ 1848239 }, /* offcore_response.all_pf_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080120\000\00010\000\000 */
{ 1848449 }, /* offcore_response.all_pf_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080120\000\00010\000\000 */
{ 1848658 }, /* offcore_response.all_pf_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080120\000\00010\000\000 */
{ 1848857 }, /* offcore_response.all_pf_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080120\000\00010\000\000 */
{ 1849055 }, /* offcore_response.all_pf_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200120\000\00010\000\000 */
{ 1849253 }, /* offcore_response.all_pf_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200120\000\00010\000\000 */
{ 1849468 }, /* offcore_response.all_pf_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200120\000\00010\000\000 */
{ 1849689 }, /* offcore_response.all_pf_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200120\000\00010\000\000 */
{ 1849899 }, /* offcore_response.all_pf_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200120\000\00010\000\000 */
{ 1850108 }, /* offcore_response.all_pf_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200120\000\00010\000\000 */
{ 1850307 }, /* offcore_response.all_pf_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200120\000\00010\000\000 */
{ 1850505 }, /* offcore_response.all_pf_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040120\000\00010\000\000 */
{ 1850703 }, /* offcore_response.all_pf_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040120\000\00010\000\000 */
{ 1850918 }, /* offcore_response.all_pf_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040120\000\00010\000\000 */
{ 1851139 }, /* offcore_response.all_pf_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040120\000\00010\000\000 */
{ 1851349 }, /* offcore_response.all_pf_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040120\000\00010\000\000 */
{ 1851558 }, /* offcore_response.all_pf_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040120\000\00010\000\000 */
{ 1851757 }, /* offcore_response.all_pf_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040120\000\00010\000\000 */
{ 1851955 }, /* offcore_response.all_pf_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100120\000\00010\000\000 */
{ 1852153 }, /* offcore_response.all_pf_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100120\000\00010\000\000 */
{ 1852368 }, /* offcore_response.all_pf_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100120\000\00010\000\000 */
{ 1852589 }, /* offcore_response.all_pf_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100120\000\00010\000\000 */
{ 1852799 }, /* offcore_response.all_pf_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100120\000\00010\000\000 */
{ 1853008 }, /* offcore_response.all_pf_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100120\000\00010\000\000 */
{ 1853207 }, /* offcore_response.all_pf_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100120\000\00010\000\000 */
{ 1863302 }, /* offcore_response.all_pf_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400120\000\00010\000\000 */
{ 1863518 }, /* offcore_response.all_pf_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400120\000\00010\000\000 */
{ 1863734 }, /* offcore_response.all_pf_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400120\000\00010\000\000 */
{ 1864108 }, /* offcore_response.all_pf_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00010\000\000 */
{ 1864316 }, /* offcore_response.all_pf_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020120\000\00010\000\000 */
{ 1864541 }, /* offcore_response.all_pf_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00010\000\000 */
{ 1864772 }, /* offcore_response.all_pf_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00010\000\000 */
{ 1864992 }, /* offcore_response.all_pf_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00010\000\000 */
{ 1865653 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00010\000\000 */
{ 1866157 }, /* offcore_response.all_pf_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00010\000\000 */
{ 1866849 }, /* offcore_response.all_reads.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107F7\000\00010\000\000 */
{ 1867028 }, /* offcore_response.all_reads.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C07F7\000\00010\000\000 */
{ 1867220 }, /* offcore_response.all_reads.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C07F7\000\00010\000\000 */
{ 1867429 }, /* offcore_response.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00010\000\000 */
{ 1867871 }, /* offcore_response.all_reads.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00010\000\000 */
{ 1868304 }, /* offcore_response.all_reads.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C07F7\000\00010\000\000 */
{ 1868507 }, /* offcore_response.all_reads.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C07F7\000\00010\000\000 */
{ 1868716 }, /* offcore_response.all_reads.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C07F7\000\00010\000\000 */
{ 1868909 }, /* offcore_response.all_reads.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C07F7\000\00010\000\000 */
{ 1869101 }, /* offcore_response.all_reads.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800807F7\000\00010\000\000 */
{ 1869297 }, /* offcore_response.all_reads.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000807F7\000\00010\000\000 */
{ 1869510 }, /* offcore_response.all_reads.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000807F7\000\00010\000\000 */
{ 1869729 }, /* offcore_response.all_reads.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000807F7\000\00010\000\000 */
{ 1869937 }, /* offcore_response.all_reads.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000807F7\000\00010\000\000 */
{ 1870144 }, /* offcore_response.all_reads.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000807F7\000\00010\000\000 */
{ 1870341 }, /* offcore_response.all_reads.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800807F7\000\00010\000\000 */
{ 1870537 }, /* offcore_response.all_reads.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F802007F7\000\00010\000\000 */
{ 1870733 }, /* offcore_response.all_reads.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8002007F7\000\00010\000\000 */
{ 1870946 }, /* offcore_response.all_reads.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4002007F7\000\00010\000\000 */
{ 1871165 }, /* offcore_response.all_reads.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002007F7\000\00010\000\000 */
{ 1871373 }, /* offcore_response.all_reads.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002007F7\000\00010\000\000 */
{ 1871580 }, /* offcore_response.all_reads.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002007F7\000\00010\000\000 */
{ 1871777 }, /* offcore_response.all_reads.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802007F7\000\00010\000\000 */
{ 1871973 }, /* offcore_response.all_reads.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800407F7\000\00010\000\000 */
{ 1872169 }, /* offcore_response.all_reads.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000407F7\000\00010\000\000 */
{ 1872382 }, /* offcore_response.all_reads.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000407F7\000\00010\000\000 */
{ 1872601 }, /* offcore_response.all_reads.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000407F7\000\00010\000\000 */
{ 1872809 }, /* offcore_response.all_reads.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000407F7\000\00010\000\000 */
{ 1873016 }, /* offcore_response.all_reads.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000407F7\000\00010\000\000 */
{ 1873213 }, /* offcore_response.all_reads.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800407F7\000\00010\000\000 */
{ 1873409 }, /* offcore_response.all_reads.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F801007F7\000\00010\000\000 */
{ 1873605 }, /* offcore_response.all_reads.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8001007F7\000\00010\000\000 */
{ 1873818 }, /* offcore_response.all_reads.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001007F7\000\00010\000\000 */
{ 1874037 }, /* offcore_response.all_reads.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001007F7\000\00010\000\000 */
{ 1874245 }, /* offcore_response.all_reads.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001007F7\000\00010\000\000 */
{ 1874452 }, /* offcore_response.all_reads.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001007F7\000\00010\000\000 */
{ 1874649 }, /* offcore_response.all_reads.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801007F7\000\00010\000\000 */
{ 1886673 }, /* offcore_response.all_reads.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F804007F7\000\00010\000\000 */
{ 1886887 }, /* offcore_response.all_reads.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804007F7\000\00010\000\000 */
{ 1887101 }, /* offcore_response.all_reads.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00010\000\000 */
{ 1887328 }, /* offcore_response.all_reads.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800207F7\000\00010\000\000 */
{ 1887534 }, /* offcore_response.all_reads.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000207F7\000\00010\000\000 */
{ 1887757 }, /* offcore_response.all_reads.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000207F7\000\00010\000\000 */
{ 1887986 }, /* offcore_response.all_reads.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000207F7\000\00010\000\000 */
{ 1888204 }, /* offcore_response.all_reads.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000207F7\000\00010\000\000 */
{ 1888421 }, /* offcore_response.all_reads.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000207F7\000\00010\000\000 */
{ 1888628 }, /* offcore_response.all_reads.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_READS.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800207F7\000\00010\000\000 */
{ 1890098 }, /* offcore_response.all_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00010\000\000 */
{ 1890588 }, /* offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00010\000\000 */
{ 1890776 }, /* offcore_response.all_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00010\000\000 */
{ 1891511 }, /* offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00010\000\000 */
{ 1892249 }, /* offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00010\000\000 */
{ 1892748 }, /* offcore_response.all_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00010\000\000 */
{ 1893274 }, /* offcore_response.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0122\000\00010\000\000 */
{ 1893776 }, /* offcore_response.all_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0122\000\00010\000\000 */
{ 1894266 }, /* offcore_response.all_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0122\000\00010\000\000 */
{ 1894608 }, /* offcore_response.all_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080122\000\00010\000\000 */
{ 1894800 }, /* offcore_response.all_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080122\000\00010\000\000 */
{ 1895009 }, /* offcore_response.all_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080122\000\00010\000\000 */
{ 1895224 }, /* offcore_response.all_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080122\000\00010\000\000 */
{ 1895428 }, /* offcore_response.all_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080122\000\00010\000\000 */
{ 1895631 }, /* offcore_response.all_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080122\000\00010\000\000 */
{ 1895824 }, /* offcore_response.all_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080122\000\00010\000\000 */
{ 1896016 }, /* offcore_response.all_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200122\000\00010\000\000 */
{ 1896208 }, /* offcore_response.all_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200122\000\00010\000\000 */
{ 1896417 }, /* offcore_response.all_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200122\000\00010\000\000 */
{ 1896632 }, /* offcore_response.all_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200122\000\00010\000\000 */
{ 1896836 }, /* offcore_response.all_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200122\000\00010\000\000 */
{ 1897039 }, /* offcore_response.all_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200122\000\00010\000\000 */
{ 1897232 }, /* offcore_response.all_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200122\000\00010\000\000 */
{ 1897424 }, /* offcore_response.all_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040122\000\00010\000\000 */
{ 1897616 }, /* offcore_response.all_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040122\000\00010\000\000 */
{ 1897825 }, /* offcore_response.all_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040122\000\00010\000\000 */
{ 1898040 }, /* offcore_response.all_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040122\000\00010\000\000 */
{ 1898244 }, /* offcore_response.all_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040122\000\00010\000\000 */
{ 1898447 }, /* offcore_response.all_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040122\000\00010\000\000 */
{ 1898640 }, /* offcore_response.all_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040122\000\00010\000\000 */
{ 1898832 }, /* offcore_response.all_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100122\000\00010\000\000 */
{ 1899024 }, /* offcore_response.all_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100122\000\00010\000\000 */
{ 1899233 }, /* offcore_response.all_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100122\000\00010\000\000 */
{ 1899448 }, /* offcore_response.all_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100122\000\00010\000\000 */
{ 1899652 }, /* offcore_response.all_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100122\000\00010\000\000 */
{ 1899855 }, /* offcore_response.all_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100122\000\00010\000\000 */
{ 1900048 }, /* offcore_response.all_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100122\000\00010\000\000 */
{ 1911663 }, /* offcore_response.all_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400122\000\00010\000\000 */
{ 1911873 }, /* offcore_response.all_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400122\000\00010\000\000 */
{ 1912083 }, /* offcore_response.all_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00010\000\000 */
{ 1912461 }, /* offcore_response.all_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00010\000\000 */
{ 1912663 }, /* offcore_response.all_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020122\000\00010\000\000 */
{ 1912882 }, /* offcore_response.all_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00010\000\000 */
{ 1913107 }, /* offcore_response.all_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00010\000\000 */
{ 1913321 }, /* offcore_response.all_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00010\000\000 */
{ 1914006 }, /* offcore_response.all_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00010\000\000 */
{ 1914524 }, /* offcore_response.all_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00010\000\000 */
{ 2026829 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00010\000\000 */
{ 2035444 }, /* offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00010\000\000 */
{ 2035646 }, /* offcore_response.demand_code_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00010\000\000 */
{ 2036399 }, /* offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00010\000\000 */
{ 2037155 }, /* offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00010\000\000 */
{ 2037670 }, /* offcore_response.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00010\000\000 */
{ 2038382 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0004\000\00010\000\000 */
{ 2039203 }, /* offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00010\000\000 */
{ 2040016 }, /* offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0004\000\00010\000\000 */
{ 2040828 }, /* offcore_response.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080004\000\00010\000\000 */
{ 2041034 }, /* offcore_response.demand_code_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080004\000\00010\000\000 */
{ 2041257 }, /* offcore_response.demand_code_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00010\000\000 */
{ 2041486 }, /* offcore_response.demand_code_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00010\000\000 */
{ 2041704 }, /* offcore_response.demand_code_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00010\000\000 */
{ 2042384 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00010\000\000 */
{ 2042900 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00010\000\000 */
{ 2043412 }, /* offcore_response.demand_code_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200004\000\00010\000\000 */
{ 2043618 }, /* offcore_response.demand_code_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200004\000\00010\000\000 */
{ 2043841 }, /* offcore_response.demand_code_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200004\000\00010\000\000 */
{ 2044070 }, /* offcore_response.demand_code_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200004\000\00010\000\000 */
{ 2044288 }, /* offcore_response.demand_code_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200004\000\00010\000\000 */
{ 2044505 }, /* offcore_response.demand_code_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200004\000\00010\000\000 */
{ 2044712 }, /* offcore_response.demand_code_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200004\000\00010\000\000 */
{ 2045070 }, /* offcore_response.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040004\000\00010\000\000 */
{ 2045276 }, /* offcore_response.demand_code_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040004\000\00010\000\000 */
{ 2045499 }, /* offcore_response.demand_code_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00010\000\000 */
{ 2045728 }, /* offcore_response.demand_code_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00010\000\000 */
{ 2045946 }, /* offcore_response.demand_code_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00010\000\000 */
{ 2046626 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00010\000\000 */
{ 2047142 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00010\000\000 */
{ 2047806 }, /* offcore_response.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100004\000\00010\000\000 */
{ 2048012 }, /* offcore_response.demand_code_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100004\000\00010\000\000 */
{ 2048235 }, /* offcore_response.demand_code_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00010\000\000 */
{ 2048464 }, /* offcore_response.demand_code_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00010\000\000 */
{ 2048682 }, /* offcore_response.demand_code_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00010\000\000 */
{ 2049362 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00010\000\000 */
{ 2049878 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00010\000\000 */
{ 2068354 }, /* offcore_response.demand_code_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400004\000\00010\000\000 */
{ 2068578 }, /* offcore_response.demand_code_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00010\000\000 */
{ 2068802 }, /* offcore_response.demand_code_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00010\000\000 */
{ 2069353 }, /* offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00010\000\000 */
{ 2069569 }, /* offcore_response.demand_code_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020004\000\00010\000\000 */
{ 2069802 }, /* offcore_response.demand_code_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00010\000\000 */
{ 2070041 }, /* offcore_response.demand_code_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00010\000\000 */
{ 2070269 }, /* offcore_response.demand_code_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00010\000\000 */
{ 2070974 }, /* offcore_response.demand_code_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00010\000\000 */
{ 2071510 }, /* offcore_response.demand_code_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00010\000\000 */
{ 2080815 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00010\000\000 */
{ 2089354 }, /* offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00010\000\000 */
{ 2089556 }, /* offcore_response.demand_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00010\000\000 */
{ 2090301 }, /* offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00010\000\000 */
{ 2091049 }, /* offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00010\000\000 */
{ 2091560 }, /* offcore_response.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00010\000\000 */
{ 2092264 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0001\000\00010\000\000 */
{ 2093069 }, /* offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00010\000\000 */
{ 2093866 }, /* offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0001\000\00010\000\000 */
{ 2094662 }, /* offcore_response.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080001\000\00010\000\000 */
{ 2094868 }, /* offcore_response.demand_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080001\000\00010\000\000 */
{ 2095091 }, /* offcore_response.demand_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00010\000\000 */
{ 2095320 }, /* offcore_response.demand_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00010\000\000 */
{ 2095538 }, /* offcore_response.demand_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00010\000\000 */
{ 2096206 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00010\000\000 */
{ 2096714 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00010\000\000 */
{ 2097218 }, /* offcore_response.demand_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200001\000\00010\000\000 */
{ 2097424 }, /* offcore_response.demand_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200001\000\00010\000\000 */
{ 2097647 }, /* offcore_response.demand_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200001\000\00010\000\000 */
{ 2097876 }, /* offcore_response.demand_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200001\000\00010\000\000 */
{ 2098094 }, /* offcore_response.demand_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200001\000\00010\000\000 */
{ 2098311 }, /* offcore_response.demand_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200001\000\00010\000\000 */
{ 2098518 }, /* offcore_response.demand_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200001\000\00010\000\000 */
{ 2098872 }, /* offcore_response.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040001\000\00010\000\000 */
{ 2099078 }, /* offcore_response.demand_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040001\000\00010\000\000 */
{ 2099301 }, /* offcore_response.demand_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00010\000\000 */
{ 2099530 }, /* offcore_response.demand_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00010\000\000 */
{ 2099748 }, /* offcore_response.demand_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00010\000\000 */
{ 2100416 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00010\000\000 */
{ 2100924 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00010\000\000 */
{ 2101576 }, /* offcore_response.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100001\000\00010\000\000 */
{ 2101782 }, /* offcore_response.demand_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100001\000\00010\000\000 */
{ 2102005 }, /* offcore_response.demand_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00010\000\000 */
{ 2102234 }, /* offcore_response.demand_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00010\000\000 */
{ 2102452 }, /* offcore_response.demand_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00010\000\000 */
{ 2103120 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00010\000\000 */
{ 2103628 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00010\000\000 */
{ 2124700 }, /* offcore_response.demand_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400001\000\00010\000\000 */
{ 2124924 }, /* offcore_response.demand_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00010\000\000 */
{ 2125148 }, /* offcore_response.demand_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00010\000\000 */
{ 2127227 }, /* offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00010\000\000 */
{ 2127443 }, /* offcore_response.demand_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020001\000\00010\000\000 */
{ 2127676 }, /* offcore_response.demand_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00010\000\000 */
{ 2127915 }, /* offcore_response.demand_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00010\000\000 */
{ 2128143 }, /* offcore_response.demand_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00010\000\000 */
{ 2128836 }, /* offcore_response.demand_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00010\000\000 */
{ 2129364 }, /* offcore_response.demand_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00010\000\000 */
{ 2138706 }, /* offcore_response.demand_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00010\000\000 */
{ 2148148 }, /* offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00010\000\000 */
{ 2148342 }, /* offcore_response.demand_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00010\000\000 */
{ 2149095 }, /* offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00010\000\000 */
{ 2149851 }, /* offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00010\000\000 */
{ 2150362 }, /* offcore_response.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00010\000\000 */
{ 2151066 }, /* offcore_response.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0002\000\00010\000\000 */
{ 2151895 }, /* offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00010\000\000 */
{ 2152716 }, /* offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0002\000\00010\000\000 */
{ 2153536 }, /* offcore_response.demand_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080002\000\00010\000\000 */
{ 2153734 }, /* offcore_response.demand_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080002\000\00010\000\000 */
{ 2153949 }, /* offcore_response.demand_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00010\000\000 */
{ 2154170 }, /* offcore_response.demand_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00010\000\000 */
{ 2154380 }, /* offcore_response.demand_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00010\000\000 */
{ 2155064 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00010\000\000 */
{ 2155580 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00010\000\000 */
{ 2156092 }, /* offcore_response.demand_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200002\000\00010\000\000 */
{ 2156290 }, /* offcore_response.demand_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200002\000\00010\000\000 */
{ 2156505 }, /* offcore_response.demand_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200002\000\00010\000\000 */
{ 2156726 }, /* offcore_response.demand_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200002\000\00010\000\000 */
{ 2156936 }, /* offcore_response.demand_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200002\000\00010\000\000 */
{ 2157145 }, /* offcore_response.demand_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200002\000\00010\000\000 */
{ 2157344 }, /* offcore_response.demand_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200002\000\00010\000\000 */
{ 2157698 }, /* offcore_response.demand_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040002\000\00010\000\000 */
{ 2157896 }, /* offcore_response.demand_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040002\000\00010\000\000 */
{ 2158111 }, /* offcore_response.demand_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00010\000\000 */
{ 2158332 }, /* offcore_response.demand_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00010\000\000 */
{ 2158542 }, /* offcore_response.demand_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00010\000\000 */
{ 2159226 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00010\000\000 */
{ 2159742 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00010\000\000 */
{ 2160410 }, /* offcore_response.demand_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100002\000\00010\000\000 */
{ 2160608 }, /* offcore_response.demand_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100002\000\00010\000\000 */
{ 2160823 }, /* offcore_response.demand_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00010\000\000 */
{ 2161044 }, /* offcore_response.demand_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00010\000\000 */
{ 2161254 }, /* offcore_response.demand_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00010\000\000 */
{ 2161938 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00010\000\000 */
{ 2162454 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00010\000\000 */
{ 2183019 }, /* offcore_response.demand_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400002\000\00010\000\000 */
{ 2183235 }, /* offcore_response.demand_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00010\000\000 */
{ 2183451 }, /* offcore_response.demand_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00010\000\000 */
{ 2185347 }, /* offcore_response.demand_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020002\000\00010\000\000 */
{ 2185555 }, /* offcore_response.demand_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020002\000\00010\000\000 */
{ 2185780 }, /* offcore_response.demand_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00010\000\000 */
{ 2186011 }, /* offcore_response.demand_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00010\000\000 */
{ 2186231 }, /* offcore_response.demand_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00010\000\000 */
{ 2186940 }, /* offcore_response.demand_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00010\000\000 */
{ 2187476 }, /* offcore_response.demand_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00010\000\000 */
{ 2196179 }, /* offcore_response.other.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00010\000\000 */
{ 2196930 }, /* offcore_response.other.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8000\000\00010\000\000 */
{ 2197114 }, /* offcore_response.other.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C8000\000\00010\000\000 */
{ 2197315 }, /* offcore_response.other.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00010\000\000 */
{ 2197522 }, /* offcore_response.other.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C8000\000\00010\000\000 */
{ 2197718 }, /* offcore_response.other.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00010\000\000 */
{ 2198201 }, /* offcore_response.other.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C8000\000\00010\000\000 */
{ 2198956 }, /* offcore_response.other.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00010\000\000 */
{ 2199703 }, /* offcore_response.other.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C8000\000\00010\000\000 */
{ 2200449 }, /* offcore_response.other.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80088000\000\00010\000\000 */
{ 2200637 }, /* offcore_response.other.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800088000\000\00010\000\000 */
{ 2200842 }, /* offcore_response.other.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00010\000\000 */
{ 2201053 }, /* offcore_response.other.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00010\000\000 */
{ 2201253 }, /* offcore_response.other.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00010\000\000 */
{ 2201879 }, /* offcore_response.other.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00010\000\000 */
{ 2202353 }, /* offcore_response.other.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00010\000\000 */
{ 2202823 }, /* offcore_response.other.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80208000\000\00010\000\000 */
{ 2203011 }, /* offcore_response.other.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800208000\000\00010\000\000 */
{ 2203216 }, /* offcore_response.other.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400208000\000\00010\000\000 */
{ 2203427 }, /* offcore_response.other.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000208000\000\00010\000\000 */
{ 2203627 }, /* offcore_response.other.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100208000\000\00010\000\000 */
{ 2203826 }, /* offcore_response.other.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200208000\000\00010\000\000 */
{ 2204015 }, /* offcore_response.other.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80208000\000\00010\000\000 */
{ 2204343 }, /* offcore_response.other.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80048000\000\00010\000\000 */
{ 2204531 }, /* offcore_response.other.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800048000\000\00010\000\000 */
{ 2204736 }, /* offcore_response.other.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00010\000\000 */
{ 2204947 }, /* offcore_response.other.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00010\000\000 */
{ 2205147 }, /* offcore_response.other.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00010\000\000 */
{ 2205773 }, /* offcore_response.other.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00010\000\000 */
{ 2206247 }, /* offcore_response.other.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00010\000\000 */
{ 2206857 }, /* offcore_response.other.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80108000\000\00010\000\000 */
{ 2207045 }, /* offcore_response.other.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800108000\000\00010\000\000 */
{ 2207250 }, /* offcore_response.other.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00010\000\000 */
{ 2207461 }, /* offcore_response.other.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00010\000\000 */
{ 2207661 }, /* offcore_response.other.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00010\000\000 */
{ 2208287 }, /* offcore_response.other.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00010\000\000 */
{ 2208761 }, /* offcore_response.other.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00010\000\000 */
{ 2221053 }, /* offcore_response.other.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80408000\000\00010\000\000 */
{ 2221259 }, /* offcore_response.other.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00010\000\000 */
{ 2221465 }, /* offcore_response.other.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00010\000\000 */
{ 2223790 }, /* offcore_response.other.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00010\000\000 */
{ 2223988 }, /* offcore_response.other.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800028000\000\00010\000\000 */
{ 2224203 }, /* offcore_response.other.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00010\000\000 */
{ 2224424 }, /* offcore_response.other.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00010\000\000 */
{ 2224634 }, /* offcore_response.other.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00010\000\000 */
{ 2225285 }, /* offcore_response.other.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00010\000\000 */
{ 2225779 }, /* offcore_response.other.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.OTHER.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00010\000\000 */
{ 2271010 }, /* offcore_response.pf_l1d_and_sw.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00010\000\000 */
{ 2271415 }, /* offcore_response.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00010\000\000 */
{ 2271615 }, /* offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00010\000\000 */
{ 2272154 }, /* offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00010\000\000 */
{ 2272694 }, /* offcore_response.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00010\000\000 */
{ 2273256 }, /* offcore_response.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00010\000\000 */
{ 2273652 }, /* offcore_response.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0400\000\00010\000\000 */
{ 2273869 }, /* offcore_response.pf_l1d_and_sw.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00010\000\000 */
{ 2274070 }, /* offcore_response.pf_l1d_and_sw.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0400\000\00010\000\000 */
{ 2274270 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080400\000\00010\000\000 */
{ 2274474 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080400\000\00010\000\000 */
{ 2274695 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080400\000\00010\000\000 */
{ 2274922 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080400\000\00010\000\000 */
{ 2275138 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080400\000\00010\000\000 */
{ 2275353 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080400\000\00010\000\000 */
{ 2275558 }, /* offcore_response.pf_l1d_and_sw.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080400\000\00010\000\000 */
{ 2275762 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200400\000\00010\000\000 */
{ 2275966 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200400\000\00010\000\000 */
{ 2276187 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200400\000\00010\000\000 */
{ 2276414 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200400\000\00010\000\000 */
{ 2276630 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200400\000\00010\000\000 */
{ 2276845 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200400\000\00010\000\000 */
{ 2277050 }, /* offcore_response.pf_l1d_and_sw.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200400\000\00010\000\000 */
{ 2277254 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040400\000\00010\000\000 */
{ 2277458 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040400\000\00010\000\000 */
{ 2277679 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040400\000\00010\000\000 */
{ 2277906 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040400\000\00010\000\000 */
{ 2278122 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040400\000\00010\000\000 */
{ 2278337 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040400\000\00010\000\000 */
{ 2278542 }, /* offcore_response.pf_l1d_and_sw.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040400\000\00010\000\000 */
{ 2278746 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100400\000\00010\000\000 */
{ 2278950 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100400\000\00010\000\000 */
{ 2279171 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100400\000\00010\000\000 */
{ 2279398 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100400\000\00010\000\000 */
{ 2279614 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100400\000\00010\000\000 */
{ 2279829 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100400\000\00010\000\000 */
{ 2280034 }, /* offcore_response.pf_l1d_and_sw.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100400\000\00010\000\000 */
{ 2287627 }, /* offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400400\000\00010\000\000 */
{ 2287849 }, /* offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400400\000\00010\000\000 */
{ 2288071 }, /* offcore_response.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400400\000\00010\000\000 */
{ 2288306 }, /* offcore_response.pf_l1d_and_sw.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020400\000\00010\000\000 */
{ 2288520 }, /* offcore_response.pf_l1d_and_sw.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020400\000\00010\000\000 */
{ 2288751 }, /* offcore_response.pf_l1d_and_sw.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020400\000\00010\000\000 */
{ 2288988 }, /* offcore_response.pf_l1d_and_sw.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020400\000\00010\000\000 */
{ 2289214 }, /* offcore_response.pf_l1d_and_sw.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020400\000\00010\000\000 */
{ 2289439 }, /* offcore_response.pf_l1d_and_sw.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020400\000\00010\000\000 */
{ 2289654 }, /* offcore_response.pf_l1d_and_sw.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020400\000\00010\000\000 */
{ 2302625 }, /* offcore_response.pf_l2_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00010\000\000 */
{ 2308239 }, /* offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00010\000\000 */
{ 2308439 }, /* offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00010\000\000 */
{ 2308950 }, /* offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00010\000\000 */
{ 2309462 }, /* offcore_response.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00010\000\000 */
{ 2309996 }, /* offcore_response.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00010\000\000 */
{ 2310569 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0010\000\00010\000\000 */
{ 2311129 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00010\000\000 */
{ 2311677 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0010\000\00010\000\000 */
{ 2312054 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080010\000\00010\000\000 */
{ 2312258 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080010\000\00010\000\000 */
{ 2312479 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080010\000\00010\000\000 */
{ 2312706 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080010\000\00010\000\000 */
{ 2312922 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080010\000\00010\000\000 */
{ 2313137 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080010\000\00010\000\000 */
{ 2313342 }, /* offcore_response.pf_l2_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080010\000\00010\000\000 */
{ 2313546 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200010\000\00010\000\000 */
{ 2313750 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200010\000\00010\000\000 */
{ 2313971 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200010\000\00010\000\000 */
{ 2314198 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200010\000\00010\000\000 */
{ 2314414 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200010\000\00010\000\000 */
{ 2314629 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200010\000\00010\000\000 */
{ 2314834 }, /* offcore_response.pf_l2_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200010\000\00010\000\000 */
{ 2315038 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040010\000\00010\000\000 */
{ 2315242 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040010\000\00010\000\000 */
{ 2315463 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040010\000\00010\000\000 */
{ 2315690 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040010\000\00010\000\000 */
{ 2315906 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040010\000\00010\000\000 */
{ 2316121 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040010\000\00010\000\000 */
{ 2316326 }, /* offcore_response.pf_l2_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040010\000\00010\000\000 */
{ 2316530 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100010\000\00010\000\000 */
{ 2316734 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100010\000\00010\000\000 */
{ 2316955 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100010\000\00010\000\000 */
{ 2317182 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100010\000\00010\000\000 */
{ 2317398 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100010\000\00010\000\000 */
{ 2317613 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100010\000\00010\000\000 */
{ 2317818 }, /* offcore_response.pf_l2_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100010\000\00010\000\000 */
{ 2331521 }, /* offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400010\000\00010\000\000 */
{ 2331743 }, /* offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400010\000\00010\000\000 */
{ 2331965 }, /* offcore_response.pf_l2_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400010\000\00010\000\000 */
{ 2332378 }, /* offcore_response.pf_l2_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00010\000\000 */
{ 2332592 }, /* offcore_response.pf_l2_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020010\000\00010\000\000 */
{ 2332823 }, /* offcore_response.pf_l2_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00010\000\000 */
{ 2333060 }, /* offcore_response.pf_l2_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00010\000\000 */
{ 2333286 }, /* offcore_response.pf_l2_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00010\000\000 */
{ 2334052 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00010\000\000 */
{ 2334628 }, /* offcore_response.pf_l2_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00010\000\000 */
{ 2336055 }, /* offcore_response.pf_l2_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00010\000\000 */
{ 2344831 }, /* offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00010\000\000 */
{ 2345023 }, /* offcore_response.pf_l2_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00010\000\000 */
{ 2345520 }, /* offcore_response.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00010\000\000 */
{ 2346018 }, /* offcore_response.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00010\000\000 */
{ 2346538 }, /* offcore_response.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00010\000\000 */
{ 2347089 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0020\000\00010\000\000 */
{ 2347629 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00010\000\000 */
{ 2348157 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0020\000\00010\000\000 */
{ 2348520 }, /* offcore_response.pf_l2_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080020\000\00010\000\000 */
{ 2348716 }, /* offcore_response.pf_l2_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080020\000\00010\000\000 */
{ 2348929 }, /* offcore_response.pf_l2_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080020\000\00010\000\000 */
{ 2349148 }, /* offcore_response.pf_l2_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080020\000\00010\000\000 */
{ 2349356 }, /* offcore_response.pf_l2_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080020\000\00010\000\000 */
{ 2349563 }, /* offcore_response.pf_l2_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080020\000\00010\000\000 */
{ 2349760 }, /* offcore_response.pf_l2_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080020\000\00010\000\000 */
{ 2349956 }, /* offcore_response.pf_l2_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200020\000\00010\000\000 */
{ 2350152 }, /* offcore_response.pf_l2_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200020\000\00010\000\000 */
{ 2350365 }, /* offcore_response.pf_l2_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200020\000\00010\000\000 */
{ 2350584 }, /* offcore_response.pf_l2_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200020\000\00010\000\000 */
{ 2350792 }, /* offcore_response.pf_l2_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200020\000\00010\000\000 */
{ 2350999 }, /* offcore_response.pf_l2_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200020\000\00010\000\000 */
{ 2351196 }, /* offcore_response.pf_l2_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200020\000\00010\000\000 */
{ 2351392 }, /* offcore_response.pf_l2_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040020\000\00010\000\000 */
{ 2351588 }, /* offcore_response.pf_l2_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040020\000\00010\000\000 */
{ 2351801 }, /* offcore_response.pf_l2_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040020\000\00010\000\000 */
{ 2352020 }, /* offcore_response.pf_l2_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040020\000\00010\000\000 */
{ 2352228 }, /* offcore_response.pf_l2_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040020\000\00010\000\000 */
{ 2352435 }, /* offcore_response.pf_l2_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040020\000\00010\000\000 */
{ 2352632 }, /* offcore_response.pf_l2_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040020\000\00010\000\000 */
{ 2352828 }, /* offcore_response.pf_l2_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100020\000\00010\000\000 */
{ 2353024 }, /* offcore_response.pf_l2_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100020\000\00010\000\000 */
{ 2353237 }, /* offcore_response.pf_l2_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100020\000\00010\000\000 */
{ 2353456 }, /* offcore_response.pf_l2_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100020\000\00010\000\000 */
{ 2353664 }, /* offcore_response.pf_l2_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100020\000\00010\000\000 */
{ 2353871 }, /* offcore_response.pf_l2_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100020\000\00010\000\000 */
{ 2354068 }, /* offcore_response.pf_l2_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100020\000\00010\000\000 */
{ 2366745 }, /* offcore_response.pf_l2_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400020\000\00010\000\000 */
{ 2366959 }, /* offcore_response.pf_l2_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400020\000\00010\000\000 */
{ 2367173 }, /* offcore_response.pf_l2_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400020\000\00010\000\000 */
{ 2367572 }, /* offcore_response.pf_l2_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00010\000\000 */
{ 2367778 }, /* offcore_response.pf_l2_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020020\000\00010\000\000 */
{ 2368001 }, /* offcore_response.pf_l2_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00010\000\000 */
{ 2368230 }, /* offcore_response.pf_l2_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00010\000\000 */
{ 2368448 }, /* offcore_response.pf_l2_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00010\000\000 */
{ 2369188 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00010\000\000 */
{ 2369744 }, /* offcore_response.pf_l2_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00010\000\000 */
{ 2375952 }, /* offcore_response.pf_l3_data_rd.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00010\000\000 */
{ 2376718 }, /* offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00010\000\000 */
{ 2376918 }, /* offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00010\000\000 */
{ 2377439 }, /* offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00010\000\000 */
{ 2377961 }, /* offcore_response.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00010\000\000 */
{ 2378505 }, /* offcore_response.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00010\000\000 */
{ 2379088 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0080\000\00010\000\000 */
{ 2379668 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0080\000\00010\000\000 */
{ 2380236 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0080\000\00010\000\000 */
{ 2380623 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080080\000\00010\000\000 */
{ 2380827 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080080\000\00010\000\000 */
{ 2381048 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080080\000\00010\000\000 */
{ 2381275 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080080\000\00010\000\000 */
{ 2381491 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080080\000\00010\000\000 */
{ 2381706 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080080\000\00010\000\000 */
{ 2381911 }, /* offcore_response.pf_l3_data_rd.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080080\000\00010\000\000 */
{ 2382115 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200080\000\00010\000\000 */
{ 2382319 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200080\000\00010\000\000 */
{ 2382540 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200080\000\00010\000\000 */
{ 2382767 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200080\000\00010\000\000 */
{ 2382983 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200080\000\00010\000\000 */
{ 2383198 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200080\000\00010\000\000 */
{ 2383403 }, /* offcore_response.pf_l3_data_rd.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200080\000\00010\000\000 */
{ 2383607 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040080\000\00010\000\000 */
{ 2383811 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040080\000\00010\000\000 */
{ 2384032 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040080\000\00010\000\000 */
{ 2384259 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040080\000\00010\000\000 */
{ 2384475 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040080\000\00010\000\000 */
{ 2384690 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040080\000\00010\000\000 */
{ 2384895 }, /* offcore_response.pf_l3_data_rd.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040080\000\00010\000\000 */
{ 2385099 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100080\000\00010\000\000 */
{ 2385303 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100080\000\00010\000\000 */
{ 2385524 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100080\000\00010\000\000 */
{ 2385751 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100080\000\00010\000\000 */
{ 2385967 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100080\000\00010\000\000 */
{ 2386182 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100080\000\00010\000\000 */
{ 2386387 }, /* offcore_response.pf_l3_data_rd.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100080\000\00010\000\000 */
{ 2396191 }, /* offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400080\000\00010\000\000 */
{ 2396413 }, /* offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400080\000\00010\000\000 */
{ 2396635 }, /* offcore_response.pf_l3_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400080\000\00010\000\000 */
{ 2397058 }, /* offcore_response.pf_l3_data_rd.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00010\000\000 */
{ 2397272 }, /* offcore_response.pf_l3_data_rd.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020080\000\00010\000\000 */
{ 2397503 }, /* offcore_response.pf_l3_data_rd.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00010\000\000 */
{ 2397740 }, /* offcore_response.pf_l3_data_rd.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00010\000\000 */
{ 2397966 }, /* offcore_response.pf_l3_data_rd.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00010\000\000 */
{ 2398762 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00010\000\000 */
{ 2399358 }, /* offcore_response.pf_l3_data_rd.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00010\000\000 */
{ 2400141 }, /* offcore_response.pf_l3_rfo.any_response\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00010\000\000 */
{ 2400869 }, /* offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00010\000\000 */
{ 2401061 }, /* offcore_response.pf_l3_rfo.l3_hit.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00010\000\000 */
{ 2401564 }, /* offcore_response.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00010\000\000 */
{ 2402068 }, /* offcore_response.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00010\000\000 */
{ 2402594 }, /* offcore_response.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00010\000\000 */
{ 2403151 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8007C0100\000\00010\000\000 */
{ 2403703 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0100\000\00010\000\000 */
{ 2404243 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803C0100\000\00010\000\000 */
{ 2404612 }, /* offcore_response.pf_l3_rfo.l3_hit_e.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80080100\000\00010\000\000 */
{ 2404808 }, /* offcore_response.pf_l3_rfo.l3_hit_e.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800080100\000\00010\000\000 */
{ 2405021 }, /* offcore_response.pf_l3_rfo.l3_hit_e.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080100\000\00010\000\000 */
{ 2405240 }, /* offcore_response.pf_l3_rfo.l3_hit_e.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080100\000\00010\000\000 */
{ 2405448 }, /* offcore_response.pf_l3_rfo.l3_hit_e.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080100\000\00010\000\000 */
{ 2405655 }, /* offcore_response.pf_l3_rfo.l3_hit_e.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080100\000\00010\000\000 */
{ 2405852 }, /* offcore_response.pf_l3_rfo.l3_hit_e.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_E.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080100\000\00010\000\000 */
{ 2406048 }, /* offcore_response.pf_l3_rfo.l3_hit_f.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80200100\000\00010\000\000 */
{ 2406244 }, /* offcore_response.pf_l3_rfo.l3_hit_f.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800200100\000\00010\000\000 */
{ 2406457 }, /* offcore_response.pf_l3_rfo.l3_hit_f.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400200100\000\00010\000\000 */
{ 2406676 }, /* offcore_response.pf_l3_rfo.l3_hit_f.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000200100\000\00010\000\000 */
{ 2406884 }, /* offcore_response.pf_l3_rfo.l3_hit_f.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100200100\000\00010\000\000 */
{ 2407091 }, /* offcore_response.pf_l3_rfo.l3_hit_f.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200200100\000\00010\000\000 */
{ 2407288 }, /* offcore_response.pf_l3_rfo.l3_hit_f.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_F.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80200100\000\00010\000\000 */
{ 2407484 }, /* offcore_response.pf_l3_rfo.l3_hit_m.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80040100\000\00010\000\000 */
{ 2407680 }, /* offcore_response.pf_l3_rfo.l3_hit_m.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800040100\000\00010\000\000 */
{ 2407893 }, /* offcore_response.pf_l3_rfo.l3_hit_m.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040100\000\00010\000\000 */
{ 2408112 }, /* offcore_response.pf_l3_rfo.l3_hit_m.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040100\000\00010\000\000 */
{ 2408320 }, /* offcore_response.pf_l3_rfo.l3_hit_m.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040100\000\00010\000\000 */
{ 2408527 }, /* offcore_response.pf_l3_rfo.l3_hit_m.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040100\000\00010\000\000 */
{ 2408724 }, /* offcore_response.pf_l3_rfo.l3_hit_m.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_M.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040100\000\00010\000\000 */
{ 2408920 }, /* offcore_response.pf_l3_rfo.l3_hit_s.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80100100\000\00010\000\000 */
{ 2409116 }, /* offcore_response.pf_l3_rfo.l3_hit_s.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800100100\000\00010\000\000 */
{ 2409329 }, /* offcore_response.pf_l3_rfo.l3_hit_s.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100100\000\00010\000\000 */
{ 2409548 }, /* offcore_response.pf_l3_rfo.l3_hit_s.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100100\000\00010\000\000 */
{ 2409756 }, /* offcore_response.pf_l3_rfo.l3_hit_s.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100100\000\00010\000\000 */
{ 2409963 }, /* offcore_response.pf_l3_rfo.l3_hit_s.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100100\000\00010\000\000 */
{ 2410160 }, /* offcore_response.pf_l3_rfo.l3_hit_s.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_HIT_S.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100100\000\00010\000\000 */
{ 2419576 }, /* offcore_response.pf_l3_rfo.pmm_hit_local_pmm.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400100\000\00010\000\000 */
{ 2419790 }, /* offcore_response.pf_l3_rfo.pmm_hit_local_pmm.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400100\000\00010\000\000 */
{ 2420004 }, /* offcore_response.pf_l3_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400100\000\00010\000\000 */
{ 2420409 }, /* offcore_response.pf_l3_rfo.supplier_none.any_snoop\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00010\000\000 */
{ 2420615 }, /* offcore_response.pf_l3_rfo.supplier_none.hit_other_core_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020100\000\00010\000\000 */
{ 2420838 }, /* offcore_response.pf_l3_rfo.supplier_none.hit_other_core_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00010\000\000 */
{ 2421067 }, /* offcore_response.pf_l3_rfo.supplier_none.hitm_other_core\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00010\000\000 */
{ 2421285 }, /* offcore_response.pf_l3_rfo.supplier_none.no_snoop_needed\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00010\000\000 */
{ 2422043 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00010\000\000 */
{ 2422611 }, /* offcore_response.pf_l3_rfo.supplier_none.snoop_none\000\000cache\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00010\000\000 */
{ 2531664 }, /* sq_misc.split_lock\000\000cache\000Number of cache line split locks sent to uncore\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the number of cache line split locks sent to the uncore\000 */
{ 2537304 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=2000003,umask=0x1\000\00000\000\000 */
{ 2537950 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=2000003,umask=0x8\000\00000\000\000 */
{ 2538599 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=2000003,umask=0x2\000\00000\000\000 */
{ 2539263 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=2000003,umask=0x4\000\00000\000\000 */
{ 855448 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x4\000\00000\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 858464 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Counts once for most SIMD 128-bit packed computational single precision floating-point instruction retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x8\000\00000\000Counts once for most SIMD 128-bit packed computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 863684 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x10\000\00000\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 867763 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x20\000\00000\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 870832 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 877888 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 881118 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 882208 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 885571 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Counts once for most SIMD scalar computational floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x3\000\00000\000Counts once for most SIMD scalar computational single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891206 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts once for most SIMD scalar computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x1\000\00000\000Counts once for most SIMD scalar computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 894912 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts once for most SIMD scalar computational single precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x2\000\00000\000Counts once for most SIMD scalar computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 899174 }, /* fp_arith_inst_retired2.128bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 512-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x20\000\00000\000Counts once for each Intel AVX-512 computational 512-bit packed BFloat16 floating-point instruction retired. Applies to the ZMM based VDPBF16PS instruction.  Each count represents 64 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000 */
{ 899818 }, /* fp_arith_inst_retired2.256bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 128-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x40\000\00000\000Counts once for each Intel AVX-512 computational 128-bit packed BFloat16 floating-point instruction retired. Applies to the XMM based VDPBF16PS instruction. Each count represents 16 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000 */
{ 900462 }, /* fp_arith_inst_retired2.512bit_packed_bf16\000\000floating point\000Intel AVX-512 computational 256-bit packed BFloat16 instructions retired\000event=0xcf,period=2000003,umask=0x80\000\00000\000Counts once for each Intel AVX-512 computational 256-bit packed BFloat16 floating-point instruction retired. Applies to the YMM based VDPBF16PS instruction.  Each count represents 32 computation operations. This event is only supported on products formerly named Cooper Lake and is not supported on products formerly named Cascade Lake\000 */
{ 901772 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775088 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781493 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000This event counts the number of the Decode Stream Buffer (DSB)-to-MITE switches including all misses because of missing Decode Stream Buffer (DSB) cache and u-arch forced misses.\nNote: Invoking MITE requires two or three cycles delay\000 */
{ 782928 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. MM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.Penalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943451 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000\000 */
{ 944466 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000\000 */
{ 949483 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Must be precise)\000event=0xc6,period=100007,umask=0x1,frontend=0x400106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Must be precise)\000 */
{ 944927 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x408006\000\00000\000\000 */
{ 947148 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x401006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 954352 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400206\000\00000\000\000 */
{ 951387 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x410006\000\00000\000\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 957056 }, /* frontend_retired.latency_ge_2_bubbles_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 2 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x200206\000\00000\000\000 */
{ 957358 }, /* frontend_retired.latency_ge_2_bubbles_ge_3\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 3 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x300206\000\00000\000\000 */
{ 957660 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x402006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 959995 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400406\000\00000\000\000 */
{ 962188 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x420006\000\00000\000\000 */
{ 964409 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x404006\000\00000\000\000 */
{ 966616 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992891 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity\000 */
{ 993527 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000\000 */
{ 994068 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000\000 */
{ 994568 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 996552 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 997882 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.DSB_CYCLES_OK]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_OK]\000 */
{ 998944 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.DSB_CYCLES_ANY]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_ANY]\000 */
{ 1000200 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts the number of cycles 4 uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001450 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002331 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1003527 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000 */
{ 1005201 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000 */
{ 1005996 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1009115 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1011962 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1013663 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1017722 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1022226 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1023696 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025427 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1031951 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when: a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread. b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions).  c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038295 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when less than 1 uop is delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >= 3\000 */
{ 1039505 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles with less than 2 uops delivered by the front-end\000 */
{ 1040076 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with less than 3 uops delivered by the front-end\000 */
{ 751900 }, /* cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 757696 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 970825 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 971725 }, /* hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000\000 */
{ 972195 }, /* hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000 */
{ 972380 }, /* hle_retired.aborted_memtype\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times an HLE execution aborted due to incompatible memory type\000 */
{ 974679 }, /* hle_retired.aborted_timer\000\000memory\000Number of times an HLE execution aborted due to hardware timer expiration\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000 */
{ 975183 }, /* hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000 */
{ 975707 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976185 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region. Does not count nested transactions\000 */
{ 1293986 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts  Spec update: SKL089\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:a. memory disambiguation,b. external snoop, orc. cross SMT-HW-thread snoop (stores) hitting load buffer  Spec update: SKL089\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1449914 }, /* ocr.all_data_rd.l3_miss.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00000\000\000 */
{ 1450123 }, /* ocr.all_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000491\000\00000\000\000 */
{ 1450367 }, /* ocr.all_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000491\000\00000\000\000 */
{ 1450623 }, /* ocr.all_data_rd.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000491\000\00000\000\000 */
{ 1450856 }, /* ocr.all_data_rd.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000491\000\00000\000\000 */
{ 1451088 }, /* ocr.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00000\000\000 */
{ 1451289 }, /* ocr.all_data_rd.l3_miss.remote_hitm\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00000\000\000 */
{ 1451470 }, /* ocr.all_data_rd.l3_miss.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000491\000\00000\000\000 */
{ 1451647 }, /* ocr.all_data_rd.l3_miss.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000491\000\00000\000\000 */
{ 1451823 }, /* ocr.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000491\000\00000\000\000 */
{ 1452032 }, /* ocr.all_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000491\000\00000\000\000 */
{ 1452267 }, /* ocr.all_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000491\000\00000\000\000 */
{ 1452511 }, /* ocr.all_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000491\000\00000\000\000 */
{ 1452738 }, /* ocr.all_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000491\000\00000\000\000 */
{ 1452964 }, /* ocr.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000491\000\00000\000\000 */
{ 1453128 }, /* ocr.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00000\000\000 */
{ 1453368 }, /* ocr.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000491\000\00000\000\000 */
{ 1453531 }, /* ocr.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00000\000\000 */
{ 1453774 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000491\000\00000\000\000 */
{ 1454001 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000491\000\00000\000\000 */
{ 1454254 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000491\000\00000\000\000 */
{ 1454516 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000491\000\00000\000\000 */
{ 1454761 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000491\000\00000\000\000 */
{ 1455005 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000491\000\00000\000\000 */
{ 1455181 }, /* ocr.all_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000491\000\00000\000\000 */
{ 1464554 }, /* ocr.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00000\000\000 */
{ 1464775 }, /* ocr.all_pf_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000490\000\00000\000\000 */
{ 1465031 }, /* ocr.all_pf_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000490\000\00000\000\000 */
{ 1465299 }, /* ocr.all_pf_data_rd.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000490\000\00000\000\000 */
{ 1465544 }, /* ocr.all_pf_data_rd.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000490\000\00000\000\000 */
{ 1465788 }, /* ocr.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00000\000\000 */
{ 1465998 }, /* ocr.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00000\000\000 */
{ 1466188 }, /* ocr.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000490\000\00000\000\000 */
{ 1466374 }, /* ocr.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000490\000\00000\000\000 */
{ 1466559 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000490\000\00000\000\000 */
{ 1466777 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000490\000\00000\000\000 */
{ 1467021 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000490\000\00000\000\000 */
{ 1467274 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000490\000\00000\000\000 */
{ 1467510 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000490\000\00000\000\000 */
{ 1467745 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000490\000\00000\000\000 */
{ 1467915 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00000\000\000 */
{ 1468164 }, /* ocr.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000490\000\00000\000\000 */
{ 1468333 }, /* ocr.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00000\000\000 */
{ 1468585 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000490\000\00000\000\000 */
{ 1468821 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000490\000\00000\000\000 */
{ 1469083 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000490\000\00000\000\000 */
{ 1469354 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000490\000\00000\000\000 */
{ 1469608 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000490\000\00000\000\000 */
{ 1469861 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000490\000\00000\000\000 */
{ 1470043 }, /* ocr.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000490\000\00000\000\000 */
{ 1479082 }, /* ocr.all_pf_rfo.l3_miss.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00000\000\000 */
{ 1479287 }, /* ocr.all_pf_rfo.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000120\000\00000\000\000 */
{ 1479527 }, /* ocr.all_pf_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00000\000\000 */
{ 1479779 }, /* ocr.all_pf_rfo.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000120\000\00000\000\000 */
{ 1480008 }, /* ocr.all_pf_rfo.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00000\000\000 */
{ 1480236 }, /* ocr.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00000\000\000 */
{ 1480434 }, /* ocr.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00000\000\000 */
{ 1480612 }, /* ocr.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00000\000\000 */
{ 1480786 }, /* ocr.all_pf_rfo.l3_miss.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00000\000\000 */
{ 1480959 }, /* ocr.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00000\000\000 */
{ 1481165 }, /* ocr.all_pf_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000120\000\00000\000\000 */
{ 1481397 }, /* ocr.all_pf_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00000\000\000 */
{ 1481638 }, /* ocr.all_pf_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00000\000\000 */
{ 1481862 }, /* ocr.all_pf_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00000\000\000 */
{ 1482085 }, /* ocr.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00000\000\000 */
{ 1482247 }, /* ocr.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00000\000\000 */
{ 1482484 }, /* ocr.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00000\000\000 */
{ 1482645 }, /* ocr.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00000\000\000 */
{ 1482885 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000120\000\00000\000\000 */
{ 1483109 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000120\000\00000\000\000 */
{ 1483359 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000120\000\00000\000\000 */
{ 1483618 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000120\000\00000\000\000 */
{ 1483860 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000120\000\00000\000\000 */
{ 1484101 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000120\000\00000\000\000 */
{ 1484275 }, /* ocr.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000120\000\00000\000\000 */
{ 1493088 }, /* ocr.all_reads.l3_miss.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS.ANY_SNOOP OCR.ALL_READS.L3_MISS.ANY_SNOOP OCR.ALL_READS.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC0007F7\000\00000\000\000 */
{ 1493289 }, /* ocr.all_reads.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C0007F7\000\00000\000\000 */
{ 1493525 }, /* ocr.all_reads.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C0007F7\000\00000\000\000 */
{ 1493773 }, /* ocr.all_reads.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C0007F7\000\00000\000\000 */
{ 1493998 }, /* ocr.all_reads.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C0007F7\000\00000\000\000 */
{ 1494222 }, /* ocr.all_reads.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00000\000\000 */
{ 1494417 }, /* ocr.all_reads.l3_miss.remote_hitm\000\000memory\000OCR.ALL_READS.L3_MISS.REMOTE_HITM OCR.ALL_READS.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00000\000\000 */
{ 1494592 }, /* ocr.all_reads.l3_miss.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS.SNOOP_MISS OCR.ALL_READS.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C0007F7\000\00000\000\000 */
{ 1494763 }, /* ocr.all_reads.l3_miss.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS.SNOOP_NONE OCR.ALL_READS.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC0007F7\000\00000\000\000 */
{ 1494933 }, /* ocr.all_reads.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F840007F7\000\00000\000\000 */
{ 1495136 }, /* ocr.all_reads.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8040007F7\000\00000\000\000 */
{ 1495365 }, /* ocr.all_reads.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4040007F7\000\00000\000\000 */
{ 1495603 }, /* ocr.all_reads.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040007F7\000\00000\000\000 */
{ 1495824 }, /* ocr.all_reads.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1040007F7\000\00000\000\000 */
{ 1496044 }, /* ocr.all_reads.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2040007F7\000\00000\000\000 */
{ 1496204 }, /* ocr.all_reads.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00000\000\000 */
{ 1496438 }, /* ocr.all_reads.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x840007F7\000\00000\000\000 */
{ 1496597 }, /* ocr.all_reads.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B8007F7\000\00000\000\000 */
{ 1496834 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F900007F7\000\00000\000\000 */
{ 1497055 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8100007F7\000\00000\000\000 */
{ 1497302 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4100007F7\000\00000\000\000 */
{ 1497558 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100007F7\000\00000\000\000 */
{ 1497797 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1100007F7\000\00000\000\000 */
{ 1498035 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2100007F7\000\00000\000\000 */
{ 1498207 }, /* ocr.all_reads.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x900007F7\000\00000\000\000 */
{ 1506778 }, /* ocr.all_rfo.l3_miss.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS.ANY_SNOOP OCR.ALL_RFO.L3_MISS.ANY_SNOOP OCR.ALL_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00000\000\000 */
{ 1506971 }, /* ocr.all_rfo.l3_miss.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000122\000\00000\000\000 */
{ 1507199 }, /* ocr.all_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00000\000\000 */
{ 1507439 }, /* ocr.all_rfo.l3_miss.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000122\000\00000\000\000 */
{ 1507656 }, /* ocr.all_rfo.l3_miss.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00000\000\000 */
{ 1507872 }, /* ocr.all_rfo.l3_miss.remote_hit_forward\000\000memory\000OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00000\000\000 */
{ 1508061 }, /* ocr.all_rfo.l3_miss.remote_hitm\000\000memory\000OCR.ALL_RFO.L3_MISS.REMOTE_HITM OCR.ALL_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00000\000\000 */
{ 1508230 }, /* ocr.all_rfo.l3_miss.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS.SNOOP_MISS OCR.ALL_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00000\000\000 */
{ 1508395 }, /* ocr.all_rfo.l3_miss.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS.SNOOP_NONE OCR.ALL_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00000\000\000 */
{ 1508559 }, /* ocr.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00000\000\000 */
{ 1508756 }, /* ocr.all_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000122\000\00000\000\000 */
{ 1508979 }, /* ocr.all_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00000\000\000 */
{ 1509211 }, /* ocr.all_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00000\000\000 */
{ 1509426 }, /* ocr.all_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00000\000\000 */
{ 1509640 }, /* ocr.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00000\000\000 */
{ 1509796 }, /* ocr.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000 */
{ 1510024 }, /* ocr.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00000\000\000 */
{ 1510179 }, /* ocr.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00000\000\000 */
{ 1510410 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000122\000\00000\000\000 */
{ 1510625 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000122\000\00000\000\000 */
{ 1510866 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000122\000\00000\000\000 */
{ 1511116 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000122\000\00000\000\000 */
{ 1511349 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED  OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000122\000\00000\000\000 */
{ 1511581 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000122\000\00000\000\000 */
{ 1511749 }, /* ocr.all_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000122\000\00000\000\000 */
{ 1527314 }, /* ocr.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00000\000\000 */
{ 1527527 }, /* ocr.demand_code_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000004\000\00000\000\000 */
{ 1527766 }, /* ocr.demand_code_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00000\000\000 */
{ 1528014 }, /* ocr.demand_code_rd.l3_miss.hitm_other_core\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000004\000\00000\000\000 */
{ 1528245 }, /* ocr.demand_code_rd.l3_miss.no_snoop_needed\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00000\000\000 */
{ 1528475 }, /* ocr.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00000\000\000 */
{ 1528668 }, /* ocr.demand_code_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00000\000\000 */
{ 1528848 }, /* ocr.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00000\000\000 */
{ 1529025 }, /* ocr.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00000\000\000 */
{ 1530582 }, /* ocr.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00000\000\000 */
{ 1530781 }, /* ocr.demand_code_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000004\000\00000\000\000 */
{ 1530997 }, /* ocr.demand_code_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00000\000\000 */
{ 1531219 }, /* ocr.demand_code_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00000\000\000 */
{ 1531430 }, /* ocr.demand_code_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000 */
{ 1531640 }, /* ocr.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00000\000\000 */
{ 1531790 }, /* ocr.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00000\000\000 */
{ 1532009 }, /* ocr.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00000\000\000 */
{ 1532158 }, /* ocr.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00000\000\000 */
{ 1532379 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000004\000\00000\000\000 */
{ 1532590 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000004\000\00000\000\000 */
{ 1532818 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000004\000\00000\000\000 */
{ 1533052 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000004\000\00000\000\000 */
{ 1533275 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all demand code reads  OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000004\000\00000\000\000 */
{ 1533497 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000004\000\00000\000\000 */
{ 1533653 }, /* ocr.demand_code_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000004\000\00000\000\000 */
{ 1557427 }, /* ocr.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00000\000\000 */
{ 1557636 }, /* ocr.demand_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000001\000\00000\000\000 */
{ 1557871 }, /* ocr.demand_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00000\000\000 */
{ 1558115 }, /* ocr.demand_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000001\000\00000\000\000 */
{ 1558342 }, /* ocr.demand_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00000\000\000 */
{ 1558568 }, /* ocr.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00000\000\000 */
{ 1558757 }, /* ocr.demand_data_rd.l3_miss.remote_hitm\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00000\000\000 */
{ 1558933 }, /* ocr.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00000\000\000 */
{ 1559106 }, /* ocr.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00000\000\000 */
{ 1561500 }, /* ocr.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00000\000\000 */
{ 1561695 }, /* ocr.demand_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000001\000\00000\000\000 */
{ 1561907 }, /* ocr.demand_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00000\000\000 */
{ 1562125 }, /* ocr.demand_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00000\000\000 */
{ 1562332 }, /* ocr.demand_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 1562538 }, /* ocr.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00000\000\000 */
{ 1562684 }, /* ocr.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00000\000\000 */
{ 1562899 }, /* ocr.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00000\000\000 */
{ 1563044 }, /* ocr.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00000\000\000 */
{ 1563261 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000001\000\00000\000\000 */
{ 1563468 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000001\000\00000\000\000 */
{ 1563692 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000001\000\00000\000\000 */
{ 1563922 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000001\000\00000\000\000 */
{ 1564141 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts demand data reads  OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000001\000\00000\000\000 */
{ 1564359 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000001\000\00000\000\000 */
{ 1564511 }, /* ocr.demand_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000001\000\00000\000\000 */
{ 1586889 }, /* ocr.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00000\000\000 */
{ 1587098 }, /* ocr.demand_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000002\000\00000\000\000 */
{ 1587333 }, /* ocr.demand_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00000\000\000 */
{ 1587577 }, /* ocr.demand_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000002\000\00000\000\000 */
{ 1587804 }, /* ocr.demand_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00000\000\000 */
{ 1588030 }, /* ocr.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00000\000\000 */
{ 1588223 }, /* ocr.demand_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000 */
{ 1588403 }, /* ocr.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00000\000\000 */
{ 1588580 }, /* ocr.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00000\000\000 */
{ 1591837 }, /* ocr.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00000\000\000 */
{ 1592036 }, /* ocr.demand_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000002\000\00000\000\000 */
{ 1592252 }, /* ocr.demand_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00000\000\000 */
{ 1592474 }, /* ocr.demand_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00000\000\000 */
{ 1592685 }, /* ocr.demand_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000 */
{ 1592895 }, /* ocr.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00000\000\000 */
{ 1593049 }, /* ocr.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00000\000\000 */
{ 1593268 }, /* ocr.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000 */
{ 1593421 }, /* ocr.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00000\000\000 */
{ 1593642 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000002\000\00000\000\000 */
{ 1593853 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000002\000\00000\000\000 */
{ 1594081 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000002\000\00000\000\000 */
{ 1594315 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000002\000\00000\000\000 */
{ 1594538 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000002\000\00000\000\000 */
{ 1594760 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000002\000\00000\000\000 */
{ 1594920 }, /* ocr.demand_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00000\000\000 */
{ 1631984 }, /* ocr.other.l3_miss.any_snoop\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.ANY_SNOOP OCR.OTHER.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC008000\000\00000\000\000 */
{ 1632167 }, /* ocr.other.l3_miss.hit_other_core_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C008000\000\00000\000\000 */
{ 1632376 }, /* ocr.other.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00000\000\000 */
{ 1632594 }, /* ocr.other.l3_miss.hitm_other_core\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.HITM_OTHER_CORE OCR.OTHER.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C008000\000\00000\000\000 */
{ 1632795 }, /* ocr.other.l3_miss.no_snoop_needed\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00000\000\000 */
{ 1632995 }, /* ocr.other.l3_miss.remote_hit_forward\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC08000\000\00000\000\000 */
{ 1633167 }, /* ocr.other.l3_miss.remote_hitm\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC08000\000\00000\000\000 */
{ 1633326 }, /* ocr.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00000\000\000 */
{ 1633482 }, /* ocr.other.l3_miss.snoop_none\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00000\000\000 */
{ 1634700 }, /* ocr.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00000\000\000 */
{ 1634878 }, /* ocr.other.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804008000\000\00000\000\000 */
{ 1635073 }, /* ocr.other.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00000\000\000 */
{ 1635274 }, /* ocr.other.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00000\000\000 */
{ 1635464 }, /* ocr.other.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00000\000\000 */
{ 1635653 }, /* ocr.other.l3_miss_local_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00000\000\000 */
{ 1635791 }, /* ocr.other.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604008000\000\00000\000\000 */
{ 1635989 }, /* ocr.other.l3_miss_local_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00000\000\000 */
{ 1636126 }, /* ocr.other.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts any other requests OCR.OTHER.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B808000\000\00000\000\000 */
{ 1636326 }, /* ocr.other.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90008000\000\00000\000\000 */
{ 1636516 }, /* ocr.other.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810008000\000\00000\000\000 */
{ 1636723 }, /* ocr.other.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410008000\000\00000\000\000 */
{ 1636936 }, /* ocr.other.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010008000\000\00000\000\000 */
{ 1637138 }, /* ocr.other.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts any other requests  OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110008000\000\00000\000\000 */
{ 1637339 }, /* ocr.other.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210008000\000\00000\000\000 */
{ 1637483 }, /* ocr.other.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90008000\000\00000\000\000 */
{ 1648863 }, /* ocr.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00000\000\000 */
{ 1649123 }, /* ocr.pf_l1d_and_sw.l3_miss.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000400\000\00000\000\000 */
{ 1649409 }, /* ocr.pf_l1d_and_sw.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000400\000\00000\000\000 */
{ 1649704 }, /* ocr.pf_l1d_and_sw.l3_miss.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000400\000\00000\000\000 */
{ 1649982 }, /* ocr.pf_l1d_and_sw.l3_miss.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000400\000\00000\000\000 */
{ 1650259 }, /* ocr.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00000\000\000 */
{ 1650500 }, /* ocr.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00000\000\000 */
{ 1650728 }, /* ocr.pf_l1d_and_sw.l3_miss.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000400\000\00000\000\000 */
{ 1650953 }, /* ocr.pf_l1d_and_sw.l3_miss.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000400\000\00000\000\000 */
{ 1651177 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000400\000\00000\000\000 */
{ 1651424 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000400\000\00000\000\000 */
{ 1651688 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000400\000\00000\000\000 */
{ 1651958 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000400\000\00000\000\000 */
{ 1652217 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00000\000\000 */
{ 1652475 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000400\000\00000\000\000 */
{ 1652674 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00000\000\000 */
{ 1652941 }, /* ocr.pf_l1d_and_sw.l3_miss_local_dram.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000400\000\00000\000\000 */
{ 1653139 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00000\000\000 */
{ 1653408 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000400\000\00000\000\000 */
{ 1653667 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000400\000\00000\000\000 */
{ 1653943 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000400\000\00000\000\000 */
{ 1654225 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000400\000\00000\000\000 */
{ 1654496 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000400\000\00000\000\000 */
{ 1654766 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000400\000\00000\000\000 */
{ 1654971 }, /* ocr.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000400\000\00000\000\000 */
{ 1664994 }, /* ocr.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00000\000\000 */
{ 1665226 }, /* ocr.pf_l2_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000010\000\00000\000\000 */
{ 1665484 }, /* ocr.pf_l2_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00000\000\000 */
{ 1665751 }, /* ocr.pf_l2_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000010\000\00000\000\000 */
{ 1666001 }, /* ocr.pf_l2_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00000\000\000 */
{ 1666250 }, /* ocr.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00000\000\000 */
{ 1666463 }, /* ocr.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00000\000\000 */
{ 1666663 }, /* ocr.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00000\000\000 */
{ 1666860 }, /* ocr.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00000\000\000 */
{ 1667056 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00000\000\000 */
{ 1667275 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000010\000\00000\000\000 */
{ 1667511 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00000\000\000 */
{ 1667753 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00000\000\000 */
{ 1667984 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00000\000\000 */
{ 1668214 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00000\000\000 */
{ 1668385 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00000\000\000 */
{ 1668624 }, /* ocr.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00000\000\000 */
{ 1668794 }, /* ocr.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00000\000\000 */
{ 1669035 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000010\000\00000\000\000 */
{ 1669266 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000010\000\00000\000\000 */
{ 1669514 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000010\000\00000\000\000 */
{ 1669768 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000010\000\00000\000\000 */
{ 1670011 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000010\000\00000\000\000 */
{ 1670253 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000010\000\00000\000\000 */
{ 1670430 }, /* ocr.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000010\000\00000\000\000 */
{ 1679795 }, /* ocr.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00000\000\000 */
{ 1680013 }, /* ocr.pf_l2_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000020\000\00000\000\000 */
{ 1680257 }, /* ocr.pf_l2_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00000\000\000 */
{ 1680510 }, /* ocr.pf_l2_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000020\000\00000\000\000 */
{ 1680746 }, /* ocr.pf_l2_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00000\000\000 */
{ 1680981 }, /* ocr.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00000\000\000 */
{ 1681184 }, /* ocr.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00000\000\000 */
{ 1681374 }, /* ocr.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00000\000\000 */
{ 1681561 }, /* ocr.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00000\000\000 */
{ 1681747 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00000\000\000 */
{ 1681956 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000020\000\00000\000\000 */
{ 1682182 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00000\000\000 */
{ 1682414 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00000\000\000 */
{ 1682635 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00000\000\000 */
{ 1682855 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00000\000\000 */
{ 1683020 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00000\000\000 */
{ 1683249 }, /* ocr.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00000\000\000 */
{ 1683413 }, /* ocr.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00000\000\000 */
{ 1683644 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000020\000\00000\000\000 */
{ 1683865 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000020\000\00000\000\000 */
{ 1684103 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000020\000\00000\000\000 */
{ 1684347 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000020\000\00000\000\000 */
{ 1684580 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000020\000\00000\000\000 */
{ 1684812 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000020\000\00000\000\000 */
{ 1684983 }, /* ocr.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000020\000\00000\000\000 */
{ 1694970 }, /* ocr.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00000\000\000 */
{ 1695212 }, /* ocr.pf_l3_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000080\000\00000\000\000 */
{ 1695480 }, /* ocr.pf_l3_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00000\000\000 */
{ 1695757 }, /* ocr.pf_l3_data_rd.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000080\000\00000\000\000 */
{ 1696017 }, /* ocr.pf_l3_data_rd.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00000\000\000 */
{ 1696276 }, /* ocr.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00000\000\000 */
{ 1696499 }, /* ocr.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00000\000\000 */
{ 1696709 }, /* ocr.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00000\000\000 */
{ 1696916 }, /* ocr.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00000\000\000 */
{ 1697122 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00000\000\000 */
{ 1697351 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000080\000\00000\000\000 */
{ 1697597 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00000\000\000 */
{ 1697849 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00000\000\000 */
{ 1698090 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00000\000\000 */
{ 1698330 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00000\000\000 */
{ 1698511 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00000\000\000 */
{ 1698760 }, /* ocr.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00000\000\000 */
{ 1698940 }, /* ocr.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00000\000\000 */
{ 1699191 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000080\000\00000\000\000 */
{ 1699432 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000080\000\00000\000\000 */
{ 1699690 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000080\000\00000\000\000 */
{ 1699954 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000080\000\00000\000\000 */
{ 1700207 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000080\000\00000\000\000 */
{ 1700459 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000080\000\00000\000\000 */
{ 1700646 }, /* ocr.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000080\000\00000\000\000 */
{ 1710343 }, /* ocr.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00000\000\000 */
{ 1710567 }, /* ocr.pf_l3_rfo.l3_miss.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000100\000\00000\000\000 */
{ 1710817 }, /* ocr.pf_l3_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00000\000\000 */
{ 1711076 }, /* ocr.pf_l3_rfo.l3_miss.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000100\000\00000\000\000 */
{ 1711318 }, /* ocr.pf_l3_rfo.l3_miss.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00000\000\000 */
{ 1711559 }, /* ocr.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00000\000\000 */
{ 1711768 }, /* ocr.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00000\000\000 */
{ 1711964 }, /* ocr.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00000\000\000 */
{ 1712157 }, /* ocr.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00000\000\000 */
{ 1712349 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00000\000\000 */
{ 1712564 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000100\000\00000\000\000 */
{ 1712796 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00000\000\000 */
{ 1713034 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00000\000\000 */
{ 1713261 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00000\000\000 */
{ 1713487 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00000\000\000 */
{ 1713658 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00000\000\000 */
{ 1713893 }, /* ocr.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00000\000\000 */
{ 1714063 }, /* ocr.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00000\000\000 */
{ 1714300 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000100\000\00000\000\000 */
{ 1714527 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000100\000\00000\000\000 */
{ 1714771 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000100\000\00000\000\000 */
{ 1715021 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000100\000\00000\000\000 */
{ 1715260 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000100\000\00000\000\000 */
{ 1715498 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000100\000\00000\000\000 */
{ 1715675 }, /* ocr.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000100\000\00000\000\000 */
{ 1752561 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Demand Data Read requests who miss L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000Demand Data Read requests who miss L3 cache\000 */
{ 1768551 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles with at least 1 Demand Data Read requests who miss L3 cache in the superQ\000event=0x60,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1778719 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000Counts number of Offcore outstanding Demand Data Read requests that miss L3 cache in the superQ every cycle\000event=0x60,period=2000003,umask=0x10\000\00000\000\000 */
{ 1780659 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles with at least 6 Demand Data Read requests that miss L3 cache in the superQ\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000\000 */
{ 1795783 }, /* offcore_response.all_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00010\000\000 */
{ 1795982 }, /* offcore_response.all_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000491\000\00010\000\000 */
{ 1796198 }, /* offcore_response.all_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000491\000\00010\000\000 */
{ 1796420 }, /* offcore_response.all_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000491\000\00010\000\000 */
{ 1796844 }, /* offcore_response.all_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000491\000\00010\000\000 */
{ 1797297 }, /* offcore_response.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00010\000\000 */
{ 1797747 }, /* offcore_response.all_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00010\000\000 */
{ 1798276 }, /* offcore_response.all_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000491\000\00010\000\000 */
{ 1798873 }, /* offcore_response.all_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000491\000\00010\000\000 */
{ 1799409 }, /* offcore_response.all_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000491\000\00010\000\000 */
{ 1799630 }, /* offcore_response.all_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000491\000\00010\000\000 */
{ 1799868 }, /* offcore_response.all_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000491\000\00010\000\000 */
{ 1800112 }, /* offcore_response.all_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000491\000\00010\000\000 */
{ 1800345 }, /* offcore_response.all_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000491\000\00010\000\000 */
{ 1801097 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000491\000\00010\000\000 */
{ 1801558 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00010\000\000 */
{ 1802146 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000491\000\00010\000\000 */
{ 1802785 }, /* offcore_response.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00010\000\000 */
{ 1803029 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000491\000\00010\000\000 */
{ 1803262 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000491\000\00010\000\000 */
{ 1803512 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000491\000\00010\000\000 */
{ 1803768 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000491\000\00010\000\000 */
{ 1804013 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000491\000\00010\000\000 */
{ 1804257 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000491\000\00010\000\000 */
{ 1804491 }, /* offcore_response.all_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000491\000\00010\000\000 */
{ 1829352 }, /* offcore_response.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00010\000\000 */
{ 1829557 }, /* offcore_response.all_pf_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000490\000\00010\000\000 */
{ 1829779 }, /* offcore_response.all_pf_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000490\000\00010\000\000 */
{ 1830007 }, /* offcore_response.all_pf_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000490\000\00010\000\000 */
{ 1830224 }, /* offcore_response.all_pf_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000490\000\00010\000\000 */
{ 1830677 }, /* offcore_response.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00010\000\000 */
{ 1831127 }, /* offcore_response.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00010\000\000 */
{ 1831650 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000490\000\00010\000\000 */
{ 1832241 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000490\000\00010\000\000 */
{ 1832771 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000490\000\00010\000\000 */
{ 1832998 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000490\000\00010\000\000 */
{ 1833242 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000490\000\00010\000\000 */
{ 1833492 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000490\000\00010\000\000 */
{ 1833731 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000490\000\00010\000\000 */
{ 1834471 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000490\000\00010\000\000 */
{ 1834932 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00010\000\000 */
{ 1835514 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000490\000\00010\000\000 */
{ 1836147 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00010\000\000 */
{ 1836397 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000490\000\00010\000\000 */
{ 1836636 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000490\000\00010\000\000 */
{ 1836892 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000490\000\00010\000\000 */
{ 1837154 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000490\000\00010\000\000 */
{ 1837405 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000490\000\00010\000\000 */
{ 1837655 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000490\000\00010\000\000 */
{ 1837895 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000490\000\00010\000\000 */
{ 1853565 }, /* offcore_response.all_pf_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00010\000\000 */
{ 1853762 }, /* offcore_response.all_pf_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000120\000\00010\000\000 */
{ 1853976 }, /* offcore_response.all_pf_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000120\000\00010\000\000 */
{ 1854196 }, /* offcore_response.all_pf_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000120\000\00010\000\000 */
{ 1854405 }, /* offcore_response.all_pf_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000120\000\00010\000\000 */
{ 1854836 }, /* offcore_response.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00010\000\000 */
{ 1855264 }, /* offcore_response.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00010\000\000 */
{ 1855751 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000120\000\00010\000\000 */
{ 1856306 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000120\000\00010\000\000 */
{ 1856800 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000120\000\00010\000\000 */
{ 1857019 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000120\000\00010\000\000 */
{ 1857255 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000120\000\00010\000\000 */
{ 1857497 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000120\000\00010\000\000 */
{ 1857728 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000120\000\00010\000\000 */
{ 1858418 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000120\000\00010\000\000 */
{ 1858857 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00010\000\000 */
{ 1859403 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000120\000\00010\000\000 */
{ 1860000 }, /* offcore_response.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00010\000\000 */
{ 1860242 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000120\000\00010\000\000 */
{ 1860473 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000120\000\00010\000\000 */
{ 1860721 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000120\000\00010\000\000 */
{ 1860975 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000120\000\00010\000\000 */
{ 1861218 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000120\000\00010\000\000 */
{ 1861460 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000120\000\00010\000\000 */
{ 1861692 }, /* offcore_response.all_pf_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_PF_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000120\000\00010\000\000 */
{ 1874981 }, /* offcore_response.all_reads.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC0007F7\000\00010\000\000 */
{ 1875176 }, /* offcore_response.all_reads.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C0007F7\000\00010\000\000 */
{ 1875388 }, /* offcore_response.all_reads.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C0007F7\000\00010\000\000 */
{ 1875606 }, /* offcore_response.all_reads.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C0007F7\000\00010\000\000 */
{ 1875984 }, /* offcore_response.all_reads.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C0007F7\000\00010\000\000 */
{ 1876190 }, /* offcore_response.all_reads.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00010\000\000 */
{ 1876402 }, /* offcore_response.all_reads.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00010\000\000 */
{ 1876601 }, /* offcore_response.all_reads.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C0007F7\000\00010\000\000 */
{ 1876797 }, /* offcore_response.all_reads.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC0007F7\000\00010\000\000 */
{ 1876992 }, /* offcore_response.all_reads.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F840007F7\000\00010\000\000 */
{ 1877209 }, /* offcore_response.all_reads.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8040007F7\000\00010\000\000 */
{ 1877443 }, /* offcore_response.all_reads.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4040007F7\000\00010\000\000 */
{ 1877683 }, /* offcore_response.all_reads.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040007F7\000\00010\000\000 */
{ 1877912 }, /* offcore_response.all_reads.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1040007F7\000\00010\000\000 */
{ 1878140 }, /* offcore_response.all_reads.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2040007F7\000\00010\000\000 */
{ 1878358 }, /* offcore_response.all_reads.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6040007F7\000\00010\000\000 */
{ 1878596 }, /* offcore_response.all_reads.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x840007F7\000\00010\000\000 */
{ 1878813 }, /* offcore_response.all_reads.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B8007F7\000\00010\000\000 */
{ 1879053 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F900007F7\000\00010\000\000 */
{ 1879282 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8100007F7\000\00010\000\000 */
{ 1879528 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4100007F7\000\00010\000\000 */
{ 1879780 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100007F7\000\00010\000\000 */
{ 1880021 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1100007F7\000\00010\000\000 */
{ 1880261 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2100007F7\000\00010\000\000 */
{ 1880491 }, /* offcore_response.all_reads.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_READS.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x900007F7\000\00010\000\000 */
{ 1900578 }, /* offcore_response.all_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00010\000\000 */
{ 1900769 }, /* offcore_response.all_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000122\000\00010\000\000 */
{ 1900977 }, /* offcore_response.all_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000122\000\00010\000\000 */
{ 1901191 }, /* offcore_response.all_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000122\000\00010\000\000 */
{ 1901597 }, /* offcore_response.all_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000122\000\00010\000\000 */
{ 1902032 }, /* offcore_response.all_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00010\000\000 */
{ 1902464 }, /* offcore_response.all_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00010\000\000 */
{ 1902965 }, /* offcore_response.all_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000122\000\00010\000\000 */
{ 1903534 }, /* offcore_response.all_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000122\000\00010\000\000 */
{ 1904042 }, /* offcore_response.all_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000122\000\00010\000\000 */
{ 1904255 }, /* offcore_response.all_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000122\000\00010\000\000 */
{ 1904485 }, /* offcore_response.all_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000122\000\00010\000\000 */
{ 1904721 }, /* offcore_response.all_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000122\000\00010\000\000 */
{ 1904946 }, /* offcore_response.all_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000122\000\00010\000\000 */
{ 1905660 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000122\000\00010\000\000 */
{ 1906103 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00010\000\000 */
{ 1906663 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000122\000\00010\000\000 */
{ 1907274 }, /* offcore_response.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00010\000\000 */
{ 1907510 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000122\000\00010\000\000 */
{ 1907735 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000122\000\00010\000\000 */
{ 1907977 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000122\000\00010\000\000 */
{ 1908225 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000122\000\00010\000\000 */
{ 1908462 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000122\000\00010\000\000 */
{ 1908698 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000122\000\00010\000\000 */
{ 1908924 }, /* offcore_response.all_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.ALL_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000122\000\00010\000\000 */
{ 2050884 }, /* offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00010\000\000 */
{ 2051089 }, /* offcore_response.demand_code_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000004\000\00010\000\000 */
{ 2051311 }, /* offcore_response.demand_code_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000004\000\00010\000\000 */
{ 2051539 }, /* offcore_response.demand_code_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000004\000\00010\000\000 */
{ 2051961 }, /* offcore_response.demand_code_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000004\000\00010\000\000 */
{ 2052412 }, /* offcore_response.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00010\000\000 */
{ 2052860 }, /* offcore_response.demand_code_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00010\000\000 */
{ 2053842 }, /* offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000004\000\00010\000\000 */
{ 2054737 }, /* offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000004\000\00010\000\000 */
{ 2055732 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000004\000\00010\000\000 */
{ 2055959 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000004\000\00010\000\000 */
{ 2056203 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00010\000\000 */
{ 2056453 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00010\000\000 */
{ 2056692 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00010\000\000 */
{ 2057426 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00010\000\000 */
{ 2057885 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00010\000\000 */
{ 2058463 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00010\000\000 */
{ 2059251 }, /* offcore_response.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00010\000\000 */
{ 2059501 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000004\000\00010\000\000 */
{ 2059740 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000004\000\00010\000\000 */
{ 2059996 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000004\000\00010\000\000 */
{ 2060258 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000004\000\00010\000\000 */
{ 2060509 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000004\000\00010\000\000 */
{ 2060759 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000004\000\00010\000\000 */
{ 2060999 }, /* offcore_response.demand_code_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_CODE_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000004\000\00010\000\000 */
{ 2104614 }, /* offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00010\000\000 */
{ 2104819 }, /* offcore_response.demand_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000001\000\00010\000\000 */
{ 2105041 }, /* offcore_response.demand_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000001\000\00010\000\000 */
{ 2105269 }, /* offcore_response.demand_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000001\000\00010\000\000 */
{ 2105687 }, /* offcore_response.demand_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000001\000\00010\000\000 */
{ 2106134 }, /* offcore_response.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00010\000\000 */
{ 2106578 }, /* offcore_response.demand_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00010\000\000 */
{ 2107540 }, /* offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000001\000\00010\000\000 */
{ 2108419 }, /* offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000001\000\00010\000\000 */
{ 2109394 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000001\000\00010\000\000 */
{ 2109621 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000001\000\00010\000\000 */
{ 2109865 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00010\000\000 */
{ 2110115 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00010\000\000 */
{ 2110354 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00010\000\000 */
{ 2111076 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00010\000\000 */
{ 2111531 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00010\000\000 */
{ 2112101 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00010\000\000 */
{ 2112877 }, /* offcore_response.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00010\000\000 */
{ 2113127 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000001\000\00010\000\000 */
{ 2113366 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000001\000\00010\000\000 */
{ 2113622 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000001\000\00010\000\000 */
{ 2113884 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000001\000\00010\000\000 */
{ 2114135 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000001\000\00010\000\000 */
{ 2114385 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000001\000\00010\000\000 */
{ 2114625 }, /* offcore_response.demand_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000001\000\00010\000\000 */
{ 2163472 }, /* offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00010\000\000 */
{ 2163669 }, /* offcore_response.demand_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000002\000\00010\000\000 */
{ 2163883 }, /* offcore_response.demand_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000002\000\00010\000\000 */
{ 2164103 }, /* offcore_response.demand_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000002\000\00010\000\000 */
{ 2164521 }, /* offcore_response.demand_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000002\000\00010\000\000 */
{ 2164968 }, /* offcore_response.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00010\000\000 */
{ 2165412 }, /* offcore_response.demand_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00010\000\000 */
{ 2166406 }, /* offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000002\000\00010\000\000 */
{ 2167309 }, /* offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000002\000\00010\000\000 */
{ 2168316 }, /* offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000002\000\00010\000\000 */
{ 2168535 }, /* offcore_response.demand_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000002\000\00010\000\000 */
{ 2168771 }, /* offcore_response.demand_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00010\000\000 */
{ 2169013 }, /* offcore_response.demand_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00010\000\000 */
{ 2169244 }, /* offcore_response.demand_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00010\000\000 */
{ 2169982 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00010\000\000 */
{ 2170437 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00010\000\000 */
{ 2171015 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00010\000\000 */
{ 2171807 }, /* offcore_response.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00010\000\000 */
{ 2172049 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000002\000\00010\000\000 */
{ 2172280 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000002\000\00010\000\000 */
{ 2172528 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000002\000\00010\000\000 */
{ 2172782 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000002\000\00010\000\000 */
{ 2173025 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000002\000\00010\000\000 */
{ 2173267 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000002\000\00010\000\000 */
{ 2173499 }, /* offcore_response.demand_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00010\000\000 */
{ 2209371 }, /* offcore_response.other.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC008000\000\00010\000\000 */
{ 2209558 }, /* offcore_response.other.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C008000\000\00010\000\000 */
{ 2209762 }, /* offcore_response.other.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C008000\000\00010\000\000 */
{ 2209972 }, /* offcore_response.other.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C008000\000\00010\000\000 */
{ 2210171 }, /* offcore_response.other.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C008000\000\00010\000\000 */
{ 2210369 }, /* offcore_response.other.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC08000\000\00010\000\000 */
{ 2210573 }, /* offcore_response.other.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC08000\000\00010\000\000 */
{ 2211477 }, /* offcore_response.other.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C008000\000\00010\000\000 */
{ 2212088 }, /* offcore_response.other.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC008000\000\00010\000\000 */
{ 2213005 }, /* offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84008000\000\00010\000\000 */
{ 2213214 }, /* offcore_response.other.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804008000\000\00010\000\000 */
{ 2213440 }, /* offcore_response.other.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00010\000\000 */
{ 2213672 }, /* offcore_response.other.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00010\000\000 */
{ 2213893 }, /* offcore_response.other.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00010\000\000 */
{ 2214573 }, /* offcore_response.other.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00010\000\000 */
{ 2214783 }, /* offcore_response.other.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604008000\000\00010\000\000 */
{ 2215319 }, /* offcore_response.other.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00010\000\000 */
{ 2215832 }, /* offcore_response.other.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B808000\000\00010\000\000 */
{ 2216064 }, /* offcore_response.other.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90008000\000\00010\000\000 */
{ 2216285 }, /* offcore_response.other.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810008000\000\00010\000\000 */
{ 2216523 }, /* offcore_response.other.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410008000\000\00010\000\000 */
{ 2216767 }, /* offcore_response.other.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010008000\000\00010\000\000 */
{ 2217000 }, /* offcore_response.other.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110008000\000\00010\000\000 */
{ 2217232 }, /* offcore_response.other.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210008000\000\00010\000\000 */
{ 2217454 }, /* offcore_response.other.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.OTHER.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90008000\000\00010\000\000 */
{ 2280459 }, /* offcore_response.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00010\000\000 */
{ 2280662 }, /* offcore_response.pf_l1d_and_sw.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000400\000\00010\000\000 */
{ 2280882 }, /* offcore_response.pf_l1d_and_sw.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000400\000\00010\000\000 */
{ 2281108 }, /* offcore_response.pf_l1d_and_sw.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000400\000\00010\000\000 */
{ 2281323 }, /* offcore_response.pf_l1d_and_sw.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000400\000\00010\000\000 */
{ 2281821 }, /* offcore_response.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00010\000\000 */
{ 2282316 }, /* offcore_response.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00010\000\000 */
{ 2282523 }, /* offcore_response.pf_l1d_and_sw.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000400\000\00010\000\000 */
{ 2283006 }, /* offcore_response.pf_l1d_and_sw.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000400\000\00010\000\000 */
{ 2283209 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000400\000\00010\000\000 */
{ 2283434 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000400\000\00010\000\000 */
{ 2283676 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000400\000\00010\000\000 */
{ 2283924 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000400\000\00010\000\000 */
{ 2284161 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00010\000\000 */
{ 2284397 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000400\000\00010\000\000 */
{ 2284903 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00010\000\000 */
{ 2285149 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000400\000\00010\000\000 */
{ 2285656 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00010\000\000 */
{ 2285904 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000400\000\00010\000\000 */
{ 2286141 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000400\000\00010\000\000 */
{ 2286395 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000400\000\00010\000\000 */
{ 2286655 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000400\000\00010\000\000 */
{ 2286904 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000400\000\00010\000\000 */
{ 2287152 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000400\000\00010\000\000 */
{ 2287390 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L1D_AND_SW.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000400\000\00010\000\000 */
{ 2318406 }, /* offcore_response.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00010\000\000 */
{ 2318609 }, /* offcore_response.pf_l2_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000010\000\00010\000\000 */
{ 2318829 }, /* offcore_response.pf_l2_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000010\000\00010\000\000 */
{ 2319055 }, /* offcore_response.pf_l2_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000010\000\00010\000\000 */
{ 2319270 }, /* offcore_response.pf_l2_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000010\000\00010\000\000 */
{ 2319740 }, /* offcore_response.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00010\000\000 */
{ 2320207 }, /* offcore_response.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00010\000\000 */
{ 2320766 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000010\000\00010\000\000 */
{ 2321393 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000010\000\00010\000\000 */
{ 2321959 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000010\000\00010\000\000 */
{ 2322184 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000010\000\00010\000\000 */
{ 2322426 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000010\000\00010\000\000 */
{ 2322674 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000010\000\00010\000\000 */
{ 2322911 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000010\000\00010\000\000 */
{ 2323706 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000010\000\00010\000\000 */
{ 2324184 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00010\000\000 */
{ 2324802 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000010\000\00010\000\000 */
{ 2325471 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00010\000\000 */
{ 2325719 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000010\000\00010\000\000 */
{ 2325956 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000010\000\00010\000\000 */
{ 2326210 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000010\000\00010\000\000 */
{ 2326470 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000010\000\00010\000\000 */
{ 2326719 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000010\000\00010\000\000 */
{ 2326967 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000010\000\00010\000\000 */
{ 2327205 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000010\000\00010\000\000 */
{ 2354636 }, /* offcore_response.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00010\000\000 */
{ 2354831 }, /* offcore_response.pf_l2_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000020\000\00010\000\000 */
{ 2355043 }, /* offcore_response.pf_l2_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000020\000\00010\000\000 */
{ 2355261 }, /* offcore_response.pf_l2_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000020\000\00010\000\000 */
{ 2355468 }, /* offcore_response.pf_l2_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000020\000\00010\000\000 */
{ 2355924 }, /* offcore_response.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00010\000\000 */
{ 2356377 }, /* offcore_response.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00010\000\000 */
{ 2356916 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000020\000\00010\000\000 */
{ 2357523 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000020\000\00010\000\000 */
{ 2358069 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000020\000\00010\000\000 */
{ 2358286 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000020\000\00010\000\000 */
{ 2358520 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000020\000\00010\000\000 */
{ 2358760 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000020\000\00010\000\000 */
{ 2358989 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000020\000\00010\000\000 */
{ 2359758 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000020\000\00010\000\000 */
{ 2360222 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00010\000\000 */
{ 2360820 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000020\000\00010\000\000 */
{ 2361469 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00010\000\000 */
{ 2361709 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000020\000\00010\000\000 */
{ 2361938 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000020\000\00010\000\000 */
{ 2362184 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000020\000\00010\000\000 */
{ 2362436 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000020\000\00010\000\000 */
{ 2362677 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000020\000\00010\000\000 */
{ 2362917 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000020\000\00010\000\000 */
{ 2363147 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L2_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000020\000\00010\000\000 */
{ 2386995 }, /* offcore_response.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00010\000\000 */
{ 2387198 }, /* offcore_response.pf_l3_data_rd.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000080\000\00010\000\000 */
{ 2387418 }, /* offcore_response.pf_l3_data_rd.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000080\000\00010\000\000 */
{ 2387644 }, /* offcore_response.pf_l3_data_rd.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000080\000\00010\000\000 */
{ 2387859 }, /* offcore_response.pf_l3_data_rd.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000080\000\00010\000\000 */
{ 2388339 }, /* offcore_response.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00010\000\000 */
{ 2388816 }, /* offcore_response.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00010\000\000 */
{ 2389395 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000080\000\00010\000\000 */
{ 2390042 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000080\000\00010\000\000 */
{ 2390628 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000080\000\00010\000\000 */
{ 2390853 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000080\000\00010\000\000 */
{ 2391095 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000080\000\00010\000\000 */
{ 2391343 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000080\000\00010\000\000 */
{ 2391580 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000080\000\00010\000\000 */
{ 2392405 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000080\000\00010\000\000 */
{ 2392893 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00010\000\000 */
{ 2393531 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000080\000\00010\000\000 */
{ 2394220 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00010\000\000 */
{ 2394468 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000080\000\00010\000\000 */
{ 2394705 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000080\000\00010\000\000 */
{ 2394959 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000080\000\00010\000\000 */
{ 2395219 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000080\000\00010\000\000 */
{ 2395468 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000080\000\00010\000\000 */
{ 2395716 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000080\000\00010\000\000 */
{ 2395954 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_DATA_RD.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000080\000\00010\000\000 */
{ 2410740 }, /* offcore_response.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00010\000\000 */
{ 2410935 }, /* offcore_response.pf_l3_rfo.l3_miss.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83C000100\000\00010\000\000 */
{ 2411147 }, /* offcore_response.pf_l3_rfo.l3_miss.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C000100\000\00010\000\000 */
{ 2411365 }, /* offcore_response.pf_l3_rfo.l3_miss.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C000100\000\00010\000\000 */
{ 2411572 }, /* offcore_response.pf_l3_rfo.l3_miss.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C000100\000\00010\000\000 */
{ 2412034 }, /* offcore_response.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.REMOTE_HIT_FORWARD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00010\000\000 */
{ 2412493 }, /* offcore_response.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.REMOTE_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00010\000\000 */
{ 2413044 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C000100\000\00010\000\000 */
{ 2413663 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC000100\000\00010\000\000 */
{ 2414221 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84000100\000\00010\000\000 */
{ 2414438 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804000100\000\00010\000\000 */
{ 2414672 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000100\000\00010\000\000 */
{ 2414912 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000100\000\00010\000\000 */
{ 2415141 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000100\000\00010\000\000 */
{ 2415928 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000100\000\00010\000\000 */
{ 2416398 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00010\000\000 */
{ 2417008 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_LOCAL_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000100\000\00010\000\000 */
{ 2417669 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_DRAM.SNOOP_MISS_OR_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00010\000\000 */
{ 2417909 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.any_snoop\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F90000100\000\00010\000\000 */
{ 2418138 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x810000100\000\00010\000\000 */
{ 2418384 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hit_other_core_no_fwd\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x410000100\000\00010\000\000 */
{ 2418636 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.hitm_other_core\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010000100\000\00010\000\000 */
{ 2418877 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.no_snoop_needed\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x110000100\000\00010\000\000 */
{ 2419117 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_miss\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x210000100\000\00010\000\000 */
{ 2419347 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_hop1_dram.snoop_none\000\000memory\000This event is deprecated. Refer to new event OCR.PF_L3_RFO.L3_MISS_REMOTE_HOP1_DRAM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000100\000\00010\000\000 */
{ 2514787 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered (Precise event)\000 */
{ 2515653 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2516231 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516758 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519252 }, /* rtm_retired.aborted_timer\000\000memory\000Number of times an RTM execution aborted due to uncommon conditions\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000 */
{ 2519638 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520181 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520659 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571935 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573674 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000 */
{ 2574110 }, /* tx_mem.abort_capacity\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional reads or writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000 */
{ 2575819 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576852 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577961 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2579066 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2579929 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2580950 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 571949 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 572666 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573399 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server michroarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 574130 }, /* core_power.throttle\000\000other\000Core cycles the core was throttled due to a pending power level request\000event=0x28,period=200003,umask=0x40\000\00000\000Core cycles the out-of-order engine was throttled due to a pending power level request\000 */
{ 578999 }, /* core_snoop_response.rsp_ifwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDFE\000event=0xef,period=2000003,umask=0x20\000\00000\000\000 */
{ 579110 }, /* core_snoop_response.rsp_ifwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDM\000event=0xef,period=2000003,umask=0x10\000\00000\000\000 */
{ 579219 }, /* core_snoop_response.rsp_ihitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITFSE\000event=0xef,period=2000003,umask=0x2\000\00000\000\000 */
{ 579331 }, /* core_snoop_response.rsp_ihiti\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITI\000event=0xef,period=2000003,umask=0x1\000\00000\000\000 */
{ 579439 }, /* core_snoop_response.rsp_sfwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDFE\000event=0xef,period=2000003,umask=0x40\000\00000\000\000 */
{ 579550 }, /* core_snoop_response.rsp_sfwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDM\000event=0xef,period=2000003,umask=0x8\000\00000\000\000 */
{ 579658 }, /* core_snoop_response.rsp_shitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_SHITFSE\000event=0xef,period=2000003,umask=0x4\000\00000\000\000 */
{ 978812 }, /* hw_interrupts.received\000\000other\000Number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000Counts the number of hardware interruptions received by the processor\000 */
{ 997212 }, /* idi_misc.wb_downgrade\000\000other\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000event=0xfe,period=100003,umask=0x4\000\00000\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000 */
{ 997542 }, /* idi_misc.wb_upgrade\000\000other\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000event=0xfe,period=100003,umask=0x2\000\00000\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000 */
{ 1443033 }, /* ocr.all_data_rd.any_response\000\000other\000OCR.ALL_DATA_RD.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00000\000\000 */
{ 1455356 }, /* ocr.all_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400491\000\00000\000\000 */
{ 1455560 }, /* ocr.all_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400491\000\00000\000\000 */
{ 1455765 }, /* ocr.all_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400491\000\00000\000\000 */
{ 1455989 }, /* ocr.all_data_rd.supplier_none.any_snoop\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020491\000\00000\000\000 */
{ 1456182 }, /* ocr.all_data_rd.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020491\000\00000\000\000 */
{ 1456401 }, /* ocr.all_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020491\000\00000\000\000 */
{ 1456629 }, /* ocr.all_data_rd.supplier_none.hitm_other_core\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020491\000\00000\000\000 */
{ 1456840 }, /* ocr.all_data_rd.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020491\000\00000\000\000 */
{ 1457050 }, /* ocr.all_data_rd.supplier_none.snoop_miss\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020491\000\00000\000\000 */
{ 1457203 }, /* ocr.all_data_rd.supplier_none.snoop_none\000\000other\000OCR.ALL_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020491\000\00000\000\000 */
{ 1457355 }, /* ocr.all_pf_data_rd.any_response\000\000other\000OCR.ALL_PF_DATA_RD.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00000\000\000 */
{ 1470224 }, /* ocr.all_pf_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400490\000\00000\000\000 */
{ 1470437 }, /* ocr.all_pf_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400490\000\00000\000\000 */
{ 1470651 }, /* ocr.all_pf_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_PF_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400490\000\00000\000\000 */
{ 1470884 }, /* ocr.all_pf_data_rd.supplier_none.any_snoop\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020490\000\00000\000\000 */
{ 1471086 }, /* ocr.all_pf_data_rd.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020490\000\00000\000\000 */
{ 1471314 }, /* ocr.all_pf_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020490\000\00000\000\000 */
{ 1471551 }, /* ocr.all_pf_data_rd.supplier_none.hitm_other_core\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020490\000\00000\000\000 */
{ 1471771 }, /* ocr.all_pf_data_rd.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020490\000\00000\000\000 */
{ 1471990 }, /* ocr.all_pf_data_rd.supplier_none.snoop_miss\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020490\000\00000\000\000 */
{ 1472149 }, /* ocr.all_pf_data_rd.supplier_none.snoop_none\000\000other\000OCR.ALL_PF_DATA_RD.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020490\000\00000\000\000 */
{ 1472307 }, /* ocr.all_pf_rfo.any_response\000\000other\000OCR.ALL_PF_RFO.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000 */
{ 1484448 }, /* ocr.all_pf_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400120\000\00000\000\000 */
{ 1484649 }, /* ocr.all_pf_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400120\000\00000\000\000 */
{ 1484851 }, /* ocr.all_pf_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_PF_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400120\000\00000\000\000 */
{ 1485072 }, /* ocr.all_pf_rfo.supplier_none.any_snoop\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_PF_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020120\000\00000\000\000 */
{ 1485262 }, /* ocr.all_pf_rfo.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020120\000\00000\000\000 */
{ 1485478 }, /* ocr.all_pf_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_PF_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020120\000\00000\000\000 */
{ 1485703 }, /* ocr.all_pf_rfo.supplier_none.hitm_other_core\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_PF_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020120\000\00000\000\000 */
{ 1485911 }, /* ocr.all_pf_rfo.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_PF_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020120\000\00000\000\000 */
{ 1486118 }, /* ocr.all_pf_rfo.supplier_none.snoop_miss\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020120\000\00000\000\000 */
{ 1486269 }, /* ocr.all_pf_rfo.supplier_none.snoop_none\000\000other\000OCR.ALL_PF_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020120\000\00000\000\000 */
{ 1486419 }, /* ocr.all_reads.any_response\000\000other\000OCR.ALL_READS.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107F7\000\00000\000\000 */
{ 1498378 }, /* ocr.all_reads.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_READS.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F804007F7\000\00000\000\000 */
{ 1498576 }, /* ocr.all_reads.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x804007F7\000\00000\000\000 */
{ 1498775 }, /* ocr.all_reads.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_READS.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00000\000\000 */
{ 1498993 }, /* ocr.all_reads.supplier_none.any_snoop\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_READS.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F800207F7\000\00000\000\000 */
{ 1499180 }, /* ocr.all_reads.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000207F7\000\00000\000\000 */
{ 1499393 }, /* ocr.all_reads.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_READS.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4000207F7\000\00000\000\000 */
{ 1499615 }, /* ocr.all_reads.supplier_none.hitm_other_core\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_READS.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10000207F7\000\00000\000\000 */
{ 1499820 }, /* ocr.all_reads.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_READS.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000207F7\000\00000\000\000 */
{ 1500024 }, /* ocr.all_reads.supplier_none.snoop_miss\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000207F7\000\00000\000\000 */
{ 1500173 }, /* ocr.all_reads.supplier_none.snoop_none\000\000other\000OCR.ALL_READS.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800207F7\000\00000\000\000 */
{ 1500321 }, /* ocr.all_rfo.any_response\000\000other\000OCR.ALL_RFO.ANY_RESPONSE have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000 */
{ 1511916 }, /* ocr.all_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400122\000\00000\000\000 */
{ 1512108 }, /* ocr.all_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400122\000\00000\000\000 */
{ 1512301 }, /* ocr.all_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED OCR.ALL_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00000\000\000 */
{ 1512513 }, /* ocr.all_rfo.supplier_none.any_snoop\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP  OCR.ALL_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020122\000\00000\000\000 */
{ 1512694 }, /* ocr.all_rfo.supplier_none.hit_other_core_fwd\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD  OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020122\000\00000\000\000 */
{ 1512901 }, /* ocr.all_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD  OCR.ALL_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020122\000\00000\000\000 */
{ 1513117 }, /* ocr.all_rfo.supplier_none.hitm_other_core\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE  OCR.ALL_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020122\000\00000\000\000 */
{ 1513316 }, /* ocr.all_rfo.supplier_none.no_snoop_needed\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED  OCR.ALL_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020122\000\00000\000\000 */
{ 1513514 }, /* ocr.all_rfo.supplier_none.snoop_miss\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020122\000\00000\000\000 */
{ 1513659 }, /* ocr.all_rfo.supplier_none.snoop_none\000\000other\000OCR.ALL_RFO.SUPPLIER_NONE.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020122\000\00000\000\000 */
{ 1515215 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts all demand code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1534910 }, /* ocr.demand_code_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400004\000\00000\000\000 */
{ 1535105 }, /* ocr.demand_code_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00000\000\000 */
{ 1535300 }, /* ocr.demand_code_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all demand code reads OCR.DEMAND_CODE_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000 */
{ 1537484 }, /* ocr.demand_code_rd.supplier_none.any_snoop\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020004\000\00000\000\000 */
{ 1537672 }, /* ocr.demand_code_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020004\000\00000\000\000 */
{ 1537877 }, /* ocr.demand_code_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00000\000\000 */
{ 1538088 }, /* ocr.demand_code_rd.supplier_none.hitm_other_core\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00000\000\000 */
{ 1538288 }, /* ocr.demand_code_rd.supplier_none.no_snoop_needed\000\000other\000Counts all demand code reads  OCR.DEMAND_CODE_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00000\000\000 */
{ 1538487 }, /* ocr.demand_code_rd.supplier_none.snoop_miss\000\000other\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00000\000\000 */
{ 1538631 }, /* ocr.demand_code_rd.supplier_none.snoop_none\000\000other\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00000\000\000 */
{ 1542302 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1566258 }, /* ocr.demand_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400001\000\00000\000\000 */
{ 1566449 }, /* ocr.demand_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00000\000\000 */
{ 1566640 }, /* ocr.demand_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts demand data reads OCR.DEMAND_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000 */
{ 1570657 }, /* ocr.demand_data_rd.supplier_none.any_snoop\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020001\000\00000\000\000 */
{ 1570841 }, /* ocr.demand_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020001\000\00000\000\000 */
{ 1571042 }, /* ocr.demand_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00000\000\000 */
{ 1571249 }, /* ocr.demand_data_rd.supplier_none.hitm_other_core\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00000\000\000 */
{ 1571445 }, /* ocr.demand_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts demand data reads  OCR.DEMAND_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00000\000\000 */
{ 1571640 }, /* ocr.demand_data_rd.supplier_none.snoop_miss\000\000other\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00000\000\000 */
{ 1571780 }, /* ocr.demand_data_rd.supplier_none.snoop_none\000\000other\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00000\000\000 */
{ 1571919 }, /* ocr.demand_rfo.any_response\000\000other\000Counts all demand data writes (RFOs) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1597243 }, /* ocr.demand_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400002\000\00000\000\000 */
{ 1597438 }, /* ocr.demand_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00000\000\000 */
{ 1597633 }, /* ocr.demand_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all demand data writes (RFOs) OCR.DEMAND_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000 */
{ 1600611 }, /* ocr.demand_rfo.supplier_none.any_snoop\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020002\000\00000\000\000 */
{ 1600799 }, /* ocr.demand_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020002\000\00000\000\000 */
{ 1601004 }, /* ocr.demand_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00000\000\000 */
{ 1601215 }, /* ocr.demand_rfo.supplier_none.hitm_other_core\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00000\000\000 */
{ 1601415 }, /* ocr.demand_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all demand data writes (RFOs)  OCR.DEMAND_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00000\000\000 */
{ 1601614 }, /* ocr.demand_rfo.supplier_none.snoop_miss\000\000other\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00000\000\000 */
{ 1601762 }, /* ocr.demand_rfo.supplier_none.snoop_none\000\000other\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00000\000\000 */
{ 1624456 }, /* ocr.other.any_response\000\000other\000Counts any other requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1637818 }, /* ocr.other.pmm_hit_local_pmm.any_snoop\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80408000\000\00000\000\000 */
{ 1637992 }, /* ocr.other.pmm_hit_local_pmm.snoop_none\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00000\000\000 */
{ 1638166 }, /* ocr.other.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts any other requests OCR.OTHER.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00000\000\000 */
{ 1638353 }, /* ocr.other.supplier_none.any_snoop\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80028000\000\00000\000\000 */
{ 1638520 }, /* ocr.other.supplier_none.hit_other_core_fwd\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800028000\000\00000\000\000 */
{ 1638704 }, /* ocr.other.supplier_none.hit_other_core_no_fwd\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00000\000\000 */
{ 1638894 }, /* ocr.other.supplier_none.hitm_other_core\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00000\000\000 */
{ 1639073 }, /* ocr.other.supplier_none.no_snoop_needed\000\000other\000Counts any other requests  OCR.OTHER.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00000\000\000 */
{ 1639251 }, /* ocr.other.supplier_none.snoop_miss\000\000other\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00000\000\000 */
{ 1639383 }, /* ocr.other.supplier_none.snoop_none\000\000other\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00000\000\000 */
{ 1640378 }, /* ocr.pf_l1d_and_sw.any_response\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1655175 }, /* ocr.pf_l1d_and_sw.pmm_hit_local_pmm.any_snoop\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400400\000\00000\000\000 */
{ 1655418 }, /* ocr.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_none\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400400\000\00000\000\000 */
{ 1655661 }, /* ocr.pf_l1d_and_sw.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests OCR.PF_L1D_AND_SW.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400400\000\00000\000\000 */
{ 1655917 }, /* ocr.pf_l1d_and_sw.supplier_none.any_snoop\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020400\000\00000\000\000 */
{ 1656153 }, /* ocr.pf_l1d_and_sw.supplier_none.hit_other_core_fwd\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020400\000\00000\000\000 */
{ 1656406 }, /* ocr.pf_l1d_and_sw.supplier_none.hit_other_core_no_fwd\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020400\000\00000\000\000 */
{ 1656665 }, /* ocr.pf_l1d_and_sw.supplier_none.hitm_other_core\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020400\000\00000\000\000 */
{ 1656913 }, /* ocr.pf_l1d_and_sw.supplier_none.no_snoop_needed\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests  OCR.PF_L1D_AND_SW.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020400\000\00000\000\000 */
{ 1657160 }, /* ocr.pf_l1d_and_sw.supplier_none.snoop_miss\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020400\000\00000\000\000 */
{ 1657353 }, /* ocr.pf_l1d_and_sw.supplier_none.snoop_none\000\000other\000Counts L1 data cache hardware prefetch requests and software prefetch requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020400\000\00000\000\000 */
{ 1657545 }, /* ocr.pf_l2_data_rd.any_response\000\000other\000Counts prefetch (that bring data to L2) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 1670606 }, /* ocr.pf_l2_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400010\000\00000\000\000 */
{ 1670821 }, /* ocr.pf_l2_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400010\000\00000\000\000 */
{ 1671036 }, /* ocr.pf_l2_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts prefetch (that bring data to L2) data reads OCR.PF_L2_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400010\000\00000\000\000 */
{ 1671264 }, /* ocr.pf_l2_data_rd.supplier_none.any_snoop\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020010\000\00000\000\000 */
{ 1671472 }, /* ocr.pf_l2_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020010\000\00000\000\000 */
{ 1671697 }, /* ocr.pf_l2_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020010\000\00000\000\000 */
{ 1671928 }, /* ocr.pf_l2_data_rd.supplier_none.hitm_other_core\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020010\000\00000\000\000 */
{ 1672148 }, /* ocr.pf_l2_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts prefetch (that bring data to L2) data reads  OCR.PF_L2_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020010\000\00000\000\000 */
{ 1672367 }, /* ocr.pf_l2_data_rd.supplier_none.snoop_miss\000\000other\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020010\000\00000\000\000 */
{ 1672532 }, /* ocr.pf_l2_data_rd.supplier_none.snoop_none\000\000other\000Counts prefetch (that bring data to L2) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020010\000\00000\000\000 */
{ 1672696 }, /* ocr.pf_l2_rfo.any_response\000\000other\000Counts all prefetch (that bring data to L2) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 1685153 }, /* ocr.pf_l2_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400020\000\00000\000\000 */
{ 1685358 }, /* ocr.pf_l2_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400020\000\00000\000\000 */
{ 1685563 }, /* ocr.pf_l2_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to L2) RFOs OCR.PF_L2_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400020\000\00000\000\000 */
{ 1685781 }, /* ocr.pf_l2_rfo.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020020\000\00000\000\000 */
{ 1685979 }, /* ocr.pf_l2_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020020\000\00000\000\000 */
{ 1686194 }, /* ocr.pf_l2_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020020\000\00000\000\000 */
{ 1686415 }, /* ocr.pf_l2_rfo.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020020\000\00000\000\000 */
{ 1686625 }, /* ocr.pf_l2_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to L2) RFOs  OCR.PF_L2_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020020\000\00000\000\000 */
{ 1686834 }, /* ocr.pf_l2_rfo.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020020\000\00000\000\000 */
{ 1686993 }, /* ocr.pf_l2_rfo.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to L2) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020020\000\00000\000\000 */
{ 1687151 }, /* ocr.pf_l3_data_rd.any_response\000\000other\000Counts all prefetch (that bring data to LLC only) data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000 */
{ 1700832 }, /* ocr.pf_l3_data_rd.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400080\000\00000\000\000 */
{ 1701057 }, /* ocr.pf_l3_data_rd.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400080\000\00000\000\000 */
{ 1701282 }, /* ocr.pf_l3_data_rd.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to LLC only) data reads OCR.PF_L3_DATA_RD.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400080\000\00000\000\000 */
{ 1701520 }, /* ocr.pf_l3_data_rd.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020080\000\00000\000\000 */
{ 1701738 }, /* ocr.pf_l3_data_rd.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020080\000\00000\000\000 */
{ 1701973 }, /* ocr.pf_l3_data_rd.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020080\000\00000\000\000 */
{ 1702214 }, /* ocr.pf_l3_data_rd.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020080\000\00000\000\000 */
{ 1702444 }, /* ocr.pf_l3_data_rd.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to LLC only) data reads  OCR.PF_L3_DATA_RD.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020080\000\00000\000\000 */
{ 1702673 }, /* ocr.pf_l3_data_rd.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020080\000\00000\000\000 */
{ 1702848 }, /* ocr.pf_l3_data_rd.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020080\000\00000\000\000 */
{ 1703022 }, /* ocr.pf_l3_rfo.any_response\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000 */
{ 1715851 }, /* ocr.pf_l3_rfo.pmm_hit_local_pmm.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80400100\000\00000\000\000 */
{ 1716062 }, /* ocr.pf_l3_rfo.pmm_hit_local_pmm.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NONE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400100\000\00000\000\000 */
{ 1716273 }, /* ocr.pf_l3_rfo.pmm_hit_local_pmm.snoop_not_needed\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs OCR.PF_L3_RFO.PMM_HIT_LOCAL_PMM.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400100\000\00000\000\000 */
{ 1716497 }, /* ocr.pf_l3_rfo.supplier_none.any_snoop\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.ANY_SNOOP\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F80020100\000\00000\000\000 */
{ 1716701 }, /* ocr.pf_l3_rfo.supplier_none.hit_other_core_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800020100\000\00000\000\000 */
{ 1716922 }, /* ocr.pf_l3_rfo.supplier_none.hit_other_core_no_fwd\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HIT_OTHER_CORE_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020100\000\00000\000\000 */
{ 1717149 }, /* ocr.pf_l3_rfo.supplier_none.hitm_other_core\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.HITM_OTHER_CORE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020100\000\00000\000\000 */
{ 1717365 }, /* ocr.pf_l3_rfo.supplier_none.no_snoop_needed\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs  OCR.PF_L3_RFO.SUPPLIER_NONE.NO_SNOOP_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020100\000\00000\000\000 */
{ 1717580 }, /* ocr.pf_l3_rfo.supplier_none.snoop_miss\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020100\000\00000\000\000 */
{ 1717745 }, /* ocr.pf_l3_rfo.supplier_none.snoop_none\000\000other\000Counts all prefetch (that bring data to LLC only) RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020100\000\00000\000\000 */
{ 468073 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000event=0x14,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 496249 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009\000\00000\000Counts all (macro) branch instructions retired  Spec update: SKL091\000 */
{ 499329 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000 */
{ 503121 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000 */
{ 504119 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 506277 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000 */
{ 508062 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 514802 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 517512 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 518926 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 522057 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 536275 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path\000 */
{ 541281 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 554675 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted direct and indirect near call instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts both taken and not taken retired mispredicted direct and indirect near calls, including both register and memory indirect (Precise event)\000 */
{ 555365 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 560165 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 606999 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 607510 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 608492 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 618032 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 627594 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638353 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 639277 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 640312 }, /* cpu_clk_unhalted.ring0_trans\000\000pipeline\000Counts when there is a transition from ring 1, 2 or 3 to ring 0\000event=0x3c,cmask=1,edge=1,period=100007\000\00000\000Counts when the Current Privilege Level (CPL) transitions from ring 1, 2 or 3 to ring 0 (Kernel)\000 */
{ 641300 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 753037 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=2000003,umask=0x10\000\00000\000\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 758894 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=2000003,umask=0x14\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847925 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no outstanding load\000event=0xa6,period=2000003,umask=0x40\000\00000\000\000 */
{ 848693 }, /* exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles where no uops were executed, the Reservation Station was not empty, the Store Buffer was full and there was no outstanding load\000event=0xa6,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 1041006 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1047887 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, Counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. Counting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1055017 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event  Spec update: SKL091, SKL044\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: SKL091, SKL044\000 */
{ 1057846 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions  Spec update: SKL091, SKL044 (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1059777 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1063267 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Number of cycles using always true condition applied to  PEBS instructions retired event  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using an always true condition applied to  PEBS instructions retired event. (inst_ret< 16)  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1066130 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Cycles the issue-stage is waiting for front-end to fetch from resteered path following branch misprediction or machine clear events\000event=0xd,period=2000003,umask=0x80\000\00000\000\000 */
{ 1066904 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1068948 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,period=2000003,umask=0x1\000\00000\000Core cycles the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1071510 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1194460 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1202058 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229766 }, /* load_hit_pre.sw_pf\000\000pipeline\000Demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283301 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_OK]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_OK]\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1284803 }, /* lsd.cycles_ok\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_4_UOPS]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_4_UOPS]\000 */
{ 1286318 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 2461899 }, /* other_assists.any\000\000pipeline\000Number of times a microcode assist is invoked by HW other than FP-assist. Examples include AD (page Access Dirty) and AVX* related assists\000event=0xc1,period=100003,umask=0x3f\000\00000\000\000 */
{ 2478166 }, /* partial_rat_stalls.scoreboard\000\000pipeline\000Cycles where the pipeline is stalled due to serializing operations\000event=0x59,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the microcode scoreboard stalls happen\000 */
{ 2501367 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Counts resource-related stall cycles\000 */
{ 2504559 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2507828 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=2000003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 2508199 }, /* rob_misc_events.pause_inst\000\000pipeline\000Number of retired PAUSE instructions (that do not end up with a VMExit to the VMM; TSX aborted Instructions may be counted). This event is not supported on first SKL and KBL products\000event=0xcc,period=2000003,umask=0x40\000\00000\000\000 */
{ 2510793 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for the thread.; Note: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512239 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate front-end Latency Bound issues\000 */
{ 6184015 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185297 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186603 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 2\000 */
{ 6187901 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189223 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190512 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191493 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192140 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198549 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200712 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201775 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202848 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203792 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6214065 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6219530 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6222270 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=2000003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000 */
{ 6231140 }, /* uops_retired.macro_fused\000\000pipeline\000Number of macro-fused uops retired. (non precise)\000event=0xc2,period=2000003,umask=0x4\000\00000\000Counts the number of macro-fused uops retired. (non precise)\000 */
{ 6235584 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used\000 */
{ 6238702 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240572 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x2\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 1212811 }, /* llc_misses.mmio_read\000uncore_cha\000uncore cache\000MMIO reads. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40040e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1214354 }, /* llc_misses.mmio_write\000uncore_cha\000uncore cache\000MMIO writes. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40041e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1221280 }, /* llc_misses.uncacheable\000uncore_cha\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1226016 }, /* llc_references.streaming_full\000uncore_cha\000uncore cache\000Streaming stores (full cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x41833\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1227688 }, /* llc_references.streaming_partial\000uncore_cha\000uncore cache\000Streaming stores (partial cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x41a33\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 2592253 }, /* unc_c_clockticks\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CLOCKTICKS. Unit: uncore_cha \000event=0\000\00011\000\000 */
{ 2593126 }, /* unc_c_fast_asserted\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_FAST_ASSERTED.HORZ. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00011\000\000 */
{ 2595531 }, /* unc_c_llc_lookup.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.ANY. Unit: uncore_cha \000event=0x34,umask=0x11\000\00011\000\000 */
{ 2597499 }, /* unc_c_llc_lookup.data_read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x3\000\00011\000\000 */
{ 2597669 }, /* unc_c_llc_lookup.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LOCAL. Unit: uncore_cha \000event=0x34,umask=0x31\000\00011\000\000 */
{ 2600597 }, /* unc_c_llc_lookup.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE. Unit: uncore_cha \000event=0x34,umask=0x91\000\00011\000\000 */
{ 2602721 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE_SNOOP. Unit: uncore_cha \000event=0x34,umask=0x9\000\00011\000\000 */
{ 2604859 }, /* unc_c_llc_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITE. Unit: uncore_cha \000event=0x34,umask=0x5\000\00011\000\000 */
{ 2605267 }, /* unc_c_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000 */
{ 2605663 }, /* unc_c_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000 */
{ 2606077 }, /* unc_c_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.LOCAL_ALL. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00011\000\000 */
{ 2606759 }, /* unc_c_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000 */
{ 2608101 }, /* unc_c_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000 */
{ 2608746 }, /* unc_c_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000 */
{ 2702473 }, /* unc_c_ring_src_thrtl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SRC_THRTL. Unit: uncore_cha \000event=0xa4\000\00011\000\000 */
{ 2729483 }, /* unc_c_tor_inserts.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.EVICT. Unit: uncore_cha \000event=0x35,umask=0x2\000\00011\000\000 */
{ 2731157 }, /* unc_c_tor_inserts.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.HIT. Unit: uncore_cha \000event=0x35,umask=0x10\000\00011\000\000 */
{ 2731318 }, /* unc_c_tor_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00011\000\000 */
{ 2731696 }, /* unc_c_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000 */
{ 2732036 }, /* unc_c_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000 */
{ 2732158 }, /* unc_c_tor_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000 */
{ 2732536 }, /* unc_c_tor_inserts.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT. Unit: uncore_cha \000event=0x35,umask=0x11\000\00011\000\000 */
{ 2732923 }, /* unc_c_tor_inserts.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS. Unit: uncore_cha \000event=0x35,umask=0x21\000\00011\000\000 */
{ 2733318 }, /* unc_c_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000 */
{ 2733439 }, /* unc_c_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000 */
{ 2733602 }, /* unc_c_tor_inserts.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00011\000\000 */
{ 2735882 }, /* unc_c_tor_inserts.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.MISS. Unit: uncore_cha \000event=0x35,umask=0x20\000\00011\000\000 */
{ 2749852 }, /* unc_c_tor_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00011\000\000 */
{ 2750230 }, /* unc_c_tor_inserts.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_HIT. Unit: uncore_cha \000event=0x35,umask=0x14\000\00011\000\000 */
{ 2750617 }, /* unc_c_tor_inserts.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_MISS. Unit: uncore_cha \000event=0x35,umask=0x24\000\00011\000\000 */
{ 2750787 }, /* unc_c_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000 */
{ 2752328 }, /* unc_c_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000 */
{ 2752449 }, /* unc_c_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000 */
{ 2753879 }, /* unc_c_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000 */
{ 2754000 }, /* unc_c_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000 */
{ 2755950 }, /* unc_c_tor_occupancy.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.EVICT. Unit: uncore_cha \000event=0x36,umask=0x2\000\00011\000\000 */
{ 2757672 }, /* unc_c_tor_occupancy.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.HIT. Unit: uncore_cha \000event=0x36,umask=0x10\000\00011\000\000 */
{ 2757837 }, /* unc_c_tor_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00011\000\000 */
{ 2758001 }, /* unc_c_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000 */
{ 2758124 }, /* unc_c_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000 */
{ 2758248 }, /* unc_c_tor_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000 */
{ 2758412 }, /* unc_c_tor_occupancy.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_HIT. Unit: uncore_cha \000event=0x36,umask=0x11\000\00011\000\000 */
{ 2758584 }, /* unc_c_tor_occupancy.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_MISS. Unit: uncore_cha \000event=0x36,umask=0x21\000\00011\000\000 */
{ 2759590 }, /* unc_c_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000 */
{ 2759713 }, /* unc_c_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000 */
{ 2759880 }, /* unc_c_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00011\000\000 */
{ 2761386 }, /* unc_c_tor_occupancy.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.MISS. Unit: uncore_cha \000event=0x36,umask=0x20\000\00011\000\000 */
{ 2775624 }, /* unc_c_tor_occupancy.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00011\000\000 */
{ 2775788 }, /* unc_c_tor_occupancy.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_HIT. Unit: uncore_cha \000event=0x36,umask=0x14\000\00011\000\000 */
{ 2775960 }, /* unc_c_tor_occupancy.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_MISS. Unit: uncore_cha \000event=0x36,umask=0x24\000\00011\000\000 */
{ 2793572 }, /* unc_cha_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2793797 }, /* unc_cha_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794022 }, /* unc_cha_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794247 }, /* unc_cha_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794472 }, /* unc_cha_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794698 }, /* unc_cha_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2798000 }, /* unc_cha_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798225 }, /* unc_cha_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798450 }, /* unc_cha_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798675 }, /* unc_cha_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798900 }, /* unc_cha_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799126 }, /* unc_cha_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2802439 }, /* unc_cha_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2802664 }, /* unc_cha_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2802889 }, /* unc_cha_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803114 }, /* unc_cha_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803339 }, /* unc_cha_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803565 }, /* unc_cha_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806867 }, /* unc_cha_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807092 }, /* unc_cha_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807317 }, /* unc_cha_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807542 }, /* unc_cha_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807767 }, /* unc_cha_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807993 }, /* unc_cha_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2811306 }, /* unc_cha_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811531 }, /* unc_cha_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811756 }, /* unc_cha_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811981 }, /* unc_cha_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812206 }, /* unc_cha_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812432 }, /* unc_cha_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815734 }, /* unc_cha_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2815959 }, /* unc_cha_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816184 }, /* unc_cha_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816409 }, /* unc_cha_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816634 }, /* unc_cha_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816860 }, /* unc_cha_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2823249 }, /* unc_cha_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823474 }, /* unc_cha_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823699 }, /* unc_cha_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823924 }, /* unc_cha_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824149 }, /* unc_cha_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824375 }, /* unc_cha_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827688 }, /* unc_cha_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2827917 }, /* unc_cha_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828146 }, /* unc_cha_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828375 }, /* unc_cha_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828604 }, /* unc_cha_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828834 }, /* unc_cha_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2829596 }, /* unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the intermediate bypass\000 */
{ 2830692 }, /* unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000 */
{ 2831749 }, /* unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the full bypass\000 */
{ 2832679 }, /* unc_cha_clockticks\000uncore_cha\000uncore cache\000Uncore cache clock ticks. Unit: uncore_cha \000event=0\000\00001\000Counts clockticks of the clock controlling the uncore caching and home agent (CHA)\000 */
{ 2832961 }, /* unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 2833058 }, /* unc_cha_core_pma.c1_state\000uncore_cha\000uncore cache\000Core PMA Events; C1  State. Unit: uncore_cha \000event=0x17,umask=0x1\000\00001\000\000 */
{ 2833180 }, /* unc_cha_core_pma.c1_transition\000uncore_cha\000uncore cache\000Core PMA Events; C1 Transition. Unit: uncore_cha \000event=0x17,umask=0x2\000\00001\000\000 */
{ 2833311 }, /* unc_cha_core_pma.c6_state\000uncore_cha\000uncore cache\000Core PMA Events; C6 State. Unit: uncore_cha \000event=0x17,umask=0x4\000\00001\000\000 */
{ 2833432 }, /* unc_cha_core_pma.c6_transition\000uncore_cha\000uncore cache\000Core PMA Events; C6 Transition. Unit: uncore_cha \000event=0x17,umask=0x8\000\00001\000\000 */
{ 2833563 }, /* unc_cha_core_pma.gv\000uncore_cha\000uncore cache\000Core PMA Events; GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00001\000\000 */
{ 2834469 }, /* unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2835970 }, /* unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2836689 }, /* unc_cha_core_snp.any_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2838200 }, /* unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2839703 }, /* unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2840427 }, /* unc_cha_core_snp.core_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Core Request to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x44\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2841933 }, /* unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2843423 }, /* unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2844143 }, /* unc_cha_core_snp.evict_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Eviction to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x84\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2845658 }, /* unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2847165 }, /* unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2847890 }, /* unc_cha_core_snp.ext_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; External Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x24\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2850751 }, /* unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2851249 }, /* unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Counts transactions that looked into the multi-socket cacheline Directory state, and therefore did not send a snoop because the Directory indicated it was not needed\000 */
{ 2852041 }, /* unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Counts  transactions that looked into the multi-socket cacheline Directory state, and sent one or more snoops, because the Directory indicated it was needed\000 */
{ 2852809 }, /* unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from the HA pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline Directory state updates memory writes issued from the HA pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2853605 }, /* unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline Directory state updates due to memory writes issued from the TOR pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2858937 }, /* unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_cha \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859488 }, /* unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_cha \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859736 }, /* unc_cha_fast_asserted.horz\000uncore_cha\000uncore cache\000FaST wire asserted; Horizontal. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 2859996 }, /* unc_cha_fast_asserted.vert\000uncore_cha\000uncore cache\000FaST wire asserted; Vertical. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 2860254 }, /* unc_cha_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000Read request from a remote socket which hit in the HitMe Cache to a line In the E state. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00001\000Counts read requests from a remote socket which hit in the HitME cache (used to cache the multi-socket Directory state) to a line in the E(Exclusive) state.  This includes the following read opcodes (RdCode, RdData, RdDataMigratory, RdCur, RdInv*, Inv*)\000 */
{ 2861212 }, /* unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; Shared hit and op is RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000\000 */
{ 2861703 }, /* unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000 */
{ 2862342 }, /* unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000\000 */
{ 2863055 }, /* unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000\000 */
{ 2863804 }, /* unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000\000 */
{ 2864533 }, /* unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; No SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000\000 */
{ 2865243 }, /* unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000\000 */
{ 2865936 }, /* unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000\000 */
{ 2866314 }, /* unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000 */
{ 2866901 }, /* unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Received RspFwdI* for a local request, but converted HitME$ to SF entry\000 */
{ 2867390 }, /* unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000 */
{ 2867974 }, /* unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000 */
{ 2868429 }, /* unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000 */
{ 2869528 }, /* unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2871320 }, /* unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2873116 }, /* unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2874913 }, /* unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2876706 }, /* unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2878494 }, /* unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2880286 }, /* unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2882079 }, /* unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2887579 }, /* unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2889369 }, /* unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2891163 }, /* unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2892958 }, /* unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2894425 }, /* unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Left. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2895578 }, /* unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Right. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2896137 }, /* unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000 */
{ 2896705 }, /* unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued; ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 2897239 }, /* unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to the any of the memory controller channels\000 */
{ 2897516 }, /* unc_cha_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Full Line MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2898147 }, /* unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2898782 }, /* unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2899110 }, /* unc_cha_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH.; Filter for memory controller 5 only\000 */
{ 2899779 }, /* unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2900112 }, /* unc_cha_iodc_alloc.invitom\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations. Unit: uncore_cha \000event=0x62,umask=0x1\000\00001\000\000 */
{ 2900294 }, /* unc_cha_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations dropped due to IODC Full. Unit: uncore_cha \000event=0x62,umask=0x2\000\00001\000\000 */
{ 2900502 }, /* unc_cha_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IDOC allocation dropped due to OSB gate. Unit: uncore_cha \000event=0x62,umask=0x4\000\00001\000\000 */
{ 2900708 }, /* unc_cha_iodc_dealloc.all\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to any reason. Unit: uncore_cha \000event=0x63,umask=0x10\000\00001\000\000 */
{ 2900875 }, /* unc_cha_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to conflicting transaction. Unit: uncore_cha \000event=0x63,umask=0x8\000\00001\000\000 */
{ 2901057 }, /* unc_cha_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00001\000\000 */
{ 2901222 }, /* unc_cha_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00001\000\000 */
{ 2901387 }, /* unc_cha_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbPushMtoI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00001\000Moved to Cbo section\000 */
{ 2903523 }, /* unc_cha_llc_lookup.any\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2913171 }, /* unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2928303 }, /* unc_cha_llc_lookup.local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Local. Unit: uncore_cha \000event=0x34,umask=0x31\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000 */
{ 2950278 }, /* unc_cha_llc_lookup.remote\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Remote. Unit: uncore_cha \000event=0x34,umask=0x91\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000 */
{ 2955522 }, /* unc_cha_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; External Snoop Request. Unit: uncore_cha \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2968298 }, /* unc_cha_llc_lookup.write\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Write Requests. Unit: uncore_cha \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2972000 }, /* unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000 */
{ 2972170 }, /* unc_cha_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000 */
{ 2974017 }, /* unc_cha_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x37,umask=0x20\000\00011\000\000 */
{ 2974682 }, /* unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized; Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975486 }, /* unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x22\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975741 }, /* unc_cha_llc_victims.local_f\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x28\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976550 }, /* unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x21\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977625 }, /* unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x24\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2978165 }, /* unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000 */
{ 2978335 }, /* unc_cha_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000 */
{ 2979057 }, /* unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized; Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x8f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2979867 }, /* unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x82\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980124 }, /* unc_cha_llc_victims.remote_f\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x88\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980939 }, /* unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x81\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982023 }, /* unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x84\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982565 }, /* unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000 */
{ 2983001 }, /* unc_cha_llc_victims.total_e\000uncore_cha\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2983247 }, /* unc_cha_llc_victims.total_f\000uncore_cha\000uncore cache\000Lines Victimized; Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2983759 }, /* unc_cha_llc_victims.total_m\000uncore_cha\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984271 }, /* unc_cha_llc_victims.total_s\000uncore_cha\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984705 }, /* unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2985052 }, /* unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2985209 }, /* unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000 */
{ 2985815 }, /* unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2986519 }, /* unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2989072 }, /* unc_cha_osb\000uncore_cha\000uncore cache\000OSB Snoop Broadcast. Unit: uncore_cha \000event=0x55\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2995618 }, /* unc_cha_pmm_memmode_nm_setconflicts.iodc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in IODC. Unit: uncore_cha \000event=0x64,umask=0x10\000\00001\0002LM related events; Counts the number of times CHA saw NM Set conflict in IODC\000 */
{ 2995894 }, /* unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000NM evictions due to another read to the same near memory set in the LLC\000 */
{ 2996822 }, /* unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000NM evictions due to another read to the same near memory set in the SF\000 */
{ 2997744 }, /* unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw NM Set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000No Reject in the CHA due to a pending read to the same near memory set in the TOR\000 */
{ 2998681 }, /* unc_cha_pmm_memmode_nm_setconflicts.tor_reject\000uncore_cha\000uncore cache\000Memory mode related events; Counts the number of times CHA saw NM Set conflict in TOR and the transaction was rejected. Unit: uncore_cha \000event=0x64,umask=0x8\000\00001\000Rejects in the CHA due to a pending read to the same near memory set in the TOR\000 */
{ 3000928 }, /* unc_cha_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 2 only\000 */
{ 3001337 }, /* unc_cha_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 3 only\000 */
{ 3001746 }, /* unc_cha_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 4 only\000 */
{ 3002156 }, /* unc_cha_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 5 only\000 */
{ 3003005 }, /* unc_cha_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 0 only\000 */
{ 3005583 }, /* unc_cha_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 1 only\000 */
{ 3010612 }, /* unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3010945 }, /* unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line without receiving data. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3012545 }, /* unc_cha_requests.reads\000uncore_cha\000uncore cache\000Read requests. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000 */
{ 3013130 }, /* unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Read requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3013437 }, /* unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Read requests from a remote socket. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3014622 }, /* unc_cha_requests.writes\000uncore_cha\000uncore cache\000Write requests. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015208 }, /* unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Write Requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015517 }, /* unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Read and Write Requests; Writes Remote. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3016450 }, /* unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3016982 }, /* unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017514 }, /* unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018046 }, /* unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018572 }, /* unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019138 }, /* unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020000 }, /* unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020593 }, /* unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020996 }, /* unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 3021281 }, /* unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 3021596 }, /* unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 3021911 }, /* unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 3022196 }, /* unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 3022479 }, /* unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 3022782 }, /* unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 3023243 }, /* unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 3023569 }, /* unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 3023734 }, /* unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xa4\000\00001\000\000 */
{ 3024170 }, /* unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024610 }, /* unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025072 }, /* unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025526 }, /* unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025972 }, /* unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026418 }, /* unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026860 }, /* unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3027322 }, /* unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000\000 */
{ 3027731 }, /* unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000\000 */
{ 3028137 }, /* unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000\000 */
{ 3028535 }, /* unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000\000 */
{ 3028928 }, /* unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000\000 */
{ 3029338 }, /* unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000\000 */
{ 3029745 }, /* unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000\000 */
{ 3030149 }, /* unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000\000 */
{ 3030461 }, /* unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000 */
{ 3030858 }, /* unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000\000 */
{ 3031132 }, /* unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000 */
{ 3031540 }, /* unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000\000 */
{ 3031893 }, /* unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000 */
{ 3032315 }, /* unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000\000 */
{ 3032717 }, /* unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000\000 */
{ 3033010 }, /* unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000 */
{ 3033408 }, /* unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000\000 */
{ 3033830 }, /* unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000\000 */
{ 3034249 }, /* unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000\000 */
{ 3034660 }, /* unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000\000 */
{ 3035066 }, /* unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000\000 */
{ 3035489 }, /* unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000\000 */
{ 3035909 }, /* unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000\000 */
{ 3036326 }, /* unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000\000 */
{ 3036651 }, /* unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3037061 }, /* unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000\000 */
{ 3037348 }, /* unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000 */
{ 3037769 }, /* unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000\000 */
{ 3038135 }, /* unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000 */
{ 3038292 }, /* unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3038707 }, /* unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000\000 */
{ 3039013 }, /* unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000 */
{ 3039644 }, /* unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3040514 }, /* unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3041381 }, /* unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3042240 }, /* unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3043094 }, /* unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3043965 }, /* unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3044833 }, /* unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3045698 }, /* unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3046572 }, /* unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3047440 }, /* unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3048305 }, /* unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3049162 }, /* unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3050014 }, /* unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3050883 }, /* unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3051749 }, /* unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3052612 }, /* unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3053478 }, /* unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects; ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3054257 }, /* unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects; HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3055098 }, /* unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries; ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3055875 }, /* unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries; HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3056479 }, /* unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3056913 }, /* unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057348 }, /* unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057784 }, /* unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3058333 }, /* unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3058941 }, /* unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3059546 }, /* unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3060143 }, /* unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3060735 }, /* unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3061344 }, /* unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3061950 }, /* unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3062553 }, /* unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063118 }, /* unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries; Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063716 }, /* unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries; ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064234 }, /* unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries; HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064841 }, /* unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3065446 }, /* unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries; LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3066067 }, /* unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3066668 }, /* unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries; SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067209 }, /* unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries; Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067456 }, /* unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3067877 }, /* unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3068299 }, /* unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000\000 */
{ 3068724 }, /* unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000\000 */
{ 3069130 }, /* unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000\000 */
{ 3069536 }, /* unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3069958 }, /* unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000\000 */
{ 3070376 }, /* unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000\000 */
{ 3070801 }, /* unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3071118 }, /* unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000\000 */
{ 3071515 }, /* unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000 */
{ 3071798 }, /* unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000\000 */
{ 3072242 }, /* unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000 */
{ 3072557 }, /* unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000\000 */
{ 3072994 }, /* unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000\000 */
{ 3073405 }, /* unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000 */
{ 3074021 }, /* unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3074551 }, /* unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3075078 }, /* unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3075597 }, /* unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3076111 }, /* unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3076642 }, /* unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3077170 }, /* unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3077695 }, /* unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078182 }, /* unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries; Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078700 }, /* unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries; ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079140 }, /* unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries; HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079669 }, /* unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080196 }, /* unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries; LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080739 }, /* unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081262 }, /* unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries; SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081725 }, /* unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries; Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3082242 }, /* unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3082777 }, /* unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3083309 }, /* unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3083833 }, /* unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3084352 }, /* unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3084888 }, /* unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3085421 }, /* unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3085951 }, /* unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086442 }, /* unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086965 }, /* unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects; ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087409 }, /* unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects; HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087943 }, /* unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3088474 }, /* unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3089022 }, /* unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3089550 }, /* unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects; SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090017 }, /* unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects; Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090535 }, /* unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3091058 }, /* unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3091578 }, /* unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3092090 }, /* unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3092597 }, /* unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3093121 }, /* unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3093642 }, /* unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094160 }, /* unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094639 }, /* unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095150 }, /* unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects; ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095582 }, /* unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects; HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096104 }, /* unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096623 }, /* unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3097159 }, /* unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3097675 }, /* unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects; SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3098130 }, /* unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects; Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3098794 }, /* unc_cha_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3099616 }, /* unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100903 }, /* unc_cha_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3101725 }, /* unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102799 }, /* unc_cha_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3103201 }, /* unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3103807 }, /* unc_cha_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3104464 }, /* unc_cha_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3104866 }, /* unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3105472 }, /* unc_cha_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3106120 }, /* unc_cha_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3106964 }, /* unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3108236 }, /* unc_cha_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3109102 }, /* unc_cha_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3109946 }, /* unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3111244 }, /* unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112060 }, /* unc_cha_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3113177 }, /* unc_cha_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3113724 }, /* unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114550 }, /* unc_cha_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115427 }, /* unc_cha_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115974 }, /* unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116800 }, /* unc_cha_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117374 }, /* unc_cha_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117935 }, /* unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118781 }, /* unc_cha_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119678 }, /* unc_cha_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120239 }, /* unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121085 }, /* unc_cha_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121340 }, /* unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3122286 }, /* unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3123230 }, /* unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3124170 }, /* unc_cha_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000Rsp*Fwd*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Counts when a transaction with the opcode type Rsp*Fwd*WB Snoop Response was received which indicates the data was written back to its home socket, and the cacheline was forwarded to the requestor socket.  This snoop response is only used in >= 4 socket systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to its home socket to be written back to memory\000 */
{ 3124752 }, /* unc_cha_snoop_resp.rsp_wbwb\000uncore_cha\000uncore cache\000Rsp*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Counts when a transaction with the opcode type Rsp*WB Snoop Response was received which indicates which indicates the data was written back to its home.  This is returned when a non-RFO request hits a cacheline in the Modified state. The Cache can either downgrade the cacheline to a S (Shared) or I (Invalid) state depending on how the system has been configured.  This response will also be sent when a cache requests E (Exclusive) ownership of a cache line without receiving data, because the cache must acquire ownership\000 */
{ 3126267 }, /* unc_cha_snoop_resp.rspcnflcts\000uncore_cha\000uncore cache\000RspCnflct* Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Counts when a a transaction with the opcode type RspCnflct* Snoop Response was received. This is returned when a snoop finds an existing outstanding transaction in a remote caching agent. This triggers conflict resolution hardware. This covers both the opcode RspCnflct and RspCnflctWbI\000 */
{ 3127517 }, /* unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received; RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3129170 }, /* unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000RspI Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000 */
{ 3129964 }, /* unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000RspIFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000 */
{ 3131886 }, /* unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received : RspS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Snoop Responses Received : RspS : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3132693 }, /* unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000RspSFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000 */
{ 3134392 }, /* unc_cha_snoop_resp_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3134888 }, /* unc_cha_snoop_resp_local.rsp_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3135939 }, /* unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3136921 }, /* unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3138358 }, /* unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3139285 }, /* unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3140247 }, /* unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3141659 }, /* unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3143797 }, /* unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent; All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Counts the number of snoops issued by the HA\000 */
{ 3144650 }, /* unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoop for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3145670 }, /* unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA.This filter includes only requests coming from remote sockets\000 */
{ 3146684 }, /* unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3147704 }, /* unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from remote sockets\000 */
{ 3148772 }, /* unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the local socket\000 */
{ 3149883 }, /* unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the remote socket\000 */
{ 3165727 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166014 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166301 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166588 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166875 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167163 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167451 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167738 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168025 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168312 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168599 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168887 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169175 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169462 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169749 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170036 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170323 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170611 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170899 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171186 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171473 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171760 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172047 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172335 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3173199 }, /* unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts; All. Unit: uncore_cha \000event=0x35,umask=0xff\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3173425 }, /* unc_cha_tor_inserts.all_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local. Unit: uncore_cha \000event=0x35,umask=0x15\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3173667 }, /* unc_cha_tor_inserts.all_io_ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0x35\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests\000 */
{ 3173953 }, /* unc_cha_tor_inserts.all_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local. Unit: uncore_cha \000event=0x35,umask=0x25\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3175701 }, /* unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts; SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3176586 }, /* unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts; Hit (Not a Miss). Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000 */
{ 3177630 }, /* unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests from iA Cores\000 */
{ 3183533 }, /* unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local iA. Unit: uncore_cha \000event=0x35,umask=0x11\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3183777 }, /* unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3185823 }, /* unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3190857 }, /* unc_cha_tor_inserts.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b233\000\00001\000\000 */
{ 3191894 }, /* unc_cha_tor_inserts.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b433\000\00001\000\000 */
{ 3192056 }, /* unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3193170 }, /* unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3198531 }, /* unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3199737 }, /* unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3205429 }, /* unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3227466 }, /* unc_cha_tor_inserts.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b233\000\00001\000\000 */
{ 3228752 }, /* unc_cha_tor_inserts.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b433\000\00001\000\000 */
{ 3228916 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3239874 }, /* unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3259197 }, /* unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts; All from Local IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally generated IO traffic\000 */
{ 3260917 }, /* unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local IO. Unit: uncore_cha \000event=0x35,umask=0x14\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3267820 }, /* unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3268808 }, /* unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x49033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM request is used by IIO to request a data write without first reading the data for ownership\000 */
{ 3270884 }, /* unc_cha_tor_inserts.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x43C33\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RdCur requests and miss the LLC. A RdCur request is used by IIO to read data without changing state\000 */
{ 3271655 }, /* unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x40033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests a cache line to be cached in E state with the intent to modify\000 */
{ 3275022 }, /* unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts; IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3275247 }, /* unc_cha_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000 */
{ 3275370 }, /* unc_cha_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000 */
{ 3275494 }, /* unc_cha_tor_inserts.irq\000uncore_cha\000uncore cache\000TOR Inserts; IRQ. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3278263 }, /* unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000 */
{ 3281786 }, /* unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts; Miss. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000 */
{ 3286529 }, /* unc_cha_tor_inserts.prq\000uncore_cha\000uncore cache\000TOR Inserts; PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3288384 }, /* unc_cha_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000 */
{ 3290043 }, /* unc_cha_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000 */
{ 3290166 }, /* unc_cha_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000 */
{ 3291169 }, /* unc_cha_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000 */
{ 3291292 }, /* unc_cha_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000 */
{ 3291694 }, /* unc_cha_tor_occupancy.all\000uncore_cha\000uncore cache\000TOR Occupancy : All. Unit: uncore_cha \000event=0x36,umask=0xff\000\00001\000TOR Occupancy : All : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3292033 }, /* unc_cha_tor_occupancy.all_from_loc\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local. Unit: uncore_cha \000event=0x36,umask=0x37\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All remotely generated requests\000 */
{ 3292681 }, /* unc_cha_tor_occupancy.all_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local. Unit: uncore_cha \000event=0x36,umask=0x17\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3292946 }, /* unc_cha_tor_occupancy.all_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local. Unit: uncore_cha \000event=0x36,umask=0x27\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3294652 }, /* unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy; SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3295606 }, /* unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hit (Not a Miss). Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000 */
{ 3296402 }, /* unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local iA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally initiated requests from iA Cores\000 */
{ 3302556 }, /* unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local iA. Unit: uncore_cha \000event=0x36,umask=0x11\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3303225 }, /* unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3305373 }, /* unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3310595 }, /* unc_cha_tor_occupancy.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b233\000\00001\000\000 */
{ 3311466 }, /* unc_cha_tor_occupancy.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b433\000\00001\000\000 */
{ 3311632 }, /* unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3312796 }, /* unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3318170 }, /* unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local iA. Unit: uncore_cha \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3318440 }, /* unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3322797 }, /* unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3340534 }, /* unc_cha_tor_occupancy.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b233\000\00001\000\000 */
{ 3341876 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b433\000\00001\000\000 */
{ 3342044 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3349467 }, /* unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3362576 }, /* unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally generated IO traffic\000 */
{ 3364092 }, /* unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local IO. Unit: uncore_cha \000event=0x36,umask=0x14\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3370079 }, /* unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3371199 }, /* unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy;  ITOM Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x49033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM is used by IIO to request a data write without first reading the data for ownership\000 */
{ 3373437 }, /* unc_cha_tor_occupancy.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Occupancy;  RDCUR misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x43C33\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RdCur requests that miss the LLC. A RdCur request is used by IIO to read data without changing state\000 */
{ 3374250 }, /* unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy;  RFO misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x40033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests data to be cached in E state with the intent to modify\000 */
{ 3377659 }, /* unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy; IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3377907 }, /* unc_cha_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000 */
{ 3378032 }, /* unc_cha_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000 */
{ 3378158 }, /* unc_cha_tor_occupancy.irq\000uncore_cha\000uncore cache\000TOR Occupancy; IRQ. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3381136 }, /* unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.ALL_FROM_LOC. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000 */
{ 3384949 }, /* unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy; Miss. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000 */
{ 3390697 }, /* unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy; PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3394228 }, /* unc_cha_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3394746 }, /* unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395270 }, /* unc_cha_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395810 }, /* unc_cha_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396328 }, /* unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3397152 }, /* unc_cha_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3397659 }, /* unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398423 }, /* unc_cha_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399239 }, /* unc_cha_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399746 }, /* unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400510 }, /* unc_cha_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3401136 }, /* unc_cha_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3401821 }, /* unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402860 }, /* unc_cha_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403951 }, /* unc_cha_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3404636 }, /* unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405675 }, /* unc_cha_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3406395 }, /* unc_cha_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407101 }, /* unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_cha \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408174 }, /* unc_cha_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3409299 }, /* unc_cha_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_cha \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410005 }, /* unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_cha \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411078 }, /* unc_cha_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_cha \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411773 }, /* unc_cha_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3412431 }, /* unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_cha \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413423 }, /* unc_cha_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3414467 }, /* unc_cha_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_cha \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415125 }, /* unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_cha \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416117 }, /* unc_cha_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_cha \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416695 }, /* unc_cha_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417153 }, /* unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_cha \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417844 }, /* unc_cha_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418586 }, /* unc_cha_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_cha \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419044 }, /* unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_cha \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419735 }, /* unc_cha_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_cha \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3420315 }, /* unc_cha_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3420969 }, /* unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421956 }, /* unc_cha_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422995 }, /* unc_cha_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3423649 }, /* unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424636 }, /* unc_cha_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3425345 }, /* unc_cha_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426422 }, /* unc_cha_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3427551 }, /* unc_cha_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428628 }, /* unc_cha_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3429224 }, /* unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429731 }, /* unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429965 }, /* unc_cha_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430198 }, /* unc_cha_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430705 }, /* unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431212 }, /* unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431709 }, /* unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432196 }, /* unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432683 }, /* unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433170 }, /* unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433657 }, /* unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434144 }, /* unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434368 }, /* unc_cha_txr_vert_bypass.iv\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3435376 }, /* unc_cha_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3435814 }, /* unc_cha_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3436221 }, /* unc_cha_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3436641 }, /* unc_cha_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3437002 }, /* unc_cha_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3437438 }, /* unc_cha_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3437868 }, /* unc_cha_txr_vert_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3442575 }, /* unc_cha_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3443017 }, /* unc_cha_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3443428 }, /* unc_cha_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3443852 }, /* unc_cha_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3444217 }, /* unc_cha_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3444657 }, /* unc_cha_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3445091 }, /* unc_cha_txr_vert_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3449883 }, /* unc_cha_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3450301 }, /* unc_cha_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3450688 }, /* unc_cha_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3451088 }, /* unc_cha_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3451429 }, /* unc_cha_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3451845 }, /* unc_cha_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3452255 }, /* unc_cha_txr_vert_inserts.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3456645 }, /* unc_cha_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3456846 }, /* unc_cha_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457048 }, /* unc_cha_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457249 }, /* unc_cha_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457451 }, /* unc_cha_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457652 }, /* unc_cha_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457854 }, /* unc_cha_txr_vert_nack.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3460244 }, /* unc_cha_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3460669 }, /* unc_cha_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3461063 }, /* unc_cha_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3461470 }, /* unc_cha_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3461818 }, /* unc_cha_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3462241 }, /* unc_cha_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3462658 }, /* unc_cha_txr_vert_occupancy.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3467100 }, /* unc_cha_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3467409 }, /* unc_cha_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3467719 }, /* unc_cha_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468028 }, /* unc_cha_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468338 }, /* unc_cha_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468647 }, /* unc_cha_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468957 }, /* unc_cha_txr_vert_starved.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472930 }, /* unc_cha_upi_credit_occupancy.vn0_ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD REQ VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x4\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3473763 }, /* unc_cha_upi_credit_occupancy.vn0_ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x8\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3474596 }, /* unc_cha_upi_credit_occupancy.vn0_bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCB VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x40\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3475430 }, /* unc_cha_upi_credit_occupancy.vn0_bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x80\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3476264 }, /* unc_cha_upi_credit_occupancy.vn0_bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x10\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3477098 }, /* unc_cha_upi_credit_occupancy.vn0_bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL DRS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x20\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3477931 }, /* unc_cha_upi_credit_occupancy.vna_ad\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x1\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3478756 }, /* unc_cha_upi_credit_occupancy.vna_bl\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x2\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3479581 }, /* unc_cha_upi_credits_acquired.ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD REQ Credits. Unit: uncore_cha \000event=0x38,umask=0x4\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3480300 }, /* unc_cha_upi_credits_acquired.ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x8\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3481023 }, /* unc_cha_upi_credits_acquired.bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCB Credits. Unit: uncore_cha \000event=0x38,umask=0x40\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3481743 }, /* unc_cha_upi_credits_acquired.bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCS Credits. Unit: uncore_cha \000event=0x38,umask=0x80\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3482463 }, /* unc_cha_upi_credits_acquired.bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL RSP Credits. Unit: uncore_cha \000event=0x38,umask=0x10\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3483183 }, /* unc_cha_upi_credits_acquired.bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL DRS Credits. Unit: uncore_cha \000event=0x38,umask=0x20\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3483902 }, /* unc_cha_upi_credits_acquired.vn0\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x2\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3484615 }, /* unc_cha_upi_credits_acquired.vna\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VNA Credits. Unit: uncore_cha \000event=0x38,umask=0x1\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3486241 }, /* unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3488021 }, /* unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3489798 }, /* unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3491572 }, /* unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3493351 }, /* unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3495131 }, /* unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3496908 }, /* unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3498682 }, /* unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3504129 }, /* unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Even. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3505905 }, /* unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3507678 }, /* unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Even. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3509448 }, /* unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3510897 }, /* unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Down. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3512029 }, /* unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Up. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3516538 }, /* unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was able to push WbPushMToI to LLC\000 */
{ 3517120 }, /* unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000 */
{ 3517409 }, /* unc_cha_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 2 only\000 */
{ 3517822 }, /* unc_cha_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 3 only\000 */
{ 3518235 }, /* unc_cha_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 4 only\000 */
{ 3518649 }, /* unc_cha_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 5 only\000 */
{ 3519507 }, /* unc_cha_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 0 only\000 */
{ 3522114 }, /* unc_cha_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 1 only\000 */
{ 3527470 }, /* unc_cha_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response any to Hit F/S/E\000 */
{ 3528109 }, /* unc_cha_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd F/E\000 */
{ 3528744 }, /* unc_cha_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd M\000 */
{ 3529361 }, /* unc_cha_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd F/E\000 */
{ 3529996 }, /* unc_cha_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd M\000 */
{ 3530627 }, /* unc_cha_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response any to Hit F/S/E\000 */
{ 3531269 }, /* unc_cha_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd F/E\000 */
{ 3531907 }, /* unc_cha_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd M\000 */
{ 3532541 }, /* unc_cha_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd F/E\000 */
{ 3533179 }, /* unc_cha_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd M\000 */
{ 3533813 }, /* unc_cha_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response any to Hit F/S/E\000 */
{ 3534461 }, /* unc_cha_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd F/E\000 */
{ 3535105 }, /* unc_cha_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd M\000 */
{ 3535745 }, /* unc_cha_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd F/E\000 */
{ 3536389 }, /* unc_cha_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd M\000 */
{ 3537029 }, /* unc_cha_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response any to Hit F/S/E\000 */
{ 3537678 }, /* unc_cha_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd F/E\000 */
{ 3538323 }, /* unc_cha_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd M\000 */
{ 3538964 }, /* unc_cha_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd F/E\000 */
{ 3539609 }, /* unc_cha_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd M\000 */
{ 3551478 }, /* unc_h_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00011\000\000 */
{ 3551804 }, /* unc_h_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00011\000\000 */
{ 3552130 }, /* unc_h_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00011\000\000 */
{ 3552456 }, /* unc_h_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00011\000\000 */
{ 3552783 }, /* unc_h_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00011\000\000 */
{ 3553111 }, /* unc_h_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00011\000\000 */
{ 3554061 }, /* unc_h_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00011\000\000 */
{ 3554391 }, /* unc_h_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00011\000\000 */
{ 3554721 }, /* unc_h_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00011\000\000 */
{ 3555051 }, /* unc_h_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00011\000\000 */
{ 3555382 }, /* unc_h_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00011\000\000 */
{ 3555714 }, /* unc_h_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00011\000\000 */
{ 3556672 }, /* unc_h_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00011\000\000 */
{ 3556998 }, /* unc_h_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00011\000\000 */
{ 3557324 }, /* unc_h_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00011\000\000 */
{ 3557650 }, /* unc_h_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00011\000\000 */
{ 3557977 }, /* unc_h_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00011\000\000 */
{ 3558305 }, /* unc_h_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00011\000\000 */
{ 3559255 }, /* unc_h_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00011\000\000 */
{ 3559585 }, /* unc_h_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00011\000\000 */
{ 3559915 }, /* unc_h_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00011\000\000 */
{ 3560245 }, /* unc_h_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00011\000\000 */
{ 3560576 }, /* unc_h_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00011\000\000 */
{ 3560908 }, /* unc_h_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00011\000\000 */
{ 3565188 }, /* unc_h_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00011\000\000 */
{ 3565514 }, /* unc_h_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00011\000\000 */
{ 3565840 }, /* unc_h_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00011\000\000 */
{ 3566166 }, /* unc_h_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00011\000\000 */
{ 3566493 }, /* unc_h_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00011\000\000 */
{ 3566821 }, /* unc_h_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00011\000\000 */
{ 3567771 }, /* unc_h_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00011\000\000 */
{ 3568101 }, /* unc_h_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00011\000\000 */
{ 3568431 }, /* unc_h_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00011\000\000 */
{ 3568761 }, /* unc_h_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00011\000\000 */
{ 3569092 }, /* unc_h_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00011\000\000 */
{ 3569424 }, /* unc_h_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00011\000\000 */
{ 3571895 }, /* unc_h_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00011\000\000 */
{ 3572225 }, /* unc_h_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00011\000\000 */
{ 3572555 }, /* unc_h_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00011\000\000 */
{ 3572885 }, /* unc_h_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00011\000\000 */
{ 3573216 }, /* unc_h_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00011\000\000 */
{ 3573548 }, /* unc_h_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00011\000\000 */
{ 3574358 }, /* unc_h_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00011\000\000 */
{ 3574544 }, /* unc_h_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00011\000\000 */
{ 3574730 }, /* unc_h_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00011\000\000 */
{ 3574916 }, /* unc_h_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00011\000\000 */
{ 3575102 }, /* unc_h_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00011\000\000 */
{ 3575289 }, /* unc_h_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00011\000\000 */
{ 3583813 }, /* unc_h_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.INTERMEDIATE. Unit: uncore_cha \000event=0x57,umask=0x2\000\00011\000\000 */
{ 3583997 }, /* unc_h_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.NOT_TAKEN. Unit: uncore_cha \000event=0x57,umask=0x4\000\00011\000\000 */
{ 3584175 }, /* unc_h_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.TAKEN. Unit: uncore_cha \000event=0x57,umask=0x1\000\00011\000\000 */
{ 3587190 }, /* unc_h_clock\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CMS_CLOCKTICKS. Unit: uncore_cha \000event=0xc0\000\00011\000\000 */
{ 3588958 }, /* unc_h_core_pma.c1_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_STATE. Unit: uncore_cha \000event=0x17,umask=0x1\000\00011\000\000 */
{ 3589122 }, /* unc_h_core_pma.c1_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x2\000\00011\000\000 */
{ 3589296 }, /* unc_h_core_pma.c6_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_STATE. Unit: uncore_cha \000event=0x17,umask=0x4\000\00011\000\000 */
{ 3589460 }, /* unc_h_core_pma.c6_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x8\000\00011\000\000 */
{ 3589634 }, /* unc_h_core_pma.gv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00011\000\000 */
{ 3589787 }, /* unc_h_core_snp.any_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_GTONE. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00011\000\000 */
{ 3589954 }, /* unc_h_core_snp.any_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_ONE. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00011\000\000 */
{ 3590117 }, /* unc_h_core_snp.any_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_REMOTE. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00011\000\000 */
{ 3590286 }, /* unc_h_core_snp.core_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_GTONE. Unit: uncore_cha \000event=0x33,umask=0x42\000\00011\000\000 */
{ 3590455 }, /* unc_h_core_snp.core_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_ONE. Unit: uncore_cha \000event=0x33,umask=0x41\000\00011\000\000 */
{ 3590620 }, /* unc_h_core_snp.core_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x44\000\00011\000\000 */
{ 3590791 }, /* unc_h_core_snp.evict_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x82\000\00011\000\000 */
{ 3590962 }, /* unc_h_core_snp.evict_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_ONE. Unit: uncore_cha \000event=0x33,umask=0x81\000\00011\000\000 */
{ 3591129 }, /* unc_h_core_snp.evict_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x84\000\00011\000\000 */
{ 3591302 }, /* unc_h_core_snp.ext_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x22\000\00011\000\000 */
{ 3591469 }, /* unc_h_core_snp.ext_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_ONE. Unit: uncore_cha \000event=0x33,umask=0x21\000\00011\000\000 */
{ 3591632 }, /* unc_h_core_snp.ext_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x24\000\00011\000\000 */
{ 3591801 }, /* unc_h_counter0_occupancy\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_COUNTER0_OCCUPANCY. Unit: uncore_cha \000event=0x1f\000\00011\000\000 */
{ 3591957 }, /* unc_h_dir_lookup.no_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.NO_SNP. Unit: uncore_cha \000event=0x53,umask=0x2\000\00011\000\000 */
{ 3592121 }, /* unc_h_dir_lookup.snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.SNP. Unit: uncore_cha \000event=0x53,umask=0x1\000\00011\000\000 */
{ 3592279 }, /* unc_h_dir_update.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.HA. Unit: uncore_cha \000event=0x54,umask=0x1\000\00011\000\000 */
{ 3592435 }, /* unc_h_dir_update.tor\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.TOR. Unit: uncore_cha \000event=0x54,umask=0x2\000\00011\000\000 */
{ 3603946 }, /* unc_h_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_DN. Unit: uncore_cha \000event=0xae,umask=0x4\000\00011\000\000 */
{ 3604134 }, /* unc_h_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_UP. Unit: uncore_cha \000event=0xae,umask=0x1\000\00011\000\000 */
{ 3613554 }, /* unc_h_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.EX_RDS. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00011\000\000 */
{ 3614908 }, /* unc_h_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.SHARED_OWNREQ. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00011\000\000 */
{ 3615084 }, /* unc_h_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00011\000\000 */
{ 3615543 }, /* unc_h_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOI_OR_S. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00011\000\000 */
{ 3618419 }, /* unc_h_hitme_lookup.read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.READ. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00011\000\000 */
{ 3619882 }, /* unc_h_hitme_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.WRITE. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00011\000\000 */
{ 3620048 }, /* unc_h_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.NOTSHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x40\000\00011\000\000 */
{ 3620237 }, /* unc_h_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.READ_OR_INV. Unit: uncore_cha \000event=0x60,umask=0x80\000\00011\000\000 */
{ 3620412 }, /* unc_h_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.SHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x20\000\00011\000\000 */
{ 3620595 }, /* unc_h_hitme_update.deallocate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE. Unit: uncore_cha \000event=0x61,umask=0x10\000\00011\000\000 */
{ 3620772 }, /* unc_h_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE_RSPFWDI_LOC. Unit: uncore_cha \000event=0x61,umask=0x1\000\00011\000\000 */
{ 3620972 }, /* unc_h_hitme_update.rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RDINVOWN. Unit: uncore_cha \000event=0x61,umask=0x8\000\00011\000\000 */
{ 3621144 }, /* unc_h_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RSPFWDI_REM. Unit: uncore_cha \000event=0x61,umask=0x2\000\00011\000\000 */
{ 3621322 }, /* unc_h_hitme_update.shared\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.SHARED. Unit: uncore_cha \000event=0x61,umask=0x4\000\00011\000\000 */
{ 3621699 }, /* unc_h_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00011\000\000 */
{ 3622094 }, /* unc_h_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00011\000\000 */
{ 3622491 }, /* unc_h_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00011\000\000 */
{ 3622890 }, /* unc_h_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00011\000\000 */
{ 3623287 }, /* unc_h_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00011\000\000 */
{ 3623682 }, /* unc_h_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00011\000\000 */
{ 3624079 }, /* unc_h_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00011\000\000 */
{ 3624478 }, /* unc_h_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00011\000\000 */
{ 3624875 }, /* unc_h_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x1\000\00011\000\000 */
{ 3625270 }, /* unc_h_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xab,umask=0x2\000\00011\000\000 */
{ 3625667 }, /* unc_h_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x4\000\00011\000\000 */
{ 3626066 }, /* unc_h_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xab,umask=0x8\000\00011\000\000 */
{ 3626449 }, /* unc_h_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.LEFT. Unit: uncore_cha \000event=0xad,umask=0x1\000\00011\000\000 */
{ 3626824 }, /* unc_h_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.RIGHT. Unit: uncore_cha \000event=0xad,umask=0x4\000\00011\000\000 */
{ 3630030 }, /* unc_h_imc_reads_count.normal\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.NORMAL. Unit: uncore_cha \000event=0x59,umask=0x1\000\00011\000\000 */
{ 3630204 }, /* unc_h_imc_reads_count.priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.PRIORITY. Unit: uncore_cha \000event=0x59,umask=0x2\000\00011\000\000 */
{ 3632094 }, /* unc_h_imc_writes_count.full\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00011\000\000 */
{ 3632266 }, /* unc_h_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00011\000\000 */
{ 3632447 }, /* unc_h_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00011\000\000 */
{ 3632637 }, /* unc_h_imc_writes_count.partial\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00011\000\000 */
{ 3632815 }, /* unc_h_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00011\000\000 */
{ 3633002 }, /* unc_h_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00011\000\000 */
{ 3647627 }, /* unc_h_iodc_alloc.invitom\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.INVITOM. Unit: uncore_cha \000event=0x62,umask=0x1\000\00011\000\000 */
{ 3647793 }, /* unc_h_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.IODCFULL. Unit: uncore_cha \000event=0x62,umask=0x2\000\00011\000\000 */
{ 3647961 }, /* unc_h_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.OSBGATED. Unit: uncore_cha \000event=0x62,umask=0x4\000\00011\000\000 */
{ 3648682 }, /* unc_h_iodc_dealloc.all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.ALL. Unit: uncore_cha \000event=0x63,umask=0x10\000\00011\000\000 */
{ 3648845 }, /* unc_h_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.SNPOUT. Unit: uncore_cha \000event=0x63,umask=0x8\000\00011\000\000 */
{ 3649013 }, /* unc_h_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00011\000\000 */
{ 3649181 }, /* unc_h_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00011\000\000 */
{ 3649349 }, /* unc_h_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBPUSHMTOI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00011\000\000 */
{ 3651067 }, /* unc_h_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_MISS. Unit: uncore_cha \000event=0x39,umask=0x20\000\00011\000\000 */
{ 3651381 }, /* unc_h_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_VIC. Unit: uncore_cha \000event=0x39,umask=0x10\000\00011\000\000 */
{ 3651678 }, /* unc_h_misc.rfo_hit_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RFO_HIT_S. Unit: uncore_cha \000event=0x39,umask=0x8\000\00011\000\000 */
{ 3651984 }, /* unc_h_misc.rspi_was_fse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RSPI_WAS_FSE. Unit: uncore_cha \000event=0x39,umask=0x1\000\00011\000\000 */
{ 3652298 }, /* unc_h_misc.wc_aliasing\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.WC_ALIASING. Unit: uncore_cha \000event=0x39,umask=0x2\000\00011\000\000 */
{ 3654323 }, /* unc_h_osb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_OSB. Unit: uncore_cha \000event=0x55\000\00011\000\000 */
{ 3655777 }, /* unc_h_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00011\000\000 */
{ 3655957 }, /* unc_h_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00011\000\000 */
{ 3656137 }, /* unc_h_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00011\000\000 */
{ 3656318 }, /* unc_h_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00011\000\000 */
{ 3656499 }, /* unc_h_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00011\000\000 */
{ 3656677 }, /* unc_h_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00011\000\000 */
{ 3656855 }, /* unc_h_requests.invitoe_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_LOCAL. Unit: uncore_cha \000event=0x50,umask=0x10\000\00011\000\000 */
{ 3657407 }, /* unc_h_requests.invitoe_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_REMOTE. Unit: uncore_cha \000event=0x50,umask=0x20\000\00011\000\000 */
{ 3657961 }, /* unc_h_requests.reads\000uncore_cha\000uncore cache\000read requests from home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00011\000\000 */
{ 3658751 }, /* unc_h_requests.reads_local\000uncore_cha\000uncore cache\000read requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x1\000\00011\000\000 */
{ 3659341 }, /* unc_h_requests.reads_remote\000uncore_cha\000uncore cache\000read requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x2\000\00011\000\000 */
{ 3659937 }, /* unc_h_requests.writes\000uncore_cha\000uncore cache\000write requests from home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00011\000\000 */
{ 3660675 }, /* unc_h_requests.writes_local\000uncore_cha\000uncore cache\000write requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x4\000\00011\000\000 */
{ 3661180 }, /* unc_h_requests.writes_remote\000uncore_cha\000uncore cache\000write requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x8\000\00011\000\000 */
{ 3686494 }, /* unc_h_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00011\000\000 */
{ 3686872 }, /* unc_h_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00011\000\000 */
{ 3687248 }, /* unc_h_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00011\000\000 */
{ 3687629 }, /* unc_h_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00011\000\000 */
{ 3687978 }, /* unc_h_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00011\000\000 */
{ 3688354 }, /* unc_h_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00011\000\000 */
{ 3688728 }, /* unc_h_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.BL. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00011\000\000 */
{ 3689107 }, /* unc_h_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00011\000\000 */
{ 3689426 }, /* unc_h_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00011\000\000 */
{ 3689755 }, /* unc_h_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00011\000\000 */
{ 3689935 }, /* unc_h_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK_AG1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00011\000\000 */
{ 3690273 }, /* unc_h_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00011\000\000 */
{ 3690602 }, /* unc_h_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00011\000\000 */
{ 3690782 }, /* unc_h_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00011\000\000 */
{ 3691109 }, /* unc_h_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00011\000\000 */
{ 3691436 }, /* unc_h_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.BL. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00011\000\000 */
{ 3691763 }, /* unc_h_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00011\000\000 */
{ 3706145 }, /* unc_h_rxc_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00011\000\000 */
{ 3706305 }, /* unc_h_rxc_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00011\000\000 */
{ 3706465 }, /* unc_h_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x2\000\00011\000\000 */
{ 3706633 }, /* unc_h_rxc_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00011\000\000 */
{ 3706794 }, /* unc_h_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00011\000\000 */
{ 3706963 }, /* unc_h_rxc_inserts.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00011\000\000 */
{ 3707124 }, /* unc_h_rxc_inserts.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00011\000\000 */
{ 3707285 }, /* unc_h_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00011\000\000 */
{ 3707467 }, /* unc_h_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00011\000\000 */
{ 3707649 }, /* unc_h_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00011\000\000 */
{ 3707832 }, /* unc_h_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00011\000\000 */
{ 3708015 }, /* unc_h_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00011\000\000 */
{ 3708197 }, /* unc_h_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00011\000\000 */
{ 3708377 }, /* unc_h_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x23,umask=0x40\000\00011\000\000 */
{ 3708558 }, /* unc_h_rxc_ipq1_reject.any_ipq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00011\000\000 */
{ 3708732 }, /* unc_h_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00011\000\000 */
{ 3708898 }, /* unc_h_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x23,umask=0x20\000\00011\000\000 */
{ 3709087 }, /* unc_h_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x4\000\00011\000\000 */
{ 3709269 }, /* unc_h_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x23,umask=0x80\000\00011\000\000 */
{ 3709448 }, /* unc_h_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x8\000\00011\000\000 */
{ 3709628 }, /* unc_h_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x23,umask=0x10\000\00011\000\000 */
{ 3709803 }, /* unc_h_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00011\000\000 */
{ 3709985 }, /* unc_h_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00011\000\000 */
{ 3710167 }, /* unc_h_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00011\000\000 */
{ 3710350 }, /* unc_h_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00011\000\000 */
{ 3710533 }, /* unc_h_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00011\000\000 */
{ 3710715 }, /* unc_h_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00011\000\000 */
{ 3710895 }, /* unc_h_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x19,umask=0x40\000\00011\000\000 */
{ 3711076 }, /* unc_h_rxc_irq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00011\000\000 */
{ 3711257 }, /* unc_h_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00011\000\000 */
{ 3711423 }, /* unc_h_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x19,umask=0x20\000\00011\000\000 */
{ 3711612 }, /* unc_h_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x4\000\00011\000\000 */
{ 3711794 }, /* unc_h_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x19,umask=0x80\000\00011\000\000 */
{ 3711973 }, /* unc_h_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x8\000\00011\000\000 */
{ 3712153 }, /* unc_h_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x19,umask=0x10\000\00011\000\000 */
{ 3712328 }, /* unc_h_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00011\000\000 */
{ 3712512 }, /* unc_h_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00011\000\000 */
{ 3712696 }, /* unc_h_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00011\000\000 */
{ 3712881 }, /* unc_h_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00011\000\000 */
{ 3713066 }, /* unc_h_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00011\000\000 */
{ 3713250 }, /* unc_h_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00011\000\000 */
{ 3713432 }, /* unc_h_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00011\000\000 */
{ 3713614 }, /* unc_h_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00011\000\000 */
{ 3713796 }, /* unc_h_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00011\000\000 */
{ 3713979 }, /* unc_h_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00011\000\000 */
{ 3714162 }, /* unc_h_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00011\000\000 */
{ 3714344 }, /* unc_h_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00011\000\000 */
{ 3714524 }, /* unc_h_rxc_ismq1_reject.any_ismq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00011\000\000 */
{ 3714701 }, /* unc_h_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00011\000\000 */
{ 3714869 }, /* unc_h_rxc_ismq1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00011\000\000 */
{ 3715038 }, /* unc_h_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00011\000\000 */
{ 3715204 }, /* unc_h_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00011\000\000 */
{ 3715368 }, /* unc_h_rxc_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00011\000\000 */
{ 3715532 }, /* unc_h_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00011\000\000 */
{ 3715697 }, /* unc_h_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00011\000\000 */
{ 3715862 }, /* unc_h_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00011\000\000 */
{ 3716046 }, /* unc_h_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00011\000\000 */
{ 3716230 }, /* unc_h_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00011\000\000 */
{ 3716415 }, /* unc_h_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00011\000\000 */
{ 3716600 }, /* unc_h_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00011\000\000 */
{ 3716784 }, /* unc_h_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00011\000\000 */
{ 3716966 }, /* unc_h_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00011\000\000 */
{ 3717149 }, /* unc_h_rxc_other1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00011\000\000 */
{ 3717320 }, /* unc_h_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00011\000\000 */
{ 3717488 }, /* unc_h_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00011\000\000 */
{ 3717679 }, /* unc_h_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00011\000\000 */
{ 3717863 }, /* unc_h_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00011\000\000 */
{ 3718044 }, /* unc_h_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00011\000\000 */
{ 3718226 }, /* unc_h_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00011\000\000 */
{ 3718403 }, /* unc_h_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00011\000\000 */
{ 3718585 }, /* unc_h_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00011\000\000 */
{ 3718767 }, /* unc_h_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00011\000\000 */
{ 3718950 }, /* unc_h_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00011\000\000 */
{ 3719133 }, /* unc_h_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00011\000\000 */
{ 3719315 }, /* unc_h_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00011\000\000 */
{ 3719495 }, /* unc_h_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x21,umask=0x40\000\00011\000\000 */
{ 3719676 }, /* unc_h_rxc_prq1_reject.any_prq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00011\000\000 */
{ 3719850 }, /* unc_h_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00011\000\000 */
{ 3720016 }, /* unc_h_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x21,umask=0x20\000\00011\000\000 */
{ 3720205 }, /* unc_h_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x4\000\00011\000\000 */
{ 3720387 }, /* unc_h_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x21,umask=0x80\000\00011\000\000 */
{ 3720566 }, /* unc_h_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x8\000\00011\000\000 */
{ 3720746 }, /* unc_h_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x21,umask=0x10\000\00011\000\000 */
{ 3720921 }, /* unc_h_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00011\000\000 */
{ 3721105 }, /* unc_h_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00011\000\000 */
{ 3721289 }, /* unc_h_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00011\000\000 */
{ 3721474 }, /* unc_h_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00011\000\000 */
{ 3721659 }, /* unc_h_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00011\000\000 */
{ 3721843 }, /* unc_h_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00011\000\000 */
{ 3722025 }, /* unc_h_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00011\000\000 */
{ 3722208 }, /* unc_h_rxc_req_q1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00011\000\000 */
{ 3722379 }, /* unc_h_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00011\000\000 */
{ 3722547 }, /* unc_h_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00011\000\000 */
{ 3722738 }, /* unc_h_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00011\000\000 */
{ 3722922 }, /* unc_h_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00011\000\000 */
{ 3723103 }, /* unc_h_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00011\000\000 */
{ 3723285 }, /* unc_h_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00011\000\000 */
{ 3723462 }, /* unc_h_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00011\000\000 */
{ 3723644 }, /* unc_h_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00011\000\000 */
{ 3723826 }, /* unc_h_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00011\000\000 */
{ 3724009 }, /* unc_h_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00011\000\000 */
{ 3724192 }, /* unc_h_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00011\000\000 */
{ 3724374 }, /* unc_h_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00011\000\000 */
{ 3724554 }, /* unc_h_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x27,umask=0x40\000\00011\000\000 */
{ 3724735 }, /* unc_h_rxc_rrq1_reject.any_rrq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00011\000\000 */
{ 3724909 }, /* unc_h_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00011\000\000 */
{ 3725075 }, /* unc_h_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x27,umask=0x20\000\00011\000\000 */
{ 3725264 }, /* unc_h_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x4\000\00011\000\000 */
{ 3725446 }, /* unc_h_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x27,umask=0x80\000\00011\000\000 */
{ 3725625 }, /* unc_h_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x8\000\00011\000\000 */
{ 3725805 }, /* unc_h_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x27,umask=0x10\000\00011\000\000 */
{ 3725980 }, /* unc_h_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00011\000\000 */
{ 3726162 }, /* unc_h_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00011\000\000 */
{ 3726344 }, /* unc_h_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00011\000\000 */
{ 3726527 }, /* unc_h_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00011\000\000 */
{ 3726710 }, /* unc_h_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00011\000\000 */
{ 3726892 }, /* unc_h_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00011\000\000 */
{ 3727072 }, /* unc_h_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x29,umask=0x40\000\00011\000\000 */
{ 3727253 }, /* unc_h_rxc_wbq1_reject.any_wbq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00011\000\000 */
{ 3727427 }, /* unc_h_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00011\000\000 */
{ 3727593 }, /* unc_h_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x29,umask=0x20\000\00011\000\000 */
{ 3727782 }, /* unc_h_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x4\000\00011\000\000 */
{ 3727964 }, /* unc_h_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x29,umask=0x80\000\00011\000\000 */
{ 3728143 }, /* unc_h_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x8\000\00011\000\000 */
{ 3728323 }, /* unc_h_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x29,umask=0x10\000\00011\000\000 */
{ 3728498 }, /* unc_h_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00011\000\000 */
{ 3728674 }, /* unc_h_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00011\000\000 */
{ 3728851 }, /* unc_h_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00011\000\000 */
{ 3729027 }, /* unc_h_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00011\000\000 */
{ 3729204 }, /* unc_h_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_BNC. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00011\000\000 */
{ 3729368 }, /* unc_h_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_CRD. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00011\000\000 */
{ 3729533 }, /* unc_h_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AK_BNC. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00011\000\000 */
{ 3729697 }, /* unc_h_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_BNC. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00011\000\000 */
{ 3729861 }, /* unc_h_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_CRD. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00011\000\000 */
{ 3730026 }, /* unc_h_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.IV_BNC. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00011\000\000 */
{ 3730190 }, /* unc_h_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00011\000\000 */
{ 3730364 }, /* unc_h_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00011\000\000 */
{ 3730539 }, /* unc_h_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AK_BNC. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00011\000\000 */
{ 3730713 }, /* unc_h_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00011\000\000 */
{ 3730887 }, /* unc_h_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00011\000\000 */
{ 3731062 }, /* unc_h_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IFV. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00011\000\000 */
{ 3731231 }, /* unc_h_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IV_BNC. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00011\000\000 */
{ 3731405 }, /* unc_h_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_BNC. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00011\000\000 */
{ 3731571 }, /* unc_h_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_CRD. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00011\000\000 */
{ 3731738 }, /* unc_h_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AK_BNC. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00011\000\000 */
{ 3731904 }, /* unc_h_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_BNC. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00011\000\000 */
{ 3732070 }, /* unc_h_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_CRD. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00011\000\000 */
{ 3732237 }, /* unc_h_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.IV_BNC. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00011\000\000 */
{ 3732403 }, /* unc_h_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00011\000\000 */
{ 3732573 }, /* unc_h_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00011\000\000 */
{ 3732744 }, /* unc_h_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00011\000\000 */
{ 3732914 }, /* unc_h_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00011\000\000 */
{ 3733084 }, /* unc_h_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00011\000\000 */
{ 3733255 }, /* unc_h_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00011\000\000 */
{ 3734957 }, /* unc_h_sf_eviction.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.E_STATE. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00011\000\000 */
{ 3735125 }, /* unc_h_sf_eviction.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.M_STATE. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00011\000\000 */
{ 3735293 }, /* unc_h_sf_eviction.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.S_STATE. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00011\000\000 */
{ 3738503 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_FWD_WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00011\000\000 */
{ 3740350 }, /* unc_h_snoop_resp.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_WBWB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00011\000\000 */
{ 3741353 }, /* unc_h_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPCNFLCTS. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00011\000\000 */
{ 3742340 }, /* unc_h_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPFWD. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00011\000\000 */
{ 3742505 }, /* unc_h_snoop_resp.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPI. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00011\000\000 */
{ 3743394 }, /* unc_h_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPIFWD. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00011\000\000 */
{ 3745194 }, /* unc_h_snoop_resp.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00011\000\000 */
{ 3746903 }, /* unc_h_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPSFWD. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00011\000\000 */
{ 3750737 }, /* unc_h_snoops_sent.\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.ALL. Unit: uncore_cha \000event=0x51,umask=0x1\000\00011\000\000 */
{ 3750894 }, /* unc_h_snoops_sent.bcst_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x10\000\00011\000\000 */
{ 3751067 }, /* unc_h_snoops_sent.bcst_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x20\000\00011\000\000 */
{ 3751241 }, /* unc_h_snoops_sent.direct_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x40\000\00011\000\000 */
{ 3751418 }, /* unc_h_snoops_sent.direct_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x80\000\00011\000\000 */
{ 3751596 }, /* unc_h_snoops_sent.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.LOCAL. Unit: uncore_cha \000event=0x51,umask=0x4\000\00011\000\000 */
{ 3751760 }, /* unc_h_snoops_sent.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.REMOTE. Unit: uncore_cha \000event=0x51,umask=0x8\000\00011\000\000 */
{ 3755686 }, /* unc_h_snp_rsp_rcv_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_FWD_WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00011\000\000 */
{ 3755872 }, /* unc_h_snp_rsp_rcv_local.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00011\000\000 */
{ 3756050 }, /* unc_h_snp_rsp_rcv_local.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPCNFLCT. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00011\000\000 */
{ 3756234 }, /* unc_h_snp_rsp_rcv_local.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPFWD. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00011\000\000 */
{ 3756412 }, /* unc_h_snp_rsp_rcv_local.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00011\000\000 */
{ 3756585 }, /* unc_h_snp_rsp_rcv_local.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPIFWD. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00011\000\000 */
{ 3756764 }, /* unc_h_snp_rsp_rcv_local.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00011\000\000 */
{ 3756937 }, /* unc_h_snp_rsp_rcv_local.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPSFWD. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00011\000\000 */
{ 3758092 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00011\000\000 */
{ 3758288 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00011\000\000 */
{ 3758484 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00011\000\000 */
{ 3758680 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00011\000\000 */
{ 3758876 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00011\000\000 */
{ 3759073 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00011\000\000 */
{ 3759270 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00011\000\000 */
{ 3759466 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00011\000\000 */
{ 3759662 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00011\000\000 */
{ 3759858 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00011\000\000 */
{ 3760054 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00011\000\000 */
{ 3760251 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00011\000\000 */
{ 3760448 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00011\000\000 */
{ 3760644 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00011\000\000 */
{ 3760840 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00011\000\000 */
{ 3761036 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00011\000\000 */
{ 3761232 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00011\000\000 */
{ 3761429 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00011\000\000 */
{ 3761626 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00011\000\000 */
{ 3761822 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00011\000\000 */
{ 3762018 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00011\000\000 */
{ 3762214 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00011\000\000 */
{ 3762410 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00011\000\000 */
{ 3762607 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00011\000\000 */
{ 3818505 }, /* unc_h_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_BNC. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00011\000\000 */
{ 3818683 }, /* unc_h_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_CRD. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00011\000\000 */
{ 3818862 }, /* unc_h_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AK_BNC. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00011\000\000 */
{ 3819040 }, /* unc_h_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_BNC. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00011\000\000 */
{ 3819218 }, /* unc_h_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_CRD. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00011\000\000 */
{ 3819397 }, /* unc_h_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_BNC. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00011\000\000 */
{ 3819571 }, /* unc_h_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_CRD. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00011\000\000 */
{ 3819746 }, /* unc_h_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AK_BNC. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00011\000\000 */
{ 3819920 }, /* unc_h_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_BNC. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00011\000\000 */
{ 3820094 }, /* unc_h_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_CRD. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00011\000\000 */
{ 3820269 }, /* unc_h_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.IV_BNC. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00011\000\000 */
{ 3820443 }, /* unc_h_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_BNC. Unit: uncore_cha \000event=0x96,umask=0x1\000\00011\000\000 */
{ 3820627 }, /* unc_h_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_CRD. Unit: uncore_cha \000event=0x96,umask=0x10\000\00011\000\000 */
{ 3820812 }, /* unc_h_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AK_BNC. Unit: uncore_cha \000event=0x96,umask=0x2\000\00011\000\000 */
{ 3820996 }, /* unc_h_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_BNC. Unit: uncore_cha \000event=0x96,umask=0x4\000\00011\000\000 */
{ 3821180 }, /* unc_h_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_CRD. Unit: uncore_cha \000event=0x96,umask=0x40\000\00011\000\000 */
{ 3821365 }, /* unc_h_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.IV_BNC. Unit: uncore_cha \000event=0x96,umask=0x8\000\00011\000\000 */
{ 3821549 }, /* unc_h_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_BNC. Unit: uncore_cha \000event=0x97,umask=0x1\000\00011\000\000 */
{ 3821729 }, /* unc_h_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_CRD. Unit: uncore_cha \000event=0x97,umask=0x10\000\00011\000\000 */
{ 3821910 }, /* unc_h_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AK_BNC. Unit: uncore_cha \000event=0x97,umask=0x2\000\00011\000\000 */
{ 3822090 }, /* unc_h_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_BNC. Unit: uncore_cha \000event=0x97,umask=0x4\000\00011\000\000 */
{ 3822270 }, /* unc_h_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_CRD. Unit: uncore_cha \000event=0x97,umask=0x40\000\00011\000\000 */
{ 3822451 }, /* unc_h_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.IV_BNC. Unit: uncore_cha \000event=0x97,umask=0x8\000\00011\000\000 */
{ 3822631 }, /* unc_h_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_BNC. Unit: uncore_cha \000event=0x95,umask=0x1\000\00011\000\000 */
{ 3822807 }, /* unc_h_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_CRD. Unit: uncore_cha \000event=0x95,umask=0x10\000\00011\000\000 */
{ 3822984 }, /* unc_h_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AK_BNC. Unit: uncore_cha \000event=0x95,umask=0x2\000\00011\000\000 */
{ 3823160 }, /* unc_h_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_BNC. Unit: uncore_cha \000event=0x95,umask=0x4\000\00011\000\000 */
{ 3823336 }, /* unc_h_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_CRD. Unit: uncore_cha \000event=0x95,umask=0x40\000\00011\000\000 */
{ 3823513 }, /* unc_h_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.IV_BNC. Unit: uncore_cha \000event=0x95,umask=0x8\000\00011\000\000 */
{ 3823689 }, /* unc_h_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_BNC. Unit: uncore_cha \000event=0x99,umask=0x1\000\00011\000\000 */
{ 3823859 }, /* unc_h_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_CRD. Unit: uncore_cha \000event=0x99,umask=0x20\000\00011\000\000 */
{ 3824030 }, /* unc_h_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AK_BNC. Unit: uncore_cha \000event=0x99,umask=0x2\000\00011\000\000 */
{ 3824200 }, /* unc_h_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_BNC. Unit: uncore_cha \000event=0x99,umask=0x4\000\00011\000\000 */
{ 3824370 }, /* unc_h_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_CRD. Unit: uncore_cha \000event=0x99,umask=0x40\000\00011\000\000 */
{ 3824541 }, /* unc_h_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.IV_BNC. Unit: uncore_cha \000event=0x99,umask=0x8\000\00011\000\000 */
{ 3824711 }, /* unc_h_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0x94,umask=0x1\000\00011\000\000 */
{ 3824891 }, /* unc_h_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0x94,umask=0x10\000\00011\000\000 */
{ 3825072 }, /* unc_h_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0x94,umask=0x2\000\00011\000\000 */
{ 3825252 }, /* unc_h_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0x94,umask=0x4\000\00011\000\000 */
{ 3825432 }, /* unc_h_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0x94,umask=0x40\000\00011\000\000 */
{ 3825613 }, /* unc_h_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0x94,umask=0x8\000\00011\000\000 */
{ 3825793 }, /* unc_h_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AD_BNC. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00011\000\000 */
{ 3825969 }, /* unc_h_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AK_BNC. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00011\000\000 */
{ 3826145 }, /* unc_h_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.BL_BNC. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00011\000\000 */
{ 3826321 }, /* unc_h_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.IV_BNC. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00011\000\000 */
{ 3827021 }, /* unc_h_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00011\000\000 */
{ 3827199 }, /* unc_h_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00011\000\000 */
{ 3827378 }, /* unc_h_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00011\000\000 */
{ 3827556 }, /* unc_h_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00011\000\000 */
{ 3827735 }, /* unc_h_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00011\000\000 */
{ 3827913 }, /* unc_h_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00011\000\000 */
{ 3828092 }, /* unc_h_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00011\000\000 */
{ 3828266 }, /* unc_h_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00011\000\000 */
{ 3828441 }, /* unc_h_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00011\000\000 */
{ 3828615 }, /* unc_h_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00011\000\000 */
{ 3828790 }, /* unc_h_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00011\000\000 */
{ 3828964 }, /* unc_h_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00011\000\000 */
{ 3829139 }, /* unc_h_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00011\000\000 */
{ 3829309 }, /* unc_h_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00011\000\000 */
{ 3829493 }, /* unc_h_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00011\000\000 */
{ 3829678 }, /* unc_h_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00011\000\000 */
{ 3829862 }, /* unc_h_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00011\000\000 */
{ 3830047 }, /* unc_h_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00011\000\000 */
{ 3830231 }, /* unc_h_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00011\000\000 */
{ 3830416 }, /* unc_h_txr_vert_cycles_full.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00011\000\000 */
{ 3830596 }, /* unc_h_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00011\000\000 */
{ 3830776 }, /* unc_h_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00011\000\000 */
{ 3830957 }, /* unc_h_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00011\000\000 */
{ 3831137 }, /* unc_h_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00011\000\000 */
{ 3831318 }, /* unc_h_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00011\000\000 */
{ 3831498 }, /* unc_h_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00011\000\000 */
{ 3831679 }, /* unc_h_txr_vert_cycles_ne.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00011\000\000 */
{ 3831855 }, /* unc_h_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00011\000\000 */
{ 3832031 }, /* unc_h_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00011\000\000 */
{ 3832208 }, /* unc_h_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00011\000\000 */
{ 3832384 }, /* unc_h_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00011\000\000 */
{ 3832561 }, /* unc_h_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00011\000\000 */
{ 3832737 }, /* unc_h_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00011\000\000 */
{ 3832914 }, /* unc_h_txr_vert_inserts.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00011\000\000 */
{ 3833086 }, /* unc_h_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00011\000\000 */
{ 3833256 }, /* unc_h_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00011\000\000 */
{ 3833427 }, /* unc_h_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00011\000\000 */
{ 3833597 }, /* unc_h_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00011\000\000 */
{ 3833768 }, /* unc_h_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00011\000\000 */
{ 3833938 }, /* unc_h_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00011\000\000 */
{ 3834109 }, /* unc_h_txr_vert_nack.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00011\000\000 */
{ 3834271 }, /* unc_h_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00011\000\000 */
{ 3834451 }, /* unc_h_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00011\000\000 */
{ 3834632 }, /* unc_h_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00011\000\000 */
{ 3834812 }, /* unc_h_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00011\000\000 */
{ 3834993 }, /* unc_h_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00011\000\000 */
{ 3835173 }, /* unc_h_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00011\000\000 */
{ 3835354 }, /* unc_h_txr_vert_occupancy.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00011\000\000 */
{ 3835530 }, /* unc_h_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00011\000\000 */
{ 3835706 }, /* unc_h_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00011\000\000 */
{ 3835883 }, /* unc_h_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00011\000\000 */
{ 3836059 }, /* unc_h_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00011\000\000 */
{ 3836236 }, /* unc_h_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00011\000\000 */
{ 3836412 }, /* unc_h_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00011\000\000 */
{ 3836589 }, /* unc_h_txr_vert_starved.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00011\000\000 */
{ 3837051 }, /* unc_h_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00011\000\000 */
{ 3837438 }, /* unc_h_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00011\000\000 */
{ 3837823 }, /* unc_h_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00011\000\000 */
{ 3838208 }, /* unc_h_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00011\000\000 */
{ 3838595 }, /* unc_h_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00011\000\000 */
{ 3838982 }, /* unc_h_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00011\000\000 */
{ 3839367 }, /* unc_h_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00011\000\000 */
{ 3839752 }, /* unc_h_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00011\000\000 */
{ 3840139 }, /* unc_h_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00011\000\000 */
{ 3840526 }, /* unc_h_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00011\000\000 */
{ 3840911 }, /* unc_h_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00011\000\000 */
{ 3841296 }, /* unc_h_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00011\000\000 */
{ 3841669 }, /* unc_h_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.DN. Unit: uncore_cha \000event=0xac,umask=0x4\000\00011\000\000 */
{ 3842032 }, /* unc_h_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.UP. Unit: uncore_cha \000event=0xac,umask=0x1\000\00011\000\000 */
{ 3842206 }, /* unc_h_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00011\000\000 */
{ 3842368 }, /* unc_h_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.MEM. Unit: uncore_cha \000event=0x56,umask=0x2\000\00011\000\000 */
{ 3856682 }, /* unc_h_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00011\000\000 */
{ 3856864 }, /* unc_h_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00011\000\000 */
{ 3857046 }, /* unc_h_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00011\000\000 */
{ 3857229 }, /* unc_h_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00011\000\000 */
{ 3857412 }, /* unc_h_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00011\000\000 */
{ 3857592 }, /* unc_h_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00011\000\000 */
{ 3857772 }, /* unc_h_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00011\000\000 */
{ 3857951 }, /* unc_h_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00011\000\000 */
{ 3858130 }, /* unc_h_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00011\000\000 */
{ 3858307 }, /* unc_h_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00011\000\000 */
{ 3858486 }, /* unc_h_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00011\000\000 */
{ 3858663 }, /* unc_h_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00011\000\000 */
{ 3858844 }, /* unc_h_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00011\000\000 */
{ 3859025 }, /* unc_h_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00011\000\000 */
{ 3859204 }, /* unc_h_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00011\000\000 */
{ 3859385 }, /* unc_h_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00011\000\000 */
{ 3859564 }, /* unc_h_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00011\000\000 */
{ 3859747 }, /* unc_h_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00011\000\000 */
{ 3859930 }, /* unc_h_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00011\000\000 */
{ 3860111 }, /* unc_h_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00011\000\000 */
{ 3860294 }, /* unc_h_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00011\000\000 */
{ 3860475 }, /* unc_h_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00011\000\000 */
{ 3860654 }, /* unc_h_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00011\000\000 */
{ 3860833 }, /* unc_h_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00011\000\000 */
{ 3861010 }, /* unc_h_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00011\000\000 */
{ 3861189 }, /* unc_h_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00011\000\000 */
{ 3872082 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3872796 }, /* unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3873432 }, /* unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests.  This is effectively the sum of read occupancy and write occupancy\000 */
{ 3877003 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000IRP Clocks. Unit: uncore_irp \000event=0x1\000\00001\000\000 */
{ 3877466 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3877854 }, /* unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878224 }, /* unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x10,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878594 }, /* unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x10,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878996 }, /* unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879579 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline. Unit: uncore_irp \000event=0x10,umask=0x10\000\00001\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline to coherent memory, without a RFO.  PCIITOM is a speculative Invalidate to Modified command that requests ownership of the cacheline and does not move data from the mesh to IRP cache\000 */
{ 3880245 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline. Unit: uncore_irp \000event=0x10,umask=0x8\000\00001\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline to coherent memory.  RFO is a Read For Ownership command that requests ownership of the cacheline and moves data from the mesh to IRP cache\000 */
{ 3880894 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3881278 }, /* unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000 */
{ 3881484 }, /* unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000Inbound read requests received by the IRP and inserted into the FAF queue. Unit: uncore_irp \000event=0x18\000\00001\000Inbound read requests to coherent memory, received by the IRP and inserted into the Fire and Forget queue (FAF), a queue used for processing inbound reads in the IRP\000 */
{ 3881907 }, /* unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000Occupancy of the IRP FAF queue. Unit: uncore_irp \000event=0x19\000\00001\000Occupancy of the IRP Fire and Forget (FAF) queue, a queue used for processing inbound reads in the IRP\000 */
{ 3882126 }, /* unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000 */
{ 3882529 }, /* unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 3882821 }, /* unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 3883402 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 3884000 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 3884594 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 3885083 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 3885538 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 3886079 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 3886653 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 3887255 }, /* unc_i_misc0.unknown\000uncore_irp\000uncore interconnect\000Misc Events - Set 0. Unit: uncore_irp \000event=0x1c,umask=0x80\000\00001\000\000 */
{ 3887973 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Lost Forward. Unit: uncore_irp \000event=0x1d,umask=0x10\000\00001\000Snoop pulled away ownership before a write was committed\000 */
{ 3888625 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x1d,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3889282 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x1d,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889944 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x1d,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890612 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x1d,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891282 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x1d,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891956 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x1d,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3892302 }, /* unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P requests from the ITC\000 */
{ 3892424 }, /* unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P B & S Queue Occupancy\000 */
{ 3892829 }, /* unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000 */
{ 3893110 }, /* unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000 */
{ 3893423 }, /* unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000 */
{ 3893727 }, /* unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000 */
{ 3893991 }, /* unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000 */
{ 3894265 }, /* unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions; Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000 */
{ 3894580 }, /* unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000 */
{ 3894883 }, /* unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000 */
{ 3900346 }, /* unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000 */
{ 3900612 }, /* unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000 */
{ 3900881 }, /* unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000 */
{ 3901139 }, /* unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000 */
{ 3901397 }, /* unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000 */
{ 3901765 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000 */
{ 3902172 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000 */
{ 3902562 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000 */
{ 3902950 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000 */
{ 3903340 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000 */
{ 3903747 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000 */
{ 3904152 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000 */
{ 3906606 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000 */
{ 3908131 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000 */
{ 3910065 }, /* unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x11,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3911565 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3914035 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000 */
{ 3915045 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3918099 }, /* unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000 */
{ 3918207 }, /* unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000 */
{ 3918327 }, /* unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000 */
{ 3918439 }, /* unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000 */
{ 3918555 }, /* unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000 */
{ 3918675 }, /* unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000 */
{ 3918787 }, /* unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000 */
{ 3918903 }, /* unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000 */
{ 3919023 }, /* unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000 */
{ 3919135 }, /* unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000 */
{ 3920506 }, /* unc_i_txr2_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3920762 }, /* unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3922871 }, /* unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923270 }, /* unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923669 }, /* unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 4330092 }, /* unc_m2m_ag0_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330324 }, /* unc_m2m_ag0_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330556 }, /* unc_m2m_ag0_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330788 }, /* unc_m2m_ag0_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331020 }, /* unc_m2m_ag0_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331253 }, /* unc_m2m_ag0_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334639 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4334871 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335103 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335335 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335567 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335800 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4339197 }, /* unc_m2m_ag0_bl_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339429 }, /* unc_m2m_ag0_bl_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339661 }, /* unc_m2m_ag0_bl_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339893 }, /* unc_m2m_ag0_bl_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340125 }, /* unc_m2m_ag0_bl_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340358 }, /* unc_m2m_ag0_bl_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343744 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4343976 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344208 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344440 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344672 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344905 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4348302 }, /* unc_m2m_ag1_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348534 }, /* unc_m2m_ag1_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348766 }, /* unc_m2m_ag1_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348998 }, /* unc_m2m_ag1_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349230 }, /* unc_m2m_ag1_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349463 }, /* unc_m2m_ag1_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352849 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353081 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353313 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353545 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353777 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354010 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4360560 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4360792 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361024 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361256 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361488 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361721 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4365118 }, /* unc_m2m_ag1_bl_credits_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365354 }, /* unc_m2m_ag1_bl_credits_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365590 }, /* unc_m2m_ag1_bl_credits_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365826 }, /* unc_m2m_ag1_bl_credits_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366062 }, /* unc_m2m_ag1_bl_credits_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366299 }, /* unc_m2m_ag1_bl_credits_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366678 }, /* unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000Traffic in which the M2M to iMC Bypass was not taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000Counts traffic in which the M2M (Mesh to Memory) to iMC (Memory Controller) bypass was not taken\000 */
{ 4367073 }, /* unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000 */
{ 4367349 }, /* unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000 */
{ 4367626 }, /* unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000 */
{ 4367881 }, /* unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Cycles - at UCLK. Unit: uncore_m2m \000event=0\000\00001\000\000 */
{ 4368117 }, /* unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000 */
{ 4368810 }, /* unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000Counts cycles when direct to core mode (which bypasses the CHA) was disabled\000 */
{ 4369559 }, /* unc_m2m_direct2core_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to core (bypassing the CHA). Unit: uncore_m2m \000event=0x23\000\00001\000Counts when messages were sent direct to core (bypassing the CHA)\000 */
{ 4370499 }, /* unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2m \000event=0x25\000\00001\000Counts reads in which direct to core transactions (which would have bypassed the CHA) were overridden\000 */
{ 4371131 }, /* unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel(R) UPI transactions were overridden. Unit: uncore_m2m \000event=0x28\000\00001\000Counts reads in which direct to Intel(R) Ultra Path Interconnect (UPI) transactions (which would have bypassed the CHA) were overridden\000 */
{ 4372713 }, /* unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to Intel(R) UPI was disabled. Unit: uncore_m2m \000event=0x27\000\00001\000Counts cycles when the ability to send messages direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was disabled\000 */
{ 4373188 }, /* unc_m2m_direct2upi_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to the Intel(R) UPI. Unit: uncore_m2m \000event=0x26\000\00001\000Counts when messages were sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA)\000 */
{ 4373972 }, /* unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel(R) UPI was overridden. Unit: uncore_m2m \000event=0x29\000\00001\000Counts when a read message that was sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was overridden\000 */
{ 4374892 }, /* unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 4375344 }, /* unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 4375796 }, /* unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 4376248 }, /* unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 4376692 }, /* unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 4377132 }, /* unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 4377572 }, /* unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 4378012 }, /* unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 4378580 }, /* unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2m \000event=0x2d,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in Any State (A, I, S or unused)\000 */
{ 4379336 }, /* unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2m \000event=0x2d,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in the A (SnoopAll) state, indicating the cacheline is stored in another socket in any state, and we must snoop the other sockets to make sure we get the latest data.  The data may be stored in any state in the local socket\000 */
{ 4380297 }, /* unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2m \000event=0x2d,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the I (Invalid) state indicating the cacheline is not stored in another socket, and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000 */
{ 4381246 }, /* unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2m \000event=0x2d,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the S (Shared) state indicating the cacheline is either stored in another socket in the S(hared) state , and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000 */
{ 4382090 }, /* unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x80\000\00001\000\000 */
{ 4382548 }, /* unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x10\000\00001\000\000 */
{ 4383006 }, /* unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x40\000\00001\000\000 */
{ 4383464 }, /* unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x20\000\00001\000\000 */
{ 4383914 }, /* unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x8\000\00001\000\000 */
{ 4384360 }, /* unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x1\000\00001\000\000 */
{ 4384806 }, /* unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x4\000\00001\000\000 */
{ 4385252 }, /* unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x2\000\00001\000\000 */
{ 4385559 }, /* unc_m2m_directory_update.a2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2m \000event=0x2e,umask=0x20\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to I (Invalid)\000 */
{ 4385996 }, /* unc_m2m_directory_update.a2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2m \000event=0x2e,umask=0x40\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to S (Shared)\000 */
{ 4387788 }, /* unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2m \000event=0x2e,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory to a new state\000 */
{ 4388476 }, /* unc_m2m_directory_update.i2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2m \000event=0x2e,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to A (SnoopAll)\000 */
{ 4388912 }, /* unc_m2m_directory_update.i2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2m \000event=0x2e,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to S (Shared)\000 */
{ 4390750 }, /* unc_m2m_directory_update.s2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2m \000event=0x2e,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to A (SnoopAll)\000 */
{ 4391186 }, /* unc_m2m_directory_update.s2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2m \000event=0x2e,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to I (Invalid)\000 */
{ 4396322 }, /* unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m2m \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397202 }, /* unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m2m \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397457 }, /* unc_m2m_fast_asserted.horz\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4397724 }, /* unc_m2m_fast_asserted.vert\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4398916 }, /* unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4400722 }, /* unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4402532 }, /* unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4404343 }, /* unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4406150 }, /* unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4407952 }, /* unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4409758 }, /* unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4411565 }, /* unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4417107 }, /* unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4418911 }, /* unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4420719 }, /* unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4422528 }, /* unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4424009 }, /* unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4425176 }, /* unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4426182 }, /* unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000Reads to iMC issued. Unit: uncore_m2m \000event=0x37,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller)\000 */
{ 4431955 }, /* unc_m2m_imc_reads.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x37,umask=0x10\000\00001\000\000 */
{ 4432280 }, /* unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; Critical Priority. Unit: uncore_m2m \000event=0x37,umask=0x2\000\00001\000\000 */
{ 4432709 }, /* unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000Reads to iMC issued at Normal Priority (Non-Isochronous). Unit: uncore_m2m \000event=0x37,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller).  It only counts  normal priority non-isochronous reads\000 */
{ 4434164 }, /* unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000Read requests to Intel(R) Optane(TM) DC persistent memory issued to the iMC from M2M. Unit: uncore_m2m \000event=0x37,umask=0x8\000\00001\000M2M Reads Issued to iMC; All, regardless of priority\000 */
{ 4434813 }, /* unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000Writes to iMC issued. Unit: uncore_m2m \000event=0x38,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) issues writes to the iMC (Memory Controller)\000 */
{ 4442461 }, /* unc_m2m_imc_writes.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x40\000\00001\000\000 */
{ 4442925 }, /* unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; Full Line Non-ISOCH. Unit: uncore_m2m \000event=0x38,umask=0x1\000\00001\000\000 */
{ 4443378 }, /* unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Full Line. Unit: uncore_m2m \000event=0x38,umask=0x4\000\00001\000\000 */
{ 4443670 }, /* unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x80\000\00001\000\000 */
{ 4444526 }, /* unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000Partial Non-Isochronous writes to the iMC. Unit: uncore_m2m \000event=0x38,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) issues partial writes to the iMC (Memory Controller).  It only counts normal priority non-isochronous writes\000 */
{ 4445125 }, /* unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Partial. Unit: uncore_m2m \000event=0x38,umask=0x8\000\00001\000\000 */
{ 4446165 }, /* unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000Write requests to Intel(R) Optane(TM) DC persistent memory issued to the iMC from M2M. Unit: uncore_m2m \000event=0x38,umask=0x20\000\00001\000M2M Writes Issued to iMC; All, regardless of priority\000 */
{ 4447160 }, /* unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4447437 }, /* unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4447577 }, /* unc_m2m_pmm_rpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x4f,umask=0x1\000\00001\000\000 */
{ 4447744 }, /* unc_m2m_pmm_rpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x4f,umask=0x2\000\00001\000\000 */
{ 4447911 }, /* unc_m2m_pmm_rpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x4f,umask=0x4\000\00001\000\000 */
{ 4448078 }, /* unc_m2m_pmm_wpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x51,umask=0x1\000\00001\000\000 */
{ 4448245 }, /* unc_m2m_pmm_wpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x51,umask=0x2\000\00001\000\000 */
{ 4448412 }, /* unc_m2m_pmm_wpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x51,umask=0x4\000\00001\000\000 */
{ 4449400 }, /* unc_m2m_prefcam_cycles_full\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full. Unit: uncore_m2m \000event=0x53\000\00001\000\000 */
{ 4450116 }, /* unc_m2m_prefcam_cycles_ne\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty. Unit: uncore_m2m \000event=0x54\000\00001\000\000 */
{ 4457481 }, /* unc_m2m_prefcam_demand_promotions\000uncore_m2m\000uncore interconnect\000Prefetch requests that got turn into a demand request. Unit: uncore_m2m \000event=0x56\000\00001\000Counts when the M2M (Mesh to Memory) promotes a outstanding request in the prefetch queue due to a subsequent demand read request that entered the M2M with the same address.  Explanatory Side Note: The Prefetch queue is made of CAM (Content Addressable Memory)\000 */
{ 4465130 }, /* unc_m2m_prefcam_inserts\000uncore_m2m\000uncore interconnect\000Inserts into the Memory Controller Prefetch Queue. Unit: uncore_m2m \000event=0x57\000\00001\000Counts when the M2M (Mesh to Memory) receives a prefetch request and inserts it into its outstanding prefetch queue.  Explanatory Side Note: the prefect queue is made from CAM: Content Addressable Memory\000 */
{ 4466470 }, /* unc_m2m_prefcam_occupancy\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy. Unit: uncore_m2m \000event=0x55\000\00001\000\000 */
{ 4469478 }, /* unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470024 }, /* unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470570 }, /* unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471116 }, /* unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471656 }, /* unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472236 }, /* unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473119 }, /* unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473726 }, /* unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4474143 }, /* unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 4474442 }, /* unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 4474771 }, /* unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 4475100 }, /* unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 4475399 }, /* unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 4475696 }, /* unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 4476013 }, /* unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 4476495 }, /* unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 4476835 }, /* unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 4477007 }, /* unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xa4\000\00001\000\000 */
{ 4477217 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00011\000\000 */
{ 4477415 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00011\000\000 */
{ 4477613 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00011\000\000 */
{ 4477811 }, /* unc_m2m_rpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4477976 }, /* unc_m2m_rpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4478141 }, /* unc_m2m_rpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x43,umask=0x4\000\00001\000\000 */
{ 4478306 }, /* unc_m2m_rpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4478472 }, /* unc_m2m_rpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4478638 }, /* unc_m2m_rpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4480217 }, /* unc_m2m_rxc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x4\000\00001\000\000 */
{ 4480336 }, /* unc_m2m_rxc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x3\000\00001\000\000 */
{ 4480736 }, /* unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Queue Inserts. Unit: uncore_m2m \000event=0x1\000\00001\000Counts when the a new entry is Received(RxC) and then added to the AD (Address Ring) Ingress Queue from the CMS (Common Mesh Stop).  This is generally used for reads, and\000 */
{ 4481030 }, /* unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x2\000\00001\000\000 */
{ 4481534 }, /* unc_m2m_rxc_bl_cycles_full\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x8\000\00001\000\000 */
{ 4481653 }, /* unc_m2m_rxc_bl_cycles_ne\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x7\000\00001\000\000 */
{ 4481775 }, /* unc_m2m_rxc_bl_inserts\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x5\000\00001\000\000 */
{ 4481897 }, /* unc_m2m_rxc_bl_occupancy\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x6\000\00001\000\000 */
{ 4482485 }, /* unc_m2m_rxr_busy_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4483321 }, /* unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4484629 }, /* unc_m2m_rxr_busy_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4485465 }, /* unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4486560 }, /* unc_m2m_rxr_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4486976 }, /* unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4487603 }, /* unc_m2m_rxr_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4488281 }, /* unc_m2m_rxr_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4488697 }, /* unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4489324 }, /* unc_m2m_rxr_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4489986 }, /* unc_m2m_rxr_crd_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4490844 }, /* unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4492137 }, /* unc_m2m_rxr_crd_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4493017 }, /* unc_m2m_rxr_crd_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4493875 }, /* unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4495194 }, /* unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496024 }, /* unc_m2m_rxr_crd_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4497162 }, /* unc_m2m_rxr_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4497723 }, /* unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498570 }, /* unc_m2m_rxr_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4499468 }, /* unc_m2m_rxr_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500029 }, /* unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500876 }, /* unc_m2m_rxr_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4501464 }, /* unc_m2m_rxr_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502039 }, /* unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502906 }, /* unc_m2m_rxr_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503824 }, /* unc_m2m_rxr_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504399 }, /* unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4505266 }, /* unc_m2m_rxr_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4522320 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4522614 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4522908 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523202 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523496 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523791 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524086 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524380 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524674 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524968 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525262 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525557 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525852 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526146 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526440 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526734 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527028 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527323 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527618 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527912 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528206 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528500 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528794 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4529089 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4529564 }, /* unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Clean line read hits(Regular and RFO) to Near Memory(DRAM cache) in Memory Mode and regular reads to DRAM in 1LM. Unit: uncore_m2m \000event=0x2c,umask=0x1\000\00001\000Tag Hit; Read Hit from NearMem, Clean Line\000 */
{ 4530303 }, /* unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty line read hits(Regular and RFO) to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x2\000\00001\000Tag Hit; Read Hit from NearMem, Dirty  Line\000 */
{ 4530830 }, /* unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Clean line underfill read hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x4\000\00001\000Tag Hit; Underfill Rd Hit from NearMem, Clean Line\000 */
{ 4531644 }, /* unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty line underfill read hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_m2m \000event=0x2c,umask=0x8\000\00001\000Tag Hit; Underfill Rd Hit from NearMem, Dirty  Line\000 */
{ 4532786 }, /* unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x41\000\00001\000\000 */
{ 4533016 }, /* unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x42\000\00001\000\000 */
{ 4533131 }, /* unc_m2m_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4533270 }, /* unc_m2m_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4533409 }, /* unc_m2m_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4533548 }, /* unc_m2m_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4533690 }, /* unc_m2m_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4533832 }, /* unc_m2m_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4534639 }, /* unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4535036 }, /* unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4535299 }, /* unc_m2m_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x49,umask=0x4\000\00001\000\000 */
{ 4536110 }, /* unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4536517 }, /* unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4536788 }, /* unc_m2m_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4536923 }, /* unc_m2m_tracker_pending_occupancy\000uncore_m2m\000uncore interconnect\000Data Pending Occupancy. Unit: uncore_m2m \000event=0x48\000\00001\000\000 */
{ 4537046 }, /* unc_m2m_txc_ad_credit_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credits Occupancy. Unit: uncore_m2m \000event=0xe\000\00001\000\000 */
{ 4537180 }, /* unc_m2m_txc_ad_credits_acquired\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credit Acquired. Unit: uncore_m2m \000event=0xd\000\00001\000\000 */
{ 4537312 }, /* unc_m2m_txc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Full. Unit: uncore_m2m \000event=0xc\000\00001\000\000 */
{ 4537428 }, /* unc_m2m_txc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0xb\000\00001\000\000 */
{ 4537547 }, /* unc_m2m_txc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x9\000\00001\000\000 */
{ 4537666 }, /* unc_m2m_txc_ad_no_credit_cycles\000uncore_m2m\000uncore interconnect\000Cycles with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0xf\000\00001\000\000 */
{ 4537805 }, /* unc_m2m_txc_ad_no_credit_stalled\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0x10\000\00001\000\000 */
{ 4537954 }, /* unc_m2m_txc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0xa\000\00001\000\000 */
{ 4538231 }, /* unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000 */
{ 4538535 }, /* unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000 */
{ 4538681 }, /* unc_m2m_txc_ak_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 4538861 }, /* unc_m2m_txc_ak_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 4539219 }, /* unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4539575 }, /* unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4539889 }, /* unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000 */
{ 4540188 }, /* unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4540512 }, /* unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4540807 }, /* unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4541097 }, /* unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000 */
{ 4541388 }, /* unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000 */
{ 4541681 }, /* unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000 */
{ 4541974 }, /* unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4542266 }, /* unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000 */
{ 4542563 }, /* unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000 */
{ 4542868 }, /* unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000 */
{ 4543198 }, /* unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000 */
{ 4543498 }, /* unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Read Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000 */
{ 4543792 }, /* unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Compare Request. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000 */
{ 4544089 }, /* unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000 */
{ 4544388 }, /* unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000 */
{ 4544693 }, /* unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000 */
{ 4545023 }, /* unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000 */
{ 4545334 }, /* unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Prefetch Read Cam Hit. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000 */
{ 4545640 }, /* unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Read Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000 */
{ 4545934 }, /* unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Compare Request. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000 */
{ 4546231 }, /* unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000 */
{ 4546576 }, /* unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 4546946 }, /* unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 4547325 }, /* unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000 */
{ 4547713 }, /* unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000 */
{ 4548046 }, /* unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000 */
{ 4548351 }, /* unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000 */
{ 4548681 }, /* unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000 */
{ 4548981 }, /* unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Read Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000 */
{ 4549275 }, /* unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Compare Request. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000 */
{ 4549572 }, /* unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000 */
{ 4549731 }, /* unc_m2m_txc_ak_sideband.rd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 4549862 }, /* unc_m2m_txc_ak_sideband.wr\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 4550252 }, /* unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4550563 }, /* unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4550870 }, /* unc_m2m_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4551022 }, /* unc_m2m_txc_bl_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1a,umask=0x1\000\00001\000\000 */
{ 4551202 }, /* unc_m2m_txc_bl_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1a,umask=0x2\000\00001\000\000 */
{ 4551560 }, /* unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4551916 }, /* unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4552230 }, /* unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4552529 }, /* unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4552853 }, /* unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4553154 }, /* unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000 */
{ 4553459 }, /* unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4553789 }, /* unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4554093 }, /* unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000 */
{ 4554398 }, /* unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4554728 }, /* unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4555078 }, /* unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4555448 }, /* unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4555827 }, /* unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 4556215 }, /* unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4556408 }, /* unc_m2m_txc_bl_occupancy.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x16,umask=0x3\000\00001\000\000 */
{ 4556547 }, /* unc_m2m_txc_bl_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x16,umask=0x1\000\00001\000\000 */
{ 4556712 }, /* unc_m2m_txc_bl_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x16,umask=0x2\000\00001\000\000 */
{ 4557187 }, /* unc_m2m_txr_horz_ads_used.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4557719 }, /* unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558257 }, /* unc_m2m_txr_horz_ads_used.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558811 }, /* unc_m2m_txr_horz_ads_used.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559343 }, /* unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4560188 }, /* unc_m2m_txr_horz_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4560709 }, /* unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561494 }, /* unc_m2m_txr_horz_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562331 }, /* unc_m2m_txr_horz_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562852 }, /* unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563637 }, /* unc_m2m_txr_horz_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4564277 }, /* unc_m2m_txr_horz_cycles_full.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4564976 }, /* unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566036 }, /* unc_m2m_txr_horz_cycles_full.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4567148 }, /* unc_m2m_txr_horz_cycles_full.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4567847 }, /* unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568907 }, /* unc_m2m_txr_horz_cycles_full.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4569641 }, /* unc_m2m_txr_horz_cycles_ne.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4570361 }, /* unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m2m \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571455 }, /* unc_m2m_txr_horz_cycles_ne.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4572601 }, /* unc_m2m_txr_horz_cycles_ne.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4573321 }, /* unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m2m \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574415 }, /* unc_m2m_txr_horz_cycles_ne.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4575124 }, /* unc_m2m_txr_horz_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4575796 }, /* unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m2m \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576809 }, /* unc_m2m_txr_horz_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577874 }, /* unc_m2m_txr_horz_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4578546 }, /* unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m2m \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579559 }, /* unc_m2m_txr_horz_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4580151 }, /* unc_m2m_txr_horz_nack.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4580623 }, /* unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m2m \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581335 }, /* unc_m2m_txr_horz_nack.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582098 }, /* unc_m2m_txr_horz_nack.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582570 }, /* unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m2m \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583282 }, /* unc_m2m_txr_horz_nack.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583876 }, /* unc_m2m_txr_horz_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4584544 }, /* unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585552 }, /* unc_m2m_txr_horz_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4586612 }, /* unc_m2m_txr_horz_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587280 }, /* unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4588288 }, /* unc_m2m_txr_horz_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4589011 }, /* unc_m2m_txr_horz_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590109 }, /* unc_m2m_txr_horz_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4591259 }, /* unc_m2m_txr_horz_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592357 }, /* unc_m2m_txr_horz_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592967 }, /* unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593488 }, /* unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593729 }, /* unc_m2m_txr_vert_ads_used.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593969 }, /* unc_m2m_txr_vert_ads_used.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594490 }, /* unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595011 }, /* unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595522 }, /* unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596023 }, /* unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596524 }, /* unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597025 }, /* unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597526 }, /* unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598027 }, /* unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598258 }, /* unc_m2m_txr_vert_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m2m \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4599294 }, /* unc_m2m_txr_vert_cycles_full.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4599739 }, /* unc_m2m_txr_vert_cycles_full.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4600153 }, /* unc_m2m_txr_vert_cycles_full.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4600580 }, /* unc_m2m_txr_vert_cycles_full.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4600948 }, /* unc_m2m_txr_vert_cycles_full.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4601391 }, /* unc_m2m_txr_vert_cycles_full.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4601828 }, /* unc_m2m_txr_vert_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4606605 }, /* unc_m2m_txr_vert_cycles_ne.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4607054 }, /* unc_m2m_txr_vert_cycles_ne.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4607472 }, /* unc_m2m_txr_vert_cycles_ne.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4607903 }, /* unc_m2m_txr_vert_cycles_ne.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4608275 }, /* unc_m2m_txr_vert_cycles_ne.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4608722 }, /* unc_m2m_txr_vert_cycles_ne.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4609163 }, /* unc_m2m_txr_vert_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m2m \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4614025 }, /* unc_m2m_txr_vert_inserts.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4614450 }, /* unc_m2m_txr_vert_inserts.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4614844 }, /* unc_m2m_txr_vert_inserts.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4615251 }, /* unc_m2m_txr_vert_inserts.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4615599 }, /* unc_m2m_txr_vert_inserts.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4616022 }, /* unc_m2m_txr_vert_inserts.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4616439 }, /* unc_m2m_txr_vert_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m2m \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4620899 }, /* unc_m2m_txr_vert_nack.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621107 }, /* unc_m2m_txr_vert_nack.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621316 }, /* unc_m2m_txr_vert_nack.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621524 }, /* unc_m2m_txr_vert_nack.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621733 }, /* unc_m2m_txr_vert_nack.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621941 }, /* unc_m2m_txr_vert_nack.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622150 }, /* unc_m2m_txr_vert_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624610 }, /* unc_m2m_txr_vert_occupancy.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4625042 }, /* unc_m2m_txr_vert_occupancy.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4625443 }, /* unc_m2m_txr_vert_occupancy.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4625857 }, /* unc_m2m_txr_vert_occupancy.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4626212 }, /* unc_m2m_txr_vert_occupancy.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4626642 }, /* unc_m2m_txr_vert_occupancy.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4627066 }, /* unc_m2m_txr_vert_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4631578 }, /* unc_m2m_txr_vert_starved.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4631894 }, /* unc_m2m_txr_vert_starved.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632211 }, /* unc_m2m_txr_vert_starved.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632527 }, /* unc_m2m_txr_vert_starved.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632844 }, /* unc_m2m_txr_vert_starved.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4633160 }, /* unc_m2m_txr_vert_starved.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4633477 }, /* unc_m2m_txr_vert_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4638447 }, /* unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4640241 }, /* unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4642032 }, /* unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4643820 }, /* unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4645613 }, /* unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4647407 }, /* unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4649198 }, /* unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4650986 }, /* unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4656475 }, /* unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4658265 }, /* unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4660052 }, /* unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4661836 }, /* unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4663299 }, /* unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4664445 }, /* unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4668699 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00011\000\000 */
{ 4668895 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00011\000\000 */
{ 4669091 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00011\000\000 */
{ 4669287 }, /* unc_m2m_wpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4669450 }, /* unc_m2m_wpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4669613 }, /* unc_m2m_wpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4669776 }, /* unc_m2m_wpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 4669940 }, /* unc_m2m_wpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 4670104 }, /* unc_m2m_wpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 4679813 }, /* unc_m2m_write_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4679964 }, /* unc_m2m_write_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4680115 }, /* unc_m2m_write_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4680266 }, /* unc_m2m_write_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4680420 }, /* unc_m2m_write_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4680574 }, /* unc_m2m_write_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4680728 }, /* unc_m2m_write_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x61,umask=0x1\000\00001\000\000 */
{ 4680871 }, /* unc_m2m_write_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x61,umask=0x2\000\00001\000\000 */
{ 4681014 }, /* unc_m2m_write_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x61,umask=0x4\000\00001\000\000 */
{ 4681157 }, /* unc_m2m_write_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x60,umask=0x1\000\00001\000\000 */
{ 4681304 }, /* unc_m2m_write_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x60,umask=0x2\000\00001\000\000 */
{ 4681451 }, /* unc_m2m_write_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x60,umask=0x4\000\00001\000\000 */
{ 4881009 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881247 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881485 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881723 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881961 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4882200 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4885658 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4885896 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886134 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886372 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886610 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886849 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4890318 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4890556 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4890794 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891032 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891270 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891509 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4894967 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895205 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895443 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895681 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895919 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4896158 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4899627 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4899865 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900103 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900341 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900579 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900818 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4904276 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904514 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904752 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904990 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4905228 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4905467 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4912155 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912393 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912631 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912869 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4913107 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4913346 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4916815 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917057 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917299 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917541 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917783 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4918026 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4918526 }, /* unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919000 }, /* unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919484 }, /* unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919969 }, /* unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4920778 }, /* unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_m3upi \000event=0x1\000\00001\000Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 4921151 }, /* unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000 */
{ 4921377 }, /* unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000Count cases BL sends direct to core\000 */
{ 4921654 }, /* unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000Cases where SMI3 sends D2U command\000 */
{ 4925155 }, /* unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m3upi \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925732 }, /* unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m3upi \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925993 }, /* unc_m3upi_fast_asserted.horz\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m3upi \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4926266 }, /* unc_m3upi_fast_asserted.vert\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4927470 }, /* unc_m3upi_horz_ring_ad_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4929288 }, /* unc_m3upi_horz_ring_ad_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4931110 }, /* unc_m3upi_horz_ring_ad_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4932933 }, /* unc_m3upi_horz_ring_ad_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4934752 }, /* unc_m3upi_horz_ring_ak_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4936566 }, /* unc_m3upi_horz_ring_ak_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4938384 }, /* unc_m3upi_horz_ring_ak_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4940203 }, /* unc_m3upi_horz_ring_ak_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4945781 }, /* unc_m3upi_horz_ring_bl_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m3upi \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4947597 }, /* unc_m3upi_horz_ring_bl_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4949417 }, /* unc_m3upi_horz_ring_bl_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m3upi \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4951238 }, /* unc_m3upi_horz_ring_bl_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4952731 }, /* unc_m3upi_horz_ring_iv_in_use.left\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m3upi \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4953910 }, /* unc_m3upi_horz_ring_iv_in_use.right\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m3upi \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4954482 }, /* unc_m3upi_m2_bl_credits_empty.iio0_iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4955306 }, /* unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4955718 }, /* unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4956130 }, /* unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4956543 }, /* unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4957066 }, /* unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4957577 }, /* unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4958703 }, /* unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959245 }, /* unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959787 }, /* unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960330 }, /* unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960874 }, /* unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961417 }, /* unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961973 }, /* unc_m3upi_ring_bounces_horz.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m3upi \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4962531 }, /* unc_m3upi_ring_bounces_horz.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m3upi \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963089 }, /* unc_m3upi_ring_bounces_horz.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m3upi \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963647 }, /* unc_m3upi_ring_bounces_horz.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m3upi \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4964199 }, /* unc_m3upi_ring_bounces_vert.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m3upi \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4964791 }, /* unc_m3upi_ring_bounces_vert.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4965692 }, /* unc_m3upi_ring_bounces_vert.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m3upi \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4966311 }, /* unc_m3upi_ring_bounces_vert.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4966740 }, /* unc_m3upi_ring_sink_starved_horz.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m3upi \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 4967051 }, /* unc_m3upi_ring_sink_starved_horz.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m3upi \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 4967392 }, /* unc_m3upi_ring_sink_starved_horz.ak_ag1\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m3upi \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 4967733 }, /* unc_m3upi_ring_sink_starved_horz.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m3upi \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 4968044 }, /* unc_m3upi_ring_sink_starved_horz.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m3upi \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 4968353 }, /* unc_m3upi_ring_sink_starved_vert.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m3upi \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 4968682 }, /* unc_m3upi_ring_sink_starved_vert.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 4969182 }, /* unc_m3upi_ring_sink_starved_vert.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m3upi \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 4969534 }, /* unc_m3upi_ring_sink_starved_vert.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 4969712 }, /* unc_m3upi_ring_src_thrtl\000uncore_m3upi\000uncore interconnect\000Source Throttle. Unit: uncore_m3upi \000event=0xa4\000\00001\000\000 */
{ 4970259 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000VN0 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4970901 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4971498 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000VN0 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4972113 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4972710 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4973288 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4974011 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000VN0 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4974711 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000VN1 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4975353 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4975950 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000VN1 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4976565 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4977162 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4977740 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4978463 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000VN1 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4978838 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; AD, BL Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4980246 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000 */
{ 4980853 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000 */
{ 4981460 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000 */
{ 4982068 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000 */
{ 4982346 }, /* unc_m3upi_rxc_arb_misc.par_bias_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn0, delaying vn1 win, because vn0 offered parallel ad/bl\000 */
{ 4982607 }, /* unc_m3upi_rxc_arb_misc.par_bias_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn1, delaying vn0 win, because vn1 offered parallel ad/bl\000 */
{ 4983171 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4983514 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4983882 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4984180 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4984566 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4984846 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4985213 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4985639 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4985982 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4986350 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4986648 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4987034 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4987314 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4987681 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4993643 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4993988 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4994358 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4994658 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4995046 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4995328 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4995697 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4996125 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4996470 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4996840 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4997140 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4997528 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4997810 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4998179 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5004336 }, /* unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000 */
{ 5004988 }, /* unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while pipeline is idle\000 */
{ 5005626 }, /* unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 1 while merging with bl message in same flit\000 */
{ 5006269 }, /* unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 2 while merging with bl message in same flit\000 */
{ 5006567 }, /* unc_m3upi_rxc_collision_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5006906 }, /* unc_m3upi_rxc_collision_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5007270 }, /* unc_m3upi_rxc_collision_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5007564 }, /* unc_m3upi_rxc_collision_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5007946 }, /* unc_m3upi_rxc_collision_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x50,umask=0x40\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5008222 }, /* unc_m3upi_rxc_collision_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5008585 }, /* unc_m3upi_rxc_collision_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5009007 }, /* unc_m3upi_rxc_collision_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5009346 }, /* unc_m3upi_rxc_collision_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5009710 }, /* unc_m3upi_rxc_collision_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5010004 }, /* unc_m3upi_rxc_collision_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5010386 }, /* unc_m3upi_rxc_collision_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5010662 }, /* unc_m3upi_rxc_collision_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5011025 }, /* unc_m3upi_rxc_collision_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5011725 }, /* unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any In BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Indication that at least one packet (flit) is in the bgf (fifo only)\000 */
{ 5012245 }, /* unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000 */
{ 5012897 }, /* unc_m3upi_rxc_crd_misc.no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; No D2K For Arb. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000VN0 or VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000 */
{ 5014209 }, /* unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; D2K Credits. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5014703 }, /* unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000 */
{ 5015227 }, /* unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF Path. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000 */
{ 5015699 }, /* unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x40\000\00001\000count of bl messages in pump-1-pending state, in completion fifo only\000 */
{ 5016119 }, /* unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000count of bl messages in pump-1-pending state, in marker table and in fifo\000 */
{ 5016596 }, /* unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Transmit Credits. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5017095 }, /* unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; VNA In Use. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000 */
{ 5018013 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5019348 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5020638 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5021946 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5023236 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5024507 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5025923 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5027316 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x44,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5028651 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5029941 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5031249 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5032539 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x44,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5033810 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x44,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5035226 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5037823 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000 */
{ 5038553 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Ready. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 1; header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000 */
{ 5039314 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Wasted. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Events related to Header Flit Generation - Set 1; Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000 */
{ 5040059 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000 */
{ 5041675 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Message. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting is in run-ahead to start new flit, and message is actually slotted into new flit\000 */
{ 5041986 }, /* unc_m3upi_rxc_flit_gen_hdr1.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Ok. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Events related to Header Flit Generation - Set 1; New header flit construction may proceed in parallel with data flit sequence\000 */
{ 5042258 }, /* unc_m3upi_rxc_flit_gen_hdr1.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Flit Finished. Unit: uncore_m3upi \000event=0x53,umask=0x80\000\00001\000Events related to Header Flit Generation - Set 1; Header flit finished assembly in parallel with data flit sequence\000 */
{ 5042535 }, /* unc_m3upi_rxc_flit_gen_hdr1.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Message. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Events related to Header Flit Generation - Set 1; Message is slotted into header flit in parallel with data flit sequence\000 */
{ 5044045 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 2; Rate-matching stall injected\000 */
{ 5044647 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 2; Rate matching stall injected, but no additional message slotted during stall cycle\000 */
{ 5044955 }, /* unc_m3upi_rxc_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent; All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000header flit is ready for transmission but could not be sent\000 */
{ 5045147 }, /* unc_m3upi_rxc_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available\000 */
{ 5045383 }, /* unc_m3upi_rxc_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available; no additional message slotted into flit\000 */
{ 5045690 }, /* unc_m3upi_rxc_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available\000 */
{ 5045926 }, /* unc_m3upi_rxc_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available; no additional message slotted into flit\000 */
{ 5046234 }, /* unc_m3upi_rxc_flit_not_sent.one_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - One Slot Taken. Unit: uncore_m3upi \000event=0x55,umask=0x20\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only one slot taken (two slots free)\000 */
{ 5046514 }, /* unc_m3upi_rxc_flit_not_sent.three_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Three Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x80\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with three slots taken (no slots free)\000 */
{ 5046796 }, /* unc_m3upi_rxc_flit_not_sent.two_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Two Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x40\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only two slots taken (one slots free)\000 */
{ 5047078 }, /* unc_m3upi_rxc_flits_data_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; All. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047277 }, /* unc_m3upi_rxc_flits_data_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047490 }, /* unc_m3upi_rxc_flits_data_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047977 }, /* unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 0. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000generating bl data flit sequence; waiting for data pump 0\000 */
{ 5048472 }, /* unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 1. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000generating bl data flit sequence; waiting for data pump 1\000 */
{ 5048963 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000 */
{ 5049435 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000pump-1-pending logic is tracking at least one message\000 */
{ 5049865 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000pump-1-pending completion fifo is full\000 */
{ 5050362 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000 */
{ 5050890 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000a bl message finished but is in limbo and moved to pump-1-pending logic\000 */
{ 5052047 }, /* unc_m3upi_rxc_flits_misc\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC. Unit: uncore_m3upi \000event=0x5a\000\00001\000\000 */
{ 5052167 }, /* unc_m3upi_rxc_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000One message in flit; VNA or non-VNA flit\000 */
{ 5052348 }, /* unc_m3upi_rxc_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message in non-VNA. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000One message in flit; non-VNA flit\000 */
{ 5052537 }, /* unc_m3upi_rxc_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Two Messages. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Two messages in flit; VNA flit\000 */
{ 5052710 }, /* unc_m3upi_rxc_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Three Messages. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Three messages in flit; VNA flit\000 */
{ 5052887 }, /* unc_m3upi_rxc_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000\000 */
{ 5053018 }, /* unc_m3upi_rxc_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000\000 */
{ 5053149 }, /* unc_m3upi_rxc_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000\000 */
{ 5053435 }, /* unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; All. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000\000 */
{ 5053857 }, /* unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Needs Data Flit. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000BL message requires data flit sequence\000 */
{ 5054318 }, /* unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 0. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000Waiting for header pump 0\000 */
{ 5054786 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x10\000\00001\000Header pump 1 is not required for flit\000 */
{ 5055333 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x58,umask=0x20\000\00001\000Header pump 1 is not required for flit but flit transmission delayed\000 */
{ 5055923 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x58,umask=0x40\000\00001\000Header pump 1 is not required for flit and not available\000 */
{ 5056428 }, /* unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000Waiting for header pump 1\000 */
{ 5060558 }, /* unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot AD. Unit: uncore_m3upi \000event=0x52,umask=0x40\000\00001\000some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061068 }, /* unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot BL. Unit: uncore_m3upi \000event=0x52,umask=0x80\000\00001\000some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061307 }, /* unc_m3upi_rxc_held.parallel_ad_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel AD Lost. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000some AD message lost contest for slot 0 (logical OR of all AD events under INGR_SLOT_LOST_MC_VN{0,1})\000 */
{ 5061805 }, /* unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Attempt. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000ad and bl messages attempted to slot into the same flit in parallel\000 */
{ 5062019 }, /* unc_m3upi_rxc_held.parallel_bl_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel BL Lost. Unit: uncore_m3upi \000event=0x52,umask=0x20\000\00001\000some BL message lost contest for slot 0 (logical OR of all BL events under INGR_SLOT_LOST_MC_VN{0,1})\000 */
{ 5062521 }, /* unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Success. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000ad and bl messages were actually slotted into the same flit in parallel\000 */
{ 5062993 }, /* unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held; VN0. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000 */
{ 5063479 }, /* unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held; VN1. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000 */
{ 5064368 }, /* unc_m3upi_rxc_inserts_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x41,umask=0x1\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5065652 }, /* unc_m3upi_rxc_inserts_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x4\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5066891 }, /* unc_m3upi_rxc_inserts_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x2\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5068148 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x20\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5069387 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x41,umask=0x40\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5070607 }, /* unc_m3upi_rxc_inserts_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x41,umask=0x8\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5071972 }, /* unc_m3upi_rxc_inserts_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x10\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5073324 }, /* unc_m3upi_rxc_inserts_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x42,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5074628 }, /* unc_m3upi_rxc_inserts_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5075887 }, /* unc_m3upi_rxc_inserts_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5077164 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5078423 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x42,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5079663 }, /* unc_m3upi_rxc_inserts_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x42,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5081048 }, /* unc_m3upi_rxc_inserts_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5082381 }, /* unc_m3upi_rxc_occupancy_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x45,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5083625 }, /* unc_m3upi_rxc_occupancy_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5084824 }, /* unc_m3upi_rxc_occupancy_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5086041 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5087240 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x45,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5088420 }, /* unc_m3upi_rxc_occupancy_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x45,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5089745 }, /* unc_m3upi_rxc_occupancy_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5091047 }, /* unc_m3upi_rxc_occupancy_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x46,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5092291 }, /* unc_m3upi_rxc_occupancy_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5093490 }, /* unc_m3upi_rxc_occupancy_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5094707 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5095906 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x46,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5097086 }, /* unc_m3upi_rxc_occupancy_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x46,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5098411 }, /* unc_m3upi_rxc_occupancy_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5099553 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5100485 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5101372 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5102277 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5103164 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5104032 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5105045 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5106035 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5106967 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5107854 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5108759 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5109646 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5110514 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5111527 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5112039 }, /* unc_m3upi_rxc_smi3_pftch.arb_lost\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Lost Arbitration. Unit: uncore_m3upi \000event=0x62,umask=0x2\000\00001\000\000 */
{ 5112194 }, /* unc_m3upi_rxc_smi3_pftch.arrived\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Arrived. Unit: uncore_m3upi \000event=0x62,umask=0x1\000\00001\000\000 */
{ 5112339 }, /* unc_m3upi_rxc_smi3_pftch.drop_old\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Old. Unit: uncore_m3upi \000event=0x62,umask=0x8\000\00001\000\000 */
{ 5112491 }, /* unc_m3upi_rxc_smi3_pftch.drop_wrap\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Wrap. Unit: uncore_m3upi \000event=0x62,umask=0x10\000\00001\000Dropped because it was overwritten by new message while prefetch queue was full\000 */
{ 5112725 }, /* unc_m3upi_rxc_smi3_pftch.slotted\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Slotted. Unit: uncore_m3upi \000event=0x62,umask=0x4\000\00001\000\000 */
{ 5113090 }, /* unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Any In Use. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000At least one remote vna credit is in use\000 */
{ 5113514 }, /* unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Corrected. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000Number of remote vna credits corrected (local return) per cycle\000 */
{ 5114207 }, /* unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 1. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000Remote vna credit level is less than 1 (i.e. no vna credits available)\000 */
{ 5114667 }, /* unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 4. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000 */
{ 5115135 }, /* unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 5. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000 */
{ 5115350 }, /* unc_m3upi_rxc_vna_crd.used\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Used. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000Number of remote vna credits consumed per cycle\000 */
{ 5117873 }, /* unc_m3upi_rxr_busy_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5118721 }, /* unc_m3upi_rxr_busy_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5120047 }, /* unc_m3upi_rxr_busy_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5120895 }, /* unc_m3upi_rxr_busy_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5122008 }, /* unc_m3upi_rxr_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5122436 }, /* unc_m3upi_rxr_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5123081 }, /* unc_m3upi_rxr_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5123777 }, /* unc_m3upi_rxr_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5124205 }, /* unc_m3upi_rxr_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5124850 }, /* unc_m3upi_rxr_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5125524 }, /* unc_m3upi_rxr_crd_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5126394 }, /* unc_m3upi_rxr_crd_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5127705 }, /* unc_m3upi_rxr_crd_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5128597 }, /* unc_m3upi_rxr_crd_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5129467 }, /* unc_m3upi_rxr_crd_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5130804 }, /* unc_m3upi_rxr_crd_starved.ifv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5131646 }, /* unc_m3upi_rxr_crd_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5132802 }, /* unc_m3upi_rxr_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5133375 }, /* unc_m3upi_rxr_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5134240 }, /* unc_m3upi_rxr_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5135156 }, /* unc_m3upi_rxr_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5135729 }, /* unc_m3upi_rxr_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5136594 }, /* unc_m3upi_rxr_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5137194 }, /* unc_m3upi_rxr_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5137781 }, /* unc_m3upi_rxr_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5138666 }, /* unc_m3upi_rxr_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5139602 }, /* unc_m3upi_rxr_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5140189 }, /* unc_m3upi_rxr_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5141074 }, /* unc_m3upi_rxr_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5157404 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5157704 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158004 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158304 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158604 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158905 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159206 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159506 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159806 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160106 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160406 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160707 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161008 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161308 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161608 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161908 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162208 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162509 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162810 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163110 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163410 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163710 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164010 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164311 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164853 }, /* unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5165295 }, /* unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5165737 }, /* unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5166176 }, /* unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5166617 }, /* unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167061 }, /* unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167505 }, /* unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167946 }, /* unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5168441 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169013 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169585 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170161 }, /* unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170986 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171440 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171894 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172345 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172798 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173254 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173710 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174163 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174859 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5175801 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5176743 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5177682 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5178623 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5179567 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180511 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5181121 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 5181436 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 5181751 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 5182064 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 5182378 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 5182695 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 5183012 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 5183170 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x4\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to CHA\000 */
{ 5183450 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x40\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn0 Snpf\000 */
{ 5183768 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x1\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI0\000 */
{ 5184066 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x2\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI1\000 */
{ 5184364 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x20\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to CHA\000 */
{ 5184645 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x80\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn1 Snpf\000 */
{ 5184963 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x8\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI0\000 */
{ 5185261 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x10\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI1\000 */
{ 5185560 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x1\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn0\000 */
{ 5185795 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_vn2snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x4\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn0 SnpF issued when SnpF pending on Vn1\000 */
{ 5186040 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x2\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn1\000 */
{ 5186275 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_vn0snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x8\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn1 SnpF issued when SnpF pending on Vn0\000 */
{ 5186520 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x1\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5186788 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x2\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187056 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x8\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187322 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x10\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187591 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x20\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187860 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x80\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5188127 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x1\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188389 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x2\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188651 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x8\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188911 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x10\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189174 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x20\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189437 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x80\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189698 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x1\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190004 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x4\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190310 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x2\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190616 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x8\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190920 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x10\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191227 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x40\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191534 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x20\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191841 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x80\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5192146 }, /* unc_m3upi_txc_ak_flq_inserts\000uncore_m3upi\000uncore interconnect\000AK Flow Q Inserts. Unit: uncore_m3upi \000event=0x2f\000\00001\000\000 */
{ 5192263 }, /* unc_m3upi_txc_ak_flq_occupancy\000uncore_m3upi\000uncore interconnect\000AK Flow Q Occupancy. Unit: uncore_m3upi \000event=0x1e\000\00001\000\000 */
{ 5192625 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193067 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193509 }, /* unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193948 }, /* unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5194389 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5194833 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5195277 }, /* unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5195718 }, /* unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5196166 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196620 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197074 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197525 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197978 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198434 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198890 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199343 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5200039 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5200979 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5201920 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5202861 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5203803 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5204745 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5205688 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5206631 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5207240 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 5207555 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 5207870 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 5208183 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 5208497 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 5208814 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 5209131 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 5209446 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 5209602 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x2\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5209863 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x38,umask=0x8\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210125 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x1\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210385 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x20\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210647 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x80\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210910 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x38,umask=0x10\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5211172 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x4\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5211484 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x8\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5211796 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x1\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212108 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x2\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212418 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x40\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212731 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x80\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5213044 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x10\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5213357 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x20\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5214970 }, /* unc_m3upi_txr_horz_ads_used.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5215514 }, /* unc_m3upi_txr_horz_ads_used.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5216064 }, /* unc_m3upi_txr_horz_ads_used.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5216630 }, /* unc_m3upi_txr_horz_ads_used.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5217174 }, /* unc_m3upi_txr_horz_ads_used.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5218037 }, /* unc_m3upi_txr_horz_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5218570 }, /* unc_m3upi_txr_horz_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5219373 }, /* unc_m3upi_txr_horz_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5220228 }, /* unc_m3upi_txr_horz_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5220761 }, /* unc_m3upi_txr_horz_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5221564 }, /* unc_m3upi_txr_horz_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5222216 }, /* unc_m3upi_txr_horz_cycles_full.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5222927 }, /* unc_m3upi_txr_horz_cycles_full.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5224005 }, /* unc_m3upi_txr_horz_cycles_full.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5225135 }, /* unc_m3upi_txr_horz_cycles_full.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5225846 }, /* unc_m3upi_txr_horz_cycles_full.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5226924 }, /* unc_m3upi_txr_horz_cycles_full.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5227670 }, /* unc_m3upi_txr_horz_cycles_ne.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5228402 }, /* unc_m3upi_txr_horz_cycles_ne.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5229514 }, /* unc_m3upi_txr_horz_cycles_ne.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5230678 }, /* unc_m3upi_txr_horz_cycles_ne.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5231410 }, /* unc_m3upi_txr_horz_cycles_ne.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5232522 }, /* unc_m3upi_txr_horz_cycles_ne.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5233243 }, /* unc_m3upi_txr_horz_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5233927 }, /* unc_m3upi_txr_horz_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5234958 }, /* unc_m3upi_txr_horz_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5236041 }, /* unc_m3upi_txr_horz_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5236725 }, /* unc_m3upi_txr_horz_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5237756 }, /* unc_m3upi_txr_horz_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5238360 }, /* unc_m3upi_txr_horz_nack.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5238844 }, /* unc_m3upi_txr_horz_nack.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5239574 }, /* unc_m3upi_txr_horz_nack.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5240355 }, /* unc_m3upi_txr_horz_nack.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5240839 }, /* unc_m3upi_txr_horz_nack.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5241569 }, /* unc_m3upi_txr_horz_nack.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5242175 }, /* unc_m3upi_txr_horz_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5242855 }, /* unc_m3upi_txr_horz_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5243881 }, /* unc_m3upi_txr_horz_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5244959 }, /* unc_m3upi_txr_horz_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5245639 }, /* unc_m3upi_txr_horz_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5246665 }, /* unc_m3upi_txr_horz_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5247400 }, /* unc_m3upi_txr_horz_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5248516 }, /* unc_m3upi_txr_horz_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5249684 }, /* unc_m3upi_txr_horz_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5250800 }, /* unc_m3upi_txr_horz_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5251422 }, /* unc_m3upi_txr_vert_ads_used.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5251955 }, /* unc_m3upi_txr_vert_ads_used.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252202 }, /* unc_m3upi_txr_vert_ads_used.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252448 }, /* unc_m3upi_txr_vert_ads_used.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252981 }, /* unc_m3upi_txr_vert_ads_used.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5253514 }, /* unc_m3upi_txr_vert_ads_used.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5254037 }, /* unc_m3upi_txr_vert_bypass.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5254550 }, /* unc_m3upi_txr_vert_bypass.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255063 }, /* unc_m3upi_txr_vert_bypass.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255576 }, /* unc_m3upi_txr_vert_bypass.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256089 }, /* unc_m3upi_txr_vert_bypass.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256602 }, /* unc_m3upi_txr_vert_bypass.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256839 }, /* unc_m3upi_txr_vert_bypass.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m3upi \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5257899 }, /* unc_m3upi_txr_vert_cycles_full.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5258350 }, /* unc_m3upi_txr_vert_cycles_full.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5258770 }, /* unc_m3upi_txr_vert_cycles_full.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5259203 }, /* unc_m3upi_txr_vert_cycles_full.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5259577 }, /* unc_m3upi_txr_vert_cycles_full.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5260026 }, /* unc_m3upi_txr_vert_cycles_full.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5260469 }, /* unc_m3upi_txr_vert_cycles_full.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m3upi \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5265306 }, /* unc_m3upi_txr_vert_cycles_ne.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5265761 }, /* unc_m3upi_txr_vert_cycles_ne.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5266185 }, /* unc_m3upi_txr_vert_cycles_ne.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5266622 }, /* unc_m3upi_txr_vert_cycles_ne.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5267000 }, /* unc_m3upi_txr_vert_cycles_ne.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5267453 }, /* unc_m3upi_txr_vert_cycles_ne.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5267900 }, /* unc_m3upi_txr_vert_cycles_ne.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m3upi \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5272822 }, /* unc_m3upi_txr_vert_inserts.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5273253 }, /* unc_m3upi_txr_vert_inserts.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5273653 }, /* unc_m3upi_txr_vert_inserts.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5274066 }, /* unc_m3upi_txr_vert_inserts.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5274420 }, /* unc_m3upi_txr_vert_inserts.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5274849 }, /* unc_m3upi_txr_vert_inserts.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5275272 }, /* unc_m3upi_txr_vert_inserts.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m3upi \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5279792 }, /* unc_m3upi_txr_vert_nack.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280006 }, /* unc_m3upi_txr_vert_nack.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280221 }, /* unc_m3upi_txr_vert_nack.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280435 }, /* unc_m3upi_txr_vert_nack.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280650 }, /* unc_m3upi_txr_vert_nack.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280864 }, /* unc_m3upi_txr_vert_nack.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5281079 }, /* unc_m3upi_txr_vert_nack.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m3upi \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5283599 }, /* unc_m3upi_txr_vert_occupancy.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5284037 }, /* unc_m3upi_txr_vert_occupancy.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5284444 }, /* unc_m3upi_txr_vert_occupancy.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5284864 }, /* unc_m3upi_txr_vert_occupancy.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5285225 }, /* unc_m3upi_txr_vert_occupancy.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5285661 }, /* unc_m3upi_txr_vert_occupancy.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5286091 }, /* unc_m3upi_txr_vert_occupancy.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m3upi \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5290663 }, /* unc_m3upi_txr_vert_starved.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5290985 }, /* unc_m3upi_txr_vert_starved.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291308 }, /* unc_m3upi_txr_vert_starved.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291630 }, /* unc_m3upi_txr_vert_starved.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291953 }, /* unc_m3upi_txr_vert_starved.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5292275 }, /* unc_m3upi_txr_vert_starved.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5292598 }, /* unc_m3upi_txr_vert_starved.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m3upi \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5296973 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5297447 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5297921 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5298396 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5298872 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5299348 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5299793 }, /* unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5300289 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5300837 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301380 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301928 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302478 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303023 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303537 }, /* unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303988 }, /* unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000Prefetches generated by the flow control queue of the M3UPI unit. Unit: uncore_m3upi \000event=0x29\000\00001\000Count cases where flow control queue that sits between the Intel(R) Ultra Path Interconnect (UPI) and the mesh spawns a prefetch to the iMC (Memory Controller)\000 */
{ 5305237 }, /* unc_m3upi_vert_ring_ad_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5307043 }, /* unc_m3upi_vert_ring_ad_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5308846 }, /* unc_m3upi_vert_ring_ad_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5310646 }, /* unc_m3upi_vert_ring_ad_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5312451 }, /* unc_m3upi_vert_ring_ak_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5314257 }, /* unc_m3upi_vert_ring_ak_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5316060 }, /* unc_m3upi_vert_ring_ak_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5317860 }, /* unc_m3upi_vert_ring_ak_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5323385 }, /* unc_m3upi_vert_ring_bl_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5325187 }, /* unc_m3upi_vert_ring_bl_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5326986 }, /* unc_m3upi_vert_ring_bl_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5328782 }, /* unc_m3upi_vert_ring_bl_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5330257 }, /* unc_m3upi_vert_ring_iv_in_use.dn\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m3upi \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5331415 }, /* unc_m3upi_vert_ring_iv_in_use.up\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m3upi \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5336863 }, /* unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5339120 }, /* unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5341293 }, /* unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5343448 }, /* unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5345558 }, /* unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5347666 }, /* unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5349137 }, /* unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000Number of Cycles there were no VN0 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5349865 }, /* unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000Number of Cycles there were no VN0 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5350509 }, /* unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000Number of Cycles there were no VN0 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5351135 }, /* unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5351716 }, /* unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000Number of Cycles there were no VN0 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5352295 }, /* unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5353766 }, /* unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5356021 }, /* unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5358192 }, /* unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5360345 }, /* unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5362453 }, /* unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5364559 }, /* unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5366029 }, /* unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Number of Cycles there were no VN1 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5366757 }, /* unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Number of Cycles there were no VN1 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5367401 }, /* unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Number of Cycles there were no VN1 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5368027 }, /* unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5368608 }, /* unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Number of Cycles there were no VN1 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5369187 }, /* unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5640867 }, /* unc_nounit_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_TxC_BL.DRS_UPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00011\000\000 */
{ 6073363 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000 */
{ 6073826 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6074439 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6075047 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Inter Processor Interrupts\000 */
{ 6075765 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000 */
{ 6076520 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6078090 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6082167 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles\000 */
{ 6082332 }, /* unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 6082474 }, /* unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 6082598 }, /* unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 6082839 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000 */
{ 6085887 }, /* unc_upi_clockticks\000uncore_upi\000uncore interconnect\000Clocks of the Intel(R) Ultra Path Interconnect (UPI). Unit: uncore_upi \000event=0x1\000\00001\000Counts clockticks of the fixed frequency clock controlling the Intel(R) Ultra Path Interconnect (UPI).  This clock runs at1/8th the 'GT/s' speed of the UPI link.  For example, a  9.6GT/s  link will have a fixed Frequency of 1.2 Ghz\000 */
{ 6086763 }, /* unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to core. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to core bypassing the CHA\000 */
{ 6088076 }, /* unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_DIRECT_ATTEMPTS.D2U. Unit: uncore_upi \000event=0x12,umask=0x2\000\00011\000\000 */
{ 6088253 }, /* unc_upi_direct_attempts.d2u\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to Intel(R) UPI. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to Intel(R) Ultra Path Interconnect (UPI) bypassing the CHA \000 */
{ 6088533 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x1\000\00001\000\000 */
{ 6088681 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x2\000\00001\000\000 */
{ 6088829 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x4\000\00001\000\000 */
{ 6088977 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x10\000\00001\000\000 */
{ 6089126 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x20\000\00001\000\000 */
{ 6089275 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x40\000\00001\000\000 */
{ 6089424 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq3\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ3. Unit: uncore_upi \000event=0x18,umask=0x80\000\00001\000\000 */
{ 6089573 }, /* unc_upi_flowq_no_vna_crd.bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.BL_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x8\000\00001\000\000 */
{ 6089721 }, /* unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles Intel(R) UPI is in L1 power mode (shutdown). Unit: uncore_upi \000event=0x21\000\00001\000Counts cycles when the Intel(R) Ultra Path Interconnect (UPI) is in L1 power mode.  L1 is a mode that totally shuts down the UPI link.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another, this event only coutns when both links are shutdown\000 */
{ 6090695 }, /* unc_upi_m3_byp_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x14,umask=0x8\000\00001\000\000 */
{ 6090833 }, /* unc_upi_m3_byp_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x14,umask=0x1\000\00001\000\000 */
{ 6090989 }, /* unc_upi_m3_byp_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x14,umask=0x4\000\00001\000\000 */
{ 6091145 }, /* unc_upi_m3_byp_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x14,umask=0x2\000\00001\000\000 */
{ 6091301 }, /* unc_upi_m3_byp_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x14,umask=0x10\000\00001\000\000 */
{ 6091442 }, /* unc_upi_m3_crd_return_blocked\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_CRD_RETURN_BLOCKED. Unit: uncore_upi \000event=0x16\000\00001\000\000 */
{ 6091568 }, /* unc_upi_m3_rxq_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x15,umask=0x20\000\00001\000\000 */
{ 6091707 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_btw_2_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_BTW_2_THRESH. Unit: uncore_upi \000event=0x15,umask=0x2\000\00001\000\000 */
{ 6091881 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x15,umask=0x1\000\00001\000\000 */
{ 6092037 }, /* unc_upi_m3_rxq_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x15,umask=0x10\000\00001\000\000 */
{ 6092194 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_btw_0_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_BTW_0_THRESH. Unit: uncore_upi \000event=0x15,umask=0x8\000\00001\000\000 */
{ 6092368 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x15,umask=0x4\000\00001\000\000 */
{ 6092524 }, /* unc_upi_m3_rxq_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x15,umask=0x40\000\00001\000\000 */
{ 6092665 }, /* unc_upi_phy_init_cycles\000uncore_upi\000uncore interconnect\000Cycles where phy is not in L0, L0c, L0p, L1. Unit: uncore_upi \000event=0x20\000\00001\000\000 */
{ 6092799 }, /* unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6094329 }, /* unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095886 }, /* unc_upi_req_slot2_from_m3.ack\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.ACK. Unit: uncore_upi \000event=0x46,umask=0x8\000\00001\000\000 */
{ 6096022 }, /* unc_upi_req_slot2_from_m3.vn0\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN0. Unit: uncore_upi \000event=0x46,umask=0x2\000\00001\000\000 */
{ 6096158 }, /* unc_upi_req_slot2_from_m3.vn1\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN1. Unit: uncore_upi \000event=0x46,umask=0x4\000\00001\000\000 */
{ 6096294 }, /* unc_upi_req_slot2_from_m3.vna\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VNA. Unit: uncore_upi \000event=0x46,umask=0x1\000\00001\000\000 */
{ 6096430 }, /* unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Receive side. Unit: uncore_upi \000event=0x24\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6098255 }, /* unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles the Rx of the Intel(R) UPI is in L0p power mode. Unit: uncore_upi \000event=0x25\000\00001\000Counts cycles when the receive side (Rx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000 */
{ 6100380 }, /* unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Match Message Class - NCB\000 */
{ 6101312 }, /* unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Match Message Class - NCB\000 */
{ 6102220 }, /* unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Match Message Class - NCS\000 */
{ 6103158 }, /* unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Match Message Class - NCS\000 */
{ 6104040 }, /* unc_upi_rxl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request. Unit: uncore_upi \000event=0x5,umask=0x8\000\00001\000REQ Message Class\000 */
{ 6104928 }, /* unc_upi_rxl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x5,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000 */
{ 6105842 }, /* unc_upi_rxl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0xc\000\00001\000Match Message Class -WB\000 */
{ 6106770 }, /* unc_upi_rxl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0x10c\000\00001\000Match Message Class -WB\000 */
{ 6107678 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0xa\000\00001\000Match Message Class - RSP\000 */
{ 6108621 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0x10a\000\00001\000Match Message Class - RSP\000 */
{ 6109538 }, /* unc_upi_rxl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x5,umask=0x1aa\000\00001\000\000 */
{ 6110419 }, /* unc_upi_rxl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x5,umask=0x12a\000\00001\000\000 */
{ 6111266 }, /* unc_upi_rxl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x5,umask=0x9\000\00001\000SNP Message Class\000 */
{ 6112148 }, /* unc_upi_rxl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x5,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000 */
{ 6113042 }, /* unc_upi_rxl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0xd\000\00001\000Match Message Class -WB\000 */
{ 6113940 }, /* unc_upi_rxl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0x10d\000\00001\000Match Message Class -WB\000 */
{ 6114124 }, /* unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot0 RxQ buffer (Receive Queue) and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6115197 }, /* unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot1 RxQ buffer  (Receive Queue) and passed directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6116292 }, /* unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot2 RxQ buffer (Receive Queue)  and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6119402 }, /* unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6120048 }, /* unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121044 }, /* unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121909 }, /* unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Counts valid data FLITs  (80 bit FLow control unITs: 64bits of data) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000 */
{ 6122222 }, /* unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000 */
{ 6123287 }, /* unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received; Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6124102 }, /* unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received; Idle. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6124630 }, /* unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6125229 }, /* unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6125486 }, /* unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Counts protocol header and credit FLITs  (80 bit FLow control unITs) received from any of the 3 UPI slots on this UPI unit\000 */
{ 6125995 }, /* unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x3,umask=0x20\000\00011\000\000 */
{ 6126547 }, /* unc_upi_rxl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x3,umask=0x80\000\00011\000\000 */
{ 6127036 }, /* unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received; Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6127590 }, /* unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6128120 }, /* unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6128650 }, /* unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6128898 }, /* unc_upi_rxl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x5,umask=0xc\000\00011\000\000 */
{ 6129076 }, /* unc_upi_rxl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x5,umask=0xd\000\00011\000\000 */
{ 6129254 }, /* unc_upi_rxl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x5,umask=0x8\000\00011\000\000 */
{ 6129432 }, /* unc_upi_rxl_hdr_match.rsp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x5,umask=0xa\000\00011\000\000 */
{ 6129615 }, /* unc_upi_rxl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x5,umask=0x9\000\00011\000\000 */
{ 6129793 }, /* unc_upi_rxl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x5,umask=0xb\000\00011\000\000 */
{ 6130575 }, /* unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6131747 }, /* unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6132919 }, /* unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6134152 }, /* unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6135446 }, /* unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6136740 }, /* unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6137367 }, /* unc_upi_rxl_slot_bypass.s0_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x1\000\00001\000\000 */
{ 6137507 }, /* unc_upi_rxl_slot_bypass.s0_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x2\000\00001\000\000 */
{ 6137647 }, /* unc_upi_rxl_slot_bypass.s1_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x4\000\00001\000\000 */
{ 6137787 }, /* unc_upi_rxl_slot_bypass.s1_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x8\000\00001\000\000 */
{ 6137927 }, /* unc_upi_rxl_slot_bypass.s2_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x10\000\00001\000\000 */
{ 6138068 }, /* unc_upi_rxl_slot_bypass.s2_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x20\000\00001\000\000 */
{ 6138209 }, /* unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Transmit side. Unit: uncore_upi \000event=0x26\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6139347 }, /* unc_upi_txl0p_clk_active.cfg_ctl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.CFG_CTL. Unit: uncore_upi \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 6139489 }, /* unc_upi_txl0p_clk_active.dfx\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.DFX. Unit: uncore_upi \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 6139624 }, /* unc_upi_txl0p_clk_active.retry\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RETRY. Unit: uncore_upi \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 6139763 }, /* unc_upi_txl0p_clk_active.rxq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ. Unit: uncore_upi \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 6139897 }, /* unc_upi_txl0p_clk_active.rxq_bypass\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_BYPASS. Unit: uncore_upi \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 6140045 }, /* unc_upi_txl0p_clk_active.rxq_cred\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_CRED. Unit: uncore_upi \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 6140189 }, /* unc_upi_txl0p_clk_active.spare\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.SPARE. Unit: uncore_upi \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 6140328 }, /* unc_upi_txl0p_clk_active.txq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.TXQ. Unit: uncore_upi \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 6141151 }, /* unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in which the Tx of the Intel(R) Ultra Path Interconnect (UPI) is in L0p power mode. Unit: uncore_upi \000event=0x27\000\00001\000Counts cycles when the transmit side (Tx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000 */
{ 6141543 }, /* unc_upi_txl0p_power_cycles_ll_enter\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_LL_ENTER. Unit: uncore_upi \000event=0x28\000\00001\000\000 */
{ 6141681 }, /* unc_upi_txl0p_power_cycles_m3_exit\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_M3_EXIT. Unit: uncore_upi \000event=0x29\000\00001\000\000 */
{ 6143589 }, /* unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Match Message Class - NCB\000 */
{ 6144525 }, /* unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Match Message Class - NCB\000 */
{ 6145437 }, /* unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Match Message Class - NCS\000 */
{ 6146379 }, /* unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Match Message Class - NCS\000 */
{ 6147265 }, /* unc_upi_txl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request. Unit: uncore_upi \000event=0x4,umask=0x8\000\00001\000REQ Message Class\000 */
{ 6148157 }, /* unc_upi_txl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x4,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000 */
{ 6149075 }, /* unc_upi_txl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0xc\000\00001\000Match Message Class -WB\000 */
{ 6150007 }, /* unc_upi_txl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0x10c\000\00001\000Match Message Class -WB\000 */
{ 6150919 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0xa\000\00001\000Match Message Class - RSP\000 */
{ 6151866 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0x10a\000\00001\000Match Message Class - RSP\000 */
{ 6152787 }, /* unc_upi_txl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x4,umask=0x1aa\000\00001\000\000 */
{ 6153672 }, /* unc_upi_txl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x4,umask=0x12a\000\00001\000\000 */
{ 6154523 }, /* unc_upi_txl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x4,umask=0x9\000\00001\000SNP Message Class\000 */
{ 6155409 }, /* unc_upi_txl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x4,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000 */
{ 6156307 }, /* unc_upi_txl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0xd\000\00001\000Match Message Class -WB\000 */
{ 6157209 }, /* unc_upi_txl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0x10d\000\00001\000Match Message Class -WB\000 */
{ 6157394 }, /* unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000FLITs that bypassed the TxL Buffer. Unit: uncore_upi \000event=0x41\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the TxL(transmit) FLIT buffer and pass directly out the UPI Link. Generally, when data is transmitted across the Intel(R) Ultra Path Interconnect (UPI), it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used in L0p (Low Power) mode and (Link Layer Retry) LLR  mode, increasing latency to transfer out to the link\000 */
{ 6158804 }, /* unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs transmitted via any slot. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 6159672 }, /* unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs transmitted from any slot. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) transmitted via any of the 3 Intel(R) Ulra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 6160805 }, /* unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6161142 }, /* unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Idle FLITs transmitted. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Counts when the Intel Ultra Path Interconnect(UPI) transmits an idle FLIT(80 bit FLow control unITs).  Every UPI cycle must be sending either data FLITs, protocol/credit FLITs or idle FLITs\000 */
{ 6161996 }, /* unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6162583 }, /* unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6162836 }, /* unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs transmitted across any slot. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Counts protocol header and credit FLITs (80 bit FLow control unITs) transmitted across any of the 3 UPI (Ultra Path Interconnect) slots on this UPI unit\000 */
{ 6163372 }, /* unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x2,umask=0x20\000\00011\000\000 */
{ 6163916 }, /* unc_upi_txl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x2,umask=0x80\000\00011\000\000 */
{ 6164397 }, /* unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6164939 }, /* unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6165457 }, /* unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6165975 }, /* unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6166219 }, /* unc_upi_txl_hdr_match.data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166340 }, /* unc_upi_txl_hdr_match.dual_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166466 }, /* unc_upi_txl_hdr_match.loc\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166582 }, /* unc_upi_txl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x4,umask=0xe\000\00011\000\000 */
{ 6166760 }, /* unc_upi_txl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x4,umask=0xf\000\00011\000\000 */
{ 6166938 }, /* unc_upi_txl_hdr_match.non_data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167063 }, /* unc_upi_txl_hdr_match.rem\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167179 }, /* unc_upi_txl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x4,umask=0x8\000\00011\000\000 */
{ 6167357 }, /* unc_upi_txl_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000 */
{ 6167545 }, /* unc_upi_txl_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_NODATA. Unit: uncore_upi \000event=0x4,umask=0xa\000\00011\000\000 */
{ 6167737 }, /* unc_upi_txl_hdr_match.sgl_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167862 }, /* unc_upi_txl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x4,umask=0x9\000\00011\000\000 */
{ 6168040 }, /* unc_upi_txl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000 */
{ 6168216 }, /* unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6169257 }, /* unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 6170298 }, /* unc_upi_vna_credit_return_blocked_vn01\000uncore_upi\000uncore interconnect\000UNC_UPI_VNA_CREDIT_RETURN_BLOCKED_VN01. Unit: uncore_upi \000event=0x45\000\00001\000\000 */
{ 6170442 }, /* unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 6241797 }, /* upi_data_bandwidth_tx\000uncore_upi\000uncore interconnect\000UPI interconnect send bandwidth for payload. Derived from unc_upi_txl_flits.all_data. Unit: uncore_upi \000event=0x2,umask=0xf\000\000017.11E-06Bytes\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 1216662 }, /* llc_misses.pcie_read\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4,ch_mask=0x1f\000\000014Bytes\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 1218626 }, /* llc_misses.pcie_write\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1,ch_mask=0x1f\000\000014Bytes\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3928271 }, /* unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the IIO Traffic Controller. Unit: uncore_iio \000event=0x1\000\00001\000Counts clockticks of the 1GHz traffic controller clock in the IIO unit\000 */
{ 3929802 }, /* unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-3. Unit: uncore_iio \000event=0xc2,ch_mask=0x0f,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3931265 }, /* unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3932194 }, /* unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3933123 }, /* unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3934052 }, /* unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3937195 }, /* unc_iio_comp_buf_inserts.port0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937356 }, /* unc_iio_comp_buf_inserts.port1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937517 }, /* unc_iio_comp_buf_inserts.port2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937678 }, /* unc_iio_comp_buf_inserts.port3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3938301 }, /* unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0-3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xf\000\00001\000\000 */
{ 3939267 }, /* unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000\000 */
{ 3939995 }, /* unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000\000 */
{ 3940758 }, /* unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000\000 */
{ 3941486 }, /* unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000\000 */
{ 3945285 }, /* unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3946101 }, /* unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3946884 }, /* unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3947667 }, /* unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3949809 }, /* unc_iio_data_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3950109 }, /* unc_iio_data_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3951729 }, /* unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3952541 }, /* unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3953320 }, /* unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3954099 }, /* unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3956228 }, /* unc_iio_data_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3956527 }, /* unc_iio_data_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3958128 }, /* unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3958930 }, /* unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3959699 }, /* unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3960468 }, /* unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3962569 }, /* unc_iio_data_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3962864 }, /* unc_iio_data_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3964452 }, /* unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3965250 }, /* unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3966015 }, /* unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3966780 }, /* unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3968868 }, /* unc_iio_data_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3969162 }, /* unc_iio_data_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3971560 }, /* unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3973128 }, /* unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3974655 }, /* unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3976127 }, /* unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 3980473 }, /* unc_iio_data_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3980770 }, /* unc_iio_data_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3983856 }, /* unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3985379 }, /* unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3986861 }, /* unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3988289 }, /* unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 3992444 }, /* unc_iio_data_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3992740 }, /* unc_iio_data_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3995027 }, /* unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3996703 }, /* unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3998338 }, /* unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3999918 }, /* unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4004544 }, /* unc_iio_data_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 4004864 }, /* unc_iio_data_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 4007165 }, /* unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit.  In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4008840 }, /* unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4010473 }, /* unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4012051 }, /* unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4016654 }, /* unc_iio_data_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 4016973 }, /* unc_iio_data_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 4018591 }, /* unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4019380 }, /* unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4020136 }, /* unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4020892 }, /* unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4022977 }, /* unc_iio_data_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4023260 }, /* unc_iio_data_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4023543 }, /* unc_iio_data_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4023931 }, /* unc_iio_data_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4024251 }, /* unc_iio_data_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4024606 }, /* unc_iio_data_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4035451 }, /* unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4037437 }, /* unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4039204 }, /* unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4041021 }, /* unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4045823 }, /* unc_iio_data_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4046099 }, /* unc_iio_data_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4047837 }, /* unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4049819 }, /* unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4051582 }, /* unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4053395 }, /* unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4058172 }, /* unc_iio_data_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4058447 }, /* unc_iio_data_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4059880 }, /* unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4060597 }, /* unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4061281 }, /* unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4061965 }, /* unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4063837 }, /* unc_iio_data_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4064095 }, /* unc_iio_data_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4065814 }, /* unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4066946 }, /* unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4068002 }, /* unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4069038 }, /* unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4071588 }, /* unc_iio_data_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4071899 }, /* unc_iio_data_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4074191 }, /* unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4075782 }, /* unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4077332 }, /* unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4078827 }, /* unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4083354 }, /* unc_iio_data_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4083664 }, /* unc_iio_data_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4101175 }, /* unc_iio_link_num_corr_err\000uncore_iio\000uncore io\000Num Link  Correctable Errors. Unit: uncore_iio \000event=0xf\000\00001\000\000 */
{ 4101285 }, /* unc_iio_link_num_retries\000uncore_iio\000uncore io\000Num Link Retries. Unit: uncore_iio \000event=0xe\000\00001\000\000 */
{ 4101382 }, /* unc_iio_mask_match\000uncore_iio\000uncore io\000Number packets that passed the Mask/Match Filter. Unit: uncore_iio \000event=0x21\000\00001\000\000 */
{ 4101975 }, /* unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4102686 }, /* unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4103435 }, /* unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4104093 }, /* unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4104822 }, /* unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4105601 }, /* unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus. Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4106244 }, /* unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4106947 }, /* unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4107688 }, /* unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4108338 }, /* unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4109059 }, /* unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4109830 }, /* unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4110041 }, /* unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0\000\00001\000\000 */
{ 4118219 }, /* unc_iio_payload_bytes_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118430 }, /* unc_iio_payload_bytes_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118641 }, /* unc_iio_payload_bytes_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118852 }, /* unc_iio_payload_bytes_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119063 }, /* unc_iio_payload_bytes_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119273 }, /* unc_iio_payload_bytes_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119483 }, /* unc_iio_payload_bytes_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4119700 }, /* unc_iio_payload_bytes_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4119917 }, /* unc_iio_payload_bytes_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4120134 }, /* unc_iio_payload_bytes_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4120351 }, /* unc_iio_payload_bytes_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120565 }, /* unc_iio_payload_bytes_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120779 }, /* unc_iio_payload_bytes_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120993 }, /* unc_iio_payload_bytes_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121207 }, /* unc_iio_payload_bytes_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121420 }, /* unc_iio_payload_bytes_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121633 }, /* unc_iio_payload_bytes_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4121849 }, /* unc_iio_payload_bytes_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122065 }, /* unc_iio_payload_bytes_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122281 }, /* unc_iio_payload_bytes_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122497 }, /* unc_iio_payload_bytes_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122712 }, /* unc_iio_payload_bytes_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122927 }, /* unc_iio_payload_bytes_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123132 }, /* unc_iio_payload_bytes_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123337 }, /* unc_iio_payload_bytes_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123542 }, /* unc_iio_payload_bytes_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123747 }, /* unc_iio_payload_bytes_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123951 }, /* unc_iio_payload_bytes_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4124155 }, /* unc_iio_payload_bytes_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124371 }, /* unc_iio_payload_bytes_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124587 }, /* unc_iio_payload_bytes_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124803 }, /* unc_iio_payload_bytes_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125019 }, /* unc_iio_payload_bytes_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125234 }, /* unc_iio_payload_bytes_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125449 }, /* unc_iio_payload_bytes_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4125667 }, /* unc_iio_payload_bytes_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4125885 }, /* unc_iio_payload_bytes_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126103 }, /* unc_iio_payload_bytes_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126321 }, /* unc_iio_payload_bytes_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126538 }, /* unc_iio_payload_bytes_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126755 }, /* unc_iio_payload_bytes_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4126971 }, /* unc_iio_payload_bytes_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127187 }, /* unc_iio_payload_bytes_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127403 }, /* unc_iio_payload_bytes_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127619 }, /* unc_iio_payload_bytes_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127834 }, /* unc_iio_payload_bytes_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4128049 }, /* unc_iio_payload_bytes_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128267 }, /* unc_iio_payload_bytes_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128485 }, /* unc_iio_payload_bytes_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128703 }, /* unc_iio_payload_bytes_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128921 }, /* unc_iio_payload_bytes_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4129138 }, /* unc_iio_payload_bytes_out.cfg_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4129355 }, /* unc_iio_payload_bytes_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129569 }, /* unc_iio_payload_bytes_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129783 }, /* unc_iio_payload_bytes_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129997 }, /* unc_iio_payload_bytes_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130211 }, /* unc_iio_payload_bytes_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130424 }, /* unc_iio_payload_bytes_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130637 }, /* unc_iio_payload_bytes_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4130853 }, /* unc_iio_payload_bytes_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131069 }, /* unc_iio_payload_bytes_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131285 }, /* unc_iio_payload_bytes_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131501 }, /* unc_iio_payload_bytes_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131716 }, /* unc_iio_payload_bytes_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131931 }, /* unc_iio_payload_bytes_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132146 }, /* unc_iio_payload_bytes_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132361 }, /* unc_iio_payload_bytes_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132576 }, /* unc_iio_payload_bytes_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132791 }, /* unc_iio_payload_bytes_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4133005 }, /* unc_iio_payload_bytes_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4133219 }, /* unc_iio_payload_bytes_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133436 }, /* unc_iio_payload_bytes_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133653 }, /* unc_iio_payload_bytes_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133870 }, /* unc_iio_payload_bytes_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134087 }, /* unc_iio_payload_bytes_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134303 }, /* unc_iio_payload_bytes_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134519 }, /* unc_iio_payload_bytes_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4134736 }, /* unc_iio_payload_bytes_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4134953 }, /* unc_iio_payload_bytes_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135170 }, /* unc_iio_payload_bytes_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135387 }, /* unc_iio_payload_bytes_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135603 }, /* unc_iio_payload_bytes_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135819 }, /* unc_iio_payload_bytes_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136038 }, /* unc_iio_payload_bytes_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136257 }, /* unc_iio_payload_bytes_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136476 }, /* unc_iio_payload_bytes_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136695 }, /* unc_iio_payload_bytes_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136913 }, /* unc_iio_payload_bytes_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4150367 }, /* unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000 */
{ 4150780 }, /* unc_iio_txn_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4150924 }, /* unc_iio_txn_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151068 }, /* unc_iio_txn_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151212 }, /* unc_iio_txn_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151356 }, /* unc_iio_txn_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151500 }, /* unc_iio_txn_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151644 }, /* unc_iio_txn_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4151791 }, /* unc_iio_txn_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4151938 }, /* unc_iio_txn_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4152085 }, /* unc_iio_txn_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4152232 }, /* unc_iio_txn_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152377 }, /* unc_iio_txn_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152522 }, /* unc_iio_txn_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152667 }, /* unc_iio_txn_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152812 }, /* unc_iio_txn_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152957 }, /* unc_iio_txn_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4153102 }, /* unc_iio_txn_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153307 }, /* unc_iio_txn_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153512 }, /* unc_iio_txn_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153717 }, /* unc_iio_txn_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153922 }, /* unc_iio_txn_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4154126 }, /* unc_iio_txn_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4154330 }, /* unc_iio_txn_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154471 }, /* unc_iio_txn_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154612 }, /* unc_iio_txn_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154753 }, /* unc_iio_txn_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154894 }, /* unc_iio_txn_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4155035 }, /* unc_iio_txn_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4155176 }, /* unc_iio_txn_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155322 }, /* unc_iio_txn_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155468 }, /* unc_iio_txn_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155614 }, /* unc_iio_txn_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155760 }, /* unc_iio_txn_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155906 }, /* unc_iio_txn_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4156052 }, /* unc_iio_txn_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156199 }, /* unc_iio_txn_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156346 }, /* unc_iio_txn_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156493 }, /* unc_iio_txn_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156640 }, /* unc_iio_txn_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156787 }, /* unc_iio_txn_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156934 }, /* unc_iio_txn_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157139 }, /* unc_iio_txn_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157344 }, /* unc_iio_txn_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157549 }, /* unc_iio_txn_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157754 }, /* unc_iio_txn_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157958 }, /* unc_iio_txn_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4158162 }, /* unc_iio_txn_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158369 }, /* unc_iio_txn_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158576 }, /* unc_iio_txn_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158783 }, /* unc_iio_txn_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158990 }, /* unc_iio_txn_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4159196 }, /* unc_iio_txn_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159399 }, /* unc_iio_txn_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159602 }, /* unc_iio_txn_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159805 }, /* unc_iio_txn_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160008 }, /* unc_iio_txn_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160210 }, /* unc_iio_txn_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160412 }, /* unc_iio_txn_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4160617 }, /* unc_iio_txn_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4160822 }, /* unc_iio_txn_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161027 }, /* unc_iio_txn_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161232 }, /* unc_iio_txn_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161436 }, /* unc_iio_txn_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161640 }, /* unc_iio_txn_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4161844 }, /* unc_iio_txn_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162048 }, /* unc_iio_txn_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162252 }, /* unc_iio_txn_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162456 }, /* unc_iio_txn_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162659 }, /* unc_iio_txn_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162862 }, /* unc_iio_txn_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163068 }, /* unc_iio_txn_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163274 }, /* unc_iio_txn_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163480 }, /* unc_iio_txn_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163686 }, /* unc_iio_txn_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163891 }, /* unc_iio_txn_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4164096 }, /* unc_iio_txn_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164302 }, /* unc_iio_txn_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164508 }, /* unc_iio_txn_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164714 }, /* unc_iio_txn_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164920 }, /* unc_iio_txn_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4165125 }, /* unc_iio_txn_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4165330 }, /* unc_iio_txn_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165538 }, /* unc_iio_txn_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165746 }, /* unc_iio_txn_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165954 }, /* unc_iio_txn_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4166162 }, /* unc_iio_txn_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4166369 }, /* unc_iio_txn_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4167902 }, /* unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4168736 }, /* unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4169537 }, /* unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4170338 }, /* unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4172495 }, /* unc_iio_txn_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4172814 }, /* unc_iio_txn_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4174450 }, /* unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4175280 }, /* unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4176077 }, /* unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4176874 }, /* unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4179018 }, /* unc_iio_txn_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4179336 }, /* unc_iio_txn_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4180953 }, /* unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4181773 }, /* unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4182560 }, /* unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4183347 }, /* unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4185463 }, /* unc_iio_txn_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4185777 }, /* unc_iio_txn_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4187381 }, /* unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4188197 }, /* unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4188980 }, /* unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4189763 }, /* unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4191866 }, /* unc_iio_txn_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4192179 }, /* unc_iio_txn_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4194293 }, /* unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4195867 }, /* unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4197400 }, /* unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4198878 }, /* unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4203090 }, /* unc_iio_txn_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4203406 }, /* unc_iio_txn_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4205513 }, /* unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4207084 }, /* unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4208614 }, /* unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4210089 }, /* unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4214278 }, /* unc_iio_txn_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4214593 }, /* unc_iio_txn_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4216357 }, /* unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4217604 }, /* unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4218775 }, /* unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4219926 }, /* unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4222580 }, /* unc_iio_txn_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4222919 }, /* unc_iio_txn_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4224796 }, /* unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4226514 }, /* unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4228191 }, /* unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4229813 }, /* unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4234458 }, /* unc_iio_txn_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4234796 }, /* unc_iio_txn_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4236442 }, /* unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4237261 }, /* unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4238047 }, /* unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4238833 }, /* unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4240957 }, /* unc_iio_txn_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4241267 }, /* unc_iio_txn_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4241577 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4241992 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4242339 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4242721 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4253397 }, /* unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4254900 }, /* unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is  made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4256362 }, /* unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4257768 }, /* unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4261808 }, /* unc_iio_txn_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4262111 }, /* unc_iio_txn_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4264153 }, /* unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4265652 }, /* unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4267110 }, /* unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4268513 }, /* unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4272530 }, /* unc_iio_txn_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4272832 }, /* unc_iio_txn_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4274301 }, /* unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4275048 }, /* unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4275762 }, /* unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4276476 }, /* unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4278387 }, /* unc_iio_txn_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4278672 }, /* unc_iio_txn_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4280427 }, /* unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4281594 }, /* unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4282685 }, /* unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4283756 }, /* unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4286350 }, /* unc_iio_txn_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4286688 }, /* unc_iio_txn_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4289036 }, /* unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4290685 }, /* unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part1 to the MMIO space of an IIO target.In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4292292 }, /* unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4293845 }, /* unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4298445 }, /* unc_iio_txn_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4298782 }, /* unc_iio_txn_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4299119 }, /* unc_iio_vtd_access.ctxt_miss\000uncore_iio\000uncore io\000VTd Access; context cache miss. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000\000 */
{ 4299245 }, /* unc_iio_vtd_access.l1_miss\000uncore_iio\000uncore io\000VTd Access; L1 miss. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000\000 */
{ 4299358 }, /* unc_iio_vtd_access.l2_miss\000uncore_iio\000uncore io\000VTd Access; L2 miss. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000\000 */
{ 4299471 }, /* unc_iio_vtd_access.l3_miss\000uncore_iio\000uncore io\000VTd Access; L3 miss. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000\000 */
{ 4299585 }, /* unc_iio_vtd_access.l4_page_hit\000uncore_iio\000uncore io\000VTd Access; Vtd hit. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000\000 */
{ 4299702 }, /* unc_iio_vtd_access.tlb1_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000\000 */
{ 4299819 }, /* unc_iio_vtd_access.tlb_full\000uncore_iio\000uncore io\000VTd Access; TLB is full. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000\000 */
{ 4299938 }, /* unc_iio_vtd_access.tlb_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000\000 */
{ 4300054 }, /* unc_iio_vtd_occupancy\000uncore_iio\000uncore io\000VTd Occupancy. Unit: uncore_iio \000event=0x40\000\00001\000\000 */
{ 1209942 }, /* llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 1211341 }, /* llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5375947 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377697 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Page Activate commands sent due to a write request. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts DRAM Page Activate commands sent on this channel due to a write request to the iMC (Memory Controller).  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS (Column Access Select) command\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5379231 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, so this event increments for every read and write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5381140 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 5382780 }, /* unc_m_cas_count.rd_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Read ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x40\000\00001\000\000 */
{ 5384152 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts CAS (Column Access Select) regular read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every regular read.  This event only counts regular reads and does not includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 5386414 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5387373 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM Underfill Read CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000Counts CAS (Column Access Select) underfill read commands issued to DRAM due to a partial write, on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this command counts underfill reads.  Partial writes must be completed by first reading in the underfill from DRAM and then merging in the partial write data before writing the full line back to DRAM. This event will generally count about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ (due to a previous write request)\000 */
{ 5388524 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5388834 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM Write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5390243 }, /* unc_m_cas_count.wr_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Write ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x80\000\00001\000\000 */
{ 5391405 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392215 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5394980 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Memory controller clock ticks. Unit: uncore_imc \000event=0\000\00001\000Counts clockticks of the fixed frequency clock of the memory controller using one of the programmable counters\000 */
{ 5395395 }, /* unc_m_clockticks_f\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using a dedicated 48-bit Fixed Counter. Unit: uncore_imc \000event=0xff\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399445 }, /* unc_m_majmode2.dram_cyc\000uncore_imc\000uncore memory\000UNC_M_MAJMODE2.DRAM_CYC. Unit: uncore_imc \000event=0xed,umask=0x2\000\00001\000\000 */
{ 5399563 }, /* unc_m_majmode2.dram_enter\000uncore_imc\000uncore memory\000UNC_M_MAJMODE2.DRAM_ENTER. Unit: uncore_imc \000event=0xed,umask=0x8\000\00001\000\000 */
{ 5399685 }, /* unc_m_majmode2.pmm_cyc\000uncore_imc\000uncore memory\000Major Mode 2 : Cycles in PMM major mode. Unit: uncore_imc \000event=0xed,umask=0x1\000\00001\000\000 */
{ 5399818 }, /* unc_m_majmode2.pmm_enter\000uncore_imc\000uncore memory\000Major Mode 2 : Entered PMM major mode. Unit: uncore_imc \000event=0xed,umask=0x4\000\00001\000\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5403917 }, /* unc_m_pmm_bandwidth.read\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth read (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000event=0xe3\000\000016.103515625E-5MB/sec\000\000 */
{ 5404116 }, /* unc_m_pmm_bandwidth.total\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth total (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000event=0xe3\000\000016.103515625E-5MB/sec\000\000 */
{ 5404317 }, /* unc_m_pmm_bandwidth.write\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory bandwidth write (MB/sec). Derived from unc_m_pmm_wpq_inserts. Unit: uncore_imc \000event=0xe7\000\000016.103515625E-5MB/sec\000\000 */
{ 5404518 }, /* unc_m_pmm_cmd1.all\000uncore_imc\000uncore memory\000All commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x1\000\00001\000\000 */
{ 5404827 }, /* unc_m_pmm_cmd1.misc\000uncore_imc\000uncore memory\000Misc Commands (error, flow ACKs). Unit: uncore_imc \000event=0xea,umask=0x80\000\00001\000\000 */
{ 5405090 }, /* unc_m_pmm_cmd1.misc_gnt\000uncore_imc\000uncore memory\000Misc GNTs. Unit: uncore_imc \000event=0xea,umask=0x40\000\00001\000\000 */
{ 5405501 }, /* unc_m_pmm_cmd1.rd\000uncore_imc\000uncore memory\000Regular reads(RPQ) commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x2\000\00001\000All Reads - RPQ or Ufill\000 */
{ 5405805 }, /* unc_m_pmm_cmd1.rpq_gnts\000uncore_imc\000uncore memory\000RPQ GNTs. Unit: uncore_imc \000event=0xea,umask=0x10\000\00001\000\000 */
{ 5406136 }, /* unc_m_pmm_cmd1.ufill_rd\000uncore_imc\000uncore memory\000Underfill read commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x8\000\00001\000Underfill reads\000 */
{ 5406439 }, /* unc_m_pmm_cmd1.wpq_gnts\000uncore_imc\000uncore memory\000Underfill GNTs. Unit: uncore_imc \000event=0xea,umask=0x20\000\00001\000\000 */
{ 5406718 }, /* unc_m_pmm_cmd1.wr\000uncore_imc\000uncore memory\000Write commands for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xea,umask=0x4\000\00001\000Writes\000 */
{ 5406872 }, /* unc_m_pmm_cmd2.nodata_exp\000uncore_imc\000uncore memory\000Expected No data packet (ERID matched NDP encoding). Unit: uncore_imc \000event=0xeb,umask=0x2\000\00001\000\000 */
{ 5407382 }, /* unc_m_pmm_cmd2.nodata_unexp\000uncore_imc\000uncore memory\000Unexpected No data packet (ERID matched a Read, but data was a NDP). Unit: uncore_imc \000event=0xeb,umask=0x4\000\00001\000\000 */
{ 5407548 }, /* unc_m_pmm_cmd2.opp_rd\000uncore_imc\000uncore memory\000Opportunistic Reads. Unit: uncore_imc \000event=0xeb,umask=0x1\000\00001\000\000 */
{ 5407931 }, /* unc_m_pmm_cmd2.pmm_ecc_error\000uncore_imc\000uncore memory\000PMM ECC Errors. Unit: uncore_imc \000event=0xeb,umask=0x20\000\00001\000\000 */
{ 5408200 }, /* unc_m_pmm_cmd2.pmm_erid_error\000uncore_imc\000uncore memory\000PMM ERID detectable parity error. Unit: uncore_imc \000event=0xeb,umask=0x40\000\00001\000\000 */
{ 5408602 }, /* unc_m_pmm_cmd2.reqs_slot0\000uncore_imc\000uncore memory\000Read Requests - Slot 0. Unit: uncore_imc \000event=0xeb,umask=0x8\000\00001\000\000 */
{ 5408865 }, /* unc_m_pmm_cmd2.reqs_slot1\000uncore_imc\000uncore memory\000Read Requests - Slot 1. Unit: uncore_imc \000event=0xeb,umask=0x10\000\00001\000\000 */
{ 5408985 }, /* unc_m_pmm_majmode1.partial_wr_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Partial Write Major Mode. Unit: uncore_imc \000event=0xec,umask=0x4\000\00001\000\000 */
{ 5409147 }, /* unc_m_pmm_majmode1.partial_wr_enter\000uncore_imc\000uncore memory\000PMM Major Mode. Unit: uncore_imc \000event=0xec,umask=0x20\000\00001\000\000 */
{ 5409269 }, /* unc_m_pmm_majmode1.partial_wr_exit\000uncore_imc\000uncore memory\000PMM Major Mode. Unit: uncore_imc \000event=0xec,umask=0x40\000\00001\000\000 */
{ 5409390 }, /* unc_m_pmm_majmode1.rd_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Read Major Mode. Unit: uncore_imc \000event=0xec,umask=0x1\000\00001\000\000 */
{ 5409535 }, /* unc_m_pmm_majmode1.wr_cyc\000uncore_imc\000uncore memory\000PMM Major Mode; Cycles PMM is in Write Major Mode. Unit: uncore_imc \000event=0xec,umask=0x2\000\00001\000\000 */
{ 5409681 }, /* unc_m_pmm_read_latency\000uncore_imc\000uncore memory\000Intel Optane DC persistent memory read latency (ns). Derived from unc_m_pmm_rpq_occupancy.all. Unit: uncore_imc \000event=0xe0,umask=0x1\000\000016000000000ns\000\000 */
{ 5409880 }, /* unc_m_pmm_rpq_cycles_full\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Full. Unit: uncore_imc \000event=0xe2\000\00001\000\000 */
{ 5409993 }, /* unc_m_pmm_rpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe1\000\00001\000\000 */
{ 5410543 }, /* unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000Write requests allocated in the PMM Write Pending Queue for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe3\000\00001\000\000 */
{ 5410950 }, /* unc_m_pmm_rpq_occupancy.all\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy of all read requests for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000\000 */
{ 5411538 }, /* unc_m_pmm_rpq_occupancy.gnt_wait\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000\000 */
{ 5413017 }, /* unc_m_pmm_wpq_cycles_full\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Full. Unit: uncore_imc \000event=0xe6\000\00001\000\000 */
{ 5413258 }, /* unc_m_pmm_wpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe5\000\00001\000\000 */
{ 5413975 }, /* unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000Write requests allocated in the PMM Write Pending Queue for Intel Optane DC persistent memory. Unit: uncore_imc \000event=0xe7\000\00001\000\000 */
{ 5414631 }, /* unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy of all write requests for Intel(R) Optane(TM) DC persistent memory. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000\000 */
{ 5415570 }, /* unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000\000 */
{ 5416183 }, /* unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x4\000\00001\000\000 */
{ 5416529 }, /* unc_m_pmm_wpq_pcommit\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_PCOMMIT. Unit: uncore_imc \000event=0xe8\000\00001\000\000 */
{ 5416633 }, /* unc_m_pmm_wpq_pcommit_cyc\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_PCOMMIT_CYC. Unit: uncore_imc \000event=0xe9\000\00001\000\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417651 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode+C37. Unit: uncore_imc \000event=0x85\000\00001\000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430087 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5431979 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5440157 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000Pre-charges due to page misses. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of explicit DRAM Precharge commands sent on this channel as a result of a DRAM page miss. This does not include the implicit precharge commands sent with CAS commands in Auto-Precharge mode. This does not include Precharge commands sent as a result of a page close counter expiration\000 */
{ 5442408 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Pre-charge for reads. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of explicit DRAM Precharge commands issued on a per channel basis due to a read, so as to close the previous DRAM page, before opening the requested page\000 */
{ 5444802 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Pre-charge for writes. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449520 }, /* unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000\000 */
{ 5449930 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000\000 */
{ 5451952 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000\000 */
{ 5450209 }, /* unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000\000 */
{ 5450500 }, /* unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000\000 */
{ 5450791 }, /* unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000\000 */
{ 5451082 }, /* unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000\000 */
{ 5451373 }, /* unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000\000 */
{ 5451664 }, /* unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000\000 */
{ 5452365 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000\000 */
{ 5452778 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000\000 */
{ 5453319 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000\000 */
{ 5453733 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000\000 */
{ 5454147 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000\000 */
{ 5454433 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000\000 */
{ 5454847 }, /* unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000\000 */
{ 5455133 }, /* unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000\000 */
{ 5455457 }, /* unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000\000 */
{ 5455801 }, /* unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000\000 */
{ 5456147 }, /* unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000\000 */
{ 5456496 }, /* unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000\000 */
{ 5456814 }, /* unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000\000 */
{ 5457224 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000\000 */
{ 5459246 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000\000 */
{ 5457503 }, /* unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000\000 */
{ 5457794 }, /* unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000\000 */
{ 5458085 }, /* unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000\000 */
{ 5458376 }, /* unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000\000 */
{ 5458667 }, /* unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000\000 */
{ 5458958 }, /* unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000\000 */
{ 5459659 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000\000 */
{ 5460072 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000\000 */
{ 5460613 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000\000 */
{ 5461027 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000\000 */
{ 5461441 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000\000 */
{ 5461727 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000\000 */
{ 5462141 }, /* unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000\000 */
{ 5462427 }, /* unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000\000 */
{ 5462751 }, /* unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000\000 */
{ 5463095 }, /* unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000\000 */
{ 5463441 }, /* unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000\000 */
{ 5463790 }, /* unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000\000 */
{ 5463939 }, /* unc_m_rd_cas_rank2.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xb2,umask=0x10\000\00001\000\000 */
{ 5464349 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000\000 */
{ 5465240 }, /* unc_m_rd_cas_rank2.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xb2,umask=0x1\000\00001\000\000 */
{ 5464466 }, /* unc_m_rd_cas_rank2.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xb2,umask=0xa\000\00001\000\000 */
{ 5464595 }, /* unc_m_rd_cas_rank2.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xb2,umask=0xb\000\00001\000\000 */
{ 5464724 }, /* unc_m_rd_cas_rank2.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xb2,umask=0xc\000\00001\000\000 */
{ 5464853 }, /* unc_m_rd_cas_rank2.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xb2,umask=0xd\000\00001\000\000 */
{ 5464982 }, /* unc_m_rd_cas_rank2.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xb2,umask=0xe\000\00001\000\000 */
{ 5465111 }, /* unc_m_rd_cas_rank2.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xb2,umask=0xf\000\00001\000\000 */
{ 5465494 }, /* unc_m_rd_cas_rank2.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xb2,umask=0x2\000\00001\000\000 */
{ 5465748 }, /* unc_m_rd_cas_rank2.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xb2,umask=0x3\000\00001\000\000 */
{ 5466130 }, /* unc_m_rd_cas_rank2.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xb2,umask=0x4\000\00001\000\000 */
{ 5466385 }, /* unc_m_rd_cas_rank2.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xb2,umask=0x5\000\00001\000\000 */
{ 5466640 }, /* unc_m_rd_cas_rank2.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xb2,umask=0x6\000\00001\000\000 */
{ 5466767 }, /* unc_m_rd_cas_rank2.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xb2,umask=0x7\000\00001\000\000 */
{ 5467022 }, /* unc_m_rd_cas_rank2.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xb2,umask=0x8\000\00001\000\000 */
{ 5467149 }, /* unc_m_rd_cas_rank2.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xb2,umask=0x9\000\00001\000\000 */
{ 5467276 }, /* unc_m_rd_cas_rank2.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb2,umask=0x11\000\00001\000\000 */
{ 5467423 }, /* unc_m_rd_cas_rank2.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb2,umask=0x12\000\00001\000\000 */
{ 5467570 }, /* unc_m_rd_cas_rank2.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb2,umask=0x13\000\00001\000\000 */
{ 5467718 }, /* unc_m_rd_cas_rank2.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb2,umask=0x14\000\00001\000\000 */
{ 5467867 }, /* unc_m_rd_cas_rank3.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xb3,umask=0x10\000\00001\000\000 */
{ 5468128 }, /* unc_m_rd_cas_rank3.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xb3\000\00001\000\000 */
{ 5469019 }, /* unc_m_rd_cas_rank3.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xb3,umask=0x1\000\00001\000\000 */
{ 5468245 }, /* unc_m_rd_cas_rank3.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xb3,umask=0xa\000\00001\000\000 */
{ 5468374 }, /* unc_m_rd_cas_rank3.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xb3,umask=0xb\000\00001\000\000 */
{ 5468503 }, /* unc_m_rd_cas_rank3.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xb3,umask=0xc\000\00001\000\000 */
{ 5468632 }, /* unc_m_rd_cas_rank3.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xb3,umask=0xd\000\00001\000\000 */
{ 5468761 }, /* unc_m_rd_cas_rank3.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xb3,umask=0xe\000\00001\000\000 */
{ 5468890 }, /* unc_m_rd_cas_rank3.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xb3,umask=0xf\000\00001\000\000 */
{ 5469273 }, /* unc_m_rd_cas_rank3.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xb3,umask=0x2\000\00001\000\000 */
{ 5469527 }, /* unc_m_rd_cas_rank3.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xb3,umask=0x3\000\00001\000\000 */
{ 5469909 }, /* unc_m_rd_cas_rank3.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xb3,umask=0x4\000\00001\000\000 */
{ 5470164 }, /* unc_m_rd_cas_rank3.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xb3,umask=0x5\000\00001\000\000 */
{ 5470419 }, /* unc_m_rd_cas_rank3.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xb3,umask=0x6\000\00001\000\000 */
{ 5470546 }, /* unc_m_rd_cas_rank3.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xb3,umask=0x7\000\00001\000\000 */
{ 5470801 }, /* unc_m_rd_cas_rank3.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xb3,umask=0x8\000\00001\000\000 */
{ 5470928 }, /* unc_m_rd_cas_rank3.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xb3,umask=0x9\000\00001\000\000 */
{ 5471055 }, /* unc_m_rd_cas_rank3.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb3,umask=0x11\000\00001\000\000 */
{ 5471202 }, /* unc_m_rd_cas_rank3.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb3,umask=0x12\000\00001\000\000 */
{ 5471349 }, /* unc_m_rd_cas_rank3.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb3,umask=0x13\000\00001\000\000 */
{ 5471497 }, /* unc_m_rd_cas_rank3.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb3,umask=0x14\000\00001\000\000 */
{ 5471815 }, /* unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000\000 */
{ 5472225 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000\000 */
{ 5474247 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000\000 */
{ 5472504 }, /* unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000\000 */
{ 5472795 }, /* unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000\000 */
{ 5473086 }, /* unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000\000 */
{ 5473377 }, /* unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000\000 */
{ 5473668 }, /* unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000\000 */
{ 5473959 }, /* unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000\000 */
{ 5474660 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000\000 */
{ 5475073 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000\000 */
{ 5475614 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000\000 */
{ 5476028 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000\000 */
{ 5476442 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000\000 */
{ 5476728 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000\000 */
{ 5477142 }, /* unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000\000 */
{ 5477428 }, /* unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000\000 */
{ 5477752 }, /* unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000\000 */
{ 5478096 }, /* unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000\000 */
{ 5478442 }, /* unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000\000 */
{ 5478791 }, /* unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000\000 */
{ 5479109 }, /* unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000\000 */
{ 5479519 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000\000 */
{ 5481541 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000\000 */
{ 5479798 }, /* unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000\000 */
{ 5480089 }, /* unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000\000 */
{ 5480380 }, /* unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000\000 */
{ 5480671 }, /* unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000\000 */
{ 5480962 }, /* unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000\000 */
{ 5481253 }, /* unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000\000 */
{ 5481954 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000\000 */
{ 5482367 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000\000 */
{ 5482908 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000\000 */
{ 5483322 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000\000 */
{ 5483736 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000\000 */
{ 5484022 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000\000 */
{ 5484436 }, /* unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000\000 */
{ 5484722 }, /* unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000\000 */
{ 5485046 }, /* unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000\000 */
{ 5485390 }, /* unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000\000 */
{ 5485736 }, /* unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000\000 */
{ 5486085 }, /* unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000\000 */
{ 5486403 }, /* unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000\000 */
{ 5486813 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000\000 */
{ 5488835 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000\000 */
{ 5487092 }, /* unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000\000 */
{ 5487383 }, /* unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000\000 */
{ 5487674 }, /* unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000\000 */
{ 5487965 }, /* unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000\000 */
{ 5488256 }, /* unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000\000 */
{ 5488547 }, /* unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000\000 */
{ 5489248 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000\000 */
{ 5489661 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000\000 */
{ 5490202 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000\000 */
{ 5490616 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000\000 */
{ 5491030 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000\000 */
{ 5491316 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000\000 */
{ 5491730 }, /* unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000\000 */
{ 5492016 }, /* unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000\000 */
{ 5492340 }, /* unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000\000 */
{ 5492684 }, /* unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000\000 */
{ 5493030 }, /* unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000\000 */
{ 5493379 }, /* unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000\000 */
{ 5493697 }, /* unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000\000 */
{ 5494107 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000\000 */
{ 5496129 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000\000 */
{ 5494386 }, /* unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000\000 */
{ 5494677 }, /* unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000\000 */
{ 5494968 }, /* unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000\000 */
{ 5495259 }, /* unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000\000 */
{ 5495550 }, /* unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000\000 */
{ 5495841 }, /* unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000\000 */
{ 5496542 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000\000 */
{ 5496955 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000\000 */
{ 5497496 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000\000 */
{ 5497910 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000\000 */
{ 5498324 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000\000 */
{ 5498610 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000\000 */
{ 5499024 }, /* unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000\000 */
{ 5499310 }, /* unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000\000 */
{ 5499634 }, /* unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000\000 */
{ 5499978 }, /* unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000\000 */
{ 5500324 }, /* unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000\000 */
{ 5500673 }, /* unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000\000 */
{ 5502958 }, /* unc_m_rpq_cycles_full\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5509114 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of read requests allocated into the Read Pending Queue (RPQ).  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  The requests deallocate after the read CAS command has been issued to DRAM.  This event counts both Isochronous and non-Isochronous requests which were issued to the RPQ\000 */
{ 5510414 }, /* unc_m_rpq_occupancy\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Counts the number of entries in the Read Pending Queue (RPQ) at each cycle.  This can then be used to calculate both the average occupancy of the queue (in conjunction with the number of cycles not empty) and the average latency in the queue (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC. They deallocate from the RPQ after the CAS command has been issued to memory\000 */
{ 5512980 }, /* unc_m_sb_accesses.fm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; Write Accepts. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00001\000\000 */
{ 5513251 }, /* unc_m_sb_accesses.fm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; Write Rejects. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00001\000\000 */
{ 5513776 }, /* unc_m_sb_accesses.nm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; FM read completions. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00001\000\000 */
{ 5514060 }, /* unc_m_sb_accesses.nm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses; FM write completions. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00001\000\000 */
{ 5514584 }, /* unc_m_sb_accesses.rd_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses; Read Accepts. Unit: uncore_imc \000event=0xd2,umask=0x1\000\00001\000\000 */
{ 5514851 }, /* unc_m_sb_accesses.rd_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses; Read Rejects. Unit: uncore_imc \000event=0xd2,umask=0x2\000\00001\000\000 */
{ 5515387 }, /* unc_m_sb_accesses.wr_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses; NM read completions. Unit: uncore_imc \000event=0xd2,umask=0x4\000\00001\000\000 */
{ 5515669 }, /* unc_m_sb_accesses.wr_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses; NM write completions. Unit: uncore_imc \000event=0xd2,umask=0x8\000\00001\000\000 */
{ 5515910 }, /* unc_m_sb_canary.alloc\000uncore_imc\000uncore memory\000Alloc. Unit: uncore_imc \000event=0xd9,umask=0x1\000\00001\000\000 */
{ 5516112 }, /* unc_m_sb_canary.dealloc\000uncore_imc\000uncore memory\000Dealloc. Unit: uncore_imc \000event=0xd9,umask=0x2\000\00001\000\000 */
{ 5516593 }, /* unc_m_sb_canary.fmrd_starved\000uncore_imc\000uncore memory\000Far Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00001\000\000 */
{ 5517071 }, /* unc_m_sb_canary.fmwr_starved\000uncore_imc\000uncore memory\000Far Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00001\000\000 */
{ 5517601 }, /* unc_m_sb_canary.nmrd_starved\000uncore_imc\000uncore memory\000Near Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00001\000\000 */
{ 5517897 }, /* unc_m_sb_canary.nmwr_starved\000uncore_imc\000uncore memory\000Near Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00001\000\000 */
{ 5518195 }, /* unc_m_sb_canary.rej\000uncore_imc\000uncore memory\000Reject. Unit: uncore_imc \000event=0xd9,umask=0x4\000\00001\000\000 */
{ 5518391 }, /* unc_m_sb_canary.vld\000uncore_imc\000uncore memory\000Valid. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00001\000\000 */
{ 5518487 }, /* unc_m_sb_cycles_full\000uncore_imc\000uncore memory\000Scoreboard Cycles Full. Unit: uncore_imc \000event=0xd1\000\00001\000\000 */
{ 5518591 }, /* unc_m_sb_cycles_ne\000uncore_imc\000uncore memory\000Scoreboard Cycles Not-Empty. Unit: uncore_imc \000event=0xd0\000\00001\000\000 */
{ 5518836 }, /* unc_m_sb_inserts.block_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Block region reads. Unit: uncore_imc \000event=0xd6,umask=0x10\000\00001\000\000 */
{ 5519112 }, /* unc_m_sb_inserts.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Block region writes. Unit: uncore_imc \000event=0xd6,umask=0x20\000\00001\000\000 */
{ 5519250 }, /* unc_m_sb_inserts.dealloc\000uncore_imc\000uncore memory\000Scoreboard Inserts; Dealloc all commands (for error flows). Unit: uncore_imc \000event=0xd6,umask=0x40\000\00001\000\000 */
{ 5519405 }, /* unc_m_sb_inserts.patrol\000uncore_imc\000uncore memory\000Scoreboard Inserts; Patrol inserts. Unit: uncore_imc \000event=0xd6,umask=0x80\000\00001\000\000 */
{ 5519672 }, /* unc_m_sb_inserts.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Persistent Mem reads. Unit: uncore_imc \000event=0xd6,umask=0x4\000\00001\000\000 */
{ 5519946 }, /* unc_m_sb_inserts.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Persistent Mem writes. Unit: uncore_imc \000event=0xd6,umask=0x8\000\00001\000\000 */
{ 5520201 }, /* unc_m_sb_inserts.rds\000uncore_imc\000uncore memory\000Scoreboard Inserts; Reads. Unit: uncore_imc \000event=0xd6,umask=0x1\000\00001\000\000 */
{ 5520437 }, /* unc_m_sb_inserts.wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts; Writes. Unit: uncore_imc \000event=0xd6,umask=0x2\000\00001\000\000 */
{ 5520697 }, /* unc_m_sb_occupancy.block_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Block region reads. Unit: uncore_imc \000event=0xd5,umask=0x20\000\00001\000\000 */
{ 5520981 }, /* unc_m_sb_occupancy.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Block region writes. Unit: uncore_imc \000event=0xd5,umask=0x40\000\00001\000\000 */
{ 5521123 }, /* unc_m_sb_occupancy.patrol\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Patrol. Unit: uncore_imc \000event=0xd5,umask=0x80\000\00001\000\000 */
{ 5521390 }, /* unc_m_sb_occupancy.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Persistent Mem reads. Unit: uncore_imc \000event=0xd5,umask=0x4\000\00001\000\000 */
{ 5521672 }, /* unc_m_sb_occupancy.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Persistent Mem writes. Unit: uncore_imc \000event=0xd5,umask=0x8\000\00001\000\000 */
{ 5521935 }, /* unc_m_sb_occupancy.rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Reads. Unit: uncore_imc \000event=0xd5,umask=0x1\000\00001\000\000 */
{ 5522056 }, /* unc_m_sb_occupancy.wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy; Writes. Unit: uncore_imc \000event=0xd5,umask=0x2\000\00001\000\000 */
{ 5523942 }, /* unc_m_sb_reject.fm_addr_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; FM requests rejected due to full address conflict. Unit: uncore_imc \000event=0xd4,umask=0x2\000\00001\000\000 */
{ 5524313 }, /* unc_m_sb_reject.nm_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; NM requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x1\000\00001\000\000 */
{ 5524682 }, /* unc_m_sb_reject.patrol_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected; Patrol requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x4\000\00001\000\000 */
{ 5525393 }, /* unc_m_sb_strv_alloc.fmrd_clr\000uncore_imc\000uncore memory\000Far Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x20\000\00001\000\000 */
{ 5525514 }, /* unc_m_sb_strv_alloc.fmrd_set\000uncore_imc\000uncore memory\000Far Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00001\000\000 */
{ 5525967 }, /* unc_m_sb_strv_alloc.fmwr_clr\000uncore_imc\000uncore memory\000Far Mem Write - Clear. Unit: uncore_imc \000event=0xd7,umask=0x80\000\00001\000\000 */
{ 5526089 }, /* unc_m_sb_strv_alloc.fmwr_set\000uncore_imc\000uncore memory\000Far Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00001\000\000 */
{ 5526611 }, /* unc_m_sb_strv_alloc.nmrd_clr\000uncore_imc\000uncore memory\000Near Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00001\000\000 */
{ 5526733 }, /* unc_m_sb_strv_alloc.nmrd_set\000uncore_imc\000uncore memory\000Near Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00001\000\000 */
{ 5527018 }, /* unc_m_sb_strv_alloc.nmwr_clr\000uncore_imc\000uncore memory\000Near Mem Write - Clear. Unit: uncore_imc \000event=0xd7,umask=0x40\000\00001\000\000 */
{ 5527141 }, /* unc_m_sb_strv_alloc.nmwr_set\000uncore_imc\000uncore memory\000Near Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00001\000\000 */
{ 5529057 }, /* unc_m_sb_strv_occ.fmrd\000uncore_imc\000uncore memory\000Far Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00001\000\000 */
{ 5529490 }, /* unc_m_sb_strv_occ.fmwr\000uncore_imc\000uncore memory\000Far Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00001\000\000 */
{ 5529980 }, /* unc_m_sb_strv_occ.nmrd\000uncore_imc\000uncore memory\000Near Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00001\000\000 */
{ 5530249 }, /* unc_m_sb_strv_occ.nmwr\000uncore_imc\000uncore memory\000Near Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00001\000\000 */
{ 5530519 }, /* unc_m_sb_tagged.ddr4_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.DDR4_CMP. Unit: uncore_imc \000event=0xdd,umask=0x8\000\00001\000\000 */
{ 5530639 }, /* unc_m_sb_tagged.new\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.NEW. Unit: uncore_imc \000event=0xdd,umask=0x1\000\00001\000\000 */
{ 5530749 }, /* unc_m_sb_tagged.occ\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.OCC. Unit: uncore_imc \000event=0xdd,umask=0x80\000\00001\000\000 */
{ 5530860 }, /* unc_m_sb_tagged.pmm0_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM0_CMP. Unit: uncore_imc \000event=0xdd,umask=0x10\000\00001\000\000 */
{ 5530981 }, /* unc_m_sb_tagged.pmm1_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM1_CMP. Unit: uncore_imc \000event=0xdd,umask=0x20\000\00001\000\000 */
{ 5531102 }, /* unc_m_sb_tagged.pmm2_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM2_CMP. Unit: uncore_imc \000event=0xdd,umask=0x40\000\00001\000\000 */
{ 5531223 }, /* unc_m_sb_tagged.rd_hit\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_HIT. Unit: uncore_imc \000event=0xdd,umask=0x2\000\00001\000\000 */
{ 5531339 }, /* unc_m_sb_tagged.rd_miss\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_MISS. Unit: uncore_imc \000event=0xdd,umask=0x4\000\00001\000\000 */
{ 5531718 }, /* unc_m_tagchk.hit\000uncore_imc\000uncore memory\000All hits to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000Tag Check; Hit\000 */
{ 5532142 }, /* unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\000All Clean line misses to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000Tag Check; Clean\000 */
{ 5532625 }, /* unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\000All dirty line misses to Near Memory(DRAM cache) in Memory Mode. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000Tag Check; Dirty\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5535448 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5538845 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5544584 }, /* unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of writes requests allocated into the Write Pending Queue (WPQ).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (Memory Controller).  The write requests deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC\000 */
{ 5546690 }, /* unc_m_wpq_occupancy\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Counts the number of entries in the Write Pending Queue (WPQ) at each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (memory controller).  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the 'not posted' filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The 'posted' filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556664 }, /* unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000\000 */
{ 5557074 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000\000 */
{ 5559096 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000\000 */
{ 5557353 }, /* unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000\000 */
{ 5557644 }, /* unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000\000 */
{ 5557935 }, /* unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000\000 */
{ 5558226 }, /* unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000\000 */
{ 5558517 }, /* unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000\000 */
{ 5558808 }, /* unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000\000 */
{ 5559509 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000\000 */
{ 5559922 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000\000 */
{ 5560463 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000\000 */
{ 5560877 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000\000 */
{ 5561291 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000\000 */
{ 5561577 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000\000 */
{ 5561991 }, /* unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000\000 */
{ 5562277 }, /* unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000\000 */
{ 5562601 }, /* unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000\000 */
{ 5562945 }, /* unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000\000 */
{ 5563291 }, /* unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000\000 */
{ 5563640 }, /* unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000\000 */
{ 5563958 }, /* unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000\000 */
{ 5564368 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000\000 */
{ 5566390 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000\000 */
{ 5564647 }, /* unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000\000 */
{ 5564938 }, /* unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000\000 */
{ 5565229 }, /* unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000\000 */
{ 5565520 }, /* unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000\000 */
{ 5565811 }, /* unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000\000 */
{ 5566102 }, /* unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000\000 */
{ 5566803 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000\000 */
{ 5567216 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000\000 */
{ 5567757 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000\000 */
{ 5568171 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000\000 */
{ 5568585 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000\000 */
{ 5568871 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000\000 */
{ 5569285 }, /* unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000\000 */
{ 5569571 }, /* unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000\000 */
{ 5569895 }, /* unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000\000 */
{ 5570239 }, /* unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000\000 */
{ 5570585 }, /* unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000\000 */
{ 5570934 }, /* unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000\000 */
{ 5571083 }, /* unc_m_wr_cas_rank2.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xba,umask=0x10\000\00001\000\000 */
{ 5571344 }, /* unc_m_wr_cas_rank2.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xba\000\00001\000\000 */
{ 5572235 }, /* unc_m_wr_cas_rank2.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xba,umask=0x1\000\00001\000\000 */
{ 5571461 }, /* unc_m_wr_cas_rank2.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xba,umask=0xa\000\00001\000\000 */
{ 5571590 }, /* unc_m_wr_cas_rank2.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xba,umask=0xb\000\00001\000\000 */
{ 5571719 }, /* unc_m_wr_cas_rank2.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xba,umask=0xc\000\00001\000\000 */
{ 5571848 }, /* unc_m_wr_cas_rank2.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xba,umask=0xd\000\00001\000\000 */
{ 5571977 }, /* unc_m_wr_cas_rank2.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xba,umask=0xe\000\00001\000\000 */
{ 5572106 }, /* unc_m_wr_cas_rank2.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xba,umask=0xf\000\00001\000\000 */
{ 5572489 }, /* unc_m_wr_cas_rank2.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xba,umask=0x2\000\00001\000\000 */
{ 5572743 }, /* unc_m_wr_cas_rank2.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xba,umask=0x3\000\00001\000\000 */
{ 5573125 }, /* unc_m_wr_cas_rank2.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xba,umask=0x4\000\00001\000\000 */
{ 5573380 }, /* unc_m_wr_cas_rank2.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xba,umask=0x5\000\00001\000\000 */
{ 5573635 }, /* unc_m_wr_cas_rank2.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xba,umask=0x6\000\00001\000\000 */
{ 5573762 }, /* unc_m_wr_cas_rank2.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xba,umask=0x7\000\00001\000\000 */
{ 5574017 }, /* unc_m_wr_cas_rank2.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xba,umask=0x8\000\00001\000\000 */
{ 5574144 }, /* unc_m_wr_cas_rank2.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xba,umask=0x9\000\00001\000\000 */
{ 5574271 }, /* unc_m_wr_cas_rank2.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xba,umask=0x11\000\00001\000\000 */
{ 5574418 }, /* unc_m_wr_cas_rank2.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xba,umask=0x12\000\00001\000\000 */
{ 5574565 }, /* unc_m_wr_cas_rank2.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xba,umask=0x13\000\00001\000\000 */
{ 5574713 }, /* unc_m_wr_cas_rank2.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xba,umask=0x14\000\00001\000\000 */
{ 5574862 }, /* unc_m_wr_cas_rank3.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xbb,umask=0x10\000\00001\000\000 */
{ 5575123 }, /* unc_m_wr_cas_rank3.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xbb\000\00001\000\000 */
{ 5576014 }, /* unc_m_wr_cas_rank3.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xbb,umask=0x1\000\00001\000\000 */
{ 5575240 }, /* unc_m_wr_cas_rank3.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xbb,umask=0xa\000\00001\000\000 */
{ 5575369 }, /* unc_m_wr_cas_rank3.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xbb,umask=0xb\000\00001\000\000 */
{ 5575498 }, /* unc_m_wr_cas_rank3.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xbb,umask=0xc\000\00001\000\000 */
{ 5575627 }, /* unc_m_wr_cas_rank3.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xbb,umask=0xd\000\00001\000\000 */
{ 5575756 }, /* unc_m_wr_cas_rank3.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xbb,umask=0xe\000\00001\000\000 */
{ 5575885 }, /* unc_m_wr_cas_rank3.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xbb,umask=0xf\000\00001\000\000 */
{ 5576268 }, /* unc_m_wr_cas_rank3.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xbb,umask=0x2\000\00001\000\000 */
{ 5576522 }, /* unc_m_wr_cas_rank3.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xbb,umask=0x3\000\00001\000\000 */
{ 5576904 }, /* unc_m_wr_cas_rank3.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xbb,umask=0x4\000\00001\000\000 */
{ 5577159 }, /* unc_m_wr_cas_rank3.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xbb,umask=0x5\000\00001\000\000 */
{ 5577414 }, /* unc_m_wr_cas_rank3.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xbb,umask=0x6\000\00001\000\000 */
{ 5577541 }, /* unc_m_wr_cas_rank3.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xbb,umask=0x7\000\00001\000\000 */
{ 5577796 }, /* unc_m_wr_cas_rank3.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xbb,umask=0x8\000\00001\000\000 */
{ 5577923 }, /* unc_m_wr_cas_rank3.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xbb,umask=0x9\000\00001\000\000 */
{ 5578050 }, /* unc_m_wr_cas_rank3.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbb,umask=0x11\000\00001\000\000 */
{ 5578197 }, /* unc_m_wr_cas_rank3.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbb,umask=0x12\000\00001\000\000 */
{ 5578344 }, /* unc_m_wr_cas_rank3.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbb,umask=0x13\000\00001\000\000 */
{ 5578492 }, /* unc_m_wr_cas_rank3.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbb,umask=0x14\000\00001\000\000 */
{ 5578810 }, /* unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000\000 */
{ 5579220 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000\000 */
{ 5581242 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000\000 */
{ 5579499 }, /* unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000\000 */
{ 5579790 }, /* unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000\000 */
{ 5580081 }, /* unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000\000 */
{ 5580372 }, /* unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000\000 */
{ 5580663 }, /* unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000\000 */
{ 5580954 }, /* unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000\000 */
{ 5581655 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000\000 */
{ 5582068 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000\000 */
{ 5582609 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000\000 */
{ 5583023 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000\000 */
{ 5583437 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000\000 */
{ 5583723 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000\000 */
{ 5584137 }, /* unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000\000 */
{ 5584423 }, /* unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000\000 */
{ 5584747 }, /* unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000\000 */
{ 5585091 }, /* unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000\000 */
{ 5585437 }, /* unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000\000 */
{ 5585786 }, /* unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000\000 */
{ 5586104 }, /* unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000\000 */
{ 5586514 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000\000 */
{ 5588536 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000\000 */
{ 5586793 }, /* unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000\000 */
{ 5587084 }, /* unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000\000 */
{ 5587375 }, /* unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000\000 */
{ 5587666 }, /* unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000\000 */
{ 5587957 }, /* unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000\000 */
{ 5588248 }, /* unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000\000 */
{ 5588949 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000\000 */
{ 5589362 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000\000 */
{ 5589903 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000\000 */
{ 5590317 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000\000 */
{ 5590731 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000\000 */
{ 5591017 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000\000 */
{ 5591431 }, /* unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000\000 */
{ 5591717 }, /* unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000\000 */
{ 5592041 }, /* unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000\000 */
{ 5592385 }, /* unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000\000 */
{ 5592731 }, /* unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000\000 */
{ 5593080 }, /* unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000\000 */
{ 5593398 }, /* unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000\000 */
{ 5593808 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000\000 */
{ 5595830 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000\000 */
{ 5594087 }, /* unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000\000 */
{ 5594378 }, /* unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000\000 */
{ 5594669 }, /* unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000\000 */
{ 5594960 }, /* unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000\000 */
{ 5595251 }, /* unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000\000 */
{ 5595542 }, /* unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000\000 */
{ 5596243 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000\000 */
{ 5596656 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000\000 */
{ 5597197 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000\000 */
{ 5597611 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000\000 */
{ 5598025 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000\000 */
{ 5598311 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000\000 */
{ 5598725 }, /* unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000\000 */
{ 5599011 }, /* unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000\000 */
{ 5599335 }, /* unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000\000 */
{ 5599679 }, /* unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000\000 */
{ 5600025 }, /* unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000\000 */
{ 5600374 }, /* unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000\000 */
{ 5600692 }, /* unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000\000 */
{ 5601102 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000\000 */
{ 5603124 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000\000 */
{ 5601381 }, /* unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000\000 */
{ 5601672 }, /* unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000\000 */
{ 5601963 }, /* unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000\000 */
{ 5602254 }, /* unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000\000 */
{ 5602545 }, /* unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000\000 */
{ 5602836 }, /* unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000\000 */
{ 5603537 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000\000 */
{ 5603950 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000\000 */
{ 5604491 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000\000 */
{ 5604905 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000\000 */
{ 5605319 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000\000 */
{ 5605605 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000\000 */
{ 5606019 }, /* unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000\000 */
{ 5606305 }, /* unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000\000 */
{ 5606629 }, /* unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000\000 */
{ 5606973 }, /* unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000\000 */
{ 5607319 }, /* unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000\000 */
{ 5607668 }, /* unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5641706 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5650924 }, /* unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000 */
{ 5656346 }, /* unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000 */
{ 5663824 }, /* unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Cycles spent in phase-shedding power state 0\000 */
{ 5664142 }, /* unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Cycles spent in phase-shedding power state 1\000 */
{ 5664460 }, /* unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Cycles spent in phase-shedding power state 2\000 */
{ 5664778 }, /* unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Cycles spent in phase-shedding power state 3\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670355 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673025 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673833 }, /* unc_p_mcp_prochot_cycles\000uncore_pcu\000uncore power\000UNC_P_MCP_PROCHOT_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5675706 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676727 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677425 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678114 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679241 }, /* unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x7\000\00001\000\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685850 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5688334 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000\000 */
{ 788320 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Counts demand data loads that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 791308 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=2000003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793371 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 798170 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data load to a 1G page\000event=0x8,period=2000003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 801032 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data load to a 2M/4M page\000event=0x8,period=2000003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 804341 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data load to a 4K page\000event=0x8,period=2000003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 807135 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 810679 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Counts demand data stores that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 813355 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 814891 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 819786 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 822786 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 825573 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 829022 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 833842 }, /* ept.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a EPT (Extended Page Table) walk for any request type\000event=0x4f,period=2000003,umask=0x10\000\00000\000Counts cycles for each PMH (Page Miss Handler) that is busy with an EPT (Extended Page Table) walk for any request type\000 */
{ 1078252 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080900 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Counts page walks of any page size (4K/2M/4M/1G) caused by a code fetch. This implies it missed in the ITLB and further levels of TLB, but the walk need not have completed\000 */
{ 1082889 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1084967 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1088976 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000Counts completed page walks (1G page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1096669 }, /* itlb_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake\000event=0x85,period=100003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH (Page Miss Handler) that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake michroarchitecture\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__cascadelakex[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 12424 }, /* \000dtlb_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14264 }, /* \000dtlb_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14680 }, /* \000dtlb_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 16888 }, /* \000io_bandwidth_read\000\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000 */
{ 18187 }, /* \000io_bandwidth_write\000\000(UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART0 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART1 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART2 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19992 }, /* \000itlb_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 20492 }, /* \000itlb_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23125 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25514 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25947 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28309 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12CC0233@ / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 29347 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40433@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40433@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 30592 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40432@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 31888 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40431@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 32995 }, /* \000llc_data_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12D40433@ / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 35184 }, /* \000llc_miss_local_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35388 }, /* \000llc_miss_local_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35595 }, /* \000llc_miss_remote_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 36012 }, /* \000loads_per_instr\000\000MEM_INST_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 41255 }, /* \000numa_reads_addressed_to_local_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 42475 }, /* \000numa_reads_addressed_to_remote_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43154 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43654 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44654 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 45098 }, /* \000pmem_memory_bandwidth_read\000\000UNC_M_PMM_RPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45264 }, /* \000pmem_memory_bandwidth_total\000\000(UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS) * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45452 }, /* \000pmem_memory_bandwidth_write\000\000UNC_M_PMM_WPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49006 }, /* \000stores_per_instr\000\000MEM_INST_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51159 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 52640 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * (FP_ASSIST.ANY + OTHER_ASSISTS.ANY) / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62896 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - tma_frontend_bound - (UOPS_ISSUED.ANY + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00000 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 70171 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 82339 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD))) + 44 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 108844 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00044 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OCR.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OCR.DEMAND_DATA_RD.L3_HIT.HIT_OTHER_CORE_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 113664 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 121545 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound - tma_pmm_bound if #has_pmem > 0 else CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound)\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 137218 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(9 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00002 */
{ 142945 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(9 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 143879 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(110 * tma_info_system_average_frequency * (OCR.DEMAND_RFO.L3_MISS.REMOTE_HITM + OCR.PF_L2_RFO.L3_MISS.REMOTE_HITM) + 47.5 * tma_info_system_average_frequency * (OCR.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE + OCR.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE)) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 154534 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00002 */
{ 160611 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 164336 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 178522 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00001 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 185358 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 187717 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1\000\00000 */
{ 190426 }, /* \000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * UOPS_RETIRED.MACRO_FUSED / UOPS_RETIRED.RETIRE_SLOTS\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000 */
{ 191743 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000(UOPS_RETIRED.RETIRE_SLOTS + UOPS_RETIRED.MACRO_FUSED - INST_RETIRED.ANY) / tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 193552 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(ICACHE_16B.IFDATA_STALL + 2 * cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@) / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 196454 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199999 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000tma_info_core_ipmispredict\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 201191 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 203428 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.CONDITIONAL + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 205415 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00001 */
{ 210181 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 213573 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216209 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.NOT_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216379 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000(BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 216744 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00001 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 218334 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 221959 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 224428 }, /* \000tma_info_core_ipmispredict\000Bad;BadSpec;BrMispredicts;TopdownL1;tma_L1_group\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000TopdownL1\000\00000 */
{ 224783 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 226971 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / DSB2MITE_SWITCHES.COUNT\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227629 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@ + 2\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232781 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00001 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238534 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00001 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243336 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245107 }, /* \000tma_info_memory_core_l2_evictions_nonsilent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.NON_SILENT / tma_info_inst_mix_instructions\000\000Rate of non silent evictions from the L2 cache per Kilo instruction\000\000\000\000\000\00000 */
{ 245315 }, /* \000tma_info_memory_core_l2_evictions_silent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.SILENT / tma_info_inst_mix_instructions\000\000Rate of silent evictions from the L2 cache per Kilo instruction where the evicted lines are dropped (no writeback to L3 or memory)\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 253898 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING + EPT.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00002 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258309 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 260111 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00001 */
{ 263422 }, /* \000tma_info_system_io_read_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Reads [GB / sec]\000\000\000\000\000\00000 */
{ 263736 }, /* \000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 265831 }, /* \000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_M_RPQ_OCCUPANCY / UNC_M_RPQ_INSERTS) / imc_0@event\\=0x0@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 267104 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 268900 }, /* \000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_M_PMM_RPQ_OCCUPANCY.ALL / UNC_M_PMM_RPQ_INSERTS) / imc_0@event\\=0x0@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 270073 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271515 }, /* \000tma_info_system_pmm_read_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_RPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for reads [GB / sec]\000\000\000\000\000\00000 */
{ 271706 }, /* \000tma_info_system_pmm_write_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_WPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 271899 }, /* \000tma_info_system_power_license0_utilization\000Power\000(CORE_POWER.LVL0_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks)\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 272769 }, /* \000tma_info_system_power_license1_utilization\000Power\000(CORE_POWER.LVL1_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 273737 }, /* \000tma_info_system_power_license2_utilization\000Power\000(CORE_POWER.LVL2_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275354 }, /* \000tma_info_system_socket_clks\000SoC\000cha_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 292417 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 298837 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00017 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 315911 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 319201 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00002 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 322701 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00059.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000 */
{ 324079 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(12 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (11 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00000 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 343499 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 348484 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00000 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 356236 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 365594 }, /* \000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - UOPS_RETIRED.MACRO_FUSED) / UOPS_RETIRED.RETIRE_SLOTS\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000 */
{ 367158 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / UOPS_RETIRED.RETIRE_SLOTS\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369645 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00000 */
{ 373560 }, /* \000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00001 */
{ 379171 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382050 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 386530 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 389567 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 391440 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((EXE_ACTIVITY.EXE_BOUND_0_PORTS + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 400041 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_NONE / 2 if #SMT_on else CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_core_core_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 403843 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_1 - UOPS_EXECUTED.CORE_CYCLES_GE_2) / 2 if #SMT_on else EXE_ACTIVITY.1_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 409809 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_2 - UOPS_EXECUTED.CORE_CYCLES_GE_3) / 2 if #SMT_on else EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 417118 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_GE_3 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_3) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 425139 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00002 */
{ 428000 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000127 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 435994 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000PARTIAL_RAT_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: PARTIAL_RAT_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 438776 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00040 * ROB_MISC_EVENTS.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000 */
{ 441609 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00002 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444174 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 452365 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 11 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00002 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 459384 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\0009 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
{ 465493 }, /* \000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
{ 465803 }, /* \000upi_data_transmit_bw\000\000UNC_UPI_TxL_FLITS.ALL_DATA * 7.111111111111111 / 1e6 / duration_time\000\000Intel(R) Ultra Path Interconnect (UPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 6171185 }, /* uncore_iio\000LLC_MISSES.PCIE_READ\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3\000\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000 */
{ 6172569 }, /* uncore_iio\000LLC_MISSES.PCIE_WRITE\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3\000\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000 */
{ 6174071 }, /* uncore_imc\000UNC_M_PMM_BANDWIDTH.TOTAL\000\000UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS\000\000Intel Optane DC persistent memory bandwidth total (MB/sec). Derived from unc_m_pmm_rpq_inserts. Unit: uncore_imc \000\0006.103515625E-5MB/sec\000\000\000\00000 */
{ 6174297 }, /* uncore_imc\000UNC_M_PMM_READ_LATENCY\000\000UNC_M_PMM_RPQ_OCCUPANCY.ALL / UNC_M_PMM_RPQ_INSERTS / UNC_M_CLOCKTICKS\000\000Intel Optane DC persistent memory read latency (ns). Derived from unc_m_pmm_rpq_occupancy.all. Unit: uncore_imc \000\0006000000000ns\000\000\000\00000 */
{ 6174536 }, /* uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode+C37. Unit: uncore_imc \000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000\000\000\000\00000 */
{ 6176517 }, /* uncore_imc\000power_self_refresh\000\000UNC_M_POWER_SELF_REFRESH / UNC_M_CLOCKTICKS * 100\000\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__elkhartlake[] = {
{ 576549 }, /* core_reject_l2q.any\000\000cache\000Counts the number of core requests (demand and L1 prefetchers) rejected by the L2 queue (L2Q) due to a full condition\000event=0x31,period=200003\000\00000\000Counts the number of (demand and L1 prefetchers) core requests rejected by the L2 queue (L2Q) due to a full or nearly full condition, which likely indicates back pressure from L2Q.  It also counts requests that would have gone directly to the External Queue (XQ), but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link.  The L2Q may also reject transactions  from a core to ensure fairness between cores, or to delay a cores dirty eviction when the address conflicts incoming external snoops.  (Note that L2 prefetcher requests that are dropped are not counted by this event).  Counts on a per core basis\000 */
{ 778889 }, /* dl1.dirty_eviction\000\000cache\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches\000event=0x51,period=200003,umask=0x1\000\00000\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches.  Does not count evictions or dirty writebacks caused by snoops.  Does not count a replacement unless a (dirty) line was written back\000 */
{ 1149126 }, /* l2_reject_xq.any\000\000cache\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition which likely indicates back pressure from the IDI link.  The XQ may reject transactions from the L2Q (non-cacheable requests), BBL (L2 misses) and WOB (L2 write-back victims)\000 */
{ 1149916 }, /* l2_request.all\000\000cache\000Counts the total number of L2 Cache accesses. Counts on a per core basis\000event=0x24,period=200003\000\00000\000Counts the total number of L2 Cache Accesses, includes hits, misses, rejects  front door requests for CRd/DRd/RFO/ItoM/L2 Prefetches only.  Counts on a per core basis\000 */
{ 1150538 }, /* l2_request.hit\000\000cache\000Counts the number of L2 Cache accesses that resulted in a hit. Counts on a per core basis\000event=0x24,period=200003,umask=0x2\000\00000\000Counts the number of L2 Cache accesses that resulted in a hit from a front door request only (does not include rejects or recycles), Counts on a per core basis\000 */
{ 1151083 }, /* l2_request.miss\000\000cache\000Counts the number of L2 Cache accesses that resulted in a miss. Counts on a per core basis\000event=0x24,period=200003,umask=0x1\000\00000\000Counts the number of L2 Cache accesses that resulted in a miss from a front door request only (does not include rejects or recycles). Counts on a per core basis\000 */
{ 1152400 }, /* l2_request.rejects\000\000cache\000Counts the number of L2 Cache accesses that miss the L2 and get rejected. Counts on a per core basis\000event=0x24,period=200003,umask=0x4\000\00000\000Counts the number of L2 Cache accesses that miss the L2 and get BBL reject  short and long rejects (includes those counted in L2_reject_XQ.any). Counts on a per core basis\000 */
{ 1248632 }, /* longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1252437 }, /* longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1303294 }, /* mem_bound_stalls.ifetch\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000 */
{ 1304075 }, /* mem_bound_stalls.ifetch_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000 */
{ 1304822 }, /* mem_bound_stalls.ifetch_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache\000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000 */
{ 1305519 }, /* mem_bound_stalls.ifetch_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1306350 }, /* mem_bound_stalls.load\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x7\000\00000\000\000 */
{ 1306761 }, /* mem_bound_stalls.load_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x4\000\00000\000\000 */
{ 1307164 }, /* mem_bound_stalls.load_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache\000event=0x34,period=200003,umask=0x1\000\00000\000\000 */
{ 1307531 }, /* mem_bound_stalls.load_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1308218 }, /* mem_bound_stalls.store_buffer_full\000\000cache\000Counts the number of cycles the core is stalled due to a store buffer being full\000event=0x34,period=200003,umask=0x40\000\00000\000\000 */
{ 1352752 }, /* mem_load_uops_retired.dram_hit\000\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x80\000\00000\000\000 */
{ 1355113 }, /* mem_load_uops_retired.hitm\000\000cache\000Counts the number of load uops retired that hit in the L3 cache, in which a snoop was required and modified data was forwarded from another core or module  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x20\000\00000\000\000 */
{ 1356362 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Counts the number of load uops retired that hit in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x1\000\00000\000\000 */
{ 1358158 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Counts the number of load uops retired that miss in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000\000 */
{ 1359677 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000\000 */
{ 1361415 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Counts the number of load uops retired that miss in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x10\000\00000\000\000 */
{ 1362932 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x4\000\00000\000\000 */
{ 1387995 }, /* mem_uops_retired.all\000\000cache\000Counts the number of memory uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired.  A single uop that performs both a load AND a store will be counted as 1, not 2 (e.g. ADD [mem], CONST)  Supports address when precise (Precise event)\000 */
{ 1389608 }, /* mem_uops_retired.all_loads\000\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000 */
{ 1392234 }, /* mem_uops_retired.all_stores\000\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000 */
{ 1414761 }, /* mem_uops_retired.lock_loads\000\000cache\000Counts the number of load uops retired that performed one or more locks  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x21\000\00000\000\000 */
{ 1416633 }, /* mem_uops_retired.split\000\000cache\000Counts the number of memory uops retired that were splits  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x43\000\00000\000\000 */
{ 1417334 }, /* mem_uops_retired.split_loads\000\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x41\000\00000\000\000 */
{ 1419426 }, /* mem_uops_retired.split_stores\000\000cache\000Counts the number of retired split store uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x42\000\00000\000\000 */
{ 1442166 }, /* ocr.all_code_rd.l3_hit\000\000cache\000Counts all code reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0044\000\00000\000\000 */
{ 1441031 }, /* ocr.all_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0044\000\00000\000\000 */
{ 1441264 }, /* ocr.all_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0044\000\00000\000\000 */
{ 1441509 }, /* ocr.all_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0044\000\00000\000\000 */
{ 1441743 }, /* ocr.all_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0044\000\00000\000\000 */
{ 1441949 }, /* ocr.all_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all code reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0044\000\00000\000\000 */
{ 1514370 }, /* ocr.corewb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache and L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3001F803C0000\000\00000\000\000 */
{ 1522191 }, /* ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0004\000\00000\000\000 */
{ 1518194 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 1518623 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000 */
{ 1519772 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1520495 }, /* ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 1521192 }, /* ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 1540920 }, /* ocr.demand_data_and_l1pf_rd.l3_hit\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00000\000\000 */
{ 1539270 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1539606 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1539954 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hitm\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1540291 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_miss\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 1540600 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_not_needed\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 1552258 }, /* ocr.demand_data_rd.l3_hit\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00010\000\000 */
{ 1546321 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00010\000\000 */
{ 1547857 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00010\000\000 */
{ 1549584 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00010\000\000 */
{ 1550703 }, /* ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00010\000\000 */
{ 1551293 }, /* ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00010\000\000 */
{ 1580657 }, /* ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0002\000\00000\000\000 */
{ 1575817 }, /* ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 1576593 }, /* ocr.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000 */
{ 1576915 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1579038 }, /* ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 1579793 }, /* ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 1602111 }, /* ocr.full_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify a full 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801F803C0000\000\00000\000\000 */
{ 1604026 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_hitm\000\000cache\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000 */
{ 1608691 }, /* ocr.hwpf_l2_code_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0040\000\00000\000\000 */
{ 1607266 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0040\000\00000\000\000 */
{ 1607557 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0040\000\00000\000\000 */
{ 1607860 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0040\000\00000\000\000 */
{ 1608152 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0040\000\00000\000\000 */
{ 1608416 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0040\000\00000\000\000 */
{ 1613603 }, /* ocr.hwpf_l2_data_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0010\000\00000\000\000 */
{ 1610862 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 1611428 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000 */
{ 1611731 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 1612321 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 1612842 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 1618449 }, /* ocr.hwpf_l2_rfo.l3_hit\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0020\000\00000\000\000 */
{ 1615813 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 1616358 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000 */
{ 1616651 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 1617220 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 1617720 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 1622882 }, /* ocr.l1wb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache that miss the L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001F803C0000\000\00000\000\000 */
{ 1623670 }, /* ocr.l2wb_m.l3_hit\000\000cache\000Counts modified writeBacks from L2 cache that miss the L3 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001F803C0000\000\00000\000\000 */
{ 1639727 }, /* ocr.partial_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify only part of a 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401F803C0000\000\00000\000\000 */
{ 1724431 }, /* ocr.reads_to_core.l3_hit\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0477\000\00000\000\000 */
{ 1720874 }, /* ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0477\000\00000\000\000 */
{ 1721903 }, /* ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0477\000\00000\000\000 */
{ 1722894 }, /* ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0477\000\00000\000\000 */
{ 1723220 }, /* ocr.reads_to_core.l3_hit.snoop_miss\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0477\000\00000\000\000 */
{ 1723518 }, /* ocr.reads_to_core.l3_hit.snoop_not_needed\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0477\000\00000\000\000 */
{ 1739801 }, /* ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0800\000\00000\000\000 */
{ 1742854 }, /* ocr.uc_rd.l3_hit\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x101F803C0000\000\00000\000\000 */
{ 1741700 }, /* ocr.uc_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004003C0000\000\00000\000\000 */
{ 1741937 }, /* ocr.uc_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008003C0000\000\00000\000\000 */
{ 1742186 }, /* ocr.uc_rd.l3_hit.snoop_hitm\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010003C0000\000\00000\000\000 */
{ 1742423 }, /* ocr.uc_rd.l3_hit.snoop_miss\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002003C0000\000\00000\000\000 */
{ 1742633 }, /* ocr.uc_rd.l3_hit.snoop_not_needed\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001003C0000\000\00000\000\000 */
{ 1743893 }, /* ocr.uc_wr.l3_hit\000\000cache\000Counts uncached memory writes that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x201F803C0000\000\00000\000\000 */
{ 2567930 }, /* topdown_fe_bound.icache\000\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses\000event=0x71,period=1000003,umask=0x20\000\00000\000\000 */
{ 761126 }, /* cycles_div_busy.fpdiv\000\000floating point\000Counts the number of cycles the floating point divider is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts the number of cycles the floating point divider is busy.  Does not imply a stall waiting for the divider\000 */
{ 1291322 }, /* machine_clears.fp_assist\000\000floating point\000Counts the number of floating point operations retired that required microcode assist\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000 */
{ 6228633 }, /* uops_retired.fpdiv\000\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event)\000event=0xc2,period=2000003,umask=0x8\000\00000\000\000 */
{ 475810 }, /* baclears.any\000\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 478968 }, /* baclears.cond\000\000frontend\000Counts the number of BACLEARS due to a conditional jump\000event=0xe6,period=200003,umask=0x10\000\00000\000\000 */
{ 479701 }, /* baclears.indirect\000\000frontend\000Counts the number of BACLEARS due to an indirect branch\000event=0xe6,period=200003,umask=0x2\000\00000\000\000 */
{ 479965 }, /* baclears.return\000\000frontend\000Counts the number of BACLEARS due to a return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000\000 */
{ 480671 }, /* baclears.uncond\000\000frontend\000Counts the number of BACLEARS due to a direct, unconditional jump\000event=0xe6,period=200003,umask=0x4\000\00000\000\000 */
{ 777925 }, /* decode_restriction.predecode_wrong\000\000frontend\000Counts the number of times a decode restriction reduces the decode throughput due to wrong instruction length prediction\000event=0xe9,period=200003,umask=0x1\000\00000\000\000 */
{ 983063 }, /* icache.accesses\000\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line\000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 985453 }, /* icache.hit\000\000frontend\000Counts the number of instruction cache hits\000event=0x80,period=200003,umask=0x1\000\00000\000Counts the number of requests that hit in the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 989052 }, /* icache.misses\000\000frontend\000Counts the number of instruction cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 1295858 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation\000event=0xc3,period=20003,umask=0x2\000\00000\000\000 */
{ 1427819 }, /* misalign_mem_ref.load_page_split\000\000memory\000Counts the number of misaligned load uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x2\000\00000\000\000 */
{ 1429789 }, /* misalign_mem_ref.store_page_split\000\000memory\000Counts the number of misaligned store uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x4\000\00000\000\000 */
{ 1442318 }, /* ocr.all_code_rd.l3_miss\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000 */
{ 1442476 }, /* ocr.all_code_rd.l3_miss_local\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000 */
{ 1514554 }, /* ocr.corewb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000 */
{ 1514744 }, /* ocr.corewb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000 */
{ 1529409 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000 */
{ 1530090 }, /* ocr.demand_code_rd.l3_miss_local\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000 */
{ 1541175 }, /* ocr.demand_data_and_l1pf_rd.l3_miss\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000 */
{ 1541436 }, /* ocr.demand_data_and_l1pf_rd.l3_miss_local\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000 */
{ 1560151 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000 */
{ 1561112 }, /* ocr.demand_data_rd.l3_miss_local\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS_LOCAL\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000 */
{ 1588756 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000 */
{ 1590774 }, /* ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000 */
{ 1602311 }, /* ocr.full_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000 */
{ 1602517 }, /* ocr.full_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000 */
{ 1608901 }, /* ocr.hwpf_l2_code_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000 */
{ 1609117 }, /* ocr.hwpf_l2_code_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000 */
{ 1613813 }, /* ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000 */
{ 1614230 }, /* ocr.hwpf_l2_data_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000 */
{ 1618649 }, /* ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000 */
{ 1619045 }, /* ocr.hwpf_l2_rfo.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000 */
{ 1623074 }, /* ocr.l1wb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000 */
{ 1623272 }, /* ocr.l1wb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000 */
{ 1623862 }, /* ocr.l2wb_m.l3_miss\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000 */
{ 1624060 }, /* ocr.l2wb_m.l3_miss_local\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000 */
{ 1633637 }, /* ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000 */
{ 1634244 }, /* ocr.other.l3_miss_local\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000 */
{ 1639938 }, /* ocr.partial_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000 */
{ 1640155 }, /* ocr.partial_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000 */
{ 1718314 }, /* ocr.prefetches.l3_miss\000\000memory\000Counts all hardware and software prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000470\000\00000\000\000 */
{ 1725253 }, /* ocr.reads_to_core.l3_miss\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000 */
{ 1726166 }, /* ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000 */
{ 1740462 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000 */
{ 1740623 }, /* ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000 */
{ 1743009 }, /* ocr.uc_rd.l3_miss\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000 */
{ 1743170 }, /* ocr.uc_rd.l3_miss_local\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000 */
{ 1744049 }, /* ocr.uc_wr.l3_miss\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000 */
{ 1744211 }, /* ocr.uc_wr.l3_miss_local\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000 */
{ 566747 }, /* bus_lock.all\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.SELF_LOCKS\000event=0x63,edge=1,period=200003\000\00010\000\000 */
{ 566869 }, /* bus_lock.block_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores\000event=0x63,period=200003,umask=0x2\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores. Counts on a per core basis\000 */
{ 567167 }, /* bus_lock.cycles_other_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.BLOCK_CYCLES\000event=0x63,period=200003,umask=0x2\000\00010\000\000 */
{ 567309 }, /* bus_lock.cycles_self_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.LOCK_CYCLES\000event=0x63,period=200003,umask=0x1\000\00010\000\000 */
{ 567449 }, /* bus_lock.lock_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued\000event=0x63,period=200003,umask=0x1\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued. Counts on a per core basis\000 */
{ 567722 }, /* bus_lock.self_locks\000\000other\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks\000event=0x63,edge=1,period=200003\000\00000\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks. Counts on a per core basis\000 */
{ 570986 }, /* c0_stalls.load_dram_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_DRAM_HIT\000event=0x34,period=200003,umask=0x4\000\00010\000\000 */
{ 571133 }, /* c0_stalls.load_l2_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_L2_HIT\000event=0x34,period=200003,umask=0x1\000\00010\000\000 */
{ 571276 }, /* c0_stalls.load_llc_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_LLC_HIT\000event=0x34,period=200003,umask=0x2\000\00010\000\000 */
{ 976774 }, /* hw_interrupts.masked\000\000other\000Counts the number of core cycles during which interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000 */
{ 977395 }, /* hw_interrupts.pending_and_masked\000\000other\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled). Increments by 1 each core cycle that both EFLAGS.IF is 0 and an INTR is pending (which means the APIC is telling the ROB to cause an INTR). This event does not increment if EFLAGS.IF is 0 but all interrupt in the APICs Interrupt Request Register (IRR) are inhibited by the PPR (thus either by ISRV or TPR)  because in these cases the interrupts would be held up in the APIC and would not be pended to the ROB. This event does count when an interrupt is only inhibited by MOV/POP SS state machines or the STI state machine. These extra inhibits only last for a single instructions and would not be important\000 */
{ 978530 }, /* hw_interrupts.received\000\000other\000Counts the number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000\000 */
{ 1440741 }, /* ocr.all_code_rd.any_response\000\000other\000Counts all code reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10044\000\00000\000\000 */
{ 1440890 }, /* ocr.all_code_rd.dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000 */
{ 1442640 }, /* ocr.all_code_rd.local_dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000 */
{ 1442787 }, /* ocr.all_code_rd.outstanding\000\000other\000Counts all code reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000044\000\00000\000\000 */
{ 1513981 }, /* ocr.corewb_m.any_response\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3000000010000\000\00000\000\000 */
{ 1514940 }, /* ocr.corewb_m.outstanding\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003000000000000\000\00000\000\000 */
{ 1515566 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1516154 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1534712 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1538774 }, /* ocr.demand_data_and_l1pf_rd.any_response\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1539026 }, /* ocr.demand_data_and_l1pf_rd.dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1541703 }, /* ocr.demand_data_and_l1pf_rd.local_dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1541953 }, /* ocr.demand_data_and_l1pf_rd.outstanding\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00000\000\000 */
{ 1542759 }, /* ocr.demand_data_rd.any_response\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00010\000\000 */
{ 1543749 }, /* ocr.demand_data_rd.dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000 */
{ 1565431 }, /* ocr.demand_data_rd.local_dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.LOCAL_DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000 */
{ 1565919 }, /* ocr.demand_data_rd.outstanding\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.OUTSTANDING\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00010\000\000 */
{ 1572074 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1573525 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1595079 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1596695 }, /* ocr.demand_rfo.outstanding\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000002\000\00000\000\000 */
{ 1601909 }, /* ocr.full_streaming_wr.any_response\000\000other\000Counts streaming stores which modify a full 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800000010000\000\00000\000\000 */
{ 1602918 }, /* ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1606860 }, /* ocr.hwpf_l2_code_rd.any_response\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000 */
{ 1607067 }, /* ocr.hwpf_l2_code_rd.dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000 */
{ 1609339 }, /* ocr.hwpf_l2_code_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000 */
{ 1609544 }, /* ocr.hwpf_l2_code_rd.outstanding\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000040\000\00000\000\000 */
{ 1609848 }, /* ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 1610248 }, /* ocr.hwpf_l2_data_rd.dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614452 }, /* ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614852 }, /* ocr.hwpf_l2_rfo.any_response\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 1615231 }, /* ocr.hwpf_l2_rfo.dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619257 }, /* ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619636 }, /* ocr.hwpf_l2_rfo.outstanding\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000020\000\00000\000\000 */
{ 1622688 }, /* ocr.l1wb_m.any_response\000\000other\000Counts modified writebacks from L1 cache that miss the L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000000010000\000\00000\000\000 */
{ 1623476 }, /* ocr.l2wb_m.any_response\000\000other\000Counts modified writeBacks from L2 cache that miss the L3 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000000010000\000\00000\000\000 */
{ 1624595 }, /* ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O accesses, that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1639514 }, /* ocr.partial_streaming_wr.any_response\000\000other\000Counts streaming stores which modify only part of a 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400000010000\000\00000\000\000 */
{ 1717909 }, /* ocr.prefetches.any_response\000\000other\000Counts all hardware and software prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10470\000\00000\000\000 */
{ 1719272 }, /* ocr.reads_to_core.any_response\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10477\000\00000\000\000 */
{ 1720003 }, /* ocr.reads_to_core.dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000 */
{ 1728233 }, /* ocr.reads_to_core.local_dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000 */
{ 1730543 }, /* ocr.reads_to_core.outstanding\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000477\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1741398 }, /* ocr.uc_rd.any_response\000\000other\000Counts uncached memory reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100000010000\000\00000\000\000 */
{ 1741555 }, /* ocr.uc_rd.dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000 */
{ 1743337 }, /* ocr.uc_rd.local_dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000 */
{ 1743488 }, /* ocr.uc_rd.outstanding\000\000other\000Counts uncached memory reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000100000000000\000\00000\000\000 */
{ 1743735 }, /* ocr.uc_wr.any_response\000\000other\000Counts uncached memory writes that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200000010000\000\00000\000\000 */
{ 497910 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 502234 }, /* br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 507645 }, /* br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 510375 }, /* br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000 */
{ 513344 }, /* br_inst_retired.jcc\000\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000 */
{ 521242 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000 */
{ 523776 }, /* br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000\000 */
{ 525103 }, /* br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000 */
{ 526112 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000 */
{ 538105 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 548123 }, /* br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 552527 }, /* br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 558108 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 562117 }, /* br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 563268 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000 */
{ 565564 }, /* btclear.any\000\000pipeline\000Counts the total number of BTCLEARS\000event=0xe8,period=200003\000\00000\000Counts the total number of BTCLEARS which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 612440 }, /* cpu_clk_unhalted.core\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000 */
{ 615598 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 619311 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x0,umask=0x03,period=2000003\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 622318 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 634226 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 761040 }, /* cycles_div_busy.any\000\000pipeline\000This event is deprecated\000event=0xcd,period=2000003\000\00010\000\000 */
{ 761547 }, /* cycles_div_busy.idiv\000\000pipeline\000Counts the number of cycles the integer divider is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts the number of cycles the integer divider is busy.  Does not imply a stall waiting for the divider\000 */
{ 1044203 }, /* inst_retired.any\000\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000 */
{ 1052183 }, /* inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000 */
{ 1189894 }, /* ld_blocks.4k_alias\000\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1191843 }, /* ld_blocks.all\000\000pipeline\000Counts the number of retired loads that are blocked for any of the following reasons:  DTLB miss, address alias, store forward or data unknown (includes memory disambiguation blocks and ESP consuming load blocks) (Precise event)\000event=0x3,period=1000003,umask=0x10\000\00000\000\000 */
{ 1192607 }, /* ld_blocks.data_unknown\000\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event)\000event=0x3,period=1000003,umask=0x1\000\00000\000\000 */
{ 1198416 }, /* ld_blocks.store_forward\000\000pipeline\000Counts the number of retired loads that are blocked because its address partially overlapped with an older store (Precise event)\000event=0x3,period=1000003,umask=0x2\000\00000\000\000 */
{ 1288621 }, /* machine_clears.any\000\000pipeline\000Counts the total number of machine clears for any reason including, but not limited to, memory ordering, memory disambiguation, SMC, and FP assist\000event=0xc3,period=20003\000\00000\000\000 */
{ 1289828 }, /* machine_clears.disambiguation\000\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU\000event=0xc3,period=20003,umask=0x8\000\00000\000\000 */
{ 1298456 }, /* machine_clears.page_fault\000\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs\000event=0xc3,period=20003,umask=0x20\000\00000\000\000 */
{ 1299922 }, /* machine_clears.smc\000\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page\000event=0xc3,period=20003,umask=0x1\000\00000\000\000 */
{ 2551516 }, /* topdown_bad_speculation.all\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003,umask=0x6\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2555005 }, /* topdown_bad_speculation.fastnuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears\000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2555794 }, /* topdown_bad_speculation.machine_clears\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2556692 }, /* topdown_bad_speculation.mispredict\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts\000event=0x73,period=1000003,umask=0x4\000\00000\000\000 */
{ 2557107 }, /* topdown_bad_speculation.monuke\000\000pipeline\000This event is deprecated. Refer to new event TOPDOWN_BAD_SPECULATION.FASTNUKE\000event=0x73,period=1000003,umask=0x2\000\00010\000\000 */
{ 2557813 }, /* topdown_be_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls\000event=0x74,period=1000003\000\00000\000\000 */
{ 2558344 }, /* topdown_be_bound.alloc_restrictions\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions\000event=0x74,period=1000003,umask=0x1\000\00000\000\000 */
{ 2559028 }, /* topdown_be_bound.mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x2\000\00000\000\000 */
{ 2559545 }, /* topdown_be_bound.non_mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x8\000\00000\000\000 */
{ 2560232 }, /* topdown_be_bound.register\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000event=0x74,period=1000003,umask=0x20\000\00000\000\000 */
{ 2561036 }, /* topdown_be_bound.reorder_buffer\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000event=0x74,period=1000003,umask=0x40\000\00000\000\000 */
{ 2561495 }, /* topdown_be_bound.serialization\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000event=0x74,period=1000003,umask=0x10\000\00000\000\000 */
{ 2562293 }, /* topdown_be_bound.store_buffer\000\000pipeline\000This event is deprecated\000event=0x74,period=1000003,umask=0x4\000\00010\000\000 */
{ 2562536 }, /* topdown_fe_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls\000event=0x71,period=1000003\000\00000\000\000 */
{ 2563071 }, /* topdown_fe_bound.branch_detect\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS\000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 2564383 }, /* topdown_fe_bound.branch_resteer\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS\000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 2565335 }, /* topdown_fe_bound.cisc\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS)\000event=0x71,period=1000003,umask=0x1\000\00000\000\000 */
{ 2565941 }, /* topdown_fe_bound.decode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls\000event=0x71,period=1000003,umask=0x8\000\00000\000\000 */
{ 2568540 }, /* topdown_fe_bound.itlb\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses\000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000 */
{ 2569631 }, /* topdown_fe_bound.other\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized\000event=0x71,period=1000003,umask=0x80\000\00000\000\000 */
{ 2570080 }, /* topdown_fe_bound.predecode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes\000event=0x71,period=1000003,umask=0x4\000\00000\000\000 */
{ 2570845 }, /* topdown_retiring.all\000\000pipeline\000Counts the total number of consumed retirement slots (Precise event)\000event=0xc2,period=1000003\000\00000\000\000 */
{ 6212632 }, /* uops_issued.any\000\000pipeline\000Counts the number of uops issued by the front end every cycle\000event=0xe,period=200003\000\00000\000Counts the number of uops issued by the front end every cycle. When 4-uops are requested and only 2-uops are delivered, the event counts 2.  Uops_issued correlates to the number of ROB entries.  If uop takes 2 ROB slots it counts as 2 uops_issued\000 */
{ 6226738 }, /* uops_retired.all\000\000pipeline\000Counts the total number of uops retired (Precise event)\000event=0xc2,period=2000003\000\00000\000\000 */
{ 6230315 }, /* uops_retired.idiv\000\000pipeline\000Counts the number of integer divide uops retired (Precise event)\000event=0xc2,period=2000003,umask=0x10\000\00000\000\000 */
{ 6231578 }, /* uops_retired.ms\000\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000 */
{ 6241237 }, /* uops_retired.x87\000\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 788975 }, /* dtlb_load_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to loads that miss the PDE (Page Directory Entry) cache\000event=0x8,period=200003,umask=0x80\000\00000\000\000 */
{ 789543 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to a demand load that did not start a page walk. Account for all page sizes. Will result in a DTLB write from STLB\000event=0x8,period=200003,umask=0x20\000\00000\000\000 */
{ 794124 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size\000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000 */
{ 797270 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1GB pages. Includes page walks that page fault\000 */
{ 799932 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 2M or 4M page\000event=0x8,period=200003,umask=0x4\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages. Includes page walks that page fault\000 */
{ 803279 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 4K page\000event=0x8,period=200003,umask=0x2\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages. Includes page walks that page fault\000 */
{ 807481 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle\000event=0x8,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 811352 }, /* dtlb_store_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to stores that miss the PDE (Page Directory Entry) cache\000event=0x49,period=2000003,umask=0x80\000\00000\000\000 */
{ 811787 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to stores that did not start a page walk. Account for all pages sizes. Will result in a DTLB write from STLB\000event=0x49,period=2000003,umask=0x20\000\00000\000\000 */
{ 816529 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size\000event=0x49,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 819410 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000 */
{ 822046 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 2M or 4M page\000event=0x49,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000 */
{ 825196 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 4K page\000event=0x49,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000 */
{ 829372 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle\000event=0x49,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 831616 }, /* ept.epde_hit\000\000virtual memory\000Counts the number of Extended Page Directory Entry hits\000event=0x4f,period=2000003,umask=0x1\000\00000\000Counts the number of Extended Page Directory Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 831940 }, /* ept.epde_miss\000\000virtual memory\000Counts the number of Extended Page Directory Entry misses\000event=0x4f,period=2000003,umask=0x2\000\00000\000Counts the number Extended Page Directory Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 832266 }, /* ept.epdpe_hit\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry hits\000event=0x4f,period=2000003,umask=0x4\000\00000\000Counts the number Extended Page Directory Pointer Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 832604 }, /* ept.epdpe_miss\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry misses\000event=0x4f,period=2000003,umask=0x8\000\00000\000Counts the number Extended Page Directory Pointer Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 834140 }, /* ept.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle\000event=0x4f,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 1077182 }, /* itlb.fills\000\000virtual memory\000Counts the number of times there was an ITLB miss and a new translation was filled into the ITLB\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) and a new translation was filled into the ITLB. The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000 */
{ 1081713 }, /* itlb_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache\000event=0x85,period=2000003,umask=0x80\000\00000\000\000 */
{ 1082122 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to an instruction fetch that did not start a page walk. Account for all pages sizes. Will result in an ITLB write from STLB\000event=0x85,period=2000003,umask=0x20\000\00000\000\000 */
{ 1086987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1089323 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 1G page\000event=0x85,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000 */
{ 1091825 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 2M or 4M page\000event=0x85,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000 */
{ 1094631 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 4K page\000event=0x85,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000 */
{ 1097075 }, /* itlb_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle\000event=0x85,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk)\000 */
{ 1193599 }, /* ld_blocks.dtlb_miss\000\000virtual memory\000Counts the number of retired loads that are blocked due to a first level TLB miss (Precise event)\000event=0x3,period=1000003,umask=0x8\000\00000\000\000 */
{ 1393706 }, /* mem_uops_retired.dtlb_miss\000\000virtual memory\000Counts the number of memory uops retired that missed in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x13\000\00000\000\000 */
{ 1394557 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Counts the number of load uops retired that miss in the second Level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x11\000\00000\000\000 */
{ 1395271 }, /* mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Counts the number of store uops retired that miss in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x12\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__elkhartlake[] = {
{ 3446 }, /* \000Average_Frequency\000\000cycles / CPU_CLK_UNHALTED.REF_TSC * msr@tsc@ / 1e9\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 4692 }, /* \000CLKS\000\000cycles\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 4787 }, /* \000CPI\000\0001 / IPC\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 4879 }, /* \000CPU_Utilization\000\000CPU_CLK_UNHALTED.REF_TSC / msr@tsc@\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 5567 }, /* \000IPC\000\000INST_RETIRED.ANY / cycles\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 5718 }, /* \000Instructions\000\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000\000\000\000\000\00000 */
{ 5795 }, /* \000IpBranch\000\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 5930 }, /* \000IpMispredict\000\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000\000\00000 */
{ 6075 }, /* \000Kernel_Utilization\000\000cycles:k / cycles\000\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 6260 }, /* \000L3_Cache_Fill_BW\000\00064 * LONGEST_LAT_CACHE.MISS / 1e9\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 6452 }, /* \000Turbo_Utilization\000\000cycles / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__goldmont[] = {
{ 575373 }, /* core_reject_l2q.all\000\000cache\000Requests rejected by the L2Q\000event=0x31,period=200003\000\00000\000Counts the number of demand and L1 prefetcher requests rejected by the L2Q due to a full or nearly full condition which likely indicates back pressure from L2Q. It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link. The L2Q may also reject transactions from a core to ensure fairness between cores, or to delay a core's dirty eviction when the address conflicts with incoming external snoops\000 */
{ 779286 }, /* dl1.dirty_eviction\000\000cache\000L1 Cache evictions for dirty data\000event=0x51,period=200003,umask=0x1\000\00000\000Counts when a modified (dirty) cache line is evicted from the data L1 cache and needs to be written back to memory.  No count will occur if the evicted line is clean, and hence does not require a writeback\000 */
{ 851171 }, /* fetch_stall.icache_fill_pending_cycles\000\000cache\000Cycles code-fetch stalled due to an outstanding ICache miss\000event=0x86,period=200003,umask=0x2\000\00000\000Counts cycles that fetch is stalled due to an outstanding ICache miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ICache miss.  Note: this event is not the same as the total number of cycles spent retrieving instruction cache lines from the memory hierarchy\000 */
{ 1148742 }, /* l2_reject_xq.all\000\000cache\000Requests rejected by the XQ\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the L2 XQ rejects due to a full or near full condition which likely indicates back pressure from the intra-die interconnect (IDI) fabric. The XQ may reject transactions from the L2Q (non-cacheable requests), L2 misses and L2 write-back victims\000 */
{ 1249101 }, /* longest_lat_cache.miss\000\000cache\000L2 cache request misses\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts memory requests originating from the core that miss in the L2 cache\000 */
{ 1253115 }, /* longest_lat_cache.reference\000\000cache\000L2 cache requests\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts memory requests originating from the core that reference a cache line in the L2 cache\000 */
{ 1352934 }, /* mem_load_uops_retired.dram_hit\000\000cache\000Loads retired that came from DRAM (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x80\000\00000\000Counts memory load uops retired where the data is retrieved from DRAM.  Event is counted at retirement, so the speculative loads are ignored.  A memory load can hit (or miss) the L1 cache, hit (or miss) the L2 cache, hit DRAM, hit in the WCB or receive a HITM response  Supports address when precise (Must be precise)\000 */
{ 1355390 }, /* mem_load_uops_retired.hitm\000\000cache\000Memory uop retired where cross core or cross module HITM occurred (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x20\000\00000\000Counts load uops retired where the cache line containing the data was in the modified state of another core or modules cache (HITM).  More specifically, this means that when the load address was checked by other caching agents (typically another processor) in the system, one of those caching agents indicated that they had a dirty copy of the data.  Loads that obtain a HITM response incur greater latency than most is typical for a load.  In addition, since HITM indicates that some other processor had this data in its cache, it implies that the data was shared between processors, or potentially was a lock or semaphore value.  This event is useful for locating sharing, false sharing, and contended locks  Supports address when precise (Must be precise)\000 */
{ 1356554 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Load uops retired that hit L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x1\000\00000\000Counts load uops retired that hit the L1 data cache  Supports address when precise (Must be precise)\000 */
{ 1358352 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Load uops retired that missed L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts load uops retired that miss the L1 data cache  Supports address when precise (Must be precise)\000 */
{ 1359864 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Load uops retired that hit L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts load uops retired that hit in the L2 cache  Supports address when precise (Must be precise)\000 */
{ 1361605 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Load uops retired that missed L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x10\000\00000\000Counts load uops retired that miss in the L2 cache  Supports address when precise (Must be precise)\000 */
{ 1365993 }, /* mem_load_uops_retired.wcb_hit\000\000cache\000Loads retired that hit WCB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x40\000\00000\000Counts memory load uops retired where the data is retrieved from the WCB (or fill buffer), indicating that the load found its data while that data was in the process of being brought into the L1 cache.  Typically a load will receive this indication when some other load or prefetch missed the L1 cache and was in the process of retrieving the cache line containing the data, but that process had not yet finished (and written the data back to the cache). For example, consider load X and Y, both referencing the same cache line that is not in the L1 cache.  If load X misses cache first, it obtains and WCB (or fill buffer) and begins the process of requesting the data.  When load Y requests the data, it will either hit the WCB, or the L1 cache, depending on exactly what time the request to Y occurs  Supports address when precise (Must be precise)\000 */
{ 1388344 }, /* mem_uops_retired.all\000\000cache\000Memory uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired that is either a loads or a store or both  Supports address when precise (Must be precise)\000 */
{ 1389860 }, /* mem_uops_retired.all_loads\000\000cache\000Load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the number of load uops retired  Supports address when precise (Must be precise)\000 */
{ 1392983 }, /* mem_uops_retired.all_stores\000\000cache\000Store uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the number of store uops retired  Supports address when precise (Must be precise)\000 */
{ 1414956 }, /* mem_uops_retired.lock_loads\000\000cache\000Locked load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x21\000\00000\000Counts locked memory uops retired.  This includes regular locks and bus locks. (To specifically count bus locks only, see the Offcore response event.)  A locked access is one with a lock prefix, or an exchange to memory.  See the SDM for a complete description of which memory load accesses are locks  Supports address when precise (Must be precise)\000 */
{ 1416809 }, /* mem_uops_retired.split\000\000cache\000Memory uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x43\000\00000\000Counts memory uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 1417503 }, /* mem_uops_retired.split_loads\000\000cache\000Load uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x41\000\00000\000Counts load uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 1421013 }, /* mem_uops_retired.split_stores\000\000cache\000Stores uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x42\000\00000\000Counts store uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 2461084 }, /* offcore_response\000\000cache\000Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000event=0xb7,period=100007,umask=0x1\000\00000\000\000 */
{ 1928122 }, /* offcore_response.any_data_rd.l2_hit\000\000cache\000Counts data reads (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043091\000\00000\000Counts data reads (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1931642 }, /* offcore_response.any_data_rd.l2_miss.any\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1932244 }, /* offcore_response.any_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1933489 }, /* offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000Counts data reads (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1934185 }, /* offcore_response.any_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000Counts data reads (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1942971 }, /* offcore_response.any_pf_data_rd.l2_hit\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1943326 }, /* offcore_response.any_pf_data_rd.l2_miss.any\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1943688 }, /* offcore_response.any_pf_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1944742 }, /* offcore_response.any_pf_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1945268 }, /* offcore_response.any_pf_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads generated by L1 or L2 prefetchers that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1952235 }, /* offcore_response.any_read.l2_hit\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000432b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1955253 }, /* offcore_response.any_read.l2_miss.any\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x36000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1955679 }, /* offcore_response.any_read.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x04000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1956861 }, /* offcore_response.any_read.l2_miss.hitm_other_core\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1957451 }, /* offcore_response.any_read.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x02000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1962179 }, /* offcore_response.any_request.any_response\000\000cache\000Counts requests to the uncore subsystem that have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000Counts requests to the uncore subsystem that have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1963760 }, /* offcore_response.any_request.l2_hit\000\000cache\000Counts requests to the uncore subsystem that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000048000\000\00000\000Counts requests to the uncore subsystem that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1966906 }, /* offcore_response.any_request.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400008000\000\00000\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1968137 }, /* offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008000\000\00000\000Counts requests to the uncore subsystem that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1968815 }, /* offcore_response.any_request.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts requests to the uncore subsystem that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008000\000\00000\000Counts requests to the uncore subsystem that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1978662 }, /* offcore_response.any_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1981982 }, /* offcore_response.any_rfo.l2_miss.any\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1982624 }, /* offcore_response.any_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1983953 }, /* offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1984689 }, /* offcore_response.any_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1991508 }, /* offcore_response.bus_locks.any_response\000\000cache\000Counts bus lock and split lock requests that have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000Counts bus lock and split lock requests that have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2000945 }, /* offcore_response.corewb.l2_hit\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2001346 }, /* offcore_response.corewb.l2_miss.any\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2001916 }, /* offcore_response.corewb.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2003062 }, /* offcore_response.corewb.l2_miss.hitm_other_core\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2003853 }, /* offcore_response.corewb.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2028085 }, /* offcore_response.demand_code_rd.l2_hit\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2031611 }, /* offcore_response.demand_code_rd.l2_miss.any\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2032349 }, /* offcore_response.demand_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2033799 }, /* offcore_response.demand_code_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2067758 }, /* offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2082342 }, /* offcore_response.demand_data_rd.l2_hit\000\000cache\000Counts demand cacheable data reads of full cache lines that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040001\000\00000\000Counts demand cacheable data reads of full cache lines that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2085189 }, /* offcore_response.demand_data_rd.l2_miss.any\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2085831 }, /* offcore_response.demand_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2087153 }, /* offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000Counts demand cacheable data reads of full cache lines that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2087889 }, /* offcore_response.demand_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand cacheable data reads of full cache lines that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000Counts demand cacheable data reads of full cache lines that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2124188 }, /* offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data reads of full cache lines that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000Counts demand cacheable data reads of full cache lines that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2140217 }, /* offcore_response.demand_rfo.l2_hit\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2143542 }, /* offcore_response.demand_rfo.l2_miss.any\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2144249 }, /* offcore_response.demand_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2145710 }, /* offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2146511 }, /* offcore_response.demand_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2182433 }, /* offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line that are outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2189320 }, /* offcore_response.full_streaming_stores.l2_hit\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2189832 }, /* offcore_response.full_streaming_stores.l2_miss.any\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2190351 }, /* offcore_response.full_streaming_stores.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2191719 }, /* offcore_response.full_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2192402 }, /* offcore_response.full_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2230445 }, /* offcore_response.partial_reads.l2_miss.any\000\000cache\000Counts demand data partial reads, including data in uncacheable (UC) or uncacheable write combining (USWC) memory types that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000080\000\00000\000Counts demand data partial reads, including data in uncacheable (UC) or uncacheable write combining (USWC) memory types that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2232782 }, /* offcore_response.partial_streaming_stores.l2_hit\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2233225 }, /* offcore_response.partial_streaming_stores.l2_miss.any\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2233675 }, /* offcore_response.partial_streaming_stores.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2234301 }, /* offcore_response.partial_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2234915 }, /* offcore_response.partial_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200004000\000\00000\000Counts partial cache line data writes to uncacheable write combining (USWC) memory region  that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2239322 }, /* offcore_response.partial_writes.l2_miss.any\000\000cache\000Counts the number of demand write requests (RFO) generated by a write to partial data cache line, including the writes to uncacheable (UC) and write through (WT), and write protected (WP) types of memory that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000100\000\00000\000Counts the number of demand write requests (RFO) generated by a write to partial data cache line, including the writes to uncacheable (UC) and write through (WT), and write protected (WP) types of memory that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2262324 }, /* offcore_response.pf_l1_data_rd.l2_hit\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000042000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2265584 }, /* offcore_response.pf_l1_data_rd.l2_miss.any\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2266266 }, /* offcore_response.pf_l1_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2267669 }, /* offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2268445 }, /* offcore_response.pf_l1_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2303192 }, /* offcore_response.pf_l2_data_rd.l2_hit\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2303766 }, /* offcore_response.pf_l2_data_rd.l2_miss.any\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2304451 }, /* offcore_response.pf_l2_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2305845 }, /* offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2306624 }, /* offcore_response.pf_l2_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2337267 }, /* offcore_response.pf_l2_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2340448 }, /* offcore_response.pf_l2_rfo.l2_miss.any\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2341115 }, /* offcore_response.pf_l2_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2342485 }, /* offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2343246 }, /* offcore_response.pf_l2_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2447594 }, /* offcore_response.streaming_stores.l2_hit\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2447999 }, /* offcore_response.streaming_stores.l2_miss.any\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2451042 }, /* offcore_response.sw_prefetch.l2_hit\000\000cache\000Counts data cache lines requests by software prefetch instructions that hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000041000\000\00000\000Counts data cache lines requests by software prefetch instructions that hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2451424 }, /* offcore_response.sw_prefetch.l2_miss.any\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x3600001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2451813 }, /* offcore_response.sw_prefetch.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, no data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2452921 }, /* offcore_response.sw_prefetch.l2_miss.hitm_other_core\000\000cache\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000001000\000\00000\000Counts data cache lines requests by software prefetch instructions that miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2453474 }, /* offcore_response.sw_prefetch.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache lines requests by software prefetch instructions that true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200001000\000\00000\000Counts data cache lines requests by software prefetch instructions that true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 761378 }, /* cycles_div_busy.fpdiv\000\000floating point\000Cycles the FP divide unit is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts core cycles the floating point divide unit is busy\000 */
{ 1291653 }, /* machine_clears.fp_assist\000\000floating point\000Machine clears due to FP assists\000event=0xc3,period=200003,umask=0x4\000\00000\000Counts machine clears due to floating point (FP) operations needing assists.  For instance, if the result was a floating point denormal, the hardware clears the pipeline and reissues uops to produce the correct IEEE compliant denormal result\000 */
{ 6229041 }, /* uops_retired.fpdiv\000\000floating point\000Floating point divide uops retired. (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x8\000\00000\000Counts the number of floating point divide uops retired (Must be precise)\000 */
{ 473969 }, /* baclears.all\000\000frontend\000BACLEARs asserted for any branch type\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the number of times a BACLEAR is signaled for any reason, including, but not limited to indirect branch/call,  Jcc (Jump on Conditional Code/Jump if Condition is Met) branch, unconditional branch/call, and returns\000 */
{ 478779 }, /* baclears.cond\000\000frontend\000BACLEARs asserted for conditional branch\000event=0xe6,period=200003,umask=0x10\000\00000\000Counts BACLEARS on Jcc (Jump on Conditional Code/Jump if Condition is Met) branches\000 */
{ 479825 }, /* baclears.return\000\000frontend\000BACLEARs asserted for return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000Counts BACLEARS on return instructions\000 */
{ 778131 }, /* decode_restriction.predecode_wrong\000\000frontend\000Decode restrictions due to predicting wrong instruction length\000event=0xe9,period=200003,umask=0x1\000\00000\000Counts the number of times the prediction (from the predecode cache) for instruction length is incorrect\000 */
{ 983878 }, /* icache.accesses\000\000frontend\000References per ICache line. This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x3\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line.  The event strives to count on a cache line basis, so that multiple fetches to a single cache line count as one ICACHE.ACCESS.  Specifically, the event counts when accesses from straight line code crosses the cache line boundary, or when a branch target is to a new line.\r\nThis event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 987021 }, /* icache.hit\000\000frontend\000References per ICache line that are available in the ICache (hit). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x1\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line and that cache line is in the ICache (hit).  The event strives to count on a cache line basis, so that multiple accesses which hit in a single cache line count as one ICACHE.HIT.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 990922 }, /* icache.misses\000\000frontend\000References per ICache line that are not available in the ICache (miss). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x2\000\00000\000Counts requests to the Instruction Cache (ICache)  for one or more bytes in an ICache Line and that cache line is not in the ICache (miss).  The event strives to count on a cache line basis, so that multiple accesses which miss in a single cache line count as one ICACHE.MISS.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is not in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 1435630 }, /* ms_decoded.ms_entry\000\000frontend\000MS decode starts\000event=0xe7,period=200003,umask=0x1\000\00000\000Counts the number of times the Microcode Sequencer (MS) starts a flow of uops from the MSROM. It does not count every time a uop is read from the MSROM.  The most common case that this counts is when a micro-coded instruction is encountered by the front end of the machine.  Other cases include when an instruction encounters a fault, trap, or microcode assist of any sort that initiates a flow of uops.  The event will count MS startups for uops that are speculative, and subsequently cleared by branch mispredict or a machine clear\000 */
{ 1296287 }, /* machine_clears.memory_ordering\000\000memory\000Machine clears due to memory ordering issue\000event=0xc3,period=200003,umask=0x2\000\00000\000Counts machine clears due to memory ordering issues.  This occurs when a snoop request happens and the machine is uncertain if memory ordering will be preserved as another core is in the process of modifying the data\000 */
{ 1427982 }, /* misalign_mem_ref.load_page_split\000\000memory\000Load uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x2\000\00000\000Counts when a memory load of a uop spans a page boundary (a split) is retired (Must be precise)\000 */
{ 1429954 }, /* misalign_mem_ref.store_page_split\000\000memory\000Store uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x4\000\00000\000Counts when a memory store of a uop spans a page boundary (a split) is retired (Must be precise)\000 */
{ 850438 }, /* fetch_stall.all\000\000other\000Cycles code-fetch stalled due to any reason\000event=0x86,period=200003\000\00000\000Counts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000 */
{ 852339 }, /* fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles code-fetch stalled due to an outstanding ITLB miss\000event=0x86,period=200003,umask=0x1\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000 */
{ 977105 }, /* hw_interrupts.masked\000\000other\000Cycles hardware interrupts are masked\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000 */
{ 978310 }, /* hw_interrupts.pending_and_masked\000\000other\000Cycles pending interrupts are masked\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts core cycles during which there are pending interrupts, but interrupts are masked (EFLAGS.IF = 0)\000 */
{ 978664 }, /* hw_interrupts.received\000\000other\000Hardware interrupts received\000event=0xcb,period=203,umask=0x1\000\00000\000Counts hardware interrupts received by the processor\000 */
{ 498442 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003\000\00000\000Counts branch instructions retired for all branch types.  This is an architectural performance event (Must be precise)\000 */
{ 501060 }, /* br_inst_retired.all_taken_branches\000\000pipeline\000Retired taken branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x80\000\00000\000Counts the number of taken branch instructions retired (Must be precise)\000 */
{ 502381 }, /* br_inst_retired.call\000\000pipeline\000Retired near call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf9\000\00000\000Counts near CALL branch instructions retired (Must be precise)\000 */
{ 508865 }, /* br_inst_retired.far_branch\000\000pipeline\000Retired far branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xbf\000\00000\000Counts far branch instructions retired.  This includes far jump, far call and return, and Interrupt call and return (Must be precise)\000 */
{ 510535 }, /* br_inst_retired.ind_call\000\000pipeline\000Retired near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfb\000\00000\000Counts near indirect CALL branch instructions retired (Must be precise)\000 */
{ 513563 }, /* br_inst_retired.jcc\000\000pipeline\000Retired conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x7e\000\00000\000Counts retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was taken and when it was not taken (Must be precise)\000 */
{ 521430 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Retired instructions of near indirect Jmp or call (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xeb\000\00000\000Counts near indirect call or near indirect jmp branch instructions retired (Must be precise)\000 */
{ 523936 }, /* br_inst_retired.rel_call\000\000pipeline\000Retired near relative call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfd\000\00000\000Counts near relative CALL branch instructions retired (Must be precise)\000 */
{ 525251 }, /* br_inst_retired.return\000\000pipeline\000Retired near return instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf7\000\00000\000Counts near return branch instructions retired (Must be precise)\000 */
{ 527065 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Retired conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfe\000\00000\000Counts Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were taken and does not count when the Jcc branch instruction were not taken (Must be precise)\000 */
{ 539051 }, /* br_misp_retired.all_branches\000\000pipeline\000Retired mispredicted branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003\000\00000\000Counts mispredicted branch instructions retired including all branch types (Must be precise)\000 */
{ 548296 }, /* br_misp_retired.ind_call\000\000pipeline\000Retired mispredicted near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfb\000\00000\000Counts mispredicted near indirect CALL branch instructions retired, where the target address taken was not what the processor predicted (Must be precise)\000 */
{ 553562 }, /* br_misp_retired.jcc\000\000pipeline\000Retired mispredicted conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0x7e\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was supposed to be taken and when it was not supposed to be taken (but the processor predicted the opposite condition) (Must be precise)\000 */
{ 558694 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Retired mispredicted instructions of near indirect Jmp or near indirect call. (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xeb\000\00000\000Counts mispredicted branch instructions retired that were near indirect call or near indirect jmp, where the target address taken was not what the processor predicted (Must be precise)\000 */
{ 562278 }, /* br_misp_retired.return\000\000pipeline\000Retired mispredicted near return instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xf7\000\00000\000Counts mispredicted near RET branch instructions retired, where the return address taken was not what the processor predicted (Must be precise)\000 */
{ 564160 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Retired mispredicted conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfe\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were supposed to be taken but the processor predicted that it would not be taken (Must be precise)\000 */
{ 611859 }, /* cpu_clk_unhalted.core\000\000pipeline\000Core cycles when core is not halted  (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1.  You cannot collect a PEBs record for this event\000 */
{ 614831 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000Core cycles when core is not halted.  This event uses a (_P)rogrammable general purpose performance counter\000 */
{ 620122 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000Reference cycles when core is not halted.  This event uses a programmable general purpose performance counter\000 */
{ 624176 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when core is not halted  (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction.  In mobile systems the core frequency may change from time.  This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  This event uses fixed counter 2.  You cannot collect a PEBs record for this event\000 */
{ 759557 }, /* cycles_div_busy.all\000\000pipeline\000Cycles a divider is busy\000event=0xcd,period=2000003\000\00000\000Counts core cycles if either divide unit is busy\000 */
{ 761778 }, /* cycles_div_busy.idiv\000\000pipeline\000Cycles the integer divide unit is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts core cycles the integer divide unit is busy\000 */
{ 1046701 }, /* inst_retired.any\000\000pipeline\000Instructions retired (Fixed event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers.  This event uses fixed counter 0.  You cannot collect a PEBs record for this event\000 */
{ 1052764 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Precise event capable) (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The event continues counting during hardware interrupts, traps, and inside interrupt handlers.  This is an architectural performance event.  This event uses a (_P)rogrammable general purpose performance counter. *This event is Precise Event capable:  The EventingRIP field in the PEBS record is precise to the address of the instruction which caused the event.  Note: Because PEBS records can be collected only on IA32_PMC0, only one event can use the PEBS facility at a time (Must be precise)\000 */
{ 1075716 }, /* issue_slots_not_consumed.any\000\000pipeline\000Unfilled issue slots per cycle\000event=0xca,period=200003\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend due to either a full resource  in the backend (RESOURCE_FULL) or due to the processor recovering from some event (RECOVERY)\000 */
{ 1076025 }, /* issue_slots_not_consumed.recovery\000\000pipeline\000Unfilled issue slots per cycle to recover\000event=0xca,period=200003,umask=0x2\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend because allocation is stalled waiting for a mispredicted jump to retire or other branch-like conditions (e.g. the event is relevant during certain microcode flows).   Counts all issue slots blocked while within this window including slots where uops were not available in the Instruction Queue\000 */
{ 1076530 }, /* issue_slots_not_consumed.resource_full\000\000pipeline\000Unfilled issue slots per cycle because of a full resource in the backend\000event=0xca,period=200003,umask=0x1\000\00000\000Counts the number of issue slots per core cycle that were not consumed because of a full resource in the backend.  Including but not limited to resources such as the Re-order Buffer (ROB), reservation stations (RS), load/store buffers, physical registers, or any other needed machine resource that is currently unavailable.   Note that uops must be available for consumption in order for this event to fire.  If a uop is not available (Instruction Queue is empty), this event will not count\000 */
{ 1190157 }, /* ld_blocks.4k_alias\000\000pipeline\000Loads blocked because address has 4k partial address false dependence (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x4\000\00000\000Counts loads that block because their address modulo 4K matches a pending store (Must be precise)\000 */
{ 1192137 }, /* ld_blocks.all_block\000\000pipeline\000Loads blocked (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x10\000\00000\000Counts anytime a load that retires is blocked for any reason (Must be precise)\000 */
{ 1192823 }, /* ld_blocks.data_unknown\000\000pipeline\000Loads blocked due to store data not ready (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x1\000\00000\000Counts a load blocked from using a store forward, but did not occur because the store data was not available at the right time.  The forward might occur subsequently when the data is available (Must be precise)\000 */
{ 1199524 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to store forward restriction (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x2\000\00000\000Counts a load blocked from using a store forward because of an address/size mismatch, only one of the loads blocked from each store will be counted (Must be precise)\000 */
{ 1201138 }, /* ld_blocks.utlb_miss\000\000pipeline\000Loads blocked because address in not in the UTLB (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x8\000\00000\000Counts loads blocked because they are unable to find their physical address in the micro TLB (UTLB) (Must be precise)\000 */
{ 1286903 }, /* machine_clears.all\000\000pipeline\000All machine clears\000event=0xc3,period=200003\000\00000\000Counts machine clears for any reason\000 */
{ 1290034 }, /* machine_clears.disambiguation\000\000pipeline\000Machine clears due to memory disambiguation\000event=0xc3,period=200003,umask=0x8\000\00000\000Counts machine clears due to memory disambiguation.  Memory disambiguation happens when a load which has been issued conflicts with a previous unretired store in the pipeline whose address was not known at issue time, but is later resolved to be the same as the load address\000 */
{ 1300507 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200003,umask=0x1\000\00000\000Counts the number of times that the processor detects that a program is writing to a code section and has to perform a machine clear because of that modification.  Self-modifying code (SMC) causes a severe penalty in all Intel(R) architecture processors\000 */
{ 6212995 }, /* uops_issued.any\000\000pipeline\000Uops issued to the back end per cycle\000event=0xe,period=200003\000\00000\000Counts uops issued by the front end and allocated into the back end of the machine.  This event counts uops that retire as well as uops that were speculatively executed but didn't retire. The sort of speculative uops that might be counted includes, but is not limited to those uops issued in the shadow of a miss-predicted branch, those uops that are inserted during an assist (such as for a denormal floating point result), and (previously allocated) uops that might be canceled during a machine clear\000 */
{ 6222895 }, /* uops_not_delivered.any\000\000pipeline\000Uops requested but not-delivered to the back-end per cycle\000event=0x9c,period=200003\000\00000\000This event used to measure front-end inefficiencies. I.e. when front-end of the machine is not delivering uops to the back-end and the back-end has is not stalled. This event can be used to identify if the machine is truly front-end bound.  When this event occurs, it is an indication that the front-end of the machine is operating at less than its theoretical peak performance. Background: We can think of the processor pipeline as being divided into 2 broader parts: Front-end and Back-end. Front-end is responsible for fetching the instruction, decoding into uops in machine understandable format and putting them into a uop queue to be consumed by back end. The back-end then takes these uops, allocates the required resources.  When all resources are ready, uops are executed. If the back-end is not ready to accept uops from the front-end, then we do not want to count these as front-end bottlenecks.  However, whenever we have bottlenecks in the back-end, we will have allocation unit stalls and eventually forcing the front-end to wait until the back-end is ready to receive more uops. This event counts only when back-end is requesting more uops and front-end is not able to provide them. When 3 uops are requested and no uops are delivered, the event counts 3. When 3 are requested, and only 1 is delivered, the event counts 2. When only 2 are delivered, the event counts 1. Alternatively stated, the event will not count if 3 uops are delivered, or if the back end is stalled and not requesting any uops at all.  Counts indicate missed opportunities for the front-end to deliver a uop to the back end. Some examples of conditions that cause front-end efficiencies are: ICache misses, ITLB misses, and decoder restrictions that limit the front-end bandwidth. Known Issues: Some uops require multiple allocation slots.  These uops will not be charged as a front end 'not delivered' opportunity, and will be regarded as a back end problem. For example, the INC instruction has one uop that requires 2 issue slots.  A stream of INC instructions will not count as UOPS_NOT_DELIVERED, even though only one instruction can be issued per clock.  The low uop issue rate for a stream of INC instructions is considered to be a back end issue\000 */
{ 6227872 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003\000\00000\000Counts uops which retired (Must be precise)\000 */
{ 6230656 }, /* uops_retired.idiv\000\000pipeline\000Integer divide uops retired. (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x10\000\00000\000Counts the number of integer divide uops retired (Must be precise)\000 */
{ 6231954 }, /* uops_retired.ms\000\000pipeline\000MS uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts uops retired that are from the complex flows issued by the micro-sequencer (MS).  Counts both the uops from a micro-coded instruction, and the uops that might be generated from a micro-coded assist (Must be precise)\000 */
{ 1078979 }, /* itlb.miss\000\000virtual memory\000ITLB misses\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) for a linear address of an instruction fetch.  It counts when new translation are filled into the ITLB.  The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000 */
{ 1393914 }, /* mem_uops_retired.dtlb_miss\000\000virtual memory\000Memory uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x13\000\00000\000Counts uops retired that had a DTLB miss on load, store or either.  Note that when two distinct memory operations to the same page miss the DTLB, only one of them will be recorded as a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 1394767 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Load uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x11\000\00000\000Counts load uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 1395483 }, /* mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Store uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x12\000\00000\000Counts store uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 2472520 }, /* page_walks.cycles\000\000virtual memory\000Duration of page-walks in cycles\000event=0x5,period=200003,umask=0x3\000\00000\000Counts every core cycle a page-walk is in progress due to either a data memory operation or an instruction fetch\000 */
{ 2473722 }, /* page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side page-walks in cycles\000event=0x5,period=200003,umask=0x1\000\00000\000Counts every core cycle when a Data-side (walks due to a data operation) page walk is in progress\000 */
{ 2475319 }, /* page_walks.i_side_cycles\000\000virtual memory\000Duration of I-side pagewalks in cycles\000event=0x5,period=200003,umask=0x2\000\00000\000Counts every core cycle when a Instruction-side (walks due to an instruction fetch) page walk is in progress\000 */
};

static const struct compact_pmu_event pmu_events__goldmontplus[] = {
{ 575961 }, /* core_reject_l2q.all\000\000cache\000Requests rejected by the L2Q\000event=0x31,period=200003\000\00000\000Counts the number of demand and L1 prefetcher requests rejected by the L2Q due to a full or nearly full condition which likely indicates back pressure from L2Q. It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link. The L2Q may also reject transactions from a core to insure fairness between cores, or to delay a core's dirty eviction when the address conflicts with incoming external snoops\000 */
{ 779591 }, /* dl1.replacement\000\000cache\000L1 Cache evictions for dirty data\000event=0x51,period=200003,umask=0x1\000\00000\000Counts when a modified (dirty) cache line is evicted from the data L1 cache and needs to be written back to memory.  No count will occur if the evicted line is clean, and hence does not require a writeback\000 */
{ 851171 }, /* fetch_stall.icache_fill_pending_cycles\000\000cache\000Cycles code-fetch stalled due to an outstanding ICache miss\000event=0x86,period=200003,umask=0x2\000\00000\000Counts cycles that fetch is stalled due to an outstanding ICache miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ICache miss.  Note: this event is not the same as the total number of cycles spent retrieving instruction cache lines from the memory hierarchy\000 */
{ 1148742 }, /* l2_reject_xq.all\000\000cache\000Requests rejected by the XQ\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the L2 XQ rejects due to a full or near full condition which likely indicates back pressure from the intra-die interconnect (IDI) fabric. The XQ may reject transactions from the L2Q (non-cacheable requests), L2 misses and L2 write-back victims\000 */
{ 1249101 }, /* longest_lat_cache.miss\000\000cache\000L2 cache request misses\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts memory requests originating from the core that miss in the L2 cache\000 */
{ 1253115 }, /* longest_lat_cache.reference\000\000cache\000L2 cache requests\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts memory requests originating from the core that reference a cache line in the L2 cache\000 */
{ 1352934 }, /* mem_load_uops_retired.dram_hit\000\000cache\000Loads retired that came from DRAM (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x80\000\00000\000Counts memory load uops retired where the data is retrieved from DRAM.  Event is counted at retirement, so the speculative loads are ignored.  A memory load can hit (or miss) the L1 cache, hit (or miss) the L2 cache, hit DRAM, hit in the WCB or receive a HITM response  Supports address when precise (Must be precise)\000 */
{ 1355390 }, /* mem_load_uops_retired.hitm\000\000cache\000Memory uop retired where cross core or cross module HITM occurred (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x20\000\00000\000Counts load uops retired where the cache line containing the data was in the modified state of another core or modules cache (HITM).  More specifically, this means that when the load address was checked by other caching agents (typically another processor) in the system, one of those caching agents indicated that they had a dirty copy of the data.  Loads that obtain a HITM response incur greater latency than most is typical for a load.  In addition, since HITM indicates that some other processor had this data in its cache, it implies that the data was shared between processors, or potentially was a lock or semaphore value.  This event is useful for locating sharing, false sharing, and contended locks  Supports address when precise (Must be precise)\000 */
{ 1356554 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Load uops retired that hit L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x1\000\00000\000Counts load uops retired that hit the L1 data cache  Supports address when precise (Must be precise)\000 */
{ 1358352 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Load uops retired that missed L1 data cache (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts load uops retired that miss the L1 data cache  Supports address when precise (Must be precise)\000 */
{ 1359864 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Load uops retired that hit L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts load uops retired that hit in the L2 cache  Supports address when precise (Must be precise)\000 */
{ 1361605 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Load uops retired that missed L2 (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x10\000\00000\000Counts load uops retired that miss in the L2 cache  Supports address when precise (Must be precise)\000 */
{ 1365993 }, /* mem_load_uops_retired.wcb_hit\000\000cache\000Loads retired that hit WCB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd1,period=200003,umask=0x40\000\00000\000Counts memory load uops retired where the data is retrieved from the WCB (or fill buffer), indicating that the load found its data while that data was in the process of being brought into the L1 cache.  Typically a load will receive this indication when some other load or prefetch missed the L1 cache and was in the process of retrieving the cache line containing the data, but that process had not yet finished (and written the data back to the cache). For example, consider load X and Y, both referencing the same cache line that is not in the L1 cache.  If load X misses cache first, it obtains and WCB (or fill buffer) and begins the process of requesting the data.  When load Y requests the data, it will either hit the WCB, or the L1 cache, depending on exactly what time the request to Y occurs  Supports address when precise (Must be precise)\000 */
{ 1388344 }, /* mem_uops_retired.all\000\000cache\000Memory uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired that is either a loads or a store or both  Supports address when precise (Must be precise)\000 */
{ 1389860 }, /* mem_uops_retired.all_loads\000\000cache\000Load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the number of load uops retired  Supports address when precise (Must be precise)\000 */
{ 1392983 }, /* mem_uops_retired.all_stores\000\000cache\000Store uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the number of store uops retired  Supports address when precise (Must be precise)\000 */
{ 1414956 }, /* mem_uops_retired.lock_loads\000\000cache\000Locked load uops retired (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x21\000\00000\000Counts locked memory uops retired.  This includes regular locks and bus locks. (To specifically count bus locks only, see the Offcore response event.)  A locked access is one with a lock prefix, or an exchange to memory.  See the SDM for a complete description of which memory load accesses are locks  Supports address when precise (Must be precise)\000 */
{ 1416809 }, /* mem_uops_retired.split\000\000cache\000Memory uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x43\000\00000\000Counts memory uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 1417503 }, /* mem_uops_retired.split_loads\000\000cache\000Load uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x41\000\00000\000Counts load uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 1421013 }, /* mem_uops_retired.split_stores\000\000cache\000Stores uops retired that split a cache-line (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x42\000\00000\000Counts store uops retired where the data requested spans a 64 byte cache line boundary  Supports address when precise (Must be precise)\000 */
{ 2461084 }, /* offcore_response\000\000cache\000Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000event=0xb7,period=100007,umask=0x1\000\00000\000\000 */
{ 1926737 }, /* offcore_response.any_data_rd.any_response\000\000cache\000Counts data reads (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000Counts data reads (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1927808 }, /* offcore_response.any_data_rd.l2_hit\000\000cache\000Counts data reads (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043091\000\00000\000Counts data reads (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1933004 }, /* offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000Counts data reads (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1934657 }, /* offcore_response.any_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000Counts data reads (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1936173 }, /* offcore_response.any_data_rd.outstanding\000\000cache\000Counts data reads (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003091\000\00000\000Counts data reads (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1942195 }, /* offcore_response.any_pf_data_rd.any_response\000\000cache\000Counts data reads generated by L1 or L2 prefetchers have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013010\000\00000\000Counts data reads generated by L1 or L2 prefetchers have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1942626 }, /* offcore_response.any_pf_data_rd.l2_hit\000\000cache\000Counts data reads generated by L1 or L2 prefetchers hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000043010\000\00000\000Counts data reads generated by L1 or L2 prefetchers hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1944226 }, /* offcore_response.any_pf_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data reads generated by L1 or L2 prefetchers miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1945771 }, /* offcore_response.any_pf_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data reads generated by L1 or L2 prefetchers true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1946264 }, /* offcore_response.any_pf_data_rd.outstanding\000\000cache\000Counts data reads generated by L1 or L2 prefetchers outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003010\000\00000\000Counts data reads generated by L1 or L2 prefetchers outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1950789 }, /* offcore_response.any_read.any_response\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000132b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1951826 }, /* offcore_response.any_read.l2_hit\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000432b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1956281 }, /* offcore_response.any_read.l2_miss.hitm_other_core\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1958018 }, /* offcore_response.any_read.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x02000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1959457 }, /* offcore_response.any_read.outstanding\000\000cache\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x40000032b7\000\00000\000Counts data read, code read, and read for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1961775 }, /* offcore_response.any_request.any_response\000\000cache\000Counts requests to the uncore subsystem have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000Counts requests to the uncore subsystem have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1963442 }, /* offcore_response.any_request.l2_hit\000\000cache\000Counts requests to the uncore subsystem hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000048000\000\00000\000Counts requests to the uncore subsystem hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1967648 }, /* offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts requests to the uncore subsystem miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008000\000\00000\000Counts requests to the uncore subsystem miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1969291 }, /* offcore_response.any_request.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts requests to the uncore subsystem true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008000\000\00000\000Counts requests to the uncore subsystem true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1973286 }, /* offcore_response.any_request.outstanding\000\000cache\000Counts requests to the uncore subsystem outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000008000\000\00000\000Counts requests to the uncore subsystem outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1976953 }, /* offcore_response.any_rfo.any_response\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1978304 }, /* offcore_response.any_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1983424 }, /* offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1985205 }, /* offcore_response.any_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1988997 }, /* offcore_response.any_rfo.outstanding\000\000cache\000Counts reads for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000022\000\00000\000Counts reads for ownership (RFO) requests (demand & prefetch) outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1991106 }, /* offcore_response.bus_locks.any_response\000\000cache\000Counts bus lock and split lock requests have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000Counts bus lock and split lock requests have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1992513 }, /* offcore_response.bus_locks.l2_hit\000\000cache\000Counts bus lock and split lock requests hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040400\000\00000\000Counts bus lock and split lock requests hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1995598 }, /* offcore_response.bus_locks.l2_miss.hitm_other_core\000\000cache\000Counts bus lock and split lock requests miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000400\000\00000\000Counts bus lock and split lock requests miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1996085 }, /* offcore_response.bus_locks.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts bus lock and split lock requests true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000400\000\00000\000Counts bus lock and split lock requests true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1997499 }, /* offcore_response.bus_locks.outstanding\000\000cache\000Counts bus lock and split lock requests outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000400\000\00000\000Counts bus lock and split lock requests outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 1999473 }, /* offcore_response.corewb.any_response\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2000554 }, /* offcore_response.corewb.l2_hit\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2002500 }, /* offcore_response.corewb.l2_miss.hitm_other_core\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2004402 }, /* offcore_response.corewb.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2009926 }, /* offcore_response.corewb.outstanding\000\000cache\000Counts the number of writeback transactions caused by L1 or L2 cache evictions outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000008\000\00000\000Counts the number of writeback transactions caused by L1 or L2 cache evictions outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2026308 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2027650 }, /* offcore_response.demand_code_rd.l2_hit\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2032977 }, /* offcore_response.demand_code_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2034392 }, /* offcore_response.demand_code_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2067180 }, /* offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000Counts demand instruction cacheline and I-side prefetch requests that miss the instruction cache outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2080053 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand cacheable data reads of full cache lines have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000Counts demand cacheable data reads of full cache lines have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2081991 }, /* offcore_response.demand_data_rd.l2_hit\000\000cache\000Counts demand cacheable data reads of full cache lines hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040001\000\00000\000Counts demand cacheable data reads of full cache lines hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2086631 }, /* offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand cacheable data reads of full cache lines miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000Counts demand cacheable data reads of full cache lines miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2088398 }, /* offcore_response.demand_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand cacheable data reads of full cache lines true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000Counts demand cacheable data reads of full cache lines true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2123694 }, /* offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data reads of full cache lines outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000Counts demand cacheable data reads of full cache lines outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2138195 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2139792 }, /* offcore_response.demand_rfo.l2_hit\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2145114 }, /* offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2147094 }, /* offcore_response.demand_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2181865 }, /* offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000Counts demand reads for ownership (RFO) requests generated by a write to full data cache line outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2188230 }, /* offcore_response.full_streaming_stores.any_response\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2188818 }, /* offcore_response.full_streaming_stores.l2_hit\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2191046 }, /* offcore_response.full_streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2193062 }, /* offcore_response.full_streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2193712 }, /* offcore_response.full_streaming_stores.outstanding\000\000cache\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000800\000\00000\000Counts full cache line data writes to uncacheable write combining (USWC) memory region and full cache-line non-temporal writes outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2260885 }, /* offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2261932 }, /* offcore_response.pf_l1_data_rd.l2_hit\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000042000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2267106 }, /* offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2268995 }, /* offcore_response.pf_l1_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2270257 }, /* offcore_response.pf_l1_data_rd.outstanding\000\000cache\000Counts data cache line reads generated by hardware L1 data cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000002000\000\00000\000Counts data cache line reads generated by hardware L1 data cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2301784 }, /* offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2302812 }, /* offcore_response.pf_l2_data_rd.l2_hit\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2305294 }, /* offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2307162 }, /* offcore_response.pf_l2_data_rd.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2330998 }, /* offcore_response.pf_l2_data_rd.outstanding\000\000cache\000Counts data cacheline reads generated by hardware L2 cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000010\000\00000\000Counts data cacheline reads generated by hardware L2 cache prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2335595 }, /* offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2336893 }, /* offcore_response.pf_l2_rfo.l2_hit\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000040020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2341940 }, /* offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2343778 }, /* offcore_response.pf_l2_rfo.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2366228 }, /* offcore_response.pf_l2_rfo.outstanding\000\000cache\000Counts reads for ownership (RFO) requests generated by L2 prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000020\000\00000\000Counts reads for ownership (RFO) requests generated by L2 prefetcher outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2446577 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2447199 }, /* offcore_response.streaming_stores.l2_hit\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000044800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2448565 }, /* offcore_response.streaming_stores.l2_miss.hitm_other_core\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2449131 }, /* offcore_response.streaming_stores.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2449674 }, /* offcore_response.streaming_stores.outstanding\000\000cache\000Counts any data writes to uncacheable write combining (USWC) memory region  outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000004800\000\00000\000Counts any data writes to uncacheable write combining (USWC) memory region  outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2450212 }, /* offcore_response.sw_prefetch.any_response\000\000cache\000Counts data cache lines requests by software prefetch instructions have any transaction responses from the uncore subsystem\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000011000\000\00000\000Counts data cache lines requests by software prefetch instructions have any transaction responses from the uncore subsystem. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2450670 }, /* offcore_response.sw_prefetch.l2_hit\000\000cache\000Counts data cache lines requests by software prefetch instructions hit the L2 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000041000\000\00000\000Counts data cache lines requests by software prefetch instructions hit the L2 cache. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2452378 }, /* offcore_response.sw_prefetch.l2_miss.hitm_other_core\000\000cache\000Counts data cache lines requests by software prefetch instructions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000001000\000\00000\000Counts data cache lines requests by software prefetch instructions miss the L2 cache with a snoop hit in the other processor module, data forwarding is required. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2454004 }, /* offcore_response.sw_prefetch.l2_miss.snoop_miss_or_no_snoop_needed\000\000cache\000Counts data cache lines requests by software prefetch instructions true miss for the L2 cache with a snoop miss in the other processor module\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200001000\000\00000\000Counts data cache lines requests by software prefetch instructions true miss for the L2 cache with a snoop miss in the other processor module.  Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 2454524 }, /* offcore_response.sw_prefetch.outstanding\000\000cache\000Counts data cache lines requests by software prefetch instructions outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000001000\000\00000\000Counts data cache lines requests by software prefetch instructions outstanding, per cycle, from the time of the L2 miss to when any response is received. Requires MSR_OFFCORE_RESP[0,1] to specify request type and response. (duplicated for both MSRs)\000 */
{ 761378 }, /* cycles_div_busy.fpdiv\000\000floating point\000Cycles the FP divide unit is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts core cycles the floating point divide unit is busy\000 */
{ 1292008 }, /* machine_clears.fp_assist\000\000floating point\000Machine clears due to FP assists\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts machine clears due to floating point (FP) operations needing assists.  For instance, if the result was a floating point denormal, the hardware clears the pipeline and reissues uops to produce the correct IEEE compliant denormal result\000 */
{ 6228815 }, /* uops_retired.fpdiv\000\000floating point\000Floating point divide uops retired (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x8\000\00000\000Counts the number of floating point divide uops retired (Must be precise)\000 */
{ 473969 }, /* baclears.all\000\000frontend\000BACLEARs asserted for any branch type\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the number of times a BACLEAR is signaled for any reason, including, but not limited to indirect branch/call,  Jcc (Jump on Conditional Code/Jump if Condition is Met) branch, unconditional branch/call, and returns\000 */
{ 478779 }, /* baclears.cond\000\000frontend\000BACLEARs asserted for conditional branch\000event=0xe6,period=200003,umask=0x10\000\00000\000Counts BACLEARS on Jcc (Jump on Conditional Code/Jump if Condition is Met) branches\000 */
{ 479825 }, /* baclears.return\000\000frontend\000BACLEARs asserted for return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000Counts BACLEARS on return instructions\000 */
{ 778131 }, /* decode_restriction.predecode_wrong\000\000frontend\000Decode restrictions due to predicting wrong instruction length\000event=0xe9,period=200003,umask=0x1\000\00000\000Counts the number of times the prediction (from the predecode cache) for instruction length is incorrect\000 */
{ 983878 }, /* icache.accesses\000\000frontend\000References per ICache line. This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x3\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line.  The event strives to count on a cache line basis, so that multiple fetches to a single cache line count as one ICACHE.ACCESS.  Specifically, the event counts when accesses from straight line code crosses the cache line boundary, or when a branch target is to a new line.\r\nThis event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 987021 }, /* icache.hit\000\000frontend\000References per ICache line that are available in the ICache (hit). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x1\000\00000\000Counts requests to the Instruction Cache (ICache) for one or more bytes in an ICache Line and that cache line is in the ICache (hit).  The event strives to count on a cache line basis, so that multiple accesses which hit in a single cache line count as one ICACHE.HIT.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 990922 }, /* icache.misses\000\000frontend\000References per ICache line that are not available in the ICache (miss). This event counts differently than Intel processors based on Silvermont microarchitecture\000event=0x80,period=200003,umask=0x2\000\00000\000Counts requests to the Instruction Cache (ICache)  for one or more bytes in an ICache Line and that cache line is not in the ICache (miss).  The event strives to count on a cache line basis, so that multiple accesses which miss in a single cache line count as one ICACHE.MISS.  Specifically, the event counts when straight line code crosses the cache line boundary, or when a branch target is to a new line, and that cache line is not in the ICache. This event counts differently than Intel processors based on Silvermont microarchitecture\000 */
{ 1435630 }, /* ms_decoded.ms_entry\000\000frontend\000MS decode starts\000event=0xe7,period=200003,umask=0x1\000\00000\000Counts the number of times the Microcode Sequencer (MS) starts a flow of uops from the MSROM. It does not count every time a uop is read from the MSROM.  The most common case that this counts is when a micro-coded instruction is encountered by the front end of the machine.  Other cases include when an instruction encounters a fault, trap, or microcode assist of any sort that initiates a flow of uops.  The event will count MS startups for uops that are speculative, and subsequently cleared by branch mispredict or a machine clear\000 */
{ 1296626 }, /* machine_clears.memory_ordering\000\000memory\000Machine clears due to memory ordering issue\000event=0xc3,period=20003,umask=0x2\000\00000\000Counts machine clears due to memory ordering issues.  This occurs when a snoop request happens and the machine is uncertain if memory ordering will be preserved - as another core is in the process of modifying the data\000 */
{ 1427982 }, /* misalign_mem_ref.load_page_split\000\000memory\000Load uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x2\000\00000\000Counts when a memory load of a uop spans a page boundary (a split) is retired (Must be precise)\000 */
{ 1429954 }, /* misalign_mem_ref.store_page_split\000\000memory\000Store uops that split a page (Precise event capable) (Must be precise)\000event=0x13,period=200003,umask=0x4\000\00000\000Counts when a memory store of a uop spans a page boundary (a split) is retired (Must be precise)\000 */
{ 850438 }, /* fetch_stall.all\000\000other\000Cycles code-fetch stalled due to any reason\000event=0x86,period=200003\000\00000\000Counts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000 */
{ 853183 }, /* fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles the code-fetch stalls and an ITLB miss is outstanding\000event=0x86,period=200003,umask=0x1\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000 */
{ 977105 }, /* hw_interrupts.masked\000\000other\000Cycles hardware interrupts are masked\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000 */
{ 978310 }, /* hw_interrupts.pending_and_masked\000\000other\000Cycles pending interrupts are masked\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts core cycles during which there are pending interrupts, but interrupts are masked (EFLAGS.IF = 0)\000 */
{ 978664 }, /* hw_interrupts.received\000\000other\000Hardware interrupts received\000event=0xcb,period=203,umask=0x1\000\00000\000Counts hardware interrupts received by the processor\000 */
{ 498442 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003\000\00000\000Counts branch instructions retired for all branch types.  This is an architectural performance event (Must be precise)\000 */
{ 501060 }, /* br_inst_retired.all_taken_branches\000\000pipeline\000Retired taken branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x80\000\00000\000Counts the number of taken branch instructions retired (Must be precise)\000 */
{ 502381 }, /* br_inst_retired.call\000\000pipeline\000Retired near call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf9\000\00000\000Counts near CALL branch instructions retired (Must be precise)\000 */
{ 508865 }, /* br_inst_retired.far_branch\000\000pipeline\000Retired far branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xbf\000\00000\000Counts far branch instructions retired.  This includes far jump, far call and return, and Interrupt call and return (Must be precise)\000 */
{ 510535 }, /* br_inst_retired.ind_call\000\000pipeline\000Retired near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfb\000\00000\000Counts near indirect CALL branch instructions retired (Must be precise)\000 */
{ 513563 }, /* br_inst_retired.jcc\000\000pipeline\000Retired conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0x7e\000\00000\000Counts retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was taken and when it was not taken (Must be precise)\000 */
{ 521430 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Retired instructions of near indirect Jmp or call (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xeb\000\00000\000Counts near indirect call or near indirect jmp branch instructions retired (Must be precise)\000 */
{ 523936 }, /* br_inst_retired.rel_call\000\000pipeline\000Retired near relative call instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfd\000\00000\000Counts near relative CALL branch instructions retired (Must be precise)\000 */
{ 525251 }, /* br_inst_retired.return\000\000pipeline\000Retired near return instructions (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xf7\000\00000\000Counts near return branch instructions retired (Must be precise)\000 */
{ 527065 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Retired conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc4,period=200003,umask=0xfe\000\00000\000Counts Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were taken and does not count when the Jcc branch instruction were not taken (Must be precise)\000 */
{ 539051 }, /* br_misp_retired.all_branches\000\000pipeline\000Retired mispredicted branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003\000\00000\000Counts mispredicted branch instructions retired including all branch types (Must be precise)\000 */
{ 548296 }, /* br_misp_retired.ind_call\000\000pipeline\000Retired mispredicted near indirect call instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfb\000\00000\000Counts mispredicted near indirect CALL branch instructions retired, where the target address taken was not what the processor predicted (Must be precise)\000 */
{ 553562 }, /* br_misp_retired.jcc\000\000pipeline\000Retired mispredicted conditional branch instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0x7e\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired, including both when the branch was supposed to be taken and when it was not supposed to be taken (but the processor predicted the opposite condition) (Must be precise)\000 */
{ 558309 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Retired mispredicted instructions of near indirect Jmp or near indirect call (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xeb\000\00000\000Counts mispredicted branch instructions retired that were near indirect call or near indirect jmp, where the target address taken was not what the processor predicted (Must be precise)\000 */
{ 562278 }, /* br_misp_retired.return\000\000pipeline\000Retired mispredicted near return instructions (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xf7\000\00000\000Counts mispredicted near RET branch instructions retired, where the return address taken was not what the processor predicted (Must be precise)\000 */
{ 564160 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Retired mispredicted conditional branch instructions that were taken (Precise event capable) (Must be precise)\000event=0xc5,period=200003,umask=0xfe\000\00000\000Counts mispredicted retired Jcc (Jump on Conditional Code/Jump if Condition is Met) branch instructions retired that were supposed to be taken but the processor predicted that it would not be taken (Must be precise)\000 */
{ 611859 }, /* cpu_clk_unhalted.core\000\000pipeline\000Core cycles when core is not halted  (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state.  The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time.  This event uses fixed counter 1.  You cannot collect a PEBs record for this event\000 */
{ 614831 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000Core cycles when core is not halted.  This event uses a (_P)rogrammable general purpose performance counter\000 */
{ 619897 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000Reference cycles when core is not halted.  This event uses a (_P)rogrammable general purpose performance counter\000 */
{ 624176 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when core is not halted  (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction.  In mobile systems the core frequency may change from time.  This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  This event uses fixed counter 2.  You cannot collect a PEBs record for this event\000 */
{ 759557 }, /* cycles_div_busy.all\000\000pipeline\000Cycles a divider is busy\000event=0xcd,period=2000003\000\00000\000Counts core cycles if either divide unit is busy\000 */
{ 761778 }, /* cycles_div_busy.idiv\000\000pipeline\000Cycles the integer divide unit is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts core cycles the integer divide unit is busy\000 */
{ 1046219 }, /* inst_retired.any\000\000pipeline\000Instructions retired (Fixed event) (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers.  This event uses fixed counter 0.  You cannot collect a PEBs record for this event (Must be precise)\000 */
{ 1052764 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Precise event capable) (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions that retire execution. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. The event continues counting during hardware interrupts, traps, and inside interrupt handlers.  This is an architectural performance event.  This event uses a (_P)rogrammable general purpose performance counter. *This event is Precise Event capable:  The EventingRIP field in the PEBS record is precise to the address of the instruction which caused the event.  Note: Because PEBS records can be collected only on IA32_PMC0, only one event can use the PEBS facility at a time (Must be precise)\000 */
{ 1058604 }, /* inst_retired.prec_dist\000\000pipeline\000Instructions retired - using Reduced Skid PEBS feature (Must be precise)\000event=0xc0,period=2000003\000\00000\000Counts INST_RETIRED.ANY using the Reduced Skid PEBS feature that reduces the shadow in which events aren't counted allowing for a more unbiased distribution of samples across instructions retired (Must be precise)\000 */
{ 1075716 }, /* issue_slots_not_consumed.any\000\000pipeline\000Unfilled issue slots per cycle\000event=0xca,period=200003\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend due to either a full resource  in the backend (RESOURCE_FULL) or due to the processor recovering from some event (RECOVERY)\000 */
{ 1076025 }, /* issue_slots_not_consumed.recovery\000\000pipeline\000Unfilled issue slots per cycle to recover\000event=0xca,period=200003,umask=0x2\000\00000\000Counts the number of issue slots per core cycle that were not consumed by the backend because allocation is stalled waiting for a mispredicted jump to retire or other branch-like conditions (e.g. the event is relevant during certain microcode flows).   Counts all issue slots blocked while within this window including slots where uops were not available in the Instruction Queue\000 */
{ 1076530 }, /* issue_slots_not_consumed.resource_full\000\000pipeline\000Unfilled issue slots per cycle because of a full resource in the backend\000event=0xca,period=200003,umask=0x1\000\00000\000Counts the number of issue slots per core cycle that were not consumed because of a full resource in the backend.  Including but not limited to resources such as the Re-order Buffer (ROB), reservation stations (RS), load/store buffers, physical registers, or any other needed machine resource that is currently unavailable.   Note that uops must be available for consumption in order for this event to fire.  If a uop is not available (Instruction Queue is empty), this event will not count\000 */
{ 1190157 }, /* ld_blocks.4k_alias\000\000pipeline\000Loads blocked because address has 4k partial address false dependence (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x4\000\00000\000Counts loads that block because their address modulo 4K matches a pending store (Must be precise)\000 */
{ 1192137 }, /* ld_blocks.all_block\000\000pipeline\000Loads blocked (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x10\000\00000\000Counts anytime a load that retires is blocked for any reason (Must be precise)\000 */
{ 1192823 }, /* ld_blocks.data_unknown\000\000pipeline\000Loads blocked due to store data not ready (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x1\000\00000\000Counts a load blocked from using a store forward, but did not occur because the store data was not available at the right time.  The forward might occur subsequently when the data is available (Must be precise)\000 */
{ 1199524 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to store forward restriction (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x2\000\00000\000Counts a load blocked from using a store forward because of an address/size mismatch, only one of the loads blocked from each store will be counted (Must be precise)\000 */
{ 1201138 }, /* ld_blocks.utlb_miss\000\000pipeline\000Loads blocked because address in not in the UTLB (Precise event capable) (Must be precise)\000event=0x3,period=200003,umask=0x8\000\00000\000Counts loads blocked because they are unable to find their physical address in the micro TLB (UTLB) (Must be precise)\000 */
{ 1287017 }, /* machine_clears.all\000\000pipeline\000All machine clears\000event=0xc3,period=20003\000\00000\000Counts machine clears for any reason\000 */
{ 1290432 }, /* machine_clears.disambiguation\000\000pipeline\000Machine clears due to memory disambiguation\000event=0xc3,period=20003,umask=0x8\000\00000\000Counts machine clears due to memory disambiguation.  Memory disambiguation happens when a load which has been issued conflicts with a previous unretired store in the pipeline whose address was not known at issue time, but is later resolved to be the same as the load address\000 */
{ 1298736 }, /* machine_clears.page_fault\000\000pipeline\000Machines clear due to a page fault\000event=0xc3,period=20003,umask=0x20\000\00000\000Counts the number of times that the machines clears due to a page fault. Covers both I-side and D-side(Loads/Stores) page faults. A page fault occurs when either page is not present, or an access violation\000 */
{ 1301116 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20003,umask=0x1\000\00000\000Counts the number of times that the processor detects that a program is writing to a code section and has to perform a machine clear because of that modification.  Self-modifying code (SMC) causes a severe penalty in all Intel(R) architecture processors\000 */
{ 6212995 }, /* uops_issued.any\000\000pipeline\000Uops issued to the back end per cycle\000event=0xe,period=200003\000\00000\000Counts uops issued by the front end and allocated into the back end of the machine.  This event counts uops that retire as well as uops that were speculatively executed but didn't retire. The sort of speculative uops that might be counted includes, but is not limited to those uops issued in the shadow of a miss-predicted branch, those uops that are inserted during an assist (such as for a denormal floating point result), and (previously allocated) uops that might be canceled during a machine clear\000 */
{ 6222895 }, /* uops_not_delivered.any\000\000pipeline\000Uops requested but not-delivered to the back-end per cycle\000event=0x9c,period=200003\000\00000\000This event used to measure front-end inefficiencies. I.e. when front-end of the machine is not delivering uops to the back-end and the back-end has is not stalled. This event can be used to identify if the machine is truly front-end bound.  When this event occurs, it is an indication that the front-end of the machine is operating at less than its theoretical peak performance. Background: We can think of the processor pipeline as being divided into 2 broader parts: Front-end and Back-end. Front-end is responsible for fetching the instruction, decoding into uops in machine understandable format and putting them into a uop queue to be consumed by back end. The back-end then takes these uops, allocates the required resources.  When all resources are ready, uops are executed. If the back-end is not ready to accept uops from the front-end, then we do not want to count these as front-end bottlenecks.  However, whenever we have bottlenecks in the back-end, we will have allocation unit stalls and eventually forcing the front-end to wait until the back-end is ready to receive more uops. This event counts only when back-end is requesting more uops and front-end is not able to provide them. When 3 uops are requested and no uops are delivered, the event counts 3. When 3 are requested, and only 1 is delivered, the event counts 2. When only 2 are delivered, the event counts 1. Alternatively stated, the event will not count if 3 uops are delivered, or if the back end is stalled and not requesting any uops at all.  Counts indicate missed opportunities for the front-end to deliver a uop to the back end. Some examples of conditions that cause front-end efficiencies are: ICache misses, ITLB misses, and decoder restrictions that limit the front-end bandwidth. Known Issues: Some uops require multiple allocation slots.  These uops will not be charged as a front end 'not delivered' opportunity, and will be regarded as a back end problem. For example, the INC instruction has one uop that requires 2 issue slots.  A stream of INC instructions will not count as UOPS_NOT_DELIVERED, even though only one instruction can be issued per clock.  The low uop issue rate for a stream of INC instructions is considered to be a back end issue\000 */
{ 6227872 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003\000\00000\000Counts uops which retired (Must be precise)\000 */
{ 6230450 }, /* uops_retired.idiv\000\000pipeline\000Integer divide uops retired (Precise Event Capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x10\000\00000\000Counts the number of integer divide uops retired (Must be precise)\000 */
{ 6231954 }, /* uops_retired.ms\000\000pipeline\000MS uops retired (Precise event capable) (Must be precise)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts uops retired that are from the complex flows issued by the micro-sequencer (MS).  Counts both the uops from a micro-coded instruction, and the uops that might be generated from a micro-coded assist (Must be precise)\000 */
{ 799573 }, /* dtlb_load_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to a demand load to a 1GB page\000event=0x8,period=200003,umask=0x8\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 1GB pages.  The page walks can end with or without a page fault\000 */
{ 801385 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand load to a 2M or 4M page\000event=0x8,period=200003,umask=0x4\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000 */
{ 804685 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand load to a 4K page\000event=0x8,period=200003,umask=0x2\000\00000\000Counts page walks completed due to demand data loads (including SW prefetches) whose address translations missed in all TLB levels and were mapped to 4K pages.  The page walks can end with or without a page fault\000 */
{ 808423 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to a demand load every cycle\000event=0x8,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to a load (demand data loads or SW prefetches). Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000 */
{ 821710 }, /* dtlb_store_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to a demand data store to a 1GB page\000event=0x49,period=2000003,umask=0x8\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 1GB pages.  The page walks can end with or without a page fault\000 */
{ 822438 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M or 4M page\000event=0x49,period=2000003,umask=0x4\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000 */
{ 825920 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=2000003,umask=0x2\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000 */
{ 830283 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to a demand data store every cycle\000event=0x49,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to a demand data store. Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000 */
{ 834568 }, /* ept.walk_pending\000\000virtual memory\000Page walks outstanding due to walking the EPT every cycle\000event=0x4f,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk only while traversing the Extended Page Table (EPT), and does not count during the rest of the translation.  The EPT is used for translating Guest-Physical Addresses to Physical Addresses for Virtual Machine Monitors (VMMs).  Average cycles per walk can be calculated by dividing the count by number of walks\000 */
{ 1078979 }, /* itlb.miss\000\000virtual memory\000ITLB misses\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) for a linear address of an instruction fetch.  It counts when new translation are filled into the ITLB.  The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000 */
{ 1090208 }, /* itlb_misses.walk_completed_1gb\000\000virtual memory\000Page walk completed due to an instruction fetch in a 1GB page\000event=0x85,period=2000003,umask=0x8\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 1GB pages.  The page walks can end with or without a page fault\000 */
{ 1092231 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to an instruction fetch in a 2M or 4M page\000event=0x85,period=2000003,umask=0x4\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 2M or 4M pages.  The page walks can end with or without a page fault\000 */
{ 1095022 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to an instruction fetch in a 4K page\000event=0x85,period=2000003,umask=0x2\000\00000\000Counts page walks completed due to instruction fetches whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000 */
{ 1098085 }, /* itlb_misses.walk_pending\000\000virtual memory\000Page walks outstanding due to an instruction fetch every cycle\000event=0x85,period=200003,umask=0x10\000\00000\000Counts once per cycle for each page walk occurring due to an instruction fetch. Includes cycles spent traversing the Extended Page Table (EPT). Average cycles per walk can be calculated by dividing by the number of walks\000 */
{ 1393914 }, /* mem_uops_retired.dtlb_miss\000\000virtual memory\000Memory uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x13\000\00000\000Counts uops retired that had a DTLB miss on load, store or either.  Note that when two distinct memory operations to the same page miss the DTLB, only one of them will be recorded as a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 1394767 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Load uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x11\000\00000\000Counts load uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 1395483 }, /* mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Store uops retired that missed the DTLB (Precise event capable)  Supports address when precise (Must be precise)\000event=0xd0,period=200003,umask=0x12\000\00000\000Counts store uops retired that caused a DTLB miss  Supports address when precise (Must be precise)\000 */
{ 2541796 }, /* tlb_flushes.stlb_any\000\000virtual memory\000STLB flushes\000event=0xbd,period=20003,umask=0x20\000\00000\000Counts STLB flushes.  The TLBs are flushed on instructions like INVLPG and MOV to CR3\000 */
};

static const struct compact_pmu_event pmu_events__grandridge[] = {
{ 1248632 }, /* longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1252437 }, /* longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1389448 }, /* mem_uops_retired.all_loads\000\000cache\000Counts the number of load ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000\000 */
{ 1392072 }, /* mem_uops_retired.all_stores\000\000cache\000Counts the number of store ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000\000 */
{ 1397475 }, /* mem_uops_retired.load_latency_gt_1024\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x400\000\00000\000\000 */
{ 1398098 }, /* mem_uops_retired.load_latency_gt_128\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000\000 */
{ 1400110 }, /* mem_uops_retired.load_latency_gt_16\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000\000 */
{ 1402114 }, /* mem_uops_retired.load_latency_gt_2048\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x800\000\00000\000\000 */
{ 1402737 }, /* mem_uops_retired.load_latency_gt_256\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000\000 */
{ 1404753 }, /* mem_uops_retired.load_latency_gt_32\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000\000 */
{ 1406757 }, /* mem_uops_retired.load_latency_gt_4\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000\000 */
{ 1408749 }, /* mem_uops_retired.load_latency_gt_512\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000\000 */
{ 1410765 }, /* mem_uops_retired.load_latency_gt_64\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000\000 */
{ 1412769 }, /* mem_uops_retired.load_latency_gt_8\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000\000 */
{ 1423686 }, /* mem_uops_retired.store_latency\000\000cache\000Counts the number of  stores uops retired same as MEM_UOPS_RETIRED.ALL_STORES  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x6\000\00000\000\000 */
{ 982859 }, /* icache.accesses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump\000event=0x80,period=200003,umask=0x3\000\00000\000\000 */
{ 988789 }, /* icache.misses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump and the instruction cache registers bytes are not present. -\000event=0x80,period=200003,umask=0x2\000\00000\000\000 */
{ 1559605 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1589226 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1572074 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 497910 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 538105 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 614004 }, /* cpu_clk_unhalted.core\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000 */
{ 615434 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.THREAD_P]\000event=0x3c,period=2000003\000\00000\000\000 */
{ 624035 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 634226 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 644590 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000 */
{ 646479 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.CORE_P]\000event=0x3c,period=2000003\000\00000\000\000 */
{ 1044654 }, /* inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1052065 }, /* inst_retired.any_p\000\000pipeline\000Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 2550658 }, /* topdown_bad_speculation.all\000\000pipeline\000Counts the number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window, including relevant microcode flows, and while uops are not yet available in the instruction queue (IQ) or until an FE_BOUND event occurs besides OTHER and CISC. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2557678 }, /* topdown_be_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to backend stalls\000event=0x74,period=1000003\000\00000\000\000 */
{ 2562399 }, /* topdown_fe_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to front end stalls\000event=0x71,period=1000003\000\00000\000\000 */
{ 2570690 }, /* topdown_retiring.all\000\000pipeline\000Counts the number of consumed retirement slots.  Similar to UOPS_RETIRED.ALL (Precise event)\000event=0x72,period=1000003\000\00000\000\000 */
{ 793957 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=1000003,umask=0xe\000\00000\000\000 */
{ 815976 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=1000003,umask=0xe\000\00000\000\000 */
{ 1086987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
};

static const struct compact_pmu_event pmu_events__graniterapids[] = {
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1157738 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read access L2 cache\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1251955 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1027935 }, /* idq_bubbles.core\000\000frontend\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations\000event=0x9c,period=1000003,umask=0x1\000\00000\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations.\nThe count may be distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Frontend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1384915 }, /* mem_trans_retired.store_sample\000\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise)\000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000 */
{ 1559769 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1589704 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FC00002\000\00000\000\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 1542449 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1564819 }, /* ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 1572300 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0002\000\00000\000\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 535230 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 624724 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 634728 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 1049915 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055337 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1199071 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x82\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 2543847 }, /* topdown.backend_bound_slots\000\000pipeline\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions\000event=0xa4,period=10000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions.\nThe count is distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Backend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6236335 }, /* uops_retired.slots\000\000pipeline\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric.\nSoftware can use this event as the numerator for the Retiring metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 795440 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 817717 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1086273 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
};

static const struct compact_pmu_event pmu_events__haswell[] = {
{ 1101984 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts when new data lines are brought into the L1 Data cache, which cause other lines to be evicted from the cache\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1108948 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113624 }, /* l1d_pend_miss.request_fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch. HWP are e\000event=0x48,period=2000003,umask=0x2\000\00000\000\000 */
{ 1123793 }, /* l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000Not rejected writebacks that hit L2 cache\000 */
{ 1128996 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines brought into the L2 cache.  Lines are filled into the L2 cache when there was an L2 miss\000 */
{ 1129766 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000L2 cache lines in E state filling L2\000 */
{ 1130314 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000L2 cache lines in I state filling L2\000 */
{ 1130762 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000L2 cache lines in S state filling L2\000 */
{ 1131913 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000Clean L2 cache lines evicted by demand\000 */
{ 1132547 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x6\000\00000\000Dirty L2 cache lines evicted by demand\000 */
{ 1157202 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts all L2 code requests\000 */
{ 1158036 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2  Spec update: HSD78, HSM80\000 */
{ 1159398 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000 */
{ 1160167 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000 */
{ 1161336 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts all L2 HW prefetcher requests\000 */
{ 1162073 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts all L2 store RFO requests\000 */
{ 1163439 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Number of instruction fetches that hit the L2 cache\000 */
{ 1164382 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Number of instruction fetches that missed the L2 cache\000 */
{ 1164849 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache  Spec update: HSD78, HSM80\000 */
{ 1166338 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x21\000\00000\000Demand data read requests that missed L2, no rejects  Spec update: HSD78, HSM80\000 */
{ 1168004 }, /* l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000 */
{ 1168378 }, /* l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000 */
{ 1169042 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that missed L2  Spec update: HSD78, HSM80\000 */
{ 1172281 }, /* l2_rqsts.references\000\000cache\000All L2 requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xff\000\00000\000All requests to L2 cache  Spec update: HSD78, HSM80\000 */
{ 1174210 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the number of store RFO requests that hit the L2 cache\000 */
{ 1174886 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000 */
{ 1179424 }, /* l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or L3 HW prefetch accessing L2, including rejects\000 */
{ 1180242 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000Transactions accessing L2 pipe\000 */
{ 1180474 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000L2 cache accesses when fetching instructions\000 */
{ 1181085 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand data read requests that access L2 cache\000 */
{ 1181568 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000L1D writebacks that access L2 cache\000 */
{ 1181956 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000L2 fill requests that access L2 cache\000 */
{ 1182496 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000L2 writebacks that access L2 cache\000 */
{ 1183040 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000RFO requests that access L2 cache\000 */
{ 1245510 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000Cycles in which the L1D is locked\000 */
{ 1247614 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000 */
{ 1251340 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000 */
{ 1342123 }, /* mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000 */
{ 1342796 }, /* mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000 */
{ 1343484 }, /* mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1344174 }, /* mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1344834 }, /* mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x1\000\00000\000This event counts retired load uops where the data came from local DRAM. This does not include hardware prefetches  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000 */
{ 1354341 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357455 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1359015 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Retired load uops missed L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000 */
{ 1360498 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1362258 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load uops missed L2. Unknown data source excluded  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1363536 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Retired load uops with L3 cache hits as data sources  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000 */
{ 1364544 }, /* mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x20\000\00000\000Retired load uops missed L3. Excludes unknown data source   Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000 */
{ 1390417 }, /* mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1392708 }, /* mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1415806 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x21\000\00000\000\000 */
{ 1418202 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000 */
{ 1419973 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000 */
{ 1421987 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423058 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745197 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Data read requests sent to uncore (demand and prefetch)\000 */
{ 1749028 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000 */
{ 1749517 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore  Spec update: HSD78, HSM80\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore  Spec update: HSD78, HSM80\000 */
{ 1751349 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Demand RFO read requests sent to uncore, including regular RFOs, locks, ItoM\000 */
{ 1754228 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1755531 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 1758525 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1763101 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1767037 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1771356 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand code Read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 1773759 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding demand data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000 */
{ 1775887 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777120 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 2460294 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000 */
{ 1780977 }, /* offcore_response.all_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0244\000\00000\000\000 */
{ 1785776 }, /* offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000 */
{ 1786545 }, /* offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000 */
{ 1867644 }, /* offcore_response.all_reads.l3_hit.hit_other_core_no_fwd\000\000cache\000hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000 */
{ 1868075 }, /* offcore_response.all_reads.l3_hit.hitm_other_core\000\000cache\000hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000 */
{ 1888834 }, /* offcore_response.all_requests.l3_hit.any_response\000\000cache\000Counts all requests hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8FFF\000\00000\000\000 */
{ 1890981 }, /* offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1891722 }, /* offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 2035865 }, /* offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 2036624 }, /* offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 2089775 }, /* offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 2090526 }, /* offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 2148553 }, /* offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 2149312 }, /* offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2293701 }, /* offcore_response.pf_l2_code_rd.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000 */
{ 2307690 }, /* offcore_response.pf_l2_data_rd.l3_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000 */
{ 2344300 }, /* offcore_response.pf_l2_rfo.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000 */
{ 2370529 }, /* offcore_response.pf_l3_code_rd.l3_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000 */
{ 2376139 }, /* offcore_response.pf_l3_data_rd.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000 */
{ 2400320 }, /* offcore_response.pf_l3_rfo.l3_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 473122 }, /* avx_insts.all\000\000floating point\000Approximate counts of AVX & AVX2 256-bit instructions, including non-arithmetic instructions, loads, and stores.  May count non-AVX instructions that employ 256-bit operations, including (but not necessarily limited to) rep string instructions that use 256-bit loads and stores for optimized performance, XSAVE* and XRSTOR*, and operations that transition the x87 FPU data registers between x87 and MMX\000event=0xc6,period=2000003,umask=0x7\000\00000\000Note that a whole rep string only counts AVX_INST.ALL once\000 */
{ 902045 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Cycles with any input/output SSE* or FP assists\000 */
{ 903110 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000Number of SIMD FP assists due to input values\000 */
{ 903734 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000Number of SIMD FP assists due to output values\000 */
{ 904406 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000Number of X87 FP assists due to input values\000 */
{ 904994 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000Number of X87 FP assists due to output values\000 */
{ 1433558 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000Number of SIMD move elimination candidate uops that were eliminated\000 */
{ 1433941 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000Number of SIMD move elimination candidate uops that were not eliminated\000 */
{ 2463440 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x8\000\00000\000\000 */
{ 2464189 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 476800 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000Number of front end re-steers due to BPU misprediction\000 */
{ 785781 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000\000 */
{ 986835 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000\000 */
{ 988022 }, /* icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000 */
{ 988163 }, /* icache.ifetch_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000 */
{ 990419 }, /* icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts Instruction Cache (ICACHE) misses\000 */
{ 998281 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered four uops. Set Cmask = 4\000 */
{ 999346 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered at least one uops. Set Cmask = 1\000 */
{ 1000024 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered four uops. Set Cmask = 4\000 */
{ 1001077 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uop. Set Cmask = 1\000 */
{ 1003345 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1006574 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Increment each cycle. # of uops delivered to IDQ from DSB path. Set Cmask = 1 to count cycles\000 */
{ 1007587 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles  Spec update: HSD135\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty  Spec update: HSD135\000 */
{ 1008434 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000Number of uops delivered to IDQ from any path\000 */
{ 1010000 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1012620 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Increment each cycle # of uops delivered to IDQ from MITE path. Set Cmask = 1 to count cycles\000 */
{ 1014378 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the Front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000 */
{ 1019000 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020351 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020890 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000 */
{ 1022589 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026444 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts uops delivered by the Front-end with the assistance of the microcode sequencer.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000 */
{ 1030271 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event count the number of undelivered (unallocated) uops from the Front-end to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled. The Front-end can allocate up to 4 uops per cycle so this event can increment 0-4 times per cycle depending on the number of unallocated uops. This event is counted on a per-core basis  Spec update: HSD135\000 */
{ 1033781 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts the number cycles during which the Front-end allocated exactly zero uops to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled.  This event is counted on a per-core basis  Spec update: HSD135\000 */
{ 1036552 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE  Spec update: HSD135\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038031 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039319 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039890 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 971064 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000\000 */
{ 972901 }, /* hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000 */
{ 973286 }, /* hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000 */
{ 973640 }, /* hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000 */
{ 973792 }, /* hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc8,period=2000003,umask=0x40\000\00000\000\000 */
{ 974404 }, /* hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000 */
{ 975867 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000\000 */
{ 976369 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1295253 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering machine clears detected. Memory ordering machine clears can result from memory address aliasing or snoops from another hardware thread or core to data inflight in the pipeline.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1370248 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000 */
{ 1372189 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000 */
{ 1374134 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000 */
{ 1376079 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x20\000\00000\000\000 */
{ 1378012 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000 */
{ 1379952 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000 */
{ 1381889 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000 */
{ 1383814 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000 */
{ 1428398 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000Speculative cache-line split load uops dispatched to L1D\000 */
{ 1430573 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split store-address uops dispatched to L1D\000 */
{ 1781246 }, /* offcore_response.all_code_rd.l3_miss.any_response\000\000memory\000Counts all demand & prefetch code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00244\000\00000\000\000 */
{ 1781424 }, /* offcore_response.all_code_rd.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400244\000\00000\000\000 */
{ 1795425 }, /* offcore_response.all_data_rd.l3_miss.any_response\000\000memory\000Counts all demand & prefetch data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00091\000\00000\000\000 */
{ 1796631 }, /* offcore_response.all_data_rd.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400091\000\00000\000\000 */
{ 1874845 }, /* offcore_response.all_reads.l3_miss.any_response\000\000memory\000miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC007F7\000\00000\000\000 */
{ 1875813 }, /* offcore_response.all_reads.l3_miss.local_dram\000\000memory\000miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004007F7\000\00000\000\000 */
{ 1888990 }, /* offcore_response.all_requests.l3_miss.any_response\000\000memory\000Counts all requests miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC08FFF\000\00000\000\000 */
{ 1900240 }, /* offcore_response.all_rfo.l3_miss.any_response\000\000memory\000Counts all demand & prefetch RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00122\000\00000\000\000 */
{ 1901394 }, /* offcore_response.all_rfo.l3_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400122\000\00000\000\000 */
{ 2050390 }, /* offcore_response.demand_code_rd.l3_miss.any_response\000\000memory\000Counts all demand code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00004\000\00000\000\000 */
{ 2051756 }, /* offcore_response.demand_code_rd.l3_miss.local_dram\000\000memory\000Counts all demand code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000 */
{ 2104132 }, /* offcore_response.demand_data_rd.l3_miss.any_response\000\000memory\000Counts demand data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00001\000\00000\000\000 */
{ 2105486 }, /* offcore_response.demand_data_rd.l3_miss.local_dram\000\000memory\000Counts demand data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000 */
{ 2162966 }, /* offcore_response.demand_rfo.l3_miss.any_response\000\000memory\000Counts all demand data writes (RFOs) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00002\000\00000\000\000 */
{ 2164312 }, /* offcore_response.demand_rfo.l3_miss.local_dram\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000 */
{ 2295184 }, /* offcore_response.pf_l2_code_rd.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00040\000\00000\000\000 */
{ 2318022 }, /* offcore_response.pf_l2_data_rd.l3_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00010\000\00000\000\000 */
{ 2354264 }, /* offcore_response.pf_l2_rfo.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00020\000\00000\000\000 */
{ 2371980 }, /* offcore_response.pf_l3_code_rd.l3_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00200\000\00000\000\000 */
{ 2386591 }, /* offcore_response.pf_l3_data_rd.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00080\000\00000\000\000 */
{ 2410356 }, /* offcore_response.pf_l3_rfo.l3_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00100\000\00000\000\000 */
{ 2515026 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000\000 */
{ 2517278 }, /* rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2517816 }, /* rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000 */
{ 2518214 }, /* rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000\000 */
{ 2518366 }, /* rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc9,period=2000003,umask=0x40\000\00000\000\000 */
{ 2518979 }, /* rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2520341 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000\000 */
{ 2520843 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2572206 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000\000 */
{ 2572916 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000\000 */
{ 2573515 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000\000 */
{ 2573943 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000 */
{ 2574898 }, /* tx_mem.abort_capacity_write\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000 */
{ 2576049 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000\000 */
{ 2577184 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000\000 */
{ 2578235 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000\000 */
{ 2579387 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000\000 */
{ 2580241 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000\000 */
{ 2581166 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000\000 */
{ 581329 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000Unhalted core cycles when the thread is in ring 0\000 */
{ 581608 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 582577 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000Unhalted core cycles when the thread is not in ring 0\000 */
{ 1245992 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000Cycles in which the L1D and L2 are locked, due to a UC lock or split lock\000 */
{ 468877 }, /* arith.divider_uops\000\000pipeline\000Any uop executed by the Divider. (This includes all divide uops, sqrt, ...)\000event=0x14,period=2000003,umask=0x2\000\00000\000\000 */
{ 487693 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 488587 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000\000 */
{ 489261 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000\000 */
{ 489802 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000\000 */
{ 490448 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 492202 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000\000 */
{ 492945 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000\000 */
{ 493664 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000\000 */
{ 494226 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000\000 */
{ 494883 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000\000 */
{ 495474 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000\000 */
{ 496089 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000\000 */
{ 496446 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000Branch instructions at retirement\000 */
{ 499640 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 505568 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts the number of conditional branch instructions retired (Precise event)\000 */
{ 508475 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100003,umask=0x40\000\00000\000Number of far branches retired\000 */
{ 515076 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000 */
{ 516527 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000 */
{ 517737 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x8\000\00000\000Counts the number of near return instructions retired (Precise event)\000 */
{ 519347 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Number of near taken branches retired (Precise event)\000 */
{ 522269 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts the number of not taken branch instructions retired\000 */
{ 528685 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 529734 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000\000 */
{ 530485 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532301 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000\000 */
{ 533148 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000\000 */
{ 534014 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 535066 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000\000 */
{ 536772 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Mispredicted branch instructions at retirement\000 */
{ 541027 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This event counts all mispredicted branch instructions retired. This is a precise event (Must be precise)\000 */
{ 546808 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 556063 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were taken but mispredicted (Precise event)\000 */
{ 607340 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 607646 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000 */
{ 608668 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000 */
{ 618202 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 631463 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state\000 */
{ 638697 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000 */
{ 639446 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000 */
{ 642877 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647330 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 749644 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 data cache miss loads. Set Cmask=8 to count cycle\000 */
{ 750997 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads  Spec update: HSD78, HSM63, HSM80\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set Cmask=2 to count cycle  Spec update: HSD78, HSM63, HSM80\000 */
{ 752706 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set Cmask=2 to count cycle\000 */
{ 753986 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline\000 */
{ 755301 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls due to L1 data cache misses\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Execution stalls due to L1 data cache miss loads. Set Cmask=0CH\000 */
{ 756776 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses  Spec update: HSM63, HSM80\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2  Spec update: HSM63, HSM80\000 */
{ 758023 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline and there were memory instructions pending (waiting for data)\000 */
{ 1040675 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000Stall cycles due to IQ is full\000 */
{ 1042207 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts cycles where the decoder is stalled on an instruction with a length changing prefix (LCP)\000 */
{ 1047242 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution  Spec update: HSD140, HSD143\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. INST_RETIRED.ANY is counted by a designated fixed counter, leaving the programmable counters available for other events. Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions  Spec update: HSD140, HSD143\000 */
{ 1054493 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: HSD11, HSD140\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement  Spec update: HSD11, HSD140\000 */
{ 1059440 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000 */
{ 1064102 }, /* inst_retired.x87\000\000pipeline\000FP operations retired. X87 FP operations that have no exceptions: Counts also flows that have several X87 or flows that use X87 uops in the exception handling\000event=0xc0,period=2000003,umask=0x2\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000 */
{ 1068591 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000This event counts the number of cycles spent waiting for a recovery after an event such as a processor nuke, JEClear, assist, hle/rtm abort etc\000 */
{ 1070848 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000 */
{ 1194460 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1199851 }, /* ld_blocks.store_forward\000\000pipeline\000loads blocked by overlapping with store buffer that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store. The penalty for blocked store forwarding is that the load must wait for the store to write its value to the cache before it can be issued\000 */
{ 1201654 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline which can have a performance impact\000 */
{ 1229109 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for H/W prefetch\000 */
{ 1230225 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for S/W prefetch\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286187 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered by the LSD\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1289676 }, /* machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1293637 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000\000 */
{ 1301984 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event is incremented when self-modifying code (SMC) is detected, which causes a machine clear.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1432782 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000Number of integer move elimination candidate uops that were eliminated\000 */
{ 1433160 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000Number of integer move elimination candidate uops that were not eliminated\000 */
{ 2462107 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000Number of microcode assists invoked by HW upon uop writeback\000 */
{ 2501165 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles  Spec update: HSD135\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles allocation is stalled due to resource related reason  Spec update: HSD135\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2505112 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts cycles during which no instructions were allocated because no Store Buffers (SB) were available\000 */
{ 2507281 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000Count cases of saving new LBR records by hardware\000 */
{ 2511687 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles when the Reservation Station ( RS ) is empty for the thread. The RS is a structure that buffers allocated micro-ops from the Front-end. If there are many cycles when the RS is empty, it may represent an underflow of instructions delivered from the Front-end\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6184529 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6185811 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6187117 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6188415 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6189739 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6191028 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6192009 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6192656 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6192787 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core  Spec update: HSD30, HSM31\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle  Spec update: HSD30, HSM31\000 */
{ 6193959 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195058 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196161 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197264 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198367 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200405 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least one uop was executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6201464 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least two uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6202535 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least three uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6203608 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 6205150 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207998 }, /* uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a uop is dispatched on port 0 in this thread\000 */
{ 6208438 }, /* uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6208575 }, /* uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a uop is dispatched on port 1 in this thread\000 */
{ 6209015 }, /* uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6209152 }, /* uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Cycles which a uop is dispatched on port 2 in this thread\000 */
{ 6209592 }, /* uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6209731 }, /* uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Cycles which a uop is dispatched on port 3 in this thread\000 */
{ 6210171 }, /* uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6210310 }, /* uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Cycles which a uop is dispatched on port 4 in this thread\000 */
{ 6210752 }, /* uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6210890 }, /* uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Cycles which a uop is dispatched on port 5 in this thread\000 */
{ 6211332 }, /* uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6211470 }, /* uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a uop is dispatched on port 6 in this thread\000 */
{ 6211912 }, /* uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6212050 }, /* uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a uop is dispatched on port 7 in this thread\000 */
{ 6212492 }, /* uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6215075 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of uops issued by the Front-end of the pipeline to the Back-end. This event is counted at the allocation stage and will count both retired and non-retired uops\000 */
{ 6216475 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6216941 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops add delay\000 */
{ 6217712 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000Number of multiply packed/scalar single precision uops allocated\000 */
{ 6218455 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (for example, 2 sources + immediate) regardless of whether it is a result of LEA instruction or not\000 */
{ 6220517 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6225390 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of micro-ops retired. Use Cmask=1 and invert to count active cycles or stalled cycles (Precise event)\000 */
{ 6228028 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6234678 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 uops or 4 instructions could retire each cycle (Precise event)\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240433 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 2784864 }, /* unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000\000 */
{ 2785265 }, /* unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000\000 */
{ 2785660 }, /* unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000\000 */
{ 2786064 }, /* unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000\000 */
{ 2786235 }, /* unc_cbo_cache_lookup.extsnp_es\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x46\000\00001\000\000 */
{ 2786420 }, /* unc_cbo_cache_lookup.extsnp_i\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x48\000\00001\000\000 */
{ 2786599 }, /* unc_cbo_cache_lookup.extsnp_m\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000\000 */
{ 2786778 }, /* unc_cbo_cache_lookup.extsnp_mesi\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x4f\000\00001\000\000 */
{ 2787207 }, /* unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000\000 */
{ 2787613 }, /* unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000\000 */
{ 2788013 }, /* unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000\000 */
{ 2788430 }, /* unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000\000 */
{ 2788854 }, /* unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000\000 */
{ 2789029 }, /* unc_cbo_cache_lookup.write_i\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x28\000\00001\000\000 */
{ 2789434 }, /* unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000\000 */
{ 2789848 }, /* unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000\000 */
{ 2790023 }, /* unc_cbo_xsnp_response.hit_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x84\000\00001\000\000 */
{ 2790229 }, /* unc_cbo_xsnp_response.hit_external\000uncore_cbox\000uncore cache\000An external snoop hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x24\000\00001\000\000 */
{ 2790402 }, /* unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000 */
{ 2790639 }, /* unc_cbo_xsnp_response.hitm_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x88\000\00001\000\000 */
{ 2790842 }, /* unc_cbo_xsnp_response.hitm_external\000uncore_cbox\000uncore cache\000An external snoop hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x28\000\00001\000\000 */
{ 2791012 }, /* unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000 */
{ 2791246 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000 */
{ 2791698 }, /* unc_cbo_xsnp_response.miss_external\000uncore_cbox\000uncore cache\000An external snoop misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x21\000\00001\000\000 */
{ 2791854 }, /* unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000 */
{ 2581686 }, /* unc_arb_coh_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle count number of valid entries in Coherency Tracker queue from allocation till deallocation. Aperture requests (snoops) appear as NC decoded internally and become coherent (snoop L3, access memory). Unit: uncore_arb \000event=0x83,umask=0x1\000\00001\000Each cycle count number of valid entries in Coherency Tracker queue from allocation till deallocation. Aperture requests (snoops) appear as NC decoded internally and become coherent (snoop L3, access memory)\000 */
{ 2582380 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop, Core aperture, etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2585861 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all Core outgoing valid entries. Such entry is defined as valid from its allocation till first of IDI0 or DRS0 messages is sent out. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2587471 }, /* unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000 */
{ 2589836 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of Core outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591875 }, /* unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Number of Writes allocated - any write transactions: full/partials writes and evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000 */
{ 3540559 }, /* unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 788623 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Misses in all TLB levels that cause a page walk of any page size\000 */
{ 789155 }, /* dtlb_load_misses.pde_cache_miss\000\000virtual memory\000DTLB demand load misses with low part of linear-to-physical address translation missed\000event=0x8,period=100003,umask=0x80\000\00000\000DTLB demand load misses with low part of linear-to-physical address translation missed\000 */
{ 790505 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000Number of cache load STLB hits. No page walk\000 */
{ 792032 }, /* dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000This event counts load operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 792438 }, /* dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000This event counts load operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 795162 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0xe\000\00000\000Completed page walks in any TLB of any page size due to demand load misses\000 */
{ 798011 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)\000event=0x8,period=2000003,umask=0x8\000\00000\000\000 */
{ 800737 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)\000event=0x8,period=2000003,umask=0x4\000\00000\000Completed page walks due to demand load misses that caused 2M/4M page walks in any TLB levels\000 */
{ 804055 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)\000event=0x8,period=2000003,umask=0x2\000\00000\000Completed page walks due to demand load misses that caused 4K page walks in any TLB levels\000 */
{ 806459 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000 */
{ 810986 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Miss in all TLB levels causes a page walk of any page size (4K/2M/4M/1G)\000 */
{ 811536 }, /* dtlb_store_misses.pde_cache_miss\000\000virtual memory\000DTLB store misses with low part of linear-to-physical address translation missed\000event=0x49,period=100003,umask=0x80\000\00000\000DTLB store misses with low part of linear-to-physical address translation missed\000 */
{ 812500 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000 */
{ 814069 }, /* dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000This event counts store operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 814480 }, /* dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000This event counts store operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 817477 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0xe\000\00000\000Completed page walks due to store miss in any TLB levels of any page size (4K/2M/4M/1G)\000 */
{ 821175 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks. (1G)\000event=0x49,period=100003,umask=0x8\000\00000\000\000 */
{ 824557 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)\000event=0x49,period=100003,umask=0x4\000\00000\000Completed page walks due to store misses in one or more TLB levels of 2M/4M page structure\000 */
{ 827627 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)\000event=0x49,period=100003,umask=0x2\000\00000\000Completed page walks due to store misses in one or more TLB levels of 4K page structure\000 */
{ 828492 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB store misses\000 */
{ 833618 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1077852 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100003,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000 */
{ 1081206 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in ITLB that causes a page walk of any page size\000 */
{ 1083416 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000ITLB misses that hit STLB. No page walk\000 */
{ 1084367 }, /* itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000ITLB misses that hit STLB (2M)\000 */
{ 1084667 }, /* itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000ITLB misses that hit STLB (4K)\000 */
{ 1087987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0xe\000\00000\000Completed page walks in ITLB of any page size\000 */
{ 1090053 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000\000 */
{ 1091248 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Completed page walks due to misses in ITLB 2M/4M page entries\000 */
{ 1094072 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Completed page walks due to misses in ITLB 4K page entries\000 */
{ 1096069 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by ITLB misses\000 */
{ 2468196 }, /* page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x11\000\00000\000Number of DTLB page walker loads that hit in the L1+FB\000 */
{ 2468532 }, /* page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x12\000\00000\000Number of DTLB page walker loads that hit in the L2\000 */
{ 2468869 }, /* page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x14\000\00000\000Number of DTLB page walker loads that hit in the L3  Spec update: HSD25\000 */
{ 2469250 }, /* page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x18\000\00000\000Number of DTLB page walker loads from memory  Spec update: HSD25\000 */
{ 2469464 }, /* page_walker_loads.ept_dtlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x41\000\00000\000\000 */
{ 2469639 }, /* page_walker_loads.ept_dtlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L2\000event=0xbc,period=2000003,umask=0x42\000\00000\000\000 */
{ 2469807 }, /* page_walker_loads.ept_dtlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L3\000event=0xbc,period=2000003,umask=0x44\000\00000\000\000 */
{ 2469975 }, /* page_walker_loads.ept_dtlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in memory\000event=0xbc,period=2000003,umask=0x48\000\00000\000\000 */
{ 2470147 }, /* page_walker_loads.ept_itlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x81\000\00000\000\000 */
{ 2470322 }, /* page_walker_loads.ept_itlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x82\000\00000\000\000 */
{ 2470490 }, /* page_walker_loads.ept_itlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x84\000\00000\000\000 */
{ 2470658 }, /* page_walker_loads.ept_itlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in memory\000event=0xbc,period=2000003,umask=0x88\000\00000\000\000 */
{ 2470986 }, /* page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x21\000\00000\000Number of ITLB page walker loads that hit in the L1+FB\000 */
{ 2471322 }, /* page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x22\000\00000\000Number of ITLB page walker loads that hit in the L2\000 */
{ 2471659 }, /* page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x24\000\00000\000Number of ITLB page walker loads that hit in the L3  Spec update: HSD25\000 */
{ 2471883 }, /* page_walker_loads.itlb_memory\000\000virtual memory\000Number of ITLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x28\000\00000\000Number of ITLB page walker loads from memory  Spec update: HSD25\000 */
{ 2540134 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100003,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000 */
{ 2541032 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100003,umask=0x20\000\00000\000Count number of STLB flush attempts\000 */
};

static const struct compact_pmu_event pmu_metrics__haswell[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51523 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 91007 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 103058 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 115591 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\00010 * ARITH.DIVIDER_UOPS / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 119617 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 131664 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 140197 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 150087 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 156284 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.REQUEST_FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194575 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 223135 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000(UOPS_EXECUTED.CORE / 2 / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@) if #SMT_on else UOPS_EXECUTED.CORE / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@))\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248732 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 253557 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257611 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267776 }, /* \000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000 */
{ 271339 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 281782 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 287936 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) - CYCLE_ACTIVITY.STALLS_L1D_PENDING) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 290473 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_PENDING - CYCLE_ACTIVITY.STALLS_L2_PENDING) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 296272 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 302819 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.L3_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 316428 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 335504 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 341091 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379797 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382600 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 387139 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390181 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 397341 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 401522 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 407482 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 414085 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418848 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 442148 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 462490 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__haswellx[] = {
{ 1101984 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts when new data lines are brought into the L1 Data cache, which cause other lines to be evicted from the cache\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1108948 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113624 }, /* l1d_pend_miss.request_fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch. HWP are e\000event=0x48,period=2000003,umask=0x2\000\00000\000\000 */
{ 1123793 }, /* l2_demand_rqsts.wb_hit\000\000cache\000Not rejected writebacks that hit L2 cache\000event=0x27,period=200003,umask=0x50\000\00000\000Not rejected writebacks that hit L2 cache\000 */
{ 1128996 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines brought into the L2 cache.  Lines are filled into the L2 cache when there was an L2 miss\000 */
{ 1129766 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000L2 cache lines in E state filling L2\000 */
{ 1130314 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000L2 cache lines in I state filling L2\000 */
{ 1130762 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000L2 cache lines in S state filling L2\000 */
{ 1131913 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x5\000\00000\000Clean L2 cache lines evicted by demand\000 */
{ 1132547 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x6\000\00000\000Dirty L2 cache lines evicted by demand\000 */
{ 1157202 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts all L2 code requests\000 */
{ 1158036 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2  Spec update: HSD78, HSM80\000 */
{ 1159398 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache  Spec update: HSD78, HSM80\000 */
{ 1160167 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache  Spec update: HSD78, HSM80\000 */
{ 1161336 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts all L2 HW prefetcher requests\000 */
{ 1162073 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts all L2 store RFO requests\000 */
{ 1163439 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Number of instruction fetches that hit the L2 cache\000 */
{ 1164382 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Number of instruction fetches that missed the L2 cache\000 */
{ 1164849 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache  Spec update: HSD78, HSM80\000 */
{ 1166338 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x21\000\00000\000Demand data read requests that missed L2, no rejects  Spec update: HSD78, HSM80\000 */
{ 1168004 }, /* l2_rqsts.l2_pf_hit\000\000cache\000L2 prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xd0\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000 */
{ 1168378 }, /* l2_rqsts.l2_pf_miss\000\000cache\000L2 prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000 */
{ 1169042 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that missed L2  Spec update: HSD78, HSM80\000 */
{ 1172281 }, /* l2_rqsts.references\000\000cache\000All L2 requests  Spec update: HSD78, HSM80\000event=0x24,period=200003,umask=0xff\000\00000\000All requests to L2 cache  Spec update: HSD78, HSM80\000 */
{ 1174210 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the number of store RFO requests that hit the L2 cache\000 */
{ 1174886 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000 */
{ 1179424 }, /* l2_trans.all_pf\000\000cache\000L2 or L3 HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or L3 HW prefetch accessing L2, including rejects\000 */
{ 1180242 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000Transactions accessing L2 pipe\000 */
{ 1180474 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000L2 cache accesses when fetching instructions\000 */
{ 1181085 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand data read requests that access L2 cache\000 */
{ 1181568 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000L1D writebacks that access L2 cache\000 */
{ 1181956 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000L2 fill requests that access L2 cache\000 */
{ 1182496 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000L2 writebacks that access L2 cache\000 */
{ 1183040 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000RFO requests that access L2 cache\000 */
{ 1245510 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000Cycles in which the L1D is locked\000 */
{ 1247614 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000 */
{ 1251340 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000 */
{ 1342123 }, /* mem_load_uops_l3_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000 */
{ 1342796 }, /* mem_load_uops_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared L3  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000 */
{ 1343484 }, /* mem_load_uops_l3_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise.  Spec update: HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1344174 }, /* mem_load_uops_l3_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1344834 }, /* mem_load_uops_l3_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x1\000\00000\000This event counts retired load uops where the data came from local DRAM. This does not include hardware prefetches  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM30 (Precise event)\000 */
{ 1345534 }, /* mem_load_uops_l3_miss_retired.remote_dram\000\000cache\000Retired load uop whose Data Source was: remote DRAM either Snoop not needed or Snoop Miss (RspI)  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x4\000\00000\000\000 */
{ 1346020 }, /* mem_load_uops_l3_miss_retired.remote_fwd\000\000cache\000Retired load uop whose Data Source was: forwarded from remote cache  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x20\000\00000\000\000 */
{ 1346461 }, /* mem_load_uops_l3_miss_retired.remote_hitm\000\000cache\000Retired load uop whose Data Source was: Remote cache HITM  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd3,period=100003,umask=0x10\000\00000\000\000 */
{ 1354341 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357455 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1359015 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops misses in L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Retired load uops missed L1 cache as data sources  Supports address when precise.  Spec update: HSM30 (Precise event)\000 */
{ 1360498 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1362258 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Miss in mid-level (L2) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load uops missed L2. Unknown data source excluded  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1363536 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Retired load uops which data sources were data hits in L3 without snoops required  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Retired load uops with L3 cache hits as data sources  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000 */
{ 1364544 }, /* mem_load_uops_retired.l3_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source  Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000event=0xd1,period=100003,umask=0x20\000\00000\000Retired load uops missed L3. Excludes unknown data source   Supports address when precise.  Spec update: HSD74, HSD29, HSD25, HSM26, HSM30 (Precise event)\000 */
{ 1390417 }, /* mem_uops_retired.all_loads\000\000cache\000Retired load uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load uops. This event accounts for SW prefetch uops of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1392708 }, /* mem_uops_retired.all_stores\000\000cache\000Retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store uops  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000 */
{ 1415806 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access  Supports address when precise.  Spec update: HSD76, HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x21\000\00000\000\000 */
{ 1418202 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000 */
{ 1419973 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000 */
{ 1421987 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423058 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB  Supports address when precise.  Spec update: HSD29, HSM30 (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745197 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Data read requests sent to uncore (demand and prefetch)\000 */
{ 1749028 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000 */
{ 1749517 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore  Spec update: HSD78, HSM80\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore  Spec update: HSD78, HSM80\000 */
{ 1751349 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Demand RFO read requests sent to uncore, including regular RFOs, locks, ItoM\000 */
{ 1754228 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1755531 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 1758525 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1763101 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1767037 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1771356 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand code Read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 1773759 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding demand data read transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000 */
{ 1775887 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue  Spec update: HSD78, HSD62, HSD61, HSM63, HSM80\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777120 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore  Spec update: HSD62, HSD61, HSM63\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles  Spec update: HSD62, HSD61, HSM63\000 */
{ 2460294 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000\000 */
{ 1781819 }, /* offcore_response.all_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0244\000\00000\000\000 */
{ 1804906 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0091\000\00000\000\000 */
{ 1805448 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0091\000\00000\000\000 */
{ 1880911 }, /* offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C07F7\000\00000\000\000 */
{ 1881756 }, /* offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C07F7\000\00000\000\000 */
{ 1889149 }, /* offcore_response.all_requests.llc_hit.any_response\000\000cache\000Counts all requests hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C8FFF\000\00000\000\000 */
{ 1909321 }, /* offcore_response.all_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1909843 }, /* offcore_response.all_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 2062698 }, /* offcore_response.demand_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 2063224 }, /* offcore_response.demand_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts all demand code reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 2116292 }, /* offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 2116814 }, /* offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 2175398 }, /* offcore_response.demand_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 2175932 }, /* offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2297702 }, /* offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0040\000\00000\000\000 */
{ 2327641 }, /* offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000 */
{ 2363376 }, /* offcore_response.pf_l2_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000 */
{ 2423919 }, /* offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) code reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0200\000\00000\000\000 */
{ 2425936 }, /* offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000 */
{ 2428628 }, /* offcore_response.pf_llc_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 473122 }, /* avx_insts.all\000\000floating point\000Approximate counts of AVX & AVX2 256-bit instructions, including non-arithmetic instructions, loads, and stores.  May count non-AVX instructions that employ 256-bit operations, including (but not necessarily limited to) rep string instructions that use 256-bit loads and stores for optimized performance, XSAVE* and XRSTOR*, and operations that transition the x87 FPU data registers between x87 and MMX\000event=0xc6,period=2000003,umask=0x7\000\00000\000Note that a whole rep string only counts AVX_INST.ALL once\000 */
{ 902045 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Cycles with any input/output SSE* or FP assists\000 */
{ 903110 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000Number of SIMD FP assists due to input values\000 */
{ 903734 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000Number of SIMD FP assists due to output values\000 */
{ 904406 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000Number of X87 FP assists due to input values\000 */
{ 904994 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000Number of X87 FP assists due to output values\000 */
{ 1433558 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000Number of SIMD move elimination candidate uops that were eliminated\000 */
{ 1433941 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000Number of SIMD move elimination candidate uops that were not eliminated\000 */
{ 2463440 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x8\000\00000\000\000 */
{ 2464189 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable  Spec update: HSD56, HSM57\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 476800 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000Number of front end re-steers due to BPU misprediction\000 */
{ 785781 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000\000 */
{ 986835 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000\000 */
{ 988022 }, /* icache.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000 */
{ 988163 }, /* icache.ifetch_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction-cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000\000 */
{ 990419 }, /* icache.misses\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts Instruction Cache (ICACHE) misses\000 */
{ 998281 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered four uops. Set Cmask = 4\000 */
{ 999346 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered at least one uops. Set Cmask = 1\000 */
{ 1000024 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered four uops. Set Cmask = 4\000 */
{ 1001077 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uop. Set Cmask = 1\000 */
{ 1003345 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1006574 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Increment each cycle. # of uops delivered to IDQ from DSB path. Set Cmask = 1 to count cycles\000 */
{ 1007587 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles  Spec update: HSD135\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty  Spec update: HSD135\000 */
{ 1008434 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000Number of uops delivered to IDQ from any path\000 */
{ 1010000 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1012620 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Increment each cycle # of uops delivered to IDQ from MITE path. Set Cmask = 1 to count cycles\000 */
{ 1014378 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the Front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000 */
{ 1019000 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020351 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020890 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000 */
{ 1022589 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026444 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000This event counts uops delivered by the Front-end with the assistance of the microcode sequencer.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance\000 */
{ 1030271 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,period=2000003,umask=0x1\000\00000\000This event count the number of undelivered (unallocated) uops from the Front-end to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled. The Front-end can allocate up to 4 uops per cycle so this event can increment 0-4 times per cycle depending on the number of unallocated uops. This event is counted on a per-core basis  Spec update: HSD135\000 */
{ 1033781 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000This event counts the number cycles during which the Front-end allocated exactly zero uops to the Resource Allocation Table (RAT) while the Back-end of the processor is not stalled.  This event is counted on a per-core basis  Spec update: HSD135\000 */
{ 1036552 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE  Spec update: HSD135\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038031 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled  Spec update: HSD135\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039319 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039890 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end  Spec update: HSD135\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 971064 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000\000 */
{ 972901 }, /* hle_retired.aborted_misc1\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000 */
{ 973286 }, /* hle_retired.aborted_misc2\000\000memory\000Number of times an HLE execution aborted due to uncommon conditions\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000 */
{ 973640 }, /* hle_retired.aborted_misc3\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000 */
{ 973792 }, /* hle_retired.aborted_misc4\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc8,period=2000003,umask=0x40\000\00000\000\000 */
{ 974404 }, /* hle_retired.aborted_misc5\000\000memory\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000Number of times an HLE execution aborted due to none of the previous 4 categories (e.g. interrupts)\000 */
{ 975867 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000\000 */
{ 976369 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1295253 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering machine clears detected. Memory ordering machine clears can result from memory address aliasing or snoops from another hardware thread or core to data inflight in the pipeline.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1370248 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Randomly selected loads with latency value being above 128  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000 */
{ 1372189 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Randomly selected loads with latency value being above 16  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000 */
{ 1374134 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Randomly selected loads with latency value being above 256  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000 */
{ 1376079 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Randomly selected loads with latency value being above 32  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x20\000\00000\000\000 */
{ 1378012 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Randomly selected loads with latency value being above 4  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000 */
{ 1379952 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Randomly selected loads with latency value being above 512  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000 */
{ 1381889 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Randomly selected loads with latency value being above 64  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000 */
{ 1383814 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Randomly selected loads with latency value being above 8  Supports address when precise.  Spec update: HSD76, HSD25, HSM26 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000 */
{ 1428398 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000Speculative cache-line split load uops dispatched to L1D\000 */
{ 1430573 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split store-address uops dispatched to L1D\000 */
{ 1782904 }, /* offcore_response.all_code_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00244\000\00000\000\000 */
{ 1783471 }, /* offcore_response.all_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400244\000\00000\000\000 */
{ 1806759 }, /* offcore_response.all_data_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00091\000\00000\000\000 */
{ 1807326 }, /* offcore_response.all_data_rd.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400091\000\00000\000\000 */
{ 1807970 }, /* offcore_response.all_data_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63F800091\000\00000\000\000 */
{ 1808186 }, /* offcore_response.all_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00091\000\00000\000\000 */
{ 1808664 }, /* offcore_response.all_data_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand & prefetch data reads miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00091\000\00000\000\000 */
{ 1883723 }, /* offcore_response.all_reads.llc_miss.any_response\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC007F7\000\00000\000\000 */
{ 1884316 }, /* offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004007F7\000\00000\000\000 */
{ 1885214 }, /* offcore_response.all_reads.llc_miss.remote_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63F8007F7\000\00000\000\000 */
{ 1885439 }, /* offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC007F7\000\00000\000\000 */
{ 1886173 }, /* offcore_response.all_reads.llc_miss.remote_hitm\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC007F7\000\00000\000\000 */
{ 1889306 }, /* offcore_response.all_requests.llc_miss.any_response\000\000memory\000Counts all requests miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC08FFF\000\00000\000\000 */
{ 1910890 }, /* offcore_response.all_rfo.llc_miss.any_response\000\000memory\000Counts all demand & prefetch RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00122\000\00000\000\000 */
{ 1911255 }, /* offcore_response.all_rfo.llc_miss.local_dram\000\000memory\000Counts all demand & prefetch RFOs miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400122\000\00000\000\000 */
{ 2064279 }, /* offcore_response.demand_code_rd.llc_miss.any_response\000\000memory\000Counts all demand code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000 */
{ 2064817 }, /* offcore_response.demand_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand code reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400004\000\00000\000\000 */
{ 2119430 }, /* offcore_response.demand_data_rd.llc_miss.any_response\000\000memory\000Counts demand data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 2119963 }, /* offcore_response.demand_data_rd.llc_miss.local_dram\000\000memory\000Counts demand data reads miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400001\000\00000\000\000 */
{ 2178287 }, /* offcore_response.demand_rfo.llc_miss.any_response\000\000memory\000Counts all demand data writes (RFOs) miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000 */
{ 2178659 }, /* offcore_response.demand_rfo.llc_miss.local_dram\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400002\000\00000\000\000 */
{ 2178869 }, /* offcore_response.demand_rfo.llc_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000 */
{ 2299303 }, /* offcore_response.pf_l2_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00040\000\00000\000\000 */
{ 2329418 }, /* offcore_response.pf_l2_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00010\000\00000\000\000 */
{ 2364863 }, /* offcore_response.pf_l2_rfo.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00020\000\00000\000\000 */
{ 2425507 }, /* offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) code reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00200\000\00000\000\000 */
{ 2427727 }, /* offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00080\000\00000\000\000 */
{ 2430157 }, /* offcore_response.pf_llc_rfo.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00100\000\00000\000\000 */
{ 2515026 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000\000 */
{ 2517278 }, /* rtm_retired.aborted_misc1\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2517816 }, /* rtm_retired.aborted_misc2\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000 */
{ 2518214 }, /* rtm_retired.aborted_misc3\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000\000 */
{ 2518366 }, /* rtm_retired.aborted_misc4\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type  Spec update: HSD65\000event=0xc9,period=2000003,umask=0x40\000\00000\000\000 */
{ 2518979 }, /* rtm_retired.aborted_misc5\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2520341 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000\000 */
{ 2520843 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2572206 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000\000 */
{ 2572916 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000\000 */
{ 2573515 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000\000 */
{ 2573943 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000\000 */
{ 2574898 }, /* tx_mem.abort_capacity_write\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000 */
{ 2576049 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000\000 */
{ 2577184 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000\000 */
{ 2578235 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000\000 */
{ 2579387 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000\000 */
{ 2580241 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000\000 */
{ 2581166 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000\000 */
{ 581329 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000Unhalted core cycles when the thread is in ring 0\000 */
{ 581608 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 582577 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000Unhalted core cycles when the thread is not in ring 0\000 */
{ 1245992 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000Cycles in which the L1D and L2 are locked, due to a UC lock or split lock\000 */
{ 468877 }, /* arith.divider_uops\000\000pipeline\000Any uop executed by the Divider. (This includes all divide uops, sqrt, ...)\000event=0x14,period=2000003,umask=0x2\000\00000\000\000 */
{ 487693 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 488587 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000\000 */
{ 489261 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000\000 */
{ 489802 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000\000 */
{ 490448 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 492202 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000\000 */
{ 492945 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000\000 */
{ 493664 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000\000 */
{ 494226 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000\000 */
{ 494883 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000\000 */
{ 495474 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000\000 */
{ 496089 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000\000 */
{ 496446 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000Branch instructions at retirement\000 */
{ 499640 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 505568 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts the number of conditional branch instructions retired (Precise event)\000 */
{ 508475 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100003,umask=0x40\000\00000\000Number of far branches retired\000 */
{ 515076 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000 */
{ 516527 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100003,umask=0x2\000\00000\000\000 */
{ 517737 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100003,umask=0x8\000\00000\000Counts the number of near return instructions retired (Precise event)\000 */
{ 519347 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Number of near taken branches retired (Precise event)\000 */
{ 522269 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts the number of not taken branch instructions retired\000 */
{ 528685 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 529734 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000\000 */
{ 530485 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532301 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000\000 */
{ 533148 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000\000 */
{ 534014 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 535066 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000\000 */
{ 536772 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Mispredicted branch instructions at retirement\000 */
{ 541027 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This event counts all mispredicted branch instructions retired. This is a precise event (Must be precise)\000 */
{ 546808 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 556063 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Number of near branch instructions retired that were taken but mispredicted (Precise event)\000 */
{ 607340 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 607646 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000 */
{ 608668 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000 */
{ 618202 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=100003,umask=0x2\000\00000\000\000 */
{ 631463 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state\000 */
{ 638697 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=100003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000 */
{ 639446 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=100003,umask=0x1\000\00000\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000 */
{ 642877 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647330 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 749644 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 data cache miss loads. Set Cmask=8 to count cycle\000 */
{ 750997 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads  Spec update: HSD78, HSM63, HSM80\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set Cmask=2 to count cycle  Spec update: HSD78, HSM63, HSM80\000 */
{ 752706 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set Cmask=2 to count cycle\000 */
{ 753986 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline\000 */
{ 755301 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls due to L1 data cache misses\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Execution stalls due to L1 data cache miss loads. Set Cmask=0CH\000 */
{ 756776 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses  Spec update: HSM63, HSM80\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2  Spec update: HSM63, HSM80\000 */
{ 758023 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000This event counts cycles during which no instructions were executed in the execution stage of the pipeline and there were memory instructions pending (waiting for data)\000 */
{ 1040675 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000Stall cycles due to IQ is full\000 */
{ 1042207 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000This event counts cycles where the decoder is stalled on an instruction with a length changing prefix (LCP)\000 */
{ 1047242 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution  Spec update: HSD140, HSD143\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. INST_RETIRED.ANY is counted by a designated fixed counter, leaving the programmable counters available for other events. Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions  Spec update: HSD140, HSD143\000 */
{ 1054493 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event  Spec update: HSD11, HSD140\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement  Spec update: HSD11, HSD140\000 */
{ 1059440 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: HSD140 (Must be precise)\000 */
{ 1064102 }, /* inst_retired.x87\000\000pipeline\000FP operations retired. X87 FP operations that have no exceptions: Counts also flows that have several X87 or flows that use X87 uops in the exception handling\000event=0xc0,period=2000003,umask=0x2\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts FP operations retired. For X87 FP operations that have no exceptions counting also includes flows that have several X87, or flows that use X87 uops in the exception handling\000 */
{ 1068591 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000This event counts the number of cycles spent waiting for a recovery after an event such as a processor nuke, JEClear, assist, hle/rtm abort etc\000 */
{ 1070848 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000 */
{ 1194460 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1199851 }, /* ld_blocks.store_forward\000\000pipeline\000loads blocked by overlapping with store buffer that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store. The penalty for blocked store forwarding is that the load must wait for the store to write its value to the cache before it can be issued\000 */
{ 1201654 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline which can have a performance impact\000 */
{ 1229109 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for H/W prefetch\000 */
{ 1230225 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for S/W prefetch\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286187 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered by the LSD\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1289676 }, /* machine_clears.cycles\000\000pipeline\000Cycles there was a Nuke. Account for both thread-specific and All Thread Nukes\000event=0xc3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1293637 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000\000 */
{ 1301984 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event is incremented when self-modifying code (SMC) is detected, which causes a machine clear.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1432782 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000Number of integer move elimination candidate uops that were eliminated\000 */
{ 1433160 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000Number of integer move elimination candidate uops that were not eliminated\000 */
{ 2462107 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x40\000\00000\000Number of microcode assists invoked by HW upon uop writeback\000 */
{ 2501165 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles  Spec update: HSD135\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles allocation is stalled due to resource related reason  Spec update: HSD135\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2505112 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000This event counts cycles during which no instructions were allocated because no Store Buffers (SB) were available\000 */
{ 2507281 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000Count cases of saving new LBR records by hardware\000 */
{ 2511687 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000This event counts cycles when the Reservation Station ( RS ) is empty for the thread. The RS is a structure that buffers allocated micro-ops from the Front-end. If there are many cycles when the RS is empty, it may represent an underflow of instructions delivered from the Front-end\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6184529 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6185811 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6187117 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6188415 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6189739 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6191028 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6192009 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6192656 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6192787 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core  Spec update: HSD30, HSM31\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle  Spec update: HSD30, HSM31\000 */
{ 6193959 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195058 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196161 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197264 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198367 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core  Spec update: HSD30, HSM31\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200405 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least one uop was executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6201464 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least two uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6202535 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000This events counts the cycles where at least three uop were executed. It is counted per thread  Spec update: HSD144, HSD30, HSM31\000 */
{ 6203608 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 6205150 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread  Spec update: HSD144, HSD30, HSM31\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207998 }, /* uops_executed_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a uop is dispatched on port 0 in this thread\000 */
{ 6208438 }, /* uops_executed_port.port_0_core\000\000pipeline\000Cycles per core when uops are executed in port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6208575 }, /* uops_executed_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a uop is dispatched on port 1 in this thread\000 */
{ 6209015 }, /* uops_executed_port.port_1_core\000\000pipeline\000Cycles per core when uops are executed in port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6209152 }, /* uops_executed_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Cycles which a uop is dispatched on port 2 in this thread\000 */
{ 6209592 }, /* uops_executed_port.port_2_core\000\000pipeline\000Cycles per core when uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 6209731 }, /* uops_executed_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Cycles which a uop is dispatched on port 3 in this thread\000 */
{ 6210171 }, /* uops_executed_port.port_3_core\000\000pipeline\000Cycles per core when uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 6210310 }, /* uops_executed_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Cycles which a uop is dispatched on port 4 in this thread\000 */
{ 6210752 }, /* uops_executed_port.port_4_core\000\000pipeline\000Cycles per core when uops are executed in port 4\000event=0xa1,any=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 6210890 }, /* uops_executed_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Cycles which a uop is dispatched on port 5 in this thread\000 */
{ 6211332 }, /* uops_executed_port.port_5_core\000\000pipeline\000Cycles per core when uops are executed in port 5\000event=0xa1,any=1,period=2000003,umask=0x20\000\00000\000\000 */
{ 6211470 }, /* uops_executed_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a uop is dispatched on port 6 in this thread\000 */
{ 6211912 }, /* uops_executed_port.port_6_core\000\000pipeline\000Cycles per core when uops are executed in port 6\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6212050 }, /* uops_executed_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a uop is dispatched on port 7 in this thread\000 */
{ 6212492 }, /* uops_executed_port.port_7_core\000\000pipeline\000Cycles per core when uops are dispatched to port 7\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6215075 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of uops issued by the Front-end of the pipeline to the Back-end. This event is counted at the allocation stage and will count both retired and non-retired uops\000 */
{ 6216475 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6216941 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated. Such uops considered perf sensitive; added by GSR u-arch\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops add delay\000 */
{ 6217712 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000Number of multiply packed/scalar single precision uops allocated\000 */
{ 6218455 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (for example, 2 sources + immediate) regardless of whether it is a result of LEA instruction or not\000 */
{ 6220517 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6225390 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of micro-ops retired. Use Cmask=1 and invert to count active cycles or stalled cycles (Precise event)\000 */
{ 6228028 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6234678 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 uops or 4 instructions could retire each cycle (Precise event)\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240433 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1207716 }, /* llc_misses.code_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for code reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x191\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1208449 }, /* llc_misses.data_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for data reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x192\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1209182 }, /* llc_misses.data_read\000uncore_cbox\000uncore cache\000LLC misses - demand and prefetch data reads - excludes LLC prefetches. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x182\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1212098 }, /* llc_misses.mmio_read\000uncore_cbox\000uncore cache\000MMIO reads. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1213639 }, /* llc_misses.mmio_write\000uncore_cbox\000uncore cache\000MMIO writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x18f,filter_nc=1\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1215186 }, /* llc_misses.pcie_non_snoop_write\000uncore_cbox\000uncore cache\000PCIe write misses (full cache line). Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1215939 }, /* llc_misses.pcie_read\000uncore_cbox\000uncore cache\000LLC misses for PCIe read current. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1217854 }, /* llc_misses.pcie_write\000uncore_cbox\000uncore cache\000ItoM write misses (as part of fast string memcpy stores) + PCIe full line writes. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x1c8\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1219820 }, /* llc_misses.rfo_llc_prefetch\000uncore_cbox\000uncore cache\000LLC prefetch misses for RFO. Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x190\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1220545 }, /* llc_misses.uncacheable\000uncore_cbox\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_c_tor_inserts.miss_opcode. Unit: uncore_cbox \000event=0x35,umask=0x3,filter_opc=0x187\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 1222170 }, /* llc_references.code_llc_prefetch\000uncore_cbox\000uncore cache\000L2 demand and L2 prefetch code references to LLC. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x181\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1222951 }, /* llc_references.pcie_ns_partial_write\000uncore_cbox\000uncore cache\000PCIe writes (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x180,filter_tid=0x3e\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1223729 }, /* llc_references.pcie_read\000uncore_cbox\000uncore cache\000PCIe read current. Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x19e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1224471 }, /* llc_references.pcie_write\000uncore_cbox\000uncore cache\000PCIe write references (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x1c8,filter_tid=0x3e\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1225252 }, /* llc_references.streaming_full\000uncore_cbox\000uncore cache\000Streaming stores (full cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18c\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 1226918 }, /* llc_references.streaming_partial\000uncore_cbox\000uncore cache\000Streaming stores (partial cache line). Derived from unc_c_tor_inserts.opcode. Unit: uncore_cbox \000event=0x35,umask=0x1,filter_opc=0x18d\000\0000164Bytes\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2592068 }, /* unc_c_bounce_control\000uncore_cbox\000uncore cache\000Bounce Control. Unit: uncore_cbox \000event=0xa\000\00001\000\000 */
{ 2592164 }, /* unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000 */
{ 2592390 }, /* unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2592888 }, /* unc_c_fast_asserted\000uncore_cbox\000uncore cache\000FaST wire asserted. Unit: uncore_cbox \000event=0x9\000\00001\000Counts the number of cycles either the local distress or incoming distress signals are asserted.  Incoming distress includes both up and dn\000 */
{ 2593371 }, /* unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000All LLC Misses (code+ data rd + data wr - including demand and prefetch). Unit: uncore_cbox \000event=0x34,umask=0x11,filter_state=0x1\000\0000164Bytes\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2596894 }, /* unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2598632 }, /* unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2599997 }, /* unc_c_llc_lookup.read\000uncore_cbox\000uncore cache\000Cache Lookups; Any Read Request. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2602045 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2604174 }, /* unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2605021 }, /* unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605435 }, /* unc_c_llc_victims.f_state\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2605831 }, /* unc_c_llc_victims.i_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606492 }, /* unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000M line evictions from LLC (writebacks to memory). Unit: uncore_cbox \000event=0x37,umask=0x1\000\0000164Bytes\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606927 }, /* unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x10\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607378 }, /* unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2608518 }, /* unc_c_llc_victims.s_state\000uncore_cbox\000uncore cache\000Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2608914 }, /* unc_c_misc.cvzero_prefetch_miss\000uncore_cbox\000uncore cache\000Cbo Misc; DRd hitting non-M with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609091 }, /* unc_c_misc.cvzero_prefetch_victim\000uncore_cbox\000uncore cache\000Cbo Misc; Clean Victim with raw CV=0. Unit: uncore_cbox \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2609265 }, /* unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo.; Number of times that an RFO hit in S state.  This is useful for determining if it might be good for a workload to use RspIWB instead of RspSWB\000 */
{ 2609694 }, /* unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2610173 }, /* unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610303 }, /* unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2610806 }, /* unc_c_qlru.age0\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 0. Unit: uncore_cbox \000event=0x3c,umask=0x1\000\00001\000How often age was set to 0\000 */
{ 2610940 }, /* unc_c_qlru.age1\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 1. Unit: uncore_cbox \000event=0x3c,umask=0x2\000\00001\000How often age was set to 1\000 */
{ 2611074 }, /* unc_c_qlru.age2\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 2. Unit: uncore_cbox \000event=0x3c,umask=0x4\000\00001\000How often age was set to 2\000 */
{ 2611208 }, /* unc_c_qlru.age3\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 3. Unit: uncore_cbox \000event=0x3c,umask=0x8\000\00001\000How often age was set to 3\000 */
{ 2611342 }, /* unc_c_qlru.lru_decrement\000uncore_cbox\000uncore cache\000LRU Queue; LRU Bits Decremented. Unit: uncore_cbox \000event=0x3c,umask=0x10\000\00001\000How often all LRU bits were decremented by 1\000 */
{ 2611515 }, /* unc_c_qlru.victim_non_zero\000uncore_cbox\000uncore cache\000LRU Queue; Non-0 Aged Victim. Unit: uncore_cbox \000event=0x3c,umask=0x20\000\00001\000How often we picked a victim that had a non-zero age\000 */
{ 2612532 }, /* unc_c_ring_ad_used.all\000uncore_cbox\000uncore cache\000AD Ring In Use; All. Unit: uncore_cbox \000event=0x1b,umask=0xf\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2617572 }, /* unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2620150 }, /* unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2622802 }, /* unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2629948 }, /* unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2631676 }, /* unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2634312 }, /* unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2640588 }, /* unc_c_ring_ak_used.all\000uncore_cbox\000uncore cache\000AK Ring In Use; All. Unit: uncore_cbox \000event=0x1c,umask=0xf\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2644780 }, /* unc_c_ring_ak_used.down\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2647352 }, /* unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2649998 }, /* unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2656295 }, /* unc_c_ring_ak_used.up\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2658019 }, /* unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2660649 }, /* unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2666914 }, /* unc_c_ring_bl_used.all\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xf\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2671107 }, /* unc_c_ring_bl_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2674535 }, /* unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity\000 */
{ 2677180 }, /* unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 2682624 }, /* unc_c_ring_bl_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2685200 }, /* unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 2687829 }, /* unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 2692409 }, /* unc_c_ring_bounces.ad\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AD. Unit: uncore_cbox \000event=0x5,umask=0x1\000\00001\000\000 */
{ 2692700 }, /* unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; AK. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2693360 }, /* unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; BL. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2694014 }, /* unc_c_ring_bounces.iv\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x10\000\00001\000\000 */
{ 2695093 }, /* unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2697097 }, /* unc_c_ring_iv_used.dn\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2698214 }, /* unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters for Down polarity\000 */
{ 2699697 }, /* unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in HSX  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 2700711 }, /* unc_c_ring_sink_starved.ad\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.AD. Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 2701237 }, /* unc_c_ring_sink_starved.ak\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.AK. Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 2701562 }, /* unc_c_ring_sink_starved.bl\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.BL. Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 2701887 }, /* unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000UNC_C_RING_SINK_STARVED.IV. Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 2702209 }, /* unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Number of cycles the Cbo is actively throttling traffic onto the Ring in order to limit bounce traffic. Unit: uncore_cbox \000event=0x7\000\00001\000\000 */
{ 2702621 }, /* unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IPQ is externally startved and therefore we are blocking the IRQ\000 */
{ 2703192 }, /* unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IRQ is externally starved and therefore we are blocking the IPQ\000 */
{ 2704016 }, /* unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; Number of times that the ISMQ Bid\000 */
{ 2704767 }, /* unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; PRQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2705019 }, /* unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705208 }, /* unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705397 }, /* unc_c_rxr_inserts.irq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706013 }, /* unc_c_rxr_inserts.prq\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706203 }, /* unc_c_rxr_inserts.prq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; PRQ. Unit: uncore_cbox \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2707348 }, /* unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IPQ in Internal Starvation\000 */
{ 2707983 }, /* unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IRQ in Internal Starvation\000 */
{ 2708618 }, /* unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the ISMQ in Internal Starvation\000 */
{ 2709258 }, /* unc_c_rxr_int_starved.prq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; PRQ. Unit: uncore_cbox \000event=0x14,umask=0x10\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2709554 }, /* unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from an address conflicts.  Address conflicts out of the IPQ should be rare.  They will generally only occur if two different sockets are sending requests to the same address at the same time.  This is a true conflict case, unlike the IPQ Address Conflict which is commonly caused by prefetching characteristics\000 */
{ 2710465 }, /* unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject.  TOR rejects from the IPQ can be caused by the Egress being full or Address Conflicts\000 */
{ 2711119 }, /* unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from the Egress being full.  IPQ requests make use of the AD Egress for regular responses, the BL egress to forward data, and the AK egress to return credits\000 */
{ 2711860 }, /* unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2712110 }, /* unc_c_rxr_ipq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Probe Queue Retries; No AD Sbo Credits. Unit: uncore_cbox \000event=0x28,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2712488 }, /* unc_c_rxr_ipq_retry2.target\000uncore_cbox\000uncore cache\000Probe Queue Retries; Target Node Filter. Unit: uncore_cbox \000event=0x28,umask=0x40\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2712880 }, /* unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000Counts the number of times that a request from the IRQ was retried because of an address match in the TOR.  In order to maintain coherency, requests to the same address are not allowed to pass each other up in the Cbo.  Therefore, if there is an outstanding request to a given address, one cannot issue another request to that address until it is complete.  This comes up most commonly with prefetches.  Outstanding prefetches occasionally will not complete their memory fetch and a demand request to the same address will then sit in the IRQ and get retried until the prefetch fills the data into the LLC.  Therefore, it will not be uncommon to see this case in high bandwidth streaming workloads when the LLC Prefetcher in the core is enabled\000 */
{ 2713930 }, /* unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000Counts the number of IRQ retries that occur.  Requests from the IRQ are retried if they are rejected from the TOR pipeline for a variety of reasons.  Some of the most common reasons include if the Egress is full, there are no RTIDs, or there is a Physical Address match to another outstanding request\000 */
{ 2714504 }, /* unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000Counts the number of times that a request from the IRQ was retried because it failed to acquire an entry in the Egress.  The egress is the buffer that queues up for allocating onto the ring.  IRQ requests can make use of all four rings and all four Egresses.  If any of the queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2715154 }, /* unc_c_rxr_irq_retry.iio_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No IIO Credits. Unit: uncore_cbox \000event=0x32,umask=0x20\000\00001\000Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2715572 }, /* unc_c_rxr_irq_retry.nid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cbox \000event=0x32,umask=0x40\000\00001\000Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2715819 }, /* unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000Number of requests rejects because of lack of QPI Ingress credits.  These credits are required in order to send transactions to the QPI agent.  Please see the QPI_IGR_CREDITS events for more information\000 */
{ 2716321 }, /* unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000Counts the number of times that requests from the IRQ were retried because there were no RTIDs available.  RTIDs are required after a request misses the LLC and needs to send snoops and/or requests to memory.  If there are no RTIDs available, requests will queue up in the IRQ and retry until one becomes available.  Note that there are multiple RTID pools for the different sockets.  There may be cases where the local RTIDs are all used, but requests destined for remote memory can still acquire an RTID because there are remote RTIDs available.  This event does not provide any filtering for this case\000 */
{ 2717197 }, /* unc_c_rxr_irq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x1\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2717472 }, /* unc_c_rxr_irq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x29,umask=0x2\000\00001\000Counts the number of times that a request from the IPQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2717747 }, /* unc_c_rxr_irq_retry2.target\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x29,umask=0x40\000\00001\000Counts the number of times that a request from the IPQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2718036 }, /* unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the total number of times that a request from the ISMQ retried because of a TOR reject.  ISMQ requests generally will not need to retry (or at least ISMQ retries are less common than IRQ retries).  ISMQ requests will retry if they are not able to acquire a needed Egress credit to get onto the ring, or for cache evictions that need to acquire an RTID.  Most ISMQ requests already have an RTID, so eviction retries will be less common here\000 */
{ 2719237 }, /* unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by a lack of Egress credits. The egress is the buffer that queues up for allocating onto the ring.  If any of the Egress queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2720310 }, /* unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2721359 }, /* unc_c_rxr_ismq_retry.nid\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2721848 }, /* unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2722237 }, /* unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by no RTIDs.  M-state cache evictions are serviced through the ISMQ, and must acquire an RTID in order to write back to memory.  If no RTIDs are available, they will be retried\000 */
{ 2723261 }, /* unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Qualify one of the other subevents by a given RTID destination NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER1.nid\000 */
{ 2724209 }, /* unc_c_rxr_ismq_retry2.ad_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No AD Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x1\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an AD packet to the Sbo\000 */
{ 2724483 }, /* unc_c_rxr_ismq_retry2.bl_sbo\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; No BL Sbo Credits. Unit: uncore_cbox \000event=0x2a,umask=0x2\000\00001\000Counts the number of times that a request from the ISMQ was retried because of it lacked credits to send an BL packet to the Sbo\000 */
{ 2724757 }, /* unc_c_rxr_ismq_retry2.target\000uncore_cbox\000uncore cache\000ISMQ Request Queue Rejects; Target Node Filter. Unit: uncore_cbox \000event=0x2a,umask=0x40\000\00001\000Counts the number of times that a request from the ISMQ was retried filtered by the Target NodeID as specified in the Cbox's Filter register\000 */
{ 2725045 }, /* unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725232 }, /* unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725419 }, /* unc_c_rxr_occupancy.irq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2726010 }, /* unc_c_rxr_occupancy.prq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; PRQ Rejects. Unit: uncore_cbox \000event=0x11,umask=0x20\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2727266 }, /* unc_c_sbo_credit_occupancy.ad\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For AD Ring. Unit: uncore_cbox \000event=0x3e,umask=0x1\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727511 }, /* unc_c_sbo_credit_occupancy.bl\000uncore_cbox\000uncore cache\000SBo Credits Occupancy; For BL Ring. Unit: uncore_cbox \000event=0x3e,umask=0x2\000\00001\000Number of Sbo credits in use in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2727756 }, /* unc_c_sbo_credits_acquired.ad\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For AD Ring. Unit: uncore_cbox \000event=0x3d,umask=0x1\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728002 }, /* unc_c_sbo_credits_acquired.bl\000uncore_cbox\000uncore cache\000SBo Credits Acquired; For BL Ring. Unit: uncore_cbox \000event=0x3d,umask=0x2\000\00001\000Number of Sbo credits acquired in a given cycle, per ring.  Each Cbo is assigned an Sbo it can communicate with\000 */
{ 2728248 }, /* unc_c_tor_inserts.all\000uncore_cbox\000uncore cache\000TOR Inserts; All. Unit: uncore_cbox \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR.    This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2730237 }, /* unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Eviction transactions inserted into the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2733765 }, /* unc_c_tor_inserts.local\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x28\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2735161 }, /* unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2736634 }, /* unc_c_tor_inserts.miss_local\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x2a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2737323 }, /* unc_c_tor_inserts.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x23\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode, inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2738662 }, /* unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 2739324 }, /* unc_c_tor_inserts.miss_remote\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x8a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2740025 }, /* unc_c_tor_inserts.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x83\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2741368 }, /* unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched (matches an RTID destination) transactions inserted into the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.  In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2742799 }, /* unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched eviction transactions inserted into the TOR\000 */
{ 2744068 }, /* unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched miss requests that were inserted into the TOR\000 */
{ 2745352 }, /* unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2746645 }, /* unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2747919 }, /* unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched write transactions inserted into the TOR\000 */
{ 2749165 }, /* unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2750908 }, /* unc_c_tor_inserts.remote\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x88\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2751593 }, /* unc_c_tor_inserts.remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x81\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2753157 }, /* unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Write transactions inserted into the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2754718 }, /* unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All valid TOR entries.  This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2756725 }, /* unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding eviction transactions in the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2758758 }, /* unc_c_tor_occupancy.llc_data_read\000uncore_cbox\000uncore cache\000Occupancy counter for LLC data reads (demand and L2 prefetch). Derived from unc_c_tor_occupancy.miss_opcode. Unit: uncore_cbox \000event=0x36,umask=0x3,filter_opc=0x182\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2760047 }, /* unc_c_tor_occupancy.local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x28\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2760639 }, /* unc_c_tor_occupancy.local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by locally HOMed memory\000 */
{ 2762159 }, /* unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding miss requests in the TOR.  'Miss' means the allocation requires an RTID.  This generally means that the request was sent to memory or MMIO\000 */
{ 2762925 }, /* unc_c_tor_occupancy.miss_local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x2a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2763522 }, /* unc_c_tor_occupancy.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x23\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by locally HOMed memory\000 */
{ 2764905 }, /* unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2765643 }, /* unc_c_tor_occupancy.miss_remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x8a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2766241 }, /* unc_c_tor_occupancy.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x83\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2767627 }, /* unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of NID matched outstanding requests in the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2769062 }, /* unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding NID matched eviction transactions in the TOR \000 */
{ 2770367 }, /* unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID\000 */
{ 2771677 }, /* unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID and an opcode\000 */
{ 2773010 }, /* unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match a NID and an opcode\000 */
{ 2773675 }, /* unc_c_tor_occupancy.nid_wb\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x50\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); NID matched write transactions int the TOR\000 */
{ 2774944 }, /* unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2776134 }, /* unc_c_tor_occupancy.remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x88\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2776727 }, /* unc_c_tor_occupancy.remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x81\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2777486 }, /* unc_c_tor_occupancy.wb\000uncore_cbox\000uncore cache\000TOR Occupancy; Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Write transactions in the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2778213 }, /* unc_c_txr_ads_used.ad\000uncore_cbox\000uncore cache\000Onto AD Ring. Unit: uncore_cbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 2778318 }, /* unc_c_txr_ads_used.ak\000uncore_cbox\000uncore cache\000Onto AK Ring. Unit: uncore_cbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 2778423 }, /* unc_c_txr_ads_used.bl\000uncore_cbox\000uncore cache\000Onto BL Ring. Unit: uncore_cbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 2778606 }, /* unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 2779216 }, /* unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 2779791 }, /* unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 2780383 }, /* unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AK ring.  This is commonly used for snoop responses coming from the core and destined for a Cachebo\000 */
{ 2781004 }, /* unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 2781612 }, /* unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 2782210 }, /* unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 2782790 }, /* unc_c_txr_starved.ad_core\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AD Ring (to core). Unit: uncore_cbox \000event=0x3,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the core AD egress spent in starvation\000 */
{ 2783391 }, /* unc_c_txr_starved.ak_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both AK egresses spent in starvation\000 */
{ 2783979 }, /* unc_c_txr_starved.bl_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both BL egresses spent in starvation\000 */
{ 2784301 }, /* unc_c_txr_starved.iv\000uncore_cbox\000uncore cache\000Injection Starvation; Onto IV Ring. Unit: uncore_cbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the cachebo IV egress spent in starvation\000 */
{ 3579343 }, /* unc_h_bt_cycles_ne\000uncore_ha\000uncore cache\000BT Cycles Not Empty. Unit: uncore_ha \000event=0x42\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3582625 }, /* unc_h_bt_to_ht_not_issued.incoming_bl_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x4\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3582923 }, /* unc_h_bt_to_ht_not_issued.incoming_snp_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Snoop Hazard. Unit: uncore_ha \000event=0x51,umask=0x2\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming snoop hazard\000 */
{ 3583221 }, /* unc_h_bt_to_ht_not_issued.rspackcflt_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x8\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3583518 }, /* unc_h_bt_to_ht_not_issued.wbmdata_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x10\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3584345 }, /* unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass\000 */
{ 3585130 }, /* unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the bypass\000 */
{ 3587414 }, /* unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000 */
{ 3592593 }, /* unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000 */
{ 3592735 }, /* unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000 */
{ 3592913 }, /* unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000 */
{ 3593093 }, /* unc_h_directory_lat_opt\000uncore_ha\000uncore cache\000Directory Lat Opt Return. Unit: uncore_ha \000event=0x41\000\00001\000Directory Latency Optimization Data Return Path Taken. When directory mode is enabled and the directory returned for a read is Dir=I, then data can be returned using a faster path if certain conditions are met (credits, free pipeline, etc)\000 */
{ 3593702 }, /* unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that did not have to send any snoops because the directory bit was clear\000 */
{ 3594878 }, /* unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that had to send one or more snoops because the directory bit was set\000 */
{ 3596877 }, /* unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3597179 }, /* unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory clears.  This occurs when snoops were sent and all returned with RspI\000 */
{ 3599011 }, /* unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory sets.  This occurs when a remote read transaction requests memory, bringing it to a remote cache\000 */
{ 3612982 }, /* unc_h_hitme_hit.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is AckCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x4\000\00001\000\000 */
{ 3613133 }, /* unc_h_hitme_hit.all\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; All Requests. Unit: uncore_ha \000event=0x71,umask=0xff\000\00001\000\000 */
{ 3613272 }, /* unc_h_hitme_hit.allocs\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x70\000\00001\000\000 */
{ 3613413 }, /* unc_h_hitme_hit.evicts\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Allocations. Unit: uncore_ha \000event=0x71,umask=0x42\000\00001\000\000 */
{ 3613716 }, /* unc_h_hitme_hit.hom\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; HOM Requests. Unit: uncore_ha \000event=0x71,umask=0xf\000\00001\000\000 */
{ 3613854 }, /* unc_h_hitme_hit.invals\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; Invalidations. Unit: uncore_ha \000event=0x71,umask=0x26\000\00001\000\000 */
{ 3613997 }, /* unc_h_hitme_hit.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x71,umask=0x1\000\00001\000\000 */
{ 3614200 }, /* unc_h_hitme_hit.rsp\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x71,umask=0x80\000\00001\000\000 */
{ 3614384 }, /* unc_h_hitme_hit.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x71,umask=0x20\000\00001\000\000 */
{ 3614567 }, /* unc_h_hitme_hit.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x71,umask=0x10\000\00001\000\000 */
{ 3614752 }, /* unc_h_hitme_hit.rspfwds\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x71,umask=0x40\000\00001\000\000 */
{ 3615246 }, /* unc_h_hitme_hit.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x71,umask=0x8\000\00001\000\000 */
{ 3615402 }, /* unc_h_hitme_hit.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI. Unit: uncore_ha \000event=0x71,umask=0x2\000\00001\000\000 */
{ 3615716 }, /* unc_h_hitme_hit_pv_bits_set.ackcnfltwbi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is AckCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x4\000\00001\000\000 */
{ 3615896 }, /* unc_h_hitme_hit_pv_bits_set.all\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; All Requests. Unit: uncore_ha \000event=0x72,umask=0xff\000\00001\000\000 */
{ 3616064 }, /* unc_h_hitme_hit_pv_bits_set.hom\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; HOM Requests. Unit: uncore_ha \000event=0x72,umask=0xf\000\00001\000\000 */
{ 3616231 }, /* unc_h_hitme_hit_pv_bits_set.read_or_invitoe\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x72,umask=0x1\000\00001\000\000 */
{ 3616463 }, /* unc_h_hitme_hit_pv_bits_set.rsp\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x72,umask=0x80\000\00001\000\000 */
{ 3616676 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_local\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x72,umask=0x20\000\00001\000\000 */
{ 3616888 }, /* unc_h_hitme_hit_pv_bits_set.rspfwdi_remote\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x72,umask=0x10\000\00001\000\000 */
{ 3617102 }, /* unc_h_hitme_hit_pv_bits_set.rspfwds\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x72,umask=0x40\000\00001\000\000 */
{ 3617287 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoe_or_s\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x72,umask=0x8\000\00001\000\000 */
{ 3617472 }, /* unc_h_hitme_hit_pv_bits_set.wbmtoi\000uncore_ha\000uncore cache\000Accumulates Number of PV bits set on HitMe Cache Hits; op is WbMtoI. Unit: uncore_ha \000event=0x72,umask=0x2\000\00001\000\000 */
{ 3617642 }, /* unc_h_hitme_lookup.ackcnfltwbi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is AckCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x4\000\00001\000\000 */
{ 3617806 }, /* unc_h_hitme_lookup.all\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; All Requests. Unit: uncore_ha \000event=0x70,umask=0xff\000\00001\000\000 */
{ 3617958 }, /* unc_h_hitme_lookup.allocs\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Allocations. Unit: uncore_ha \000event=0x70,umask=0x70\000\00001\000\000 */
{ 3618112 }, /* unc_h_hitme_lookup.hom\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; HOM Requests. Unit: uncore_ha \000event=0x70,umask=0xf\000\00001\000\000 */
{ 3618263 }, /* unc_h_hitme_lookup.invals\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; Invalidations. Unit: uncore_ha \000event=0x70,umask=0x26\000\00001\000\000 */
{ 3618583 }, /* unc_h_hitme_lookup.read_or_invitoe\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdInvOwn, RdCur or InvItoE. Unit: uncore_ha \000event=0x70,umask=0x1\000\00001\000\000 */
{ 3618799 }, /* unc_h_hitme_lookup.rsp\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspI, RspIWb, RspS, RspSWb, RspCnflt or RspCnfltWbI. Unit: uncore_ha \000event=0x70,umask=0x80\000\00001\000\000 */
{ 3618996 }, /* unc_h_hitme_lookup.rspfwdi_local\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_ha \000event=0x70,umask=0x20\000\00001\000\000 */
{ 3619192 }, /* unc_h_hitme_lookup.rspfwdi_remote\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_ha \000event=0x70,umask=0x10\000\00001\000\000 */
{ 3619390 }, /* unc_h_hitme_lookup.rspfwds\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RsSFwd or RspSFwdWb. Unit: uncore_ha \000event=0x70,umask=0x40\000\00001\000\000 */
{ 3619559 }, /* unc_h_hitme_lookup.wbmtoe_or_s\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE or WbMtoS. Unit: uncore_ha \000event=0x70,umask=0x8\000\00001\000\000 */
{ 3619728 }, /* unc_h_hitme_lookup.wbmtoi\000uncore_ha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoI. Unit: uncore_ha \000event=0x70,umask=0x2\000\00001\000\000 */
{ 3627792 }, /* unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628119 }, /* unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628446 }, /* unc_h_igr_no_credit_cycles.ad_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628774 }, /* unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629101 }, /* unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629428 }, /* unc_h_igr_no_credit_cycles.bl_qpi2\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629756 }, /* unc_h_imc_reads.normal\000uncore_ha\000uncore cache\000HA to iMC Normal Priority Reads Issued; Normal Priority. Unit: uncore_ha \000event=0x17,umask=0x1\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 3630382 }, /* unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000 */
{ 3630468 }, /* unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3630784 }, /* unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631110 }, /* unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631438 }, /* unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631765 }, /* unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3649797 }, /* unc_h_iot_backpressure.hub\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x2\000\00001\000\000 */
{ 3649908 }, /* unc_h_iot_backpressure.sat\000uncore_ha\000uncore cache\000IOT Backpressure. Unit: uncore_ha \000event=0x61,umask=0x1\000\00001\000\000 */
{ 3650019 }, /* unc_h_iot_cts_east_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650171 }, /* unc_h_iot_cts_east_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x64,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650323 }, /* unc_h_iot_cts_hi.cts2\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650470 }, /* unc_h_iot_cts_hi.cts3\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Hi. Unit: uncore_ha \000event=0x65,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650617 }, /* unc_h_iot_cts_west_lo.cts0\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3650769 }, /* unc_h_iot_cts_west_lo.cts1\000uncore_ha\000uncore cache\000IOT Common Trigger Sequencer - Lo. Unit: uncore_ha \000event=0x62,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 3652460 }, /* unc_h_osb.cancelled\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Cancelled. Unit: uncore_ha \000event=0x53,umask=0x10\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB.; OSB Snoop broadcast cancelled due to D2C or Other. OSB cancel is counted when OSB local read is not allowed even when the transaction in local InItoE. It also counts D2C OSB cancel, but also includes the cases were D2C was not set in the first place for the transaction coming from the ring\000 */
{ 3653009 }, /* unc_h_osb.invitoe_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local InvItoE. Unit: uncore_ha \000event=0x53,umask=0x4\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653272 }, /* unc_h_osb.reads_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local Reads. Unit: uncore_ha \000event=0x53,umask=0x2\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653531 }, /* unc_h_osb.reads_local_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Reads Local -  Useful. Unit: uncore_ha \000event=0x53,umask=0x20\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653808 }, /* unc_h_osb.remote\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote. Unit: uncore_ha \000event=0x53,umask=0x8\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654057 }, /* unc_h_osb.remote_useful\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote - Useful. Unit: uncore_ha \000event=0x53,umask=0x40\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654449 }, /* unc_h_osb_edr.all\000uncore_ha\000uncore cache\000OSB Early Data Return; All. Unit: uncore_ha \000event=0x54,umask=0x1\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654695 }, /* unc_h_osb_edr.reads_local_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local  I. Unit: uncore_ha \000event=0x54,umask=0x2\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654965 }, /* unc_h_osb_edr.reads_local_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local S. Unit: uncore_ha \000event=0x54,umask=0x8\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655234 }, /* unc_h_osb_edr.reads_remote_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote I. Unit: uncore_ha \000event=0x54,umask=0x4\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655505 }, /* unc_h_osb_edr.reads_remote_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote S. Unit: uncore_ha \000event=0x54,umask=0x10\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3657030 }, /* unc_h_requests.invitoe_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x10\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from the local socket\000 */
{ 3657584 }, /* unc_h_requests.invitoe_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x20\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from remote sockets\000 */
{ 3658081 }, /* unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming ead requests.  This is a good proxy for LLC Read Misses (including RFOs)\000 */
{ 3658883 }, /* unc_h_requests.reads_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Reads. Unit: uncore_ha \000event=0x1,umask=0x1\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the local socket.  This is a good proxy for LLC Read Misses (including RFOs) from the local socket\000 */
{ 3659475 }, /* unc_h_requests.reads_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Reads. Unit: uncore_ha \000event=0x1,umask=0x2\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the remote socket.  This is a good proxy for LLC Read Misses (including RFOs) from the remote socket\000 */
{ 3660059 }, /* unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming write requests\000 */
{ 3660809 }, /* unc_h_requests.writes_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Writes. Unit: uncore_ha \000event=0x1,umask=0x4\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from the local socket\000 */
{ 3661316 }, /* unc_h_requests.writes_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Writes. Unit: uncore_ha \000event=0x1,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from remote sockets\000 */
{ 3661687 }, /* unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3662382 }, /* unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3663162 }, /* unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3666081 }, /* unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3666420 }, /* unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3667177 }, /* unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3670007 }, /* unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3670702 }, /* unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3671482 }, /* unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3674401 }, /* unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3674740 }, /* unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3675497 }, /* unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3678327 }, /* unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3679022 }, /* unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 3679802 }, /* unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 3682721 }, /* unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3683060 }, /* unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 3683817 }, /* unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 3693072 }, /* unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3694856 }, /* unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3696640 }, /* unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3698424 }, /* unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3700168 }, /* unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3701870 }, /* unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3703572 }, /* unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3705274 }, /* unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3733425 }, /* unc_h_sbo0_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733616 }, /* unc_h_sbo0_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 3733807 }, /* unc_h_sbo0_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x68,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3733999 }, /* unc_h_sbo0_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x68,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 3734191 }, /* unc_h_sbo1_credit_occupancy.ad\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_ha \000event=0x6b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734382 }, /* unc_h_sbo1_credit_occupancy.bl\000uncore_ha\000uncore cache\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_ha \000event=0x6b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 3734573 }, /* unc_h_sbo1_credits_acquired.ad\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_ha \000event=0x69,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3734765 }, /* unc_h_sbo1_credits_acquired.bl\000uncore_ha\000uncore cache\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_ha \000event=0x69,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 3736413 }, /* unc_h_snoop_cycles_ne.all\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; All Requests. Unit: uncore_ha \000event=0x8,umask=0x3\000\00001\000Counts cycles when one or more snoops are outstanding.; Tracked for snoops from both local and remote sockets\000 */
{ 3736659 }, /* unc_h_snoop_cycles_ne.local\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Local Requests. Unit: uncore_ha \000event=0x8,umask=0x1\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from the local socket\000 */
{ 3736919 }, /* unc_h_snoop_cycles_ne.remote\000uncore_ha\000uncore cache\000Cycles with Snoops Outstanding; Remote Requests. Unit: uncore_ha \000event=0x8,umask=0x2\000\00001\000Counts cycles when one or more snoops are outstanding.; This filter includes only requests coming from remote sockets\000 */
{ 3737179 }, /* unc_h_snoop_occupancy.local\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Local Requests. Unit: uncore_ha \000event=0x9,umask=0x1\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from the local socket\000 */
{ 3737841 }, /* unc_h_snoop_occupancy.remote\000uncore_ha\000uncore cache\000Tracker Snoops Outstanding Accumulator; Remote Requests. Unit: uncore_ha \000event=0x9,umask=0x2\000\00001\000Accumulates the occupancy of either the local HA tracker pool that have snoops pending in every cycle.    This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if an HT (HomeTracker) entry is available and this occupancy is decremented when all the snoop responses have returned.; This filter includes only requests coming from remote sockets\000 */
{ 3738676 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000M line forwarded from remote cache along with writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x20\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3740517 }, /* unc_h_snoop_resp.rsp_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*WB. Unit: uncore_ha \000event=0x21,umask=0x10\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3741525 }, /* unc_h_snoop_resp.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received; RSPCNFLCT*. Unit: uncore_ha \000event=0x21,umask=0x40\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3742665 }, /* unc_h_snoop_resp.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received; RspI. Unit: uncore_ha \000event=0x21,umask=0x1\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3743560 }, /* unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000M line forwarded from remote cache with no writeback to memory. Unit: uncore_ha \000event=0x21,umask=0x4\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3745354 }, /* unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Shared line response from remote cache. Unit: uncore_ha \000event=0x21,umask=0x2\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3747843 }, /* unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Shared line forwarded from remote cache. Unit: uncore_ha \000event=0x21,umask=0x8\000\0000164Bytes\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3750143 }, /* unc_h_snoops_rsp_after_data.local\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Local Requests. Unit: uncore_ha \000event=0xa,umask=0x1\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from the local socket\000 */
{ 3750440 }, /* unc_h_snoops_rsp_after_data.remote\000uncore_ha\000uncore cache\000Data beat the Snoop Responses; Remote Requests. Unit: uncore_ha \000event=0xa,umask=0x2\000\00001\000Counts the number of reads when the snoop was on the critical path to the data return.; This filter includes only requests coming from remote sockets\000 */
{ 3751926 }, /* unc_h_snp_resp_recv_local.other\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Other. Unit: uncore_ha \000event=0x60,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for all other snoop responses\000 */
{ 3752158 }, /* unc_h_snp_resp_recv_local.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_ha \000event=0x60,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3752627 }, /* unc_h_snp_resp_recv_local.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_ha \000event=0x60,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3753011 }, /* unc_h_snp_resp_recv_local.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_ha \000event=0x60,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3753465 }, /* unc_h_snp_resp_recv_local.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_ha \000event=0x60,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3754303 }, /* unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3754721 }, /* unc_h_snp_resp_recv_local.rspxfwdxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_ha \000event=0x60,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3755195 }, /* unc_h_snp_resp_recv_local.rspxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_ha \000event=0x60,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3757116 }, /* unc_h_stall_no_sbo_credit.sbo0_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757360 }, /* unc_h_stall_no_sbo_credit.sbo0_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757604 }, /* unc_h_stall_no_sbo_credit.sbo1_ad\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_ha \000event=0x6c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3757848 }, /* unc_h_stall_no_sbo_credit.sbo1_bl\000uncore_ha\000uncore cache\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_ha \000event=0x6c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 3763538 }, /* unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 0\000 */
{ 3765043 }, /* unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 1\000 */
{ 3766548 }, /* unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 2\000 */
{ 3768053 }, /* unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 3\000 */
{ 3769559 }, /* unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 4\000 */
{ 3771066 }, /* unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 5\000 */
{ 3772573 }, /* unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 6\000 */
{ 3774080 }, /* unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 7\000 */
{ 3775589 }, /* unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 10\000 */
{ 3777101 }, /* unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 11\000 */
{ 3778611 }, /* unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 8\000 */
{ 3780118 }, /* unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 9\000 */
{ 3793272 }, /* unc_h_tracker_cycles_full.all\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles Completely Used. Unit: uncore_ha \000event=0x2,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the HA tracker pool (HT) is completely used including reserved HT entries.  It will not return valid count when BT is disabled\000 */
{ 3794203 }, /* unc_h_tracker_cycles_full.gp\000uncore_ha\000uncore cache\000Tracker Cycles Full; Cycles GP Completely Used. Unit: uncore_ha \000event=0x2,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is completely used.  This can be used with edge detect to identify the number of situations when the pool became fully utilized.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, the system could be starved for RTIDs but not fill up the HA trackers.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Counts the number of cycles when the general purpose (GP) HA tracker pool (HT) is completely used.  It will not return valid count when BT is disabled\000 */
{ 3795127 }, /* unc_h_tracker_cycles_ne.all\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; All Requests. Unit: uncore_ha \000event=0x3,umask=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; Requests coming from both local and remote sockets\000 */
{ 3796110 }, /* unc_h_tracker_cycles_ne.local\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Local Requests. Unit: uncore_ha \000event=0x3,umask=0x1\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from the local socket\000 */
{ 3797110 }, /* unc_h_tracker_cycles_ne.remote\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty; Remote Requests. Unit: uncore_ha \000event=0x3,umask=0x2\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring.; This filter includes only requests coming from remote sockets\000 */
{ 3799550 }, /* unc_h_tracker_occupancy.invitoe_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x40\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800176 }, /* unc_h_tracker_occupancy.invitoe_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote InvItoE Requests. Unit: uncore_ha \000event=0x4,umask=0x80\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3800804 }, /* unc_h_tracker_occupancy.reads_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Read Requests. Unit: uncore_ha \000event=0x4,umask=0x4\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3801424 }, /* unc_h_tracker_occupancy.reads_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Read Requests. Unit: uncore_ha \000event=0x4,umask=0x8\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802046 }, /* unc_h_tracker_occupancy.writes_local\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Local Write Requests. Unit: uncore_ha \000event=0x4,umask=0x10\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3802669 }, /* unc_h_tracker_occupancy.writes_remote\000uncore_ha\000uncore cache\000Tracker Occupancy Accumulator; Remote Write Requests. Unit: uncore_ha \000event=0x4,umask=0x20\000\00001\000Accumulates the occupancy of the local HA tracker pool in every cycle.  This can be used in conjection with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA trackers are allocated as soon as a request enters the HA if a HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3803294 }, /* unc_h_tracker_pending_occupancy.local\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Local Requests. Unit: uncore_ha \000event=0x5,umask=0x1\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from the local socket\000 */
{ 3803895 }, /* unc_h_tracker_pending_occupancy.remote\000uncore_ha\000uncore cache\000Data Pending Occupancy Accumulator; Remote Requests. Unit: uncore_ha \000event=0x5,umask=0x2\000\00001\000Accumulates the number of transactions that have data from the memory controller until they get scheduled to the Egress.  This can be used to calculate the queuing latency for two things.  (1) If the system is waiting for snoops, this will increase.  (2) If the system can't schedule to the Egress because of either (a) Egress Credits or (b) QPI BL IGR credits for remote requests.; This filter includes only requests coming from remote sockets\000 */
{ 3804496 }, /* unc_h_txr_ad.hom\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x4\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details.; Filter for outbound NDR transactions sent on the AD ring.  NDR stands for non-data response and is generally used for completions that do not include data.  AD NDR is used for transactions to remote sockets\000 */
{ 3805581 }, /* unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000AD Egress Full; Cycles full from both schedulers\000 */
{ 3805861 }, /* unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3806176 }, /* unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3806491 }, /* unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000AD Egress Not Empty; Cycles full from both schedulers\000 */
{ 3806782 }, /* unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000AD Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3807113 }, /* unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000AD Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3807443 }, /* unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000AD Egress Allocations; Allocations from both schedulers\000 */
{ 3807736 }, /* unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3808063 }, /* unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3809300 }, /* unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000AK Egress Full; Cycles full from both schedulers\000 */
{ 3809580 }, /* unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3809895 }, /* unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3810210 }, /* unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000AK Egress Not Empty; Cycles full from both schedulers\000 */
{ 3810501 }, /* unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000AK Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3810832 }, /* unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000AK Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3811162 }, /* unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000AK Egress Allocations; Allocations from both schedulers\000 */
{ 3811455 }, /* unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3811782 }, /* unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3813194 }, /* unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to the cache\000 */
{ 3813726 }, /* unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent directly to the requesting core\000 */
{ 3814273 }, /* unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to a remote socket over QPI\000 */
{ 3814812 }, /* unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000BL Egress Full; Cycles full from both schedulers\000 */
{ 3815092 }, /* unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3815407 }, /* unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3815722 }, /* unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000BL Egress Not Empty; Cycles full from both schedulers\000 */
{ 3816013 }, /* unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000BL Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3816344 }, /* unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000BL Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3816674 }, /* unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000BL Egress Allocations; Allocations from both schedulers\000 */
{ 3816967 }, /* unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3817294 }, /* unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3826497 }, /* unc_h_txr_starved.ak\000uncore_ha\000uncore cache\000Injection Starvation; For AK Ring. Unit: uncore_ha \000event=0x6d,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3826759 }, /* unc_h_txr_starved.bl\000uncore_ha\000uncore cache\000Injection Starvation; For BL Ring. Unit: uncore_ha \000event=0x6d,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3843414 }, /* unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3845224 }, /* unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3847034 }, /* unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3848844 }, /* unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3850614 }, /* unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3852342 }, /* unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3854070 }, /* unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3855798 }, /* unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 2480779 }, /* qpi_ctl_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of non data (control) flits transmitted . Derived from unc_q_txl_flits_g0.non_data. Unit: uncore_qpi \000event=0,umask=0x4\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 2482340 }, /* qpi_data_bandwidth_tx\000uncore_qpi\000uncore interconnect\000Number of data flits transmitted . Derived from unc_q_txl_flits_g0.data. Unit: uncore_qpi \000event=0,umask=0x2\000\000018Bytes\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 3871403 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3873716 }, /* unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3876751 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000 */
{ 3877660 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878039 }, /* unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878409 }, /* unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878795 }, /* unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879191 }, /* unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879386 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIItoM. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3880060 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000Coherent Ops; RFO. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3881086 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3883149 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x10\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary\000 */
{ 3883756 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x4\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary\000 */
{ 3884348 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x14,umask=0x8\000\00001\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary\000 */
{ 3884906 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Counts Timeouts - Set 0 : Fastpath Rejects\000 */
{ 3885359 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Counts Timeouts - Set 0 : Fastpath Requests\000 */
{ 3885844 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x20\000\00001\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary\000 */
{ 3886416 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x14,umask=0x40\000\00001\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary\000 */
{ 3886820 }, /* unc_i_misc0.pf_timeout\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch TimeOut. Unit: uncore_irp \000event=0x14,umask=0x80\000\00001\000Indicates the fetch for a previous prefetch wasn't accepted by the prefetch.   This happens in the case of a prefetch TimeOut\000 */
{ 3887372 }, /* unc_i_misc1.data_throttle\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Data Throttled. Unit: uncore_irp \000event=0x15,umask=0x80\000\00001\000IRP throttled switch data\000 */
{ 3887762 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1. Unit: uncore_irp \000event=0x15,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888414 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x15,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3889079 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x15,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889739 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890405 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891075 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x15,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891747 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3895230 }, /* unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895678 }, /* unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_CYCLES_FULL. Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896298 }, /* unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896614 }, /* unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_DRS_OCCUPANCY. Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897234 }, /* unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_CYCLES_FULL. Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897854 }, /* unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898170 }, /* unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCB_OCCUPANCY. Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898790 }, /* unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_CYCLES_FULL. Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899410 }, /* unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899726 }, /* unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000UNC_I_RxR_BL_NCS_OCCUPANCY. Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3901893 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x17,umask=0x4\000\00001\000Snoop Responses : Hit E or S\000 */
{ 3902294 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Snoop Responses : Hit I\000 */
{ 3902684 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x17,umask=0x8\000\00001\000Snoop Responses : Hit M\000 */
{ 3903070 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Snoop Responses : Miss\000 */
{ 3903467 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x17,umask=0x10\000\00001\000Snoop Responses : SnpCode\000 */
{ 3903874 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x17,umask=0x20\000\00001\000Snoop Responses : SnpData\000 */
{ 3904277 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x17,umask=0x40\000\00001\000Snoop Responses : SnpInv\000 */
{ 3907099 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x16,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000 */
{ 3908632 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x16,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000 */
{ 3910563 }, /* unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x16,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3913028 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3913535 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Write Prefetches. Unit: uncore_irp \000event=0x16,umask=0x8\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of write prefetches\000 */
{ 3916846 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3921293 }, /* unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3921548 }, /* unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3921798 }, /* unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3921985 }, /* unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3922172 }, /* unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 5688742 }, /* unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/4th the GT/s speed of the QPI link.  For example, a 4GT/s link will have qfclk or 1GHz.  HSX does not support dynamic link speeds, so this frequency is fixed\000 */
{ 5689710 }, /* unc_q_cto_count\000uncore_qpi\000uncore interconnect\000Count of CTO Events. Unit: uncore_qpi \000event=0x38\000\00001\000Counts the number of CTO (cluster trigger outs) events that were asserted across the two slots.  If both slots trigger in a given cycle, the event will increment by 2.  You can use edge detect to count the number of cases when both events triggered\000 */
{ 5690060 }, /* unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits.  Had there been enough credits, the spawn would have worked as the RBT bit was set and the RBT tag matched\000 */
{ 5691288 }, /* unc_q_direct2core.failure_credits_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x20\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and there weren't enough Egress credits.   The valid bit was set\000 */
{ 5691945 }, /* unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits AND the RBT bit was not set, but the RBT tag matched\000 */
{ 5693134 }, /* unc_q_direct2core.failure_credits_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss, Invalid. Unit: uncore_qpi \000event=0x13,umask=0x80\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match, the valid bit was not set and there weren't enough Egress credits\000 */
{ 5693806 }, /* unc_q_direct2core.failure_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x10\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match although the valid bit was set and there were enough Egress credits\000 */
{ 5694968 }, /* unc_q_direct2core.failure_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the route-back table (RBT) specified that the transaction should not trigger a direct2core transaction.  This is common for IO transactions.  There were enough Egress credits and the RBT tag matched but the valid bit was not set\000 */
{ 5695749 }, /* unc_q_direct2core.failure_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss and Invalid. Unit: uncore_qpi \000event=0x13,umask=0x40\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and the valid bit was not set although there were enough Egress credits\000 */
{ 5696913 }, /* unc_q_direct2core.success_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn was successful.  There were sufficient credits, the RBT valid bit was set and there was an RBT tag match.  The message was marked to spawn direct2core\000 */
{ 5697587 }, /* unc_q_l1_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L1. Unit: uncore_qpi \000event=0x12\000\00001\000Number of QPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a QPI link.  Use edge detect to count the number of instances when the QPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 5701151 }, /* unc_q_rxl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xf\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5701702 }, /* unc_q_rxl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0x10\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5702372 }, /* unc_q_rxl_bypassed\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x9\000\00001\000Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 5702855 }, /* unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during link initialization\000 */
{ 5703862 }, /* unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; Normal Operations. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during normal operation\000 */
{ 5705021 }, /* unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the DRS message class\000 */
{ 5705718 }, /* unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the HOM message class\000 */
{ 5706415 }, /* unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCB message class\000 */
{ 5707112 }, /* unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCS message class\000 */
{ 5707809 }, /* unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NDR message class\000 */
{ 5708508 }, /* unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the SNP message class\000 */
{ 5709207 }, /* unc_q_rxl_credits_consumed_vn1.drs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x39,umask=0x1\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the DRS message class\000 */
{ 5709575 }, /* unc_q_rxl_credits_consumed_vn1.hom\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x39,umask=0x8\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the HOM message class\000 */
{ 5709943 }, /* unc_q_rxl_credits_consumed_vn1.ncb\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x39,umask=0x2\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCB message class\000 */
{ 5710311 }, /* unc_q_rxl_credits_consumed_vn1.ncs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x39,umask=0x4\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCS message class\000 */
{ 5710679 }, /* unc_q_rxl_credits_consumed_vn1.ndr\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x39,umask=0x20\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NDR message class\000 */
{ 5711048 }, /* unc_q_rxl_credits_consumed_vn1.snp\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x39,umask=0x10\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the SNP message class\000 */
{ 5711417 }, /* unc_q_rxl_credits_consumed_vna\000uncore_qpi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_qpi \000event=0x1d\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5711727 }, /* unc_q_rxl_cycles_ne\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty. Unit: uncore_qpi \000event=0xa\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy\000 */
{ 5712262 }, /* unc_q_rxl_cycles_ne_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN0. Unit: uncore_qpi \000event=0xf,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5712861 }, /* unc_q_rxl_cycles_ne_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN1. Unit: uncore_qpi \000event=0xf,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5713460 }, /* unc_q_rxl_cycles_ne_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN0. Unit: uncore_qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714060 }, /* unc_q_rxl_cycles_ne_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN1. Unit: uncore_qpi \000event=0x12,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714660 }, /* unc_q_rxl_cycles_ne_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN0. Unit: uncore_qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715260 }, /* unc_q_rxl_cycles_ne_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN1. Unit: uncore_qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715860 }, /* unc_q_rxl_cycles_ne_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN0. Unit: uncore_qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5716460 }, /* unc_q_rxl_cycles_ne_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN1. Unit: uncore_qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5717060 }, /* unc_q_rxl_cycles_ne_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN0. Unit: uncore_qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5717660 }, /* unc_q_rxl_cycles_ne_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN1. Unit: uncore_qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5718260 }, /* unc_q_rxl_cycles_ne_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN0. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5718860 }, /* unc_q_rxl_cycles_ne_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN1. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5723528 }, /* unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of flits received over QPI that do not hold protocol payload.  When QPI is not in a power saving state, it continuously transmits flits across the link.  When there are no protocol flits to send, it will send IDLE and NULL flits  across.  These flits sometimes do carry a payload, such as credit returns, but are generally not considered part of the QPI bandwidth\000 */
{ 5729146 }, /* unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data\000 */
{ 5731892 }, /* unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5734688 }, /* unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5737511 }, /* unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits received over QPI on the home channel\000 */
{ 5740071 }, /* unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits received over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5742745 }, /* unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request received over QPI on the home channel.  This basically counts the number of remote memory requests received over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5745489 }, /* unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits received over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are received on the home channel\000 */
{ 5748168 }, /* unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5750790 }, /* unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5753552 }, /* unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5756302 }, /* unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits received over QPI.    This includes extended headers\000 */
{ 5758922 }, /* unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5761696 }, /* unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5763199 }, /* unc_q_rxl_inserts\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x8\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5763737 }, /* unc_q_rxl_inserts_drs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN0. Unit: uncore_qpi \000event=0x9,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5764339 }, /* unc_q_rxl_inserts_drs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN1. Unit: uncore_qpi \000event=0x9,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5765520 }, /* unc_q_rxl_inserts_hom.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN0. Unit: uncore_qpi \000event=0xc,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5766122 }, /* unc_q_rxl_inserts_hom.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN1. Unit: uncore_qpi \000event=0xc,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5767303 }, /* unc_q_rxl_inserts_ncb.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN0. Unit: uncore_qpi \000event=0xa,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5767905 }, /* unc_q_rxl_inserts_ncb.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN1. Unit: uncore_qpi \000event=0xa,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5769086 }, /* unc_q_rxl_inserts_ncs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN0. Unit: uncore_qpi \000event=0xb,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5769688 }, /* unc_q_rxl_inserts_ncs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN1. Unit: uncore_qpi \000event=0xb,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5770869 }, /* unc_q_rxl_inserts_ndr.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN0. Unit: uncore_qpi \000event=0xe,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5771471 }, /* unc_q_rxl_inserts_ndr.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN1. Unit: uncore_qpi \000event=0xe,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5772652 }, /* unc_q_rxl_inserts_snp.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN0. Unit: uncore_qpi \000event=0xd,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5773254 }, /* unc_q_rxl_inserts_snp.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN1. Unit: uncore_qpi \000event=0xd,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5774435 }, /* unc_q_rxl_occupancy\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - All Packets. Unit: uncore_qpi \000event=0xb\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 5775035 }, /* unc_q_rxl_occupancy_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x15,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5775686 }, /* unc_q_rxl_occupancy_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x15,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5776965 }, /* unc_q_rxl_occupancy_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x18,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5777616 }, /* unc_q_rxl_occupancy_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x18,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5778895 }, /* unc_q_rxl_occupancy_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x16,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5779546 }, /* unc_q_rxl_occupancy_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x16,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5780825 }, /* unc_q_rxl_occupancy_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x17,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5781476 }, /* unc_q_rxl_occupancy_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x17,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5782755 }, /* unc_q_rxl_occupancy_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN0. Unit: uncore_qpi \000event=0x1a,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5783406 }, /* unc_q_rxl_occupancy_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN1. Unit: uncore_qpi \000event=0x1a,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5784685 }, /* unc_q_rxl_occupancy_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x19,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5785336 }, /* unc_q_rxl_occupancy_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x19,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5788063 }, /* unc_q_rxl_stalls_vn0.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788473 }, /* unc_q_rxl_stalls_vn0.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788883 }, /* unc_q_rxl_stalls_vn0.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789293 }, /* unc_q_rxl_stalls_vn0.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789703 }, /* unc_q_rxl_stalls_vn0.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790114 }, /* unc_q_rxl_stalls_vn0.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790525 }, /* unc_q_rxl_stalls_vn0.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet because there were insufficient BGF credits.  For details on a message class granularity, use the Egress Credit Occupancy events\000 */
{ 5790893 }, /* unc_q_rxl_stalls_vn0.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled because a GV transition (frequency transition) was taking place\000 */
{ 5791163 }, /* unc_q_rxl_stalls_vn1.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - HOM. Unit: uncore_qpi \000event=0x3a,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791574 }, /* unc_q_rxl_stalls_vn1.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - DRS. Unit: uncore_qpi \000event=0x3a,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791985 }, /* unc_q_rxl_stalls_vn1.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - SNP. Unit: uncore_qpi \000event=0x3a,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792396 }, /* unc_q_rxl_stalls_vn1.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NDR. Unit: uncore_qpi \000event=0x3a,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792807 }, /* unc_q_rxl_stalls_vn1.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCS. Unit: uncore_qpi \000event=0x3a,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793219 }, /* unc_q_rxl_stalls_vn1.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCB. Unit: uncore_qpi \000event=0x3a,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793631 }, /* unc_q_txl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xc\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5794182 }, /* unc_q_txl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0xd\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5794851 }, /* unc_q_txl_bypassed\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x5\000\00001\000Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the QPI Link. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5795291 }, /* unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is almost full, we block some but not all packets\000 */
{ 5795874 }, /* unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is totally full, we are not allowed to send any packets\000 */
{ 5796435 }, /* unc_q_txl_cycles_ne\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Cycles not Empty. Unit: uncore_qpi \000event=0x6\000\00001\000Counts the number of cycles when the TxQ is not empty. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5798047 }, /* unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 5802153 }, /* unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 5804958 }, /* unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency\000 */
{ 5807622 }, /* unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5810436 }, /* unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5813277 }, /* unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits transmitted over QPI on the home channel\000 */
{ 5815852 }, /* unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits transmitted over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5818541 }, /* unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request transmitted over QPI on the home channel.  This basically counts the number of remote memory requests transmitted over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5821303 }, /* unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits transmitted over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are transmitted on the home channel\000 */
{ 5824009 }, /* unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5826654 }, /* unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5829432 }, /* unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5832198 }, /* unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits transmitted over QPI.    This includes extended headers\000 */
{ 5834837 }, /* unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5837630 }, /* unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5839144 }, /* unc_q_txl_inserts\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x4\000\00001\000Number of allocations into the QPI Tx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5839647 }, /* unc_q_txl_occupancy\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_qpi \000event=0x7\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 5840151 }, /* unc_q_txr_ad_hom_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x26,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840446 }, /* unc_q_txr_ad_hom_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x26,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840741 }, /* unc_q_txr_ad_hom_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN0. Unit: uncore_qpi \000event=0x22,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841076 }, /* unc_q_txr_ad_hom_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN1. Unit: uncore_qpi \000event=0x22,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841411 }, /* unc_q_txr_ad_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x28,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5841709 }, /* unc_q_txr_ad_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x28,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5842007 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x24,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842342 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x24,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842677 }, /* unc_q_txr_ad_snp_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x27,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5842974 }, /* unc_q_txr_ad_snp_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x27,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843271 }, /* unc_q_txr_ad_snp_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN0. Unit: uncore_qpi \000event=0x23,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843608 }, /* unc_q_txr_ad_snp_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN1. Unit: uncore_qpi \000event=0x23,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5844509 }, /* unc_q_txr_ak_ndr_credit_acquired\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x29\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000 */
{ 5845408 }, /* unc_q_txr_ak_ndr_credit_occupancy\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x25\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000 */
{ 5845705 }, /* unc_q_txr_bl_drs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x2a,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5845978 }, /* unc_q_txr_bl_drs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x2a,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846251 }, /* unc_q_txr_bl_drs_credit_acquired.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for Shared VN. Unit: uncore_qpi \000event=0x2a,umask=0x4\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846533 }, /* unc_q_txr_bl_drs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN0. Unit: uncore_qpi \000event=0x1f,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5846847 }, /* unc_q_txr_bl_drs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN1. Unit: uncore_qpi \000event=0x1f,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847161 }, /* unc_q_txr_bl_drs_credit_occupancy.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for Shared VN. Unit: uncore_qpi \000event=0x1f,umask=0x4\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847484 }, /* unc_q_txr_bl_ncb_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x2b,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5847757 }, /* unc_q_txr_bl_ncb_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x2b,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5848030 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN0. Unit: uncore_qpi \000event=0x20,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848344 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN1. Unit: uncore_qpi \000event=0x20,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848658 }, /* unc_q_txr_bl_ncs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x2c,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5848931 }, /* unc_q_txr_bl_ncs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x2c,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5849204 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN0. Unit: uncore_qpi \000event=0x21,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849518 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN1. Unit: uncore_qpi \000event=0x21,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849832 }, /* unc_q_vna_credit_return_occupancy\000uncore_qpi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_qpi \000event=0x1b\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 5850059 }, /* unc_q_vna_credit_returns\000uncore_qpi\000uncore interconnect\000VNA Credits Returned. Unit: uncore_qpi \000event=0x1c\000\00001\000Number of VNA credits returned\000 */
{ 5902377 }, /* unc_r3_c_hi_ad_credits_empty.cbo10\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 10\000 */
{ 5902817 }, /* unc_r3_c_hi_ad_credits_empty.cbo11\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 11\000 */
{ 5903257 }, /* unc_r3_c_hi_ad_credits_empty.cbo12\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 12\000 */
{ 5903699 }, /* unc_r3_c_hi_ad_credits_empty.cbo13\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 13\000 */
{ 5904365 }, /* unc_r3_c_hi_ad_credits_empty.cbo14_16\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 14&16\000 */
{ 5904592 }, /* unc_r3_c_hi_ad_credits_empty.cbo8\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 8\000 */
{ 5905028 }, /* unc_r3_c_hi_ad_credits_empty.cbo9\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 9\000 */
{ 5905464 }, /* unc_r3_c_hi_ad_credits_empty.cbo_15_17\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x1f,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 15&17\000 */
{ 5905692 }, /* unc_r3_c_lo_ad_credits_empty.cbo0\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 0\000 */
{ 5906126 }, /* unc_r3_c_lo_ad_credits_empty.cbo1\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 1\000 */
{ 5906560 }, /* unc_r3_c_lo_ad_credits_empty.cbo2\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 2\000 */
{ 5906994 }, /* unc_r3_c_lo_ad_credits_empty.cbo3\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 3\000 */
{ 5907428 }, /* unc_r3_c_lo_ad_credits_empty.cbo4\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 4\000 */
{ 5907864 }, /* unc_r3_c_lo_ad_credits_empty.cbo5\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 5\000 */
{ 5908300 }, /* unc_r3_c_lo_ad_credits_empty.cbo6\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 6\000 */
{ 5908736 }, /* unc_r3_c_lo_ad_credits_empty.cbo7\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x22,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 7\000 */
{ 5909172 }, /* unc_r3_clockticks\000uncore_r3qpi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_r3qpi \000event=0x1\000\00001\000Counts the number of uclks in the QPI uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the QPI Agent is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5909550 }, /* unc_r3_ha_r2_bl_credits_empty.ha0\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x1\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA0\000 */
{ 5909958 }, /* unc_r3_ha_r2_bl_credits_empty.ha1\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x2\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA1\000 */
{ 5910366 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncb\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x4\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCB Messages\000 */
{ 5910804 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncs\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x8\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCS Messages\000 */
{ 5916510 }, /* unc_r3_iot_backpressure.hub\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x2\000\00001\000\000 */
{ 5916634 }, /* unc_r3_iot_backpressure.sat\000uncore_r3qpi\000uncore interconnect\000IOT Backpressure. Unit: uncore_r3qpi \000event=0xb,umask=0x1\000\00001\000\000 */
{ 5916758 }, /* unc_r3_iot_cts_hi.cts2\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5916918 }, /* unc_r3_iot_cts_hi.cts3\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Hi. Unit: uncore_r3qpi \000event=0xd,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917078 }, /* unc_r3_iot_cts_lo.cts0\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x1\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917238 }, /* unc_r3_iot_cts_lo.cts1\000uncore_r3qpi\000uncore interconnect\000IOT Common Trigger Sequencer - Lo. Unit: uncore_r3qpi \000event=0xc,umask=0x2\000\00001\000Debug Mask/Match Tie-Ins\000 */
{ 5917398 }, /* unc_r3_qpi0_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x2\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 HOM Messages\000 */
{ 5917814 }, /* unc_r3_qpi0_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x8\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 NDR Messages\000 */
{ 5918230 }, /* unc_r3_qpi0_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x4\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 SNP Messages\000 */
{ 5918646 }, /* unc_r3_qpi0_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x10\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 HOM Messages\000 */
{ 5919064 }, /* unc_r3_qpi0_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x40\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 NDR Messages\000 */
{ 5919482 }, /* unc_r3_qpi0_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x20\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 SNP Messages\000 */
{ 5919900 }, /* unc_r3_qpi0_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x20,umask=0x1\000\00001\000No credits available to send to QPI0 on the AD Ring; VNA\000 */
{ 5920906 }, /* unc_r3_qpi0_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x10\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 HOM Messages\000 */
{ 5921324 }, /* unc_r3_qpi0_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x40\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 NDR Messages\000 */
{ 5921742 }, /* unc_r3_qpi0_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x20\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 SNP Messages\000 */
{ 5922160 }, /* unc_r3_qpi0_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x21,umask=0x1\000\00001\000No credits available to send to QPI0 on the BL Ring; VNA\000 */
{ 5923375 }, /* unc_r3_qpi1_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x10\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 HOM Messages\000 */
{ 5923793 }, /* unc_r3_qpi1_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x40\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 NDR Messages\000 */
{ 5924211 }, /* unc_r3_qpi1_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x20\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 SNP Messages\000 */
{ 5924611 }, /* unc_r3_qpi1_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x1\000\00001\000No credits available to send to QPI1 on the AD Ring; VNA\000 */
{ 5925010 }, /* unc_r3_qpi1_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x2\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 HOM Messages\000 */
{ 5925426 }, /* unc_r3_qpi1_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x8\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 NDR Messages\000 */
{ 5925842 }, /* unc_r3_qpi1_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x4\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 SNP Messages\000 */
{ 5926259 }, /* unc_r3_qpi1_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x10\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 HOM Messages\000 */
{ 5926677 }, /* unc_r3_qpi1_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x40\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 NDR Messages\000 */
{ 5927095 }, /* unc_r3_qpi1_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x20\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 SNP Messages\000 */
{ 5927495 }, /* unc_r3_qpi1_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x1\000\00001\000No credits available to send to QPI1 on the BL Ring; VNA\000 */
{ 5928033 }, /* unc_r3_ring_ad_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5928754 }, /* unc_r3_ring_ad_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5929560 }, /* unc_r3_ring_ad_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5931641 }, /* unc_r3_ring_ad_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5931993 }, /* unc_r3_ring_ad_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5932776 }, /* unc_r3_ring_ad_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5934798 }, /* unc_r3_ring_ak_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5935893 }, /* unc_r3_ring_ak_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5936697 }, /* unc_r3_ring_ak_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5938406 }, /* unc_r3_ring_ak_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5939124 }, /* unc_r3_ring_ak_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5939905 }, /* unc_r3_ring_ak_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5941563 }, /* unc_r3_ring_bl_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5942284 }, /* unc_r3_ring_bl_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5943090 }, /* unc_r3_ring_bl_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5945171 }, /* unc_r3_ring_bl_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5945523 }, /* unc_r3_ring_bl_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5946306 }, /* unc_r3_ring_bl_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5949115 }, /* unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5950665 }, /* unc_r3_ring_iv_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5951017 }, /* unc_r3_ring_sink_starved.ak\000uncore_r3qpi\000uncore interconnect\000Ring Stop Starved; AK. Unit: uncore_r3qpi \000event=0xe,umask=0x2\000\00001\000Number of cycles the ringstop is in starvation (per ring)\000 */
{ 5952208 }, /* unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5954130 }, /* unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5955100 }, /* unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5956070 }, /* unc_r3_rxr_cycles_ne_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; DRS. Unit: uncore_r3qpi \000event=0x14,umask=0x8\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5956583 }, /* unc_r3_rxr_cycles_ne_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5957096 }, /* unc_r3_rxr_cycles_ne_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCB. Unit: uncore_r3qpi \000event=0x14,umask=0x10\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5957610 }, /* unc_r3_rxr_cycles_ne_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NCS. Unit: uncore_r3qpi \000event=0x14,umask=0x20\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5958124 }, /* unc_r3_rxr_cycles_ne_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x14,umask=0x4\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5958637 }, /* unc_r3_rxr_cycles_ne_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles when the QPI VN1  Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5959150 }, /* unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5960086 }, /* unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5961022 }, /* unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5961960 }, /* unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5962898 }, /* unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5963834 }, /* unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5964770 }, /* unc_r3_rxr_inserts_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x15,umask=0x8\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5965266 }, /* unc_r3_rxr_inserts_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x15,umask=0x1\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5965762 }, /* unc_r3_rxr_inserts_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x15,umask=0x10\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5966259 }, /* unc_r3_rxr_inserts_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x15,umask=0x20\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5966756 }, /* unc_r3_rxr_inserts_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x15,umask=0x4\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5967252 }, /* unc_r3_rxr_inserts_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x15,umask=0x2\000\00001\000Counts the number of allocations into the QPI VN1  Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5973044 }, /* unc_r3_rxr_occupancy_vn1.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5973518 }, /* unc_r3_rxr_occupancy_vn1.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; HOM Ingress Queue\000 */
{ 5973992 }, /* unc_r3_rxr_occupancy_vn1.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCB Ingress Queue\000 */
{ 5974467 }, /* unc_r3_rxr_occupancy_vn1.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NCS Ingress Queue\000 */
{ 5974942 }, /* unc_r3_rxr_occupancy_vn1.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; NDR Ingress Queue\000 */
{ 5975416 }, /* unc_r3_rxr_occupancy_vn1.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI VN1  Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI VN1  Ingress Not Empty event to calculate average occupancy or the QPI VN1  Ingress Allocations event in order to calculate average queuing latency.; SNP Ingress Queue\000 */
{ 5975890 }, /* unc_r3_sbo0_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5976095 }, /* unc_r3_sbo0_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5976300 }, /* unc_r3_sbo0_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5976506 }, /* unc_r3_sbo0_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5976712 }, /* unc_r3_sbo1_credit_occupancy.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For AD Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x1\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 5976917 }, /* unc_r3_sbo1_credit_occupancy.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Occupancy; For BL Ring. Unit: uncore_r3qpi \000event=0x2b,umask=0x2\000\00001\000Number of Sbo 1 credits in use in a given cycle, per ring\000 */
{ 5977122 }, /* unc_r3_sbo1_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For AD Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x1\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 5977328 }, /* unc_r3_sbo1_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000SBo1 Credits Acquired; For BL Ring. Unit: uncore_r3qpi \000event=0x29,umask=0x2\000\00001\000Number of Sbo 1 credits acquired in a given cycle, per ring\000 */
{ 5977534 }, /* unc_r3_stall_no_sbo_credit.sbo0_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5977792 }, /* unc_r3_stall_no_sbo_credit.sbo0_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978050 }, /* unc_r3_stall_no_sbo_credit.sbo1_ad\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978308 }, /* unc_r3_stall_no_sbo_credit.sbo1_bl\000uncore_r3qpi\000uncore interconnect\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r3qpi \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5978566 }, /* unc_r3_txr_nack.dn_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AD CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5978724 }, /* unc_r3_txr_nack.dn_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5978882 }, /* unc_r3_txr_nack.dn_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5979040 }, /* unc_r3_txr_nack.up_ad\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; AK CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5979198 }, /* unc_r3_txr_nack.up_ak\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CW. Unit: uncore_r3qpi \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000 */
{ 5979349 }, /* unc_r3_txr_nack.up_bl\000uncore_r3qpi\000uncore interconnect\000Egress CCW NACK; BL CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5980411 }, /* unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5982203 }, /* unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5983926 }, /* unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5985675 }, /* unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5987347 }, /* unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5989049 }, /* unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 5990780 }, /* unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5992862 }, /* unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5994875 }, /* unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5996914 }, /* unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5998876 }, /* unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6000868 }, /* unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6002889 }, /* unc_r3_vn1_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x8\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6003877 }, /* unc_r3_vn1_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x1\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6004796 }, /* unc_r3_vn1_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x10\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6005740 }, /* unc_r3_vn1_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x20\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6006607 }, /* unc_r3_vn1_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x4\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6007505 }, /* unc_r3_vn1_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x2\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6008432 }, /* unc_r3_vn1_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x8\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6009569 }, /* unc_r3_vn1_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x1\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6010637 }, /* unc_r3_vn1_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x10\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6011730 }, /* unc_r3_vn1_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x20\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6012746 }, /* unc_r3_vn1_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x4\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6013793 }, /* unc_r3_vn1_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x2\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6015739 }, /* unc_r3_vna_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x1\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6016691 }, /* unc_r3_vna_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x4\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6018440 }, /* unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6020284 }, /* unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6022059 }, /* unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6023860 }, /* unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Standard (NCS)\000 */
{ 6025555 }, /* unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6027309 }, /* unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6029092 }, /* unc_s_bounce_control\000uncore_sbox\000uncore interconnect\000Bounce Control. Unit: uncore_sbox \000event=0xa\000\00001\000\000 */
{ 6029195 }, /* unc_s_clockticks\000uncore_sbox\000uncore interconnect\000Uncore Clocks. Unit: uncore_sbox \000event=0\000\00001\000\000 */
{ 6029291 }, /* unc_s_fast_asserted\000uncore_sbox\000uncore interconnect\000FaST wire asserted. Unit: uncore_sbox \000event=0x9\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 6030374 }, /* unc_s_ring_ad_used.down\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down. Unit: uncore_sbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6032128 }, /* unc_s_ring_ad_used.down_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6033939 }, /* unc_s_ring_ad_used.down_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6034842 }, /* unc_s_ring_ad_used.up\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up. Unit: uncore_sbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6036584 }, /* unc_s_ring_ad_used.up_even\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6038381 }, /* unc_s_ring_ad_used.up_odd\000uncore_sbox\000uncore interconnect\000AD Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6040121 }, /* unc_s_ring_ak_used.down\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down. Unit: uncore_sbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6041873 }, /* unc_s_ring_ak_used.down_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Event. Unit: uncore_sbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6043682 }, /* unc_s_ring_ak_used.down_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Down and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6044584 }, /* unc_s_ring_ak_used.up\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up. Unit: uncore_sbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6046324 }, /* unc_s_ring_ak_used.up_even\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Even. Unit: uncore_sbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6048119 }, /* unc_s_ring_ak_used.up_odd\000uncore_sbox\000uncore interconnect\000AK Ring In Use; Up and Odd. Unit: uncore_sbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6049858 }, /* unc_s_ring_bl_used.down\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down. Unit: uncore_sbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6051610 }, /* unc_s_ring_bl_used.down_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Event. Unit: uncore_sbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Event ring polarity\000 */
{ 6053419 }, /* unc_s_ring_bl_used.down_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Down and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity\000 */
{ 6054321 }, /* unc_s_ring_bl_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up. Unit: uncore_sbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 6056061 }, /* unc_s_ring_bl_used.up_even\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Even. Unit: uncore_sbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity\000 */
{ 6057856 }, /* unc_s_ring_bl_used.up_odd\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Up and Odd. Unit: uncore_sbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop. We really have two rings in HSX -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity\000 */
{ 6058752 }, /* unc_s_ring_bounces.ad_cache\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring. Unit: uncore_sbox \000event=0x5,umask=0x1\000\00001\000\000 */
{ 6058906 }, /* unc_s_ring_bounces.ak_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_sbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 6059086 }, /* unc_s_ring_bounces.bl_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_sbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 6059264 }, /* unc_s_ring_bounces.iv_core\000uncore_sbox\000uncore interconnect\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_sbox \000event=0x5,umask=0x8\000\00001\000\000 */
{ 6059447 }, /* unc_s_ring_iv_used.dn\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 6060009 }, /* unc_s_ring_iv_used.up\000uncore_sbox\000uncore interconnect\000BL Ring in Use; Any. Unit: uncore_sbox \000event=0x1e,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  There is only 1 IV ring in HSX.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD.; Filters any polarity\000 */
{ 6060571 }, /* unc_s_ring_sink_starved.ad_cache\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AD_CACHE. Unit: uncore_sbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 6060714 }, /* unc_s_ring_sink_starved.ak_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.AK_CORE. Unit: uncore_sbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 6060855 }, /* unc_s_ring_sink_starved.bl_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.BL_CORE. Unit: uncore_sbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 6060996 }, /* unc_s_ring_sink_starved.iv_core\000uncore_sbox\000uncore interconnect\000UNC_S_RING_SINK_STARVED.IV_CORE. Unit: uncore_sbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 6061137 }, /* unc_s_rxr_busy_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6061536 }, /* unc_s_rxr_busy_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x15,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6061935 }, /* unc_s_rxr_busy_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x15,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6062334 }, /* unc_s_rxr_busy_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x15,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress because a message (credited/bounceable) is  being sent\000 */
{ 6062733 }, /* unc_s_rxr_bypass.ad_bnc\000uncore_sbox\000uncore interconnect\000Bypass; AD - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x2\000\00001\000Bypass the Sbo Ingress\000 */
{ 6062878 }, /* unc_s_rxr_bypass.ad_crd\000uncore_sbox\000uncore interconnect\000Bypass; AD - Credits. Unit: uncore_sbox \000event=0x12,umask=0x1\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063023 }, /* unc_s_rxr_bypass.ak\000uncore_sbox\000uncore interconnect\000Bypass; AK. Unit: uncore_sbox \000event=0x12,umask=0x10\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063155 }, /* unc_s_rxr_bypass.bl_bnc\000uncore_sbox\000uncore interconnect\000Bypass; BL - Bounces. Unit: uncore_sbox \000event=0x12,umask=0x8\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063300 }, /* unc_s_rxr_bypass.bl_crd\000uncore_sbox\000uncore interconnect\000Bypass; BL - Credits. Unit: uncore_sbox \000event=0x12,umask=0x4\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063445 }, /* unc_s_rxr_bypass.iv\000uncore_sbox\000uncore interconnect\000Bypass; IV. Unit: uncore_sbox \000event=0x12,umask=0x20\000\00001\000Bypass the Sbo Ingress\000 */
{ 6063577 }, /* unc_s_rxr_crd_starved.ad_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6063942 }, /* unc_s_rxr_crd_starved.ad_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; AD - Credits. Unit: uncore_sbox \000event=0x14,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6064307 }, /* unc_s_rxr_crd_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; AK. Unit: uncore_sbox \000event=0x14,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6064659 }, /* unc_s_rxr_crd_starved.bl_bnc\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Bounces. Unit: uncore_sbox \000event=0x14,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065024 }, /* unc_s_rxr_crd_starved.bl_crd\000uncore_sbox\000uncore interconnect\000Injection Starvation; BL - Credits. Unit: uncore_sbox \000event=0x14,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065389 }, /* unc_s_rxr_crd_starved.ifv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IVF Credit. Unit: uncore_sbox \000event=0x14,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6065750 }, /* unc_s_rxr_crd_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; IV. Unit: uncore_sbox \000event=0x14,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the Ingress cannot send a transaction onto the ring for a long period of time.  In this case, the Ingress but unable to forward to Egress due to lack of credit\000 */
{ 6066102 }, /* unc_s_rxr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x2\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066346 }, /* unc_s_rxr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x13,umask=0x1\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066590 }, /* unc_s_rxr_inserts.ak\000uncore_sbox\000uncore interconnect\000Ingress Allocations; AK. Unit: uncore_sbox \000event=0x13,umask=0x10\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6066821 }, /* unc_s_rxr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x13,umask=0x8\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067065 }, /* unc_s_rxr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x13,umask=0x4\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067309 }, /* unc_s_rxr_inserts.iv\000uncore_sbox\000uncore interconnect\000Ingress Allocations; IV. Unit: uncore_sbox \000event=0x13,umask=0x20\000\00001\000Number of allocations into the Sbo Ingress  The Ingress is used to queue up requests received from the ring\000 */
{ 6067540 }, /* unc_s_rxr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6067793 }, /* unc_s_rxr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x11,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068046 }, /* unc_s_rxr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; AK. Unit: uncore_sbox \000event=0x11,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068286 }, /* unc_s_rxr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x11,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068539 }, /* unc_s_rxr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x11,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6068792 }, /* unc_s_rxr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Ingress Occupancy; IV. Unit: uncore_sbox \000event=0x11,umask=0x20\000\00001\000Occupancy event for the Ingress buffers in the Sbo.  The Ingress is used to queue up requests received from the ring\000 */
{ 6069032 }, /* unc_s_txr_ads_used.ad\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AD. Unit: uncore_sbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 6069153 }, /* unc_s_txr_ads_used.ak\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.AK. Unit: uncore_sbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 6069274 }, /* unc_s_txr_ads_used.bl\000uncore_sbox\000uncore interconnect\000UNC_S_TxR_ADS_USED.BL. Unit: uncore_sbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 6069395 }, /* unc_s_txr_inserts.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6069635 }, /* unc_s_txr_inserts.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; AD - Credits. Unit: uncore_sbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6069875 }, /* unc_s_txr_inserts.ak\000uncore_sbox\000uncore interconnect\000Egress Allocations; AK. Unit: uncore_sbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070102 }, /* unc_s_txr_inserts.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Bounces. Unit: uncore_sbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070342 }, /* unc_s_txr_inserts.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Allocations; BL - Credits. Unit: uncore_sbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070582 }, /* unc_s_txr_inserts.iv\000uncore_sbox\000uncore interconnect\000Egress Allocations; IV. Unit: uncore_sbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Sbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 6070809 }, /* unc_s_txr_occupancy.ad_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071057 }, /* unc_s_txr_occupancy.ad_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AD - Credits. Unit: uncore_sbox \000event=0x1,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071305 }, /* unc_s_txr_occupancy.ak\000uncore_sbox\000uncore interconnect\000Egress Occupancy; AK. Unit: uncore_sbox \000event=0x1,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071540 }, /* unc_s_txr_occupancy.bl_bnc\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Bounces. Unit: uncore_sbox \000event=0x1,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6071788 }, /* unc_s_txr_occupancy.bl_crd\000uncore_sbox\000uncore interconnect\000Egress Occupancy; BL - Credits. Unit: uncore_sbox \000event=0x1,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6072036 }, /* unc_s_txr_occupancy.iv\000uncore_sbox\000uncore interconnect\000Egress Occupancy; IV. Unit: uncore_sbox \000event=0x1,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Sbo.  The egress is used to queue up requests destined for the ring\000 */
{ 6072271 }, /* unc_s_txr_starved.ad\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AD Ring. Unit: uncore_sbox \000event=0x3,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6072544 }, /* unc_s_txr_starved.ak\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto AK Ring. Unit: uncore_sbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6072817 }, /* unc_s_txr_starved.bl\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto BL Ring. Unit: uncore_sbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6073090 }, /* unc_s_txr_starved.iv\000uncore_sbox\000uncore interconnect\000Injection Starvation; Onto IV Ring. Unit: uncore_sbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 6073510 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000UNC_U_CLOCKTICKS. Unit: uncore_ubox \000event=0\000\00001\000\000 */
{ 6074014 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076954 }, /* unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077187 }, /* unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077419 }, /* unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077656 }, /* unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6081974 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6082839 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000 */
{ 6083291 }, /* unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6083494 }, /* unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6083890 }, /* unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084282 }, /* unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084686 }, /* unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6085090 }, /* unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores; PREQ, PSMI, P2U, Thermal, PCUSMI, PMI\000 */
{ 6085499 }, /* unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085682 }, /* unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 5850201 }, /* unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5850571 }, /* unc_r2_iio_credit.isoch_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x4\000\00001\000\000 */
{ 5850701 }, /* unc_r2_iio_credit.isoch_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.ISOCH_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x8\000\00001\000\000 */
{ 5850831 }, /* unc_r2_iio_credit.prq_qpi0\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI0. Unit: uncore_r2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 5850957 }, /* unc_r2_iio_credit.prq_qpi1\000uncore_r2pcie\000uncore io\000UNC_R2_IIO_CREDIT.PRQ_QPI1. Unit: uncore_r2pcie \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 5851083 }, /* unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5852294 }, /* unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5853507 }, /* unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5856769 }, /* unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5857982 }, /* unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5859197 }, /* unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5860751 }, /* unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5861456 }, /* unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5862246 }, /* unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5865200 }, /* unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5865544 }, /* unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5866311 }, /* unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5868837 }, /* unc_r2_ring_ak_bounces.dn\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Dn. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869035 }, /* unc_r2_ring_ak_bounces.up\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Up. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5869572 }, /* unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5870277 }, /* unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5871067 }, /* unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5874021 }, /* unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5874365 }, /* unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5875132 }, /* unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5877997 }, /* unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5878702 }, /* unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity\000 */
{ 5879492 }, /* unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity\000 */
{ 5882446 }, /* unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5882790 }, /* unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity\000 */
{ 5883557 }, /* unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity\000 */
{ 5886083 }, /* unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5887540 }, /* unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5889079 }, /* unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x3\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5890495 }, /* unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5891469 }, /* unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5892443 }, /* unc_r2_rxr_inserts.ncb\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCB. Unit: uncore_r2pcie \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5892923 }, /* unc_r2_rxr_inserts.ncs\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCS. Unit: uncore_r2pcie \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5893403 }, /* unc_r2_rxr_occupancy.drs\000uncore_r2pcie\000uncore io\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r2pcie \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given R2PCIe Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the R2PCIe Ingress Not Empty event to calculate average occupancy or the R2PCIe Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5893855 }, /* unc_r2_sbo0_credit_occupancy.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For AD Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x1\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894052 }, /* unc_r2_sbo0_credit_occupancy.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Occupancy; For BL Ring. Unit: uncore_r2pcie \000event=0x2a,umask=0x2\000\00001\000Number of Sbo 0 credits in use in a given cycle, per ring\000 */
{ 5894249 }, /* unc_r2_sbo0_credits_acquired.ad\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For AD Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894447 }, /* unc_r2_sbo0_credits_acquired.bl\000uncore_r2pcie\000uncore io\000SBo0 Credits Acquired; For BL Ring. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000Number of Sbo 0 credits acquired in a given cycle, per ring\000 */
{ 5894645 }, /* unc_r2_stall_no_sbo_credit.sbo0_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x1\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5894895 }, /* unc_r2_stall_no_sbo_credit.sbo0_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo0, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x4\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895145 }, /* unc_r2_stall_no_sbo_credit.sbo1_ad\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, AD Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x2\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895395 }, /* unc_r2_stall_no_sbo_credit.sbo1_bl\000uncore_r2pcie\000uncore io\000Stall on No Sbo Credits; For SBo1, BL Ring. Unit: uncore_r2pcie \000event=0x2c,umask=0x8\000\00001\000Number of cycles Egress is stalled waiting for an Sbo credit to become available.  Per Sbo, per Ring\000 */
{ 5895645 }, /* unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AD Egress Queue\000 */
{ 5896035 }, /* unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AK Egress Queue\000 */
{ 5896425 }, /* unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; BL Egress Queue\000 */
{ 5896815 }, /* unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AD Egress Queue\000 */
{ 5897859 }, /* unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AK Egress Queue\000 */
{ 5898903 }, /* unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; BL Egress Queue\000 */
{ 5900823 }, /* unc_r2_txr_nack_cw.dn_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5900976 }, /* unc_r2_txr_nack_cw.dn_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5901129 }, /* unc_r2_txr_nack_cw.dn_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901282 }, /* unc_r2_txr_nack_cw.up_ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x8\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5901435 }, /* unc_r2_txr_nack_cw.up_ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x20\000\00001\000AD Clockwise Egress Queue\000 */
{ 5901581 }, /* unc_r2_txr_nack_cw.up_bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x26,umask=0x10\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 1210502 }, /* llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 1211826 }, /* llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5376386 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377260 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5380151 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5382226 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 5385713 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5386574 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5386724 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the number of underfill reads that are issued by the memory controller.  This will generally be about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ.  While it is possible for underfills to be issed in both WMM and RMM, this event counts both\000 */
{ 5388684 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5389726 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5391708 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392506 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5394556 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5395982 }, /* unc_m_dclockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417303 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430087 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5430855 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5439445 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of page misses.  This does not include explicit precharge commands sent with CAS commands in Auto-Precharge mode.  This does not include PRE commands sent as a result of the page close counter expiration\000 */
{ 5442207 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5444600 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449351 }, /* unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5449781 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5451793 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5450047 }, /* unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5450338 }, /* unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5450629 }, /* unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5450920 }, /* unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5451211 }, /* unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5451502 }, /* unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5452206 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5452619 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5453160 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5453574 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5453988 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5454274 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5454688 }, /* unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5454974 }, /* unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5455260 }, /* unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5455604 }, /* unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5455948 }, /* unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5456295 }, /* unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5456645 }, /* unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5457075 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5459087 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5457341 }, /* unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5457632 }, /* unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5457923 }, /* unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5458214 }, /* unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5458505 }, /* unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5458796 }, /* unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5459500 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5459913 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5460454 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5460868 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5461282 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5461568 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5461982 }, /* unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5462268 }, /* unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5462554 }, /* unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5462898 }, /* unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5463242 }, /* unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5463589 }, /* unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5464200 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5471646 }, /* unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5472076 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5474088 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5472342 }, /* unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5472633 }, /* unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5472924 }, /* unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5473215 }, /* unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5473506 }, /* unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5473797 }, /* unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5474501 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5474914 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5475455 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5475869 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5476283 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5476569 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5476983 }, /* unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5477269 }, /* unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5477555 }, /* unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5477899 }, /* unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5478243 }, /* unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5478590 }, /* unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5478940 }, /* unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5479370 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5481382 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5479636 }, /* unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5479927 }, /* unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5480218 }, /* unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5480509 }, /* unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5480800 }, /* unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5481091 }, /* unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5481795 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5482208 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5482749 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5483163 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5483577 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5483863 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5484277 }, /* unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5484563 }, /* unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5484849 }, /* unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5485193 }, /* unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5485537 }, /* unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5485884 }, /* unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5486234 }, /* unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5486664 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5488676 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5486930 }, /* unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5487221 }, /* unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5487512 }, /* unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5487803 }, /* unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5488094 }, /* unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5488385 }, /* unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5489089 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5489502 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5490043 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5490457 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5490871 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5491157 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5491571 }, /* unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5491857 }, /* unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5492143 }, /* unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5492487 }, /* unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5492831 }, /* unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5493178 }, /* unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5493528 }, /* unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000RD_CAS Access to Rank 0 : All Banks\000 */
{ 5493958 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000RD_CAS Access to Rank 0 : Bank 0\000 */
{ 5495970 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000RD_CAS Access to Rank 0 : Bank 1\000 */
{ 5494224 }, /* unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000RD_CAS Access to Rank 0 : Bank 10\000 */
{ 5494515 }, /* unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000RD_CAS Access to Rank 0 : Bank 11\000 */
{ 5494806 }, /* unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000RD_CAS Access to Rank 0 : Bank 12\000 */
{ 5495097 }, /* unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000RD_CAS Access to Rank 0 : Bank 13\000 */
{ 5495388 }, /* unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000RD_CAS Access to Rank 0 : Bank 14\000 */
{ 5495679 }, /* unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000RD_CAS Access to Rank 0 : Bank 15\000 */
{ 5496383 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000RD_CAS Access to Rank 0 : Bank 2\000 */
{ 5496796 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000RD_CAS Access to Rank 0 : Bank 3\000 */
{ 5497337 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000RD_CAS Access to Rank 0 : Bank 4\000 */
{ 5497751 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000RD_CAS Access to Rank 0 : Bank 5\000 */
{ 5498165 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000RD_CAS Access to Rank 0 : Bank 6\000 */
{ 5498451 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000RD_CAS Access to Rank 0 : Bank 7\000 */
{ 5498865 }, /* unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000RD_CAS Access to Rank 0 : Bank 8\000 */
{ 5499151 }, /* unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000RD_CAS Access to Rank 0 : Bank 9\000 */
{ 5499437 }, /* unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000RD_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5499781 }, /* unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000RD_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5500125 }, /* unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000RD_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5500472 }, /* unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000RD_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5508571 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5534086 }, /* unc_m_vmse_mxb_wr_occupancy\000uncore_imc\000uncore memory\000VMSE MXB write buffer occupancy. Unit: uncore_imc \000event=0x91\000\00001\000\000 */
{ 5534206 }, /* unc_m_vmse_wr_push.rmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in RMM. Unit: uncore_imc \000event=0x90,umask=0x2\000\00001\000\000 */
{ 5534350 }, /* unc_m_vmse_wr_push.wmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in WMM. Unit: uncore_imc \000event=0x90,umask=0x1\000\00001\000\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5534994 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5540700 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556495 }, /* unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5556925 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5558937 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5557191 }, /* unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5557482 }, /* unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5557773 }, /* unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5558064 }, /* unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5558355 }, /* unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5558646 }, /* unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5559350 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5559763 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5560304 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5560718 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5561132 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5561418 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5561832 }, /* unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5562118 }, /* unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5562404 }, /* unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5562748 }, /* unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5563092 }, /* unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5563439 }, /* unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5563789 }, /* unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5564219 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5566231 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5564485 }, /* unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5564776 }, /* unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5565067 }, /* unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5565358 }, /* unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5565649 }, /* unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5565940 }, /* unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5566644 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5567057 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5567598 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5568012 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5568426 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5568712 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5569126 }, /* unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5569412 }, /* unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5569698 }, /* unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5570042 }, /* unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5570386 }, /* unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5570733 }, /* unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5578641 }, /* unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5579071 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5581083 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5579337 }, /* unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5579628 }, /* unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5579919 }, /* unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5580210 }, /* unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5580501 }, /* unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5580792 }, /* unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5581496 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5581909 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5582450 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5582864 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5583278 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5583564 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5583978 }, /* unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5584264 }, /* unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5584550 }, /* unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5584894 }, /* unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5585238 }, /* unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5585585 }, /* unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5585935 }, /* unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5586365 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5588377 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5586631 }, /* unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5586922 }, /* unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5587213 }, /* unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5587504 }, /* unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5587795 }, /* unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5588086 }, /* unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5588790 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5589203 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5589744 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5590158 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5590572 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5590858 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5591272 }, /* unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5591558 }, /* unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5591844 }, /* unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5592188 }, /* unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5592532 }, /* unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5592879 }, /* unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5593229 }, /* unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5593659 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5595671 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5593925 }, /* unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5594216 }, /* unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5594507 }, /* unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5594798 }, /* unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5595089 }, /* unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5595380 }, /* unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5596084 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5596497 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5597038 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5597452 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5597866 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5598152 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5598566 }, /* unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5598852 }, /* unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5599138 }, /* unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5599482 }, /* unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5599826 }, /* unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5600173 }, /* unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5600523 }, /* unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000WR_CAS Access to Rank 0 : All Banks\000 */
{ 5600953 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000WR_CAS Access to Rank 0 : Bank 0\000 */
{ 5602965 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000WR_CAS Access to Rank 0 : Bank 1\000 */
{ 5601219 }, /* unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000WR_CAS Access to Rank 0 : Bank 10\000 */
{ 5601510 }, /* unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000WR_CAS Access to Rank 0 : Bank 11\000 */
{ 5601801 }, /* unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000WR_CAS Access to Rank 0 : Bank 12\000 */
{ 5602092 }, /* unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000WR_CAS Access to Rank 0 : Bank 13\000 */
{ 5602383 }, /* unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000WR_CAS Access to Rank 0 : Bank 14\000 */
{ 5602674 }, /* unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000WR_CAS Access to Rank 0 : Bank 15\000 */
{ 5603378 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000WR_CAS Access to Rank 0 : Bank 2\000 */
{ 5603791 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000WR_CAS Access to Rank 0 : Bank 3\000 */
{ 5604332 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000WR_CAS Access to Rank 0 : Bank 4\000 */
{ 5604746 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000WR_CAS Access to Rank 0 : Bank 5\000 */
{ 5605160 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000WR_CAS Access to Rank 0 : Bank 6\000 */
{ 5605446 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000WR_CAS Access to Rank 0 : Bank 7\000 */
{ 5605860 }, /* unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000WR_CAS Access to Rank 0 : Bank 8\000 */
{ 5606146 }, /* unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000WR_CAS Access to Rank 0 : Bank 9\000 */
{ 5606432 }, /* unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000WR_CAS Access to Rank 0 : Bank Group 0 (Banks 0-3)\000 */
{ 5606776 }, /* unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000WR_CAS Access to Rank 0 : Bank Group 1 (Banks 4-7)\000 */
{ 5607120 }, /* unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000WR_CAS Access to Rank 0 : Bank Group 2 (Banks 8-11)\000 */
{ 5607467 }, /* unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000WR_CAS Access to Rank 0 : Bank Group 3 (Banks 12-15)\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5642030 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 800 MHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5642773 }, /* unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x60\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643193 }, /* unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643614 }, /* unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644035 }, /* unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644456 }, /* unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644877 }, /* unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645086 }, /* unc_p_core15_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6f\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645295 }, /* unc_p_core16_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645504 }, /* unc_p_core17_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646130 }, /* unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646755 }, /* unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647173 }, /* unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647798 }, /* unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x64\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648423 }, /* unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x65\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649048 }, /* unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x66\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649673 }, /* unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x67\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650298 }, /* unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x68\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650716 }, /* unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x69\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5656797 }, /* unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x30\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659691 }, /* unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x31\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657159 }, /* unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3a\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657522 }, /* unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3b\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657885 }, /* unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3c\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658248 }, /* unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3d\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658611 }, /* unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658791 }, /* unc_p_demotions_core15\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x3f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658971 }, /* unc_p_demotions_core16\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659151 }, /* unc_p_demotions_core17\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660230 }, /* unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x32\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660769 }, /* unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x33\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661308 }, /* unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x34\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661847 }, /* unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x35\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662386 }, /* unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x36\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662925 }, /* unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x37\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663285 }, /* unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x38\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663645 }, /* unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x39\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5665096 }, /* unc_p_freq_band0_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xb\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5665711 }, /* unc_p_freq_band1_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xc\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666326 }, /* unc_p_freq_band2_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xd\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666941 }, /* unc_p_freq_band3_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xe\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668753 }, /* unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670355 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673025 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5675706 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676395 }, /* unc_p_pkg_residency_c1e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C1E. Unit: uncore_pcu \000event=0x4e\000\00001\000Counts the number of cycles when the package was in C1E.  This event can be used in conjunction with edge detect to count C1E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676727 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677425 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678114 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678803 }, /* unc_p_pkg_residency_c7_cycles\000uncore_pcu\000uncore power\000Package C7 State Residency. Unit: uncore_pcu \000event=0x2e\000\00001\000Counts the number of cycles when the package was in C7.  This event can be used in conjunction with edge detect to count C7 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685850 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5686491 }, /* unc_p_ufs_transitions_no_change\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_NO_CHANGE. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000 */
{ 5686659 }, /* unc_p_ufs_transitions_ring_gv\000uncore_pcu\000uncore power\000UNC_P_UFS_TRANSITIONS_RING_GV. Unit: uncore_pcu \000event=0x79\000\00001\000Ring GV with same final and initial frequency\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 788623 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Misses in all TLB levels that cause a page walk of any page size\000 */
{ 789155 }, /* dtlb_load_misses.pde_cache_miss\000\000virtual memory\000DTLB demand load misses with low part of linear-to-physical address translation missed\000event=0x8,period=100003,umask=0x80\000\00000\000DTLB demand load misses with low part of linear-to-physical address translation missed\000 */
{ 790505 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=2000003,umask=0x60\000\00000\000Number of cache load STLB hits. No page walk\000 */
{ 792032 }, /* dtlb_load_misses.stlb_hit_2m\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (2M)\000event=0x8,period=2000003,umask=0x40\000\00000\000This event counts load operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 792438 }, /* dtlb_load_misses.stlb_hit_4k\000\000virtual memory\000Load misses that miss the  DTLB and hit the STLB (4K)\000event=0x8,period=2000003,umask=0x20\000\00000\000This event counts load operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 795162 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0xe\000\00000\000Completed page walks in any TLB of any page size due to demand load misses\000 */
{ 798011 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (1G)\000event=0x8,period=2000003,umask=0x8\000\00000\000\000 */
{ 800737 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (2M/4M)\000event=0x8,period=2000003,umask=0x4\000\00000\000Completed page walks due to demand load misses that caused 2M/4M page walks in any TLB levels\000 */
{ 804055 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes (4K)\000event=0x8,period=2000003,umask=0x2\000\00000\000Completed page walks due to demand load misses that caused 4K page walks in any TLB levels\000 */
{ 806459 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000 */
{ 810986 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Miss in all TLB levels causes a page walk of any page size (4K/2M/4M/1G)\000 */
{ 811536 }, /* dtlb_store_misses.pde_cache_miss\000\000virtual memory\000DTLB store misses with low part of linear-to-physical address translation missed\000event=0x49,period=100003,umask=0x80\000\00000\000DTLB store misses with low part of linear-to-physical address translation missed\000 */
{ 812500 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x60\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000 */
{ 814069 }, /* dtlb_store_misses.stlb_hit_2m\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (2M)\000event=0x49,period=100003,umask=0x40\000\00000\000This event counts store operations from a 2M page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 814480 }, /* dtlb_store_misses.stlb_hit_4k\000\000virtual memory\000Store misses that miss the  DTLB and hit the STLB (4K)\000event=0x49,period=100003,umask=0x20\000\00000\000This event counts store operations from a 4K page that miss the first DTLB level but hit the second and do not cause page walks\000 */
{ 817477 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0xe\000\00000\000Completed page walks due to store miss in any TLB levels of any page size (4K/2M/4M/1G)\000 */
{ 821175 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks. (1G)\000event=0x49,period=100003,umask=0x8\000\00000\000\000 */
{ 824557 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks (2M/4M)\000event=0x49,period=100003,umask=0x4\000\00000\000Completed page walks due to store misses in one or more TLB levels of 2M/4M page structure\000 */
{ 827627 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (4K)\000event=0x49,period=100003,umask=0x2\000\00000\000Completed page walks due to store misses in one or more TLB levels of 4K page structure\000 */
{ 828492 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB store misses\000 */
{ 833618 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1077852 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100003,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000 */
{ 1081206 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in ITLB that causes a page walk of any page size\000 */
{ 1083416 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x60\000\00000\000ITLB misses that hit STLB. No page walk\000 */
{ 1084367 }, /* itlb_misses.stlb_hit_2m\000\000virtual memory\000Code misses that miss the  DTLB and hit the STLB (2M)\000event=0x85,period=100003,umask=0x40\000\00000\000ITLB misses that hit STLB (2M)\000 */
{ 1084667 }, /* itlb_misses.stlb_hit_4k\000\000virtual memory\000Core misses that miss the  DTLB and hit the STLB (4K)\000event=0x85,period=100003,umask=0x20\000\00000\000ITLB misses that hit STLB (4K)\000 */
{ 1087987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0xe\000\00000\000Completed page walks in ITLB of any page size\000 */
{ 1090053 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Store miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000\000 */
{ 1091248 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Completed page walks due to misses in ITLB 2M/4M page entries\000 */
{ 1094072 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Completed page walks due to misses in ITLB 4K page entries\000 */
{ 1096069 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=100003,umask=0x10\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by ITLB misses\000 */
{ 2468196 }, /* page_walker_loads.dtlb_l1\000\000virtual memory\000Number of DTLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x11\000\00000\000Number of DTLB page walker loads that hit in the L1+FB\000 */
{ 2468532 }, /* page_walker_loads.dtlb_l2\000\000virtual memory\000Number of DTLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x12\000\00000\000Number of DTLB page walker loads that hit in the L2\000 */
{ 2468869 }, /* page_walker_loads.dtlb_l3\000\000virtual memory\000Number of DTLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x14\000\00000\000Number of DTLB page walker loads that hit in the L3  Spec update: HSD25\000 */
{ 2469250 }, /* page_walker_loads.dtlb_memory\000\000virtual memory\000Number of DTLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x18\000\00000\000Number of DTLB page walker loads from memory  Spec update: HSD25\000 */
{ 2469464 }, /* page_walker_loads.ept_dtlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x41\000\00000\000\000 */
{ 2469639 }, /* page_walker_loads.ept_dtlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L2\000event=0xbc,period=2000003,umask=0x42\000\00000\000\000 */
{ 2469807 }, /* page_walker_loads.ept_dtlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in the L3\000event=0xbc,period=2000003,umask=0x44\000\00000\000\000 */
{ 2469975 }, /* page_walker_loads.ept_dtlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the DTLB that hit in memory\000event=0xbc,period=2000003,umask=0x48\000\00000\000\000 */
{ 2470147 }, /* page_walker_loads.ept_itlb_l1\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L1 and FB\000event=0xbc,period=2000003,umask=0x81\000\00000\000\000 */
{ 2470322 }, /* page_walker_loads.ept_itlb_l2\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x82\000\00000\000\000 */
{ 2470490 }, /* page_walker_loads.ept_itlb_l3\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in the L2\000event=0xbc,period=2000003,umask=0x84\000\00000\000\000 */
{ 2470658 }, /* page_walker_loads.ept_itlb_memory\000\000virtual memory\000Counts the number of Extended Page Table walks from the ITLB that hit in memory\000event=0xbc,period=2000003,umask=0x88\000\00000\000\000 */
{ 2470986 }, /* page_walker_loads.itlb_l1\000\000virtual memory\000Number of ITLB page walker hits in the L1+FB\000event=0xbc,period=2000003,umask=0x21\000\00000\000Number of ITLB page walker loads that hit in the L1+FB\000 */
{ 2471322 }, /* page_walker_loads.itlb_l2\000\000virtual memory\000Number of ITLB page walker hits in the L2\000event=0xbc,period=2000003,umask=0x22\000\00000\000Number of ITLB page walker loads that hit in the L2\000 */
{ 2471659 }, /* page_walker_loads.itlb_l3\000\000virtual memory\000Number of ITLB page walker hits in the L3 + XSNP  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x24\000\00000\000Number of ITLB page walker loads that hit in the L3  Spec update: HSD25\000 */
{ 2471883 }, /* page_walker_loads.itlb_memory\000\000virtual memory\000Number of ITLB page walker hits in Memory  Spec update: HSD25\000event=0xbc,period=2000003,umask=0x28\000\00000\000Number of ITLB page walker loads from memory  Spec update: HSD25\000 */
{ 2540134 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100003,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000 */
{ 2541032 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100003,umask=0x20\000\00000\000Count number of STLB flush attempts\000 */
};

static const struct compact_pmu_event pmu_metrics__haswellx[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 14264 }, /* \000dtlb_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14680 }, /* \000dtlb_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 17417 }, /* \000io_bandwidth_read\000\000cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x19e@ * 64 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000 */
{ 18826 }, /* \000io_bandwidth_write\000\000cbox@UNC_C_TOR_INSERTS.OPCODE\\,filter_opc\\=0x1c8\\,filter_tid\\=0x3e@ * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19992 }, /* \000itlb_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 20492 }, /* \000itlb_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23335 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25728 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_UOPS_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26145 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 27715 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x181@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x191@) / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28587 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 29730 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 31020 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cbox@UNC_C_TOR_OCCUPANCY.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@) / (UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 32657 }, /* \000llc_data_read_mpi_demand_plus_prefetch\000\000(cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_OPCODE\\,filter_opc\\=0x192@) / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 36195 }, /* \000loads_per_instr\000\000MEM_UOPS_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 40864 }, /* \000numa_reads_addressed_to_local_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 42080 }, /* \000numa_reads_addressed_to_remote_dram\000\000cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@ / (cbox@UNC_C_TOR_INSERTS.MISS_LOCAL_OPCODE\\,filter_opc\\=0x182@ + cbox@UNC_C_TOR_INSERTS.MISS_REMOTE_OPCODE\\,filter_opc\\=0x182@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43424 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43946 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44198 }, /* \000percent_uops_delivered_from_loop_stream_detector\000\000(UOPS_ISSUED.ANY - IDQ.MITE_UOPS - IDQ.MS_UOPS - IDQ.DSB_UOPS) / UOPS_ISSUED.ANY\000\000Uops delivered from loop stream detector(LSD) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44896 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 45620 }, /* \000qpi_data_transmit_bw\000\000UNC_Q_TxL_FLITS_G0.DATA * 8 / 1e6 / duration_time\000\000Intel(R) Quick Path Interconnect (QPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49192 }, /* \000stores_per_instr\000\000MEM_UOPS_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51523 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 87604 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 43 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 101792 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 115591 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\00010 * ARITH.DIVIDER_UOPS / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 119617 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 131664 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(8 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 140197 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(8 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 145955 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(200 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_MISS.REMOTE_HITM + 60 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 156284 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.REQUEST_FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194575 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 223135 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000(UOPS_EXECUTED.CORE / 2 / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@) if #SMT_on else UOPS_EXECUTED.CORE / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@))\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248732 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 253557 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258687 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267423 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182\\,thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 270482 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_INSERTS.MISS_OPCODE@filter_opc\\=0x182@) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275234 }, /* \000tma_info_system_socket_clks\000SoC\000cbox_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 281782 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(14 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 287936 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) - CYCLE_ACTIVITY.STALLS_L1D_PENDING) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 290473 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_PENDING - CYCLE_ACTIVITY.STALLS_L2_PENDING) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 296272 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.L3_HIT / (MEM_LOAD_UOPS_RETIRED.L3_HIT + 7 * MEM_LOAD_UOPS_RETIRED.L3_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 305980 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00041 * (MEM_LOAD_UOPS_RETIRED.L3_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 316428 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 320002 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\000200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00001 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 335504 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 341091 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379797 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382600 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 387139 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390181 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 397341 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@)) / 2 - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB if #SMT_on else min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - (cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 401522 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 407482 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 414085 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418848 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 421613 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(200 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) + 180 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00001 */
{ 429446 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000310 * (MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.L3_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_L3_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00001 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 442148 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 462490 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000INST_RETIRED.X87 * tma_info_thread_uoppi / UOPS_RETIRED.RETIRE_SLOTS\000tma_x87_use > 0.1\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 465652 }, /* \000uncore_frequency\000\000UNC_C_CLOCKTICKS / (#num_cores / #num_packages * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__icelake[] = {
{ 1100860 }, /* l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105377 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106609 }, /* l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107376 }, /* l1d_pend_miss.l2_stall\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1110782 }, /* l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112359 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1134424 }, /* l2_lines_out.non_silent\000\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000 */
{ 1136984 }, /* l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1137997 }, /* l2_lines_out.useless_hwpf\000\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses\000event=0xf2,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159594 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1160355 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165401 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1170124 }, /* l2_rqsts.miss\000\000cache\000This event is deprecated\000event=0x24,period=200003,umask=0x3f\000\00010\000\000 */
{ 1173337 }, /* l2_rqsts.references\000\000cache\000This event is deprecated\000event=0x24,period=200003,umask=0xff\000\00010\000\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177137 }, /* l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177638 }, /* l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312052 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315394 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1321627 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1322950 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1324093 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326535 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1330329 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or Bus Lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1332237 }, /* mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1333977 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335514 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336567 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337424 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338416 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339662 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1516538 }, /* ocr.demand_code_rd.l3_hit.any\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0004\000\00000\000\000 */
{ 1517912 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 1518919 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1520231 }, /* ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 1520925 }, /* ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 1521460 }, /* ocr.demand_code_rd.l3_hit.snoop_sent\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0004\000\00000\000\000 */
{ 1544094 }, /* ocr.demand_data_rd.l3_hit.any\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0001\000\00000\000\000 */
{ 1545403 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1548626 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1550484 }, /* ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 1551071 }, /* ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 1551504 }, /* ocr.demand_data_rd.l3_hit.snoop_sent\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0001\000\00000\000\000 */
{ 1574428 }, /* ocr.demand_rfo.l3_hit.any\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0002\000\00000\000\000 */
{ 1576127 }, /* ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 1577226 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1579321 }, /* ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 1580087 }, /* ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 1580389 }, /* ocr.demand_rfo.l3_hit.snoop_sent\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0002\000\00000\000\000 */
{ 1603778 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.any\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0400\000\00000\000\000 */
{ 1604338 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_miss\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00000\000\000 */
{ 1604617 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_not_needed\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000 */
{ 1610636 }, /* ocr.hwpf_l2_data_rd.l3_hit.any\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0010\000\00000\000\000 */
{ 1611153 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 1612023 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 1612585 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 1613117 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 1613377 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0010\000\00000\000\000 */
{ 1615598 }, /* ocr.hwpf_l2_rfo.l3_hit.any\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0020\000\00000\000\000 */
{ 1616094 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 1616933 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 1617474 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 1617985 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 1618234 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0020\000\00000\000\000 */
{ 1620260 }, /* ocr.hwpf_l3.l3_hit.any\000\000cache\000Counts hardware prefetches to the L3 only that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C2380\000\00000\000\000 */
{ 1626136 }, /* ocr.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000 */
{ 1626694 }, /* ocr.other.l3_hit.snoop_miss\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000 */
{ 1627100 }, /* ocr.other.l3_hit.snoop_not_needed\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000 */
{ 1627357 }, /* ocr.other.l3_hit.snoop_sent\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C8000\000\00000\000\000 */
{ 1739218 }, /* ocr.streaming_wr.l3_hit.any\000\000cache\000Counts streaming stores that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0800\000\00000\000\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746303 }, /* offcore_requests.all_requests\000\000cache\000Counts memory transactions sent to the uncore\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions sent to the uncore including requests initiated by the core, all L3 prefetches, reads resulting from page walks, and snoop responses\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1754378 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000For every cycle, increments by the number of outstanding data read requests pending\000event=0x60,period=1000003,umask=0x8\000\00000\000For every cycle, increments by the number of outstanding data read requests pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1760397 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles where at least 1 outstanding data read request is pending\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Cycles where at least 1 outstanding data read request is pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1764791 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles where at least 1 outstanding Demand RFO request is pending\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Cycles where at least 1 outstanding Demand RFO request is pending.   RFOs are initiated by a core as part of a data store operation.  Demand RFO requests include RFOs, locks, and ItoM transactions.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1772768 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x60,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1778347 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Store Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x4\000\00000\000Counts the number of off-core outstanding read-for-ownership (RFO) store transactions every cycle. An RFO transaction is considered to be in the Off-core outstanding state between L2 cache miss and transaction completion\000 */
{ 2530749 }, /* sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2532185 }, /* sq_misc.sq_full\000\000cache\000Cycles the queue waiting for offcore responses is full\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the queue waiting for responses from the uncore cannot take any more entries\000 */
{ 2537136 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2537780 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538434 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539067 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 472289 }, /* assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 854349 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 860385 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 862608 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 866643 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 872056 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 875751 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 878977 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 883416 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 887276 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 890230 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 893916 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898444 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775692 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781964 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE transitions count\000event=0xab,cmask=1,edge=1,period=100003,umask=0x2\000\00000\000Counts the number of Decode Stream Buffer (DSB a.k.a. Uop Cache)-to-MITE speculative transitions\000 */
{ 782565 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0xab,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943187 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944203 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 949857 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 945210 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x508006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 947605 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x501006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 953608 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 951670 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x510006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 958117 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x502006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 960274 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 962471 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x520006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 964690 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x504006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967070 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992514 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_DATA.STALLS]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_DATA.STALLS]\000 */
{ 993172 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 993710 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000Counts instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 994253 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000 */
{ 994901 }, /* icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_16B.IFDATA_STALL]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_16B.IFDATA_STALL]\000 */
{ 996232 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000 */
{ 1003938 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1004475 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1006310 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010161 }, /* idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1010842 }, /* idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1012316 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1017043 }, /* idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024432 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025109 }, /* idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=100003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1029922 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1035288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=5,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036953 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 751759 }, /* cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=1000003,umask=0x2\000\00000\000\000 */
{ 757545 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 971248 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one)\000event=0xc8,period=100003,umask=0x4\000\00000\000Counts the number of times HLE abort was triggered\000 */
{ 971465 }, /* hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=100003,umask=0x80\000\00000\000Counts the number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000 */
{ 971889 }, /* hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=100003,umask=0x8\000\00000\000Counts the number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000 */
{ 974829 }, /* hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=100003,umask=0x20\000\00000\000Counts the number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000 */
{ 975537 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=100003,umask=0x2\000\00000\000Counts the number of times HLE commit succeeded\000 */
{ 975991 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an HLE region. Does not count nested transactions\000 */
{ 1296966 }, /* machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1529201 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00004\000\00000\000\000 */
{ 1559278 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00001\000\00000\000\000 */
{ 1589461 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00002\000\00000\000\000 */
{ 1605163 }, /* ocr.hwpf_l1d_and_swpf.l3_miss\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00400\000\00000\000\000 */
{ 1614029 }, /* ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts hardware prefetch data reads (which bring data to L2)  that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00010\000\00000\000\000 */
{ 1618855 }, /* ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts hardware prefetch RFOs (which bring data to L2) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00020\000\00000\000\000 */
{ 1633820 }, /* ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC08000\000\00000\000\000 */
{ 1740302 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00800\000\00000\000\000 */
{ 1752416 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000\000 */
{ 1768078 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles where at least one demand data read request known to have missed the L3 cache is pending\000event=0x60,cmask=1,period=1000003,umask=0x10\000\00000\000Cycles where at least one demand data read request known to have missed the L3 cache is pending.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2515369 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2515927 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516525 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519396 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2572419 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=100003,umask=0x2\000\00000\000Counts Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2573092 }, /* tx_exec.misc3\000\000memory\000Number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=100003,umask=0x4\000\00000\000Counts Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 2576510 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=100003,umask=0x10\000\00000\000Counts the number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577677 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=100003,umask=0x8\000\00000\000Counts the number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2578735 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=100003,umask=0x20\000\00000\000Counts the number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2579607 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=100003,umask=0x4\000\00000\000Counts the number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2580724 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=100003,umask=0x40\000\00000\000Counts the number of times we could not allocate Lock Buffer\000 */
{ 572304 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Counts Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 573029 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Counts Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573765 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server microarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 1515566 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1515766 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1533808 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543304 }, /* ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1564662 }, /* ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1572540 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1573743 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1595303 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1603145 }, /* ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1603360 }, /* ocr.hwpf_l1d_and_swpf.dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000 */
{ 1605929 }, /* ocr.hwpf_l1d_and_swpf.local_dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000 */
{ 1610055 }, /* ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 1610447 }, /* ocr.hwpf_l2_data_rd.dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614657 }, /* ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1615049 }, /* ocr.hwpf_l2_rfo.any_response\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 1615420 }, /* ocr.hwpf_l2_rfo.dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619452 }, /* ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1624769 }, /* ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1624959 }, /* ocr.other.dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000 */
{ 1637626 }, /* ocr.other.local_dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1739070 }, /* ocr.streaming_wr.dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000 */
{ 1741244 }, /* ocr.streaming_wr.local_dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000 */
{ 468280 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0x14,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 471702 }, /* assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x7\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502931 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504333 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 504924 }, /* br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 508295 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511305 }, /* br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 515219 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 517928 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 519163 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 535753 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=50021\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542758 }, /* br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 544064 }, /* br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545483 }, /* br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 548979 }, /* br_misp_retired.indirect\000\000pipeline\000All miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000event=0xc5,period=50021,umask=0x80\000\00000\000Counts all miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000 */
{ 550538 }, /* br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 555535 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 560471 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=50021,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 616704 }, /* cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 617767 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 621045 }, /* cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 626122 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638164 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000Counts core crystal clock cycles when the thread is unhalted\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 748732 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750161 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 752892 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754470 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 755810 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 758739 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=1000003,umask=0x14\000\00000\000\000 */
{ 759202 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847674 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 1041607 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1050414 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055840 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057998 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1060581 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with a reduced effect of PEBS shadow in IP distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1062948 }, /* inst_retired.stall_cycles\000\000pipeline\000Cycles without actually retired instructions\000event=0xc0,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000This event counts cycles without actually retired instructions\000 */
{ 1064821 }, /* int_misc.all_recovery_cycles\000\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000 */
{ 1065804 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xd,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1067113 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1069580 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xd,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072919 }, /* int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xd,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1194117 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1201415 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies due to partial compare on address\000 */
{ 1231173 }, /* load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285110 }, /* lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=5,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286007 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1288826 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431801 }, /* misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR to be enabled properly\000 */
{ 1432509 }, /* misc_retired.pause_inst\000\000pipeline\000Number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000event=0xcc,period=100003,umask=0x40\000\00000\000Counts number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000 */
{ 2504245 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506218 }, /* resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2510439 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=1000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into stravation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2513050 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty\000event=0x5e,cmask=1,edge=1,inv=1,period=100003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2543188 }, /* topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Counts the number of Top-down Microarchitecture Analysis (TMA) method's  slots where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2546876 }, /* topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by branch mispredictions. This event estimates number of operations that were issued but not retired from the speculative path as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6178334 }, /* uops_decoded.dec0\000\000pipeline\000Number of uops decoded out of instructions exclusively fetched by decoder 0\000event=0x56,period=1000003,umask=0x1\000\00000\000Uops exclusively fetched by decoder 0\000 */
{ 6179516 }, /* uops_dispatched.port_0\000\000pipeline\000Number of uops executed on port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6180060 }, /* uops_dispatched.port_1\000\000pipeline\000Number of uops executed on port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6180604 }, /* uops_dispatched.port_2_3\000\000pipeline\000Number of uops executed on port 2 and 3\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 2 and 3\000 */
{ 6181215 }, /* uops_dispatched.port_4_9\000\000pipeline\000Number of uops executed on port 4 and 9\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 5 and 9\000 */
{ 6181807 }, /* uops_dispatched.port_5\000\000pipeline\000Number of uops executed on port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6182390 }, /* uops_dispatched.port_6\000\000pipeline\000Number of uops executed on port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6182937 }, /* uops_dispatched.port_7_8\000\000pipeline\000Number of uops executed on port 7 and 8\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 7 and 8\000 */
{ 6193009 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000 */
{ 6194148 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195247 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196350 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6197453 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200004 }, /* uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201055 }, /* uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202126 }, /* uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203199 }, /* uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207380 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6213867 }, /* uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6219243 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread\000event=0xe,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6221020 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to 'Mixing Intel AVX and Intel SSE Code' section of the Optimization Guide\000 */
{ 6236200 }, /* uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6238210 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6239807 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2582207 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop,  etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2582856 }, /* unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2583336 }, /* unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000 */
{ 2584516 }, /* unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2585084 }, /* unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2586171 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2589284 }, /* unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2590033 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of all outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591436 }, /* unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 3540688 }, /* unc_clock.socket\000uncore_clock\000uncore other\000UNC_CLOCK.SOCKET. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 791106 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793108 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802110 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x8,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805386 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x8,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 808161 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x8,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813152 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815445 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 823499 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 826601 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 830031 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x49,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1082642 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085650 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1097779 }, /* itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x85,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__icelake[] = {
{ 3582 }, /* \000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 4490 }, /* \000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000 */
{ 4591 }, /* \000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 50452 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5 + UOPS_DISPATCHED.PORT_6) / (4 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 53706 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * ASSISTS.ANY / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 59207 }, /* \000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 5 * cpu@INT_MISC.RECOVERY_CYCLES\\,cmask\\=1\\,edge@ / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 64724 }, /* \000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 68110 }, /* \000tma_branch_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * BR_INST_RETIRED.ALL_BRANCHES / (tma_retiring * tma_info_thread_slots)\000tma_branch_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions\000\000100%\000\000\000\00000 */
{ 69335 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 81165 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(29 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM + 23.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98081 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000 */
{ 100830 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00023.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 114219 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122993 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124667 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 134887 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 139263 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 147700 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00032.5 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 153696 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 158121 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 163606 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000(5 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE - INT_MISC.UOP_DROPPING) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 172771 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 177787 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180064 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 182343 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 184622 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 186270 }, /* \000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 192366 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer + tma_retiring * (UOPS_DECODED.DEC0 - cpu@UOPS_DECODED.DEC0\\,cmask\\=1@) / IDQ.MITE_UOPS\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 195231 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_16B.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197105 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 198371 }, /* \000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198640 }, /* \000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198902 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199501 }, /* \000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 200566 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 202880 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 207397 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 211900 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 214466 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216037 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216577 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 217012 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000 */
{ 217249 }, /* \000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000 */
{ 217937 }, /* \000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219831 }, /* \000tma_info_core_flopc\000Flops;Ret\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 222547 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 226105 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 5 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 227202 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227819 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229446 }, /* \000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232323 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239974 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242664 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 11\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247858 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * (OFFCORE_REQUESTS.ALL_DATA_RD - OFFCORE_REQUESTS.DEMAND_DATA_RD + L2_RQSTS.ALL_DEMAND_MISS + L2_RQSTS.SWPF_MISS) / tma_info_inst_mix_instructions\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251156 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251574 }, /* \000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,umask\\=0x10@ / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 254261 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256405 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257211 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 262284 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 272373 }, /* \000tma_info_system_power_license0_utilization\000Power\000CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 273292 }, /* \000tma_info_system_power_license1_utilization\000Power\000CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274252 }, /* \000tma_info_system_power_license2_utilization\000Power\000CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274904 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277349 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277503 }, /* \000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000 */
{ 277851 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278166 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 7.5\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 291636 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + L1D_PEND_MISS.FB_FULL_PERIODS) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 309429 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0009 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 314141 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317952 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3 / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 318802 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 325792 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 328183 }, /* \000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(LSD.CYCLES_ACTIVE - LSD.CYCLES_OK) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000 */
{ 329816 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 342540 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000 */
{ 348825 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001 */
{ 352279 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 357790 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 359354 }, /* \000tma_mite_4wide\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_mite_group\000(cpu@IDQ.MITE_UOPS\\,cmask\\=4@ - cpu@IDQ.MITE_UOPS\\,cmask\\=5@) / tma_info_thread_clks\000tma_mite_4wide > 0.05 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where (only) 4 uops were delivered by the MITE pipeline\000\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 366608 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369076 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_branch_instructions + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 377934 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 380965 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 385354 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 388354 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 392550 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 402317 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 408697 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 416142 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 419352 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 432289 }, /* \000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 436702 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 437735 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000140 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000 */
{ 440531 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 446331 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000L1D_PEND_MISS.L2_STALL / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 451466 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 455967 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 457909 }, /* \000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 458764 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\00010 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__icelakex[] = {
{ 1100860 }, /* l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105377 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106609 }, /* l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107376 }, /* l1d_pend_miss.l2_stall\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1110782 }, /* l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112359 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1133063 }, /* l2_lines_out.non_silent\000\000cache\000Cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by the L2 cache due to L2 cache fills.  Evicted lines are delivered to the L3, which may or may not cache them, according to system load and priorities\000 */
{ 1136984 }, /* l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159594 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165401 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177137 }, /* l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177638 }, /* l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1251955 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312052 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315394 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1319998 }, /* mem_load_l3_hit_retired.xsnp_fwd\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1322006 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000This event is deprecated. Refer to new event MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00010\000\000 */
{ 1323290 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000This event is deprecated. Refer to new event MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00010\000\000 */
{ 1324093 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1324910 }, /* mem_load_l3_hit_retired.xsnp_no_fwd\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326535 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327262 }, /* mem_load_l3_miss_retired.local_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1328144 }, /* mem_load_l3_miss_retired.remote_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from remote dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x2\000\00000\000\000 */
{ 1328360 }, /* mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000 */
{ 1329165 }, /* mem_load_l3_miss_retired.remote_hitm\000\000cache\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000 */
{ 1329464 }, /* mem_load_l3_miss_retired.remote_pmm\000\000cache\000Retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x10\000\00000\000Counts retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000 */
{ 1330329 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or Bus Lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1332237 }, /* mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1333977 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335514 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336567 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337424 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338416 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339662 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1341019 }, /* mem_load_retired.local_pmm\000\000cache\000Retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x80\000\00000\000Counts retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3 (AppDirect or Memory Mode) and DRAM cache(Memory Mode)  Supports address when precise (Precise event)\000 */
{ 1521942 }, /* ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000 */
{ 1519498 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1535865 }, /* ocr.demand_code_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000004\000\00000\000\000 */
{ 1536561 }, /* ocr.demand_code_rd.snc_cache.hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000004\000\00000\000\000 */
{ 1551896 }, /* ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 1545861 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that resulted in a snoop that hit in another core, which did not forward the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1547050 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1549115 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1567142 }, /* ocr.demand_data_rd.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x830000001\000\00000\000\000 */
{ 1567713 }, /* ocr.demand_data_rd.remote_cache.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1030000001\000\00000\000\000 */
{ 1569018 }, /* ocr.demand_data_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand data reads that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000001\000\00000\000\000 */
{ 1569624 }, /* ocr.demand_data_rd.snc_cache.hitm\000\000cache\000Counts demand data reads that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000001\000\00000\000\000 */
{ 1581399 }, /* ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 1577875 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1598492 }, /* ocr.demand_rfo.snc_cache.hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000002\000\00000\000\000 */
{ 1599258 }, /* ocr.demand_rfo.snc_cache.hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000002\000\00000\000\000 */
{ 1604899 }, /* ocr.hwpf_l1d_and_swpf.l3_hit\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000 */
{ 1620670 }, /* ocr.hwpf_l3.l3_hit\000\000cache\000Counts hardware prefetches to the L3 only that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80082380\000\00000\000\000 */
{ 1718079 }, /* ocr.prefetches.l3_hit\000\000cache\000Counts hardware and software prefetches to all cache levels that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C27F0\000\00000\000\000 */
{ 1724129 }, /* ocr.reads_to_core.l3_hit\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F003C0477\000\00000\000\000 */
{ 1720555 }, /* ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop that hit in another core, which did not forward the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0477\000\00000\000\000 */
{ 1721551 }, /* ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0477\000\00000\000\000 */
{ 1722567 }, /* ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0477\000\00000\000\000 */
{ 1731887 }, /* ocr.reads_to_core.remote_cache.snoop_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop was sent and data was returned (Modified or Not Modified)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1830000477\000\00000\000\000 */
{ 1732641 }, /* ocr.reads_to_core.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x830000477\000\00000\000\000 */
{ 1733408 }, /* ocr.reads_to_core.remote_cache.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1030000477\000\00000\000\000 */
{ 1735877 }, /* ocr.reads_to_core.snc_cache.hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x808000477\000\00000\000\000 */
{ 1736679 }, /* ocr.reads_to_core.snc_cache.hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008000477\000\00000\000\000 */
{ 1739602 }, /* ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that hit in the L3 or were snooped from another core's caches on the same socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080800\000\00000\000\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746303 }, /* offcore_requests.all_requests\000\000cache\000Counts memory transactions sent to the uncore\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions sent to the uncore including requests initiated by the core, all L3 prefetches, reads resulting from page walks, and snoop responses\000 */
{ 1749318 }, /* offcore_requests.demand_code_rd\000\000cache\000Counts cacheable and non-cacheable code reads to the core\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code reads to the core\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1754378 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000For every cycle, increments by the number of outstanding data read requests pending\000event=0x60,period=1000003,umask=0x8\000\00000\000For every cycle, increments by the number of outstanding data read requests pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1760397 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles where at least 1 outstanding data read request is pending\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Cycles where at least 1 outstanding data read request is pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1761845 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with outstanding code read requests pending\000event=0x60,cmask=1,period=1000003,umask=0x2\000\00000\000Cycles with outstanding code read requests pending.  Code Read requests include both cacheable and non-cacheable Code Reads.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1764791 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles where at least 1 outstanding Demand RFO request is pending\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Cycles where at least 1 outstanding Demand RFO request is pending.   RFOs are initiated by a core as part of a data store operation.  Demand RFO requests include RFOs, locks, and ItoM transactions.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1769864 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000For every cycle, increments by the number of outstanding code read requests pending\000event=0x60,period=1000003,umask=0x2\000\00000\000For every cycle, increments by the number of outstanding code read requests pending.  Code Read requests include both cacheable and non-cacheable Code Reads.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1772768 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x60,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 2530749 }, /* sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2532185 }, /* sq_misc.sq_full\000\000cache\000Cycles the queue waiting for offcore responses is full\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the queue waiting for responses from the uncore cannot take any more entries\000 */
{ 2537136 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2537780 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538434 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539067 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 472289 }, /* assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 854349 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 860385 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 862608 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 866643 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 872056 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 875751 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 878977 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 883416 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 887276 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 890230 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 893916 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898444 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775692 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781964 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE transitions count\000event=0xab,cmask=1,edge=1,period=100003,umask=0x2\000\00000\000Counts the number of Decode Stream Buffer (DSB a.k.a. Uop Cache)-to-MITE speculative transitions\000 */
{ 782565 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0xab,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943187 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944203 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 949857 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 945210 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x508006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 947605 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x501006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 953608 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 951670 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x510006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 958117 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x502006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 960274 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 962471 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x520006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 964690 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x504006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967070 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992514 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_DATA.STALLS]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_DATA.STALLS]\000 */
{ 993172 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 993710 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000Counts instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 994253 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000 */
{ 994901 }, /* icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_16B.IFDATA_STALL]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_16B.IFDATA_STALL]\000 */
{ 996232 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000 */
{ 1003938 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1004475 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1006310 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010161 }, /* idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1010842 }, /* idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1012316 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1024432 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025109 }, /* idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=100003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1029922 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1035288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=5,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036953 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 757545 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 1296966 }, /* machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1529854 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000 */
{ 1530305 }, /* ocr.demand_code_rd.l3_miss_local\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400004\000\00000\000\000 */
{ 1559960 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1560880 }, /* ocr.demand_data_rd.l3_miss_local\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400001\000\00000\000\000 */
{ 1589975 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FC00002\000\00000\000\000 */
{ 1591256 }, /* ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by the local socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F04400002\000\00000\000\000 */
{ 1605386 }, /* ocr.hwpf_l1d_and_swpf.l3_miss\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00400\000\00000\000\000 */
{ 1605637 }, /* ocr.hwpf_l1d_and_swpf.l3_miss_local\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84400400\000\00000\000\000 */
{ 1621068 }, /* ocr.hwpf_l3.l3_miss\000\000memory\000Counts hardware prefetches to the L3 only that missed the local socket's L1, L2, and L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x94002380\000\00000\000\000 */
{ 1621494 }, /* ocr.hwpf_l3.l3_miss_local\000\000memory\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84002380\000\00000\000\000 */
{ 1622222 }, /* ocr.itom.l3_miss_local\000\000memory\000Counts full cacheline writes (ItoM) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000 */
{ 1634018 }, /* ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC08000\000\00000\000\000 */
{ 1634433 }, /* ocr.other.l3_miss_local\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F84408000\000\00000\000\000 */
{ 1718493 }, /* ocr.prefetches.l3_miss_local\000\000memory\000Counts hardware and software prefetches to all cache levels that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F844027F0\000\00000\000\000 */
{ 1724964 }, /* ocr.reads_to_core.l3_miss\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FC00477\000\00000\000\000 */
{ 1725833 }, /* ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by the local socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F04400477\000\00000\000\000 */
{ 1726969 }, /* ocr.reads_to_core.l3_miss_local_socket\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that missed the L3 Cache and were supplied by the local socket (DRAM or PMM), whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM or DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x70CC00477\000\00000\000\000 */
{ 1740129 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that missed the local socket's L1, L2, and L3 caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x94000800\000\00000\000\000 */
{ 1741017 }, /* ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000800\000\00000\000\000 */
{ 1752416 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000\000 */
{ 1768078 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles where at least one demand data read request known to have missed the L3 cache is pending\000event=0x60,cmask=1,period=1000003,umask=0x10\000\00000\000Cycles where at least one demand data read request known to have missed the L3 cache is pending.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000 */
{ 1779457 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000This event is deprecated\000event=0x60,period=2000003,umask=0x10\000\00010\000\000 */
{ 1780137 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles where the core is waiting on at least 6 outstanding demand data read requests known to have missed the L3 cache\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000Cycles where the core is waiting on at least 6 outstanding demand data read requests known to have missed the L3 cache.  Note that this event does not capture all elapsed cycles while the requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2515369 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2515927 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516525 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519396 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2572419 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=100003,umask=0x2\000\00000\000Counts Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2573092 }, /* tx_exec.misc3\000\000memory\000Number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=100003,umask=0x4\000\00000\000Counts Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 572304 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Counts Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 573029 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Counts Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573765 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server microarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 577373 }, /* core_snoop_response.i_fwd_fe\000\000other\000Hit snoop reply with data, line invalidated\000event=0xef,period=1000003,umask=0x20\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated: removed from this core's cache, after the data is forwarded back to the requestor and indicating the data was found unmodified in the (FE) Forward or Exclusive State in this cores caches cache.  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 577840 }, /* core_snoop_response.i_fwd_m\000\000other\000HitM snoop reply with data, line invalidated\000event=0xef,period=1000003,umask=0x10\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated: removed from this core's caches, after the data is forwarded back to the requestor, and indicating the data was found modified(M) in this cores caches cache (aka HitM response).  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 578291 }, /* core_snoop_response.i_hit_fse\000\000other\000Hit snoop reply without sending the data, line invalidated\000event=0xef,period=1000003,umask=0x2\000\00000\000Counts responses to snoops indicating the line will now be (I)nvalidated in this core's caches without being forwarded back to the requestor. The line was in Forward, Shared or Exclusive (FSE) state in this cores caches.  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 578726 }, /* core_snoop_response.miss\000\000other\000Line not found snoop reply\000event=0xef,period=1000003,umask=0x1\000\00000\000Counts responses to snoops indicating that the data was not found (IHitI) in this core's caches. A single snoop response from the core counts on all hyperthreads of the Core\000 */
{ 579770 }, /* core_snoop_response.s_fwd_fe\000\000other\000Hit snoop reply with data, line kept in Shared state\000event=0xef,period=1000003,umask=0x40\000\00000\000Counts responses to snoops indicating the line may be kept on this core in the (S)hared state, after the data is forwarded back to the requestor, initially the data was found in the cache in the (FS) Forward or Shared state.  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 580203 }, /* core_snoop_response.s_fwd_m\000\000other\000HitM snoop reply with data, line kept in Shared state\000event=0xef,period=1000003,umask=0x8\000\00000\000Counts responses to snoops indicating the line may be kept on this core in the (S)hared state, after the data is forwarded back to the requestor, initially the data was found in the cache in the (M)odified state.  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 580623 }, /* core_snoop_response.s_hit_fse\000\000other\000Hit snoop reply without sending the data, line kept in Shared state\000event=0xef,period=1000003,umask=0x4\000\00000\000Counts responses to snoops indicating the line was kept on this core in the (S)hared state, and that the data was found unmodified but not forwarded back to the requestor, initially the data was found in the cache in the (FSE) Forward, Shared state or Exclusive state.  A single snoop response from the core counts on all hyperthreads of the core\000 */
{ 1515566 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1516346 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000004\000\00000\000\000 */
{ 1534361 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000 */
{ 1537192 }, /* ocr.demand_code_rd.snc_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000004\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543602 }, /* ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000001\000\00000\000\000 */
{ 1565125 }, /* ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 1565616 }, /* ocr.demand_data_rd.local_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000 */
{ 1566113 }, /* ocr.demand_data_rd.pmm\000\000other\000Counts demand data reads that were supplied by PMM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703C00001\000\00000\000\000 */
{ 1568167 }, /* ocr.demand_data_rd.remote_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x730000001\000\00000\000\000 */
{ 1568527 }, /* ocr.demand_data_rd.remote_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000001\000\00000\000\000 */
{ 1570165 }, /* ocr.demand_data_rd.snc_dram\000\000other\000Counts demand data reads that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000001\000\00000\000\000 */
{ 1570412 }, /* ocr.demand_data_rd.snc_pmm\000\000other\000Counts demand data reads that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800001\000\00000\000\000 */
{ 1572775 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0002\000\00000\000\000 */
{ 1574201 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000002\000\00000\000\000 */
{ 1595926 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000 */
{ 1596312 }, /* ocr.demand_rfo.local_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000 */
{ 1597018 }, /* ocr.demand_rfo.pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703C00002\000\00000\000\000 */
{ 1597841 }, /* ocr.demand_rfo.remote_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000002\000\00000\000\000 */
{ 1599959 }, /* ocr.demand_rfo.snc_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000002\000\00000\000\000 */
{ 1600286 }, /* ocr.demand_rfo.snc_pmm\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800002\000\00000\000\000 */
{ 1603571 }, /* ocr.hwpf_l1d_and_swpf.dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000400\000\00000\000\000 */
{ 1606146 }, /* ocr.hwpf_l1d_and_swpf.local_dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000400\000\00000\000\000 */
{ 1606512 }, /* ocr.hwpf_l2.any_response\000\000other\000Counts hardware prefetch (which bring data to L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10070\000\00000\000\000 */
{ 1620095 }, /* ocr.hwpf_l3.any_response\000\000other\000Counts hardware prefetches to the L3 only that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x12380\000\00000\000\000 */
{ 1621978 }, /* ocr.hwpf_l3.remote\000\000other\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90002380\000\00000\000\000 */
{ 1622453 }, /* ocr.itom.remote\000\000other\000Counts full cacheline writes (ItoM) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x90000002\000\00000\000\000 */
{ 1624769 }, /* ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1719014 }, /* ocr.reads_to_core.any_response\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0477\000\00000\000\000 */
{ 1719758 }, /* ocr.reads_to_core.dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x73C000477\000\00000\000\000 */
{ 1727829 }, /* ocr.reads_to_core.local_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000477\000\00000\000\000 */
{ 1728472 }, /* ocr.reads_to_core.local_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those PMM accesses that are controlled by the close SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400477\000\00000\000\000 */
{ 1729292 }, /* ocr.reads_to_core.local_socket_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x70C000477\000\00000\000\000 */
{ 1730127 }, /* ocr.reads_to_core.local_socket_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM accesses that are controlled by the close or distant SNC Cluster\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700C00477\000\00000\000\000 */
{ 1731205 }, /* ocr.reads_to_core.remote\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by a remote socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F33000477\000\00000\000\000 */
{ 1734058 }, /* ocr.reads_to_core.remote_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x730000477\000\00000\000\000 */
{ 1734625 }, /* ocr.reads_to_core.remote_memory\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM or PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x731800477\000\00000\000\000 */
{ 1735190 }, /* ocr.reads_to_core.remote_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to another socket\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x703000477\000\00000\000\000 */
{ 1737416 }, /* ocr.reads_to_core.snc_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x708000477\000\00000\000\000 */
{ 1737761 }, /* ocr.reads_to_core.snc_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x700800477\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1744631 }, /* ocr.write_estimate.memory\000\000other\000Counts Demand RFOs, ItoM's, PREFECTHW's, Hardware RFO Prefetches to the L1/L2 and Streaming stores that likely resulted in a store to Memory (DRAM or PMM)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xFBFF80822\000\00000\000\000 */
{ 468280 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0x14,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 471702 }, /* assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x7\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502931 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504333 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 504924 }, /* br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 508295 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511305 }, /* br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 515219 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 517928 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 519163 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 535753 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=50021\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542758 }, /* br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 544064 }, /* br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545483 }, /* br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 548979 }, /* br_misp_retired.indirect\000\000pipeline\000All miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000event=0xc5,period=50021,umask=0x80\000\00000\000Counts all miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000 */
{ 550809 }, /* br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) calls, including both register and memory indirect (Precise event)\000 */
{ 555535 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 560471 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=50021,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 616704 }, /* cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 617767 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 621045 }, /* cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 626122 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638164 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000Counts core crystal clock cycles when the thread is unhalted\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 748732 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750161 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 752892 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754470 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 755810 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 758739 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=1000003,umask=0x14\000\00000\000\000 */
{ 759202 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847674 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 1041607 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1050414 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055840 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057998 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1060581 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with a reduced effect of PEBS shadow in IP distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1064821 }, /* int_misc.all_recovery_cycles\000\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000 */
{ 1065804 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xd,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1067113 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1069580 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xd,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072919 }, /* int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xd,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1194117 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1201415 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies due to partial compare on address\000 */
{ 1231173 }, /* load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285110 }, /* lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=5,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286007 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1288826 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431801 }, /* misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR to be enabled properly\000 */
{ 1432509 }, /* misc_retired.pause_inst\000\000pipeline\000Number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000event=0xcc,period=100003,umask=0x40\000\00000\000Counts number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000 */
{ 2504245 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506218 }, /* resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2510439 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=1000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into stravation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2513050 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty\000event=0x5e,cmask=1,edge=1,inv=1,period=100003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2543188 }, /* topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Counts the number of Top-down Microarchitecture Analysis (TMA) method's  slots where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6178334 }, /* uops_decoded.dec0\000\000pipeline\000Number of uops decoded out of instructions exclusively fetched by decoder 0\000event=0x56,period=1000003,umask=0x1\000\00000\000Uops exclusively fetched by decoder 0\000 */
{ 6179516 }, /* uops_dispatched.port_0\000\000pipeline\000Number of uops executed on port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6180060 }, /* uops_dispatched.port_1\000\000pipeline\000Number of uops executed on port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6180604 }, /* uops_dispatched.port_2_3\000\000pipeline\000Number of uops executed on port 2 and 3\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 2 and 3\000 */
{ 6181215 }, /* uops_dispatched.port_4_9\000\000pipeline\000Number of uops executed on port 4 and 9\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 5 and 9\000 */
{ 6181807 }, /* uops_dispatched.port_5\000\000pipeline\000Number of uops executed on port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6182390 }, /* uops_dispatched.port_6\000\000pipeline\000Number of uops executed on port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6182937 }, /* uops_dispatched.port_7_8\000\000pipeline\000Number of uops executed on port 7 and 8\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 7 and 8\000 */
{ 6194148 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195247 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196350 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6197453 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200004 }, /* uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201055 }, /* uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202126 }, /* uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203199 }, /* uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207380 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6213867 }, /* uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6219243 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread\000event=0xe,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6221020 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to 'Mixing Intel AVX and Intel SSE Code' section of the Optimization Guide\000 */
{ 6236200 }, /* uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6238210 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6239807 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2792074 }, /* unc_cha_2lm_nm_invitox.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.LOCAL. Unit: uncore_cha \000event=0x65,umask=0x1\000\00011\000\000 */
{ 2792254 }, /* unc_cha_2lm_nm_invitox.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.REMOTE. Unit: uncore_cha \000event=0x65,umask=0x2\000\00011\000\000 */
{ 2792436 }, /* unc_cha_2lm_nm_invitox.setconflict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_INVITOX.SETCONFLICT. Unit: uncore_cha \000event=0x65,umask=0x4\000\00011\000\000 */
{ 2792628 }, /* unc_cha_2lm_nm_setconflicts.llc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00011\000\000 */
{ 2792814 }, /* unc_cha_2lm_nm_setconflicts.sf\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.SF. Unit: uncore_cha \000event=0x64,umask=0x1\000\00011\000\000 */
{ 2792998 }, /* unc_cha_2lm_nm_setconflicts.tor\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS.TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00011\000\000 */
{ 2793184 }, /* unc_cha_2lm_nm_setconflicts2.memwr\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWR. Unit: uncore_cha \000event=0x70,umask=0x2\000\00011\000\000 */
{ 2793376 }, /* unc_cha_2lm_nm_setconflicts2.memwrni\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWRNI. Unit: uncore_cha \000event=0x70,umask=0x4\000\00011\000\000 */
{ 2794924 }, /* unc_cha_ag0_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795203 }, /* unc_cha_ag0_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795482 }, /* unc_cha_ag0_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795761 }, /* unc_cha_ag0_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796040 }, /* unc_cha_ag0_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796320 }, /* unc_cha_ag0_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796600 }, /* unc_cha_ag0_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796880 }, /* unc_cha_ag0_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797160 }, /* unc_cha_ag0_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797442 }, /* unc_cha_ag0_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797721 }, /* unc_cha_ag0_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2799352 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799632 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799912 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800192 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800472 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800753 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801034 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801315 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801596 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801879 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2802159 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2803791 }, /* unc_cha_ag0_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804070 }, /* unc_cha_ag0_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804349 }, /* unc_cha_ag0_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804628 }, /* unc_cha_ag0_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804907 }, /* unc_cha_ag0_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805187 }, /* unc_cha_ag0_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805467 }, /* unc_cha_ag0_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805747 }, /* unc_cha_ag0_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806027 }, /* unc_cha_ag0_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806309 }, /* unc_cha_ag0_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806588 }, /* unc_cha_ag0_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2808219 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2808499 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2808779 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809059 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809339 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809620 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809901 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810182 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810463 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810746 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2811026 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2812658 }, /* unc_cha_ag1_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812937 }, /* unc_cha_ag1_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813216 }, /* unc_cha_ag1_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813495 }, /* unc_cha_ag1_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813774 }, /* unc_cha_ag1_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814054 }, /* unc_cha_ag1_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814334 }, /* unc_cha_ag1_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814614 }, /* unc_cha_ag1_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814894 }, /* unc_cha_ag1_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815176 }, /* unc_cha_ag1_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815455 }, /* unc_cha_ag1_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2817086 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817366 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817646 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817926 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818206 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818487 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818768 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819049 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819330 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819613 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819893 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2820173 }, /* unc_cha_ag1_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2820452 }, /* unc_cha_ag1_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2820731 }, /* unc_cha_ag1_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821010 }, /* unc_cha_ag1_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821289 }, /* unc_cha_ag1_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821569 }, /* unc_cha_ag1_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821849 }, /* unc_cha_ag1_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822129 }, /* unc_cha_ag1_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822409 }, /* unc_cha_ag1_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822691 }, /* unc_cha_ag1_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822970 }, /* unc_cha_ag1_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2824601 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824881 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825161 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825441 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825721 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826002 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826283 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826564 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826845 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827128 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827408 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2829064 }, /* unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000CHA to iMC Bypass : Intermediate bypass Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the intermediate bypass\000 */
{ 2830078 }, /* unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000CHA to iMC Bypass : Not Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000 */
{ 2831272 }, /* unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000CHA to iMC Bypass : Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the full bypass\000 */
{ 2832550 }, /* unc_cha_clockticks\000uncore_cha\000uncore cache\000Clockticks of the uncore caching and home agent (CHA). Unit: uncore_cha \000event=0\000\00001\000\000 */
{ 2832961 }, /* unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 2833673 }, /* unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xf2\000\00001\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2835204 }, /* unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xf1\000\00001\000Core Cross Snoops Issued : Any Single Snoop : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2837419 }, /* unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Core Cross Snoops Issued : Multiple Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2838928 }, /* unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Core Cross Snoops Issued : Single Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2841161 }, /* unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Core Cross Snoops Issued : Multiple Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2842657 }, /* unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Core Cross Snoops Issued : Single Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2844874 }, /* unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Core Cross Snoops Issued : Multiple External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2846387 }, /* unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Core Cross Snoops Issued : Single External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2848625 }, /* unc_cha_core_snp.remote_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote. Unit: uncore_cha \000event=0x33,umask=0x12\000\00001\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2849432 }, /* unc_cha_core_snp.remote_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Snoop Target from Remote. Unit: uncore_cha \000event=0x33,umask=0x11\000\00001\000Core Cross Snoops Issued : Single Snoop Target from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2850231 }, /* unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Counter 0 Occupancy : Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2851574 }, /* unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state lookups : Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Multi-socket cacheline directory state lookups : Snoop Not Needed : Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to. : Filters for transactions that did not have to send any snoops because the directory was clean\000 */
{ 2852350 }, /* unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state lookups : Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Multi-socket cacheline directory state lookups : Snoop Needed : Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to. : Filters for transactions that had to send one or more snoops because the directory was not clean\000 */
{ 2853191 }, /* unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state updates; memory write due to directory update from the home agent (HA) pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline directory state updates memory writes issued from the home agent (HA) pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2854084 }, /* unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline directory state updates; memory write due to directory update from (table of requests) TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline directory state updates due to memory writes issued from the table of requests (TOR) pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2854609 }, /* unc_cha_direct_go.ha_suppress_drd\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x4\000\00001\000\000 */
{ 2854722 }, /* unc_cha_direct_go.ha_suppress_no_d2c\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x2\000\00001\000\000 */
{ 2854838 }, /* unc_cha_direct_go.ha_tor_dealloc\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x1\000\00001\000\000 */
{ 2854950 }, /* unc_cha_direct_go_opc.extcmp\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x1\000\00001\000\000 */
{ 2855058 }, /* unc_cha_direct_go_opc.fast_go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x10\000\00001\000\000 */
{ 2855168 }, /* unc_cha_direct_go_opc.fast_go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x20\000\00001\000\000 */
{ 2855283 }, /* unc_cha_direct_go_opc.go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x4\000\00001\000\000 */
{ 2855387 }, /* unc_cha_direct_go_opc.go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x8\000\00001\000\000 */
{ 2855496 }, /* unc_cha_direct_go_opc.idle_due_suppress\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x80\000\00001\000\000 */
{ 2855616 }, /* unc_cha_direct_go_opc.nop\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x40\000\00001\000\000 */
{ 2855722 }, /* unc_cha_direct_go_opc.pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x2\000\00001\000\000 */
{ 2855828 }, /* unc_cha_distress_asserted.dpt_local\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Local. Unit: uncore_cha \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 2856147 }, /* unc_cha_distress_asserted.dpt_nonlocal\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Remote. Unit: uncore_cha \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 2856470 }, /* unc_cha_distress_asserted.dpt_stall_iv\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_cha \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 2856830 }, /* unc_cha_distress_asserted.dpt_stall_nocrd\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_cha \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 2857203 }, /* unc_cha_distress_asserted.horz\000uncore_cha\000uncore cache\000Distress signal asserted : Horizontal. Unit: uncore_cha \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 2857548 }, /* unc_cha_distress_asserted.pmm_local\000uncore_cha\000uncore cache\000Distress signal asserted : PMM Local. Unit: uncore_cha \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 2857915 }, /* unc_cha_distress_asserted.pmm_nonlocal\000uncore_cha\000uncore cache\000Distress signal asserted : PMM Remote. Unit: uncore_cha \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 2858291 }, /* unc_cha_distress_asserted.vert\000uncore_cha\000uncore cache\000Distress signal asserted : Vertical. Unit: uncore_cha \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 2858632 }, /* unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_cha \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859187 }, /* unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_cha \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2860254 }, /* unc_cha_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000Read request from a remote socket which hit in the HitMe Cache to a line In the E state. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00001\000Counts read requests from a remote socket which hit in the HitME cache (used to cache the multi-socket Directory state) to a line in the E(Exclusive) state.  This includes the following read opcodes (RdCode, RdData, RdDataMigratory, RdCur, RdInv*, Inv*)\000 */
{ 2860689 }, /* unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket ownership read requests that hit in S state. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000Counts Number of Hits in HitMe Cache : Remote socket ownership read requests that hit in S state. : Shared hit and op is RdInvOwn, RdInv, Inv*\000 */
{ 2861394 }, /* unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket WBMtoE requests. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000 */
{ 2861848 }, /* unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Remote socket writeback to I or S requests. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000Counts Number of Hits in HitMe Cache : Remote socket writeback to I or S requests : op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS\000 */
{ 2862525 }, /* unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : Remote socket read requests. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000Counts Number of times HitMe Cache is accessed : Remote socket read requests : op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*\000 */
{ 2863266 }, /* unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : Remote socket write (i.e. writeback) requests. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000Counts Number of times HitMe Cache is accessed : Remote socket write (i.e. writeback) requests : op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS\000 */
{ 2864186 }, /* unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests that are not to shared line. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests that are not to shared line : No SF/LLC HitS/F and op is RdInvOwn\000 */
{ 2864717 }, /* unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket read or invalidate requests. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket read or invalidate requests : op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*\000 */
{ 2865442 }, /* unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests to shared line. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000Counts Number of Misses in HitMe Cache : Remote socket RdInvOwn requests to shared line : SF/LLC HitS/F and op is RdInvOwn\000 */
{ 2866114 }, /* unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000 */
{ 2866513 }, /* unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request : Received RspFwdI* for a local request, but converted HitME$ to SF entry\000 */
{ 2867185 }, /* unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000 */
{ 2867594 }, /* unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request : Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000 */
{ 2868249 }, /* unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000 */
{ 2868608 }, /* unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2870403 }, /* unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2872193 }, /* unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2873993 }, /* unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2875788 }, /* unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2877579 }, /* unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2879365 }, /* unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2881161 }, /* unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2882952 }, /* unc_cha_horz_ring_akc_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2883879 }, /* unc_cha_horz_ring_akc_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2884803 }, /* unc_cha_horz_ring_akc_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2885733 }, /* unc_cha_horz_ring_akc_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2886660 }, /* unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_cha \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2888453 }, /* unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_cha \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2890241 }, /* unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_cha \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2892039 }, /* unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_cha \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2893832 }, /* unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Left. Unit: uncore_cha \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2894982 }, /* unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Right. Unit: uncore_cha \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2896137 }, /* unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000 */
{ 2896411 }, /* unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued : ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000HA to iMC Reads Issued : ISOCH : Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 2896965 }, /* unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to any of the memory controller channels\000 */
{ 2897842 }, /* unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Full Line : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2898479 }, /* unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2899475 }, /* unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Partial : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2901580 }, /* unc_cha_llc_lookup.all\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x1fffff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2902911 }, /* unc_cha_llc_lookup.all_remote\000uncore_cha\000uncore cache\000Cache Lookups : All transactions from Remote Agents. Unit: uncore_cha \000event=0x34,umask=0x1e20ff\000\00001\000Cache Lookups : All transactions from Remote Agents : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2904238 }, /* unc_cha_llc_lookup.any_f\000uncore_cha\000uncore cache\000Cache Lookups : All Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : All Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local or remote transaction to the LLC, including prefetch\000 */
{ 2906108 }, /* unc_cha_llc_lookup.code\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00011\000\000 */
{ 2906280 }, /* unc_cha_llc_lookup.code_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00011\000\000 */
{ 2906464 }, /* unc_cha_llc_lookup.code_read\000uncore_cha\000uncore cache\000Cache Lookups : Code Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00001\000Cache Lookups : Code Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2907025 }, /* unc_cha_llc_lookup.code_read_f\000uncore_cha\000uncore cache\000Cache Lookups : CRd Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : CRd Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2908292 }, /* unc_cha_llc_lookup.code_read_local\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2908989 }, /* unc_cha_llc_lookup.code_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Code Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd001\000\00001\000Cache Lookups : Code Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2909567 }, /* unc_cha_llc_lookup.code_read_remote\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2910245 }, /* unc_cha_llc_lookup.code_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ_REMOTE. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00011\000\000 */
{ 2911085 }, /* unc_cha_llc_lookup.corepref_or_dmnd_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local transaction to the LLC, including prefetches from the Core\000 */
{ 2912366 }, /* unc_cha_llc_lookup.data_rd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00011\000\000 */
{ 2912541 }, /* unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2914362 }, /* unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00011\000\000 */
{ 2914675 }, /* unc_cha_llc_lookup.data_read_f\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Data Read Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Read transactions\000 */
{ 2916484 }, /* unc_cha_llc_lookup.data_read_local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2917171 }, /* unc_cha_llc_lookup.data_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc101\000\00001\000Cache Lookups : Data Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2918327 }, /* unc_cha_llc_lookup.data_read_remote\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a01ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2918996 }, /* unc_cha_llc_lookup.dmnd_read_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x841ff\000\00011\000\000 */
{ 2919184 }, /* unc_cha_llc_lookup.e\000uncore_cha\000uncore cache\000Cache Lookups : E State. Unit: uncore_cha \000event=0x34,umask=0x20\000\00001\000Cache Lookups : E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Exclusive State\000 */
{ 2920315 }, /* unc_cha_llc_lookup.f\000uncore_cha\000uncore cache\000Cache Lookups : F State. Unit: uncore_cha \000event=0x34,umask=0x80\000\00001\000Cache Lookups : F State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Forward State\000 */
{ 2921442 }, /* unc_cha_llc_lookup.flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests. Unit: uncore_cha \000event=0x34,umask=0x1a44ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2922015 }, /* unc_cha_llc_lookup.flush_inv_local\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1844ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2922645 }, /* unc_cha_llc_lookup.flush_inv_remote\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a04ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2923256 }, /* unc_cha_llc_lookup.flush_or_inv_f\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Flush or Invalidate Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2924379 }, /* unc_cha_llc_lookup.i\000uncore_cha\000uncore cache\000Cache Lookups : I State. Unit: uncore_cha \000event=0x34,umask=0x1\000\00001\000Cache Lookups : I State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Miss\000 */
{ 2925478 }, /* unc_cha_llc_lookup.llc_pf_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LLCPREF_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00011\000\000 */
{ 2925662 }, /* unc_cha_llc_lookup.llcpref_local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Prefetch requests to the LLC that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2926358 }, /* unc_cha_llc_lookup.llcpref_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local LLC prefetch requests (from LLC) Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local LLC prefetch requests (from LLC) Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local LLC prefetch to the LLC\000 */
{ 2927661 }, /* unc_cha_llc_lookup.loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000 */
{ 2932368 }, /* unc_cha_llc_lookup.local_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed locally Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000 */
{ 2939078 }, /* unc_cha_llc_lookup.locally_homed_address\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LOC_HOM. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00011\000\000 */
{ 2939264 }, /* unc_cha_llc_lookup.m\000uncore_cha\000uncore cache\000Cache Lookups : M State. Unit: uncore_cha \000event=0x34,umask=0x40\000\00001\000Cache Lookups : M State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Modified State\000 */
{ 2940393 }, /* unc_cha_llc_lookup.miss_all\000uncore_cha\000uncore cache\000Cache Lookups : All Misses. Unit: uncore_cha \000event=0x34,umask=0x1fe001\000\00001\000Cache Lookups : All Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2941484 }, /* unc_cha_llc_lookup.other_req_f\000uncore_cha\000uncore cache\000Cache Lookups : Write Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Write Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Writeback transactions to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2942815 }, /* unc_cha_llc_lookup.pref_or_dmnd_remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote non-snoop request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote non-snoop request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Non-snoop transactions to the LLC from remote agent\000 */
{ 2944101 }, /* unc_cha_llc_lookup.read\000uncore_cha\000uncore cache\000Cache Lookups : Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd9ff\000\00001\000Cache Lookups : Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2944647 }, /* unc_cha_llc_lookup.read_local_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0x9d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2945288 }, /* unc_cha_llc_lookup.read_local_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x11d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2945932 }, /* unc_cha_llc_lookup.read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd901\000\00001\000Cache Lookups : Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2946495 }, /* unc_cha_llc_lookup.read_miss_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0xbd901\000\00001\000Cache Lookups : Locally HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2947093 }, /* unc_cha_llc_lookup.read_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0x13d901\000\00001\000Cache Lookups : Remotely HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2947694 }, /* unc_cha_llc_lookup.read_or_snoop_remote_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x161901\000\00001\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2948385 }, /* unc_cha_llc_lookup.read_remote_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0xa19ff\000\00001\000Cache Lookups : Remotely Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2949029 }, /* unc_cha_llc_lookup.read_sf_hit\000uncore_cha\000uncore cache\000Cache Lookups : Reads that Hit the Snoop Filter. Unit: uncore_cha \000event=0x34,umask=0x1bd90e\000\00001\000Cache Lookups : Reads that Hit the Snoop Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2949634 }, /* unc_cha_llc_lookup.rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000 */
{ 2952211 }, /* unc_cha_llc_lookup.remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed remotely Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000 */
{ 2956219 }, /* unc_cha_llc_lookup.remote_snoop_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote snoop request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote snoop request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Snoop transactions to the LLC from remote agent\000 */
{ 2957467 }, /* unc_cha_llc_lookup.remote_snp\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Snoop Requests from a Remote Socket. Unit: uncore_cha \000event=0x34,umask=0x1c19ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2958876 }, /* unc_cha_llc_lookup.remotely_homed_address\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REM_HOM. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00011\000\000 */
{ 2959064 }, /* unc_cha_llc_lookup.rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests. Unit: uncore_cha \000event=0x34,umask=0x1bc8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2959698 }, /* unc_cha_llc_lookup.rfo_f\000uncore_cha\000uncore cache\000Cache Lookups : RFO Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : RFO Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2961492 }, /* unc_cha_llc_lookup.rfo_local\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2962183 }, /* unc_cha_llc_lookup.rfo_miss\000uncore_cha\000uncore cache\000Cache Lookups : RFO Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc801\000\00001\000Cache Lookups : RFO Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2962743 }, /* unc_cha_llc_lookup.rfo_pref_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.RFO_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x888ff\000\00011\000\000 */
{ 2962924 }, /* unc_cha_llc_lookup.rfo_remote\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a08ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2963596 }, /* unc_cha_llc_lookup.s\000uncore_cha\000uncore cache\000Cache Lookups : S State. Unit: uncore_cha \000event=0x34,umask=0x10\000\00001\000Cache Lookups : S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Shared State\000 */
{ 2964721 }, /* unc_cha_llc_lookup.sf_e\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - E State. Unit: uncore_cha \000event=0x34,umask=0x4\000\00001\000Cache Lookups : SnoopFilter - E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Exclusive State\000 */
{ 2965918 }, /* unc_cha_llc_lookup.sf_h\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - H State. Unit: uncore_cha \000event=0x34,umask=0x8\000\00001\000Cache Lookups : SnoopFilter - H State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit HitMe State\000 */
{ 2967107 }, /* unc_cha_llc_lookup.sf_s\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - S State. Unit: uncore_cha \000event=0x34,umask=0x2\000\00001\000Cache Lookups : SnoopFilter - S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Shared State\000 */
{ 2969661 }, /* unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITES_AND_OTHER. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00011\000\000 */
{ 2970513 }, /* unc_cha_llc_lookup.write_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITES_AND_OTHER. Unit: uncore_cha \000event=0x34,umask=0x17c2ff\000\00011\000\000 */
{ 2970700 }, /* unc_cha_llc_lookup.writes_and_other\000uncore_cha\000uncore cache\000Cache Lookups : Filters Requests for those that write info into the cache. Unit: uncore_cha \000event=0x34,umask=0x1a42ff\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2971426 }, /* unc_cha_llc_victims.all\000uncore_cha\000uncore cache\000Lines Victimized : All Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0xf\000\00001\000Lines Victimized : All Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2971715 }, /* unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Lines Victimized : Lines in E state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2974138 }, /* unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized : Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x200f\000\00001\000Lines Victimized : Local - All Lines : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2974932 }, /* unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x2002\000\00001\000Lines Victimized : Local - Lines in E State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975996 }, /* unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x2001\000\00001\000Lines Victimized : Local - Lines in M State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976805 }, /* unc_cha_llc_victims.local_only\000uncore_cha\000uncore cache\000Lines Victimized : Local Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Local Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977071 }, /* unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x2004\000\00001\000Lines Victimized : Local - Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977880 }, /* unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Lines Victimized : Lines in M state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2978508 }, /* unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized : Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x800f\000\00001\000Lines Victimized : Remote - All Lines : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2979309 }, /* unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x8002\000\00001\000Lines Victimized : Remote - Lines in E State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980381 }, /* unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x8001\000\00001\000Lines Victimized : Remote - Lines in M State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2981196 }, /* unc_cha_llc_victims.remote_only\000uncore_cha\000uncore cache\000Lines Victimized : Remote Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Remote Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2981465 }, /* unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized : Remote - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x8004\000\00001\000Lines Victimized : Remote - Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982280 }, /* unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Lines Victimized : Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984517 }, /* unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Cbo Misc : CV0 Prefetch Miss : Miscellaneous events in the Cbo\000 */
{ 2984861 }, /* unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Cbo Misc : CV0 Prefetch Victim : Miscellaneous events in the Cbo\000 */
{ 2985209 }, /* unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000 */
{ 2985457 }, /* unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc : Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Cbo Misc : Silent Snoop Eviction : Miscellaneous events in the Cbo. : Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2986136 }, /* unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc : Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Cbo Misc : Write Combining Aliasing : Miscellaneous events in the Cbo. : Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2986862 }, /* unc_cha_misc_external.mbe_inst0\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_cha \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 2987048 }, /* unc_cha_misc_external.mbe_inst1\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_cha \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 2987234 }, /* unc_cha_osb.local_invitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local InvItoE. Unit: uncore_cha \000event=0x55,umask=0x1\000\00001\000OSB Snoop Broadcast : Local InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2987540 }, /* unc_cha_osb.local_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local Rd. Unit: uncore_cha \000event=0x55,umask=0x2\000\00001\000OSB Snoop Broadcast : Local Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2987833 }, /* unc_cha_osb.off_pwrheuristic\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Off. Unit: uncore_cha \000event=0x55,umask=0x20\000\00001\000OSB Snoop Broadcast : Off : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988123 }, /* unc_cha_osb.remote_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd. Unit: uncore_cha \000event=0x55,umask=0x4\000\00001\000OSB Snoop Broadcast : Remote Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988419 }, /* unc_cha_osb.remote_readinvitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd InvItoE. Unit: uncore_cha \000event=0x55,umask=0x8\000\00001\000OSB Snoop Broadcast : Remote Rd InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988738 }, /* unc_cha_osb.rfo_hits_snp_bcast\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast. Unit: uncore_cha \000event=0x55,umask=0x10\000\00001\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2989300 }, /* unc_cha_pipe_reject.adegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989455 }, /* unc_cha_pipe_reject.akegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989610 }, /* unc_cha_pipe_reject.allrsfways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989768 }, /* unc_cha_pipe_reject.blegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989923 }, /* unc_cha_pipe_reject.fsf_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990075 }, /* unc_cha_pipe_reject.gotrack_allowsnp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x4\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990245 }, /* unc_cha_pipe_reject.gotrack_allwayrsv\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x10\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990417 }, /* unc_cha_pipe_reject.gotrack_pamatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x2\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990586 }, /* unc_cha_pipe_reject.gotrack_waymatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x8\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990756 }, /* unc_cha_pipe_reject.hacredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990908 }, /* unc_cha_pipe_reject.idx_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991062 }, /* unc_cha_pipe_reject.ipq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991223 }, /* unc_cha_pipe_reject.irq_pmm\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x20\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991385 }, /* unc_cha_pipe_reject.irq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991546 }, /* unc_cha_pipe_reject.ismq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991708 }, /* unc_cha_pipe_reject.ivegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991863 }, /* unc_cha_pipe_reject.llc_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992019 }, /* unc_cha_pipe_reject.notallowsnoop\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992176 }, /* unc_cha_pipe_reject.one_fsf_vic\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992331 }, /* unc_cha_pipe_reject.one_rsp_con\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992486 }, /* unc_cha_pipe_reject.pmm_memmode_tor_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992651 }, /* unc_cha_pipe_reject.pmm_memmode_tormatch_multi\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992821 }, /* unc_cha_pipe_reject.prq_pmm\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x40\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992983 }, /* unc_cha_pipe_reject.ptl_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x80\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993148 }, /* unc_cha_pipe_reject.rmw_setmatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x1\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993314 }, /* unc_cha_pipe_reject.rrq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993475 }, /* unc_cha_pipe_reject.setmatchentrywsct\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993636 }, /* unc_cha_pipe_reject.sf_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993791 }, /* unc_cha_pipe_reject.topa_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993945 }, /* unc_cha_pipe_reject.torid_match_go_p\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994105 }, /* unc_cha_pipe_reject.vn_ad_req\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994258 }, /* unc_cha_pipe_reject.vn_ad_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994411 }, /* unc_cha_pipe_reject.vn_bl_ncb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994564 }, /* unc_cha_pipe_reject.vn_bl_ncs\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994717 }, /* unc_cha_pipe_reject.vn_bl_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994870 }, /* unc_cha_pipe_reject.vn_bl_wb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2995022 }, /* unc_cha_pipe_reject.way_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2995175 }, /* unc_cha_pmm_memmode_nm_invitox.local\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.LOCAL. Unit: uncore_cha \000event=0x65,umask=0x1\000\00001\000\000 */
{ 2995318 }, /* unc_cha_pmm_memmode_nm_invitox.remote\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.REMOTE. Unit: uncore_cha \000event=0x65,umask=0x2\000\00001\000\000 */
{ 2995463 }, /* unc_cha_pmm_memmode_nm_invitox.setconflict\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.SETCONFLICT. Unit: uncore_cha \000event=0x65,umask=0x4\000\00001\000\000 */
{ 2996452 }, /* unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC : NM evictions due to another read to the same near memory set in the LLC\000 */
{ 2997376 }, /* unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in SF/LLC : NM evictions due to another read to the same near memory set in the SF\000 */
{ 2998307 }, /* unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000PMM Memory Mode related events : Counts the number of times CHA saw NM Set conflict in TOR : No Reject in the CHA due to a pending read to the same near memory set in the TOR\000 */
{ 2998995 }, /* unc_cha_pmm_memmode_nm_setconflicts2.iodc\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.IODC. Unit: uncore_cha \000event=0x70,umask=0x1\000\00001\000\000 */
{ 2999148 }, /* unc_cha_pmm_memmode_nm_setconflicts2.memwr\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWR. Unit: uncore_cha \000event=0x70,umask=0x2\000\00001\000\000 */
{ 2999303 }, /* unc_cha_pmm_memmode_nm_setconflicts2.memwrni\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWRNI. Unit: uncore_cha \000event=0x70,umask=0x4\000\00001\000\000 */
{ 2999462 }, /* unc_cha_pmm_qos.ddr4_fast_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.DDR4_FAST_INSERT. Unit: uncore_cha \000event=0x66,umask=0x2\000\00001\000\000 */
{ 2999597 }, /* unc_cha_pmm_qos.rej_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.REJ_IRQ. Unit: uncore_cha \000event=0x66,umask=0x8\000\00001\000\000 */
{ 2999714 }, /* unc_cha_pmm_qos.slow_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOW_INSERT. Unit: uncore_cha \000event=0x66,umask=0x1\000\00001\000\000 */
{ 2999839 }, /* unc_cha_pmm_qos.slowtorq_skip\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOWTORQ_SKIP. Unit: uncore_cha \000event=0x66,umask=0x40\000\00001\000\000 */
{ 2999969 }, /* unc_cha_pmm_qos.throttle\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE. Unit: uncore_cha \000event=0x66,umask=0x4\000\00001\000\000 */
{ 3000088 }, /* unc_cha_pmm_qos.throttle_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_IRQ. Unit: uncore_cha \000event=0x66,umask=0x20\000\00001\000\000 */
{ 3000216 }, /* unc_cha_pmm_qos.throttle_prq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_PRQ. Unit: uncore_cha \000event=0x66,umask=0x10\000\00001\000\000 */
{ 3000344 }, /* unc_cha_pmm_qos_occupancy.ddr_fast_fifo\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS_OCCUPANCY.DDR_FAST_FIFO. Unit: uncore_cha \000event=0x67,umask=0x2\000\00001\000: count # of FAST TOR Request inserted to ha_tor_req_fifo\000 */
{ 3000718 }, /* unc_cha_pmm_qos_occupancy.ddr_slow_fifo\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS_OCCUPANCY.DDR_SLOW_FIFO. Unit: uncore_cha \000event=0x67,umask=0x1\000\00001\000: count # of SLOW TOR Request inserted to ha_pmm_tor_req_fifo\000 */
{ 3002566 }, /* unc_cha_read_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000CHA iMC CHNx READ Credits Empty : MC0 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 0 only\000 */
{ 3005144 }, /* unc_cha_read_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000CHA iMC CHNx READ Credits Empty : MC1 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 1 only\000 */
{ 3003412 }, /* unc_cha_read_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC10. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC10 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 10 only\000 */
{ 3003845 }, /* unc_cha_read_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC11. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC11 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 11 only\000 */
{ 3004278 }, /* unc_cha_read_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC12. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC12 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 12 only\000 */
{ 3004711 }, /* unc_cha_read_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC13. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC13 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 13 only\000 */
{ 3005990 }, /* unc_cha_read_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000CHA iMC CHNx READ Credits Empty : MC2 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 2 only\000 */
{ 3006429 }, /* unc_cha_read_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000CHA iMC CHNx READ Credits Empty : MC3 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 3 only\000 */
{ 3006868 }, /* unc_cha_read_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000CHA iMC CHNx READ Credits Empty : MC4 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 4 only\000 */
{ 3007308 }, /* unc_cha_read_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000CHA iMC CHNx READ Credits Empty : MC5 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 5 only\000 */
{ 3007748 }, /* unc_cha_read_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC6. Unit: uncore_cha \000event=0x58,umask=0x40\000\00001\000CHA iMC CHNx READ Credits Empty : MC6 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 6 only\000 */
{ 3008188 }, /* unc_cha_read_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC7. Unit: uncore_cha \000event=0x58,umask=0x80\000\00001\000CHA iMC CHNx READ Credits Empty : MC7 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 7 only\000 */
{ 3008628 }, /* unc_cha_read_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC8. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC8 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 8 only\000 */
{ 3009057 }, /* unc_cha_read_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC9. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC9 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 9 only\000 */
{ 3009486 }, /* unc_cha_requests.invitoe\000uncore_cha\000uncore cache\000Local INVITOE requests (exclusive ownership of a cache line without receiving data) that miss the SF/LLC and remote INVITOE requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x30\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3010216 }, /* unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local INVITOE requests (exclusive ownership of a cache line without receiving data) that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3011272 }, /* unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Remote INVITOE requests (exclusive ownership of a cache line without receiving data) sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3011964 }, /* unc_cha_requests.reads\000uncore_cha\000uncore cache\000Local read requests that miss the SF/LLC and remote read requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000 */
{ 3012786 }, /* unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Local read requests that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3013732 }, /* unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Remote read requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3014042 }, /* unc_cha_requests.writes\000uncore_cha\000uncore cache\000Local write requests that miss the SF/LLC and remote write requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3014862 }, /* unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Local write requests that miss the SF/LLC and are sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015831 }, /* unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Remote write requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3016157 }, /* unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3016689 }, /* unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_cha \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017221 }, /* unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017753 }, /* unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_cha \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018285 }, /* unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3018807 }, /* unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019395 }, /* unc_cha_ring_bounces_vert.akc\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. Unit: uncore_cha \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019673 }, /* unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020255 }, /* unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020853 }, /* unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000\000 */
{ 3021138 }, /* unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_cha \000event=0xad,umask=0x2\000\00001\000\000 */
{ 3021423 }, /* unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xad,umask=0x20\000\00001\000\000 */
{ 3021768 }, /* unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000\000 */
{ 3022053 }, /* unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_cha \000event=0xad,umask=0x8\000\00001\000\000 */
{ 3022338 }, /* unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : AD. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000\000 */
{ 3022619 }, /* unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000\000 */
{ 3022944 }, /* unc_cha_ring_sink_starved_vert.akc\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring. Unit: uncore_cha \000event=0xab,umask=0x10\000\00001\000\000 */
{ 3023082 }, /* unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000\000 */
{ 3023403 }, /* unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000\000 */
{ 3023832 }, /* unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xae\000\00001\000\000 */
{ 3023930 }, /* unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Ingress (from CMS) Allocations : IPQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024370 }, /* unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Ingress (from CMS) Allocations : IRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024810 }, /* unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Ingress (from CMS) Allocations : IRQ Rejected : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025285 }, /* unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025727 }, /* unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026177 }, /* unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Ingress (from CMS) Allocations : RRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026619 }, /* unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Ingress (from CMS) Allocations : WBQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3027061 }, /* unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3027469 }, /* unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3027878 }, /* unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3028290 }, /* unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3028683 }, /* unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3029076 }, /* unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3029485 }, /* unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3029890 }, /* unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3030302 }, /* unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000 */
{ 3030606 }, /* unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IPQ0 Reject counter was true\000 */
{ 3030990 }, /* unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000 */
{ 3031260 }, /* unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000 */
{ 3031735 }, /* unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000 */
{ 3032037 }, /* unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000 */
{ 3032461 }, /* unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3032859 }, /* unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000 */
{ 3033147 }, /* unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3033568 }, /* unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3033990 }, /* unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3034415 }, /* unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3034821 }, /* unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3035227 }, /* unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3035649 }, /* unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3036067 }, /* unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3036492 }, /* unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3036809 }, /* unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IRQ0 Reject counter was true\000 */
{ 3037206 }, /* unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000 */
{ 3037489 }, /* unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way : Way conflict with another request that caused the reject\000 */
{ 3037977 }, /* unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000 */
{ 3038292 }, /* unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3038451 }, /* unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3038862 }, /* unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000 */
{ 3039163 }, /* unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000ISMQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3040032 }, /* unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000ISMQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3040902 }, /* unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000ISMQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3041775 }, /* unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000ISMQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3042629 }, /* unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000ISMQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3043483 }, /* unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000ISMQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3044353 }, /* unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000ISMQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3045219 }, /* unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000ISMQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3046092 }, /* unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000ISMQ Retries - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3046959 }, /* unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000ISMQ Retries - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3047827 }, /* unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000ISMQ Retries - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3048698 }, /* unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000ISMQ Retries - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3049550 }, /* unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000ISMQ Retries - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3050402 }, /* unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000ISMQ Retries - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3051270 }, /* unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000ISMQ Retries - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3052134 }, /* unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000ISMQ Retries - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3053005 }, /* unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000ISMQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3053851 }, /* unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000ISMQ Rejects - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3054626 }, /* unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000ISMQ Retries - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3055470 }, /* unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000ISMQ Retries - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3056243 }, /* unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Occupancy : IPQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3056677 }, /* unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Occupancy : IRQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057111 }, /* unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Occupancy : RRQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057547 }, /* unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Occupancy : WBQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057983 }, /* unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Other Retries - Set 0 : AD REQ on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a request\000 */
{ 3058590 }, /* unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Other Retries - Set 0 : AD RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a response\000 */
{ 3059198 }, /* unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Other Retries - Set 0 : Non UPI AK Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject AK ring message\000 */
{ 3059809 }, /* unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Other Retries - Set 0 : BL NCB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCB\000 */
{ 3060401 }, /* unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Other Retries - Set 0 : BL NCS on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCS\000 */
{ 3060993 }, /* unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Other Retries - Set 0 : BL RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a response\000 */
{ 3061601 }, /* unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Other Retries - Set 0 : BL WB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a writeback\000 */
{ 3062205 }, /* unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Other Retries - Set 0 : Non UPI IV Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject IV ring message\000 */
{ 3062816 }, /* unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Other Retries - Set 1 : Allow Snoop : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063373 }, /* unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Other Retries - Set 1 : ANY0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Any condition listed in the Other0 Reject counter was true\000 */
{ 3063958 }, /* unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Other Retries - Set 1 : HA : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064472 }, /* unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Other Retries - Set 1 : LLC OR SF Way : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Way conflict with another request that caused the reject\000 */
{ 3065146 }, /* unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Other Retries - Set 1 : LLC Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3065700 }, /* unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Other Retries - Set 1 : PhyAddr Match : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Address match with an outstanding request that was rejected\000 */
{ 3066323 }, /* unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Other Retries - Set 1 : SF Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Requests did not generate Snoop filter victim\000 */
{ 3066920 }, /* unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Other Retries - Set 1 : Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067616 }, /* unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3068037 }, /* unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3068465 }, /* unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3068885 }, /* unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3069291 }, /* unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3069696 }, /* unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3070116 }, /* unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3070542 }, /* unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3070959 }, /* unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3071263 }, /* unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the PRQ0 Reject counter was true\000 */
{ 3071656 }, /* unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000 */
{ 3071962 }, /* unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000 */
{ 3072399 }, /* unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000 */
{ 3072716 }, /* unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000 */
{ 3073149 }, /* unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3073555 }, /* unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000 */
{ 3073706 }, /* unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000Request Queue Retries - Set 0 : AD REQ on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a request\000 */
{ 3074235 }, /* unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000Request Queue Retries - Set 0 : AD RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a response\000 */
{ 3074765 }, /* unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000Request Queue Retries - Set 0 : Non UPI AK Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject AK ring message\000 */
{ 3075298 }, /* unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000Request Queue Retries - Set 0 : BL NCB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCB\000 */
{ 3075812 }, /* unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000Request Queue Retries - Set 0 : BL NCS on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCS\000 */
{ 3076326 }, /* unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000Request Queue Retries - Set 0 : BL RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a response\000 */
{ 3076856 }, /* unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000Request Queue Retries - Set 0 : BL WB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a writeback\000 */
{ 3077382 }, /* unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000Request Queue Retries - Set 0 : Non UPI IV Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject IV ring message\000 */
{ 3077915 }, /* unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000Request Queue Retries - Set 1 : Allow Snoop : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078394 }, /* unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000Request Queue Retries - Set 1 : ANY0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Any condition listed in the WBQ0 Reject counter was true\000 */
{ 3078899 }, /* unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000Request Queue Retries - Set 1 : HA : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079335 }, /* unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000Request Queue Retries - Set 1 : LLC OR SF Way : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Way conflict with another request that caused the reject\000 */
{ 3079931 }, /* unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000Request Queue Retries - Set 1 : LLC Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080407 }, /* unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000Request Queue Retries - Set 1 : PhyAddr Match : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Address match with an outstanding request that was rejected\000 */
{ 3080952 }, /* unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000Request Queue Retries - Set 1 : SF Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Requests did not generate Snoop filter victim\000 */
{ 3081471 }, /* unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000Request Queue Retries - Set 1 : Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081929 }, /* unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000RRQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a request\000 */
{ 3082463 }, /* unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000RRQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a response\000 */
{ 3082998 }, /* unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000RRQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject AK ring message\000 */
{ 3083536 }, /* unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000RRQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCB\000 */
{ 3084055 }, /* unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000RRQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCS\000 */
{ 3084574 }, /* unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000RRQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a response\000 */
{ 3085109 }, /* unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000RRQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a writeback\000 */
{ 3085640 }, /* unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000RRQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject IV ring message\000 */
{ 3086178 }, /* unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000RRQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086661 }, /* unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000RRQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Any condition listed in the RRQ0 Reject counter was true\000 */
{ 3087171 }, /* unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000RRQ Rejects - Set 1 : HA : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087611 }, /* unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000RRQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Way conflict with another request that caused the reject\000 */
{ 3088212 }, /* unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000RRQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3088692 }, /* unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000RRQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Address match with an outstanding request that was rejected\000 */
{ 3089242 }, /* unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000RRQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Requests did not generate Snoop filter victim\000 */
{ 3089766 }, /* unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000RRQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090228 }, /* unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000WBQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a request\000 */
{ 3090750 }, /* unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000WBQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a response\000 */
{ 3091273 }, /* unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000WBQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject AK ring message\000 */
{ 3091799 }, /* unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000WBQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCB\000 */
{ 3092306 }, /* unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000WBQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCS\000 */
{ 3092813 }, /* unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000WBQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a response\000 */
{ 3093336 }, /* unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000WBQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a writeback\000 */
{ 3093855 }, /* unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000WBQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject IV ring message\000 */
{ 3094381 }, /* unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000WBQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094852 }, /* unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000WBQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Any condition listed in the WBQ0 Reject counter was true\000 */
{ 3095350 }, /* unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000WBQ Rejects - Set 1 : HA : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095778 }, /* unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000WBQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Way conflict with another request that caused the reject\000 */
{ 3096367 }, /* unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000WBQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096835 }, /* unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000WBQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Address match with an outstanding request that was rejected\000 */
{ 3097373 }, /* unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000WBQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Requests did not generate Snoop filter victim\000 */
{ 3097885 }, /* unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000WBQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3098335 }, /* unc_cha_rxr_busy_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 3099178 }, /* unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100001 }, /* unc_cha_rxr_busy_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100444 }, /* unc_cha_rxr_busy_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 3101287 }, /* unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102110 }, /* unc_cha_rxr_busy_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102553 }, /* unc_cha_rxr_bypass.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - All. Unit: uncore_cha \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 3102976 }, /* unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_cha \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 3103379 }, /* unc_cha_rxr_bypass.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3103609 }, /* unc_cha_rxr_bypass.ak\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AK. Unit: uncore_cha \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 3103984 }, /* unc_cha_rxr_bypass.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3104218 }, /* unc_cha_rxr_bypass.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - All. Unit: uncore_cha \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 3104641 }, /* unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_cha \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 3105044 }, /* unc_cha_rxr_bypass.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3105274 }, /* unc_cha_rxr_bypass.iv\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : IV. Unit: uncore_cha \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 3105649 }, /* unc_cha_rxr_crd_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 3106515 }, /* unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3107360 }, /* unc_cha_rxr_crd_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3107814 }, /* unc_cha_rxr_crd_starved.ak\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AK. Unit: uncore_cha \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3108631 }, /* unc_cha_rxr_crd_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 3109497 }, /* unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3110342 }, /* unc_cha_rxr_crd_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3110796 }, /* unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_cha \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3111638 }, /* unc_cha_rxr_crd_starved.iv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IV. Unit: uncore_cha \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112455 }, /* unc_cha_rxr_crd_starved_1\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Unit: uncore_cha \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112856 }, /* unc_cha_rxr_inserts.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - All. Unit: uncore_cha \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3113424 }, /* unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_cha \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3113972 }, /* unc_cha_rxr_inserts.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114277 }, /* unc_cha_rxr_inserts.ak\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AK. Unit: uncore_cha \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114797 }, /* unc_cha_rxr_inserts.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115106 }, /* unc_cha_rxr_inserts.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - All. Unit: uncore_cha \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3115674 }, /* unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_cha \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116222 }, /* unc_cha_rxr_inserts.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116527 }, /* unc_cha_rxr_inserts.iv\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : IV. Unit: uncore_cha \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117047 }, /* unc_cha_rxr_occupancy.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - All. Unit: uncore_cha \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3117629 }, /* unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118191 }, /* unc_cha_rxr_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118502 }, /* unc_cha_rxr_occupancy.ak\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AK. Unit: uncore_cha \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119036 }, /* unc_cha_rxr_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119351 }, /* unc_cha_rxr_occupancy.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - All. Unit: uncore_cha \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3119933 }, /* unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120495 }, /* unc_cha_rxr_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120806 }, /* unc_cha_rxr_occupancy.iv\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : IV. Unit: uncore_cha \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121811 }, /* unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3122756 }, /* unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3123698 }, /* unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3125406 }, /* unc_cha_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received : RSPCNFLCT*. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Snoop Responses Received : RSPCNFLCT* : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3126689 }, /* unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Snoop Responses Received : RspFwd : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3128307 }, /* unc_cha_snoop_resp.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*Fwd*WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Snoop Responses Received : Rsp*Fwd*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3129566 }, /* unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received : RspI. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000 */
{ 3130529 }, /* unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspIFwd. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000 */
{ 3131490 }, /* unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received : RspS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Counts when a transaction with the opcode type RspS Snoop Response was received which indicates when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3133103 }, /* unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspSFwd. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000 */
{ 3133515 }, /* unc_cha_snoop_resp.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*WB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Snoop Responses Received : Rsp*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3135401 }, /* unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Snoop Responses Received Local : RspCnflct : Number of snoop responses received for a Local  request : Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3136430 }, /* unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Snoop Responses Received Local : RspFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3137368 }, /* unc_cha_snoop_resp_local.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Snoop Responses Received Local : Rsp*FWD*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3137910 }, /* unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Snoop Responses Received Local : RspI : Number of snoop responses received for a Local  request : Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3138764 }, /* unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Snoop Responses Received Local : RspIFwd : Number of snoop responses received for a Local  request : Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3139761 }, /* unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Snoop Responses Received Local : RspS : Number of snoop responses received for a Local  request : Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3141174 }, /* unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Snoop Responses Received Local : RspSFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3142097 }, /* unc_cha_snoop_resp_local.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Snoop Responses Received Local : Rsp*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3142653 }, /* unc_cha_snoop_rsp_misc.mtoi_rspdatam\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIDataM. Unit: uncore_cha \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 3142806 }, /* unc_cha_snoop_rsp_misc.mtoi_rspifwdm\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIFwdM. Unit: uncore_cha \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 3142958 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x20\000\00001\000\000 */
{ 3143130 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x10\000\00001\000\000 */
{ 3143300 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x8\000\00001\000\000 */
{ 3143462 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x4\000\00001\000\000 */
{ 3143622 }, /* unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent : All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Snoops Sent : All : Counts the number of snoops issued by the HA\000 */
{ 3144316 }, /* unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Snoops Sent : Broadcast snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA responding to local requests\000 */
{ 3144962 }, /* unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Snoops Sent : Broadcast snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA responding to remote requests\000 */
{ 3145985 }, /* unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Snoops Sent : Directed snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA responding to local requests\000 */
{ 3146997 }, /* unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Snoops Sent : Directed snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA responding to remote requests\000 */
{ 3148442 }, /* unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent : Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Snoops Sent : Snoops sent for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA responding to local requests\000 */
{ 3149549 }, /* unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent : Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Snoops Sent : Snoops sent for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA responding to remote requests\000 */
{ 3150237 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3150588 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3150939 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151290 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151641 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151993 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3152345 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3152697 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153049 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153400 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153751 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154102 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154453 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154805 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155157 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155509 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155861 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156212 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156563 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156914 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157265 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157617 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157969 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3158321 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3158673 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159024 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159375 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159726 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160077 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160429 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160781 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161133 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161485 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161839 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162190 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162541 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162897 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163250 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163603 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163959 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3164312 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3164665 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3165021 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3165374 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172623 }, /* unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts : All. Unit: uncore_cha \000event=0x35,umask=0xc001ffff\000\00001\000TOR Inserts : All : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3174601 }, /* unc_cha_tor_inserts.ddr\000uncore_cha\000uncore cache\000TOR Inserts : DDR4 Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : DDR4 Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3174198 }, /* unc_cha_tor_inserts.ddr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.DDR. Unit: uncore_cha \000event=0x35\000\00011\000\000 */
{ 3174923 }, /* unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts : SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000TOR Inserts : SF/LLC Evictions : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3176020 }, /* unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts : Just Hits. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Hits : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3176970 }, /* unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc001ff01\000\00001\000TOR Inserts : All requests from iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3177916 }, /* unc_cha_tor_inserts.ia_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8c7ff01\000\00001\000TOR Inserts : CLFlushes issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3178602 }, /* unc_cha_tor_inserts.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8d7ff01\000\00001\000TOR Inserts : CLFlushOpts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3179304 }, /* unc_cha_tor_inserts.ia_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc80fff01\000\00001\000TOR Inserts : CRDs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3179872 }, /* unc_cha_tor_inserts.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88fff01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3180093 }, /* unc_cha_tor_inserts.ia_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc817ff01\000\00001\000TOR Inserts : DRds issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3180661 }, /* unc_cha_tor_inserts.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc827ff01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3181253 }, /* unc_cha_tor_inserts.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8a7ff01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3181879 }, /* unc_cha_tor_inserts.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc897ff01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3182481 }, /* unc_cha_tor_inserts.ia_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc837ff01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3182877 }, /* unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd01\000\00001\000TOR Inserts : All requests from iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3184191 }, /* unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffd01\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3184804 }, /* unc_cha_tor_inserts.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffd01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3186237 }, /* unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc817fd01\000\00001\000TOR Inserts : DRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3186850 }, /* unc_cha_tor_inserts.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fd01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3187487 }, /* unc_cha_tor_inserts.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fd01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3188158 }, /* unc_cha_tor_inserts.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc897fd01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3188805 }, /* unc_cha_tor_inserts.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fd01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to page walks that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3189583 }, /* unc_cha_tor_inserts.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fd01\000\00001\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3189982 }, /* unc_cha_tor_inserts.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3190659 }, /* unc_cha_tor_inserts.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT_LLCPREFCODE. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00011\000\000 */
{ 3191019 }, /* unc_cha_tor_inserts.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3191696 }, /* unc_cha_tor_inserts.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT_LLCPREFDATA. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00011\000\000 */
{ 3192489 }, /* unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xccc7fd01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3193584 }, /* unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fd01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3194206 }, /* unc_cha_tor_inserts.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fd01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3194862 }, /* unc_cha_tor_inserts.ia_hit_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores that hit in the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc57fd01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3195287 }, /* unc_cha_tor_inserts.ia_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcc47ff01\000\00001\000TOR Inserts : ItoMs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3196299 }, /* unc_cha_tor_inserts.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcd47ff01\000\00001\000TOR Inserts : ItoMCacheNears issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3196695 }, /* unc_cha_tor_inserts.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcccfff01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3197295 }, /* unc_cha_tor_inserts.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xccd7ff01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3197895 }, /* unc_cha_tor_inserts.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xccc7ff01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3198938 }, /* unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe01\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3200158 }, /* unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffe01\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3201186 }, /* unc_cha_tor_inserts.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc80efe01\000\00001\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3201633 }, /* unc_cha_tor_inserts.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffe01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3202675 }, /* unc_cha_tor_inserts.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc88efe01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3203524 }, /* unc_cha_tor_inserts.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc88f7e01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3204365 }, /* unc_cha_tor_inserts.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc80f7e01\000\00001\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3205850 }, /* unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc817fe01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3206909 }, /* unc_cha_tor_inserts.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3207675 }, /* unc_cha_tor_inserts.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc816fe01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3208824 }, /* unc_cha_tor_inserts.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3209708 }, /* unc_cha_tor_inserts.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3210197 }, /* unc_cha_tor_inserts.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fe01\000\00001\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3211036 }, /* unc_cha_tor_inserts.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fe01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3211921 }, /* unc_cha_tor_inserts.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3212687 }, /* unc_cha_tor_inserts.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc897fe01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3214179 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3214959 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc896fe01\000\00001\000TOR Inserts; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3215603 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3216512 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3217399 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3218182 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8977e01\000\00001\000TOR Inserts; Data read prefetch from remote IA that misses in the snoop filter\000 */
{ 3218830 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970601\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3219744 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970a01\000\00001\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3220251 }, /* unc_cha_tor_inserts.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8177e01\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3221402 }, /* unc_cha_tor_inserts.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170601\000\00001\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3222291 }, /* unc_cha_tor_inserts.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170a01\000\00001\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3223021 }, /* unc_cha_tor_inserts.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fe01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3223462 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3223692 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3223926 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00011\000\000 */
{ 3224136 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3224376 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_LOCAL_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00011\000\000 */
{ 3224598 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3224838 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3225072 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3225313 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_REMOTE_WCILF_DDR. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00011\000\000 */
{ 3225537 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3226127 }, /* unc_cha_tor_inserts.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fe01\000\00001\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3226533 }, /* unc_cha_tor_inserts.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefCode issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcccffe01\000\00001\000TOR Inserts : LLCPrefCode issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3227630 }, /* unc_cha_tor_inserts.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefData issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xccd7fe01\000\00001\000TOR Inserts : LLCPrefData issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3229356 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xccc7fe01\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3230870 }, /* unc_cha_tor_inserts.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3231747 }, /* unc_cha_tor_inserts.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3232626 }, /* unc_cha_tor_inserts.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3233508 }, /* unc_cha_tor_inserts.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3233995 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3234227 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3234463 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00011\000\000 */
{ 3234675 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3234917 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_LOCAL_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00011\000\000 */
{ 3235141 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3235383 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3235619 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3235862 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_dram\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS_REMOTE_WCIL_DDR. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00011\000\000 */
{ 3236088 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3236726 }, /* unc_cha_tor_inserts.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3237608 }, /* unc_cha_tor_inserts.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3238492 }, /* unc_cha_tor_inserts.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3238982 }, /* unc_cha_tor_inserts.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3240295 }, /* unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fe01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3241323 }, /* unc_cha_tor_inserts.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc806fe01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3242000 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fe01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3243091 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc886fe01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3243807 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8877e01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3244527 }, /* unc_cha_tor_inserts.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8077e01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC - HOMed remotely : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3245444 }, /* unc_cha_tor_inserts.ia_miss_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc57fe01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3246221 }, /* unc_cha_tor_inserts.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc877de01\000\00001\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3246983 }, /* unc_cha_tor_inserts.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3247768 }, /* unc_cha_tor_inserts.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3248585 }, /* unc_cha_tor_inserts.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3249385 }, /* unc_cha_tor_inserts.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3250173 }, /* unc_cha_tor_inserts.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3250995 }, /* unc_cha_tor_inserts.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3251791 }, /* unc_cha_tor_inserts.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Inserts : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc87fde01\000\00001\000TOR Inserts : WiLs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3252194 }, /* unc_cha_tor_inserts.ia_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc807ff01\000\00001\000TOR Inserts : RFOs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3252771 }, /* unc_cha_tor_inserts.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc887ff01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3253382 }, /* unc_cha_tor_inserts.ia_specitom\000uncore_cha\000uncore cache\000TOR Inserts : SpecItoMs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcc57ff01\000\00001\000TOR Inserts : SpecItoMs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3254072 }, /* unc_cha_tor_inserts.ia_wbeftoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc3fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3254916 }, /* unc_cha_tor_inserts.ia_wbeftoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc37ff01\000\00001\000WbEFtoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3255759 }, /* unc_cha_tor_inserts.ia_wbmtoe\000uncore_cha\000uncore cache\000TOR Inserts : WBMtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc2fff01\000\00001\000WbMtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3256178 }, /* unc_cha_tor_inserts.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by an iA Cores. Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc27ff01\000\00001\000WbMtoIs issued by iA Cores .  (Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3257010 }, /* unc_cha_tor_inserts.ia_wbstoi\000uncore_cha\000uncore cache\000TOR Inserts : WBStoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc67ff01\000\00001\000WbStoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3257757 }, /* unc_cha_tor_inserts.ia_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc86fff01\000\00001\000TOR Inserts : WCiLs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3258455 }, /* unc_cha_tor_inserts.ia_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc867ff01\000\00001\000TOR Inserts : WCiLF issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3258825 }, /* unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc001ff04\000\00001\000TOR Inserts : All requests from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3260123 }, /* unc_cha_tor_inserts.io_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8c3ff04\000\00001\000TOR Inserts : CLFlushes issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3260507 }, /* unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd04\000\00001\000TOR Inserts : All requests from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3261481 }, /* unc_cha_tor_inserts.io_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fd04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3262222 }, /* unc_cha_tor_inserts.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fd04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3262724 }, /* unc_cha_tor_inserts.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fd04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3263558 }, /* unc_cha_tor_inserts.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fd04\000\00001\000TOR Inserts : RFOs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3264294 }, /* unc_cha_tor_inserts.io_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc43ff04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3264861 }, /* unc_cha_tor_inserts.io_itom_local\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices to locally HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcc42ff04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3265264 }, /* unc_cha_tor_inserts.io_itom_remote\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices to remotely HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcc437f04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3265669 }, /* unc_cha_tor_inserts.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcd43ff04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3266413 }, /* unc_cha_tor_inserts.io_itomcachenear_local\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices to locally HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcd42ff04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3266907 }, /* unc_cha_tor_inserts.io_itomcachenear_remote\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices to remotely HOMed memory. Unit: uncore_cha \000event=0x35,umask=0xcd437f04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3267403 }, /* unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe04\000\00001\000TOR Inserts : All requests from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3268390 }, /* unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fe04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3269528 }, /* unc_cha_tor_inserts.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fe04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3270037 }, /* unc_cha_tor_inserts.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fe04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3271240 }, /* unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fe04\000\00001\000TOR Inserts : RFOs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3272431 }, /* unc_cha_tor_inserts.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8f3ff04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3273016 }, /* unc_cha_tor_inserts.io_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc803ff04\000\00001\000TOR Inserts : RFOs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3274081 }, /* unc_cha_tor_inserts.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc23ff04\000\00001\000TOR Inserts : WbMtoIs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3274460 }, /* unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts : IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000TOR Inserts : IPQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3275719 }, /* unc_cha_tor_inserts.irq_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - iA. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000TOR Inserts : IRQ - iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From an iA Core\000 */
{ 3276345 }, /* unc_cha_tor_inserts.irq_non_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - Non iA. Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000TOR Inserts : IRQ - Non iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3276959 }, /* unc_cha_tor_inserts.isoc\000uncore_cha\000uncore cache\000TOR Inserts : Just ISOC. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just ISOC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3277527 }, /* unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff05\000\00001\000TOR Inserts : All from Local iA and IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000 */
{ 3278386 }, /* unc_cha_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA. Unit: uncore_cha \000event=0x35,umask=0xc000ff01\000\00001\000TOR Inserts : All from Local iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000 */
{ 3279120 }, /* unc_cha_tor_inserts.loc_io\000uncore_cha\000uncore cache\000TOR Inserts : All from Local IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff04\000\00001\000TOR Inserts : All from Local IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000 */
{ 3279830 }, /* unc_cha_tor_inserts.local_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Local Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Local Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3280444 }, /* unc_cha_tor_inserts.match_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3281210 }, /* unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts : Just Misses. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Misses : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3282517 }, /* unc_cha_tor_inserts.mmcfg\000uncore_cha\000uncore cache\000TOR Inserts : MMCFG Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMCFG Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3283352 }, /* unc_cha_tor_inserts.nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3283938 }, /* unc_cha_tor_inserts.noncoh\000uncore_cha\000uncore cache\000TOR Inserts : Just NonCoherent. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NonCoherent : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3284538 }, /* unc_cha_tor_inserts.not_nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NotNearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NotNearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3285393 }, /* unc_cha_tor_inserts.pmm\000uncore_cha\000uncore cache\000TOR Inserts : PMM Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : PMM Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3285713 }, /* unc_cha_tor_inserts.premorph_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3286754 }, /* unc_cha_tor_inserts.prq_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - IOSF. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000TOR Inserts : PRQ - IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000 */
{ 3287398 }, /* unc_cha_tor_inserts.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - Non IOSF. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000TOR Inserts : PRQ - Non IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3288859 }, /* unc_cha_tor_inserts.remote_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Remote Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Remote Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3289479 }, /* unc_cha_tor_inserts.rrq\000uncore_cha\000uncore cache\000TOR Inserts : RRQ. Unit: uncore_cha \000event=0x35,umask=0x40\000\00001\000TOR Inserts : RRQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3290605 }, /* unc_cha_tor_inserts.wbq\000uncore_cha\000uncore cache\000TOR Inserts : WBQ. Unit: uncore_cha \000event=0x35,umask=0x80\000\00001\000TOR Inserts : WBQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3293484 }, /* unc_cha_tor_occupancy.ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DDR4 Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : DDR4 Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3293828 }, /* unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy : SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000TOR Occupancy : SF/LLC Evictions : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3294993 }, /* unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy : Just Hits. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Hits : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3296012 }, /* unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc001ff01\000\00001\000TOR Occupancy : All requests from iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297090 }, /* unc_cha_tor_occupancy.ia_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8c7ff01\000\00001\000TOR Occupancy : CLFlushes issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297492 }, /* unc_cha_tor_occupancy.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8d7ff01\000\00001\000TOR Occupancy : CLFlushOpts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297901 }, /* unc_cha_tor_occupancy.ia_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc80fff01\000\00001\000TOR Occupancy : CRDs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3298497 }, /* unc_cha_tor_occupancy.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88fff01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3298724 }, /* unc_cha_tor_occupancy.ia_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc817ff01\000\00001\000TOR Occupancy : DRds issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3299320 }, /* unc_cha_tor_occupancy.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc827ff01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3299940 }, /* unc_cha_tor_occupancy.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8a7ff01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3300594 }, /* unc_cha_tor_occupancy.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc897ff01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3301695 }, /* unc_cha_tor_occupancy.ia_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk. Unit: uncore_cha \000event=0x36,umask=0xc837ff01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3302128 }, /* unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd01\000\00001\000TOR Occupancy : All requests from iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3303661 }, /* unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffd01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3304302 }, /* unc_cha_tor_occupancy.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffd01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3305809 }, /* unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc817fd01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3306450 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fd01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3307115 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fd01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3307814 }, /* unc_cha_tor_occupancy.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc897fd01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3308998 }, /* unc_cha_tor_occupancy.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fd01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3309469 }, /* unc_cha_tor_occupancy.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fd01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3309890 }, /* unc_cha_tor_occupancy.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcccffd01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3310761 }, /* unc_cha_tor_occupancy.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xccd7fd01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3312087 }, /* unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xccc7fd01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3313232 }, /* unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fd01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3313882 }, /* unc_cha_tor_occupancy.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fd01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3314566 }, /* unc_cha_tor_occupancy.ia_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc47ff01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3314957 }, /* unc_cha_tor_occupancy.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcd47ff01\000\00001\000TOR Occupancy : ItoMCacheNears issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3315375 }, /* unc_cha_tor_occupancy.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcccfff01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3316003 }, /* unc_cha_tor_occupancy.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xccd7ff01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3316663 }, /* unc_cha_tor_occupancy.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xccc7ff01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3317327 }, /* unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe01\000\00001\000TOR Occupancy : All requests from iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3318883 }, /* unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffe01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3319536 }, /* unc_cha_tor_occupancy.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc80efe01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3320005 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3320692 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc88efe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3321178 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc88f7e01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3321667 }, /* unc_cha_tor_occupancy.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc80f7e01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3323240 }, /* unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc817fe01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3324392 }, /* unc_cha_tor_occupancy.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3325204 }, /* unc_cha_tor_occupancy.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc816fe01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3326004 }, /* unc_cha_tor_occupancy.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3326515 }, /* unc_cha_tor_occupancy.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3327026 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fe01\000\00001\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3327897 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fe01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3328814 }, /* unc_cha_tor_occupancy.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3329626 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc897fe01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3330760 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3331248 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc896fe01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3331493 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3332019 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3332545 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3333033 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8977e01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3333279 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3333808 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3334337 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8177e01\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3335143 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3335657 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3336945 }, /* unc_cha_tor_occupancy.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fe01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3337423 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3337659 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8678601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3337899 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8668601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3338145 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8668a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3338391 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8678a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3338631 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8670601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3338878 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8670a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3339125 }, /* unc_cha_tor_occupancy.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fe01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3339553 }, /* unc_cha_tor_occupancy.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefCode issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcccffe01\000\00001\000TOR Occupancy : LLCPrefCode issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3340702 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefData issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xccd7fe01\000\00001\000TOR Occupancy : LLCPrefData issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3342506 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xccc7fe01\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3343679 }, /* unc_cha_tor_occupancy.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3344185 }, /* unc_cha_tor_occupancy.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3344691 }, /* unc_cha_tor_occupancy.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3345200 }, /* unc_cha_tor_occupancy.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3345709 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3345947 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f8601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3346189 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86e8601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3346437 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86e8a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3346685 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f8a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3346927 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f0601\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3347176 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86f0a01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3347425 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3347934 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3348443 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3348955 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3349910 }, /* unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fe01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3350990 }, /* unc_cha_tor_occupancy.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc806fe01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3351696 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fe01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3352843 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc886fe01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3353587 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8877e01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3354335 }, /* unc_cha_tor_occupancy.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8077e01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3355301 }, /* unc_cha_tor_occupancy.ia_miss_specitom\000uncore_cha\000uncore cache\000TOR Occupancy : SpecItoMs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc57fe01\000\00001\000TOR Occupancy : SpecItoMs issued by iA Cores that missed the LLC: For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent. Does not include addressless requests such as locks and interrupts\000 */
{ 3355744 }, /* unc_cha_tor_occupancy.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc877de01\000\00001\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3356175 }, /* unc_cha_tor_occupancy.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3356611 }, /* unc_cha_tor_occupancy.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357079 }, /* unc_cha_tor_occupancy.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357547 }, /* unc_cha_tor_occupancy.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357984 }, /* unc_cha_tor_occupancy.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3358455 }, /* unc_cha_tor_occupancy.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3358926 }, /* unc_cha_tor_occupancy.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc87fde01\000\00001\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3359351 }, /* unc_cha_tor_occupancy.ia_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc807ff01\000\00001\000TOR Occupancy : RFOs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3359956 }, /* unc_cha_tor_occupancy.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc887ff01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3360599 }, /* unc_cha_tor_occupancy.ia_specitom\000uncore_cha\000uncore cache\000TOR Occupancy : SpecItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc57ff01\000\00001\000TOR Occupancy : SpecItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361002 }, /* unc_cha_tor_occupancy.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc27ff01\000\00001\000TOR Occupancy : WbMtoIs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361399 }, /* unc_cha_tor_occupancy.ia_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc86fff01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361790 }, /* unc_cha_tor_occupancy.ia_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc867ff01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3362182 }, /* unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc001ff04\000\00001\000TOR Occupancy : All requests from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3363254 }, /* unc_cha_tor_occupancy.io_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8c3ff04\000\00001\000TOR Occupancy : CLFlushes issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3363660 }, /* unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd04\000\00001\000TOR Occupancy : All requests from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3364763 }, /* unc_cha_tor_occupancy.io_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fd04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3365608 }, /* unc_cha_tor_occupancy.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fd04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3366132 }, /* unc_cha_tor_occupancy.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fd04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3367010 }, /* unc_cha_tor_occupancy.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fd04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3367849 }, /* unc_cha_tor_occupancy.io_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc43ff04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3369154 }, /* unc_cha_tor_occupancy.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcd43ff04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3369640 }, /* unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe04\000\00001\000TOR Occupancy : All requests from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3370759 }, /* unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fe04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372015 }, /* unc_cha_tor_occupancy.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fe04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372546 }, /* unc_cha_tor_occupancy.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fe04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3373813 }, /* unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fe04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3375059 }, /* unc_cha_tor_occupancy.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8f3ff04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3375873 }, /* unc_cha_tor_occupancy.io_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc803ff04\000\00001\000TOR Occupancy : RFOs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3376649 }, /* unc_cha_tor_occupancy.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc23ff04\000\00001\000TOR Occupancy : WbMtoIs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3377050 }, /* unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy : IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000TOR Occupancy : IPQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3378406 }, /* unc_cha_tor_occupancy.irq_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - iA. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000TOR Occupancy : IRQ - iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From an iA Core\000 */
{ 3379078 }, /* unc_cha_tor_occupancy.irq_non_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - Non iA. Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000TOR Occupancy : IRQ - Non iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3379739 }, /* unc_cha_tor_occupancy.isoc\000uncore_cha\000uncore cache\000TOR Occupancy : Just ISOC. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just ISOC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3380354 }, /* unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA and IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff05\000\00001\000TOR Occupancy : All from Local iA and IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000 */
{ 3381316 }, /* unc_cha_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA. Unit: uncore_cha \000event=0x36,umask=0xc000ff01\000\00001\000TOR Occupancy : All from Local iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000 */
{ 3382096 }, /* unc_cha_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff04\000\00001\000TOR Occupancy : All from Local IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000 */
{ 3382852 }, /* unc_cha_tor_occupancy.local_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Local Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Local Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3383513 }, /* unc_cha_tor_occupancy.match_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3384326 }, /* unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy : Just Misses. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Misses : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3385702 }, /* unc_cha_tor_occupancy.mmcfg\000uncore_cha\000uncore cache\000TOR Occupancy : MMCFG Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMCFG Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3386609 }, /* unc_cha_tor_occupancy.nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3387242 }, /* unc_cha_tor_occupancy.noncoh\000uncore_cha\000uncore cache\000TOR Occupancy : Just NonCoherent. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NonCoherent : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3387889 }, /* unc_cha_tor_occupancy.not_nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NotNearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NotNearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3388542 }, /* unc_cha_tor_occupancy.pmm\000uncore_cha\000uncore cache\000TOR Occupancy : PMM Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : PMM Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3389154 }, /* unc_cha_tor_occupancy.premorph_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3390017 }, /* unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - IOSF. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000TOR Occupancy : PRQ - IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000 */
{ 3390945 }, /* unc_cha_tor_occupancy.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - Non IOSF. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000TOR Occupancy : PRQ - Non IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3392378 }, /* unc_cha_tor_occupancy.remote_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Remote Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Remote Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3393924 }, /* unc_cha_txr_horz_ads_used.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - All. Unit: uncore_cha \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3394464 }, /* unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_cha \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3394983 }, /* unc_cha_txr_horz_ads_used.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395506 }, /* unc_cha_txr_horz_ads_used.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - All. Unit: uncore_cha \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3396046 }, /* unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_cha \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396565 }, /* unc_cha_txr_horz_ads_used.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396852 }, /* unc_cha_txr_horz_bypass.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_cha \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3397381 }, /* unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_cha \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3397889 }, /* unc_cha_txr_horz_bypass.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398172 }, /* unc_cha_txr_horz_bypass.ak\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AK. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398652 }, /* unc_cha_txr_horz_bypass.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398939 }, /* unc_cha_txr_horz_bypass.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_cha \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3399468 }, /* unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_cha \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399976 }, /* unc_cha_txr_horz_bypass.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400259 }, /* unc_cha_txr_horz_bypass.iv\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : IV. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400739 }, /* unc_cha_txr_horz_cycles_full.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_cha \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3401446 }, /* unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_cha \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402132 }, /* unc_cha_txr_horz_cycles_full.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402512 }, /* unc_cha_txr_horz_cycles_full.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403170 }, /* unc_cha_txr_horz_cycles_full.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403554 }, /* unc_cha_txr_horz_cycles_full.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_cha \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3404261 }, /* unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_cha \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3404947 }, /* unc_cha_txr_horz_cycles_full.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405327 }, /* unc_cha_txr_horz_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405985 }, /* unc_cha_txr_horz_cycles_ne.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_cha \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3406713 }, /* unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_cha \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407420 }, /* unc_cha_txr_horz_cycles_ne.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407813 }, /* unc_cha_txr_horz_cycles_ne.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408492 }, /* unc_cha_txr_horz_cycles_ne.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408889 }, /* unc_cha_txr_horz_cycles_ne.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_cha \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3409617 }, /* unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_cha \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410324 }, /* unc_cha_txr_horz_cycles_ne.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410717 }, /* unc_cha_txr_horz_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411396 }, /* unc_cha_txr_horz_inserts.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_cha \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3412076 }, /* unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_cha \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3412735 }, /* unc_cha_txr_horz_inserts.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413095 }, /* unc_cha_txr_horz_inserts.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413726 }, /* unc_cha_txr_horz_inserts.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3414090 }, /* unc_cha_txr_horz_inserts.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_cha \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3414770 }, /* unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_cha \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415429 }, /* unc_cha_txr_horz_inserts.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415789 }, /* unc_cha_txr_horz_inserts.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416420 }, /* unc_cha_txr_horz_nack.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_cha \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 3416899 }, /* unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_cha \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417358 }, /* unc_cha_txr_horz_nack.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417617 }, /* unc_cha_txr_horz_nack.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AK. Unit: uncore_cha \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418048 }, /* unc_cha_txr_horz_nack.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418311 }, /* unc_cha_txr_horz_nack.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_cha \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 3418790 }, /* unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_cha \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419249 }, /* unc_cha_txr_horz_nack.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419508 }, /* unc_cha_txr_horz_nack.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : IV. Unit: uncore_cha \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419939 }, /* unc_cha_txr_horz_occupancy.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_cha \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3420615 }, /* unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421270 }, /* unc_cha_txr_horz_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421629 }, /* unc_cha_txr_horz_occupancy.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422256 }, /* unc_cha_txr_horz_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422619 }, /* unc_cha_txr_horz_occupancy.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_cha \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3423295 }, /* unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3423950 }, /* unc_cha_txr_horz_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424309 }, /* unc_cha_txr_horz_occupancy.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424936 }, /* unc_cha_txr_horz_starved.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 3425668 }, /* unc_cha_txr_horz_starved.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426061 }, /* unc_cha_txr_horz_starved.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426745 }, /* unc_cha_txr_horz_starved.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3427142 }, /* unc_cha_txr_horz_starved.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 3427874 }, /* unc_cha_txr_horz_starved.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428267 }, /* unc_cha_txr_horz_starved.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_cha \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428951 }, /* unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429457 }, /* unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430432 }, /* unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430938 }, /* unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431446 }, /* unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3431932 }, /* unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432420 }, /* unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432906 }, /* unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433394 }, /* unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433880 }, /* unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434577 }, /* unc_cha_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434840 }, /* unc_cha_txr_vert_bypass_1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3435108 }, /* unc_cha_txr_vert_bypass_1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3438262 }, /* unc_cha_txr_vert_cycles_full0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3438761 }, /* unc_cha_txr_vert_cycles_full0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3439229 }, /* unc_cha_txr_vert_cycles_full0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3439710 }, /* unc_cha_txr_vert_cycles_full0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3440132 }, /* unc_cha_txr_vert_cycles_full0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3440629 }, /* unc_cha_txr_vert_cycles_full0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3441120 }, /* unc_cha_txr_vert_cycles_full0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3441589 }, /* unc_cha_txr_vert_cycles_full1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3442091 }, /* unc_cha_txr_vert_cycles_full1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3445489 }, /* unc_cha_txr_vert_cycles_ne0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3445997 }, /* unc_cha_txr_vert_cycles_ne0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3446474 }, /* unc_cha_txr_vert_cycles_ne0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3446964 }, /* unc_cha_txr_vert_cycles_ne0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3447395 }, /* unc_cha_txr_vert_cycles_ne0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3447901 }, /* unc_cha_txr_vert_cycles_ne0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3448401 }, /* unc_cha_txr_vert_cycles_ne0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3448879 }, /* unc_cha_txr_vert_cycles_ne1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3449390 }, /* unc_cha_txr_vert_cycles_ne1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3452629 }, /* unc_cha_txr_vert_inserts0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3453095 }, /* unc_cha_txr_vert_inserts0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3453530 }, /* unc_cha_txr_vert_inserts0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3453978 }, /* unc_cha_txr_vert_inserts0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3454367 }, /* unc_cha_txr_vert_inserts0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3454831 }, /* unc_cha_txr_vert_inserts0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3455289 }, /* unc_cha_txr_vert_inserts0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3455725 }, /* unc_cha_txr_vert_inserts1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3456194 }, /* unc_cha_txr_vert_inserts1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3458041 }, /* unc_cha_txr_vert_nack0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458287 }, /* unc_cha_txr_vert_nack0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458534 }, /* unc_cha_txr_vert_nack0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458780 }, /* unc_cha_txr_vert_nack0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459027 }, /* unc_cha_txr_vert_nack0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459273 }, /* unc_cha_txr_vert_nack0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459520 }, /* unc_cha_txr_vert_nack0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459746 }, /* unc_cha_txr_vert_nack1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459995 }, /* unc_cha_txr_vert_nack1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3463039 }, /* unc_cha_txr_vert_occupancy0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3463510 }, /* unc_cha_txr_vert_occupancy0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3463950 }, /* unc_cha_txr_vert_occupancy0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3464403 }, /* unc_cha_txr_vert_occupancy0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3464797 }, /* unc_cha_txr_vert_occupancy0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3465266 }, /* unc_cha_txr_vert_occupancy0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3465729 }, /* unc_cha_txr_vert_occupancy0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3466170 }, /* unc_cha_txr_vert_occupancy1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3466644 }, /* unc_cha_txr_vert_occupancy1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3469252 }, /* unc_cha_txr_vert_starved0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3469621 }, /* unc_cha_txr_vert_starved0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3469991 }, /* unc_cha_txr_vert_starved0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3470360 }, /* unc_cha_txr_vert_starved0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3470730 }, /* unc_cha_txr_vert_starved0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471099 }, /* unc_cha_txr_vert_starved0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471469 }, /* unc_cha_txr_vert_starved0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471818 }, /* unc_cha_txr_vert_starved1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472190 }, /* unc_cha_txr_vert_starved1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472562 }, /* unc_cha_txr_vert_starved1.tgc\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3485328 }, /* unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3487111 }, /* unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3488889 }, /* unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3490666 }, /* unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3492438 }, /* unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3494221 }, /* unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3495999 }, /* unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3497776 }, /* unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3499548 }, /* unc_cha_vert_ring_akc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3500469 }, /* unc_cha_vert_ring_akc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3501387 }, /* unc_cha_vert_ring_akc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3502304 }, /* unc_cha_vert_ring_akc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3503218 }, /* unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Even. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3504997 }, /* unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3506771 }, /* unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Even. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3508544 }, /* unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3510312 }, /* unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Down. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3511448 }, /* unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Up. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3512578 }, /* unc_cha_vert_ring_tgc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3513499 }, /* unc_cha_vert_ring_tgc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3514417 }, /* unc_cha_vert_ring_tgc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3515334 }, /* unc_cha_vert_ring_tgc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3516248 }, /* unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000WbPushMtoI : Pushed to LLC : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was able to push WbPushMToI to LLC\000 */
{ 3516797 }, /* unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000WbPushMtoI : Pushed to Memory : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000 */
{ 3519063 }, /* unc_cha_write_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC0 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 0 only\000 */
{ 3521670 }, /* unc_cha_write_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC1 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 1 only\000 */
{ 3519918 }, /* unc_cha_write_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC10. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC10 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 10 only\000 */
{ 3520356 }, /* unc_cha_write_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC11. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC11 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 11 only\000 */
{ 3520794 }, /* unc_cha_write_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC12. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC12 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 12 only\000 */
{ 3521232 }, /* unc_cha_write_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC13. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC13 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 13 only\000 */
{ 3522525 }, /* unc_cha_write_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC2 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 2 only\000 */
{ 3522969 }, /* unc_cha_write_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC3 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 3 only\000 */
{ 3523413 }, /* unc_cha_write_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC4 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 4 only\000 */
{ 3523858 }, /* unc_cha_write_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC5 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 5 only\000 */
{ 3524303 }, /* unc_cha_write_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC6. Unit: uncore_cha \000event=0x5a,umask=0x40\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC6 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 6 only\000 */
{ 3524748 }, /* unc_cha_write_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC7. Unit: uncore_cha \000event=0x5a,umask=0x80\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC7 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 7 only\000 */
{ 3525193 }, /* unc_cha_write_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC8. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC8 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 8 only\000 */
{ 3525627 }, /* unc_cha_write_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC9. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC9 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 9 only\000 */
{ 3526061 }, /* unc_cha_xpt_pref.drop0_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x8\000\00001\000XPT Prefetches : Dropped (on 0?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526320 }, /* unc_cha_xpt_pref.drop0_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x4\000\00001\000XPT Prefetches : Dropped (on 0?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3526581 }, /* unc_cha_xpt_pref.drop1_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x80\000\00001\000XPT Prefetches : Dropped (on 1?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526841 }, /* unc_cha_xpt_pref.drop1_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x40\000\00001\000XPT Prefetches : Dropped (on 1?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3527103 }, /* unc_cha_xpt_pref.sent0\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 0?). Unit: uncore_cha \000event=0x6f,umask=0x1\000\00001\000XPT Prefetches : Sent (on 0?) : Number of XPT prefetches sent\000 */
{ 3527286 }, /* unc_cha_xpt_pref.sent1\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 1?). Unit: uncore_cha \000event=0x6f,umask=0x10\000\00001\000XPT Prefetches : Sent (on 1?) : Number of XPT prefetches sent\000 */
{ 3870998 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Total Write Cache Occupancy : Any Source : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events. : Tracks all requests from any source port\000 */
{ 3872442 }, /* unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Total Write Cache Occupancy : Snoops : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3873110 }, /* unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests to coherent memory. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests to coherent memory.  This is effectively the sum of read occupancy and write occupancy\000 */
{ 3876876 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clockticks of the IO coherency tracker (IRP). Unit: uncore_irp \000event=0x1\000\00001\000\000 */
{ 3877246 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops : CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Coherent Ops : CLFlush : Counts the number of coherency related operations servied by the IRP\000 */
{ 3879579 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline. Unit: uncore_irp \000event=0x10,umask=0x10\000\00001\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline to coherent memory, without a RFO.  PCIITOM is a speculative Invalidate to Modified command that requests ownership of the cacheline and does not move data from the mesh to IRP cache\000 */
{ 3880245 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline. Unit: uncore_irp \000event=0x10,umask=0x8\000\00001\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline to coherent memory.  RFO is a Read For Ownership command that requests ownership of the cacheline and moves data from the mesh to IRP cache\000 */
{ 3880677 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops : WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Coherent Ops : WbMtoI : Counts the number of coherency related operations servied by the IRP\000 */
{ 3881278 }, /* unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000 */
{ 3881484 }, /* unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000Inbound read requests received by the IRP and inserted into the FAF queue. Unit: uncore_irp \000event=0x18\000\00001\000Inbound read requests to coherent memory, received by the IRP and inserted into the Fire and Forget queue (FAF), a queue used for processing inbound reads in the IRP\000 */
{ 3881907 }, /* unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000Occupancy of the IRP FAF queue. Unit: uncore_irp \000event=0x19\000\00001\000Occupancy of the IRP Fire and Forget (FAF) queue, a queue used for processing inbound reads in the IRP\000 */
{ 3882126 }, /* unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000 */
{ 3882245 }, /* unc_i_irp_all.evicts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3882382 }, /* unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3882674 }, /* unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3882966 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x10\000\00001\000\000 */
{ 3883580 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x4\000\00001\000\000 */
{ 3884171 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x8\000\00001\000\000 */
{ 3884766 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Rejects. Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 3885218 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Requests. Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 3885674 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x20\000\00001\000\000 */
{ 3886244 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x40\000\00001\000\000 */
{ 3887083 }, /* unc_i_misc0.slowpath_fwpf_no_prf\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Slow path fwpf didn't find prefetch. Unit: uncore_irp \000event=0x1e,umask=0x80\000\00001\000\000 */
{ 3887536 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Lost Forward. Unit: uncore_irp \000event=0x1f,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888161 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Invalid. Unit: uncore_irp \000event=0x1f,umask=0x20\000\00001\000Misc Events - Set 1 : Received Invalid : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3888836 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Valid. Unit: uncore_irp \000event=0x1f,umask=0x40\000\00001\000Misc Events - Set 1 : Received Valid : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889485 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of E Line. Unit: uncore_irp \000event=0x1f,umask=0x4\000\00001\000Misc Events - Set 1 : Slow Transfer of E Line : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890149 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of I Line. Unit: uncore_irp \000event=0x1f,umask=0x1\000\00001\000Misc Events - Set 1 : Slow Transfer of I Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3890819 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of M Line. Unit: uncore_irp \000event=0x1f,umask=0x8\000\00001\000Misc Events - Set 1 : Slow Transfer of M Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3891489 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of S Line. Unit: uncore_irp \000event=0x1f,umask=0x2\000\00001\000Misc Events - Set 1 : Slow Transfer of S Line : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3892165 }, /* unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P Requests : P2P requests from the ITC\000 */
{ 3892549 }, /* unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P Occupancy : P2P B & S Queue Occupancy\000 */
{ 3892690 }, /* unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000 */
{ 3892967 }, /* unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000 */
{ 3893252 }, /* unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000 */
{ 3893593 }, /* unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000 */
{ 3893860 }, /* unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000 */
{ 3894121 }, /* unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions : Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000 */
{ 3894408 }, /* unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000 */
{ 3894751 }, /* unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000 */
{ 3900346 }, /* unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000 */
{ 3900612 }, /* unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000 */
{ 3900881 }, /* unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000 */
{ 3901139 }, /* unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000 */
{ 3901397 }, /* unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000 */
{ 3901636 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000 */
{ 3902049 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000 */
{ 3902439 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000 */
{ 3902829 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses : Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000 */
{ 3903212 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000 */
{ 3903619 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000 */
{ 3904026 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000 */
{ 3906074 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Inbound Transaction Count : Atomic : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of atomic transactions\000 */
{ 3907592 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Inbound Transaction Count : Other : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of 'other' kinds of transactions\000 */
{ 3914035 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000 */
{ 3914331 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Inbound Transaction Count : Writes : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3918099 }, /* unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000 */
{ 3918207 }, /* unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000 */
{ 3918327 }, /* unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000 */
{ 3918439 }, /* unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000 */
{ 3918555 }, /* unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000 */
{ 3918675 }, /* unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000 */
{ 3918787 }, /* unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000 */
{ 3918903 }, /* unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000 */
{ 3919023 }, /* unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000 */
{ 3919135 }, /* unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000 */
{ 3919251 }, /* unc_i_txr2_ad01_stall_credit_cycles\000uncore_irp\000uncore interconnect\000UNC_I_TxR2_AD01_STALL_CREDIT_CYCLES. Unit: uncore_irp \000event=0x1c\000\00001\000: Counts the number times when it is not possible to issue a request to the M2PCIe because there are no Egress Credits available on AD0, A1 or AD0&AD1 both. Stalls on both AD0 and AD1 will count as 2\000 */
{ 3919924 }, /* unc_i_txr2_ad0_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD0 Egress Credits Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000No AD0 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD0 Egress Credits available\000 */
{ 3920215 }, /* unc_i_txr2_ad1_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD1 Egress Credits Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000No AD1 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD1 Egress Credits available\000 */
{ 3921013 }, /* unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1d\000\00001\000No BL Egress Credit Stalls : Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3923058 }, /* unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923457 }, /* unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3924019 }, /* unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Outbound Request Queue Occupancy : Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 4331486 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331772 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332058 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332344 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332630 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332917 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333204 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333491 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333778 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334067 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334353 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4336033 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336320 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336607 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336894 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337181 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337469 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337757 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338045 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338333 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338623 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338910 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4340591 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340877 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341163 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341449 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341735 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342022 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342309 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342596 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342883 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343172 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343458 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4345138 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345425 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345712 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345999 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346286 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346574 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346862 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347150 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347438 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347728 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4348015 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4349696 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349982 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350268 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350554 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350840 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351127 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351414 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351701 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351988 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352277 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352563 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4354243 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354530 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354817 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355104 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355391 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355679 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355967 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356255 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356543 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356833 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4357120 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4357407 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4357693 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4357979 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358265 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358551 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358838 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359125 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359412 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359699 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359988 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4360274 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4361954 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362241 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362528 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362815 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363102 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363390 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363678 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363966 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364254 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364544 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364831 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4366536 }, /* unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000\000 */
{ 4366939 }, /* unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000 */
{ 4367206 }, /* unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000 */
{ 4367491 }, /* unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000 */
{ 4367760 }, /* unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Clockticks of the mesh to memory (M2M). Unit: uncore_m2m \000event=0\000\00001\000\000 */
{ 4368117 }, /* unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000 */
{ 4369061 }, /* unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode, which bypasses the CHA, was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000\000 */
{ 4369413 }, /* unc_m2m_direct2core_not_taken_notforked\000uncore_m2m\000uncore interconnect\000UNC_M2M_DIRECT2CORE_NOT_TAKEN_NOTFORKED. Unit: uncore_m2m \000event=0x60\000\00001\000\000 */
{ 4370156 }, /* unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4370954 }, /* unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2m \000event=0x28\000\00001\000\000 */
{ 4372414 }, /* unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled. Unit: uncore_m2m \000event=0x27\000\00001\000\000 */
{ 4373770 }, /* unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2m \000event=0x29\000\00001\000Clockticks of the mesh to PCI (M2P)\000 */
{ 4374741 }, /* unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 4375193 }, /* unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 4375645 }, /* unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 4376097 }, /* unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 4376545 }, /* unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 4376985 }, /* unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 4377425 }, /* unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 4377865 }, /* unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 4378158 }, /* unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in any state. Unit: uncore_m2m \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 4378899 }, /* unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in A state. Unit: uncore_m2m \000event=0x2d,umask=0x8\000\00001\000\000 */
{ 4379861 }, /* unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in I state. Unit: uncore_m2m \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 4380810 }, /* unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Lookups : Found in S state. Unit: uncore_m2m \000event=0x2d,umask=0x4\000\00001\000\000 */
{ 4381937 }, /* unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x80\000\00001\000\000 */
{ 4382395 }, /* unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x10\000\00001\000\000 */
{ 4382853 }, /* unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x40\000\00001\000\000 */
{ 4383311 }, /* unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x20\000\00001\000\000 */
{ 4383765 }, /* unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x8\000\00001\000\000 */
{ 4384211 }, /* unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x1\000\00001\000\000 */
{ 4384657 }, /* unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x4\000\00001\000\000 */
{ 4385103 }, /* unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x2\000\00001\000\000 */
{ 4387411 }, /* unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates : From/to any state. Note: event counts are incorrect in 2LM mode. Unit: uncore_m2m \000event=0x2e,umask=0x1\000\00001\000\000 */
{ 4392599 }, /* unc_m2m_distress_asserted.dpt_local\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Local. Unit: uncore_m2m \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 4392925 }, /* unc_m2m_distress_asserted.dpt_nonlocal\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Remote. Unit: uncore_m2m \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 4393255 }, /* unc_m2m_distress_asserted.dpt_stall_iv\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2m \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 4393622 }, /* unc_m2m_distress_asserted.dpt_stall_nocrd\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2m \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 4394002 }, /* unc_m2m_distress_asserted.horz\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Horizontal. Unit: uncore_m2m \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4394354 }, /* unc_m2m_distress_asserted.pmm_local\000uncore_m2m\000uncore interconnect\000Distress signal asserted : PMM Local. Unit: uncore_m2m \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4394728 }, /* unc_m2m_distress_asserted.pmm_nonlocal\000uncore_m2m\000uncore interconnect\000Distress signal asserted : PMM Remote. Unit: uncore_m2m \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4395111 }, /* unc_m2m_distress_asserted.vert\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Vertical. Unit: uncore_m2m \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4395459 }, /* unc_m2m_distress_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_DISTRESS_PMM. Unit: uncore_m2m \000event=0xf2\000\00001\000\000 */
{ 4395567 }, /* unc_m2m_distress_pmm_memmode\000uncore_m2m\000uncore interconnect\000UNC_M2M_DISTRESS_PMM_MEMMODE. Unit: uncore_m2m \000event=0xf1\000\00001\000\000 */
{ 4395691 }, /* unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2m \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4396579 }, /* unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2m \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397989 }, /* unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4399798 }, /* unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4401602 }, /* unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4403416 }, /* unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4405225 }, /* unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4407030 }, /* unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4408830 }, /* unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4410640 }, /* unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4412445 }, /* unc_m2m_horz_ring_akc_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4413379 }, /* unc_m2m_horz_ring_akc_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4414310 }, /* unc_m2m_horz_ring_akc_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4415247 }, /* unc_m2m_horz_ring_akc_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4416181 }, /* unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2m \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4417988 }, /* unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4419790 }, /* unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2m \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4421602 }, /* unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4423409 }, /* unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Left. Unit: uncore_m2m \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4424573 }, /* unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Right. Unit: uncore_m2m \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4425892 }, /* unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x704\000\00001\000\000 */
{ 4426664 }, /* unc_m2m_imc_reads.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x104\000\00001\000\000 */
{ 4426997 }, /* unc_m2m_imc_reads.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x140\000\00001\000\000 */
{ 4427287 }, /* unc_m2m_imc_reads.ch0_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x102\000\00001\000\000 */
{ 4427577 }, /* unc_m2m_imc_reads.ch0_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x101\000\00001\000\000 */
{ 4427906 }, /* unc_m2m_imc_reads.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x110\000\00001\000\000 */
{ 4428229 }, /* unc_m2m_imc_reads.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x108\000\00001\000\000 */
{ 4428529 }, /* unc_m2m_imc_reads.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x120\000\00001\000M2M Reads Issued to iMC : PMM - Ch0 : Counts all PMM dimm read requests(full line) sent from M2M to iMC\000 */
{ 4429233 }, /* unc_m2m_imc_reads.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x204\000\00001\000\000 */
{ 4429566 }, /* unc_m2m_imc_reads.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x240\000\00001\000\000 */
{ 4429856 }, /* unc_m2m_imc_reads.ch1_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x202\000\00001\000\000 */
{ 4430146 }, /* unc_m2m_imc_reads.ch1_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x201\000\00001\000\000 */
{ 4430475 }, /* unc_m2m_imc_reads.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x210\000\00001\000\000 */
{ 4430798 }, /* unc_m2m_imc_reads.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x208\000\00001\000\000 */
{ 4431098 }, /* unc_m2m_imc_reads.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x220\000\00001\000M2M Reads Issued to iMC : PMM - Ch1 : Counts all PMM dimm read requests(full line) sent from M2M to iMC\000 */
{ 4431518 }, /* unc_m2m_imc_reads.ch2_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch2. Unit: uncore_m2m \000event=0x37,umask=0x440\000\00001\000\000 */
{ 4431668 }, /* unc_m2m_imc_reads.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x740\000\00001\000\000 */
{ 4432119 }, /* unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x702\000\00001\000\000 */
{ 4432549 }, /* unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x701\000\00001\000\000 */
{ 4433131 }, /* unc_m2m_imc_reads.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x710\000\00001\000\000 */
{ 4433451 }, /* unc_m2m_imc_reads.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : DDR - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x708\000\00001\000\000 */
{ 4434016 }, /* unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : PMM - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x720\000\00001\000\000 */
{ 4434658 }, /* unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c10\000\00001\000\000 */
{ 4435127 }, /* unc_m2m_imc_writes.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x410\000\00001\000\000 */
{ 4435559 }, /* unc_m2m_imc_writes.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4435699 }, /* unc_m2m_imc_writes.ch0_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x401\000\00001\000\000 */
{ 4436030 }, /* unc_m2m_imc_writes.ch0_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x404\000\00001\000\000 */
{ 4436337 }, /* unc_m2m_imc_writes.ch0_ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4436588 }, /* unc_m2m_imc_writes.ch0_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4436859 }, /* unc_m2m_imc_writes.ch0_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x402\000\00001\000\000 */
{ 4437197 }, /* unc_m2m_imc_writes.ch0_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x408\000\00001\000\000 */
{ 4437655 }, /* unc_m2m_imc_writes.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x440\000\00001\000\000 */
{ 4437826 }, /* unc_m2m_imc_writes.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x420\000\00001\000\000 */
{ 4438130 }, /* unc_m2m_imc_writes.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x480\000\00001\000M2M Writes Issued to iMC : PMM - Ch0 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000 */
{ 4438913 }, /* unc_m2m_imc_writes.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x810\000\00001\000\000 */
{ 4439175 }, /* unc_m2m_imc_writes.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4439486 }, /* unc_m2m_imc_writes.ch1_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x801\000\00001\000\000 */
{ 4439780 }, /* unc_m2m_imc_writes.ch1_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x804\000\00001\000\000 */
{ 4439941 }, /* unc_m2m_imc_writes.ch1_ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4440192 }, /* unc_m2m_imc_writes.ch1_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4440463 }, /* unc_m2m_imc_writes.ch1_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x802\000\00001\000\000 */
{ 4440931 }, /* unc_m2m_imc_writes.ch1_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x808\000\00001\000\000 */
{ 4441238 }, /* unc_m2m_imc_writes.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x840\000\00001\000\000 */
{ 4441535 }, /* unc_m2m_imc_writes.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x820\000\00001\000\000 */
{ 4441687 }, /* unc_m2m_imc_writes.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x880\000\00001\000M2M Writes Issued to iMC : PMM - Ch1 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000 */
{ 4442316 }, /* unc_m2m_imc_writes.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4442760 }, /* unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c01\000\00001\000\000 */
{ 4443211 }, /* unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c04\000\00001\000\000 */
{ 4443526 }, /* unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4443940 }, /* unc_m2m_imc_writes.ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4444221 }, /* unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c02\000\00001\000\000 */
{ 4444957 }, /* unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c08\000\00001\000\000 */
{ 4445424 }, /* unc_m2m_imc_writes.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c40\000\00001\000\000 */
{ 4445732 }, /* unc_m2m_imc_writes.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : DDR - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c20\000\00001\000\000 */
{ 4445890 }, /* unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : PMM - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c80\000\00001\000\000 */
{ 4446407 }, /* unc_m2m_mirr_wrq_inserts\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts. Unit: uncore_m2m \000event=0x64\000\00001\000\000 */
{ 4446520 }, /* unc_m2m_mirr_wrq_occupancy\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x65\000\00001\000\000 */
{ 4446637 }, /* unc_m2m_misc_external.mbe_inst0\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2m \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 4446830 }, /* unc_m2m_misc_external.mbe_inst1\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2m \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 4447023 }, /* unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4447296 }, /* unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4448697 }, /* unc_m2m_prefcam_cis_drops\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_CIS_DROPS. Unit: uncore_m2m \000event=0x73\000\00001\000\000 */
{ 4448815 }, /* unc_m2m_prefcam_cycles_full.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : All Channels. Unit: uncore_m2m \000event=0x6b,umask=0x7\000\00001\000\000 */
{ 4448965 }, /* unc_m2m_prefcam_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 4449110 }, /* unc_m2m_prefcam_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 4449255 }, /* unc_m2m_prefcam_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x6b,umask=0x4\000\00001\000\000 */
{ 4449519 }, /* unc_m2m_prefcam_cycles_ne.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : All Channels. Unit: uncore_m2m \000event=0x6c,umask=0x7\000\00001\000\000 */
{ 4449672 }, /* unc_m2m_prefcam_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x6c,umask=0x1\000\00001\000\000 */
{ 4449820 }, /* unc_m2m_prefcam_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x6c,umask=0x2\000\00001\000\000 */
{ 4449968 }, /* unc_m2m_prefcam_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x6c,umask=0x4\000\00001\000\000 */
{ 4450238 }, /* unc_m2m_prefcam_deallocs.ch0_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x1\000\00001\000\000 */
{ 4450377 }, /* unc_m2m_prefcam_deallocs.ch0_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x2\000\00001\000\000 */
{ 4450516 }, /* unc_m2m_prefcam_deallocs.ch0_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x4\000\00001\000\000 */
{ 4450654 }, /* unc_m2m_prefcam_deallocs.ch0_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x8\000\00001\000\000 */
{ 4450793 }, /* unc_m2m_prefcam_deallocs.ch1_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x10\000\00001\000\000 */
{ 4450933 }, /* unc_m2m_prefcam_deallocs.ch1_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x20\000\00001\000\000 */
{ 4451073 }, /* unc_m2m_prefcam_deallocs.ch1_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x40\000\00001\000\000 */
{ 4451212 }, /* unc_m2m_prefcam_deallocs.ch1_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x80\000\00001\000\000 */
{ 4451352 }, /* unc_m2m_prefcam_deallocs.ch2_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000 */
{ 4451481 }, /* unc_m2m_prefcam_deallocs.ch2_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000 */
{ 4451610 }, /* unc_m2m_prefcam_deallocs.ch2_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000 */
{ 4451738 }, /* unc_m2m_prefcam_deallocs.ch2_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e\000\00001\000\000 */
{ 4451867 }, /* unc_m2m_prefcam_demand_drops.ch0_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 0. Unit: uncore_m2m \000event=0x6f,umask=0x2\000\00001\000\000 */
{ 4452154 }, /* unc_m2m_prefcam_demand_drops.ch0_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 0. Unit: uncore_m2m \000event=0x6f,umask=0x1\000\00001\000\000 */
{ 4452441 }, /* unc_m2m_prefcam_demand_drops.ch1_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 1. Unit: uncore_m2m \000event=0x6f,umask=0x8\000\00001\000\000 */
{ 4452728 }, /* unc_m2m_prefcam_demand_drops.ch1_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 1. Unit: uncore_m2m \000event=0x6f,umask=0x4\000\00001\000\000 */
{ 4453015 }, /* unc_m2m_prefcam_demand_drops.ch2_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - Ch 2. Unit: uncore_m2m \000event=0x6f,umask=0x20\000\00001\000\000 */
{ 4453166 }, /* unc_m2m_prefcam_demand_drops.ch2_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 2. Unit: uncore_m2m \000event=0x6f,umask=0x10\000\00001\000\000 */
{ 4453477 }, /* unc_m2m_prefcam_demand_drops.upi_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2m \000event=0x6f,umask=0x2a\000\00001\000\000 */
{ 4453638 }, /* unc_m2m_prefcam_demand_drops.xpt_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - All Channels. Unit: uncore_m2m \000event=0x6f,umask=0x15\000\00001\000\000 */
{ 4454101 }, /* unc_m2m_prefcam_demand_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 0. Unit: uncore_m2m \000event=0x74,umask=0x1\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 0\000 */
{ 4454490 }, /* unc_m2m_prefcam_demand_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x74,umask=0x4\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 1\000 */
{ 4454716 }, /* unc_m2m_prefcam_demand_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 2. Unit: uncore_m2m \000event=0x74,umask=0x10\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 2\000 */
{ 4455389 }, /* unc_m2m_prefcam_demand_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- All Channels. Unit: uncore_m2m \000event=0x74,umask=0x15\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - All Channels\000 */
{ 4455804 }, /* unc_m2m_prefcam_demand_no_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 0. Unit: uncore_m2m \000event=0x75,umask=0x1\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 0\000 */
{ 4456211 }, /* unc_m2m_prefcam_demand_no_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x75,umask=0x4\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 1\000 */
{ 4456448 }, /* unc_m2m_prefcam_demand_no_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 2. Unit: uncore_m2m \000event=0x75,umask=0x10\000\00001\000\000 */
{ 4457291 }, /* unc_m2m_prefcam_demand_no_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - All Channels. Unit: uncore_m2m \000event=0x75,umask=0x15\000\00001\000\000 */
{ 4457895 }, /* unc_m2m_prefcam_drop_reasons_ch0.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x10\000\00001\000\000 */
{ 4458056 }, /* unc_m2m_prefcam_drop_reasons_ch0.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x2\000\00001\000\000 */
{ 4458221 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x20\000\00001\000\000 */
{ 4458379 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x40\000\00001\000\000 */
{ 4458539 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x4\000\00001\000\000 */
{ 4458697 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x1\000\00001\000\000 */
{ 4458859 }, /* unc_m2m_prefcam_drop_reasons_ch0.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000 */
{ 4459006 }, /* unc_m2m_prefcam_drop_reasons_ch0.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x8\000\00001\000\000 */
{ 4459162 }, /* unc_m2m_prefcam_drop_reasons_ch0.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000 */
{ 4459310 }, /* unc_m2m_prefcam_drop_reasons_ch0.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x80\000\00001\000\000 */
{ 4459468 }, /* unc_m2m_prefcam_drop_reasons_ch0.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000 */
{ 4459616 }, /* unc_m2m_prefcam_drop_reasons_ch1.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x10\000\00001\000\000 */
{ 4459777 }, /* unc_m2m_prefcam_drop_reasons_ch1.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x2\000\00001\000\000 */
{ 4459942 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x20\000\00001\000\000 */
{ 4460100 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x40\000\00001\000\000 */
{ 4460260 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x4\000\00001\000\000 */
{ 4460418 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x1\000\00001\000\000 */
{ 4460580 }, /* unc_m2m_prefcam_drop_reasons_ch1.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000 */
{ 4460727 }, /* unc_m2m_prefcam_drop_reasons_ch1.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x8\000\00001\000\000 */
{ 4460883 }, /* unc_m2m_prefcam_drop_reasons_ch1.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000 */
{ 4461031 }, /* unc_m2m_prefcam_drop_reasons_ch1.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x80\000\00001\000\000 */
{ 4461189 }, /* unc_m2m_prefcam_drop_reasons_ch1.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000 */
{ 4461337 }, /* unc_m2m_prefcam_drop_reasons_ch2.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x10\000\00001\000\000 */
{ 4461498 }, /* unc_m2m_prefcam_drop_reasons_ch2.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x2\000\00001\000\000 */
{ 4461663 }, /* unc_m2m_prefcam_drop_reasons_ch2.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x20\000\00001\000\000 */
{ 4461821 }, /* unc_m2m_prefcam_drop_reasons_ch2.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x40\000\00001\000\000 */
{ 4461981 }, /* unc_m2m_prefcam_drop_reasons_ch2.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x4\000\00001\000\000 */
{ 4462139 }, /* unc_m2m_prefcam_drop_reasons_ch2.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x1\000\00001\000\000 */
{ 4462301 }, /* unc_m2m_prefcam_drop_reasons_ch2.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000 */
{ 4462448 }, /* unc_m2m_prefcam_drop_reasons_ch2.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x8\000\00001\000\000 */
{ 4462604 }, /* unc_m2m_prefcam_drop_reasons_ch2.upi_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000 */
{ 4462752 }, /* unc_m2m_prefcam_drop_reasons_ch2.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72,umask=0x80\000\00001\000\000 */
{ 4462910 }, /* unc_m2m_prefcam_drop_reasons_ch2.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch2 - Reasons. Unit: uncore_m2m \000event=0x72\000\00001\000\000 */
{ 4463200 }, /* unc_m2m_prefcam_inserts.ch0_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2m \000event=0x6d,umask=0x2\000\00001\000\000 */
{ 4463484 }, /* unc_m2m_prefcam_inserts.ch0_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2m \000event=0x6d,umask=0x1\000\00001\000\000 */
{ 4463768 }, /* unc_m2m_prefcam_inserts.ch1_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2m \000event=0x6d,umask=0x8\000\00001\000\000 */
{ 4464052 }, /* unc_m2m_prefcam_inserts.ch1_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2m \000event=0x6d,umask=0x4\000\00001\000\000 */
{ 4464194 }, /* unc_m2m_prefcam_inserts.ch2_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 2. Unit: uncore_m2m \000event=0x6d,umask=0x20\000\00001\000\000 */
{ 4464337 }, /* unc_m2m_prefcam_inserts.ch2_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 2. Unit: uncore_m2m \000event=0x6d,umask=0x10\000\00001\000\000 */
{ 4464632 }, /* unc_m2m_prefcam_inserts.upi_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2m \000event=0x6d,umask=0x2a\000\00001\000\000 */
{ 4464977 }, /* unc_m2m_prefcam_inserts.xpt_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2m \000event=0x6d,umask=0x15\000\00001\000\000 */
{ 4465619 }, /* unc_m2m_prefcam_occupancy.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2m \000event=0x6a,umask=0x7\000\00001\000\000 */
{ 4465906 }, /* unc_m2m_prefcam_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2m \000event=0x6a,umask=0x1\000\00001\000\000 */
{ 4466188 }, /* unc_m2m_prefcam_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2m \000event=0x6a,umask=0x2\000\00001\000\000 */
{ 4466329 }, /* unc_m2m_prefcam_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 2. Unit: uncore_m2m \000event=0x6a,umask=0x4\000\00001\000\000 */
{ 4466585 }, /* unc_m2m_prefcam_resp_miss.allch\000uncore_m2m\000uncore interconnect\000: All Channels. Unit: uncore_m2m \000event=0x76,umask=0x7\000\00001\000\000 */
{ 4466947 }, /* unc_m2m_prefcam_resp_miss.ch0\000uncore_m2m\000uncore interconnect\000: Channel 0. Unit: uncore_m2m \000event=0x76,umask=0x1\000\00001\000\000 */
{ 4467183 }, /* unc_m2m_prefcam_resp_miss.ch1\000uncore_m2m\000uncore interconnect\000: Channel 1. Unit: uncore_m2m \000event=0x76,umask=0x2\000\00001\000\000 */
{ 4467301 }, /* unc_m2m_prefcam_resp_miss.ch2\000uncore_m2m\000uncore interconnect\000: Channel 2. Unit: uncore_m2m \000event=0x76,umask=0x4\000\00001\000\000 */
{ 4467419 }, /* unc_m2m_prefcam_rxc_cycles_ne\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_CYCLES_NE. Unit: uncore_m2m \000event=0x79\000\00001\000\000 */
{ 4467701 }, /* unc_m2m_prefcam_rxc_deallocs.1lm_posted\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2m \000event=0x7a,umask=0x2\000\00001\000\000 */
{ 4467999 }, /* unc_m2m_prefcam_rxc_deallocs.cis\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2m \000event=0x7a,umask=0x8\000\00001\000\000 */
{ 4468313 }, /* unc_m2m_prefcam_rxc_deallocs.pmm_memmode_accept\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.PMM_MEMMODE_ACCEPT. Unit: uncore_m2m \000event=0x7a,umask=0x4\000\00001\000\000 */
{ 4468637 }, /* unc_m2m_prefcam_rxc_deallocs.squashed\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2m \000event=0x7a,umask=0x1\000\00001\000\000 */
{ 4468789 }, /* unc_m2m_prefcam_rxc_inserts\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_INSERTS. Unit: uncore_m2m \000event=0x78\000\00001\000\000 */
{ 4469052 }, /* unc_m2m_prefcam_rxc_occupancy\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_OCCUPANCY. Unit: uncore_m2m \000event=0x77\000\00001\000\000 */
{ 4469178 }, /* unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4469724 }, /* unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2m \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470270 }, /* unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470816 }, /* unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2m \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471362 }, /* unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4471898 }, /* unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472500 }, /* unc_m2m_ring_bounces_vert.akc\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. Unit: uncore_m2m \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472785 }, /* unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473381 }, /* unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473993 }, /* unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000\000 */
{ 4474292 }, /* unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2m \000event=0xad,umask=0x2\000\00001\000\000 */
{ 4474591 }, /* unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xad,umask=0x20\000\00001\000\000 */
{ 4474950 }, /* unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000\000 */
{ 4475249 }, /* unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2m \000event=0xad,umask=0x8\000\00001\000\000 */
{ 4475548 }, /* unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000\000 */
{ 4475843 }, /* unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000\000 */
{ 4476182 }, /* unc_m2m_ring_sink_starved_vert.akc\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring. Unit: uncore_m2m \000event=0xab,umask=0x10\000\00001\000\000 */
{ 4476327 }, /* unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000\000 */
{ 4476662 }, /* unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000\000 */
{ 4477112 }, /* unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xae\000\00001\000\000 */
{ 4478804 }, /* unc_m2m_rpq_no_reg_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4478961 }, /* unc_m2m_rpq_no_reg_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4479118 }, /* unc_m2m_rpq_no_reg_crd.ch2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 2. Unit: uncore_m2m \000event=0x43,umask=0x4\000\00001\000\000 */
{ 4479275 }, /* unc_m2m_rpq_no_reg_crd_pmm.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 0. Unit: uncore_m2m \000event=0x4f,umask=0x1\000\00001\000\000 */
{ 4479431 }, /* unc_m2m_rpq_no_reg_crd_pmm.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 1. Unit: uncore_m2m \000event=0x4f,umask=0x2\000\00001\000\000 */
{ 4479587 }, /* unc_m2m_rpq_no_reg_crd_pmm.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC RPQ Cycles w/Credits - PMM : Channel 2. Unit: uncore_m2m \000event=0x4f,umask=0x4\000\00001\000\000 */
{ 4479743 }, /* unc_m2m_rpq_no_spec_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4479901 }, /* unc_m2m_rpq_no_spec_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4480059 }, /* unc_m2m_rpq_no_spec_crd.ch2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4480217 }, /* unc_m2m_rxc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x4\000\00001\000\000 */
{ 4480336 }, /* unc_m2m_rxc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x3\000\00001\000\000 */
{ 4480614 }, /* unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x1\000\00001\000\000 */
{ 4481030 }, /* unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x2\000\00001\000\000 */
{ 4481274 }, /* unc_m2m_rxc_ad_pref_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy - Prefetches. Unit: uncore_m2m \000event=0x77\000\00001\000\000 */
{ 4481415 }, /* unc_m2m_rxc_ak_wr_cmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x5c\000\00001\000\000 */
{ 4481534 }, /* unc_m2m_rxc_bl_cycles_full\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x8\000\00001\000\000 */
{ 4481653 }, /* unc_m2m_rxc_bl_cycles_ne\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x7\000\00001\000\000 */
{ 4481775 }, /* unc_m2m_rxc_bl_inserts\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x5\000\00001\000\000 */
{ 4481897 }, /* unc_m2m_rxc_bl_occupancy\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x6\000\00001\000\000 */
{ 4482019 }, /* unc_m2m_rxr_busy_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4482876 }, /* unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4483713 }, /* unc_m2m_rxr_busy_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4484163 }, /* unc_m2m_rxr_busy_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4485020 }, /* unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4485857 }, /* unc_m2m_rxr_busy_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4486307 }, /* unc_m2m_rxr_bypass.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2m \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4486744 }, /* unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4487161 }, /* unc_m2m_rxr_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4487398 }, /* unc_m2m_rxr_bypass.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AK. Unit: uncore_m2m \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 4487787 }, /* unc_m2m_rxr_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4488028 }, /* unc_m2m_rxr_bypass.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2m \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4488465 }, /* unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4488882 }, /* unc_m2m_rxr_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4489119 }, /* unc_m2m_rxr_bypass.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : IV. Unit: uncore_m2m \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 4489508 }, /* unc_m2m_rxr_crd_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4490388 }, /* unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4491247 }, /* unc_m2m_rxr_crd_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4491708 }, /* unc_m2m_rxr_crd_starved.ak\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AK. Unit: uncore_m2m \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4492539 }, /* unc_m2m_rxr_crd_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4493419 }, /* unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4494278 }, /* unc_m2m_rxr_crd_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4494739 }, /* unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4495595 }, /* unc_m2m_rxr_crd_starved.iv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IV. Unit: uncore_m2m \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496426 }, /* unc_m2m_rxr_crd_starved_1\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation. Unit: uncore_m2m \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496834 }, /* unc_m2m_rxr_inserts.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2m \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4497416 }, /* unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4497978 }, /* unc_m2m_rxr_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498290 }, /* unc_m2m_rxr_inserts.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AK. Unit: uncore_m2m \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498824 }, /* unc_m2m_rxr_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4499140 }, /* unc_m2m_rxr_inserts.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2m \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4499722 }, /* unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500284 }, /* unc_m2m_rxr_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500596 }, /* unc_m2m_rxr_inserts.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : IV. Unit: uncore_m2m \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4501130 }, /* unc_m2m_rxr_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2m \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4501726 }, /* unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502302 }, /* unc_m2m_rxr_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502620 }, /* unc_m2m_rxr_occupancy.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AK. Unit: uncore_m2m \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503168 }, /* unc_m2m_rxr_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503490 }, /* unc_m2m_rxr_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2m \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4504086 }, /* unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504662 }, /* unc_m2m_rxr_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504980 }, /* unc_m2m_rxr_occupancy.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : IV. Unit: uncore_m2m \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4505528 }, /* unc_m2m_scoreboard_ad_retry_accepts\000uncore_m2m\000uncore interconnect\000UNC_M2M_SCOREBOARD_AD_RETRY_ACCEPTS. Unit: uncore_m2m \000event=0x33\000\00001\000\000 */
{ 4505666 }, /* unc_m2m_scoreboard_ad_retry_rejects\000uncore_m2m\000uncore interconnect\000UNC_M2M_SCOREBOARD_AD_RETRY_REJECTS. Unit: uncore_m2m \000event=0x34\000\00001\000\000 */
{ 4505804 }, /* unc_m2m_scoreboard_bl_retry_accepts\000uncore_m2m\000uncore interconnect\000Retry - Mem Mirroring Mode. Unit: uncore_m2m \000event=0x35\000\00001\000\000 */
{ 4505933 }, /* unc_m2m_scoreboard_bl_retry_rejects\000uncore_m2m\000uncore interconnect\000Retry - Mem Mirroring Mode. Unit: uncore_m2m \000event=0x36\000\00001\000\000 */
{ 4506062 }, /* unc_m2m_scoreboard_rd_accepts\000uncore_m2m\000uncore interconnect\000Scoreboard Accepts. Unit: uncore_m2m \000event=0x2f\000\00001\000\000 */
{ 4506177 }, /* unc_m2m_scoreboard_rd_rejects\000uncore_m2m\000uncore interconnect\000Scoreboard Rejects. Unit: uncore_m2m \000event=0x30\000\00001\000\000 */
{ 4506292 }, /* unc_m2m_scoreboard_wr_accepts\000uncore_m2m\000uncore interconnect\000Scoreboard Accepts. Unit: uncore_m2m \000event=0x31\000\00001\000\000 */
{ 4506407 }, /* unc_m2m_scoreboard_wr_rejects\000uncore_m2m\000uncore interconnect\000Scoreboard Rejects. Unit: uncore_m2m \000event=0x32\000\00001\000\000 */
{ 4506522 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4506880 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507238 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507596 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507954 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4508313 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4508672 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509031 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509390 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509748 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510106 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510464 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510822 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511181 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511540 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511899 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512258 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512616 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512974 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4513332 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4513690 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514049 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514408 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514767 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515126 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515484 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515842 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516200 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516558 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516917 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517276 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517635 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517994 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4518355 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4518713 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519071 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519434 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519794 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520154 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520517 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520877 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521237 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521600 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521960 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4529827 }, /* unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Read Hit. Unit: uncore_m2m \000event=0x2c,umask=0x1\000\00001\000Tag Hit : Clean NearMem Read Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean full line read hits (reads and RFOs)\000 */
{ 4530534 }, /* unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Read Hit. Unit: uncore_m2m \000event=0x2c,umask=0x2\000\00001\000Tag Hit : Dirty NearMem Read Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty full line read hits (reads and RFOs)\000 */
{ 4531334 }, /* unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Underfill Hit. Unit: uncore_m2m \000event=0x2c,umask=0x4\000\00001\000Tag Hit : Clean NearMem Underfill Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean underfill hits due to a partial write\000 */
{ 4532154 }, /* unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Underfill Hit. Unit: uncore_m2m \000event=0x2c,umask=0x8\000\00001\000Tag Hit : Dirty NearMem Underfill Hit : Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty underfill read hits due to a partial write\000 */
{ 4532469 }, /* unc_m2m_tag_miss\000uncore_m2m\000uncore interconnect\000Tag Miss. Unit: uncore_m2m \000event=0x61\000\00001\000\000 */
{ 4532786 }, /* unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x41\000\00001\000\000 */
{ 4533016 }, /* unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x42\000\00001\000\000 */
{ 4533974 }, /* unc_m2m_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4534107 }, /* unc_m2m_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4534240 }, /* unc_m2m_tracker_full.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4534507 }, /* unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4534904 }, /* unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4535167 }, /* unc_m2m_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 2. Unit: uncore_m2m \000event=0x49,umask=0x4\000\00001\000\000 */
{ 4535430 }, /* unc_m2m_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4535566 }, /* unc_m2m_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4535702 }, /* unc_m2m_tracker_ne.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4535974 }, /* unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4536381 }, /* unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4536652 }, /* unc_m2m_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 2. Unit: uncore_m2m \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4537046 }, /* unc_m2m_txc_ad_credit_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credits Occupancy. Unit: uncore_m2m \000event=0xe\000\00001\000\000 */
{ 4537180 }, /* unc_m2m_txc_ad_credits_acquired\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credit Acquired. Unit: uncore_m2m \000event=0xd\000\00001\000\000 */
{ 4537312 }, /* unc_m2m_txc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Full. Unit: uncore_m2m \000event=0xc\000\00001\000\000 */
{ 4537428 }, /* unc_m2m_txc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0xb\000\00001\000\000 */
{ 4537547 }, /* unc_m2m_txc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x9\000\00001\000\000 */
{ 4537666 }, /* unc_m2m_txc_ad_no_credit_cycles\000uncore_m2m\000uncore interconnect\000Cycles with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0xf\000\00001\000\000 */
{ 4537805 }, /* unc_m2m_txc_ad_no_credit_stalled\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0x10\000\00001\000\000 */
{ 4537954 }, /* unc_m2m_txc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0xa\000\00001\000\000 */
{ 4538073 }, /* unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000 */
{ 4538388 }, /* unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000 */
{ 4539040 }, /* unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4539397 }, /* unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4539752 }, /* unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000 */
{ 4540025 }, /* unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4540350 }, /* unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4540673 }, /* unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4540962 }, /* unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000 */
{ 4541253 }, /* unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000 */
{ 4541546 }, /* unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000 */
{ 4541839 }, /* unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4542131 }, /* unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000 */
{ 4542423 }, /* unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000 */
{ 4542702 }, /* unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000 */
{ 4543033 }, /* unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000 */
{ 4543362 }, /* unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000 */
{ 4543655 }, /* unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000 */
{ 4543952 }, /* unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000 */
{ 4544248 }, /* unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000 */
{ 4544527 }, /* unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000 */
{ 4544858 }, /* unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000 */
{ 4545187 }, /* unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000 */
{ 4545504 }, /* unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000 */
{ 4545797 }, /* unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000 */
{ 4546094 }, /* unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000 */
{ 4546390 }, /* unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 4546761 }, /* unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 4547130 }, /* unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000 */
{ 4547519 }, /* unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000 */
{ 4547906 }, /* unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000 */
{ 4548185 }, /* unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000 */
{ 4548516 }, /* unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000 */
{ 4548845 }, /* unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000 */
{ 4549138 }, /* unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000 */
{ 4549435 }, /* unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000 */
{ 4549993 }, /* unc_m2m_txc_akc_credits\000uncore_m2m\000uncore interconnect\000AKC Credits. Unit: uncore_m2m \000event=0x5f\000\00001\000\000 */
{ 4550095 }, /* unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4550408 }, /* unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4550717 }, /* unc_m2m_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to QPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4551381 }, /* unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4551738 }, /* unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4552093 }, /* unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4552366 }, /* unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4552691 }, /* unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4553014 }, /* unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000 */
{ 4553293 }, /* unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4553624 }, /* unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4553953 }, /* unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000 */
{ 4554232 }, /* unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4554563 }, /* unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4554892 }, /* unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4555263 }, /* unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4555632 }, /* unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 4556021 }, /* unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4556876 }, /* unc_m2m_txr_horz_ads_used.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2m \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4557430 }, /* unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4557963 }, /* unc_m2m_txr_horz_ads_used.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558500 }, /* unc_m2m_txr_horz_ads_used.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2m \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4559054 }, /* unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559587 }, /* unc_m2m_txr_horz_ads_used.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559881 }, /* unc_m2m_txr_horz_bypass.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2m \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4560424 }, /* unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4560946 }, /* unc_m2m_txr_horz_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561236 }, /* unc_m2m_txr_horz_bypass.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561730 }, /* unc_m2m_txr_horz_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562024 }, /* unc_m2m_txr_horz_bypass.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2m \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4562567 }, /* unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563089 }, /* unc_m2m_txr_horz_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563379 }, /* unc_m2m_txr_horz_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563873 }, /* unc_m2m_txr_horz_cycles_full.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2m \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4564594 }, /* unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4565294 }, /* unc_m2m_txr_horz_cycles_full.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4565681 }, /* unc_m2m_txr_horz_cycles_full.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566353 }, /* unc_m2m_txr_horz_cycles_full.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566744 }, /* unc_m2m_txr_horz_cycles_full.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2m \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4567465 }, /* unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568165 }, /* unc_m2m_txr_horz_cycles_full.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568552 }, /* unc_m2m_txr_horz_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4569224 }, /* unc_m2m_txr_horz_cycles_ne.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2m \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4569966 }, /* unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4570687 }, /* unc_m2m_txr_horz_cycles_ne.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571087 }, /* unc_m2m_txr_horz_cycles_ne.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571780 }, /* unc_m2m_txr_horz_cycles_ne.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4572184 }, /* unc_m2m_txr_horz_cycles_ne.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2m \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4572926 }, /* unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4573647 }, /* unc_m2m_txr_horz_cycles_ne.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574047 }, /* unc_m2m_txr_horz_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574740 }, /* unc_m2m_txr_horz_inserts.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2m \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4575434 }, /* unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576107 }, /* unc_m2m_txr_horz_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576474 }, /* unc_m2m_txr_horz_inserts.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577119 }, /* unc_m2m_txr_horz_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577490 }, /* unc_m2m_txr_horz_inserts.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2m \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4578184 }, /* unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4578857 }, /* unc_m2m_txr_horz_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579224 }, /* unc_m2m_txr_horz_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579869 }, /* unc_m2m_txr_horz_nack.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2m \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4580362 }, /* unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4580835 }, /* unc_m2m_txr_horz_nack.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581101 }, /* unc_m2m_txr_horz_nack.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2m \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581546 }, /* unc_m2m_txr_horz_nack.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581816 }, /* unc_m2m_txr_horz_nack.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2m \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4582309 }, /* unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582782 }, /* unc_m2m_txr_horz_nack.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583048 }, /* unc_m2m_txr_horz_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2m \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583493 }, /* unc_m2m_txr_horz_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2m \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4584183 }, /* unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4584852 }, /* unc_m2m_txr_horz_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585218 }, /* unc_m2m_txr_horz_occupancy.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585859 }, /* unc_m2m_txr_horz_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4586229 }, /* unc_m2m_txr_horz_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2m \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4586919 }, /* unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587588 }, /* unc_m2m_txr_horz_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587954 }, /* unc_m2m_txr_horz_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4588595 }, /* unc_m2m_txr_horz_starved.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4589341 }, /* unc_m2m_txr_horz_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4589741 }, /* unc_m2m_txr_horz_starved.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590439 }, /* unc_m2m_txr_horz_starved.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590843 }, /* unc_m2m_txr_horz_starved.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4591589 }, /* unc_m2m_txr_horz_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4591989 }, /* unc_m2m_txr_horz_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592687 }, /* unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593207 }, /* unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594210 }, /* unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594730 }, /* unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595252 }, /* unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4595752 }, /* unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596254 }, /* unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596754 }, /* unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597256 }, /* unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597756 }, /* unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598474 }, /* unc_m2m_txr_vert_bypass.iv_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598744 }, /* unc_m2m_txr_vert_bypass_1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4599019 }, /* unc_m2m_txr_vert_bypass_1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4602229 }, /* unc_m2m_txr_vert_cycles_full0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4602735 }, /* unc_m2m_txr_vert_cycles_full0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4603210 }, /* unc_m2m_txr_vert_cycles_full0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4603698 }, /* unc_m2m_txr_vert_cycles_full0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4604127 }, /* unc_m2m_txr_vert_cycles_full0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4604631 }, /* unc_m2m_txr_vert_cycles_full0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4605129 }, /* unc_m2m_txr_vert_cycles_full0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4605605 }, /* unc_m2m_txr_vert_cycles_full1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4606114 }, /* unc_m2m_txr_vert_cycles_full1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4609568 }, /* unc_m2m_txr_vert_cycles_ne0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4610083 }, /* unc_m2m_txr_vert_cycles_ne0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4610567 }, /* unc_m2m_txr_vert_cycles_ne0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4611064 }, /* unc_m2m_txr_vert_cycles_ne0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4611502 }, /* unc_m2m_txr_vert_cycles_ne0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4612015 }, /* unc_m2m_txr_vert_cycles_ne0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4612522 }, /* unc_m2m_txr_vert_cycles_ne0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4613007 }, /* unc_m2m_txr_vert_cycles_ne1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4613525 }, /* unc_m2m_txr_vert_cycles_ne1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4616820 }, /* unc_m2m_txr_vert_inserts0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4617293 }, /* unc_m2m_txr_vert_inserts0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4617735 }, /* unc_m2m_txr_vert_inserts0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4618190 }, /* unc_m2m_txr_vert_inserts0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4618586 }, /* unc_m2m_txr_vert_inserts0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4619057 }, /* unc_m2m_txr_vert_inserts0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4619522 }, /* unc_m2m_txr_vert_inserts0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4619965 }, /* unc_m2m_txr_vert_inserts1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4620441 }, /* unc_m2m_txr_vert_inserts1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4622344 }, /* unc_m2m_txr_vert_nack0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622597 }, /* unc_m2m_txr_vert_nack0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622851 }, /* unc_m2m_txr_vert_nack0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623104 }, /* unc_m2m_txr_vert_nack0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623358 }, /* unc_m2m_txr_vert_nack0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623611 }, /* unc_m2m_txr_vert_nack0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623865 }, /* unc_m2m_txr_vert_nack0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624098 }, /* unc_m2m_txr_vert_nack1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624354 }, /* unc_m2m_txr_vert_nack1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4627454 }, /* unc_m2m_txr_vert_occupancy0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4627932 }, /* unc_m2m_txr_vert_occupancy0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4628379 }, /* unc_m2m_txr_vert_occupancy0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4628839 }, /* unc_m2m_txr_vert_occupancy0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4629240 }, /* unc_m2m_txr_vert_occupancy0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4629716 }, /* unc_m2m_txr_vert_occupancy0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4630186 }, /* unc_m2m_txr_vert_occupancy0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4630634 }, /* unc_m2m_txr_vert_occupancy1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4631115 }, /* unc_m2m_txr_vert_occupancy1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4633779 }, /* unc_m2m_txr_vert_starved0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634155 }, /* unc_m2m_txr_vert_starved0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634532 }, /* unc_m2m_txr_vert_starved0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634908 }, /* unc_m2m_txr_vert_starved0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4635285 }, /* unc_m2m_txr_vert_starved0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4635661 }, /* unc_m2m_txr_vert_starved0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636038 }, /* unc_m2m_txr_vert_starved0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636394 }, /* unc_m2m_txr_vert_starved1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636773 }, /* unc_m2m_txr_vert_starved1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4637152 }, /* unc_m2m_txr_vert_starved1.tgc\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4637527 }, /* unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4639324 }, /* unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4641116 }, /* unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4642907 }, /* unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4644693 }, /* unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4646490 }, /* unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4648282 }, /* unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4650073 }, /* unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4651859 }, /* unc_m2m_vert_ring_akc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4652787 }, /* unc_m2m_vert_ring_akc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4653712 }, /* unc_m2m_vert_ring_akc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4654636 }, /* unc_m2m_vert_ring_akc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4655557 }, /* unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4657350 }, /* unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4659138 }, /* unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4660925 }, /* unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4662707 }, /* unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Down. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4663857 }, /* unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Up. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4665001 }, /* unc_m2m_vert_ring_tgc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4665929 }, /* unc_m2m_vert_ring_tgc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4666854 }, /* unc_m2m_vert_ring_tgc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4667778 }, /* unc_m2m_vert_ring_tgc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4670388 }, /* unc_m2m_wpq_flush.ch0\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 0. Unit: uncore_m2m \000event=0x58,umask=0x1\000\00001\000\000 */
{ 4670628 }, /* unc_m2m_wpq_flush.ch1\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 1. Unit: uncore_m2m \000event=0x58,umask=0x2\000\00001\000\000 */
{ 4670748 }, /* unc_m2m_wpq_flush.ch2\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 2. Unit: uncore_m2m \000event=0x58,umask=0x4\000\00001\000\000 */
{ 4671024 }, /* unc_m2m_wpq_no_reg_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4671336 }, /* unc_m2m_wpq_no_reg_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4671492 }, /* unc_m2m_wpq_no_reg_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4671648 }, /* unc_m2m_wpq_no_reg_crd_pmm.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 0. Unit: uncore_m2m \000event=0x51,umask=0x1\000\00001\000\000 */
{ 4671804 }, /* unc_m2m_wpq_no_reg_crd_pmm.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 1. Unit: uncore_m2m \000event=0x51,umask=0x2\000\00001\000\000 */
{ 4671960 }, /* unc_m2m_wpq_no_reg_crd_pmm.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - PMM : Channel 2. Unit: uncore_m2m \000event=0x51,umask=0x4\000\00001\000\000 */
{ 4672273 }, /* unc_m2m_wpq_no_spec_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 4672587 }, /* unc_m2m_wpq_no_spec_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 4672744 }, /* unc_m2m_wpq_no_spec_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 4672901 }, /* unc_m2m_wr_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4673043 }, /* unc_m2m_wr_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4673185 }, /* unc_m2m_wr_tracker_full.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 2. Unit: uncore_m2m \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4673327 }, /* unc_m2m_wr_tracker_full.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Mirror. Unit: uncore_m2m \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 4673608 }, /* unc_m2m_wr_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x56,umask=0x1\000\00001\000\000 */
{ 4673890 }, /* unc_m2m_wr_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x56,umask=0x2\000\00001\000\000 */
{ 4674031 }, /* unc_m2m_wr_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 2. Unit: uncore_m2m \000event=0x56,umask=0x4\000\00001\000\000 */
{ 4674317 }, /* unc_m2m_wr_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4674607 }, /* unc_m2m_wr_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4674752 }, /* unc_m2m_wr_tracker_ne.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 2. Unit: uncore_m2m \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4675040 }, /* unc_m2m_wr_tracker_ne.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Mirror. Unit: uncore_m2m \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 4675324 }, /* unc_m2m_wr_tracker_ne.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x10\000\00001\000\000 */
{ 4675605 }, /* unc_m2m_wr_tracker_ne.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x20\000\00001\000\000 */
{ 4675906 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x63,umask=0x1\000\00001\000\000 */
{ 4676230 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x63,umask=0x2\000\00001\000\000 */
{ 4676392 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 2. Unit: uncore_m2m \000event=0x63,umask=0x4\000\00001\000\000 */
{ 4676720 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x62,umask=0x1\000\00001\000\000 */
{ 4677052 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x62,umask=0x2\000\00001\000\000 */
{ 4677218 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 2. Unit: uncore_m2m \000event=0x62,umask=0x4\000\00001\000\000 */
{ 4677384 }, /* unc_m2m_wr_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x55,umask=0x1\000\00001\000\000 */
{ 4677529 }, /* unc_m2m_wr_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x55,umask=0x2\000\00001\000\000 */
{ 4677674 }, /* unc_m2m_wr_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 2. Unit: uncore_m2m \000event=0x55,umask=0x4\000\00001\000\000 */
{ 4677819 }, /* unc_m2m_wr_tracker_occupancy.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Mirror. Unit: uncore_m2m \000event=0x55,umask=0x8\000\00001\000\000 */
{ 4677962 }, /* unc_m2m_wr_tracker_occupancy.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x10\000\00001\000\000 */
{ 4678104 }, /* unc_m2m_wr_tracker_occupancy.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x20\000\00001\000\000 */
{ 4678398 }, /* unc_m2m_wr_tracker_posted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x5e,umask=0x1\000\00001\000\000 */
{ 4678708 }, /* unc_m2m_wr_tracker_posted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x5e,umask=0x2\000\00001\000\000 */
{ 4678863 }, /* unc_m2m_wr_tracker_posted_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 2. Unit: uncore_m2m \000event=0x5e,umask=0x4\000\00001\000\000 */
{ 4679177 }, /* unc_m2m_wr_tracker_posted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x5d,umask=0x1\000\00001\000\000 */
{ 4679495 }, /* unc_m2m_wr_tracker_posted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x5d,umask=0x2\000\00001\000\000 */
{ 4679654 }, /* unc_m2m_wr_tracker_posted_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 2. Unit: uncore_m2m \000event=0x5d,umask=0x4\000\00001\000\000 */
{ 4882439 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4882731 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4883023 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4883315 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4883607 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4883900 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4884193 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4884486 }, /* unc_m3upi_ag0_ad_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4884779 }, /* unc_m3upi_ag0_ad_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4885074 }, /* unc_m3upi_ag0_ad_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4885366 }, /* unc_m3upi_ag0_ad_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4887088 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4887381 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4887674 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4887967 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4888260 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4888554 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4888848 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4889142 }, /* unc_m3upi_ag0_ad_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4889436 }, /* unc_m3upi_ag0_ad_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4889732 }, /* unc_m3upi_ag0_ad_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4890025 }, /* unc_m3upi_ag0_ad_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4891748 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4892040 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4892332 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4892624 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4892916 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4893209 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4893502 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4893795 }, /* unc_m3upi_ag0_bl_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4894088 }, /* unc_m3upi_ag0_bl_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4894383 }, /* unc_m3upi_ag0_bl_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4894675 }, /* unc_m3upi_ag0_bl_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4896397 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4896690 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4896983 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4897276 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4897569 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4897863 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4898157 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4898451 }, /* unc_m3upi_ag0_bl_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4898745 }, /* unc_m3upi_ag0_bl_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4899041 }, /* unc_m3upi_ag0_bl_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4899334 }, /* unc_m3upi_ag0_bl_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4901057 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4901349 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4901641 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4901933 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4902225 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4902518 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4902811 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m3upi \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4903104 }, /* unc_m3upi_ag1_ad_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m3upi \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4903397 }, /* unc_m3upi_ag1_ad_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4903692 }, /* unc_m3upi_ag1_ad_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4903984 }, /* unc_m3upi_ag1_ad_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4905706 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4905999 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4906292 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4906585 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4906878 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4907172 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4907466 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4907760 }, /* unc_m3upi_ag1_ad_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4908054 }, /* unc_m3upi_ag1_ad_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4908350 }, /* unc_m3upi_ag1_ad_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4908643 }, /* unc_m3upi_ag1_ad_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4908936 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m3upi \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4909228 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m3upi \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4909520 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m3upi \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4909812 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m3upi \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4910104 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4910397 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4910690 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4910983 }, /* unc_m3upi_ag1_bl_crd_acquired0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4911276 }, /* unc_m3upi_ag1_bl_crd_acquired1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m3upi \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4911571 }, /* unc_m3upi_ag1_bl_crd_acquired1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m3upi \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4911863 }, /* unc_m3upi_ag1_bl_crd_acquired1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m3upi \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4913585 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m3upi \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4913878 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m3upi \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4914171 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m3upi \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4914464 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m3upi \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4914757 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m3upi \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4915051 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m3upi \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4915345 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr6\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m3upi \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4915639 }, /* unc_m3upi_ag1_bl_crd_occupancy0.tgr7\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m3upi \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4915933 }, /* unc_m3upi_ag1_bl_crd_occupancy1.tgr10\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m3upi \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4916229 }, /* unc_m3upi_ag1_bl_crd_occupancy1.tgr8\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m3upi \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4916522 }, /* unc_m3upi_ag1_bl_crd_occupancy1.tgr9\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m3upi \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4918269 }, /* unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000CBox AD Credits Empty : Requests : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4918747 }, /* unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000CBox AD Credits Empty : Snoops : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919219 }, /* unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000CBox AD Credits Empty : VNA Messages : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919709 }, /* unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000CBox AD Credits Empty : Writebacks : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4920191 }, /* unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000Clockticks of the mesh to UPI (M3UPI). Unit: uncore_m3upi \000event=0x1\000\00001\000Clockticks of the mesh to UPI (M3UPI) : Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 4921151 }, /* unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000 */
{ 4921510 }, /* unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000D2C Sent : Count cases BL sends direct to core\000 */
{ 4921786 }, /* unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000D2U Sent : Cases where SMI3 sends D2U command\000 */
{ 4921929 }, /* unc_m3upi_distress_asserted.dpt_local\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Local. Unit: uncore_m3upi \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 4922261 }, /* unc_m3upi_distress_asserted.dpt_nonlocal\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Remote. Unit: uncore_m3upi \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 4922597 }, /* unc_m3upi_distress_asserted.dpt_stall_iv\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m3upi \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 4922970 }, /* unc_m3upi_distress_asserted.dpt_stall_nocrd\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m3upi \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 4923356 }, /* unc_m3upi_distress_asserted.horz\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : Horizontal. Unit: uncore_m3upi \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4923714 }, /* unc_m3upi_distress_asserted.pmm_local\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : PMM Local. Unit: uncore_m3upi \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4924094 }, /* unc_m3upi_distress_asserted.pmm_nonlocal\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : PMM Remote. Unit: uncore_m3upi \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4924483 }, /* unc_m3upi_distress_asserted.vert\000uncore_m3upi\000uncore interconnect\000Distress signal asserted : Vertical. Unit: uncore_m3upi \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4924837 }, /* unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m3upi \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925418 }, /* unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m3upi \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4926537 }, /* unc_m3upi_horz_ring_ad_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4928358 }, /* unc_m3upi_horz_ring_ad_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4930174 }, /* unc_m3upi_horz_ring_ad_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4932000 }, /* unc_m3upi_horz_ring_ad_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4933821 }, /* unc_m3upi_horz_ring_ak_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4935638 }, /* unc_m3upi_horz_ring_ak_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4937450 }, /* unc_m3upi_horz_ring_ak_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4939272 }, /* unc_m3upi_horz_ring_ak_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4941089 }, /* unc_m3upi_horz_ring_akc_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m3upi \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4942029 }, /* unc_m3upi_horz_ring_akc_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m3upi \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4942966 }, /* unc_m3upi_horz_ring_akc_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m3upi \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4943909 }, /* unc_m3upi_horz_ring_akc_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m3upi \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4944849 }, /* unc_m3upi_horz_ring_bl_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m3upi \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4946668 }, /* unc_m3upi_horz_ring_bl_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m3upi \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4948482 }, /* unc_m3upi_horz_ring_bl_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m3upi \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4950306 }, /* unc_m3upi_horz_ring_bl_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m3upi \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4952125 }, /* unc_m3upi_horz_ring_iv_in_use.left\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use : Left. Unit: uncore_m3upi \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4953301 }, /* unc_m3upi_horz_ring_iv_in_use.right\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use : Right. Unit: uncore_m3upi \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4954740 }, /* unc_m3upi_m2_bl_credits_empty.iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only) : No vn0 and vna credits available to send to M2\000 */
{ 4955085 }, /* unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000M2 BL Credits Empty : IIO2 : No vn0 and vna credits available to send to M2\000 */
{ 4955497 }, /* unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000M2 BL Credits Empty : IIO3 : No vn0 and vna credits available to send to M2\000 */
{ 4955909 }, /* unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000M2 BL Credits Empty : IIO4 : No vn0 and vna credits available to send to M2\000 */
{ 4956321 }, /* unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000 */
{ 4956735 }, /* unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together : No vn0 and vna credits available to send to M2\000 */
{ 4957310 }, /* unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x80\000\00001\000M2 BL Credits Empty : Selected M2p BL NCS credits : No vn0 and vna credits available to send to M2\000 */
{ 4957791 }, /* unc_m3upi_m2_bl_credits_empty.ubox_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000 */
{ 4958013 }, /* unc_m3upi_misc_external.mbe_inst0\000uncore_m3upi\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m3upi \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 4958212 }, /* unc_m3upi_misc_external.mbe_inst1\000uncore_m3upi\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m3upi \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 4958411 }, /* unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi Slot Flit Received : AD - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4958953 }, /* unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi Slot Flit Received : AD - Slot 1 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959495 }, /* unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi Slot Flit Received : AD - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960037 }, /* unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi Slot Flit Received : AK - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960581 }, /* unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi Slot Flit Received : AK - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961125 }, /* unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi Slot Flit Received : BL - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961667 }, /* unc_m3upi_ring_bounces_horz.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m3upi \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4962225 }, /* unc_m3upi_ring_bounces_horz.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m3upi \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4962783 }, /* unc_m3upi_ring_bounces_horz.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m3upi \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963341 }, /* unc_m3upi_ring_bounces_horz.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m3upi \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963899 }, /* unc_m3upi_ring_bounces_vert.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m3upi \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4964447 }, /* unc_m3upi_ring_bounces_vert.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m3upi \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4965061 }, /* unc_m3upi_ring_bounces_vert.akc\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. Unit: uncore_m3upi \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4965352 }, /* unc_m3upi_ring_bounces_vert.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m3upi \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4965960 }, /* unc_m3upi_ring_bounces_vert.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m3upi \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4966584 }, /* unc_m3upi_ring_sink_starved_horz.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m3upi \000event=0xad,umask=0x1\000\00001\000\000 */
{ 4966895 }, /* unc_m3upi_ring_sink_starved_horz.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m3upi \000event=0xad,umask=0x2\000\00001\000\000 */
{ 4967206 }, /* unc_m3upi_ring_sink_starved_horz.ak_ag1\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m3upi \000event=0xad,umask=0x20\000\00001\000\000 */
{ 4967577 }, /* unc_m3upi_ring_sink_starved_horz.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m3upi \000event=0xad,umask=0x4\000\00001\000\000 */
{ 4967888 }, /* unc_m3upi_ring_sink_starved_horz.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m3upi \000event=0xad,umask=0x8\000\00001\000\000 */
{ 4968199 }, /* unc_m3upi_ring_sink_starved_vert.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m3upi \000event=0xab,umask=0x1\000\00001\000\000 */
{ 4968506 }, /* unc_m3upi_ring_sink_starved_vert.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m3upi \000event=0xab,umask=0x2\000\00001\000\000 */
{ 4968857 }, /* unc_m3upi_ring_sink_starved_vert.akc\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring. Unit: uncore_m3upi \000event=0xab,umask=0x10\000\00001\000\000 */
{ 4969008 }, /* unc_m3upi_ring_sink_starved_vert.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m3upi \000event=0xab,umask=0x4\000\00001\000\000 */
{ 4969355 }, /* unc_m3upi_ring_sink_starved_vert.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m3upi \000event=0xab,umask=0x8\000\00001\000\000 */
{ 4969823 }, /* unc_m3upi_ring_src_thrtl\000uncore_m3upi\000uncore interconnect\000Source Throttle. Unit: uncore_m3upi \000event=0xae\000\00001\000\000 */
{ 4969934 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000Lost Arb for VN0 : REQ on AD : VN0 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4970551 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000Lost Arb for VN0 : RSP on AD : VN0 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4971218 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000Lost Arb for VN0 : SNP on AD : VN0 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4971745 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000Lost Arb for VN0 : NCB on BL : VN0 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4972448 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000Lost Arb for VN0 : NCS on BL : VN0 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4972939 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000Lost Arb for VN0 : RSP on BL : VN0 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4973604 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000Lost Arb for VN0 : WB on BL : VN0 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4974386 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000Lost Arb for VN1 : REQ on AD : VN1 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4975003 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000Lost Arb for VN1 : RSP on AD : VN1 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4975670 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000Lost Arb for VN1 : SNP on AD : VN1 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4976197 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000Lost Arb for VN1 : NCB on BL : VN1 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4976900 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000Lost Arb for VN1 : NCS on BL : VN1 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4977391 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000Lost Arb for VN1 : RSP on BL : VN1 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4978056 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000Lost Arb for VN1 : WB on BL : VN1 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4979060 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN0 : AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4979337 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN1 : AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4979614 }, /* unc_m3upi_rxc_arb_misc.all_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : Max Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x80\000\00001\000Arb Miscellaneous : Max Parallel Win : VN0 and VN1 arbitration sub-pipelines both produced AD and BL winners (maximum possible parallel winners)\000 */
{ 4979916 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN0 : Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000 */
{ 4980523 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN1 : Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000 */
{ 4981130 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN0 : Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000 */
{ 4981738 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN1 : Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000 */
{ 4982868 }, /* unc_m3upi_rxc_arb_misc.vn01_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : VN0, VN1 Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000Arb Miscellaneous : VN0, VN1 Parallel Win : VN0 and VN1 arbitration sub-pipelines had parallel winners (at least one AD or BL on each side)\000 */
{ 4988107 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000No Credits to Arb for VN0 : REQ on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4988493 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000No Credits to Arb for VN0 : RSP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4988904 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000No Credits to Arb for VN0 : SNP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4989245 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000No Credits to Arb for VN0 : NCB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4989674 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000No Credits to Arb for VN0 : NCS on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4989997 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000No Credits to Arb for VN0 : RSP on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4990407 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000No Credits to Arb for VN0 : WB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4990875 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000No Credits to Arb for VN1 : REQ on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4991261 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000No Credits to Arb for VN1 : RSP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4991672 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000No Credits to Arb for VN1 : SNP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4992013 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000No Credits to Arb for VN1 : NCB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4992442 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000No Credits to Arb for VN1 : NCS on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4992765 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000No Credits to Arb for VN1 : RSP on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4993175 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000No Credits to Arb for VN1 : WB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4998607 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000Can't Arb for VN0 : REQ on AD : VN0 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4998981 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000Can't Arb for VN0 : RSP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4999380 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000Can't Arb for VN0 : SNP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4999709 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000Can't Arb for VN0 : NCB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5000126 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000Can't Arb for VN0 : NCS on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5000437 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000Can't Arb for VN0 : RSP on BL : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5000835 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000Can't Arb for VN0 : WB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5001291 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000Can't Arb for VN1 : REQ on AD : VN1 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5001665 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000Can't Arb for VN1 : RSP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5002064 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000Can't Arb for VN1 : SNP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5002393 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000Can't Arb for VN1 : NCB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5002810 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000Can't Arb for VN1 : NCS on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5003121 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000Can't Arb for VN1 : RSP on BL : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5003519 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000Can't Arb for VN1 : WB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5003975 }, /* unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000 */
{ 5004645 }, /* unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on Idle : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while pipeline is idle\000 */
{ 5005281 }, /* unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 1 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 1 while merging with bl message in same flit\000 */
{ 5005924 }, /* unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 2 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 2 while merging with bl message in same flit\000 */
{ 5011447 }, /* unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any In BGF FIFO. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Miscellaneous Credit Events : Any In BGF FIFO : Indication that at least one packet (flit) is in the bgf (fifo only)\000 */
{ 5011954 }, /* unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any in BGF Path. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Miscellaneous Credit Events : Any in BGF Path : Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000 */
{ 5012487 }, /* unc_m3upi_rxc_crd_misc.lt1_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 1\000 */
{ 5012692 }, /* unc_m3upi_rxc_crd_misc.lt2_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 2\000 */
{ 5013152 }, /* unc_m3upi_rxc_crd_misc.vn0_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : No D2K For Arb. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Miscellaneous Credit Events : No D2K For Arb : VN0 BL RSP message was blocked from arbitration request due to lack of D2K CMP credit\000 */
{ 5013451 }, /* unc_m3upi_rxc_crd_misc.vn1_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Miscellaneous Credit Events : VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000 */
{ 5013717 }, /* unc_m3upi_rxc_crd_occ.consumed\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Credits Consumed. Unit: uncore_m3upi \000event=0x60,umask=0x80\000\00001\000Credit Occupancy : Credits Consumed : number of remote vna credits consumed per cycle\000 */
{ 5013950 }, /* unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : D2K Credits. Unit: uncore_m3upi \000event=0x60,umask=0x10\000\00001\000Credit Occupancy : D2K Credits : D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5014434 }, /* unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Credit Occupancy : Packets in BGF FIFO : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000 */
{ 5014930 }, /* unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000Credit Occupancy : Packets in BGF Path : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000 */
{ 5015482 }, /* unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x40\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in completion fifo only\000 */
{ 5015897 }, /* unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x20\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in marker table and in fifo\000 */
{ 5016322 }, /* unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Transmit Credits. Unit: uncore_m3upi \000event=0x60,umask=0x8\000\00001\000Credit Occupancy : Transmit Credits : Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5016831 }, /* unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : VNA In Use. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Credit Occupancy : VNA In Use : Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000 */
{ 5017326 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5018636 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5019996 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5021216 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5022612 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5023796 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5025154 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5026629 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD. Unit: uncore_m3upi \000event=0x44,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5027939 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5029299 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5030519 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5031915 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL. Unit: uncore_m3upi \000event=0x44,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5033099 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL. Unit: uncore_m3upi \000event=0x44,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5034457 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5035932 }, /* unc_m3upi_rxc_data_flits_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000Data Flit Not Sent : All : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but could not be sent for any reason, e.g. low credits, low tsv, stall injection\000 */
{ 5036278 }, /* unc_m3upi_rxc_data_flits_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000Data Flit Not Sent : No BGF Credits : Data flit is ready for transmission but could not be sent\000 */
{ 5036530 }, /* unc_m3upi_rxc_data_flits_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000Data Flit Not Sent : No TxQ Credits : Data flit is ready for transmission but could not be sent\000 */
{ 5036783 }, /* unc_m3upi_rxc_data_flits_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : TSV High. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000Data Flit Not Sent : TSV High : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while tsv high\000 */
{ 5037093 }, /* unc_m3upi_rxc_data_flits_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000Data Flit Not Sent : Cycle valid for Flit : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while cycle is valid for flit transmission\000 */
{ 5037463 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Flit Gen - Header 1 : Accumulate : Events related to Header Flit Generation - Set 1 : Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000 */
{ 5038146 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Ready. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Flit Gen - Header 1 : Accumulate Ready : Events related to Header Flit Generation - Set 1 : header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000 */
{ 5038917 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Wasted. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Flit Gen - Header 1 : Accumulate Wasted : Events related to Header Flit Generation - Set 1 : Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000 */
{ 5039667 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Flit Gen - Header 1 : Run-Ahead - Blocked : Events related to Header Flit Generation - Set 1 : Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000 */
{ 5040405 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x80\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: message was slotted only after run-ahead was over; run-ahead mode definitely wasted\000 */
{ 5040723 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_during\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Message. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Flit Gen - Header 1 : Run-Ahead - Message : Events related to Header Flit Generation - Set 1 : run-ahead mode: one message slotted during run-ahead\000 */
{ 5041039 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: second message slotted immediately after run-ahead; potential run-ahead success\000 */
{ 5041353 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_sent\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: two (or three) message flit sent immediately after run-ahead; complete run-ahead success\000 */
{ 5042811 }, /* unc_m3upi_rxc_flit_gen_hdr2.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Ok. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000Flit Gen - Header 2 : Parallel Ok : Events related to Header Flit Generation - Set 2 : new header flit construction may proceed in parallel with data flit sequence\000 */
{ 5043120 }, /* unc_m3upi_rxc_flit_gen_hdr2.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Flit Finished. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000Flit Gen - Header 2 : Parallel Flit Finished : Events related to Header Flit Generation - Set 2 : header flit finished assembly in parallel with data flit sequence\000 */
{ 5043446 }, /* unc_m3upi_rxc_flit_gen_hdr2.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Message. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000Flit Gen - Header 2 : Parallel Message : Events related to Header Flit Generation - Set 2 : message is slotted into header flit in parallel with data flit sequence\000 */
{ 5043764 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000Flit Gen - Header 2 : Rate-matching Stall : Events related to Header Flit Generation - Set 2 : Rate-matching stall injected\000 */
{ 5044280 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000Flit Gen - Header 2 : Rate-matching Stall - No Message : Events related to Header Flit Generation - Set 2 : Rate matching stall injected, but no additional message slotted during stall cycle\000 */
{ 5047703 }, /* unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 0. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 0 : generating bl data flit sequence; waiting for data pump 0\000 */
{ 5048198 }, /* unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 1. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 1 : generating bl data flit sequence; waiting for data pump 1\000 */
{ 5048693 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x10\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000 */
{ 5049198 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x8\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is tracking at least one message\000 */
{ 5049637 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x40\000\00001\000Generating BL Data Flit Sequence : pump-1-pending completion fifo is full\000 */
{ 5050058 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x20\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000 */
{ 5050631 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Generating BL Data Flit Sequence : a bl message finished but is in limbo and moved to pump-1-pending logic\000 */
{ 5051114 }, /* unc_m3upi_rxc_flits_misc.s2req_in_holdoff\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_HOLDOFF. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000: slot 2 request naturally serviced during hold-off period\000 */
{ 5051336 }, /* unc_m3upi_rxc_flits_misc.s2req_in_service\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_SERVICE. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000: slot 2 request forcibly serviced during service window\000 */
{ 5051556 }, /* unc_m3upi_rxc_flits_misc.s2req_received\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_RECEIVED. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000: slot 2 request received from link layer while idle (with no slot 2 request active immediately prior)\000 */
{ 5051818 }, /* unc_m3upi_rxc_flits_misc.s2req_withdrawn\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_WITHDRAWN. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000: slot 2 request withdrawn during hold-off period or service window\000 */
{ 5053280 }, /* unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : All. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000\000 */
{ 5053589 }, /* unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Needs Data Flit. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Slotting BL Message Into Header Flit : Needs Data Flit : BL message requires data flit sequence\000 */
{ 5054067 }, /* unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 0. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 0 : Waiting for header pump 0\000 */
{ 5054512 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 : Header pump 1 is not required for flit\000 */
{ 5055000 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble : Header pump 1 is not required for flit but flit transmission delayed\000 */
{ 5055597 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail : Header pump 1 is not required for flit and not available\000 */
{ 5056177 }, /* unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 1 : Waiting for header pump 1\000 */
{ 5056622 }, /* unc_m3upi_rxc_hdr_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent : All. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Header Not Sent : All : header flit is ready for transmission but could not be sent : header flit is ready for transmission but could not be sent for any reason, e.g. no credits, low tsv, stall injection\000 */
{ 5056963 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Header Not Sent : No BGF Credits : header flit is ready for transmission but could not be sent : No BGF credits available\000 */
{ 5057240 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Header Not Sent : No BGF Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No BGF credits available; no additional message slotted into flit\000 */
{ 5057616 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Header Not Sent : No TxQ Credits : header flit is ready for transmission but could not be sent : No TxQ credits available\000 */
{ 5057894 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Header Not Sent : No TxQ Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No TxQ credits available; no additional message slotted into flit\000 */
{ 5058270 }, /* unc_m3upi_rxc_hdr_flit_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Header Not Sent : TSV High. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Header Not Sent : TSV High : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while tsv high\000 */
{ 5058576 }, /* unc_m3upi_rxc_hdr_flit_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Header Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Header Not Sent : Cycle valid for Flit : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while cycle is valid for flit transmission\000 */
{ 5058942 }, /* unc_m3upi_rxc_hdr_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Sent Header Flit : One Message : One message in flit; VNA or non-VNA flit\000 */
{ 5059161 }, /* unc_m3upi_rxc_hdr_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message in non-VNA. Unit: uncore_m3upi \000event=0x54,umask=0x8\000\00001\000Sent Header Flit : One Message in non-VNA : One message in flit; non-VNA flit\000 */
{ 5059399 }, /* unc_m3upi_rxc_hdr_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Messages. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Sent Header Flit : Two Messages : Two messages in flit; VNA flit\000 */
{ 5059611 }, /* unc_m3upi_rxc_hdr_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Three Messages. Unit: uncore_m3upi \000event=0x54,umask=0x4\000\00001\000Sent Header Flit : Three Messages : Three messages in flit; VNA flit\000 */
{ 5059829 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Slot Taken. Unit: uncore_m3upi \000event=0x54,umask=0x10\000\00001\000\000 */
{ 5059981 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x20\000\00001\000\000 */
{ 5060134 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : All Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x40\000\00001\000\000 */
{ 5060287 }, /* unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot AD. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Message Held : Can't Slot AD : some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5060797 }, /* unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Message Held : Can't Slot BL : some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061556 }, /* unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Attempt. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Message Held : Parallel Attempt : ad and bl messages attempted to slot into the same flit in parallel\000 */
{ 5062268 }, /* unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Success. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Message Held : Parallel Success : ad and bl messages were actually slotted into the same flit in parallel\000 */
{ 5062739 }, /* unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held : VN0. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Message Held : VN0 : vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000 */
{ 5063225 }, /* unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held : VN1. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Message Held : VN1 : vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000 */
{ 5063711 }, /* unc_m3upi_rxc_inserts_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : REQ on AD. Unit: uncore_m3upi \000event=0x41,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : REQ on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5064970 }, /* unc_m3upi_rxc_inserts_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : RSP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : RSP on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5066279 }, /* unc_m3upi_rxc_inserts_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : SNP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : SNP on AD : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5067448 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : NCB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : NCB on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5068793 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : NCS on BL. Unit: uncore_m3upi \000event=0x41,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : NCS on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5069926 }, /* unc_m3upi_rxc_inserts_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : RSP on BL. Unit: uncore_m3upi \000event=0x41,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : RSP on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5071233 }, /* unc_m3upi_rxc_inserts_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts : WB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Inserts : WB on BL : Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5072657 }, /* unc_m3upi_rxc_inserts_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : REQ on AD. Unit: uncore_m3upi \000event=0x42,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : REQ on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5073936 }, /* unc_m3upi_rxc_inserts_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : RSP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : RSP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5075265 }, /* unc_m3upi_rxc_inserts_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : SNP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : SNP on AD : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5076454 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : NCB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : NCB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5077819 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : NCS on BL. Unit: uncore_m3upi \000event=0x42,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : NCS on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5078972 }, /* unc_m3upi_rxc_inserts_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : RSP on BL. Unit: uncore_m3upi \000event=0x42,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : RSP on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5080299 }, /* unc_m3upi_rxc_inserts_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts : WB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Inserts : WB on BL : Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5081743 }, /* unc_m3upi_rxc_occupancy_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : REQ on AD. Unit: uncore_m3upi \000event=0x45,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : REQ on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5082962 }, /* unc_m3upi_rxc_occupancy_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5084231 }, /* unc_m3upi_rxc_occupancy_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : SNP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : SNP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5085360 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : NCB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : NCB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5086665 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : NCS on BL. Unit: uncore_m3upi \000event=0x45,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : NCS on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5087758 }, /* unc_m3upi_rxc_occupancy_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on BL. Unit: uncore_m3upi \000event=0x45,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : RSP on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5089025 }, /* unc_m3upi_rxc_occupancy_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy : WB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Occupancy : WB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5090409 }, /* unc_m3upi_rxc_occupancy_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : REQ on AD. Unit: uncore_m3upi \000event=0x46,umask=0x1\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : REQ on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5091628 }, /* unc_m3upi_rxc_occupancy_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x4\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5092897 }, /* unc_m3upi_rxc_occupancy_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : SNP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x2\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : SNP on AD : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5094026 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : NCB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x20\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : NCB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5095331 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : NCS on BL. Unit: uncore_m3upi \000event=0x46,umask=0x40\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : NCS on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5096424 }, /* unc_m3upi_rxc_occupancy_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on BL. Unit: uncore_m3upi \000event=0x46,umask=0x8\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : RSP on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5097691 }, /* unc_m3upi_rxc_occupancy_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy : WB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x10\000\00001\000VN1 Ingress (from CMS) Queue - Occupancy : WB on BL : Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5099075 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000VN0 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5099982 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000VN0 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5100939 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000VN0 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5101756 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000VN0 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5102749 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000VN0 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5103530 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000VN0 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5104485 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000VN0 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5105557 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000VN1 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5106464 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000VN1 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5107421 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000VN1 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5108238 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000VN1 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5109231 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000VN1 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5110012 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000VN1 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5110967 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000VN1 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5112870 }, /* unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Any In Use. Unit: uncore_m3upi \000event=0x5a,umask=0x20\000\00001\000Remote VNA Credits : Any In Use : At least one remote vna credit is in use\000 */
{ 5113275 }, /* unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Corrected. Unit: uncore_m3upi \000event=0x5a,umask=0x1\000\00001\000Remote VNA Credits : Corrected : Number of remote vna credits corrected (local return) per cycle\000 */
{ 5113967 }, /* unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 1. Unit: uncore_m3upi \000event=0x5a,umask=0x2\000\00001\000Remote VNA Credits : Level < 1 : Remote vna credit level is less than 1 (i.e. no vna credits available)\000 */
{ 5113719 }, /* unc_m3upi_rxc_vna_crd.lt10\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 10. Unit: uncore_m3upi \000event=0x5a,umask=0x10\000\00001\000Remote VNA Credits : Level < 10 : remote vna credit level is less than 10; parallel vn0/vn1 arb not possible\000 */
{ 5114413 }, /* unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 4. Unit: uncore_m3upi \000event=0x5a,umask=0x4\000\00001\000Remote VNA Credits : Level < 4 : Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000 */
{ 5114887 }, /* unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 5. Unit: uncore_m3upi \000event=0x5a,umask=0x8\000\00001\000Remote VNA Credits : Level < 5 : Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000 */
{ 5115529 }, /* unc_m3upi_rxc_vna_crd_misc.req_adbl_alloc_l5\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_ADBL_ALLOC_L5. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000: remote vna credit count was less than 5 and allocation to ad or bl messages was required\000 */
{ 5115789 }, /* unc_m3upi_rxc_vna_crd_misc.req_vn01_alloc_lt10\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_VN01_ALLOC_LT10. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000: remote vna credit count was less than 10 and allocation to vn0 or vn1 was required\000 */
{ 5116047 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000: on vn0, remote vna credits were allocated only to ad messages, not to bl\000 */
{ 5116280 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000: on vn0, remote vna credits were allocated only to bl messages, not to ad\000 */
{ 5116513 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000: remote vna credits were allocated only to vn0, not to vn1\000 */
{ 5116724 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000: on vn1, remote vna credits were allocated only to ad messages, not to bl\000 */
{ 5116957 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x80\000\00001\000: on vn1, remote vna credits were allocated only to bl messages, not to ad\000 */
{ 5117190 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000: remote vna credits were allocated only to vn1, not to vn0\000 */
{ 5117401 }, /* unc_m3upi_rxr_busy_starved.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 5118270 }, /* unc_m3upi_rxr_busy_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m3upi \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5119119 }, /* unc_m3upi_rxr_busy_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5119575 }, /* unc_m3upi_rxr_busy_starved.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 5120444 }, /* unc_m3upi_rxr_busy_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m3upi \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5121293 }, /* unc_m3upi_rxr_busy_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5121749 }, /* unc_m3upi_rxr_bypass.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - All. Unit: uncore_m3upi \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 5122198 }, /* unc_m3upi_rxr_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m3upi \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 5122627 }, /* unc_m3upi_rxr_bypass.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 5122870 }, /* unc_m3upi_rxr_bypass.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AK. Unit: uncore_m3upi \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 5123271 }, /* unc_m3upi_rxr_bypass.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 5123518 }, /* unc_m3upi_rxr_bypass.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - All. Unit: uncore_m3upi \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 5123967 }, /* unc_m3upi_rxr_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m3upi \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 5124396 }, /* unc_m3upi_rxr_bypass.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m3upi \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 5124639 }, /* unc_m3upi_rxr_bypass.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass : IV. Unit: uncore_m3upi \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 5125040 }, /* unc_m3upi_rxr_crd_starved.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 5125932 }, /* unc_m3upi_rxr_crd_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5126803 }, /* unc_m3upi_rxr_crd_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5127270 }, /* unc_m3upi_rxr_crd_starved.ak\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : AK. Unit: uncore_m3upi \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5128113 }, /* unc_m3upi_rxr_crd_starved.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 5129005 }, /* unc_m3upi_rxr_crd_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5129876 }, /* unc_m3upi_rxr_crd_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5130343 }, /* unc_m3upi_rxr_crd_starved.ifv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m3upi \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5131211 }, /* unc_m3upi_rxr_crd_starved.iv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation : IV. Unit: uncore_m3upi \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5132054 }, /* unc_m3upi_rxr_crd_starved_1\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation. Unit: uncore_m3upi \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5132468 }, /* unc_m3upi_rxr_inserts.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - All. Unit: uncore_m3upi \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 5133062 }, /* unc_m3upi_rxr_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m3upi \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5133636 }, /* unc_m3upi_rxr_inserts.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5133954 }, /* unc_m3upi_rxr_inserts.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AK. Unit: uncore_m3upi \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5134500 }, /* unc_m3upi_rxr_inserts.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5134822 }, /* unc_m3upi_rxr_inserts.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - All. Unit: uncore_m3upi \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 5135416 }, /* unc_m3upi_rxr_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m3upi \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5135990 }, /* unc_m3upi_rxr_inserts.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m3upi \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5136308 }, /* unc_m3upi_rxr_inserts.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations : IV. Unit: uncore_m3upi \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5136854 }, /* unc_m3upi_rxr_occupancy.ad_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m3upi \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 5137462 }, /* unc_m3upi_rxr_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m3upi \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5138050 }, /* unc_m3upi_rxr_occupancy.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5138374 }, /* unc_m3upi_rxr_occupancy.ak\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AK. Unit: uncore_m3upi \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5138934 }, /* unc_m3upi_rxr_occupancy.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5139262 }, /* unc_m3upi_rxr_occupancy.bl_all\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m3upi \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 5139870 }, /* unc_m3upi_rxr_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m3upi \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5140458 }, /* unc_m3upi_rxr_occupancy.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m3upi \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5140782 }, /* unc_m3upi_rxr_occupancy.iv\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy : IV. Unit: uncore_m3upi \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5141342 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5141706 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5142070 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5142434 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5142798 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5143163 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5143528 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5143893 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5144258 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5144622 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5144986 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5145350 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5145714 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5146079 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5146444 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5146809 }, /* unc_m3upi_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5147174 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5147538 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5147902 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5148266 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5148630 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5148995 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5149360 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5149725 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5150090 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m3upi \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5150454 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m3upi \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5150818 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m3upi \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5151182 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m3upi \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5151546 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m3upi \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5151911 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m3upi \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5152276 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m3upi \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5152641 }, /* unc_m3upi_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m3upi \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5153006 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5153373 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5153737 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5154101 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5154470 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5154836 }, /* unc_m3upi_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5155202 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5155571 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5155937 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5156303 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m3upi \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5156672 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m3upi \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5157038 }, /* unc_m3upi_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m3upi \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164612 }, /* unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000Failed ARB for AD : VN0 REQ Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165054 }, /* unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000Failed ARB for AD : VN0 RSP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165496 }, /* unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000Failed ARB for AD : VN0 SNP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165938 }, /* unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000Failed ARB for AD : VN0 WB Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5166375 }, /* unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000Failed ARB for AD : VN1 REQ Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5166819 }, /* unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000Failed ARB for AD : VN1 RSP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5167263 }, /* unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000Failed ARB for AD : VN1 SNP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5167707 }, /* unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000Failed ARB for AD : VN1 WB Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5168146 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5168718 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169290 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169862 }, /* unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170738 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000AD Flow Q Not Empty : VN0 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171192 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000AD Flow Q Not Empty : VN0 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171646 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000AD Flow Q Not Empty : VN0 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172100 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000AD Flow Q Not Empty : VN0 WB Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172549 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000AD Flow Q Not Empty : VN1 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173005 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000AD Flow Q Not Empty : VN1 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173461 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000AD Flow Q Not Empty : VN1 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173917 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000AD Flow Q Not Empty : VN1 WB Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174368 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000AD Flow Q Inserts : VN0 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5175310 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000AD Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5176252 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000AD Flow Q Inserts : VN0 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5177194 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000AD Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5178131 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000AD Flow Q Inserts : VN1 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5179075 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000AD Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180019 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000AD Flow Q Inserts : VN1 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180963 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 5181278 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 5181593 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 5181908 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 5182219 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 5182536 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 5182853 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 5192146 }, /* unc_m3upi_txc_ak_flq_inserts\000uncore_m3upi\000uncore interconnect\000AK Flow Q Inserts. Unit: uncore_m3upi \000event=0x2f\000\00001\000\000 */
{ 5192263 }, /* unc_m3upi_txc_ak_flq_occupancy\000uncore_m3upi\000uncore interconnect\000AK Flow Q Occupancy. Unit: uncore_m3upi \000event=0x1e\000\00001\000\000 */
{ 5192384 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000Failed ARB for BL : VN0 NCB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5192826 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000Failed ARB for BL : VN0 NCS Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5193268 }, /* unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000Failed ARB for BL : VN0 RSP Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5193710 }, /* unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000Failed ARB for BL : VN0 WB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5194147 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000Failed ARB for BL : VN1 NCS Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5194591 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000Failed ARB for BL : VN1 NCB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195035 }, /* unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000Failed ARB for BL : VN1 RSP Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195479 }, /* unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000Failed ARB for BL : VN1 WB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195918 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000BL Flow Q Not Empty : VN0 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196372 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000BL Flow Q Not Empty : VN0 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196826 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000BL Flow Q Not Empty : VN0 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197280 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000BL Flow Q Not Empty : VN0 WB Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197729 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000BL Flow Q Not Empty : VN1 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198185 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000BL Flow Q Not Empty : VN1 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198641 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000BL Flow Q Not Empty : VN1 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199097 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000BL Flow Q Not Empty : VN1 WB Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199548 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000BL Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5200490 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000BL Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5201429 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000BL Flow Q Inserts : VN0 NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5202371 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000BL Flow Q Inserts : VN0 NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5203311 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000BL Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5204255 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000BL Flow Q Inserts : VN1 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5205196 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000BL Flow Q Inserts : VN1_NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5206140 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000BL Flow Q Inserts : VN1_NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5207082 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 5207397 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 5207712 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 5208027 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 5208338 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 5208655 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 5208972 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 5209289 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 5213668 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 5213831 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 5213995 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x4\000\00001\000\000 */
{ 5214159 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x10\000\00001\000\000 */
{ 5214323 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x20\000\00001\000\000 */
{ 5214488 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x40\000\00001\000\000 */
{ 5214653 }, /* unc_m3upi_txr_horz_ads_used.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m3upi \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 5215219 }, /* unc_m3upi_txr_horz_ads_used.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m3upi \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5215764 }, /* unc_m3upi_txr_horz_ads_used.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m3upi \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5216313 }, /* unc_m3upi_txr_horz_ads_used.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m3upi \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 5216879 }, /* unc_m3upi_txr_horz_ads_used.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m3upi \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5217424 }, /* unc_m3upi_txr_horz_ads_used.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m3upi \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5217724 }, /* unc_m3upi_txr_horz_bypass.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m3upi \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 5218279 }, /* unc_m3upi_txr_horz_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m3upi \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5218813 }, /* unc_m3upi_txr_horz_bypass.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5219109 }, /* unc_m3upi_txr_horz_bypass.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AK. Unit: uncore_m3upi \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5219615 }, /* unc_m3upi_txr_horz_bypass.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5219915 }, /* unc_m3upi_txr_horz_bypass.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m3upi \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 5220470 }, /* unc_m3upi_txr_horz_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m3upi \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5221004 }, /* unc_m3upi_txr_horz_bypass.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m3upi \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5221300 }, /* unc_m3upi_txr_horz_bypass.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used : IV. Unit: uncore_m3upi \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5221806 }, /* unc_m3upi_txr_horz_cycles_full.ad_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m3upi \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5222539 }, /* unc_m3upi_txr_horz_cycles_full.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m3upi \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5223251 }, /* unc_m3upi_txr_horz_cycles_full.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5223644 }, /* unc_m3upi_txr_horz_cycles_full.ak\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m3upi \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5224328 }, /* unc_m3upi_txr_horz_cycles_full.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5224725 }, /* unc_m3upi_txr_horz_cycles_full.bl_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m3upi \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5225458 }, /* unc_m3upi_txr_horz_cycles_full.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m3upi \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5226170 }, /* unc_m3upi_txr_horz_cycles_full.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m3upi \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5226563 }, /* unc_m3upi_txr_horz_cycles_full.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m3upi \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5227247 }, /* unc_m3upi_txr_horz_cycles_ne.ad_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m3upi \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5228001 }, /* unc_m3upi_txr_horz_cycles_ne.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m3upi \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5228734 }, /* unc_m3upi_txr_horz_cycles_ne.ad_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5229140 }, /* unc_m3upi_txr_horz_cycles_ne.ak\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m3upi \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5229845 }, /* unc_m3upi_txr_horz_cycles_ne.akc_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5230255 }, /* unc_m3upi_txr_horz_cycles_ne.bl_all\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m3upi \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5231009 }, /* unc_m3upi_txr_horz_cycles_ne.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m3upi \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5231742 }, /* unc_m3upi_txr_horz_cycles_ne.bl_uncrd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m3upi \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5232148 }, /* unc_m3upi_txr_horz_cycles_ne.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m3upi \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5232853 }, /* unc_m3upi_txr_horz_inserts.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m3upi \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5233559 }, /* unc_m3upi_txr_horz_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m3upi \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5234244 }, /* unc_m3upi_txr_horz_inserts.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5234617 }, /* unc_m3upi_txr_horz_inserts.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m3upi \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5235274 }, /* unc_m3upi_txr_horz_inserts.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5235651 }, /* unc_m3upi_txr_horz_inserts.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m3upi \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5236357 }, /* unc_m3upi_txr_horz_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m3upi \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5237042 }, /* unc_m3upi_txr_horz_inserts.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m3upi \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5237415 }, /* unc_m3upi_txr_horz_inserts.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m3upi \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5238072 }, /* unc_m3upi_txr_horz_nack.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m3upi \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 5238577 }, /* unc_m3upi_txr_horz_nack.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m3upi \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5239062 }, /* unc_m3upi_txr_horz_nack.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5239334 }, /* unc_m3upi_txr_horz_nack.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m3upi \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5239791 }, /* unc_m3upi_txr_horz_nack.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5240067 }, /* unc_m3upi_txr_horz_nack.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m3upi \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 5240572 }, /* unc_m3upi_txr_horz_nack.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m3upi \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5241057 }, /* unc_m3upi_txr_horz_nack.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m3upi \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5241329 }, /* unc_m3upi_txr_horz_nack.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m3upi \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5241786 }, /* unc_m3upi_txr_horz_occupancy.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m3upi \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5242488 }, /* unc_m3upi_txr_horz_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m3upi \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5243169 }, /* unc_m3upi_txr_horz_occupancy.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5243541 }, /* unc_m3upi_txr_horz_occupancy.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m3upi \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5244194 }, /* unc_m3upi_txr_horz_occupancy.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5244570 }, /* unc_m3upi_txr_horz_occupancy.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m3upi \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 5245272 }, /* unc_m3upi_txr_horz_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m3upi \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5245953 }, /* unc_m3upi_txr_horz_occupancy.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m3upi \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5246325 }, /* unc_m3upi_txr_horz_occupancy.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m3upi \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5246978 }, /* unc_m3upi_txr_horz_starved.ad_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 5247736 }, /* unc_m3upi_txr_horz_starved.ad_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5248142 }, /* unc_m3upi_txr_horz_starved.ak\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m3upi \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5248852 }, /* unc_m3upi_txr_horz_starved.akc_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5249262 }, /* unc_m3upi_txr_horz_starved.bl_all\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m3upi \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 5250020 }, /* unc_m3upi_txr_horz_starved.bl_uncrd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m3upi \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5250426 }, /* unc_m3upi_txr_horz_starved.iv\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m3upi \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5251136 }, /* unc_m3upi_txr_vert_ads_used.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5251668 }, /* unc_m3upi_txr_vert_ads_used.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252695 }, /* unc_m3upi_txr_vert_ads_used.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5253227 }, /* unc_m3upi_txr_vert_ads_used.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5253761 }, /* unc_m3upi_txr_vert_bypass.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5254273 }, /* unc_m3upi_txr_vert_bypass.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5254787 }, /* unc_m3upi_txr_vert_bypass.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255299 }, /* unc_m3upi_txr_vert_bypass.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255813 }, /* unc_m3upi_txr_vert_bypass.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m3upi \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256325 }, /* unc_m3upi_txr_vert_bypass.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5257061 }, /* unc_m3upi_txr_vert_bypass.iv_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m3upi \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5257337 }, /* unc_m3upi_txr_vert_bypass_1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5257618 }, /* unc_m3upi_txr_vert_bypass_1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5260876 }, /* unc_m3upi_txr_vert_cycles_full0.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5261388 }, /* unc_m3upi_txr_vert_cycles_full0.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5261869 }, /* unc_m3upi_txr_vert_cycles_full0.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5262363 }, /* unc_m3upi_txr_vert_cycles_full0.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5262798 }, /* unc_m3upi_txr_vert_cycles_full0.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5263308 }, /* unc_m3upi_txr_vert_cycles_full0.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m3upi \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5263812 }, /* unc_m3upi_txr_vert_cycles_full0.iv_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m3upi \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5264294 }, /* unc_m3upi_txr_vert_cycles_full1.akc_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m3upi \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5264809 }, /* unc_m3upi_txr_vert_cycles_full1.akc_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m3upi \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5268311 }, /* unc_m3upi_txr_vert_cycles_ne0.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5268832 }, /* unc_m3upi_txr_vert_cycles_ne0.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5269322 }, /* unc_m3upi_txr_vert_cycles_ne0.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5269825 }, /* unc_m3upi_txr_vert_cycles_ne0.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5270269 }, /* unc_m3upi_txr_vert_cycles_ne0.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5270788 }, /* unc_m3upi_txr_vert_cycles_ne0.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m3upi \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5271301 }, /* unc_m3upi_txr_vert_cycles_ne0.iv_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m3upi \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5271792 }, /* unc_m3upi_txr_vert_cycles_ne1.akc_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m3upi \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5272316 }, /* unc_m3upi_txr_vert_cycles_ne1.akc_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m3upi \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5275659 }, /* unc_m3upi_txr_vert_inserts0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5276138 }, /* unc_m3upi_txr_vert_inserts0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5276586 }, /* unc_m3upi_txr_vert_inserts0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5277047 }, /* unc_m3upi_txr_vert_inserts0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5277449 }, /* unc_m3upi_txr_vert_inserts0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5277926 }, /* unc_m3upi_txr_vert_inserts0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5278397 }, /* unc_m3upi_txr_vert_inserts0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5278846 }, /* unc_m3upi_txr_vert_inserts1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5279328 }, /* unc_m3upi_txr_vert_inserts1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5281279 }, /* unc_m3upi_txr_vert_nack0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5281538 }, /* unc_m3upi_txr_vert_nack0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5281798 }, /* unc_m3upi_txr_vert_nack0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5282057 }, /* unc_m3upi_txr_vert_nack0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5282317 }, /* unc_m3upi_txr_vert_nack0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5282576 }, /* unc_m3upi_txr_vert_nack0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5282836 }, /* unc_m3upi_txr_vert_nack0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : IV. Unit: uncore_m3upi \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5283075 }, /* unc_m3upi_txr_vert_nack1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m3upi \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5283337 }, /* unc_m3upi_txr_vert_nack1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m3upi \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5286485 }, /* unc_m3upi_txr_vert_occupancy0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5286969 }, /* unc_m3upi_txr_vert_occupancy0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5287422 }, /* unc_m3upi_txr_vert_occupancy0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5287888 }, /* unc_m3upi_txr_vert_occupancy0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5288295 }, /* unc_m3upi_txr_vert_occupancy0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5288777 }, /* unc_m3upi_txr_vert_occupancy0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5289253 }, /* unc_m3upi_txr_vert_occupancy0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5289707 }, /* unc_m3upi_txr_vert_occupancy1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5290194 }, /* unc_m3upi_txr_vert_occupancy1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5292906 }, /* unc_m3upi_txr_vert_starved0.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5293288 }, /* unc_m3upi_txr_vert_starved0.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5293671 }, /* unc_m3upi_txr_vert_starved0.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5294053 }, /* unc_m3upi_txr_vert_starved0.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5294436 }, /* unc_m3upi_txr_vert_starved0.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5294818 }, /* unc_m3upi_txr_vert_starved0.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5295201 }, /* unc_m3upi_txr_vert_starved0.iv_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m3upi \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5295563 }, /* unc_m3upi_txr_vert_starved1.akc_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5295948 }, /* unc_m3upi_txr_vert_starved1.akc_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m3upi \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5296333 }, /* unc_m3upi_txr_vert_starved1.tgc\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m3upi \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5296714 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000UPI0 AD Credits Empty : VN0 REQ Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5297188 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000UPI0 AD Credits Empty : VN0 RSP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5297662 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000UPI0 AD Credits Empty : VN0 SNP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5298136 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000UPI0 AD Credits Empty : VN1 REQ Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5298612 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000UPI0 AD Credits Empty : VN1 RSP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5299088 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000UPI0 AD Credits Empty : VN1 SNP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5299564 }, /* unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000UPI0 AD Credits Empty : VNA : No credits available to send to UPIs on the AD Ring\000 */
{ 5299991 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000UPI0 BL Credits Empty : VN0 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5300543 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000UPI0 BL Credits Empty : VN0 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301087 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000UPI0 BL Credits Empty : VN0 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301629 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000UPI0 BL Credits Empty : VN1 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302183 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000UPI0 BL Credits Empty : VN1 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302729 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000UPI0 BL Credits Empty : VN1 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303273 }, /* unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000UPI0 BL Credits Empty : VNA : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303770 }, /* unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000FlowQ Generated Prefetch. Unit: uncore_m3upi \000event=0x29\000\00001\000FlowQ Generated Prefetch : Count cases where FlowQ causes spawn of Prefetch to iMC/SMI3 target\000 */
{ 5304311 }, /* unc_m3upi_vert_ring_ad_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5306120 }, /* unc_m3upi_vert_ring_ad_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5307924 }, /* unc_m3upi_vert_ring_ad_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5309727 }, /* unc_m3upi_vert_ring_ad_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5311525 }, /* unc_m3upi_vert_ring_ak_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5313334 }, /* unc_m3upi_vert_ring_ak_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5315138 }, /* unc_m3upi_vert_ring_ak_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5316941 }, /* unc_m3upi_vert_ring_ak_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5318739 }, /* unc_m3upi_vert_ring_akc_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5319673 }, /* unc_m3upi_vert_ring_akc_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5320604 }, /* unc_m3upi_vert_ring_akc_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5321534 }, /* unc_m3upi_vert_ring_akc_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5322461 }, /* unc_m3upi_vert_ring_bl_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m3upi \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5324266 }, /* unc_m3upi_vert_ring_bl_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m3upi \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5326066 }, /* unc_m3upi_vert_ring_bl_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m3upi \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5327865 }, /* unc_m3upi_vert_ring_bl_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m3upi \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5329659 }, /* unc_m3upi_vert_ring_iv_in_use.dn\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use : Down. Unit: uncore_m3upi \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5330821 }, /* unc_m3upi_vert_ring_iv_in_use.up\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use : Up. Unit: uncore_m3upi \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5331977 }, /* unc_m3upi_vert_ring_tgc_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m3upi \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5332911 }, /* unc_m3upi_vert_ring_tgc_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m3upi \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5333842 }, /* unc_m3upi_vert_ring_tgc_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m3upi \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5334772 }, /* unc_m3upi_vert_ring_tgc_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m3upi \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5335699 }, /* unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000VN0 Credit Used : WB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5337996 }, /* unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000VN0 Credit Used : NCB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5340212 }, /* unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000VN0 Credit Used : REQ on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5342342 }, /* unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000VN0 Credit Used : RSP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5344522 }, /* unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000VN0 Credit Used : SNP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5346562 }, /* unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000VN0 Credit Used : RSP on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5348738 }, /* unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000VN0 No Credits : WB on BL : Number of Cycles there were no VN0 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5349506 }, /* unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000VN0 No Credits : NCB on BL : Number of Cycles there were no VN0 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5350193 }, /* unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000VN0 No Credits : REQ on AD : Number of Cycles there were no VN0 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5350794 }, /* unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000VN0 No Credits : RSP on AD : Number of Cycles there were no VN0 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5351445 }, /* unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000VN0 No Credits : SNP on AD : Number of Cycles there were no VN0 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5351956 }, /* unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000VN0 No Credits : RSP on BL : Number of Cycles there were no VN0 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5352603 }, /* unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000VN1 Credit Used : WB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5354898 }, /* unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000VN1 Credit Used : NCB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5357112 }, /* unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000VN1 Credit Used : REQ on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5359240 }, /* unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000VN1 Credit Used : RSP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5361418 }, /* unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000VN1 Credit Used : SNP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5363456 }, /* unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000VN1 Credit Used : RSP on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5365630 }, /* unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000VN1 No Credits : WB on BL : Number of Cycles there were no VN1 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5366398 }, /* unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000VN1 No Credits : NCB on BL : Number of Cycles there were no VN1 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5367085 }, /* unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000VN1 No Credits : REQ on AD : Number of Cycles there were no VN1 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5367686 }, /* unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000VN1 No Credits : RSP on AD : Number of Cycles there were no VN1 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5368337 }, /* unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000VN1 No Credits : SNP on AD : Number of Cycles there were no VN1 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5368848 }, /* unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000VN1 No Credits : RSP on BL : Number of Cycles there were no VN1 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5369495 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x82\000\00001\000\000 */
{ 5369690 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xa0\000\00001\000\000 */
{ 5369885 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x81\000\00001\000\000 */
{ 5370080 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x90\000\00001\000\000 */
{ 5370275 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x84\000\00001\000\000 */
{ 5370470 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xc0\000\00001\000\000 */
{ 5370665 }, /* unc_m3upi_wb_occ_compare.rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x2\000\00001\000\000 */
{ 5370835 }, /* unc_m3upi_wb_occ_compare.rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x20\000\00001\000\000 */
{ 5371006 }, /* unc_m3upi_wb_occ_compare.rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x1\000\00001\000\000 */
{ 5371176 }, /* unc_m3upi_wb_occ_compare.rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x10\000\00001\000\000 */
{ 5371347 }, /* unc_m3upi_wb_occ_compare.rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x4\000\00001\000\000 */
{ 5371517 }, /* unc_m3upi_wb_occ_compare.rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x40\000\00001\000\000 */
{ 5371688 }, /* unc_m3upi_wb_pending.local_and_rt_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x4\000\00001\000\000 */
{ 5371844 }, /* unc_m3upi_wb_pending.local_and_rt_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x40\000\00001\000\000 */
{ 5372001 }, /* unc_m3upi_wb_pending.localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x1\000\00001\000\000 */
{ 5372151 }, /* unc_m3upi_wb_pending.localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x10\000\00001\000\000 */
{ 5372302 }, /* unc_m3upi_wb_pending.routethru_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x2\000\00001\000\000 */
{ 5372452 }, /* unc_m3upi_wb_pending.routethru_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x20\000\00001\000\000 */
{ 5372603 }, /* unc_m3upi_wb_pending.waiting4pull_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x8\000\00001\000\000 */
{ 5372759 }, /* unc_m3upi_wb_pending.waiting4pull_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x80\000\00001\000\000 */
{ 5372916 }, /* unc_m3upi_xpt_pftch.arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARB. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000: xpt prefetch message is making arbitration request\000 */
{ 5373096 }, /* unc_m3upi_xpt_pftch.arrived\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARRIVED. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000: xpt prefetch message arrived in ingress pipeline\000 */
{ 5373282 }, /* unc_m3upi_xpt_pftch.bypass\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.BYPASS. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000: xpt prefetch message took bypass path\000 */
{ 5373455 }, /* unc_m3upi_xpt_pftch.flitted\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.FLITTED. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000: xpt prefetch message was slotted into flit (non bypass)\000 */
{ 5373649 }, /* unc_m3upi_xpt_pftch.lost_arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_ARB. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000: xpt prefetch message lost arbitration\000 */
{ 5373826 }, /* unc_m3upi_xpt_pftch.lost_old\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_OLD. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000: xpt prefetch message was dropped because it became too old\000 */
{ 5374025 }, /* unc_m3upi_xpt_pftch.lost_qfull\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_QFULL. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000: xpt prefetch message was dropped because it was overwritten by new message while prefetch queue was full\000 */
{ 6073363 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000 */
{ 6073690 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : Doorbell. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000\000 */
{ 6074265 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received : Interrupt. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Message Received : Interrupt : Interrupts\000 */
{ 6074870 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Message Received : IPI : Inter Processor Interrupts\000 */
{ 6075510 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Message Received : MSI : Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000 */
{ 6076306 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Message Received : VLW : Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6077892 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000IDI Lock/SplitLock Cycles : Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6078260 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 6078414 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 6078568 }, /* unc_u_m2u_misc1.rxc_cycles_ne_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 6078722 }, /* unc_u_m2u_misc1.rxc_cycles_ne_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x8\000\00001\000\000 */
{ 6078876 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x10\000\00001\000\000 */
{ 6079041 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x20\000\00001\000\000 */
{ 6079206 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x40\000\00001\000\000 */
{ 6079371 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x80\000\00001\000\000 */
{ 6079536 }, /* unc_u_m2u_misc2.rxc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 6079686 }, /* unc_u_m2u_misc2.rxc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 6079834 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCB. Unit: uncore_ubox \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 6079998 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCS. Unit: uncore_ubox \000event=0x4e,umask=0x8\000\00001\000\000 */
{ 6080162 }, /* unc_u_m2u_misc2.txc_cycles_empty_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AK. Unit: uncore_ubox \000event=0x4e,umask=0x20\000\00001\000\000 */
{ 6080313 }, /* unc_u_m2u_misc2.txc_cycles_empty_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AKC. Unit: uncore_ubox \000event=0x4e,umask=0x40\000\00001\000\000 */
{ 6080466 }, /* unc_u_m2u_misc2.txc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x10\000\00001\000\000 */
{ 6080617 }, /* unc_u_m2u_misc2.txc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x80\000\00001\000\000 */
{ 6080766 }, /* unc_u_m2u_misc3.txc_cycles_full_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AK. Unit: uncore_ubox \000event=0x4f,umask=0x1\000\00001\000\000 */
{ 6080914 }, /* unc_u_m2u_misc3.txc_cycles_full_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AKC. Unit: uncore_ubox \000event=0x4f,umask=0x2\000\00001\000\000 */
{ 6081763 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack : Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000Cycles PHOLD Assert to Ack : Assert to ACK : PHOLD cycles\000 */
{ 6082332 }, /* unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 6082474 }, /* unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 6082598 }, /* unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 6083007 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000RACU Request : Number outstanding register requests within message channel tracker\000 */
{ 6086255 }, /* unc_upi_clockticks\000uncore_upi\000uncore interconnect\000Number of kfclks. Unit: uncore_upi \000event=0x1\000\00001\000Number of kfclks : Counts the number of clocks in the UPI LL.  This clock runs at 1/8th the GT/s speed of the UPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  Current products do not support dynamic link speeds, so this frequency is fixed\000 */
{ 6087000 }, /* unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2C. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Direct packet attempts : D2C : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 6087538 }, /* unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2K. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Direct packet attempts : D2K : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 6088533 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x1\000\00001\000\000 */
{ 6088681 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x2\000\00001\000\000 */
{ 6088829 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x4\000\00001\000\000 */
{ 6088977 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x10\000\00001\000\000 */
{ 6089126 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x20\000\00001\000\000 */
{ 6089275 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x40\000\00001\000\000 */
{ 6089424 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq3\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ3. Unit: uncore_upi \000event=0x18,umask=0x80\000\00001\000\000 */
{ 6089573 }, /* unc_upi_flowq_no_vna_crd.bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.BL_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x8\000\00001\000\000 */
{ 6090178 }, /* unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L1. Unit: uncore_upi \000event=0x21\000\00001\000Cycles in L1 : Number of UPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a UPI link.  Use edge detect to count the number of instances when the UPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 6090695 }, /* unc_upi_m3_byp_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x14,umask=0x8\000\00001\000\000 */
{ 6090833 }, /* unc_upi_m3_byp_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x14,umask=0x1\000\00001\000\000 */
{ 6090989 }, /* unc_upi_m3_byp_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x14,umask=0x4\000\00001\000\000 */
{ 6091145 }, /* unc_upi_m3_byp_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x14,umask=0x2\000\00001\000\000 */
{ 6091301 }, /* unc_upi_m3_byp_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x14,umask=0x10\000\00001\000\000 */
{ 6091442 }, /* unc_upi_m3_crd_return_blocked\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_CRD_RETURN_BLOCKED. Unit: uncore_upi \000event=0x16\000\00001\000\000 */
{ 6091568 }, /* unc_upi_m3_rxq_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x15,umask=0x20\000\00001\000\000 */
{ 6091707 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_btw_2_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_BTW_2_THRESH. Unit: uncore_upi \000event=0x15,umask=0x2\000\00001\000\000 */
{ 6091881 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x15,umask=0x1\000\00001\000\000 */
{ 6092037 }, /* unc_upi_m3_rxq_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x15,umask=0x10\000\00001\000\000 */
{ 6092194 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_btw_0_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_BTW_0_THRESH. Unit: uncore_upi \000event=0x15,umask=0x8\000\00001\000\000 */
{ 6092368 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x15,umask=0x4\000\00001\000\000 */
{ 6092524 }, /* unc_upi_m3_rxq_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x15,umask=0x40\000\00001\000\000 */
{ 6092665 }, /* unc_upi_phy_init_cycles\000uncore_upi\000uncore interconnect\000Cycles where phy is not in L0, L0c, L0p, L1. Unit: uncore_upi \000event=0x20\000\00001\000\000 */
{ 6093557 }, /* unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000L1 Req Nack : Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095094 }, /* unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000L1 Req (same as L1 Ack). : Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095886 }, /* unc_upi_req_slot2_from_m3.ack\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.ACK. Unit: uncore_upi \000event=0x46,umask=0x8\000\00001\000\000 */
{ 6096022 }, /* unc_upi_req_slot2_from_m3.vn0\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN0. Unit: uncore_upi \000event=0x46,umask=0x2\000\00001\000\000 */
{ 6096158 }, /* unc_upi_req_slot2_from_m3.vn1\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN1. Unit: uncore_upi \000event=0x46,umask=0x4\000\00001\000\000 */
{ 6096294 }, /* unc_upi_req_slot2_from_m3.vna\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VNA. Unit: uncore_upi \000event=0x46,umask=0x1\000\00001\000\000 */
{ 6096998 }, /* unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x24\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6097567 }, /* unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x25\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 6099673 }, /* unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6100571 }, /* unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6101509 }, /* unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6102413 }, /* unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6103357 }, /* unc_upi_rxl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Request. Unit: uncore_upi \000event=0x5,umask=0x8\000\00001\000Matches on Receive path of a UPI Port : Request : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6104211 }, /* unc_upi_rxl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Request, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x108\000\00001\000Matches on Receive path of a UPI Port : Request, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6105138 }, /* unc_upi_rxl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Data. Unit: uncore_upi \000event=0x5,umask=0xc\000\00001\000Matches on Receive path of a UPI Port : Response - Data : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6106032 }, /* unc_upi_rxl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Data, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10c\000\00001\000Matches on Receive path of a UPI Port : Response - Data, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6106966 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - No Data. Unit: uncore_upi \000event=0x5,umask=0xa\000\00001\000Matches on Receive path of a UPI Port : Response - No Data : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6107875 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - No Data, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10a\000\00001\000Matches on Receive path of a UPI Port : Response - No Data, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6108824 }, /* unc_upi_rxl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Conflict. Unit: uncore_upi \000event=0x5,umask=0x1aa\000\00001\000Matches on Receive path of a UPI Port : Response - Conflict : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6109711 }, /* unc_upi_rxl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Response - Invalid. Unit: uncore_upi \000event=0x5,umask=0x12a\000\00001\000Matches on Receive path of a UPI Port : Response - Invalid : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6110587 }, /* unc_upi_rxl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Snoop. Unit: uncore_upi \000event=0x5,umask=0x9\000\00001\000Matches on Receive path of a UPI Port : Snoop : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6111435 }, /* unc_upi_rxl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Snoop, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x109\000\00001\000Matches on Receive path of a UPI Port : Snoop, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6112356 }, /* unc_upi_rxl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Writeback. Unit: uncore_upi \000event=0x5,umask=0xd\000\00001\000Matches on Receive path of a UPI Port : Writeback : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6113220 }, /* unc_upi_rxl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Writeback, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10d\000\00001\000Matches on Receive path of a UPI Port : Writeback, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6114649 }, /* unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 0. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000RxQ Flit Buffer Bypassed : Slot 0 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6115744 }, /* unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 1. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000RxQ Flit Buffer Bypassed : Slot 1 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6116818 }, /* unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 2. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000RxQ Flit Buffer Bypassed : Slot 2 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6117366 }, /* unc_upi_rxl_crc_errors\000uncore_upi\000uncore interconnect\000CRC Errors Detected. Unit: uncore_upi \000event=0xb\000\00001\000CRC Errors Detected : Number of CRC errors detected in the UPI Agent.  Each UPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the UPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000 */
{ 6118668 }, /* unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000LLR Requests Sent : Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs\000 */
{ 6119714 }, /* unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000VN0 Credit Consumed : Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6120360 }, /* unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000VN1 Credit Consumed : Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121356 }, /* unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38\000\00001\000VNA Credit Consumed : Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121690 }, /* unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Data. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Valid Flits Received : All Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6122644 }, /* unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Valid Flits Received : Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000Valid Flits Received : Null FLITs received from any slot : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6122914 }, /* unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received : Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Valid Flits Received : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6123836 }, /* unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received : Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Valid Flits Received : Null FLITs received from any slot : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6124279 }, /* unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Valid Flits Received : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6124938 }, /* unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Valid Flits Received : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6125767 }, /* unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Non Data. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Valid Flits Received : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6126166 }, /* unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x3,umask=0x20\000\00001\000Valid Flits Received : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000 */
{ 6126721 }, /* unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received : Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Valid Flits Received : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6127308 }, /* unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Valid Flits Received : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6127838 }, /* unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Valid Flits Received : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6128368 }, /* unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Valid Flits Received : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6129969 }, /* unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000RxQ Flit Buffer Allocations : Slot 0 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6131141 }, /* unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000RxQ Flit Buffer Allocations : Slot 1 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6132313 }, /* unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000RxQ Flit Buffer Allocations : Slot 2 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6133485 }, /* unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000RxQ Occupancy - All Packets : Slot 0 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6134779 }, /* unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000RxQ Occupancy - All Packets : Slot 1 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6136073 }, /* unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000RxQ Occupancy - All Packets : Slot 2 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6137367 }, /* unc_upi_rxl_slot_bypass.s0_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x1\000\00001\000\000 */
{ 6137507 }, /* unc_upi_rxl_slot_bypass.s0_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x2\000\00001\000\000 */
{ 6137647 }, /* unc_upi_rxl_slot_bypass.s1_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x4\000\00001\000\000 */
{ 6137787 }, /* unc_upi_rxl_slot_bypass.s1_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x8\000\00001\000\000 */
{ 6137927 }, /* unc_upi_rxl_slot_bypass.s2_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x10\000\00001\000\000 */
{ 6138068 }, /* unc_upi_rxl_slot_bypass.s2_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x20\000\00001\000\000 */
{ 6138778 }, /* unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x26\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6139347 }, /* unc_upi_txl0p_clk_active.cfg_ctl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.CFG_CTL. Unit: uncore_upi \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 6139489 }, /* unc_upi_txl0p_clk_active.dfx\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.DFX. Unit: uncore_upi \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 6139624 }, /* unc_upi_txl0p_clk_active.retry\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RETRY. Unit: uncore_upi \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 6139763 }, /* unc_upi_txl0p_clk_active.rxq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ. Unit: uncore_upi \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 6139897 }, /* unc_upi_txl0p_clk_active.rxq_bypass\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_BYPASS. Unit: uncore_upi \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 6140045 }, /* unc_upi_txl0p_clk_active.rxq_cred\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_CRED. Unit: uncore_upi \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 6140189 }, /* unc_upi_txl0p_clk_active.spare\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.SPARE. Unit: uncore_upi \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 6140328 }, /* unc_upi_txl0p_clk_active.txq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.TXQ. Unit: uncore_upi \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 6140463 }, /* unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x27\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 6141543 }, /* unc_upi_txl0p_power_cycles_ll_enter\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_LL_ENTER. Unit: uncore_upi \000event=0x28\000\00001\000\000 */
{ 6141681 }, /* unc_upi_txl0p_power_cycles_m3_exit\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_M3_EXIT. Unit: uncore_upi \000event=0x29\000\00001\000\000 */
{ 6142879 }, /* unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6143781 }, /* unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6144723 }, /* unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6145631 }, /* unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6146579 }, /* unc_upi_txl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Request. Unit: uncore_upi \000event=0x4,umask=0x8\000\00001\000Matches on Transmit path of a UPI Port : Request : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6147437 }, /* unc_upi_txl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Request, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x108\000\00001\000Matches on Transmit path of a UPI Port : Request, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6148368 }, /* unc_upi_txl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Data. Unit: uncore_upi \000event=0x4,umask=0xc\000\00001\000Matches on Transmit path of a UPI Port : Response - Data : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6149266 }, /* unc_upi_txl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Data, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10c\000\00001\000Matches on Transmit path of a UPI Port : Response - Data, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6150204 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - No Data. Unit: uncore_upi \000event=0x4,umask=0xa\000\00001\000Matches on Transmit path of a UPI Port : Response - No Data : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6151117 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - No Data, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10a\000\00001\000Matches on Transmit path of a UPI Port : Response - No Data, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6152070 }, /* unc_upi_txl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Conflict. Unit: uncore_upi \000event=0x4,umask=0x1aa\000\00001\000Matches on Transmit path of a UPI Port : Response - Conflict : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6152961 }, /* unc_upi_txl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Response - Invalid. Unit: uncore_upi \000event=0x4,umask=0x12a\000\00001\000Matches on Transmit path of a UPI Port : Response - Invalid : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6153841 }, /* unc_upi_txl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Snoop. Unit: uncore_upi \000event=0x4,umask=0x9\000\00001\000Matches on Transmit path of a UPI Port : Snoop : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6154693 }, /* unc_upi_txl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Snoop, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x109\000\00001\000Matches on Transmit path of a UPI Port : Snoop, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6155618 }, /* unc_upi_txl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Writeback. Unit: uncore_upi \000event=0x4,umask=0xd\000\00001\000Matches on Transmit path of a UPI Port : Writeback : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6156486 }, /* unc_upi_txl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Writeback, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10d\000\00001\000Matches on Transmit path of a UPI Port : Writeback, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6157916 }, /* unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_upi \000event=0x41\000\00001\000Tx Flit Buffer Bypassed : Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the UPI Link. Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 6158593 }, /* unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Data. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Valid Flits Sent : All Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6159947 }, /* unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Null FLITs transmitted to any slot. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000Valid Flits Sent : Null FLITs transmitted to any slot : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6160440 }, /* unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Valid Flits Sent : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6161453 }, /* unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Idle. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Valid Flits Sent : Idle : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6161653 }, /* unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Valid Flits Sent : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6162300 }, /* unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Valid Flits Sent : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6163152 }, /* unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Non Data. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Valid Flits Sent : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6163543 }, /* unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x2,umask=0x20\000\00001\000Valid Flits Sent : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000 */
{ 6164090 }, /* unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Valid Flits Sent : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6164665 }, /* unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Valid Flits Sent : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6165183 }, /* unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Valid Flits Sent : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6165701 }, /* unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Valid Flits Sent : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6168722 }, /* unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Tx Flit Buffer Allocations : Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6169764 }, /* unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Tx Flit Buffer Occupancy : Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 6170298 }, /* unc_upi_vna_credit_return_blocked_vn01\000uncore_upi\000uncore interconnect\000UNC_UPI_VNA_CREDIT_RETURN_BLOCKED_VN01. Unit: uncore_upi \000event=0x45\000\00001\000\000 */
{ 6170671 }, /* unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000VNA Credits Pending Return - Occupancy : Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 3924647 }, /* unc_iio_bandwidth_in.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x20\000\00001\000\000 */
{ 3924873 }, /* unc_iio_bandwidth_in.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x21\000\00001\000\000 */
{ 3925099 }, /* unc_iio_bandwidth_in.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x22\000\00001\000\000 */
{ 3925325 }, /* unc_iio_bandwidth_in.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x23\000\00001\000\000 */
{ 3925551 }, /* unc_iio_bandwidth_in.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x24\000\00001\000\000 */
{ 3925777 }, /* unc_iio_bandwidth_in.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x25\000\00001\000\000 */
{ 3926003 }, /* unc_iio_bandwidth_in.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x26\000\00001\000\000 */
{ 3926229 }, /* unc_iio_bandwidth_in.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x27\000\00001\000\000 */
{ 3928641 }, /* unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the integrated IO (IIO) traffic controller. Unit: uncore_iio \000event=0x1\000\00001\000Clockticks of the integrated IO (IIO) traffic controller : Increments counter once every Traffic Controller clock, the LSCLK (500MHz)\000 */
{ 3929193 }, /* unc_iio_clockticks_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for IIO clocktick. Unit: uncore_iio_free_running \000event=0xff,umask=0x10\000\00001\000Free running counter that increments for integrated IO (IIO) traffic controller clockticks\000 */
{ 3929633 }, /* unc_iio_comp_buf_inserts.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts : All Ports. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x04,umask=0x3\000\00001\000\000 */
{ 3929999 }, /* unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-7. Unit: uncore_iio \000event=0xc2,ch_mask=0xff,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0-7\000 */
{ 3930900 }, /* unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3931829 }, /* unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000 */
{ 3932758 }, /* unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000 */
{ 3933687 }, /* unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000 */
{ 3934616 }, /* unc_iio_comp_buf_inserts.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 4. Unit: uncore_iio \000event=0xc2,ch_mask=0x10,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000 */
{ 3935354 }, /* unc_iio_comp_buf_inserts.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 5. Unit: uncore_iio \000event=0xc2,ch_mask=0x20,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000 */
{ 3936092 }, /* unc_iio_comp_buf_inserts.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 6. Unit: uncore_iio \000event=0xc2,ch_mask=0x40,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000 */
{ 3936830 }, /* unc_iio_comp_buf_inserts.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 7. Unit: uncore_iio \000event=0xc2,ch_mask=0x80,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000 */
{ 3937839 }, /* unc_iio_comp_buf_occupancy.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000 */
{ 3938067 }, /* unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000 */
{ 3938933 }, /* unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000PCIe Completion Buffer Occupancy : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3939661 }, /* unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000PCIe Completion Buffer Occupancy : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000 */
{ 3940424 }, /* unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000PCIe Completion Buffer Occupancy : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000 */
{ 3941152 }, /* unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000PCIe Completion Buffer Occupancy : Part 3 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000 */
{ 3941948 }, /* unc_iio_comp_buf_occupancy.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 4. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x10\000\00001\000PCIe Completion Buffer Occupancy : Part 4 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000 */
{ 3942494 }, /* unc_iio_comp_buf_occupancy.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 5. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x20\000\00001\000PCIe Completion Buffer Occupancy : Part 5 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000 */
{ 3943075 }, /* unc_iio_comp_buf_occupancy.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 6. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x40\000\00001\000PCIe Completion Buffer Occupancy : Part 6 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000 */
{ 3943621 }, /* unc_iio_comp_buf_occupancy.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x80\000\00001\000PCIe Completion Buffer Occupancy : Part 7 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000 */
{ 3943956 }, /* unc_iio_data_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3944369 }, /* unc_iio_data_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3944782 }, /* unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3945673 }, /* unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3946421 }, /* unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3947239 }, /* unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3947987 }, /* unc_iio_data_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3948490 }, /* unc_iio_data_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3948918 }, /* unc_iio_data_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3949381 }, /* unc_iio_data_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3950409 }, /* unc_iio_data_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3950819 }, /* unc_iio_data_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3951229 }, /* unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3952116 }, /* unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3952860 }, /* unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3953674 }, /* unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3954418 }, /* unc_iio_data_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3954918 }, /* unc_iio_data_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3955343 }, /* unc_iio_data_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3955803 }, /* unc_iio_data_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3956826 }, /* unc_iio_data_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3957230 }, /* unc_iio_data_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3957634 }, /* unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3958511 }, /* unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3959245 }, /* unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3960049 }, /* unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3960783 }, /* unc_iio_data_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3961277 }, /* unc_iio_data_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3961696 }, /* unc_iio_data_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3962150 }, /* unc_iio_data_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3963159 }, /* unc_iio_data_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3963560 }, /* unc_iio_data_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3963961 }, /* unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3964834 }, /* unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3965564 }, /* unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3966364 }, /* unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3967094 }, /* unc_iio_data_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3967585 }, /* unc_iio_data_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3968001 }, /* unc_iio_data_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3968452 }, /* unc_iio_data_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3969649 }, /* unc_iio_data_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3970093 }, /* unc_iio_data_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3970537 }, /* unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3972248 }, /* unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3973705 }, /* unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3975247 }, /* unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3977205 }, /* unc_iio_data_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3978168 }, /* unc_iio_data_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3979091 }, /* unc_iio_data_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3980014 }, /* unc_iio_data_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3981261 }, /* unc_iio_data_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3982070 }, /* unc_iio_data_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3982879 }, /* unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3984545 }, /* unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3985957 }, /* unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3987455 }, /* unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3988871 }, /* unc_iio_data_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3989854 }, /* unc_iio_data_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3990694 }, /* unc_iio_data_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3991604 }, /* unc_iio_data_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3993036 }, /* unc_iio_data_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3993490 }, /* unc_iio_data_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3993944 }, /* unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3995763 }, /* unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3997328 }, /* unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3998978 }, /* unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4001092 }, /* unc_iio_data_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4002113 }, /* unc_iio_data_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4003094 }, /* unc_iio_data_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4004075 }, /* unc_iio_data_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4005184 }, /* unc_iio_data_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4005635 }, /* unc_iio_data_req_by_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4006086 }, /* unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4007904 }, /* unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4009467 }, /* unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4011115 }, /* unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4013223 }, /* unc_iio_data_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4014238 }, /* unc_iio_data_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4015213 }, /* unc_iio_data_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4016188 }, /* unc_iio_data_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4017292 }, /* unc_iio_data_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4017695 }, /* unc_iio_data_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4018098 }, /* unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4018962 }, /* unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4019683 }, /* unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4020474 }, /* unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4021195 }, /* unc_iio_data_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4021688 }, /* unc_iio_data_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4022106 }, /* unc_iio_data_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4022559 }, /* unc_iio_data_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4025455 }, /* unc_iio_data_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4025890 }, /* unc_iio_data_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4026852 }, /* unc_iio_data_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4027829 }, /* unc_iio_data_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4028766 }, /* unc_iio_data_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4029703 }, /* unc_iio_data_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4030680 }, /* unc_iio_data_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4031657 }, /* unc_iio_data_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4032594 }, /* unc_iio_data_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4033531 }, /* unc_iio_data_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4034173 }, /* unc_iio_data_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4034569 }, /* unc_iio_data_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4034965 }, /* unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4037026 }, /* unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4038758 }, /* unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4040610 }, /* unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4042819 }, /* unc_iio_data_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4043710 }, /* unc_iio_data_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4044561 }, /* unc_iio_data_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4045412 }, /* unc_iio_data_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4046568 }, /* unc_iio_data_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4046961 }, /* unc_iio_data_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4047354 }, /* unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4049411 }, /* unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4051139 }, /* unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4052987 }, /* unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4055189 }, /* unc_iio_data_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4056074 }, /* unc_iio_data_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4056919 }, /* unc_iio_data_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4057764 }, /* unc_iio_data_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4058722 }, /* unc_iio_data_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4059078 }, /* unc_iio_data_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4059434 }, /* unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4060226 }, /* unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4060875 }, /* unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4061594 }, /* unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4062243 }, /* unc_iio_data_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4062689 }, /* unc_iio_data_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4063060 }, /* unc_iio_data_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4063466 }, /* unc_iio_data_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4064353 }, /* unc_iio_data_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4064810 }, /* unc_iio_data_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4065267 }, /* unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4066474 }, /* unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4067495 }, /* unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4068566 }, /* unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4069590 }, /* unc_iio_data_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4070137 }, /* unc_iio_data_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4070609 }, /* unc_iio_data_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4071116 }, /* unc_iio_data_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4072210 }, /* unc_iio_data_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4072664 }, /* unc_iio_data_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4073118 }, /* unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4074852 }, /* unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4076332 }, /* unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4077897 }, /* unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4079920 }, /* unc_iio_data_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4080935 }, /* unc_iio_data_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4081910 }, /* unc_iio_data_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4082885 }, /* unc_iio_data_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4084330 }, /* unc_iio_inbound_arb_req.data\000uncore_iio\000uncore io\000Incoming arbitration requests : Passing data to be written. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests : Passing data to be written : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4085027 }, /* unc_iio_inbound_arb_req.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing final read or write of line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests : Issuing final read or write of line : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4085709 }, /* unc_iio_inbound_arb_req.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests : Processing response from IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests : Processing response from IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086351 }, /* unc_iio_inbound_arb_req.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing to IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests : Issuing to IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086998 }, /* unc_iio_inbound_arb_req.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests : Request Ownership. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests : Request Ownership : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4087657 }, /* unc_iio_inbound_arb_req.wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Writing line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests : Writing line : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4088356 }, /* unc_iio_inbound_arb_won.data\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Passing data to be written. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests granted : Passing data to be written : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4089107 }, /* unc_iio_inbound_arb_won.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing final read or write of line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests granted : Issuing final read or write of line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4089843 }, /* unc_iio_inbound_arb_won.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Processing response from IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests granted : Processing response from IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4090539 }, /* unc_iio_inbound_arb_won.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing to IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests granted : Issuing to IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4091234 }, /* unc_iio_inbound_arb_won.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Request Ownership. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests granted : Request Ownership : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4091941 }, /* unc_iio_inbound_arb_won.wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Writing line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests granted : Writing line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4092284 }, /* unc_iio_iommu0.1g_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 1G Page. Unit: uncore_iio \000event=0x40,umask=0x10\000\00001\000: IOTLB Hits to a 1G Page : Counts if a transaction to a 1G page, on its first lookup, hits the IOTLB\000 */
{ 4092501 }, /* unc_iio_iommu0.2m_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 2M Page. Unit: uncore_iio \000event=0x40,umask=0x8\000\00001\000: IOTLB Hits to a 2M Page : Counts if a transaction to a 2M page, on its first lookup, hits the IOTLB\000 */
{ 4092717 }, /* unc_iio_iommu0.4k_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 4K Page. Unit: uncore_iio \000event=0x40,umask=0x4\000\00001\000: IOTLB Hits to a 4K Page : Counts if a transaction to a 4K page, on its first lookup, hits the IOTLB\000 */
{ 4092933 }, /* unc_iio_iommu0.all_lookups\000uncore_iio\000uncore io\000: IOTLB lookups all. Unit: uncore_iio \000event=0x40,umask=0x2\000\00001\000: IOTLB lookups all : Some transactions have to look up IOTLB multiple times.  Counts every time a request looks up IOTLB\000 */
{ 4093388 }, /* unc_iio_iommu0.ctxt_cache_hits\000uncore_iio\000uncore io\000: Context cache hits. Unit: uncore_iio \000event=0x40,umask=0x80\000\00001\000: Context cache hits : Counts each time a first look up of the transaction hits the RCC\000 */
{ 4093818 }, /* unc_iio_iommu0.ctxt_cache_lookups\000uncore_iio\000uncore io\000: Context cache lookups. Unit: uncore_iio \000event=0x40,umask=0x40\000\00001\000: Context cache lookups : Counts each time a transaction looks up root context cache\000 */
{ 4094286 }, /* unc_iio_iommu0.first_lookups\000uncore_iio\000uncore io\000: IOTLB lookups first. Unit: uncore_iio \000event=0x40,umask=0x1\000\00001\000: IOTLB lookups first : Some transactions have to look up IOTLB multiple times.  Counts the first time a request looks up IOTLB\000 */
{ 4094530 }, /* unc_iio_iommu0.misses\000uncore_iio\000uncore io\000: IOTLB Fills (same as IOTLB miss). Unit: uncore_iio \000event=0x40,umask=0x20\000\00001\000: IOTLB Fills (same as IOTLB miss) : When a transaction misses IOTLB, it does a page walk to look up memory and bring in the relevant page translation. Counts when this page translation is written to IOTLB\000 */
{ 4095199 }, /* unc_iio_iommu1.cyc_pwt_full\000uncore_iio\000uncore io\000: Cycles PWT full. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000: Cycles PWT full : Counts cycles the IOMMU has reached its maximum limit for outstanding page walks\000 */
{ 4095412 }, /* unc_iio_iommu1.num_mem_accesses\000uncore_iio\000uncore io\000: IOMMU memory access. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000: IOMMU memory access : IOMMU sends out memory fetches when it misses the cache look up which is indicated by this signal.  M2IOSF only uses low priority channel\000 */
{ 4095976 }, /* unc_iio_iommu1.pwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000 */
{ 4096639 }, /* unc_iio_iommu1.pwc_2m_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000 */
{ 4097075 }, /* unc_iio_iommu1.pwc_4k_hits\000uncore_iio\000uncore io\000: PWC Hit to a 4K page. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000: PWC Hit to a 4K page : Counts each time a transaction's first look up hits the SLPWC at the 4K level\000 */
{ 4097513 }, /* unc_iio_iommu1.pwc_512g_hits\000uncore_iio\000uncore io\000: PWT Hit to a 256T page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWT Hit to a 256T page : Counts each time a transaction's first look up hits the SLPWC at the 512G level\000 */
{ 4097740 }, /* unc_iio_iommu1.pwc_cache_fills\000uncore_iio\000uncore io\000: PageWalk cache fill. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000: PageWalk cache fill : When a transaction misses SLPWC, it does a page walk to look up memory and bring in the relevant page translation. When this page translation is written to SLPWC, ObsPwcFillValid_nnnH is asserted\000 */
{ 4098079 }, /* unc_iio_iommu1.pwt_cache_lookups\000uncore_iio\000uncore io\000: PageWalk cache lookup. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000: PageWalk cache lookup : Counts each time a transaction looks up second level page walk cache\000 */
{ 4098961 }, /* unc_iio_iommu3.int_cache_hits\000uncore_iio\000uncore io\000: Interrupt Entry cache hit. Unit: uncore_iio \000event=0x43,umask=0x80\000\00001\000: Interrupt Entry cache hit : Counts each time a transaction's first look up hits the IEC\000 */
{ 4099175 }, /* unc_iio_iommu3.int_cache_lookups\000uncore_iio\000uncore io\000: Interrupt Entry cache lookup. Unit: uncore_iio \000event=0x43,umask=0x40\000\00001\000: Interrupt Entry cache lookup : Counts the number of transaction looks up that interrupt remapping cache\000 */
{ 4099411 }, /* unc_iio_iommu3.num_ctxt_cache_inval_device\000uncore_iio\000uncore io\000: Device-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x20\000\00001\000: Device-selective Context cache invalidation cycles : Counts number of Device selective context cache invalidation events\000 */
{ 4099696 }, /* unc_iio_iommu3.num_ctxt_cache_inval_domain\000uncore_iio\000uncore io\000: Domain-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x10\000\00001\000: Domain-selective Context cache invalidation cycles : Counts number of Domain selective context cache invalidation events\000 */
{ 4099981 }, /* unc_iio_iommu3.num_ctxt_cache_inval_gbl\000uncore_iio\000uncore io\000: Context cache global invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x8\000\00001\000: Context cache global invalidation cycles : Counts number of Context Cache global invalidation events\000 */
{ 4100232 }, /* unc_iio_iommu3.num_inval_domain\000uncore_iio\000uncore io\000: Domain-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x2\000\00001\000: Domain-selective IOTLB invalidation cycles : Counts number of Domain selective invalidation events\000 */
{ 4100475 }, /* unc_iio_iommu3.num_inval_gbl\000uncore_iio\000uncore io\000: Global IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x1\000\00001\000: Global IOTLB invalidation cycles : Indicates that IOMMU is doing global invalidation\000 */
{ 4100691 }, /* unc_iio_iommu3.num_inval_page\000uncore_iio\000uncore io\000: Page-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x4\000\00001\000: Page-selective IOTLB invalidation cycles : Counts number of Page-selective within Domain Invalidation events\000 */
{ 4101748 }, /* unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000AND Mask/match for debug bus : Non-PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4102428 }, /* unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4103167 }, /* unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4103874 }, /* unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000AND Mask/match for debug bus : PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4104553 }, /* unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4105322 }, /* unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4106020 }, /* unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000OR Mask/match for debug bus : Non-PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4106692 }, /* unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4107423 }, /* unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4108122 }, /* unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000OR Mask/match for debug bus : PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4108793 }, /* unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4109554 }, /* unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4110128 }, /* unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0x80\000\00001\000\000 */
{ 4110218 }, /* unc_iio_num_oustanding_req_from_cpu.to_io\000uncore_iio\000uncore io\000Occupancy of outbound request queue : To device. Unit: uncore_iio \000event=0xc5,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Occupancy of outbound request queue : To device : Counts number of outbound requests/completions IIO is currently processing\000 */
{ 4110524 }, /* unc_iio_num_outstanding_req_of_cpu.data\000uncore_iio\000uncore io\000: Passing data to be written. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000: Passing data to be written : Only for posted requests\000 */
{ 4110741 }, /* unc_iio_num_outstanding_req_of_cpu.final_rd_wr\000uncore_iio\000uncore io\000: Issuing final read or write of line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000 */
{ 4110918 }, /* unc_iio_num_outstanding_req_of_cpu.iommu_hit\000uncore_iio\000uncore io\000: Processing response from IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000 */
{ 4111088 }, /* unc_iio_num_outstanding_req_of_cpu.iommu_req\000uncore_iio\000uncore io\000: Issuing to IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4111244 }, /* unc_iio_num_outstanding_req_of_cpu.req_own\000uncore_iio\000uncore io\000: Request Ownership. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000: Request Ownership : Only for posted requests\000 */
{ 4111445 }, /* unc_iio_num_outstanding_req_of_cpu.wr\000uncore_iio\000uncore io\000: Writing line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000: Writing line : Only for posted requests\000 */
{ 4111632 }, /* unc_iio_num_req_from_cpu.irp\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From IRP. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests sent to PCIe from main die : From IRP : Captures Posted/Non-posted allocations from IRP. i.e. either non-confined P2P traffic or from the CPU\000 */
{ 4111964 }, /* unc_iio_num_req_from_cpu.itc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From ITC. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests sent to PCIe from main die : From ITC : Confined P2P\000 */
{ 4112207 }, /* unc_iio_num_req_from_cpu.prealloc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : Completion allocations. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4112401 }, /* unc_iio_num_req_of_cpu.all.drop\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : Drop request. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests PCIe makes of the main die : Drop request : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU. : Packet error detected, must be dropped\000 */
{ 4113191 }, /* unc_iio_num_req_of_cpu.commit.all\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : All. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests PCIe makes of the main die : All : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU\000 */
{ 4113733 }, /* unc_iio_num_req_of_cpu_by_tgt.abort\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Abort. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x80\000\00001\000\000 */
{ 4114099 }, /* unc_iio_num_req_of_cpu_by_tgt.confined_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Confined P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x40\000\00001\000\000 */
{ 4114471 }, /* unc_iio_num_req_of_cpu_by_tgt.loc_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Local P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000\000 */
{ 4114833 }, /* unc_iio_num_req_of_cpu_by_tgt.mcast\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Multi-cast. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000 */
{ 4115187 }, /* unc_iio_num_req_of_cpu_by_tgt.mem\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Memory. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000 */
{ 4115534 }, /* unc_iio_num_req_of_cpu_by_tgt.msgb\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : MsgB. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4115890 }, /* unc_iio_num_req_of_cpu_by_tgt.rem_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Remote P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000\000 */
{ 4116246 }, /* unc_iio_num_req_of_cpu_by_tgt.ubox\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Ubox. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4116576 }, /* unc_iio_num_tgt_matched_req_of_cpu\000uncore_iio\000uncore io\000ITC address map 1. Unit: uncore_iio \000event=0x8f\000\00001\000\000 */
{ 4117113 }, /* unc_iio_outbound_cl_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound cacheline requests issued : 64B requests issued to device. Unit: uncore_iio \000event=0xd0,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound cacheline requests issued : 64B requests issued to device : Each outbound cacheline granular request may need to make multiple passes through the pipeline.  Each time a cacheline completes all its passes it advances line\000 */
{ 4117880 }, /* unc_iio_outbound_tlp_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound TLP (transaction layer packet) requests issued : To device. Unit: uncore_iio \000event=0xd1,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound TLP (transaction layer packet) requests issued : To device : Each time an outbound completes all its passes it advances the pointer\000 */
{ 4137426 }, /* unc_iio_pwt_occupancy\000uncore_iio\000uncore io\000PWT occupancy. Unit: uncore_iio \000event=0x42\000\00001\000PWT occupancy : Indicates how many page walks are outstanding at any point in time\000 */
{ 4137600 }, /* unc_iio_req_from_pcie_cl_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Passing data to be written. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - cacheline complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4138769 }, /* unc_iio_req_from_pcie_cl_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - cacheline complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line\000 */
{ 4139640 }, /* unc_iio_req_from_pcie_cl_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Request Ownership. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - cacheline complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4140513 }, /* unc_iio_req_from_pcie_cl_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Writing line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - cacheline complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4141376 }, /* unc_iio_req_from_pcie_cmpl.data\000uncore_iio\000uncore io\000PCIe Request complete : Passing data to be written. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4141941 }, /* unc_iio_req_from_pcie_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4142787 }, /* unc_iio_req_from_pcie_cmpl.iommu_hit\000uncore_iio\000uncore io\000PCIe Request complete : Processing response from IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000PCIe Request complete : Processing response from IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4143542 }, /* unc_iio_req_from_pcie_cmpl.iommu_req\000uncore_iio\000uncore io\000PCIe Request complete : Issuing to IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000PCIe Request complete : Issuing to IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4144328 }, /* unc_iio_req_from_pcie_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request complete : Request Ownership. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4145130 }, /* unc_iio_req_from_pcie_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request complete : Writing line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4146269 }, /* unc_iio_req_from_pcie_pass_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - pass complete : Passing data to be written. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - pass complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4147462 }, /* unc_iio_req_from_pcie_pass_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - pass complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state\000 */
{ 4148645 }, /* unc_iio_req_from_pcie_pass_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - pass complete : Request Ownership. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - pass complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4149800 }, /* unc_iio_req_from_pcie_pass_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Writing line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - pass complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4150562 }, /* unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Symbol Times on Link : Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000 */
{ 4166576 }, /* unc_iio_txn_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4166988 }, /* unc_iio_txn_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4167400 }, /* unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4168309 }, /* unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4169075 }, /* unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4169911 }, /* unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4170677 }, /* unc_iio_txn_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4171179 }, /* unc_iio_txn_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4171606 }, /* unc_iio_txn_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4172068 }, /* unc_iio_txn_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4173133 }, /* unc_iio_txn_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4173542 }, /* unc_iio_txn_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4173951 }, /* unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4174856 }, /* unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4175618 }, /* unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4176450 }, /* unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4177212 }, /* unc_iio_txn_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4177711 }, /* unc_iio_txn_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4178135 }, /* unc_iio_txn_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4178594 }, /* unc_iio_txn_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4179654 }, /* unc_iio_txn_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4180057 }, /* unc_iio_txn_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4180460 }, /* unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4181355 }, /* unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4182107 }, /* unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4182929 }, /* unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4183681 }, /* unc_iio_txn_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4184174 }, /* unc_iio_txn_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4184592 }, /* unc_iio_txn_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4185045 }, /* unc_iio_txn_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4186091 }, /* unc_iio_txn_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4186491 }, /* unc_iio_txn_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4186891 }, /* unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4187782 }, /* unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4188530 }, /* unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4189348 }, /* unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4190096 }, /* unc_iio_txn_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4190586 }, /* unc_iio_txn_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4191001 }, /* unc_iio_txn_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4191451 }, /* unc_iio_txn_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4192492 }, /* unc_iio_txn_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4192899 }, /* unc_iio_txn_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4193306 }, /* unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4195023 }, /* unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4196486 }, /* unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4198034 }, /* unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4199501 }, /* unc_iio_txn_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4200488 }, /* unc_iio_txn_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4201332 }, /* unc_iio_txn_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4202246 }, /* unc_iio_txn_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4203722 }, /* unc_iio_txn_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4204126 }, /* unc_iio_txn_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4204530 }, /* unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4206244 }, /* unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4207704 }, /* unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4209249 }, /* unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4210713 }, /* unc_iio_txn_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4211694 }, /* unc_iio_txn_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4212532 }, /* unc_iio_txn_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4213440 }, /* unc_iio_txn_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4214908 }, /* unc_iio_txn_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4215361 }, /* unc_iio_txn_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4215814 }, /* unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4217136 }, /* unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4218272 }, /* unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4219458 }, /* unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4220598 }, /* unc_iio_txn_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4221141 }, /* unc_iio_txn_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4221609 }, /* unc_iio_txn_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4222112 }, /* unc_iio_txn_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4223258 }, /* unc_iio_txn_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4224256 }, /* unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4226049 }, /* unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4227691 }, /* unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4229348 }, /* unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4231034 }, /* unc_iio_txn_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4232047 }, /* unc_iio_txn_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4233020 }, /* unc_iio_txn_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4233993 }, /* unc_iio_txn_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4235134 }, /* unc_iio_txn_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4235540 }, /* unc_iio_txn_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4235946 }, /* unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4236840 }, /* unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4237591 }, /* unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4238412 }, /* unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4239163 }, /* unc_iio_txn_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4239659 }, /* unc_iio_txn_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4240080 }, /* unc_iio_txn_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4240536 }, /* unc_iio_txn_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4243068 }, /* unc_iio_txn_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4243506 }, /* unc_iio_txn_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4244474 }, /* unc_iio_txn_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4245457 }, /* unc_iio_txn_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4246400 }, /* unc_iio_txn_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4247343 }, /* unc_iio_txn_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4248326 }, /* unc_iio_txn_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4249309 }, /* unc_iio_txn_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4250252 }, /* unc_iio_txn_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4251195 }, /* unc_iio_txn_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4251648 }, /* unc_iio_txn_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4252039 }, /* unc_iio_txn_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4252430 }, /* unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4254075 }, /* unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4255468 }, /* unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4256944 }, /* unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4258815 }, /* unc_iio_txn_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4259704 }, /* unc_iio_txn_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4260553 }, /* unc_iio_txn_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4261402 }, /* unc_iio_txn_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4262414 }, /* unc_iio_txn_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4262802 }, /* unc_iio_txn_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4263190 }, /* unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4264832 }, /* unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4266220 }, /* unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4267693 }, /* unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4269558 }, /* unc_iio_txn_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4270441 }, /* unc_iio_txn_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4271284 }, /* unc_iio_txn_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4272127 }, /* unc_iio_txn_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4273134 }, /* unc_iio_txn_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4273493 }, /* unc_iio_txn_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4273852 }, /* unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4274674 }, /* unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4275353 }, /* unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4276102 }, /* unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4276781 }, /* unc_iio_txn_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4277230 }, /* unc_iio_txn_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4277604 }, /* unc_iio_txn_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4278013 }, /* unc_iio_txn_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4278957 }, /* unc_iio_txn_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4279417 }, /* unc_iio_txn_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4279877 }, /* unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4281119 }, /* unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4282175 }, /* unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4283281 }, /* unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4284340 }, /* unc_iio_txn_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4284890 }, /* unc_iio_txn_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4285365 }, /* unc_iio_txn_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4285875 }, /* unc_iio_txn_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4287026 }, /* unc_iio_txn_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4287483 }, /* unc_iio_txn_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4288489 }, /* unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4290213 }, /* unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4291785 }, /* unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4293373 }, /* unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4294990 }, /* unc_iio_txn_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4296011 }, /* unc_iio_txn_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4296992 }, /* unc_iio_txn_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4297973 }, /* unc_iio_txn_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4681598 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4681880 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682162 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682444 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682726 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683009 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683292 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683575 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683858 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684143 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684425 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684707 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4684990 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685273 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685556 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685839 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686123 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686407 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686691 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686975 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687261 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687544 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687827 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688109 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688391 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688673 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688955 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689238 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689521 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689804 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690087 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690372 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690654 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690936 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691219 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691502 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691785 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692068 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692352 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692636 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692920 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693204 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693490 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693773 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4694056 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694338 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694620 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694902 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695184 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695467 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695750 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696033 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696316 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696601 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696883 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4697165 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4697448 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4697731 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698014 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698297 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698581 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698865 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699149 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699433 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699719 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4700002 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4700285 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4700567 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4700849 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701131 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701413 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701696 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701979 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702262 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702545 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702830 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4703112 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4703394 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4703677 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4703960 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704243 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704526 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704810 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705094 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705378 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705662 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705948 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4706231 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4706514 }, /* unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000Clockticks of the mesh to PCI (M2P). Unit: uncore_m2pcie \000event=0x1\000\00001\000Clockticks of the mesh to PCI (M2P) : Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 4707189 }, /* unc_m2p_cms_clockticks\000uncore_m2pcie\000uncore io\000CMS Clockticks. Unit: uncore_m2pcie \000event=0xc0\000\00001\000\000 */
{ 4707289 }, /* unc_m2p_distress_asserted.dpt_local\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Local. Unit: uncore_m2pcie \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 4707611 }, /* unc_m2p_distress_asserted.dpt_nonlocal\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Remote. Unit: uncore_m2pcie \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 4707937 }, /* unc_m2p_distress_asserted.dpt_stall_iv\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2pcie \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 4708300 }, /* unc_m2p_distress_asserted.dpt_stall_nocrd\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2pcie \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 4708676 }, /* unc_m2p_distress_asserted.horz\000uncore_m2pcie\000uncore io\000Distress signal asserted : Horizontal. Unit: uncore_m2pcie \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4709024 }, /* unc_m2p_distress_asserted.pmm_local\000uncore_m2pcie\000uncore io\000Distress signal asserted : PMM Local. Unit: uncore_m2pcie \000event=0xaf,umask=0x10\000\00001\000Distress signal asserted : PMM Local : Counts the number of cycles either the local or incoming distress signals are asserted. : If the CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4709394 }, /* unc_m2p_distress_asserted.pmm_nonlocal\000uncore_m2pcie\000uncore io\000Distress signal asserted : PMM Remote. Unit: uncore_m2pcie \000event=0xaf,umask=0x20\000\00001\000Distress signal asserted : PMM Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : If another CHA TOR has too many PMM transactions, this signal will throttle outgoing MS2IDI traffic\000 */
{ 4709773 }, /* unc_m2p_distress_asserted.vert\000uncore_m2pcie\000uncore io\000Distress signal asserted : Vertical. Unit: uncore_m2pcie \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4714289 }, /* unc_m2p_egress_ordering.iv_snoopgo_dn\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2pcie \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4714597 }, /* unc_m2p_egress_ordering.iv_snoopgo_up\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2pcie \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4714901 }, /* unc_m2p_horz_ring_ad_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4715824 }, /* unc_m2p_horz_ring_ad_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4716744 }, /* unc_m2p_horz_ring_ad_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4717670 }, /* unc_m2p_horz_ring_ad_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4718593 }, /* unc_m2p_horz_ring_ak_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4719514 }, /* unc_m2p_horz_ring_ak_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4720432 }, /* unc_m2p_horz_ring_ak_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4721356 }, /* unc_m2p_horz_ring_ak_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4722277 }, /* unc_m2p_horz_ring_akc_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4723207 }, /* unc_m2p_horz_ring_akc_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4724134 }, /* unc_m2p_horz_ring_akc_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4725067 }, /* unc_m2p_horz_ring_akc_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4725997 }, /* unc_m2p_horz_ring_bl_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4726919 }, /* unc_m2p_horz_ring_bl_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4727838 }, /* unc_m2p_horz_ring_bl_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4728763 }, /* unc_m2p_horz_ring_bl_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4729685 }, /* unc_m2p_horz_ring_iv_in_use.left\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Left. Unit: uncore_m2pcie \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4730281 }, /* unc_m2p_horz_ring_iv_in_use.right\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Right. Unit: uncore_m2pcie \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4730880 }, /* unc_m2p_iio_credits_acquired.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x1\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4731581 }, /* unc_m2p_iio_credits_acquired.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x2\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4732282 }, /* unc_m2p_iio_credits_acquired.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x4\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4732983 }, /* unc_m2p_iio_credits_acquired.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x8\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4733684 }, /* unc_m2p_iio_credits_acquired.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x10\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4734386 }, /* unc_m2p_iio_credits_acquired.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x20\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4735088 }, /* unc_m2p_iio_credits_reject.drs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : DRS. Unit: uncore_m2pcie \000event=0x34,umask=0x8\000\00001\000M2PCIe IIO Failed to Acquire a Credit : DRS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the DRS message class\000 */
{ 4735684 }, /* unc_m2p_iio_credits_reject.ncb\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCB. Unit: uncore_m2pcie \000event=0x34,umask=0x10\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCB : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCB message class\000 */
{ 4736281 }, /* unc_m2p_iio_credits_reject.ncs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCS. Unit: uncore_m2pcie \000event=0x34,umask=0x20\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCS message class\000 */
{ 4736878 }, /* unc_m2p_iio_credits_used.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x1\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4737607 }, /* unc_m2p_iio_credits_used.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x2\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4738336 }, /* unc_m2p_iio_credits_used.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x4\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739065 }, /* unc_m2p_iio_credits_used.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x8\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739794 }, /* unc_m2p_iio_credits_used.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x10\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4740524 }, /* unc_m2p_iio_credits_used.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x20\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4742091 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4742262 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4742433 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4742604 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x8\000\00001\000\000 */
{ 4742775 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x10\000\00001\000\000 */
{ 4742947 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x20\000\00001\000\000 */
{ 4743119 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x40\000\00001\000\000 */
{ 4743291 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x80\000\00001\000\000 */
{ 4743463 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4743634 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4743805 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4743976 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x8\000\00001\000\000 */
{ 4744147 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4744322 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4744497 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x4\000\00001\000\000 */
{ 4744672 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x8\000\00001\000\000 */
{ 4744847 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000 */
{ 4745023 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000 */
{ 4745199 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000 */
{ 4745551 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000 */
{ 4745903 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x1\000\00001\000\000 */
{ 4746078 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x2\000\00001\000\000 */
{ 4746253 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x4\000\00001\000\000 */
{ 4746428 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x8\000\00001\000\000 */
{ 4746603 }, /* unc_m2p_local_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4746758 }, /* unc_m2p_local_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4746913 }, /* unc_m2p_local_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x17,umask=0x4\000\00001\000\000 */
{ 4747068 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4747241 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4747414 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4747587 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_3\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent3. Unit: uncore_m2pcie \000event=0x44,umask=0x8\000\00001\000\000 */
{ 4747760 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_4\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent4. Unit: uncore_m2pcie \000event=0x44,umask=0x10\000\00001\000\000 */
{ 4747934 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_5\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent5. Unit: uncore_m2pcie \000event=0x44,umask=0x20\000\00001\000\000 */
{ 4748108 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4748277 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4748446 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4748615 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x8\000\00001\000\000 */
{ 4748784 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x10\000\00001\000\000 */
{ 4748954 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x20\000\00001\000\000 */
{ 4749124 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x40\000\00001\000\000 */
{ 4749294 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x80\000\00001\000\000 */
{ 4749464 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x1\000\00001\000\000 */
{ 4749633 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x2\000\00001\000\000 */
{ 4749802 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x4\000\00001\000\000 */
{ 4749971 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x8\000\00001\000\000 */
{ 4750140 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4750313 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4750486 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4750659 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 4750832 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x10\000\00001\000\000 */
{ 4751006 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x20\000\00001\000\000 */
{ 4751180 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x40\000\00001\000\000 */
{ 4751354 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x80\000\00001\000\000 */
{ 4751528 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4751701 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4751874 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4752047 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 4752220 }, /* unc_m2p_misc_external.mbe_inst0\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2pcie \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 4752409 }, /* unc_m2p_misc_external.mbe_inst1\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2pcie \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 4752598 }, /* unc_m2p_p2p_crd_occupancy.all\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : All. Unit: uncore_m2pcie \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4752728 }, /* unc_m2p_p2p_crd_occupancy.local_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4752869 }, /* unc_m2p_p2p_crd_occupancy.local_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4753010 }, /* unc_m2p_p2p_crd_occupancy.remote_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x4\000\00001\000\000 */
{ 4753153 }, /* unc_m2p_p2p_crd_occupancy.remote_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4753296 }, /* unc_m2p_p2p_ded_received.all\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : All. Unit: uncore_m2pcie \000event=0x16,umask=0x10\000\00001\000\000 */
{ 4753431 }, /* unc_m2p_p2p_ded_received.local_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x1\000\00001\000\000 */
{ 4753577 }, /* unc_m2p_p2p_ded_received.local_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x2\000\00001\000\000 */
{ 4753723 }, /* unc_m2p_p2p_ded_received.remote_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x4\000\00001\000\000 */
{ 4753871 }, /* unc_m2p_p2p_ded_received.remote_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x8\000\00001\000\000 */
{ 4754019 }, /* unc_m2p_p2p_shar_received.all\000uncore_m2pcie\000uncore io\000Shared Credits  Received : All. Unit: uncore_m2pcie \000event=0x15,umask=0x10\000\00001\000\000 */
{ 4754153 }, /* unc_m2p_p2p_shar_received.local_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4754298 }, /* unc_m2p_p2p_shar_received.local_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4754443 }, /* unc_m2p_p2p_shar_received.remote_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x4\000\00001\000\000 */
{ 4754590 }, /* unc_m2p_p2p_shar_received.remote_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x8\000\00001\000\000 */
{ 4754737 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x1\000\00001\000\000 */
{ 4754904 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x2\000\00001\000\000 */
{ 4755071 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x4\000\00001\000\000 */
{ 4755238 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x8\000\00001\000\000 */
{ 4755405 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x10\000\00001\000\000 */
{ 4755573 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x20\000\00001\000\000 */
{ 4755741 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4755908 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4756075 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x49,umask=0x4\000\00001\000\000 */
{ 4756242 }, /* unc_m2p_remote_p2p_ded_returned.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4756406 }, /* unc_m2p_remote_p2p_ded_returned.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4756570 }, /* unc_m2p_remote_p2p_ded_returned.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x4\000\00001\000\000 */
{ 4756734 }, /* unc_m2p_remote_p2p_ded_returned.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x8\000\00001\000\000 */
{ 4756898 }, /* unc_m2p_remote_p2p_ded_returned.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x10\000\00001\000\000 */
{ 4757063 }, /* unc_m2p_remote_p2p_ded_returned.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x20\000\00001\000\000 */
{ 4757228 }, /* unc_m2p_remote_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4757385 }, /* unc_m2p_remote_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4757542 }, /* unc_m2p_remote_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x18,umask=0x4\000\00001\000\000 */
{ 4757699 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4757874 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4758049 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4758224 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x1\000\00001\000\000 */
{ 4758389 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x2\000\00001\000\000 */
{ 4758554 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x4\000\00001\000\000 */
{ 4758719 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x8\000\00001\000\000 */
{ 4758884 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x10\000\00001\000\000 */
{ 4759050 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x20\000\00001\000\000 */
{ 4759216 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4759381 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4759546 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x43,umask=0x4\000\00001\000\000 */
{ 4759711 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4759880 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4760049 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 4760218 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x8\000\00001\000\000 */
{ 4760387 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x10\000\00001\000\000 */
{ 4760557 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x20\000\00001\000\000 */
{ 4760727 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4760896 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4761065 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4761234 }, /* unc_m2p_ring_bounces_horz.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2pcie \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4761530 }, /* unc_m2p_ring_bounces_horz.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2pcie \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4761826 }, /* unc_m2p_ring_bounces_horz.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2pcie \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4762122 }, /* unc_m2p_ring_bounces_horz.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2pcie \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4762418 }, /* unc_m2p_ring_bounces_vert.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2pcie \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4762708 }, /* unc_m2p_ring_bounces_vert.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763042 }, /* unc_m2p_ring_bounces_vert.akc\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. Unit: uncore_m2pcie \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763323 }, /* unc_m2p_ring_bounces_vert.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763653 }, /* unc_m2p_ring_bounces_vert.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763994 }, /* unc_m2p_ring_sink_starved_horz.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2pcie \000event=0xad,umask=0x1\000\00001\000\000 */
{ 4764140 }, /* unc_m2p_ring_sink_starved_horz.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2pcie \000event=0xad,umask=0x2\000\00001\000\000 */
{ 4764286 }, /* unc_m2p_ring_sink_starved_horz.ak_ag1\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2pcie \000event=0xad,umask=0x20\000\00001\000\000 */
{ 4764462 }, /* unc_m2p_ring_sink_starved_horz.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2pcie \000event=0xad,umask=0x4\000\00001\000\000 */
{ 4764608 }, /* unc_m2p_ring_sink_starved_horz.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2pcie \000event=0xad,umask=0x8\000\00001\000\000 */
{ 4764754 }, /* unc_m2p_ring_sink_starved_vert.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2pcie \000event=0xab,umask=0x1\000\00001\000\000 */
{ 4764898 }, /* unc_m2p_ring_sink_starved_vert.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xab,umask=0x2\000\00001\000\000 */
{ 4765064 }, /* unc_m2p_ring_sink_starved_vert.akc\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring. Unit: uncore_m2pcie \000event=0xab,umask=0x10\000\00001\000\000 */
{ 4765205 }, /* unc_m2p_ring_sink_starved_vert.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2pcie \000event=0xab,umask=0x4\000\00001\000\000 */
{ 4765369 }, /* unc_m2p_ring_sink_starved_vert.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xab,umask=0x8\000\00001\000\000 */
{ 4765538 }, /* unc_m2p_ring_src_thrtl\000uncore_m2pcie\000uncore io\000Source Throttle. Unit: uncore_m2pcie \000event=0xae\000\00001\000\000 */
{ 4765639 }, /* unc_m2p_rxc_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4765888 }, /* unc_m2p_rxc_cycles_ne.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766140 }, /* unc_m2p_rxc_cycles_ne.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766392 }, /* unc_m2p_rxc_cycles_ne.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766644 }, /* unc_m2p_rxc_cycles_ne.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x20\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766897 }, /* unc_m2p_rxc_cycles_ne.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x40\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767150 }, /* unc_m2p_rxc_cycles_ne.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x8\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767402 }, /* unc_m2p_rxc_cycles_ne.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x10\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767655 }, /* unc_m2p_rxc_inserts.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768017 }, /* unc_m2p_rxc_inserts.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768382 }, /* unc_m2p_rxc_inserts.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x2\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768747 }, /* unc_m2p_rxc_inserts.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769112 }, /* unc_m2p_rxc_inserts.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x20\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769478 }, /* unc_m2p_rxc_inserts.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769844 }, /* unc_m2p_rxc_inserts.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x8\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4770209 }, /* unc_m2p_rxc_inserts.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x10\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4770575 }, /* unc_m2p_rxr_busy_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4771037 }, /* unc_m2p_rxr_busy_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4771478 }, /* unc_m2p_rxr_busy_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4771924 }, /* unc_m2p_rxr_busy_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4772386 }, /* unc_m2p_rxr_busy_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4772827 }, /* unc_m2p_rxr_busy_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4773273 }, /* unc_m2p_rxr_bypass.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4773522 }, /* unc_m2p_rxr_bypass.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4773750 }, /* unc_m2p_rxr_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4773983 }, /* unc_m2p_rxr_bypass.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AK. Unit: uncore_m2pcie \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 4774184 }, /* unc_m2p_rxr_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4774421 }, /* unc_m2p_rxr_bypass.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4774670 }, /* unc_m2p_rxr_bypass.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4774898 }, /* unc_m2p_rxr_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4775131 }, /* unc_m2p_rxr_bypass.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : IV. Unit: uncore_m2pcie \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 4775332 }, /* unc_m2p_rxr_crd_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4775806 }, /* unc_m2p_rxr_crd_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4776258 }, /* unc_m2p_rxr_crd_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4776715 }, /* unc_m2p_rxr_crd_starved.ak\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4777140 }, /* unc_m2p_rxr_crd_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4777614 }, /* unc_m2p_rxr_crd_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778066 }, /* unc_m2p_rxr_crd_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778523 }, /* unc_m2p_rxr_crd_starved.ifv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778974 }, /* unc_m2p_rxr_crd_starved.iv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4779399 }, /* unc_m2p_rxr_crd_starved_1\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation. Unit: uncore_m2pcie \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4779803 }, /* unc_m2p_rxr_inserts.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4780127 }, /* unc_m2p_rxr_inserts.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4780430 }, /* unc_m2p_rxr_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4780738 }, /* unc_m2p_rxr_inserts.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AK. Unit: uncore_m2pcie \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781014 }, /* unc_m2p_rxr_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781326 }, /* unc_m2p_rxr_inserts.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4781650 }, /* unc_m2p_rxr_inserts.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781953 }, /* unc_m2p_rxr_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4782261 }, /* unc_m2p_rxr_inserts.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : IV. Unit: uncore_m2pcie \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4782537 }, /* unc_m2p_rxr_occupancy.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4782867 }, /* unc_m2p_rxr_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783176 }, /* unc_m2p_rxr_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783490 }, /* unc_m2p_rxr_occupancy.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AK. Unit: uncore_m2pcie \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783772 }, /* unc_m2p_rxr_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4784090 }, /* unc_m2p_rxr_occupancy.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4784420 }, /* unc_m2p_rxr_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4784729 }, /* unc_m2p_rxr_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4785043 }, /* unc_m2p_rxr_occupancy.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : IV. Unit: uncore_m2pcie \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4785325 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4785679 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786033 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786387 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786741 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787096 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787451 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787806 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788161 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788515 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788869 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789223 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789577 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789932 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790287 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790642 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790997 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4791351 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4791705 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792059 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792413 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792768 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793123 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793478 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793833 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794187 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794541 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794895 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795249 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795604 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795959 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4796314 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4796669 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797026 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797380 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797734 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798093 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798449 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798805 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799164 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799520 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799876 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4800235 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4800591 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4800947 }, /* unc_m2p_txc_credits.pmm\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PMM. Unit: uncore_m2pcie \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 4801067 }, /* unc_m2p_txc_credits.prq\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PRQ. Unit: uncore_m2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 4801187 }, /* unc_m2p_txc_cycles_full.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x1\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4801490 }, /* unc_m2p_txc_cycles_full.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x10\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4801794 }, /* unc_m2p_txc_cycles_full.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x2\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802097 }, /* unc_m2p_txc_cycles_full.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x20\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802401 }, /* unc_m2p_txc_cycles_full.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x4\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802704 }, /* unc_m2p_txc_cycles_full.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x40\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4803357 }, /* unc_m2p_txc_cycles_full.pmm_block_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x80\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4804016 }, /* unc_m2p_txc_cycles_full.pmm_block_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x8\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4804326 }, /* unc_m2p_txc_cycles_ne.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x1\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4804855 }, /* unc_m2p_txc_cycles_ne.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x10\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4805385 }, /* unc_m2p_txc_cycles_ne.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x2\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4805914 }, /* unc_m2p_txc_cycles_ne.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x20\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4806444 }, /* unc_m2p_txc_cycles_ne.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x4\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4806973 }, /* unc_m2p_txc_cycles_ne.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x40\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4808081 }, /* unc_m2p_txc_cycles_ne.pmm_distress_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x80\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4809198 }, /* unc_m2p_txc_cycles_ne.pmm_distress_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x8\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4809737 }, /* unc_m2p_txc_inserts.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x1\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4810184 }, /* unc_m2p_txc_inserts.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x10\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4810632 }, /* unc_m2p_txc_inserts.ak_crd_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x8\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811083 }, /* unc_m2p_txc_inserts.ak_crd_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x80\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811535 }, /* unc_m2p_txc_inserts.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x4\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811982 }, /* unc_m2p_txc_inserts.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x40\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4812430 }, /* unc_m2p_txr_horz_ads_used.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4812737 }, /* unc_m2p_txr_horz_ads_used.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813022 }, /* unc_m2p_txr_horz_ads_used.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813312 }, /* unc_m2p_txr_horz_ads_used.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4813619 }, /* unc_m2p_txr_horz_ads_used.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813904 }, /* unc_m2p_txr_horz_ads_used.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4814194 }, /* unc_m2p_txr_horz_bypass.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4814497 }, /* unc_m2p_txr_horz_bypass.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4814778 }, /* unc_m2p_txr_horz_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815064 }, /* unc_m2p_txr_horz_bypass.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2pcie \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815318 }, /* unc_m2p_txr_horz_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815608 }, /* unc_m2p_txr_horz_bypass.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4815911 }, /* unc_m2p_txr_horz_bypass.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816192 }, /* unc_m2p_txr_horz_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816478 }, /* unc_m2p_txr_horz_bypass.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2pcie \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816732 }, /* unc_m2p_txr_horz_cycles_full.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4817132 }, /* unc_m2p_txr_horz_cycles_full.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4817510 }, /* unc_m2p_txr_horz_cycles_full.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4817893 }, /* unc_m2p_txr_horz_cycles_full.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2pcie \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4818244 }, /* unc_m2p_txr_horz_cycles_full.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4818631 }, /* unc_m2p_txr_horz_cycles_full.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4819031 }, /* unc_m2p_txr_horz_cycles_full.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4819409 }, /* unc_m2p_txr_horz_cycles_full.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4819792 }, /* unc_m2p_txr_horz_cycles_full.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2pcie \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4820143 }, /* unc_m2p_txr_horz_cycles_ne.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4820556 }, /* unc_m2p_txr_horz_cycles_ne.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4820947 }, /* unc_m2p_txr_horz_cycles_ne.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4821343 }, /* unc_m2p_txr_horz_cycles_ne.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2pcie \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4821707 }, /* unc_m2p_txr_horz_cycles_ne.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4822107 }, /* unc_m2p_txr_horz_cycles_ne.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4822520 }, /* unc_m2p_txr_horz_cycles_ne.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4822911 }, /* unc_m2p_txr_horz_cycles_ne.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4823307 }, /* unc_m2p_txr_horz_cycles_ne.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2pcie \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4823671 }, /* unc_m2p_txr_horz_inserts.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4824051 }, /* unc_m2p_txr_horz_inserts.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4824409 }, /* unc_m2p_txr_horz_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4824772 }, /* unc_m2p_txr_horz_inserts.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2pcie \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4825103 }, /* unc_m2p_txr_horz_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4825470 }, /* unc_m2p_txr_horz_inserts.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4825850 }, /* unc_m2p_txr_horz_inserts.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826208 }, /* unc_m2p_txr_horz_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826571 }, /* unc_m2p_txr_horz_inserts.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2pcie \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826902 }, /* unc_m2p_txr_horz_nack.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4827180 }, /* unc_m2p_txr_horz_nack.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827437 }, /* unc_m2p_txr_horz_nack.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827699 }, /* unc_m2p_txr_horz_nack.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2pcie \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827929 }, /* unc_m2p_txr_horz_nack.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828195 }, /* unc_m2p_txr_horz_nack.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4828473 }, /* unc_m2p_txr_horz_nack.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828730 }, /* unc_m2p_txr_horz_nack.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828992 }, /* unc_m2p_txr_horz_nack.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2pcie \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4829222 }, /* unc_m2p_txr_horz_occupancy.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4829601 }, /* unc_m2p_txr_horz_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4829958 }, /* unc_m2p_txr_horz_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4830320 }, /* unc_m2p_txr_horz_occupancy.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2pcie \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4830650 }, /* unc_m2p_txr_horz_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4831016 }, /* unc_m2p_txr_horz_occupancy.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4831395 }, /* unc_m2p_txr_horz_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4831752 }, /* unc_m2p_txr_horz_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4832114 }, /* unc_m2p_txr_horz_occupancy.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2pcie \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4832444 }, /* unc_m2p_txr_horz_starved.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4832856 }, /* unc_m2p_txr_horz_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4833252 }, /* unc_m2p_txr_horz_starved.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4833616 }, /* unc_m2p_txr_horz_starved.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4834016 }, /* unc_m2p_txr_horz_starved.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4834428 }, /* unc_m2p_txr_horz_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4834824 }, /* unc_m2p_txr_horz_starved.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4835188 }, /* unc_m2p_txr_vert_ads_used.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4835464 }, /* unc_m2p_txr_vert_ads_used.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4835741 }, /* unc_m2p_txr_vert_ads_used.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4836017 }, /* unc_m2p_txr_vert_ads_used.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4836294 }, /* unc_m2p_txr_vert_bypass.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4836560 }, /* unc_m2p_txr_vert_bypass.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4836827 }, /* unc_m2p_txr_vert_bypass.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837093 }, /* unc_m2p_txr_vert_bypass.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837360 }, /* unc_m2p_txr_vert_bypass.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837626 }, /* unc_m2p_txr_vert_bypass.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837893 }, /* unc_m2p_txr_vert_bypass.iv_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838159 }, /* unc_m2p_txr_vert_bypass_1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838430 }, /* unc_m2p_txr_vert_bypass_1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838701 }, /* unc_m2p_txr_vert_cycles_full0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4839203 }, /* unc_m2p_txr_vert_cycles_full0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4839674 }, /* unc_m2p_txr_vert_cycles_full0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4840158 }, /* unc_m2p_txr_vert_cycles_full0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4840583 }, /* unc_m2p_txr_vert_cycles_full0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4841083 }, /* unc_m2p_txr_vert_cycles_full0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4841577 }, /* unc_m2p_txr_vert_cycles_full0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4842049 }, /* unc_m2p_txr_vert_cycles_full1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4842554 }, /* unc_m2p_txr_vert_cycles_full1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4843041 }, /* unc_m2p_txr_vert_cycles_ne0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4843552 }, /* unc_m2p_txr_vert_cycles_ne0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4844032 }, /* unc_m2p_txr_vert_cycles_ne0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4844525 }, /* unc_m2p_txr_vert_cycles_ne0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4844959 }, /* unc_m2p_txr_vert_cycles_ne0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4845468 }, /* unc_m2p_txr_vert_cycles_ne0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4845971 }, /* unc_m2p_txr_vert_cycles_ne0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4846452 }, /* unc_m2p_txr_vert_cycles_ne1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4846966 }, /* unc_m2p_txr_vert_cycles_ne1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4847462 }, /* unc_m2p_txr_vert_inserts0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4847931 }, /* unc_m2p_txr_vert_inserts0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4848369 }, /* unc_m2p_txr_vert_inserts0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4848820 }, /* unc_m2p_txr_vert_inserts0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4849212 }, /* unc_m2p_txr_vert_inserts0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4849679 }, /* unc_m2p_txr_vert_inserts0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4850140 }, /* unc_m2p_txr_vert_inserts0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4850579 }, /* unc_m2p_txr_vert_inserts1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4851051 }, /* unc_m2p_txr_vert_inserts1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4851505 }, /* unc_m2p_txr_vert_nack0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4851754 }, /* unc_m2p_txr_vert_nack0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852004 }, /* unc_m2p_txr_vert_nack0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852253 }, /* unc_m2p_txr_vert_nack0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852503 }, /* unc_m2p_txr_vert_nack0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852752 }, /* unc_m2p_txr_vert_nack0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853002 }, /* unc_m2p_txr_vert_nack0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2pcie \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853231 }, /* unc_m2p_txr_vert_nack1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853483 }, /* unc_m2p_txr_vert_nack1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853735 }, /* unc_m2p_txr_vert_occupancy0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4854209 }, /* unc_m2p_txr_vert_occupancy0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4854652 }, /* unc_m2p_txr_vert_occupancy0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4855108 }, /* unc_m2p_txr_vert_occupancy0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4855505 }, /* unc_m2p_txr_vert_occupancy0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4855977 }, /* unc_m2p_txr_vert_occupancy0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4856443 }, /* unc_m2p_txr_vert_occupancy0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4856887 }, /* unc_m2p_txr_vert_occupancy1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4857364 }, /* unc_m2p_txr_vert_occupancy1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4857823 }, /* unc_m2p_txr_vert_starved0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858195 }, /* unc_m2p_txr_vert_starved0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858568 }, /* unc_m2p_txr_vert_starved0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858940 }, /* unc_m2p_txr_vert_starved0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4859313 }, /* unc_m2p_txr_vert_starved0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4859685 }, /* unc_m2p_txr_vert_starved0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860058 }, /* unc_m2p_txr_vert_starved0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860410 }, /* unc_m2p_txr_vert_starved1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860785 }, /* unc_m2p_txr_vert_starved1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4861160 }, /* unc_m2p_txr_vert_starved1.tgc\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4861531 }, /* unc_m2p_vert_ring_ad_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4862447 }, /* unc_m2p_vert_ring_ad_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4863360 }, /* unc_m2p_vert_ring_ad_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4864272 }, /* unc_m2p_vert_ring_ad_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4865181 }, /* unc_m2p_vert_ring_ak_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4866097 }, /* unc_m2p_vert_ring_ak_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4867010 }, /* unc_m2p_vert_ring_ak_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4867922 }, /* unc_m2p_vert_ring_ak_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4868831 }, /* unc_m2p_vert_ring_akc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4869755 }, /* unc_m2p_vert_ring_akc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4870676 }, /* unc_m2p_vert_ring_akc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4871596 }, /* unc_m2p_vert_ring_akc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4872513 }, /* unc_m2p_vert_ring_bl_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4873427 }, /* unc_m2p_vert_ring_bl_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4874338 }, /* unc_m2p_vert_ring_bl_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4875248 }, /* unc_m2p_vert_ring_bl_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4876155 }, /* unc_m2p_vert_ring_iv_in_use.dn\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Down. Unit: uncore_m2pcie \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4876743 }, /* unc_m2p_vert_ring_iv_in_use.up\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Up. Unit: uncore_m2pcie \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4877327 }, /* unc_m2p_vert_ring_tgc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4878251 }, /* unc_m2p_vert_ring_tgc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4879172 }, /* unc_m2p_vert_ring_tgc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4880092 }, /* unc_m2p_vert_ring_tgc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5374991 }, /* unc_m_act_count.all\000uncore_imc\000uncore memory\000DRAM Activate Count : All Activates. Unit: uncore_imc \000event=0x1,umask=0xb\000\00001\000DRAM Activate Count : All Activates : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5375460 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count : Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000DRAM Activate Count : Activate due to Bypass : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5379676 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x3f\000\00001\000Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5381681 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts the total number of DRAM Read CAS commands, w/ and w/o auto-pre, issued on this channel.  This includes underfills\000 */
{ 5382954 }, /* unc_m_cas_count.rd_pre_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre : DRAM RD_CAS and WR_CAS Commands : Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with explicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5383751 }, /* unc_m_cas_count.rd_pre_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5384755 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts the total number of DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.   We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5388088 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM underfill read CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total of DRAM Read CAS commands issued due to an underfill\000 */
{ 5389276 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x30\000\00001\000Counts the total number of DRAM Write CAS commands issued, w/ and w/o auto-pre, on this channel\000 */
{ 5390418 }, /* unc_m_cas_count.wr_nonpre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5390952 }, /* unc_m_cas_count.wr_pre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5394556 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5395549 }, /* unc_m_clockticks_freerun\000uncore_imc_free_running\000uncore memory\000Free running counter that increments for the Memory Controller. Unit: uncore_imc_free_running \000event=0xff,umask=0x10\000\00001\000\000 */
{ 5397214 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x44\000\00001\000DRAM Precharge All Commands : Counts the number of times that the precharge all command was sent\000 */
{ 5397589 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x4\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5397948 }, /* unc_m_dram_refresh.opportunistic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x1\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5398154 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x2\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5399174 }, /* unc_m_hclockticks\000uncore_imc\000uncore memory\000Half clockticks for IMC. Unit: uncore_imc \000event=0xff\000\00001\000\000 */
{ 5403217 }, /* unc_m_parity_errors\000uncore_imc\000uncore memory\000UNC_M_PARITY_ERRORS. Unit: uncore_imc \000event=0x2c\000\00001\000\000 */
{ 5403317 }, /* unc_m_pcls.rd\000uncore_imc\000uncore memory\000UNC_M_PCLS.RD. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5403513 }, /* unc_m_pcls.total\000uncore_imc\000uncore memory\000UNC_M_PCLS.TOTAL. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5403721 }, /* unc_m_pcls.wr\000uncore_imc\000uncore memory\000UNC_M_PCLS.WR. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5404665 }, /* unc_m_pmm_cmd1.all\000uncore_imc\000uncore memory\000PMM Commands : All. Unit: uncore_imc \000event=0xea,umask=0x1\000\00001\000PMM Commands : All : Counts all commands issued to PMM\000 */
{ 5404951 }, /* unc_m_pmm_cmd1.misc\000uncore_imc\000uncore memory\000PMM Commands : Misc Commands (error, flow ACKs). Unit: uncore_imc \000event=0xea,umask=0x80\000\00001\000\000 */
{ 5405195 }, /* unc_m_pmm_cmd1.misc_gnt\000uncore_imc\000uncore memory\000PMM Commands : Misc GNTs. Unit: uncore_imc \000event=0xea,umask=0x40\000\00001\000\000 */
{ 5405315 }, /* unc_m_pmm_cmd1.rd\000uncore_imc\000uncore memory\000PMM Commands : Reads - RPQ. Unit: uncore_imc \000event=0xea,umask=0x2\000\00001\000PMM Commands : Reads - RPQ : Counts read requests issued to the PMM RPQ\000 */
{ 5405686 }, /* unc_m_pmm_cmd1.rpq_gnts\000uncore_imc\000uncore memory\000PMM Commands : RPQ GNTs. Unit: uncore_imc \000event=0xea,umask=0x10\000\00001\000\000 */
{ 5405909 }, /* unc_m_pmm_cmd1.ufill_rd\000uncore_imc\000uncore memory\000PMM Commands : Underfill reads. Unit: uncore_imc \000event=0xea,umask=0x8\000\00001\000PMM Commands : Underfill reads : Counts underfill read commands, due to a partial write, issued to PMM\000 */
{ 5406314 }, /* unc_m_pmm_cmd1.wpq_gnts\000uncore_imc\000uncore memory\000PMM Commands : Underfill GNTs. Unit: uncore_imc \000event=0xea,umask=0x20\000\00001\000\000 */
{ 5406549 }, /* unc_m_pmm_cmd1.wr\000uncore_imc\000uncore memory\000PMM Commands : Writes. Unit: uncore_imc \000event=0xea,umask=0x4\000\00001\000PMM Commands : Writes : Counts write commands issued to PMM\000 */
{ 5407020 }, /* unc_m_pmm_cmd2.nodata_exp\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Expected No data packet (ERID matched NDP encoding). Unit: uncore_imc \000event=0xeb,umask=0x2\000\00001\000\000 */
{ 5407192 }, /* unc_m_pmm_cmd2.nodata_unexp\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Unexpected No data packet (ERID matched a Read, but data was a NDP). Unit: uncore_imc \000event=0xeb,umask=0x4\000\00001\000\000 */
{ 5407660 }, /* unc_m_pmm_cmd2.opp_rd\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Opportunistic Reads. Unit: uncore_imc \000event=0xeb,umask=0x1\000\00001\000\000 */
{ 5407796 }, /* unc_m_pmm_cmd2.pmm_ecc_error\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : ECC Errors. Unit: uncore_imc \000event=0xeb,umask=0x20\000\00001\000\000 */
{ 5408046 }, /* unc_m_pmm_cmd2.pmm_erid_error\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : ERID detectable parity error. Unit: uncore_imc \000event=0xeb,umask=0x40\000\00001\000\000 */
{ 5408334 }, /* unc_m_pmm_cmd2.pmm_erid_starved\000uncore_imc\000uncore memory\000PMM Commands - Part 2. Unit: uncore_imc \000event=0xeb,umask=0x80\000\00001\000\000 */
{ 5408459 }, /* unc_m_pmm_cmd2.reqs_slot0\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Read Requests - Slot 0. Unit: uncore_imc \000event=0xeb,umask=0x8\000\00001\000\000 */
{ 5408721 }, /* unc_m_pmm_cmd2.reqs_slot1\000uncore_imc\000uncore memory\000PMM Commands - Part 2 : Read Requests - Slot 1. Unit: uncore_imc \000event=0xeb,umask=0x10\000\00001\000\000 */
{ 5409880 }, /* unc_m_pmm_rpq_cycles_full\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Full. Unit: uncore_imc \000event=0xe2\000\00001\000\000 */
{ 5409993 }, /* unc_m_pmm_rpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Read Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe1\000\00001\000\000 */
{ 5410292 }, /* unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000PMM Read Queue Inserts. Unit: uncore_imc \000event=0xe3\000\00001\000PMM Read Queue Inserts : Counts number of read requests allocated in the PMM Read Pending Queue.   This includes both ISOCH and non-ISOCH requests\000 */
{ 5410719 }, /* unc_m_pmm_rpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5411655 }, /* unc_m_pmm_rpq_occupancy.gnt_wait\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5412375 }, /* unc_m_pmm_rpq_occupancy.no_gnt\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x2\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5413017 }, /* unc_m_pmm_wpq_cycles_full\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Full. Unit: uncore_imc \000event=0xe6\000\00001\000\000 */
{ 5413258 }, /* unc_m_pmm_wpq_cycles_ne\000uncore_imc\000uncore memory\000PMM Write Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe5\000\00001\000\000 */
{ 5413375 }, /* unc_m_pmm_wpq_flush\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_FLUSH. Unit: uncore_imc \000event=0xe8\000\00001\000\000 */
{ 5413475 }, /* unc_m_pmm_wpq_flush_cyc\000uncore_imc\000uncore memory\000UNC_M_PMM_WPQ_FLUSH_CYC. Unit: uncore_imc \000event=0xe9\000\00001\000\000 */
{ 5413770 }, /* unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000PMM Write Queue Inserts. Unit: uncore_imc \000event=0xe7\000\00001\000PMM Write Queue Inserts : Counts number of  write requests allocated in the PMM Write Pending Queue\000 */
{ 5414151 }, /* unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000 */
{ 5415682 }, /* unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000 */
{ 5416295 }, /* unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x4\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000 */
{ 5416934 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5418958 }, /* unc_m_power_cke_cycles.low_0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x1\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5419790 }, /* unc_m_power_cke_cycles.low_1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x2\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5420622 }, /* unc_m_power_cke_cycles.low_2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x4\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5421454 }, /* unc_m_power_cke_cycles.low_3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x8\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5428666 }, /* unc_m_power_crit_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5429254 }, /* unc_m_power_crit_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5430287 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5436769 }, /* unc_m_power_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5437352 }, /* unc_m_power_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5437822 }, /* unc_m_pre_count.all\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x2,umask=0x1c\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5439100 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to page miss. Unit: uncore_imc \000event=0x2,umask=0xc\000\00001\000DRAM Precharge commands. : Precharge due to page miss : Counts the number of DRAM Precharge commands sent on this channel. : Pages Misses are due to precharges from bank scheduler (rd/wr requests)\000 */
{ 5440906 }, /* unc_m_pre_count.pgt\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to page table. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000DRAM Precharge commands. : Precharge due to page table : Counts the number of DRAM Precharge commands sent on this channel. : Precharges from Page Table\000 */
{ 5441916 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000 */
{ 5444306 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000 */
{ 5501292 }, /* unc_m_rdb_full\000uncore_imc\000uncore memory\000Read Data Buffer Full. Unit: uncore_imc \000event=0x19\000\00001\000\000 */
{ 5501821 }, /* unc_m_rdb_inserts\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17\000\00001\000\000 */
{ 5502577 }, /* unc_m_rdb_not_empty\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18\000\00001\000\000 */
{ 5502851 }, /* unc_m_rdb_occupancy\000uncore_imc\000uncore memory\000Read Data Buffer Occupancy. Unit: uncore_imc \000event=0x1a\000\00001\000\000 */
{ 5503589 }, /* unc_m_rpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5504258 }, /* unc_m_rpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x15\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5504927 }, /* unc_m_rpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x1\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5505763 }, /* unc_m_rpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x2\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5507389 }, /* unc_m_rpq_inserts.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5507980 }, /* unc_m_rpq_inserts.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5511146 }, /* unc_m_rpq_occupancy_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5511864 }, /* unc_m_rpq_occupancy_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5512582 }, /* unc_m_sb_accesses.accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : Scoreboard Accesses Accepted. Unit: uncore_imc \000event=0xd2,umask=0x5\000\00001\000\000 */
{ 5512844 }, /* unc_m_sb_accesses.fm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Accepts. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00001\000\000 */
{ 5513115 }, /* unc_m_sb_accesses.fm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Rejects. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00001\000\000 */
{ 5513386 }, /* unc_m_sb_accesses.fmrd_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00011\000\000 */
{ 5513510 }, /* unc_m_sb_accesses.fmwr_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00011\000\000 */
{ 5513634 }, /* unc_m_sb_accesses.nm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM read completions. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00001\000\000 */
{ 5513917 }, /* unc_m_sb_accesses.nm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM write completions. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00001\000\000 */
{ 5514202 }, /* unc_m_sb_accesses.nmrd_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00011\000\000 */
{ 5514326 }, /* unc_m_sb_accesses.nmwr_cmps\000uncore_imc\000uncore memory\000This event is deprecated. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00011\000\000 */
{ 5514450 }, /* unc_m_sb_accesses.rd_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Accepts. Unit: uncore_imc \000event=0xd2,umask=0x1\000\00001\000\000 */
{ 5514717 }, /* unc_m_sb_accesses.rd_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Rejects. Unit: uncore_imc \000event=0xd2,umask=0x2\000\00001\000\000 */
{ 5514984 }, /* unc_m_sb_accesses.rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : Scoreboard Accesses Rejected. Unit: uncore_imc \000event=0xd2,umask=0xa\000\00001\000\000 */
{ 5515246 }, /* unc_m_sb_accesses.wr_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM read completions. Unit: uncore_imc \000event=0xd2,umask=0x4\000\00001\000\000 */
{ 5515527 }, /* unc_m_sb_accesses.wr_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM write completions. Unit: uncore_imc \000event=0xd2,umask=0x8\000\00001\000\000 */
{ 5515810 }, /* unc_m_sb_canary.alloc\000uncore_imc\000uncore memory\000: Alloc. Unit: uncore_imc \000event=0xd9,umask=0x1\000\00001\000\000 */
{ 5516008 }, /* unc_m_sb_canary.dealloc\000uncore_imc\000uncore memory\000: Dealloc. Unit: uncore_imc \000event=0xd9,umask=0x2\000\00001\000\000 */
{ 5516214 }, /* unc_m_sb_canary.fm_rd_starved\000uncore_imc\000uncore memory\000: Near Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00001\000\000 */
{ 5516340 }, /* unc_m_sb_canary.fm_tgr_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00001\000\000 */
{ 5516469 }, /* unc_m_sb_canary.fm_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00001\000\000 */
{ 5516714 }, /* unc_m_sb_canary.fmrd_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_RD_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00011\000\000 */
{ 5516889 }, /* unc_m_sb_canary.fmtgrwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_TGR_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00011\000\000 */
{ 5517193 }, /* unc_m_sb_canary.fmwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.FM_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00011\000\000 */
{ 5517368 }, /* unc_m_sb_canary.nm_rd_starved\000uncore_imc\000uncore memory\000: Valid. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00001\000\000 */
{ 5517476 }, /* unc_m_sb_canary.nm_wr_starved\000uncore_imc\000uncore memory\000: Near Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00001\000\000 */
{ 5517723 }, /* unc_m_sb_canary.nmrd_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.NM_RD_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00011\000\000 */
{ 5518020 }, /* unc_m_sb_canary.nmwr_starved\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_CANARY.NM_WR_STARVED. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00011\000\000 */
{ 5518292 }, /* unc_m_sb_canary.vld\000uncore_imc\000uncore memory\000: Reject. Unit: uncore_imc \000event=0xd9,umask=0x4\000\00001\000\000 */
{ 5518487 }, /* unc_m_sb_cycles_full\000uncore_imc\000uncore memory\000Scoreboard Cycles Full. Unit: uncore_imc \000event=0xd1\000\00001\000\000 */
{ 5518591 }, /* unc_m_sb_cycles_ne\000uncore_imc\000uncore memory\000Scoreboard Cycles Not-Empty. Unit: uncore_imc \000event=0xd0\000\00001\000\000 */
{ 5518698 }, /* unc_m_sb_inserts.block_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region reads. Unit: uncore_imc \000event=0xd6,umask=0x10\000\00001\000\000 */
{ 5518973 }, /* unc_m_sb_inserts.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region writes. Unit: uncore_imc \000event=0xd6,umask=0x20\000\00001\000\000 */
{ 5519535 }, /* unc_m_sb_inserts.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem reads. Unit: uncore_imc \000event=0xd6,umask=0x4\000\00001\000\000 */
{ 5519808 }, /* unc_m_sb_inserts.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem writes. Unit: uncore_imc \000event=0xd6,umask=0x8\000\00001\000\000 */
{ 5520083 }, /* unc_m_sb_inserts.rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Reads. Unit: uncore_imc \000event=0xd6,umask=0x1\000\00001\000\000 */
{ 5520318 }, /* unc_m_sb_inserts.wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Writes. Unit: uncore_imc \000event=0xd6,umask=0x2\000\00001\000\000 */
{ 5520555 }, /* unc_m_sb_occupancy.block_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region reads. Unit: uncore_imc \000event=0xd5,umask=0x20\000\00001\000\000 */
{ 5520838 }, /* unc_m_sb_occupancy.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region writes. Unit: uncore_imc \000event=0xd5,umask=0x40\000\00001\000\000 */
{ 5521249 }, /* unc_m_sb_occupancy.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem reads. Unit: uncore_imc \000event=0xd5,umask=0x4\000\00001\000\000 */
{ 5521530 }, /* unc_m_sb_occupancy.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem writes. Unit: uncore_imc \000event=0xd5,umask=0x8\000\00001\000\000 */
{ 5521813 }, /* unc_m_sb_occupancy.rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Reads. Unit: uncore_imc \000event=0xd5,umask=0x1\000\00001\000\000 */
{ 5522178 }, /* unc_m_sb_pref_inserts.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : All. Unit: uncore_imc \000event=0xda,umask=0x1\000\00001\000\000 */
{ 5522308 }, /* unc_m_sb_pref_inserts.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : DDR4. Unit: uncore_imc \000event=0xda,umask=0x2\000\00001\000\000 */
{ 5522569 }, /* unc_m_sb_pref_inserts.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : Persistent Mem. Unit: uncore_imc \000event=0xda,umask=0x4\000\00001\000\000 */
{ 5522710 }, /* unc_m_sb_pref_occupancy.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : All. Unit: uncore_imc \000event=0xdb,umask=0x1\000\00001\000\000 */
{ 5522844 }, /* unc_m_sb_pref_occupancy.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : DDR4. Unit: uncore_imc \000event=0xdb,umask=0x2\000\00001\000\000 */
{ 5522979 }, /* unc_m_sb_pref_occupancy.pmem\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_PREF_OCCUPANCY.PMM. Unit: uncore_imc \000event=0xdb,umask=0x4\000\00011\000\000 */
{ 5523334 }, /* unc_m_sb_pref_occupancy.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : Persistent Mem. Unit: uncore_imc \000event=0xdb,umask=0x4\000\00001\000\000 */
{ 5523479 }, /* unc_m_sb_reject.canary\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x8\000\00001\000\000 */
{ 5523611 }, /* unc_m_sb_reject.ddr_early_cmp\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x20\000\00001\000\000 */
{ 5523751 }, /* unc_m_sb_reject.fm_addr_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : FM requests rejected due to full address conflict. Unit: uncore_imc \000event=0xd4,umask=0x2\000\00001\000\000 */
{ 5524132 }, /* unc_m_sb_reject.nm_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : NM requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x1\000\00001\000\000 */
{ 5524493 }, /* unc_m_sb_reject.patrol_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : Patrol requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x4\000\00001\000\000 */
{ 5524870 }, /* unc_m_sb_strv_alloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00001\000\000 */
{ 5524987 }, /* unc_m_sb_strv_alloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00001\000\000 */
{ 5525109 }, /* unc_m_sb_strv_alloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00001\000\000 */
{ 5525227 }, /* unc_m_sb_strv_alloc.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_RD. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00011\000\000 */
{ 5525632 }, /* unc_m_sb_strv_alloc.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_TGR. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00011\000\000 */
{ 5525801 }, /* unc_m_sb_strv_alloc.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.FM_WR. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00011\000\000 */
{ 5526208 }, /* unc_m_sb_strv_alloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00001\000\000 */
{ 5526326 }, /* unc_m_sb_strv_alloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00001\000\000 */
{ 5526445 }, /* unc_m_sb_strv_alloc.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.NM_RD. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00011\000\000 */
{ 5526852 }, /* unc_m_sb_strv_alloc.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_ALLOC.NM_WR. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00011\000\000 */
{ 5527261 }, /* unc_m_sb_strv_dealloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x2\000\00001\000\000 */
{ 5527380 }, /* unc_m_sb_strv_dealloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xde,umask=0x10\000\00001\000\000 */
{ 5527504 }, /* unc_m_sb_strv_dealloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x8\000\00001\000\000 */
{ 5527624 }, /* unc_m_sb_strv_dealloc.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_RD. Unit: uncore_imc \000event=0xde,umask=0x2\000\00011\000\000 */
{ 5527794 }, /* unc_m_sb_strv_dealloc.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_TGR. Unit: uncore_imc \000event=0xde,umask=0x10\000\00011\000\000 */
{ 5527967 }, /* unc_m_sb_strv_dealloc.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.FM_WR. Unit: uncore_imc \000event=0xde,umask=0x8\000\00011\000\000 */
{ 5528137 }, /* unc_m_sb_strv_dealloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x1\000\00001\000\000 */
{ 5528257 }, /* unc_m_sb_strv_dealloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x4\000\00001\000\000 */
{ 5528378 }, /* unc_m_sb_strv_dealloc.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.NM_RD. Unit: uncore_imc \000event=0xde,umask=0x1\000\00011\000\000 */
{ 5528548 }, /* unc_m_sb_strv_dealloc.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_DEALLOC.NM_WR. Unit: uncore_imc \000event=0xde,umask=0x4\000\00011\000\000 */
{ 5528718 }, /* unc_m_sb_strv_occ.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00001\000\000 */
{ 5528827 }, /* unc_m_sb_strv_occ.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd8,umask=0x10\000\00001\000\000 */
{ 5528947 }, /* unc_m_sb_strv_occ.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00001\000\000 */
{ 5529163 }, /* unc_m_sb_strv_occ.fmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_RD. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00011\000\000 */
{ 5529325 }, /* unc_m_sb_strv_occ.fmtgr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_TGR. Unit: uncore_imc \000event=0xd8,umask=0x10\000\00011\000\000 */
{ 5529597 }, /* unc_m_sb_strv_occ.fmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.FM_WR. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00011\000\000 */
{ 5529759 }, /* unc_m_sb_strv_occ.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00001\000\000 */
{ 5529869 }, /* unc_m_sb_strv_occ.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00001\000\000 */
{ 5530087 }, /* unc_m_sb_strv_occ.nmrd\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.NM_RD. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00011\000\000 */
{ 5530357 }, /* unc_m_sb_strv_occ.nmwr\000uncore_imc\000uncore memory\000This event is deprecated. Refer to new event UNC_M_SB_STRV_OCC.NM_WR. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00011\000\000 */
{ 5530519 }, /* unc_m_sb_tagged.ddr4_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.DDR4_CMP. Unit: uncore_imc \000event=0xdd,umask=0x8\000\00001\000\000 */
{ 5530639 }, /* unc_m_sb_tagged.new\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.NEW. Unit: uncore_imc \000event=0xdd,umask=0x1\000\00001\000\000 */
{ 5530749 }, /* unc_m_sb_tagged.occ\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.OCC. Unit: uncore_imc \000event=0xdd,umask=0x80\000\00001\000\000 */
{ 5530860 }, /* unc_m_sb_tagged.pmm0_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM0_CMP. Unit: uncore_imc \000event=0xdd,umask=0x10\000\00001\000\000 */
{ 5530981 }, /* unc_m_sb_tagged.pmm1_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM1_CMP. Unit: uncore_imc \000event=0xdd,umask=0x20\000\00001\000\000 */
{ 5531102 }, /* unc_m_sb_tagged.pmm2_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM2_CMP. Unit: uncore_imc \000event=0xdd,umask=0x40\000\00001\000\000 */
{ 5531223 }, /* unc_m_sb_tagged.rd_hit\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_HIT. Unit: uncore_imc \000event=0xdd,umask=0x2\000\00001\000\000 */
{ 5531339 }, /* unc_m_sb_tagged.rd_miss\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_MISS. Unit: uncore_imc \000event=0xdd,umask=0x4\000\00001\000\000 */
{ 5531457 }, /* unc_m_tagchk.hit\000uncore_imc\000uncore memory\0002LM Tag Check : Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000\000 */
{ 5531870 }, /* unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\0002LM Tag Check : Miss, no data in this line. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000\000 */
{ 5532316 }, /* unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\0002LM Tag Check : Miss, existing data may be evicted to Far Memory. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000\000 */
{ 5532799 }, /* unc_m_tagchk.nm_rd_hit\000uncore_imc\000uncore memory\0002LM Tag Check : Read Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x8\000\00001\000\000 */
{ 5533068 }, /* unc_m_tagchk.nm_wr_hit\000uncore_imc\000uncore memory\0002LM Tag Check : Write Hit in Near Memory Cache. Unit: uncore_imc \000event=0xd3,umask=0x10\000\00001\000\000 */
{ 5535905 }, /* unc_m_wpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5536401 }, /* unc_m_wpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x16\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5536897 }, /* unc_m_wpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x1\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5537871 }, /* unc_m_wpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x2\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5541626 }, /* unc_m_wpq_inserts.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5542390 }, /* unc_m_wpq_inserts.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5548167 }, /* unc_m_wpq_occupancy_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x82\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5549641 }, /* unc_m_wpq_occupancy_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x83\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5551115 }, /* unc_m_wpq_read_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5551801 }, /* unc_m_wpq_read_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5553803 }, /* unc_m_wpq_write_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5554490 }, /* unc_m_wpq_write_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5641037 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000Clockticks of the power control unit (PCU). Unit: uncore_pcu \000event=0\000\00001\000Clockticks of the power control unit (PCU) : The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5650924 }, /* unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000 */
{ 5656346 }, /* unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000 */
{ 5663972 }, /* unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Phase Shed 0 Cycles : Cycles spent in phase-shedding power state 0\000 */
{ 5664290 }, /* unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Phase Shed 1 Cycles : Cycles spent in phase-shedding power state 1\000 */
{ 5664608 }, /* unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Phase Shed 2 Cycles : Cycles spent in phase-shedding power state 2\000 */
{ 5664926 }, /* unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Phase Shed 3 Cycles : Cycles spent in phase-shedding power state 3\000 */
{ 5667556 }, /* unc_p_freq_clip_avx256\000uncore_pcu\000uncore power\000AVX256 Frequency Clipping. Unit: uncore_pcu \000event=0x49\000\00001\000\000 */
{ 5667664 }, /* unc_p_freq_clip_avx512\000uncore_pcu\000uncore power\000AVX512 Frequency Clipping. Unit: uncore_pcu \000event=0x4a\000\00001\000\000 */
{ 5668479 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Thermal Strongest Upper Limit Cycles : Number of cycles any frequency is reduced due to a thermal limit.  Count only if throttling is occurring\000 */
{ 5669130 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Power Strongest Upper Limit Cycles : Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670854 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000IO P Limit Strongest Lower Limit Cycles : Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673412 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Cycles spent changing Frequency : Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5674248 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Memory Phase Shedding Cycles : Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5676034 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Package C State Residency - C0 : Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677059 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Package C State Residency - C2E : Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677753 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Package C State Residency - C3 : Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678442 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Package C State Residency - C6 : Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679127 }, /* unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000 */
{ 5679355 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State : C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C0 and C1 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5680610 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State : C3. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C3 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681844 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State : C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C6 and C7 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684699 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000External Prochot : Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685335 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Internal Prochot : Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5686051 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Total Core C State Transition Cycles : Number of cycles spent performing core C state transitions across all cores\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 791106 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793108 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 798859 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data load to a 1G page\000event=0x8,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802110 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x8,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805386 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x8,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 808161 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x8,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813152 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815445 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 820481 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 823499 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 826601 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 830031 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x49,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1082642 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085650 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1097779 }, /* itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x85,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__icelakex[] = {
{ 3686 }, /* \000C1_Core_Residency\000Power\000cstate_core@c1\\-residency@ / TSC\000\000C1 residency percent per core\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 12911 }, /* \000dtlb_2nd_level_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 13408 }, /* \000dtlb_2nd_level_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 13834 }, /* \000dtlb_2nd_level_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 17634 }, /* \000io_bandwidth_write\000\000(UNC_CHA_TOR_INSERTS.IO_HIT_ITOM + UNC_CHA_TOR_INSERTS.IO_MISS_ITOM + UNC_CHA_TOR_INSERTS.IO_HIT_ITOMCACHENEAR + UNC_CHA_TOR_INSERTS.IO_MISS_ITOMCACHENEAR) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19058 }, /* \000itlb_2nd_level_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 19568 }, /* \000itlb_2nd_level_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23125 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25514 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25947 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 27418 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_CRD + UNC_CHA_TOR_INSERTS.IA_MISS_CRD_PREF) / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 33273 }, /* \000llc_demand_data_read_miss_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 33606 }, /* \000llc_demand_data_read_miss_latency_for_local_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 34002 }, /* \000llc_demand_data_read_miss_latency_for_remote_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 34774 }, /* \000llc_demand_data_read_miss_to_pmem_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to Intel(R) Optane(TM) Persistent Memory(PMEM) in nano seconds\000\0001ns\000\000\000\00000 */
{ 35184 }, /* \000llc_miss_local_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35388 }, /* \000llc_miss_local_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35595 }, /* \000llc_miss_remote_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 35802 }, /* \000llc_miss_remote_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 36012 }, /* \000loads_per_instr\000\000MEM_INST_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39732 }, /* \000memory_extra_write_bw_due_to_directory_updates\000\000(UNC_CHA_DIR_UPDATE.HA + UNC_CHA_DIR_UPDATE.TOR + UNC_M2M_DIRECTORY_UPDATE.ANY) * 64 / 1e6 / duration_time\000\000Memory write bandwidth (MB/sec) caused by directory updates; includes DDR and Intel(R) Optane(TM) Persistent Memory(PMEM)\000\0001MB/s\000\000\000\00000 */
{ 40404 }, /* \000numa_reads_addressed_to_local_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 41615 }, /* \000numa_reads_addressed_to_remote_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43154 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43654 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44654 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 45098 }, /* \000pmem_memory_bandwidth_read\000\000UNC_M_PMM_RPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45264 }, /* \000pmem_memory_bandwidth_total\000\000(UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS) * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45452 }, /* \000pmem_memory_bandwidth_write\000\000UNC_M_PMM_WPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49006 }, /* \000stores_per_instr\000\000MEM_INST_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 50452 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5 + UOPS_DISPATCHED.PORT_6) / (4 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 53706 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * ASSISTS.ANY / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 59207 }, /* \000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 5 * cpu@INT_MISC.RECOVERY_CYCLES\\,cmask\\=1\\,edge@ / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 64724 }, /* \000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 68110 }, /* \000tma_branch_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * BR_INST_RETIRED.ALL_BRANCHES / (tma_retiring * tma_info_thread_slots)\000tma_branch_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions\000\000100%\000\000\000\00000 */
{ 69335 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 83652 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 43.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98081 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000 */
{ 107711 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043.5 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 114219 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 121545 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound - tma_pmm_bound if #has_pmem > 0 else CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound)\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124667 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 134887 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 139263 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 148497 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00048 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 153696 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 158121 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 163606 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000(5 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE - INT_MISC.UOP_DROPPING) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 172771 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 177787 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180064 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 182343 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 184622 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 186270 }, /* \000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 192366 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer + tma_retiring * (UOPS_DECODED.DEC0 - cpu@UOPS_DECODED.DEC0\\,cmask\\=1@) / IDQ.MITE_UOPS\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 195231 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_16B.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197105 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 198371 }, /* \000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198640 }, /* \000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198902 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199501 }, /* \000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199999 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000tma_info_core_ipmispredict\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 201191 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 202880 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 204415 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 209301 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 213573 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216037 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216577 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 217012 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000 */
{ 217249 }, /* \000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000 */
{ 217937 }, /* \000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219831 }, /* \000tma_info_core_flopc\000Flops;Ret\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 222547 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 224428 }, /* \000tma_info_core_ipmispredict\000Bad;BadSpec;BrMispredicts;TopdownL1;tma_L1_group\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000TopdownL1\000\00000 */
{ 226105 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 5 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 227202 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227819 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232323 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239974 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242664 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 11\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245107 }, /* \000tma_info_memory_core_l2_evictions_nonsilent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.NON_SILENT / tma_info_inst_mix_instructions\000\000Rate of non silent evictions from the L2 cache per Kilo instruction\000\000\000\000\000\00000 */
{ 245315 }, /* \000tma_info_memory_core_l2_evictions_silent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.SILENT / tma_info_inst_mix_instructions\000\000Rate of silent evictions from the L2 cache per Kilo instruction where the evicted lines are dropped (no writeback to L3 or memory)\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247858 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * (OFFCORE_REQUESTS.ALL_DATA_RD - OFFCORE_REQUESTS.DEMAND_DATA_RD + L2_RQSTS.ALL_DEMAND_MISS + L2_RQSTS.SWPF_MISS) / tma_info_inst_mix_instructions\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251156 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251574 }, /* \000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,umask\\=0x10@ / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 254261 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256405 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258309 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 262284 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 263119 }, /* \000tma_info_system_io_read_bw\000IoBW;Mem;Server;SoC\000(UNC_CHA_TOR_INSERTS.IO_HIT_ITOM + UNC_CHA_TOR_INSERTS.IO_MISS_ITOM + UNC_CHA_TOR_INSERTS.IO_HIT_ITOMCACHENEAR + UNC_CHA_TOR_INSERTS.IO_MISS_ITOMCACHENEAR) * 64 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Reads [GB / sec]\000\000\000\000\000\00000 */
{ 264048 }, /* \000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000UNC_CHA_TOR_INSERTS.IO_PCIRDCUR * 64 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 265046 }, /* \000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / cha_0@event\\=0x0@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 267104 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 268041 }, /* \000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / cha_0@event\\=0x0@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 270073 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271515 }, /* \000tma_info_system_pmm_read_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_RPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for reads [GB / sec]\000\000\000\000\000\00000 */
{ 271706 }, /* \000tma_info_system_pmm_write_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_WPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 272373 }, /* \000tma_info_system_power_license0_utilization\000Power\000CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 273292 }, /* \000tma_info_system_power_license1_utilization\000Power\000CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274252 }, /* \000tma_info_system_power_license2_utilization\000Power\000CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274904 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275354 }, /* \000tma_info_system_socket_clks\000SoC\000cha_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277349 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277503 }, /* \000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000 */
{ 277851 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278166 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 7.5\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 291636 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + L1D_PEND_MISS.FB_FULL_PERIODS) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 300765 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00019 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 314141 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317952 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3 / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 318802 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 322011 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00043.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000 */
{ 325792 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 329816 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 342540 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000 */
{ 348825 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001 */
{ 352279 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 357790 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 359354 }, /* \000tma_mite_4wide\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_mite_group\000(cpu@IDQ.MITE_UOPS\\,cmask\\=4@ - cpu@IDQ.MITE_UOPS\\,cmask\\=5@) / tma_info_thread_clks\000tma_mite_4wide > 0.05 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where (only) 4 uops were delivered by the MITE pipeline\000\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 366608 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369076 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_branch_instructions + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 371650 }, /* \000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00000 */
{ 377934 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 380965 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 385354 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 388354 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 392550 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 402317 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 408697 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 416142 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 419352 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 426210 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(97 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 97 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00000 */
{ 427277 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000108 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000 */
{ 432289 }, /* \000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 436702 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 438256 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00037 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000 */
{ 440531 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 446331 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000L1D_PEND_MISS.L2_STALL / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 451466 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 455967 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 457909 }, /* \000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 458764 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\00010 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
{ 465493 }, /* \000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
{ 465803 }, /* \000upi_data_transmit_bw\000\000UNC_UPI_TxL_FLITS.ALL_DATA * 7.111111111111111 / 1e6 / duration_time\000\000Intel(R) Ultra Path Interconnect (UPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__ivybridge[] = {
{ 1101353 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts the number of lines brought into the L1 data cache\000 */
{ 1105009 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers inavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles a demand request was blocked due to Fill Buffers inavailability\000 */
{ 1108731 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss oustandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113216 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with L1D load Misses outstanding from any thread on physical core\000 */
{ 1125021 }, /* l2_l1d_wb_rqsts.all\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in any state\000event=0x28,period=200003,umask=0xf\000\00000\000\000 */
{ 1125152 }, /* l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000Not rejected writebacks from L1D to L2 cache lines in E state\000 */
{ 1125475 }, /* l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000Not rejected writebacks from L1D to L2 cache lines in M state\000 */
{ 1125929 }, /* l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000Not rejected writebacks that missed LLC\000 */
{ 1128882 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000L2 cache lines filling L2\000 */
{ 1129766 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000L2 cache lines in E state filling L2\000 */
{ 1130314 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000L2 cache lines in I state filling L2\000 */
{ 1130762 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000L2 cache lines in S state filling L2\000 */
{ 1131651 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000Clean L2 cache lines evicted by demand\000 */
{ 1132285 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000Dirty L2 cache lines evicted by demand\000 */
{ 1132816 }, /* l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000Dirty L2 cache lines filling the L2\000 */
{ 1135089 }, /* l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000Clean L2 cache lines evicted by the MLC prefetcher\000 */
{ 1135365 }, /* l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000Dirty L2 cache lines evicted by the MLC prefetcher\000 */
{ 1157003 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 code requests\000 */
{ 1158253 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2\000 */
{ 1161096 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000Counts all L2 HW prefetcher requests\000 */
{ 1161863 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000Counts all L2 store RFO requests\000 */
{ 1162963 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000Number of instruction fetches that hit the L2 cache\000 */
{ 1163940 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000Number of instruction fetches that missed the L2 cache\000 */
{ 1165120 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000Demand Data Read requests that hit L2 cache\000 */
{ 1171158 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000 */
{ 1171715 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000 */
{ 1173832 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000RFO requests that hit L2 cache\000 */
{ 1175144 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000 */
{ 1178567 }, /* l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000RFOs that access cache lines in any state\000 */
{ 1178944 }, /* l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000RFOs that hit cache lines in M state\000 */
{ 1179200 }, /* l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000RFOs that miss cache lines\000 */
{ 1179774 }, /* l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or LLC HW prefetch accessing L2, including rejects\000 */
{ 1180242 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000Transactions accessing L2 pipe\000 */
{ 1180474 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000L2 cache accesses when fetching instructions\000 */
{ 1180921 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand Data Read requests that access L2 cache\000 */
{ 1181568 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000L1D writebacks that access L2 cache\000 */
{ 1181956 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000L2 fill requests that access L2 cache\000 */
{ 1182496 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000L2 writebacks that access L2 cache\000 */
{ 1183040 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000RFO requests that access L2 cache\000 */
{ 1245510 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000Cycles in which the L1D is locked\000 */
{ 1247819 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000 */
{ 1251579 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000 */
{ 1346677 }, /* mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000 */
{ 1348121 }, /* mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000 */
{ 1349678 }, /* mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1350289 }, /* mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1350995 }, /* mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Retired load uops which data sources missed LLC but serviced from local dram\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load uops whose data source was local memory (cross-socket snoop not needed or missed)\000 */
{ 1354625 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357660 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1359330 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops which data sources following L1 data-cache miss (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000\000 */
{ 1360709 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1362601 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Retired load uops with L2 cache misses as data sources (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000\000 */
{ 1364932 }, /* mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000\000 */
{ 1365699 }, /* mem_load_uops_retired.llc_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1389167 }, /* mem_uops_retired.all_loads\000\000cache\000All retired load uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000\000 */
{ 1391786 }, /* mem_uops_retired.all_stores\000\000cache\000All retired store uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000\000 */
{ 1416283 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access. (Precise Event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1419081 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000 */
{ 1420860 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000 */
{ 1422472 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423549 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745197 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Data read requests sent to uncore (demand and prefetch)\000 */
{ 1748863 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncachaeble code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000 */
{ 1750273 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore\000 */
{ 1751349 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Demand RFO read requests sent to uncore, including regular RFOs, locks, ItoM\000 */
{ 1753018 }, /* offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Cases when offcore requests buffer cannot take more entries for core\000 */
{ 1756855 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1759834 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000 */
{ 1762279 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000 */
{ 1763845 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000 */
{ 1767278 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000 */
{ 1771703 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand Code Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1774624 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding Demand Data Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1776129 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000 */
{ 1777442 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1781637 }, /* offcore_response.all_code_rd.llc_hit.any_response\000\000cache\000Counts all demand & prefetch code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0244\000\00000\000\000 */
{ 1782363 }, /* offcore_response.all_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0244\000\00000\000\000 */
{ 1784697 }, /* offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000105B3\000\00000\000\000 */
{ 1804724 }, /* offcore_response.all_data_rd.llc_hit.any_response\000\000cache\000Counts all demand & prefetch data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0091\000\00000\000\000 */
{ 1805176 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0091\000\00000\000\000 */
{ 1805720 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0091\000\00000\000\000 */
{ 1805994 }, /* offcore_response.all_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0091\000\00000\000\000 */
{ 1866683 }, /* offcore_response.all_reads.any_response\000\000cache\000Counts all data/code/rfo references (demand & prefetch)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000107F7\000\00000\000\000 */
{ 1889947 }, /* offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010122\000\00000\000\000 */
{ 1909149 }, /* offcore_response.all_rfo.llc_hit.any_response\000\000cache\000Counts all demand & prefetch RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0122\000\00000\000\000 */
{ 1910369 }, /* offcore_response.all_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0122\000\00000\000\000 */
{ 1999322 }, /* offcore_response.corewb.any_response\000\000cache\000Counts all writebacks from the core to the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 2025769 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010004\000\00000\000\000 */
{ 2062524 }, /* offcore_response.demand_code_rd.llc_hit.any_response\000\000cache\000Counts all demand code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0004\000\00000\000\000 */
{ 2063754 }, /* offcore_response.demand_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0004\000\00000\000\000 */
{ 2079519 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts all demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010001\000\00000\000\000 */
{ 2116118 }, /* offcore_response.demand_data_rd.llc_hit.any_response\000\000cache\000Counts all demand data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0001\000\00000\000\000 */
{ 2116550 }, /* offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0001\000\00000\000\000 */
{ 2117074 }, /* offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0001\000\00000\000\000 */
{ 2117340 }, /* offcore_response.demand_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0001\000\00000\000\000 */
{ 2138060 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand rfo's\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010002\000\00000\000\000 */
{ 2175220 }, /* offcore_response.demand_rfo.llc_hit.any_response\000\000cache\000Counts all demand data writes (RFOs) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0002\000\00000\000\000 */
{ 2176200 }, /* offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0002\000\00000\000\000 */
{ 2176470 }, /* offcore_response.demand_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0002\000\00000\000\000 */
{ 2195890 }, /* offcore_response.other.any_response\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses. It also includes L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 2446094 }, /* offcore_response.split_lock_uc_lock.any_response\000\000cache\000Counts requests where the address of an atomic lock instruction spans a cache line boundary or the lock instruction is executed on uncacheable address\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 2447058 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts non-temporal stores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 902045 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Cycles with any input/output SSE* or FP assists\000 */
{ 903110 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000Number of SIMD FP assists due to input values\000 */
{ 903734 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000Number of SIMD FP assists due to output values\000 */
{ 904406 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000Number of X87 FP assists due to input values\000 */
{ 904994 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000Number of X87 FP assists due to output values\000 */
{ 906200 }, /* fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000 */
{ 906653 }, /* fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000 */
{ 907106 }, /* fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000Counts number of SSE* or AVX-128 double precision FP scalar uops executed\000 */
{ 907543 }, /* fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000 */
{ 908949 }, /* fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULsand IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000Counts number of X87 uops executed\000 */
{ 1433783 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000 */
{ 1434178 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000 */
{ 2462623 }, /* other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000Number of assists associated with 256-bit AVX store operations\000 */
{ 2463621 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 2464364 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable\000event=0xc1,period=100003,umask=0x20\000\00000\000\000 */
{ 2523673 }, /* simd_fp_256.packed_double\000\000floating point\000number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000Counts 256-bit packed double-precision floating-point instructions\000 */
{ 2524056 }, /* simd_fp_256.packed_single\000\000floating point\000number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000Counts 256-bit packed single-precision floating-point instructions\000 */
{ 476800 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000Number of front end re-steers due to BPU misprediction\000 */
{ 781344 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000Number of DSB to MITE switches\000 */
{ 784002 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Cycles DSB to MITE switches caused delay\000 */
{ 786479 }, /* dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000DSB Fill encountered > 3 DSB lines\000 */
{ 986197 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000 */
{ 988304 }, /* icache.ifetch_stall\000\000frontend\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000 */
{ 989948 }, /* icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes UC accesses\000 */
{ 998281 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered four uops. Set Cmask = 4\000 */
{ 999346 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered at least one uops. Set Cmask = 1\000 */
{ 1000024 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered four uops. Set Cmask = 4\000 */
{ 1001263 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uops. Set Cmask = 1\000 */
{ 1002689 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000 */
{ 1006574 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Increment each cycle. # of uops delivered to IDQ from DSB path. Set Cmask = 1 to count cycles\000 */
{ 1007764 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty\000 */
{ 1008434 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000Number of uops delivered to IDQ from any path\000 */
{ 1009430 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000 */
{ 1012620 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Increment each cycle # of uops delivered to IDQ from MITE path. Set Cmask = 1 to count cycles\000 */
{ 1016423 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000 */
{ 1019228 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000 */
{ 1020559 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequenser (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequenser (MS) is busy\000 */
{ 1021882 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000 */
{ 1023418 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000 */
{ 1023696 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1027031 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequenser (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Increment each cycle # of uops delivered to IDQ from MS by either DSB or MITE. Set Cmask = 1 to count cycles\000 */
{ 1031644 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Count issue pipeline slots where no uop was delivered from the front end to the back end when there is no back-end stall\000 */
{ 1035047 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039076 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1295713 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000\000 */
{ 1369507 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Loads with latency value being above 128 (Must be precise)\000 */
{ 1371453 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Loads with latency value being above 16 (Must be precise)\000 */
{ 1373393 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Loads with latency value being above 256 (Must be precise)\000 */
{ 1375340 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Loads with latency value being above 32 (Must be precise)\000 */
{ 1377432 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Loads with latency value being above 4 (Must be precise)\000 */
{ 1379211 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Loads with latency value being above 512 (Must be precise)\000 */
{ 1381156 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Loads with latency value being above 64 (Must be precise)\000 */
{ 1383085 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Loads with latency value being above 8 (Must be precise)\000 */
{ 1384539 }, /* mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000 */
{ 1428398 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000Speculative cache-line split load uops dispatched to L1D\000 */
{ 1430375 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split Store-address uops dispatched to L1D\000 */
{ 1783265 }, /* offcore_response.all_code_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400244\000\00000\000\000 */
{ 1807120 }, /* offcore_response.all_data_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400091\000\00000\000\000 */
{ 1884101 }, /* offcore_response.all_reads.llc_miss.dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3004003f7\000\00000\000\000 */
{ 2025077 }, /* offcore_response.data_in_socket.llc_miss.local_dram\000\000memory\000Counts LLC replacements\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004001b3\000\00000\000\000 */
{ 2064624 }, /* offcore_response.demand_code_rd.llc_miss.dram\000\000memory\000Counts demand code reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400004\000\00000\000\000 */
{ 2119770 }, /* offcore_response.demand_data_rd.llc_miss.dram\000\000memory\000Counts demand data reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400001\000\00000\000\000 */
{ 2476239 }, /* page_walks.llc_miss\000\000memory\000Number of any page walk that had a miss in LLC\000event=0xbe,period=100003,umask=0x1\000\00000\000\000 */
{ 581329 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000Unhalted core cycles when the thread is in ring 0\000 */
{ 581763 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000Number of intervals between processor halts while thread is in ring 0\000 */
{ 582577 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000Unhalted core cycles when the thread is not in ring 0\000 */
{ 1245992 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000Cycles in which the L1D and L2 are locked, due to a UC lock or split lock\000 */
{ 469914 }, /* arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x4\000\00000\000Divide operations executed\000 */
{ 470046 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000Cycles that the divider is active, includes INT and FP. Set 'edge =1, cmask=1' to count the number of divides\000 */
{ 487693 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 488171 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000Speculative and retired macro-conditional branches\000 */
{ 488718 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000Speculative and retired macro-unconditional branches excluding calls and indirects\000 */
{ 489423 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000Speculative and retired direct near calls\000 */
{ 489929 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000Speculative and retired indirect branches excluding calls and returns\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 491857 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000Not taken macro-conditional branches\000 */
{ 492526 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000Taken speculative and retired macro-conditional branches\000 */
{ 493084 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000 */
{ 493844 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000Taken speculative and retired direct near calls\000 */
{ 494361 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000Taken speculative and retired indirect branches excluding calls and returns\000 */
{ 495056 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000Taken speculative and retired indirect calls\000 */
{ 495608 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000Taken speculative and retired indirect branches with return mnemonic\000 */
{ 496446 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000Branch instructions at retirement\000 */
{ 499640 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 505985 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000 */
{ 508615 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000Number of far branches retired\000 */
{ 515672 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 516989 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 518283 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000 */
{ 519723 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000 */
{ 522269 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts the number of not taken branch instructions retired\000 */
{ 528685 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 529266 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000Speculative and retired mispredicted macro conditional branches\000 */
{ 530018 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000Mispredicted indirect branches excluding calls and returns\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 531808 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000Not taken speculative and retired mispredicted macro conditional branches\000 */
{ 532677 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000Taken speculative and retired mispredicted macro conditional branches\000 */
{ 533448 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000 */
{ 534200 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000Taken speculative and retired mispredicted indirect calls\000 */
{ 534551 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000 */
{ 536772 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Mispredicted branch instructions at retirement\000 */
{ 541568 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000 */
{ 546808 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 556324 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 607176 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 608123 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000 */
{ 609363 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 618365 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 632010 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 638913 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000 */
{ 640120 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 643233 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000 */
{ 646093 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000 */
{ 647330 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 649413 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 749439 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 cache miss loads. Set AnyThread to count per core\000 */
{ 750447 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss load* is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 751258 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set AnyThread to count per core\000 */
{ 752515 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set AnyThread to count per core\000 */
{ 753182 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 754270 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Total execution stalls\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755301 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls due to L1 data cache misses\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Execution stalls due to L1 data cache miss loads. Set Cmask=0CH\000 */
{ 756116 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss load* is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 756987 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2\000 */
{ 758325 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759049 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 1040675 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000Stall cycles due to IQ is full\000 */
{ 1042873 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000\000 */
{ 1049742 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1054717 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement\000 */
{ 1060286 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000 */
{ 1069883 }, /* int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071754 }, /* int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1194796 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1195738 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000Loads blocked by overlapping with store buffer that cannot be forwarded\000 */
{ 1202712 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000False dependencies in MOB due to partial compare on address\000 */
{ 1229109 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for H/W prefetch\000 */
{ 1230225 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for S/W prefetch\000 */
{ 1283604 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000 */
{ 1284194 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1292920 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Counts the number of executed AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000 */
{ 1301641 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Number of self-modifying-code machine clears detected\000 */
{ 1433006 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000 */
{ 1433396 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000 */
{ 2462471 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x80\000\00000\000\000 */
{ 2501504 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles Allocation is stalled due to Resource Related reason\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2504874 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Cycles stalled due to no store buffers available (not including draining form sync)\000 */
{ 2507281 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000Count cases of saving new LBR records by hardware\000 */
{ 2511149 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Cycles the RS is empty for the thread\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6183709 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a Uop is dispatched on port 0\000 */
{ 6184659 }, /* uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000Cycles per core when uops are dispatched to port 0\000 */
{ 6184991 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a Uop is dispatched on port 1\000 */
{ 6185941 }, /* uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000Cycles per core when uops are dispatched to port 1\000 */
{ 6186273 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000Cycles which a Uop is dispatched on port 2\000 */
{ 6187400 }, /* uops_dispatched_port.port_2_core\000\000pipeline\000Uops dispatched to port 2, loads and stores per core (speculative and retired)\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187569 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000Cycles which a Uop is dispatched on port 3\000 */
{ 6188545 }, /* uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000Cycles per core when load or STA uops are dispatched to port 3\000 */
{ 6188915 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a Uop is dispatched on port 4\000 */
{ 6189870 }, /* uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000Cycles per core when uops are dispatched to port 4\000 */
{ 6190204 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a Uop is dispatched on port 5\000 */
{ 6191159 }, /* uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000Cycles per core when uops are dispatched to port 5\000 */
{ 6193165 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle\000 */
{ 6194393 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195494 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles at least 2 micro-op is executed from any thread on physical core\000 */
{ 6196597 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Cycles at least 3 micro-op is executed from any thread on physical core\000 */
{ 6197700 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Cycles at least 4 micro-op is executed from any thread on physical core\000 */
{ 6198712 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000Cycles with no micro-ops executed from any thread on physical core\000 */
{ 6200712 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201775 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202848 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203792 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205896 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6206950 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Counts total number of uops to be executed per-thread each cycle. Set Cmask = 1, INV =1 to count stall cycles\000 */
{ 6214313 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Increments each cycle the # of Uops issued by the RAT to RS. Set Cmask = 1, Inv = 1, Any= 1to count stalled cycles of this core\000 */
{ 6216160 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000 */
{ 6217450 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops adds delay\000 */
{ 6217712 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000Number of multiply packed/scalar single precision uops allocated\000 */
{ 6218054 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000 */
{ 6219867 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000 */
{ 6227452 }, /* uops_retired.all\000\000pipeline\000Retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6228028 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6234993 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240056 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 2784864 }, /* unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000\000 */
{ 2785265 }, /* unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000\000 */
{ 2785660 }, /* unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000\000 */
{ 2786064 }, /* unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000\000 */
{ 2786235 }, /* unc_cbo_cache_lookup.extsnp_es\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x46\000\00001\000\000 */
{ 2786420 }, /* unc_cbo_cache_lookup.extsnp_i\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x48\000\00001\000\000 */
{ 2786599 }, /* unc_cbo_cache_lookup.extsnp_m\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000\000 */
{ 2786778 }, /* unc_cbo_cache_lookup.extsnp_mesi\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x4f\000\00001\000\000 */
{ 2787207 }, /* unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000\000 */
{ 2787613 }, /* unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000\000 */
{ 2788013 }, /* unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000\000 */
{ 2788430 }, /* unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000\000 */
{ 2788854 }, /* unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000\000 */
{ 2789029 }, /* unc_cbo_cache_lookup.write_i\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x28\000\00001\000\000 */
{ 2789434 }, /* unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000\000 */
{ 2789848 }, /* unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000\000 */
{ 2790023 }, /* unc_cbo_xsnp_response.hit_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x84\000\00001\000\000 */
{ 2790229 }, /* unc_cbo_xsnp_response.hit_external\000uncore_cbox\000uncore cache\000An external snoop hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x24\000\00001\000\000 */
{ 2790402 }, /* unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000 */
{ 2790639 }, /* unc_cbo_xsnp_response.hitm_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x88\000\00001\000\000 */
{ 2790842 }, /* unc_cbo_xsnp_response.hitm_external\000uncore_cbox\000uncore cache\000An external snoop hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x28\000\00001\000\000 */
{ 2791012 }, /* unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000 */
{ 2791246 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000 */
{ 2791698 }, /* unc_cbo_xsnp_response.miss_external\000uncore_cbox\000uncore cache\000An external snoop misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x21\000\00001\000\000 */
{ 2791854 }, /* unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000 */
{ 2581513 }, /* unc_arb_coh_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Cycles weighted by number of requests pending in Coherency Tracker. Unit: uncore_arb \000event=0x83,umask=0x1\000\00001\000\000 */
{ 2582567 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of requests allocated in Coherency Tracker. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2585257 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Counts cycles weighted by the number of requests waiting for data returning from the memory controller. Accounts for coherent and non-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2587134 }, /* unc_arb_trk_occupancy.cycles_over_half_full\000uncore_arb\000uncore interconnect\000Cycles with at least half of the requests outstanding are waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=10,umask=0x1\000\00001\000\000 */
{ 2587471 }, /* unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000 */
{ 2589625 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Counts the number of coherent and in-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591061 }, /* unc_arb_trk_requests.evictions\000uncore_arb\000uncore interconnect\000Counts the number of LLC evictions allocated. Unit: uncore_arb \000event=0x81,umask=0x80\000\00001\000\000 */
{ 2591683 }, /* unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Counts the number of allocated write entries, include full, partial, and LLC evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000 */
{ 3540250 }, /* unc_clock.socket\000uncore_arb\000uncore interconnect\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_arb \000event=0xff\000\00001\000\000 */
{ 787480 }, /* dtlb_load_misses.large_page_walk_completed\000\000virtual memory\000Page walk for a large page completed for Demand load\000event=0x8,period=100003,umask=0x88\000\00000\000\000 */
{ 787758 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes an page walk of any page size\000event=0x8,period=100003,umask=0x81\000\00000\000Misses in all TLB levels that cause a page walk of any page size from demand loads\000 */
{ 789915 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x5f,period=100003,umask=0x4\000\00000\000Counts load operations that missed 1st level DTLB but hit the 2nd level\000 */
{ 794873 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0x82\000\00000\000Misses in all TLB levels that caused page walk completed of any size by demand loads\000 */
{ 806932 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Demand load cycles page miss handler (PMH) is busy with this walk\000event=0x8,period=2000003,umask=0x84\000\00000\000Cycle PMH is busy with a walk due to demand loads\000 */
{ 810986 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Miss in all TLB levels causes a page walk of any page size (4K/2M/4M/1G)\000 */
{ 812051 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000 */
{ 817084 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000Miss in all TLB levels causes a page walk that completes of any page size (4K/2M/4M/1G)\000 */
{ 828731 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000Cycles PMH is busy with this walk\000 */
{ 832947 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1078052 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000 */
{ 1079859 }, /* itlb_misses.large_page_walk_completed\000\000virtual memory\000Completed page walks in ITLB due to STLB load misses for large pages\000event=0x85,period=100003,umask=0x80\000\00000\000Completed page walks in ITLB due to STLB load misses for large pages\000 */
{ 1081396 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in all ITLB levels that cause page walks\000 */
{ 1083030 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000Number of cache load STLB hits. No page walk\000 */
{ 1087648 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000Misses in all ITLB levels that cause completed page walks\000 */
{ 1096296 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000Cycle PMH is busy with a walk\000 */
{ 2540513 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000 */
{ 2541163 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Count number of STLB flush attempts\000 */
};

static const struct compact_pmu_event pmu_metrics__ivybridge[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51887 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5) / (3 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 94435 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) + 43 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 106581 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 120903 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 129662 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 138383 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 151736 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00060 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 155428 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 171419 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 174786 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194894 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFETCH_STALL / tma_info_thread_clks - tma_itlb_misses\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219516 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 224070 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 230525 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\0001 / (tma_fp_scalar + tma_fp_vector)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248902 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.LLC_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 253557 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257611 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 261800 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267776 }, /* \000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000 */
{ 271339 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 281284 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(12 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 287936 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) - CYCLE_ACTIVITY.STALLS_L1D_PENDING) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 290473 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_PENDING - CYCLE_ACTIVITY.STALLS_L2_PENDING) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 297708 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 303915 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00029 * (MEM_LOAD_UOPS_RETIRED.LLC_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_RETIRED.LLC_MISS))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317465 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 335504 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 346683 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379797 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382600 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 387139 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 398843 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 401522 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 405006 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 411919 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418342 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 440028 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 463482 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__ivytown[] = {
{ 1101353 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts the number of lines brought into the L1 data cache\000 */
{ 1105009 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers inavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles a demand request was blocked due to Fill Buffers inavailability\000 */
{ 1108948 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Increments the number of outstanding L1D misses every cycle. Set Cmask = 1 and Edge =1 to count occurrences\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113216 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with L1D load Misses outstanding from any thread on physical core\000 */
{ 1125021 }, /* l2_l1d_wb_rqsts.all\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in any state\000event=0x28,period=200003,umask=0xf\000\00000\000\000 */
{ 1125152 }, /* l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000Not rejected writebacks from L1D to L2 cache lines in E state\000 */
{ 1125475 }, /* l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000Not rejected writebacks from L1D to L2 cache lines in M state\000 */
{ 1125929 }, /* l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000Not rejected writebacks that missed LLC\000 */
{ 1128882 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000L2 cache lines filling L2\000 */
{ 1129766 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000L2 cache lines in E state filling L2\000 */
{ 1130314 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000L2 cache lines in I state filling L2\000 */
{ 1130762 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000L2 cache lines in S state filling L2\000 */
{ 1131651 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000Clean L2 cache lines evicted by demand\000 */
{ 1132285 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000Dirty L2 cache lines evicted by demand\000 */
{ 1132816 }, /* l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000Dirty L2 cache lines filling the L2\000 */
{ 1135089 }, /* l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000Clean L2 cache lines evicted by the MLC prefetcher\000 */
{ 1135365 }, /* l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000Dirty L2 cache lines evicted by the MLC prefetcher\000 */
{ 1157003 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000Counts all L2 code requests\000 */
{ 1158253 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000Counts any demand and L1 HW prefetch data load requests to L2\000 */
{ 1161096 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000Counts all L2 HW prefetcher requests\000 */
{ 1161863 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000Counts all L2 store RFO requests\000 */
{ 1162963 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000Number of instruction fetches that hit the L2 cache\000 */
{ 1163940 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000Number of instruction fetches that missed the L2 cache\000 */
{ 1165120 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000Demand Data Read requests that hit L2 cache\000 */
{ 1171158 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000Counts all L2 HW prefetcher requests that hit L2\000 */
{ 1171715 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000Counts all L2 HW prefetcher requests that missed L2\000 */
{ 1173832 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000RFO requests that hit L2 cache\000 */
{ 1175144 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000Counts the number of store RFO requests that miss the L2 cache\000 */
{ 1178567 }, /* l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000RFOs that access cache lines in any state\000 */
{ 1178944 }, /* l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000RFOs that hit cache lines in M state\000 */
{ 1179200 }, /* l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000RFOs that miss cache lines\000 */
{ 1179774 }, /* l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000Any MLC or LLC HW prefetch accessing L2, including rejects\000 */
{ 1180242 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000Transactions accessing L2 pipe\000 */
{ 1180474 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000L2 cache accesses when fetching instructions\000 */
{ 1180921 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000Demand Data Read requests that access L2 cache\000 */
{ 1181568 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000L1D writebacks that access L2 cache\000 */
{ 1181956 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000L2 fill requests that access L2 cache\000 */
{ 1182496 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000L2 writebacks that access L2 cache\000 */
{ 1183040 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000RFO requests that access L2 cache\000 */
{ 1245510 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000Cycles in which the L1D is locked\000 */
{ 1247819 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000This event counts each cache miss condition for references to the last level cache\000 */
{ 1251579 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000This event counts requests originating from the core that reference a cache line in the last level cache\000 */
{ 1346677 }, /* mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000\000 */
{ 1348121 }, /* mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000\000 */
{ 1349678 }, /* mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1350289 }, /* mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1351255 }, /* mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Retired load uops whose data source was local DRAM (Snoop not needed, Snoop Miss, or Snoop Hit data not forwarded)\000event=0xd3,period=100007,umask=0x3\000\00000\000\000 */
{ 1351616 }, /* mem_load_uops_llc_miss_retired.remote_dram\000\000cache\000Retired load uops whose data source was remote DRAM (Snoop not needed, Snoop Miss, or Snoop Hit data not forwarded)\000event=0xd3,period=100007,umask=0xc\000\00000\000\000 */
{ 1351822 }, /* mem_load_uops_llc_miss_retired.remote_fwd\000\000cache\000Data forwarded from remote cache\000event=0xd3,period=100007,umask=0x20\000\00000\000\000 */
{ 1351945 }, /* mem_load_uops_llc_miss_retired.remote_hitm\000\000cache\000Remote cache HITM\000event=0xd3,period=100007,umask=0x10\000\00000\000\000 */
{ 1354625 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357660 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1359330 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Retired load uops which data sources following L1 data-cache miss (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000\000 */
{ 1360709 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1362601 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Retired load uops with L2 cache misses as data sources (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000\000 */
{ 1364932 }, /* mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000\000 */
{ 1365699 }, /* mem_load_uops_retired.llc_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1389167 }, /* mem_uops_retired.all_loads\000\000cache\000All retired load uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000\000 */
{ 1391786 }, /* mem_uops_retired.all_stores\000\000cache\000All retired store uops. (Precise Event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000\000 */
{ 1416283 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access. (Precise Event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1419081 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x41\000\00000\000\000 */
{ 1420860 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary. (Precise Event)\000event=0xd0,period=100003,umask=0x42\000\00000\000\000 */
{ 1422472 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423549 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB. (Precise Event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745197 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Data read requests sent to uncore (demand and prefetch)\000 */
{ 1749028 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Demand code read requests sent to uncore\000 */
{ 1750273 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Demand data read requests sent to uncore\000 */
{ 1751349 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Demand RFO read requests sent to uncore, including regular RFOs, locks, ItoM\000 */
{ 1753018 }, /* offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Cases when offcore requests buffer cannot take more entries for core\000 */
{ 1756855 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Offcore outstanding cacheable data read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1759834 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000 */
{ 1762279 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000 */
{ 1763845 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000 */
{ 1767278 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000 */
{ 1771703 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding code reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Offcore outstanding Demand Code Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1774624 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Offcore outstanding Demand Data Read transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1776129 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000 */
{ 1777442 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000Offcore outstanding RFO store transactions in SQ to uncore. Set Cmask=1 to count cycles\000 */
{ 1805176 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0091\000\00000\000\000 */
{ 1805720 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0091\000\00000\000\000 */
{ 1805994 }, /* offcore_response.all_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0091\000\00000\000\000 */
{ 1806301 }, /* offcore_response.all_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0091\000\00000\000\000 */
{ 1838310 }, /* offcore_response.all_pf_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch data reads that hit the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0090\000\00000\000\000 */
{ 1838483 }, /* offcore_response.all_pf_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0090\000\00000\000\000 */
{ 1838749 }, /* offcore_response.all_pf_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0090\000\00000\000\000 */
{ 1839017 }, /* offcore_response.all_pf_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0090\000\00000\000\000 */
{ 1839318 }, /* offcore_response.all_pf_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0090\000\00000\000\000 */
{ 1880720 }, /* offcore_response.all_reads.llc_hit.any_response\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c03f7\000\00000\000\000 */
{ 1881190 }, /* offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c03f7\000\00000\000\000 */
{ 1882037 }, /* offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c03f7\000\00000\000\000 */
{ 1882607 }, /* offcore_response.all_reads.llc_hit.no_snoop_needed\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c03f7\000\00000\000\000 */
{ 1883243 }, /* offcore_response.all_reads.llc_hit.snoop_miss\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c03f7\000\00000\000\000 */
{ 1999322 }, /* offcore_response.corewb.any_response\000\000cache\000Counts all writebacks from the core to the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 2062524 }, /* offcore_response.demand_code_rd.llc_hit.any_response\000\000cache\000Counts all demand code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0004\000\00000\000\000 */
{ 2116118 }, /* offcore_response.demand_data_rd.llc_hit.any_response\000\000cache\000Counts all demand data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0001\000\00000\000\000 */
{ 2116550 }, /* offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0001\000\00000\000\000 */
{ 2117074 }, /* offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0001\000\00000\000\000 */
{ 2117340 }, /* offcore_response.demand_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0001\000\00000\000\000 */
{ 2117639 }, /* offcore_response.demand_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0001\000\00000\000\000 */
{ 2176200 }, /* offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0002\000\00000\000\000 */
{ 2220710 }, /* offcore_response.other.lru_hints\000\000cache\000Counts L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803c8000\000\00000\000\000 */
{ 2221884 }, /* offcore_response.other.portio_mmio_uc\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23ffc08000\000\00000\000\000 */
{ 2297503 }, /* offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0040\000\00000\000\000 */
{ 2327830 }, /* offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0010\000\00000\000\000 */
{ 2328025 }, /* offcore_response.pf_l2_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0010\000\00000\000\000 */
{ 2328314 }, /* offcore_response.pf_l2_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0010\000\00000\000\000 */
{ 2328605 }, /* offcore_response.pf_l2_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0010\000\00000\000\000 */
{ 2328929 }, /* offcore_response.pf_l2_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0010\000\00000\000\000 */
{ 2423713 }, /* offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0200\000\00000\000\000 */
{ 2426342 }, /* offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0080\000\00000\000\000 */
{ 2426544 }, /* offcore_response.pf_llc_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0080\000\00000\000\000 */
{ 2426840 }, /* offcore_response.pf_llc_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0080\000\00000\000\000 */
{ 2427138 }, /* offcore_response.pf_llc_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0080\000\00000\000\000 */
{ 2427469 }, /* offcore_response.pf_llc_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0080\000\00000\000\000 */
{ 2446094 }, /* offcore_response.split_lock_uc_lock.any_response\000\000cache\000Counts requests where the address of an atomic lock instruction spans a cache line boundary or the lock instruction is executed on uncacheable address\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 2447058 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts non-temporal stores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 902045 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Cycles with any input/output SSE* or FP assists\000 */
{ 903110 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000Number of SIMD FP assists due to input values\000 */
{ 903734 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000Number of SIMD FP assists due to output values\000 */
{ 904406 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000Number of X87 FP assists due to input values\000 */
{ 904994 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000Number of X87 FP assists due to output values\000 */
{ 906200 }, /* fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000 */
{ 906653 }, /* fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000 */
{ 907106 }, /* fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000Counts number of SSE* or AVX-128 double precision FP scalar uops executed\000 */
{ 907543 }, /* fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000 */
{ 908247 }, /* fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULs and IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000Counts number of X87 uops executed\000 */
{ 1433783 }, /* move_elimination.simd_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x2\000\00000\000\000 */
{ 1434178 }, /* move_elimination.simd_not_eliminated\000\000floating point\000Number of SIMD Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x8\000\00000\000\000 */
{ 2462623 }, /* other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000Number of assists associated with 256-bit AVX store operations\000 */
{ 2463621 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 2464364 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable\000event=0xc1,period=100003,umask=0x20\000\00000\000\000 */
{ 2523673 }, /* simd_fp_256.packed_double\000\000floating point\000number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000Counts 256-bit packed double-precision floating-point instructions\000 */
{ 2524056 }, /* simd_fp_256.packed_single\000\000floating point\000number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000Counts 256-bit packed single-precision floating-point instructions\000 */
{ 476800 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000Number of front end re-steers due to BPU misprediction\000 */
{ 781344 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000Number of DSB to MITE switches\000 */
{ 784002 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Cycles DSB to MITE switches caused delay\000 */
{ 786479 }, /* dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000DSB Fill encountered > 3 DSB lines\000 */
{ 986197 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000 */
{ 988304 }, /* icache.ifetch_stall\000\000frontend\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code-fetch stalled due to L1 instruction-cache miss or an iTLB miss\000 */
{ 989948 }, /* icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes UC accesses\000 */
{ 998281 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered four uops. Set Cmask = 4\000 */
{ 999346 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts cycles DSB is delivered at least one uops. Set Cmask = 1\000 */
{ 1000024 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered four uops. Set Cmask = 4\000 */
{ 1001263 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts cycles MITE is delivered at least one uops. Set Cmask = 1\000 */
{ 1002689 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000 */
{ 1006574 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Increment each cycle. # of uops delivered to IDQ from DSB path. Set Cmask = 1 to count cycles\000 */
{ 1007764 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000Counts cycles the IDQ is empty\000 */
{ 1008434 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000Number of uops delivered to IDQ from any path\000 */
{ 1009430 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000 */
{ 1012620 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Increment each cycle # of uops delivered to IDQ from MITE path. Set Cmask = 1 to count cycles\000 */
{ 1014085 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000 */
{ 1018168 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000 */
{ 1019605 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000 */
{ 1020890 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by DSB. Set Cmask = 1 to count cycles. Add Edge=1 to count # of delivery\000 */
{ 1022589 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Increment each cycle # of uops delivered to IDQ when MS_busy by MITE. Set Cmask = 1 to count cycles\000 */
{ 1023696 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025795 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Increment each cycle # of uops delivered to IDQ from MS by either DSB or MITE. Set Cmask = 1 to count cycles\000 */
{ 1031644 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Count issue pipeline slots where no uop was delivered from the front end to the back end when there is no back-end stall\000 */
{ 1035047 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039076 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1295713 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000\000 */
{ 1369507 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Loads with latency value being above 128 (Must be precise)\000 */
{ 1371453 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Loads with latency value being above 16 (Must be precise)\000 */
{ 1373393 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Loads with latency value being above 256 (Must be precise)\000 */
{ 1375340 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Loads with latency value being above 32 (Must be precise)\000 */
{ 1377432 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4 (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Loads with latency value being above 4 (Must be precise)\000 */
{ 1379211 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Loads with latency value being above 512 (Must be precise)\000 */
{ 1381156 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Loads with latency value being above 64 (Must be precise)\000 */
{ 1383085 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Loads with latency value being above 8 (Must be precise)\000 */
{ 1384539 }, /* mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000 */
{ 1428398 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000Speculative cache-line split load uops dispatched to L1D\000 */
{ 1430375 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000Speculative cache-line split Store-address uops dispatched to L1D\000 */
{ 1783083 }, /* offcore_response.all_code_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch code reads that miss the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc00244\000\00000\000\000 */
{ 1783899 }, /* offcore_response.all_code_rd.llc_miss.remote_dram\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800244\000\00000\000\000 */
{ 1784119 }, /* offcore_response.all_code_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f800244\000\00000\000\000 */
{ 1806938 }, /* offcore_response.all_data_rd.llc_miss.any_response\000\000memory\000Counts all demand & prefetch data reads that hits the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20091\000\00000\000\000 */
{ 1883911 }, /* offcore_response.all_reads.llc_miss.any_response\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that hit the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc203f7\000\00000\000\000 */
{ 1884762 }, /* offcore_response.all_reads.llc_miss.local_dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004003f7\000\00000\000\000 */
{ 1885935 }, /* offcore_response.all_reads.llc_miss.remote_hit_forward\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f8203f7\000\00000\000\000 */
{ 1886412 }, /* offcore_response.all_reads.llc_miss.remote_hitm\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc003f7\000\00000\000\000 */
{ 2064450 }, /* offcore_response.demand_code_rd.llc_miss.any_response\000\000memory\000Counts all demand code reads that miss the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20004\000\00000\000\000 */
{ 2065023 }, /* offcore_response.demand_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400004\000\00000\000\000 */
{ 2065233 }, /* offcore_response.demand_code_rd.llc_miss.remote_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800004\000\00000\000\000 */
{ 2065445 }, /* offcore_response.demand_code_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand code reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820004\000\00000\000\000 */
{ 2065666 }, /* offcore_response.demand_code_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand code reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00004\000\00000\000\000 */
{ 2119217 }, /* offcore_response.demand_data_rd.llc_miss.any_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00001\000\00000\000\000 */
{ 2119597 }, /* offcore_response.demand_data_rd.llc_miss.any_response\000\000memory\000Counts demand data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20001\000\00000\000\000 */
{ 2120165 }, /* offcore_response.demand_data_rd.llc_miss.local_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400001\000\00000\000\000 */
{ 2120371 }, /* offcore_response.demand_data_rd.llc_miss.remote_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800001\000\00000\000\000 */
{ 2120579 }, /* offcore_response.demand_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts demand data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820001\000\00000\000\000 */
{ 2120796 }, /* offcore_response.demand_data_rd.llc_miss.remote_hitm\000\000memory\000Counts demand data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00001\000\00000\000\000 */
{ 2179095 }, /* offcore_response.demand_rfo.llc_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) that miss the LLC and the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc20002\000\00000\000\000 */
{ 2299056 }, /* offcore_response.pf_l2_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) code reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20040\000\00000\000\000 */
{ 2329180 }, /* offcore_response.pf_l2_data_rd.llc_miss.any_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00010\000\00000\000\000 */
{ 2329610 }, /* offcore_response.pf_l2_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20010\000\00000\000\000 */
{ 2330026 }, /* offcore_response.pf_l2_data_rd.llc_miss.local_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400010\000\00000\000\000 */
{ 2330257 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads  that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800010\000\00000\000\000 */
{ 2330491 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820010\000\00000\000\000 */
{ 2330733 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00010\000\00000\000\000 */
{ 2425298 }, /* offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20200\000\00000\000\000 */
{ 2428193 }, /* offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20080\000\00000\000\000 */
{ 581329 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000Unhalted core cycles when the thread is in ring 0\000 */
{ 581763 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000Number of intervals between processor halts while thread is in ring 0\000 */
{ 582577 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000Unhalted core cycles when the thread is not in ring 0\000 */
{ 1245992 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000Cycles in which the L1D and L2 are locked, due to a UC lock or split lock\000 */
{ 469914 }, /* arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x4\000\00000\000Divide operations executed\000 */
{ 470046 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000Cycles that the divider is active, includes INT and FP. Set 'edge =1, cmask=1' to count the number of divides\000 */
{ 487693 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 488171 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000Speculative and retired macro-conditional branches\000 */
{ 488718 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000Speculative and retired macro-unconditional branches excluding calls and indirects\000 */
{ 489423 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000Speculative and retired direct near calls\000 */
{ 489929 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000Speculative and retired indirect branches excluding calls and returns\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 491857 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000Not taken macro-conditional branches\000 */
{ 492526 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000Taken speculative and retired macro-conditional branches\000 */
{ 493084 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000 */
{ 493844 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000Taken speculative and retired direct near calls\000 */
{ 494361 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000Taken speculative and retired indirect branches excluding calls and returns\000 */
{ 495056 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000Taken speculative and retired indirect calls\000 */
{ 495608 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000Taken speculative and retired indirect branches with return mnemonic\000 */
{ 496446 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000Branch instructions at retirement\000 */
{ 499640 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 505985 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000 */
{ 508615 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000Number of far branches retired\000 */
{ 515672 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 516989 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 518283 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000 */
{ 519723 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000 */
{ 522269 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts the number of not taken branch instructions retired\000 */
{ 528685 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000Counts all near executed branches (not necessarily retired)\000 */
{ 529266 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000Speculative and retired mispredicted macro conditional branches\000 */
{ 530018 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000Mispredicted indirect branches excluding calls and returns\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 531808 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000Not taken speculative and retired mispredicted macro conditional branches\000 */
{ 532677 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000Taken speculative and retired mispredicted macro conditional branches\000 */
{ 533448 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000 */
{ 534200 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000Taken speculative and retired mispredicted indirect calls\000 */
{ 534551 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000 */
{ 536772 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Mispredicted branch instructions at retirement\000 */
{ 541568 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000 */
{ 546808 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 556324 }, /* br_misp_retired.near_taken\000\000pipeline\000number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 607176 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 608123 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Increments at the frequency of XCLK (100 MHz) when not halted\000 */
{ 609363 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 618365 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 632010 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 638913 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000Reference cycles when the thread is unhalted. (counts at 100 MHz rate)\000 */
{ 640120 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted. (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 643233 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000 */
{ 646093 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000 */
{ 647330 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling\000 */
{ 649413 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000Core cycles when at least one thread on the physical core is not in halt state\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 749439 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Cycles with pending L1 cache miss loads\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000Cycles with pending L1 cache miss loads. Set AnyThread to count per core\000 */
{ 750447 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss load* is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 751258 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Cycles with pending L2 cache miss loads\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with pending L2 miss loads. Set AnyThread to count per core\000 */
{ 752515 }, /* cycle_activity.cycles_ldm_pending\000\000pipeline\000Cycles with pending memory loads\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles with pending memory loads. Set AnyThread to count per core\000 */
{ 753182 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 754270 }, /* cycle_activity.cycles_no_execute\000\000pipeline\000This event increments by 1 for every cycle where there was no execute for this thread\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000Total execution stalls\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755301 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Execution stalls due to L1 data cache misses\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000Execution stalls due to L1 data cache miss loads. Set Cmask=0CH\000 */
{ 756116 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss load* is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 756987 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Execution stalls due to L2 cache misses\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000Number of loads missed L2\000 */
{ 758325 }, /* cycle_activity.stalls_ldm_pending\000\000pipeline\000Execution stalls due to memory subsystem\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759049 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 1040675 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000Stall cycles due to IQ is full\000 */
{ 1042873 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000\000 */
{ 1049742 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1054717 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000Number of instructions at retirement\000 */
{ 1060286 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution (Must be precise)\000 */
{ 1069883 }, /* int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071754 }, /* int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc.)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1194796 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1195738 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000Loads blocked by overlapping with store buffer that cannot be forwarded\000 */
{ 1202712 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000False dependencies in MOB due to partial compare on address\000 */
{ 1229109 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for H/W prefetch\000 */
{ 1230225 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Non-SW-prefetch load dispatches that hit fill buffer allocated for S/W prefetch\000 */
{ 1283604 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000 */
{ 1284194 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1292920 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Counts the number of executed AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000 */
{ 1301641 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Number of self-modifying-code machine clears detected\000 */
{ 1433006 }, /* move_elimination.int_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were eliminated\000event=0x58,period=1000003,umask=0x1\000\00000\000\000 */
{ 1433396 }, /* move_elimination.int_not_eliminated\000\000pipeline\000Number of integer Move Elimination candidate uops that were not eliminated\000event=0x58,period=1000003,umask=0x4\000\00000\000\000 */
{ 2462471 }, /* other_assists.any_wb_assist\000\000pipeline\000Number of times any microcode assist is invoked by HW upon uop writeback\000event=0xc1,period=100003,umask=0x80\000\00000\000\000 */
{ 2501504 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Cycles Allocation is stalled due to Resource Related reason\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2504874 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Cycles stalled due to no store buffers available (not including draining form sync)\000 */
{ 2507281 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000Count cases of saving new LBR records by hardware\000 */
{ 2511149 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Cycles the RS is empty for the thread\000 */
{ 2512825 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=200003,umask=0x1\000\00000\000\000 */
{ 6183709 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Cycles which a Uop is dispatched on port 0\000 */
{ 6184659 }, /* uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000Cycles per core when uops are dispatched to port 0\000 */
{ 6184991 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Cycles which a Uop is dispatched on port 1\000 */
{ 6185941 }, /* uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000Cycles per core when uops are dispatched to port 1\000 */
{ 6186273 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000Cycles which a Uop is dispatched on port 2\000 */
{ 6187400 }, /* uops_dispatched_port.port_2_core\000\000pipeline\000Uops dispatched to port 2, loads and stores per core (speculative and retired)\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187569 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000Cycles which a Uop is dispatched on port 3\000 */
{ 6188545 }, /* uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000Cycles per core when load or STA uops are dispatched to port 3\000 */
{ 6188915 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000Cycles which a Uop is dispatched on port 4\000 */
{ 6189870 }, /* uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000Cycles per core when uops are dispatched to port 4\000 */
{ 6190204 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000Cycles which a Uop is dispatched on port 5\000 */
{ 6191159 }, /* uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000Cycles per core when uops are dispatched to port 5\000 */
{ 6193165 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts total number of uops to be executed per-core each cycle\000 */
{ 6194393 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Cycles at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195494 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Cycles at least 2 micro-op is executed from any thread on physical core\000 */
{ 6196597 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Cycles at least 3 micro-op is executed from any thread on physical core\000 */
{ 6197700 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Cycles at least 4 micro-op is executed from any thread on physical core\000 */
{ 6198712 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000Cycles with no micro-ops executed from any thread on physical core\000 */
{ 6200712 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201775 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202848 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203792 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205896 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6206950 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Counts total number of uops to be executed per-thread each cycle. Set Cmask = 1, INV =1 to count stall cycles\000 */
{ 6214313 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Increments each cycle the # of Uops issued by the RAT to RS. Set Cmask = 1, Inv = 1, Any= 1to count stalled cycles of this core\000 */
{ 6216160 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000 */
{ 6217450 }, /* uops_issued.flags_merge\000\000pipeline\000Number of flags-merge uops being allocated\000event=0xe,period=2000003,umask=0x10\000\00000\000Number of flags-merge uops allocated. Such uops adds delay\000 */
{ 6217712 }, /* uops_issued.single_mul\000\000pipeline\000Number of Multiply packed/scalar single precision uops allocated\000event=0xe,period=2000003,umask=0x40\000\00000\000Number of multiply packed/scalar single precision uops allocated\000 */
{ 6218054 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000Number of slow LEA or similar uops allocated. Such uop has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000 */
{ 6219867 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000 */
{ 6227452 }, /* uops_retired.all\000\000pipeline\000Retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6228028 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6234993 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240056 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 2592164 }, /* unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000 */
{ 2592390 }, /* unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2594135 }, /* unc_c_llc_lookup.any\000uncore_cbox\000uncore cache\000Cache Lookups; Any Request. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2595690 }, /* unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Read transactions\000 */
{ 2597832 }, /* unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; Lookups that Match NID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2600762 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2602897 }, /* unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:17] bits correspond to [M'FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2605021 }, /* unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606246 }, /* unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cbox \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607153 }, /* unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607378 }, /* unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in.; Qualify one of the other subevents by the Target NID.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.   In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2608272 }, /* unc_c_llc_victims.s_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2609265 }, /* unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo.; Number of times that an RFO hit in S state.  This is useful for determining if it might be good for a workload to use RspIWB instead of RspSWB\000 */
{ 2609694 }, /* unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2610173 }, /* unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610303 }, /* unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2610806 }, /* unc_c_qlru.age0\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 0. Unit: uncore_cbox \000event=0x3c,umask=0x1\000\00001\000How often age was set to 0\000 */
{ 2610940 }, /* unc_c_qlru.age1\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 1. Unit: uncore_cbox \000event=0x3c,umask=0x2\000\00001\000How often age was set to 1\000 */
{ 2611074 }, /* unc_c_qlru.age2\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 2. Unit: uncore_cbox \000event=0x3c,umask=0x4\000\00001\000How often age was set to 2\000 */
{ 2611208 }, /* unc_c_qlru.age3\000uncore_cbox\000uncore cache\000LRU Queue; LRU Age 3. Unit: uncore_cbox \000event=0x3c,umask=0x8\000\00001\000How often age was set to 3\000 */
{ 2611342 }, /* unc_c_qlru.lru_decrement\000uncore_cbox\000uncore cache\000LRU Queue; LRU Bits Decremented. Unit: uncore_cbox \000event=0x3c,umask=0x10\000\00001\000How often all LRU bits were decremented by 1\000 */
{ 2611515 }, /* unc_c_qlru.victim_non_zero\000uncore_cbox\000uncore cache\000LRU Queue; Non-0 Aged Victim. Unit: uncore_cbox \000event=0x3c,umask=0x20\000\00001\000How often we picked a victim that had a non-zero age\000 */
{ 2613369 }, /* unc_c_ring_ad_used.ccw\000uncore_cbox\000uncore cache\000AD Ring In Use; Counterclockwise. Unit: uncore_cbox \000event=0x1b,umask=0xc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2615057 }, /* unc_c_ring_ad_used.cw\000uncore_cbox\000uncore cache\000AD Ring In Use; Clockwise. Unit: uncore_cbox \000event=0x1b,umask=0x3\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2618411 }, /* unc_c_ring_ad_used.down\000uncore_cbox\000uncore cache\000AD Ring In Use; Down. Unit: uncore_cbox \000event=0x1b,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2624553 }, /* unc_c_ring_ad_used.down_vr0_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000 */
{ 2625485 }, /* unc_c_ring_ad_used.down_vr0_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000 */
{ 2626414 }, /* unc_c_ring_ad_used.down_vr1_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000 */
{ 2627347 }, /* unc_c_ring_ad_used.down_vr1_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000 */
{ 2628277 }, /* unc_c_ring_ad_used.up\000uncore_cbox\000uncore cache\000AD Ring In Use; Up. Unit: uncore_cbox \000event=0x1b,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2636053 }, /* unc_c_ring_ad_used.up_vr0_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000 */
{ 2636979 }, /* unc_c_ring_ad_used.up_vr0_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000 */
{ 2637902 }, /* unc_c_ring_ad_used.up_vr1_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000 */
{ 2638829 }, /* unc_c_ring_ad_used.up_vr1_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1b,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000 */
{ 2641423 }, /* unc_c_ring_ak_used.ccw\000uncore_cbox\000uncore cache\000AK Ring In Use; Counterclockwise. Unit: uncore_cbox \000event=0x1c,umask=0xc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2643107 }, /* unc_c_ring_ak_used.cw\000uncore_cbox\000uncore cache\000AK Ring In Use; Clockwise. Unit: uncore_cbox \000event=0x1c,umask=0x3\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2645617 }, /* unc_c_ring_ak_used.down\000uncore_cbox\000uncore cache\000AK Ring In Use; Down. Unit: uncore_cbox \000event=0x1c,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2651745 }, /* unc_c_ring_ak_used.down_vr0_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000 */
{ 2652675 }, /* unc_c_ring_ak_used.down_vr0_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000 */
{ 2653602 }, /* unc_c_ring_ak_used.down_vr1_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000 */
{ 2654533 }, /* unc_c_ring_ak_used.down_vr1_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000 */
{ 2655461 }, /* unc_c_ring_ak_used.up\000uncore_cbox\000uncore cache\000AK Ring In Use; Up. Unit: uncore_cbox \000event=0x1c,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2662386 }, /* unc_c_ring_ak_used.up_vr0_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000 */
{ 2663310 }, /* unc_c_ring_ak_used.up_vr0_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000 */
{ 2664231 }, /* unc_c_ring_ak_used.up_vr1_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000 */
{ 2665156 }, /* unc_c_ring_ak_used.up_vr1_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1c,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000 */
{ 2667750 }, /* unc_c_ring_bl_used.ccw\000uncore_cbox\000uncore cache\000BL Ring in Use; Counterclockwise. Unit: uncore_cbox \000event=0x1d,umask=0xc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2669434 }, /* unc_c_ring_bl_used.cw\000uncore_cbox\000uncore cache\000BL Ring in Use; Clockwise. Unit: uncore_cbox \000event=0x1d,umask=0x3\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2671944 }, /* unc_c_ring_bl_used.down\000uncore_cbox\000uncore cache\000BL Ring in Use; Down. Unit: uncore_cbox \000event=0x1d,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2678074 }, /* unc_c_ring_bl_used.down_vr0_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 0\000 */
{ 2679004 }, /* unc_c_ring_bl_used.down_vr0_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 0\000 */
{ 2679931 }, /* unc_c_ring_bl_used.down_vr1_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Even ring polarity on Virtual Ring 1\000 */
{ 2680862 }, /* unc_c_ring_bl_used.down_vr1_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Down and Odd ring polarity on Virtual Ring 1\000 */
{ 2681790 }, /* unc_c_ring_bl_used.up\000uncore_cbox\000uncore cache\000BL Ring in Use; Up. Unit: uncore_cbox \000event=0x1d,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2688717 }, /* unc_c_ring_bl_used.up_vr0_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 0\000 */
{ 2689641 }, /* unc_c_ring_bl_used.up_vr0_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd on Vring 0. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 0\000 */
{ 2690562 }, /* unc_c_ring_bl_used.up_vr1_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Even ring polarity on Virtual Ring 1\000 */
{ 2691487 }, /* unc_c_ring_bl_used.up_vr1_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd on VRing 1. Unit: uncore_cbox \000event=0x1d,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring.; Filters for the Up and Odd ring polarity on Virtual Ring 1\000 */
{ 2692555 }, /* unc_c_ring_bounces.ad_irq\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2692846 }, /* unc_c_ring_bounces.ak\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2693014 }, /* unc_c_ring_bounces.ak_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2693506 }, /* unc_c_ring_bounces.bl\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000 */
{ 2693672 }, /* unc_c_ring_bounces.bl_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2694014 }, /* unc_c_ring_bounces.iv\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x10\000\00001\000\000 */
{ 2694186 }, /* unc_c_ring_bounces.iv_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.: Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000 */
{ 2696185 }, /* unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000IV Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters any polarity\000 */
{ 2698777 }, /* unc_c_ring_iv_used.down\000uncore_cbox\000uncore cache\000IV Ring in Use; Down. Unit: uncore_cbox \000event=0x1e,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for Down polarity\000 */
{ 2700251 }, /* unc_c_ring_iv_used.up\000uncore_cbox\000uncore cache\000IV Ring in Use; Up. Unit: uncore_cbox \000event=0x1e,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for Up polarity\000 */
{ 2700937 }, /* unc_c_ring_sink_starved.ad_ipq\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 2701037 }, /* unc_c_ring_sink_starved.ad_irq\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 2702011 }, /* unc_c_ring_sink_starved.iv\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x10\000\00001\000\000 */
{ 2702393 }, /* unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x7\000\00001\000\000 */
{ 2702621 }, /* unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IPQ is externally startved and therefore we are blocking the IRQ\000 */
{ 2703192 }, /* unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; IRQ is externally starved and therefore we are blocking the IPQ\000 */
{ 2704016 }, /* unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues.; Number of times that the ISMQ Bid\000 */
{ 2704578 }, /* unc_c_rxr_ext_starved.prq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000IRQ is blocking the ingress queue and causing the starvation\000 */
{ 2705019 }, /* unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705208 }, /* unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705397 }, /* unc_c_rxr_inserts.irq_rej\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705599 }, /* unc_c_rxr_inserts.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Allocations: IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2706397 }, /* unc_c_rxr_inserts.vfifo\000uncore_cbox\000uncore cache\000Ingress Allocations; VFIFO. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue.; Counts the number of allocations into the IRQ Ordering FIFO.  In JKT, it is necessary to keep IO requests in order.  Therefore, they are allocated into an ordering FIFO that sits next to the IRQ, and must be satisfied from the FIFO in order (with respect to each other).  This event, in conjunction with the Occupancy Accumulator event, can be used to calculate average lifetime in the FIFO.  Transactions are allocated into the FIFO as soon as they enter the Cachebo (and the IRQ) and are deallocated from the FIFO as soon as they are deallocated from the IRQ\000 */
{ 2707348 }, /* unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IPQ in Internal Starvation\000 */
{ 2707983 }, /* unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the IRQ in Internal Starvation\000 */
{ 2708618 }, /* unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue.; Cycles with the ISMQ in Internal Starvation\000 */
{ 2709554 }, /* unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from an address conflicts.  Address conflicts out of the IPQ should be rare.  They will generally only occur if two different sockets are sending requests to the same address at the same time.  This is a true conflict case, unlike the IPQ Address Conflict which is commonly caused by prefetching characteristics\000 */
{ 2710465 }, /* unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject.  TOR rejects from the IPQ can be caused by the Egress being full or Address Conflicts\000 */
{ 2711119 }, /* unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries.; Counts the number of times that a request form the IPQ was retried because of a TOR reject from the Egress being full.  IPQ requests make use of the AD Egress for regular responses, the BL egress to forward data, and the AK egress to return credits\000 */
{ 2711860 }, /* unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2712880 }, /* unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000Counts the number of times that a request from the IRQ was retried because of an address match in the TOR.  In order to maintain coherency, requests to the same address are not allowed to pass each other up in the Cbo.  Therefore, if there is an outstanding request to a given address, one cannot issue another request to that address until it is complete.  This comes up most commonly with prefetches.  Outstanding prefetches occasionally will not complete their memory fetch and a demand request to the same address will then sit in the IRQ and get retried until the prefetch fills the data into the LLC.  Therefore, it will not be uncommon to see this case in high bandwidth streaming workloads when the LLC Prefetcher in the core is enabled\000 */
{ 2713930 }, /* unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000Counts the number of IRQ retries that occur.  Requests from the IRQ are retried if they are rejected from the TOR pipeline for a variety of reasons.  Some of the most common reasons include if the Egress is full, there are no RTIDs, or there is a Physical Address match to another outstanding request\000 */
{ 2714504 }, /* unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000Counts the number of times that a request from the IRQ was retried because it failed to acquire an entry in the Egress.  The egress is the buffer that queues up for allocating onto the ring.  IRQ requests can make use of all four rings and all four Egresses.  If any of the queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2715154 }, /* unc_c_rxr_irq_retry.iio_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No IIO Credits. Unit: uncore_cbox \000event=0x32,umask=0x20\000\00001\000Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2715819 }, /* unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000Number of requests rejects because of lack of QPI Ingress credits.  These credits are required in order to send transactions to the QPI agent.  Please see the QPI_IGR_CREDITS events for more information\000 */
{ 2716321 }, /* unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000Counts the number of times that requests from the IRQ were retried because there were no RTIDs available.  RTIDs are required after a request misses the LLC and needs to send snoops and/or requests to memory.  If there are no RTIDs available, requests will queue up in the IRQ and retry until one becomes available.  Note that there are multiple RTID pools for the different sockets.  There may be cases where the local RTIDs are all used, but requests destined for remote memory can still acquire an RTID because there are remote RTIDs available.  This event does not provide any filtering for this case\000 */
{ 2718036 }, /* unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the total number of times that a request from the ISMQ retried because of a TOR reject.  ISMQ requests generally will not need to retry (or at least ISMQ retries are less common than IRQ retries).  ISMQ requests will retry if they are not able to acquire a needed Egress credit to get onto the ring, or for cache evictions that need to acquire an RTID.  Most ISMQ requests already have an RTID, so eviction retries will be less common here\000 */
{ 2719237 }, /* unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by a lack of Egress credits. The egress is the buffer that queues up for allocating onto the ring.  If any of the Egress queues that a given request needs to make use of are full, the request will be retried\000 */
{ 2720310 }, /* unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Number of times a request attempted to acquire the NCS/NCB credit for sending messages on BL to the IIO.  There is a single credit in each CBo that is shared between the NCS and NCB message classes for sending transactions on the BL ring (such as read data) to the IIO\000 */
{ 2721848 }, /* unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2722237 }, /* unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Counts the number of times that a request from the ISMQ retried because of a TOR reject caused by no RTIDs.  M-state cache evictions are serviced through the ISMQ, and must acquire an RTID in order to write back to memory.  If no RTIDs are available, they will be retried\000 */
{ 2723757 }, /* unc_c_rxr_ismq_retry.wb_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No WB Credits. Unit: uncore_cbox \000event=0x33,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores.; Retries of writes to local memory due to lack of HT WB credits\000 */
{ 2725045 }, /* unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725232 }, /* unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725419 }, /* unc_c_rxr_occupancy.irq_rej\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725619 }, /* unc_c_rxr_occupancy.irq_rejected\000uncore_cbox\000uncore cache\000IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2726210 }, /* unc_c_rxr_occupancy.vfifo\000uncore_cbox\000uncore cache\000Ingress Occupancy; VFIFO. Unit: uncore_cbox \000event=0x11,umask=0x10\000\00001\000Counts number of entries in the specified Ingress queue in each cycle.; Accumulates the number of used entries in the IRQ Ordering FIFO in each cycle.  In JKT, it is necessary to keep IO requests in order.  Therefore, they are allocated into an ordering FIFO that sits next to the IRQ, and must be satisfied from the FIFO in order (with respect to each other).  This event, in conjunction with the Allocations event, can be used to calculate average lifetime in the FIFO.  This event can be used in conjunction with the Not Empty event to calculate average queue occupancy. Transactions are allocated into the FIFO as soon as they enter the Cachebo (and the IRQ) and are deallocated from the FIFO as soon as they are deallocated from the IRQ\000 */
{ 2728248 }, /* unc_c_tor_inserts.all\000uncore_cbox\000uncore cache\000TOR Inserts; All. Unit: uncore_cbox \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR.    This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2730237 }, /* unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Eviction transactions inserted into the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2733765 }, /* unc_c_tor_inserts.local\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x28\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2734438 }, /* unc_c_tor_inserts.local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x21\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2736634 }, /* unc_c_tor_inserts.miss_local\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory. Unit: uncore_cbox \000event=0x35,umask=0x2a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2737323 }, /* unc_c_tor_inserts.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x23\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode, inserted into the TOR that are satisfied by locally HOMed memory\000 */
{ 2738662 }, /* unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match an opcode\000 */
{ 2739324 }, /* unc_c_tor_inserts.miss_remote\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x8a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2740025 }, /* unc_c_tor_inserts.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x83\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2741368 }, /* unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched (matches an RTID destination) transactions inserted into the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.  In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2742799 }, /* unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched eviction transactions inserted into the TOR\000 */
{ 2744068 }, /* unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All NID matched miss requests that were inserted into the TOR\000 */
{ 2745352 }, /* unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Miss transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2746645 }, /* unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match a NID and an opcode\000 */
{ 2747919 }, /* unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; NID matched write transactions inserted into the TOR\000 */
{ 2749165 }, /* unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Transactions inserted into the TOR that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2750908 }, /* unc_c_tor_inserts.remote\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory. Unit: uncore_cbox \000event=0x35,umask=0x88\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2751593 }, /* unc_c_tor_inserts.remote_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x81\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; All transactions, satisfied by an opcode,  inserted into the TOR that are satisfied by remote caches or remote memory\000 */
{ 2753157 }, /* unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182).; Write transactions inserted into the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2754718 }, /* unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All valid TOR entries.  This includes requests that reside in the TOR for a short time, such as LLC Hits that do not need to snoop cores or requests that get rejected and have to be retried through one of the ingress queues.  The TOR is more commonly a bottleneck in skews with smaller core counts, where the ratio of RTIDs to TOR entries is larger.  Note that there are reserved TOR entries for various request types, so it is possible that a given request type be blocked with an occupancy that is less than 20.  Also note that generally requests will not be able to arbitrate into the TOR pipeline if there are no available TOR slots\000 */
{ 2756725 }, /* unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding eviction transactions in the TOR.  Evictions can be quick, such as when the line is in the F, S, or E states and no core valid bits are set.  They can also be longer if either CV bits are set (so the cores need to be snooped) and/or if there is a HitM (in which case it is necessary to write the request out to memory)\000 */
{ 2760047 }, /* unc_c_tor_occupancy.local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x28\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2760639 }, /* unc_c_tor_occupancy.local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by locally HOMed memory\000 */
{ 2762159 }, /* unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding miss requests in the TOR.  'Miss' means the allocation requires an RTID.  This generally means that the request was sent to memory or MMIO\000 */
{ 2762925 }, /* unc_c_tor_occupancy.miss_local\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x2a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2763522 }, /* unc_c_tor_occupancy.miss_local_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Local Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x23\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by locally HOMed memory\000 */
{ 2764905 }, /* unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries for miss transactions that match an opcode. This generally means that the request was sent to memory or MMIO\000 */
{ 2765643 }, /* unc_c_tor_occupancy.miss_remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x8a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2766241 }, /* unc_c_tor_occupancy.miss_remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Misses to Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x83\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss transactions, satisfied by an opcode, in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2767627 }, /* unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of NID matched outstanding requests in the TOR.  The NID is programmed in Cn_MSR_PMON_BOX_FILTER.nid.In conjunction with STATE = I, it is possible to monitor misses to specific NIDs in the system\000 */
{ 2769062 }, /* unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding NID matched eviction transactions in the TOR \000 */
{ 2770367 }, /* unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID\000 */
{ 2771677 }, /* unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding Miss requests in the TOR that match a NID and an opcode\000 */
{ 2773010 }, /* unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match a NID and an opcode\000 */
{ 2773675 }, /* unc_c_tor_occupancy.nid_wb\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x50\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); NID matched write transactions int the TOR\000 */
{ 2774944 }, /* unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); TOR entries that match an opcode (matched by Cn_MSR_PMON_BOX_FILTER.opc)\000 */
{ 2776134 }, /* unc_c_tor_occupancy.remote\000uncore_cbox\000uncore cache\000TOR Occupancy. Unit: uncore_cbox \000event=0x36,umask=0x88\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2776727 }, /* unc_c_tor_occupancy.remote_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Remote Memory - Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x81\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Number of outstanding  transactions, satisfied by an opcode,  in the TOR that are satisfied by remote caches or remote memory\000 */
{ 2777486 }, /* unc_c_tor_occupancy.wb\000uncore_cbox\000uncore cache\000TOR Occupancy; Writebacks. Unit: uncore_cbox \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); Write transactions in the TOR.   This does not include RFO, but actual operations that contain data being sent from the core\000 */
{ 2778213 }, /* unc_c_txr_ads_used.ad\000uncore_cbox\000uncore cache\000Onto AD Ring. Unit: uncore_cbox \000event=0x4,umask=0x1\000\00001\000\000 */
{ 2778318 }, /* unc_c_txr_ads_used.ak\000uncore_cbox\000uncore cache\000Onto AK Ring. Unit: uncore_cbox \000event=0x4,umask=0x2\000\00001\000\000 */
{ 2778423 }, /* unc_c_txr_ads_used.bl\000uncore_cbox\000uncore cache\000Onto BL Ring. Unit: uncore_cbox \000event=0x4,umask=0x4\000\00001\000\000 */
{ 2778606 }, /* unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 2779216 }, /* unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 2779791 }, /* unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 2780383 }, /* unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the AK ring.  This is commonly used for snoop responses coming from the core and destined for a Cachebo\000 */
{ 2781004 }, /* unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 2781612 }, /* unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Corebo destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 2782210 }, /* unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring.; Ring transactions from the Cachebo destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 2782790 }, /* unc_c_txr_starved.ad_core\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AD Ring (to core). Unit: uncore_cbox \000event=0x3,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the core AD egress spent in starvation\000 */
{ 2783391 }, /* unc_c_txr_starved.ak_both\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that both AK egresses spent in starvation\000 */
{ 2784301 }, /* unc_c_txr_starved.iv\000uncore_cbox\000uncore cache\000Injection Starvation; Onto IV Ring. Unit: uncore_cbox \000event=0x3,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time.; cycles that the cachebo IV egress spent in starvation\000 */
{ 3578798 }, /* unc_h_bt_bypass\000uncore_ha\000uncore cache\000BT Bypass. Unit: uncore_ha \000event=0x52\000\00001\000Number of transactions that bypass the BT (fifo) to HT\000 */
{ 3579343 }, /* unc_h_bt_cycles_ne\000uncore_ha\000uncore cache\000BT Cycles Not Empty. Unit: uncore_ha \000event=0x42\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3578935 }, /* unc_h_bt_cycles_ne.local\000uncore_ha\000uncore cache\000BT Cycles Not Empty: Local. Unit: uncore_ha \000event=0x42,umask=0x1\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3579138 }, /* unc_h_bt_cycles_ne.remote\000uncore_ha\000uncore cache\000BT Cycles Not Empty: Remote. Unit: uncore_ha \000event=0x42,umask=0x2\000\00001\000Cycles the Backup Tracker (BT) is not empty. The BT is the actual HOM tracker in IVT\000 */
{ 3579523 }, /* unc_h_bt_occupancy.local\000uncore_ha\000uncore cache\000BT Occupancy; Local. Unit: uncore_ha \000event=0x43,umask=0x1\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3580030 }, /* unc_h_bt_occupancy.reads_local\000uncore_ha\000uncore cache\000BT Occupancy; Reads Local. Unit: uncore_ha \000event=0x43,umask=0x4\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3580549 }, /* unc_h_bt_occupancy.reads_remote\000uncore_ha\000uncore cache\000BT Occupancy; Reads Remote. Unit: uncore_ha \000event=0x43,umask=0x8\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3581070 }, /* unc_h_bt_occupancy.remote\000uncore_ha\000uncore cache\000BT Occupancy; Remote. Unit: uncore_ha \000event=0x43,umask=0x2\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3581579 }, /* unc_h_bt_occupancy.writes_local\000uncore_ha\000uncore cache\000BT Occupancy; Writes Local. Unit: uncore_ha \000event=0x43,umask=0x10\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3582101 }, /* unc_h_bt_occupancy.writes_remote\000uncore_ha\000uncore cache\000BT Occupancy; Writes Remote. Unit: uncore_ha \000event=0x43,umask=0x20\000\00001\000Accumulates the occupancy of the HA BT pool in every cycle.  This can be used with the not empty stat to calculate average queue occupancy or the allocations stat in order to calculate average queue latency.  HA BTs are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3582625 }, /* unc_h_bt_to_ht_not_issued.incoming_bl_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x4\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3582923 }, /* unc_h_bt_to_ht_not_issued.incoming_snp_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Snoop Hazard. Unit: uncore_ha \000event=0x51,umask=0x2\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming snoop hazard\000 */
{ 3583221 }, /* unc_h_bt_to_ht_not_issued.rspackcflt_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x8\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3583518 }, /* unc_h_bt_to_ht_not_issued.wbmdata_hazard\000uncore_ha\000uncore cache\000BT to HT Not Issued; Incoming Data Hazard. Unit: uncore_ha \000event=0x51,umask=0x10\000\00001\000Counts the number of cycles when the HA does not issue transaction from BT to HT.; Cycles unable to issue from BT due to incoming BL data hazard\000 */
{ 3584345 }, /* unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass\000 */
{ 3585130 }, /* unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the bypass\000 */
{ 3587414 }, /* unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000 */
{ 3587782 }, /* unc_h_conflict_cycles.ackcnflts\000uncore_ha\000uncore cache\000Conflict Checks; Acknowledge Conflicts. Unit: uncore_ha \000event=0xb,umask=0x8\000\00001\000Count the number of Ackcnflts\000 */
{ 3587948 }, /* unc_h_conflict_cycles.cmp_fwds\000uncore_ha\000uncore cache\000Conflict Checks; Cmp Fwds. Unit: uncore_ha \000event=0xb,umask=0x10\000\00001\000Count the number of Cmp_Fwd. This will give the number of late conflicts\000 */
{ 3588144 }, /* unc_h_conflict_cycles.conflict\000uncore_ha\000uncore cache\000Conflict Checks; Conflict Detected. Unit: uncore_ha \000event=0xb,umask=0x2\000\00001\000Counts the number of cycles that we are handling conflicts\000 */
{ 3588466 }, /* unc_h_conflict_cycles.last\000uncore_ha\000uncore cache\000Conflict Checks; Last in conflict chain. Unit: uncore_ha \000event=0xb,umask=0x4\000\00001\000Count every last conflictor in conflict chain. Can be used to compute the average conflict chain length as (#Ackcnflts/#LastConflictor)+1. This can be used to give a feel for the conflict chain lengths while analyzing lock kernels\000 */
{ 3592593 }, /* unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000 */
{ 3592735 }, /* unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000 */
{ 3592913 }, /* unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000 */
{ 3593093 }, /* unc_h_directory_lat_opt\000uncore_ha\000uncore cache\000Directory Lat Opt Return. Unit: uncore_ha \000event=0x41\000\00001\000Directory Latency Optimization Data Return Path Taken. When directory mode is enabled and the directory returned for a read is Dir=I, then data can be returned using a faster path if certain conditions are met (credits, free pipeline, etc)\000 */
{ 3593438 }, /* unc_h_directory_lookup.any\000uncore_ha\000uncore cache\000Directory Lookups: Any state. Unit: uncore_ha \000event=0xc,umask=0x10\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3593702 }, /* unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that did not have to send any snoops because the directory bit was clear\000 */
{ 3594348 }, /* unc_h_directory_lookup.snoop_a\000uncore_ha\000uncore cache\000Directory Lookups: Snoop A. Unit: uncore_ha \000event=0xc,umask=0x8\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3594613 }, /* unc_h_directory_lookup.snoop_s\000uncore_ha\000uncore cache\000Directory Lookups: Snoop S. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3594878 }, /* unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to.; Filters for transactions that had to send one or more snoops because the directory bit was set\000 */
{ 3595507 }, /* unc_h_directory_lookup.state_a\000uncore_ha\000uncore cache\000Directory Lookups: A State. Unit: uncore_ha \000event=0xc,umask=0x80\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3595773 }, /* unc_h_directory_lookup.state_i\000uncore_ha\000uncore cache\000Directory Lookups: I State. Unit: uncore_ha \000event=0xc,umask=0x20\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3596039 }, /* unc_h_directory_lookup.state_s\000uncore_ha\000uncore cache\000Directory Lookups: S State. Unit: uncore_ha \000event=0xc,umask=0x40\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3596305 }, /* unc_h_directory_update.a2i\000uncore_ha\000uncore cache\000Directory Updates: A2I. Unit: uncore_ha \000event=0xd,umask=0x20\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3596591 }, /* unc_h_directory_update.a2s\000uncore_ha\000uncore cache\000Directory Updates: A2S. Unit: uncore_ha \000event=0xd,umask=0x40\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3596877 }, /* unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3597179 }, /* unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory clears.  This occurs when snoops were sent and all returned with RspI\000 */
{ 3597870 }, /* unc_h_directory_update.i2a\000uncore_ha\000uncore cache\000Directory Updates: I2A. Unit: uncore_ha \000event=0xd,umask=0x4\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3598155 }, /* unc_h_directory_update.i2s\000uncore_ha\000uncore cache\000Directory Updates: I2S. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3598440 }, /* unc_h_directory_update.s2a\000uncore_ha\000uncore cache\000Directory Updates: S2A. Unit: uncore_ha \000event=0xd,umask=0x10\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3598726 }, /* unc_h_directory_update.s2i\000uncore_ha\000uncore cache\000Directory Updates: S2I. Unit: uncore_ha \000event=0xd,umask=0x8\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3599011 }, /* unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears.; Filter for directory sets.  This occurs when a remote read transaction requests memory, bringing it to a remote cache\000 */
{ 3627004 }, /* unc_h_igr_ad_qpi2_accumulator\000uncore_ha\000uncore cache\000AD QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x59\000\00001\000Accumulates the number of credits available to the QPI Link 2 AD Ingress buffer\000 */
{ 3627203 }, /* unc_h_igr_bl_qpi2_accumulator\000uncore_ha\000uncore cache\000BL QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x5a\000\00001\000Accumulates the number of credits available to the QPI Link 2 BL Ingress buffer\000 */
{ 3627402 }, /* unc_h_igr_credits_ad_qpi2\000uncore_ha\000uncore cache\000AD QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x59\000\00001\000Accumulates the number of credits available to the QPI Link 2 AD Ingress buffer\000 */
{ 3627597 }, /* unc_h_igr_credits_bl_qpi2\000uncore_ha\000uncore cache\000BL QPI Link 2 Credit Accumulator. Unit: uncore_ha \000event=0x5a\000\00001\000Accumulates the number of credits available to the QPI Link 2 BL Ingress buffer\000 */
{ 3627792 }, /* unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628119 }, /* unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628774 }, /* unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629101 }, /* unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629756 }, /* unc_h_imc_reads.normal\000uncore_ha\000uncore cache\000HA to iMC Normal Priority Reads Issued; Normal Priority. Unit: uncore_ha \000event=0x17,umask=0x1\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 3630382 }, /* unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000 */
{ 3630468 }, /* unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3630784 }, /* unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631110 }, /* unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631438 }, /* unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631765 }, /* unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3648129 }, /* unc_h_iodc_conflicts.any\000uncore_ha\000uncore cache\000IODC Conflicts; Any Conflict. Unit: uncore_ha \000event=0x57,umask=0x1\000\00001\000\000 */
{ 3648250 }, /* unc_h_iodc_conflicts.last\000uncore_ha\000uncore cache\000IODC Conflicts; Last Conflict. Unit: uncore_ha \000event=0x57,umask=0x4\000\00001\000\000 */
{ 3648373 }, /* unc_h_iodc_conflicts.remote_invi2e_same_rtid\000uncore_ha\000uncore cache\000IODC Conflicts: Remote InvItoE - Same RTID. Unit: uncore_ha \000event=0x57,umask=0x1\000\00001\000\000 */
{ 3648528 }, /* unc_h_iodc_conflicts.remote_other_same_addr\000uncore_ha\000uncore cache\000IODC Conflicts: Remote (Other) - Same Addr. Unit: uncore_ha \000event=0x57,umask=0x4\000\00001\000\000 */
{ 3649525 }, /* unc_h_iodc_inserts\000uncore_ha\000uncore cache\000IODC Inserts. Unit: uncore_ha \000event=0x56\000\00001\000IODC Allocations\000 */
{ 3649630 }, /* unc_h_iodc_olen_wbmtoi\000uncore_ha\000uncore cache\000Num IODC 0 Length Writes. Unit: uncore_ha \000event=0x58\000\00001\000Num IODC 0 Length Writebacks M to I - All of which are dropped\000 */
{ 3653009 }, /* unc_h_osb.invitoe_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local InvItoE. Unit: uncore_ha \000event=0x53,umask=0x4\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653272 }, /* unc_h_osb.reads_local\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Local Reads. Unit: uncore_ha \000event=0x53,umask=0x2\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3653808 }, /* unc_h_osb.remote\000uncore_ha\000uncore cache\000OSB Snoop Broadcast; Remote. Unit: uncore_ha \000event=0x53,umask=0x8\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3654449 }, /* unc_h_osb_edr.all\000uncore_ha\000uncore cache\000OSB Early Data Return; All. Unit: uncore_ha \000event=0x54,umask=0x1\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654695 }, /* unc_h_osb_edr.reads_local_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local  I. Unit: uncore_ha \000event=0x54,umask=0x2\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3654965 }, /* unc_h_osb_edr.reads_local_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Local S. Unit: uncore_ha \000event=0x54,umask=0x8\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655234 }, /* unc_h_osb_edr.reads_remote_i\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote I. Unit: uncore_ha \000event=0x54,umask=0x4\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3655505 }, /* unc_h_osb_edr.reads_remote_s\000uncore_ha\000uncore cache\000OSB Early Data Return; Reads to Remote S. Unit: uncore_ha \000event=0x54,umask=0x10\000\00001\000Counts the number of transactions that broadcast snoop due to OSB, but found clean data in memory and was able to do early data return\000 */
{ 3657030 }, /* unc_h_requests.invitoe_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x10\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from the local socket\000 */
{ 3657584 }, /* unc_h_requests.invitoe_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote InvItoEs. Unit: uncore_ha \000event=0x1,umask=0x20\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only InvItoEs coming from remote sockets\000 */
{ 3658081 }, /* unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming ead requests.  This is a good proxy for LLC Read Misses (including RFOs)\000 */
{ 3658883 }, /* unc_h_requests.reads_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Reads. Unit: uncore_ha \000event=0x1,umask=0x1\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the local socket.  This is a good proxy for LLC Read Misses (including RFOs) from the local socket\000 */
{ 3659475 }, /* unc_h_requests.reads_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Reads. Unit: uncore_ha \000event=0x1,umask=0x2\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only read requests coming from the remote socket.  This is a good proxy for LLC Read Misses (including RFOs) from the remote socket\000 */
{ 3660059 }, /* unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; Incoming write requests\000 */
{ 3660809 }, /* unc_h_requests.writes_local\000uncore_ha\000uncore cache\000Read and Write Requests; Local Writes. Unit: uncore_ha \000event=0x1,umask=0x4\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from the local socket\000 */
{ 3661316 }, /* unc_h_requests.writes_remote\000uncore_ha\000uncore cache\000Read and Write Requests; Remote Writes. Unit: uncore_ha \000event=0x1,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc).; This filter includes only writes coming from remote sockets\000 */
{ 3662034 }, /* unc_h_ring_ad_used.ccw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3e,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3663937 }, /* unc_h_ring_ad_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3664389 }, /* unc_h_ring_ad_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3664838 }, /* unc_h_ring_ad_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3665291 }, /* unc_h_ring_ad_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3665741 }, /* unc_h_ring_ad_used.cw\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3e,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3667929 }, /* unc_h_ring_ad_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3668366 }, /* unc_h_ring_ad_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3668800 }, /* unc_h_ring_ad_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3669238 }, /* unc_h_ring_ad_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3e,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3670354 }, /* unc_h_ring_ak_used.ccw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x3f,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3672257 }, /* unc_h_ring_ak_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3672709 }, /* unc_h_ring_ak_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3673158 }, /* unc_h_ring_ak_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3673611 }, /* unc_h_ring_ak_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3674061 }, /* unc_h_ring_ak_used.cw\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise. Unit: uncore_ha \000event=0x3f,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3676249 }, /* unc_h_ring_ak_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3676686 }, /* unc_h_ring_ak_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3677120 }, /* unc_h_ring_ak_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3677558 }, /* unc_h_ring_ak_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x3f,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3678674 }, /* unc_h_ring_bl_used.ccw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise. Unit: uncore_ha \000event=0x40,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3680577 }, /* unc_h_ring_bl_used.ccw_vr0_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3681029 }, /* unc_h_ring_bl_used.ccw_vr0_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3681478 }, /* unc_h_ring_bl_used.ccw_vr1_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3681931 }, /* unc_h_ring_bl_used.ccw_vr1_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3682381 }, /* unc_h_ring_bl_used.cw\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise. Unit: uncore_ha \000event=0x40,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3684569 }, /* unc_h_ring_bl_used.cw_vr0_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 3685006 }, /* unc_h_ring_bl_used.cw_vr0_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 3685440 }, /* unc_h_ring_bl_used.cw_vr1_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 3685878 }, /* unc_h_ring_bl_used.cw_vr1_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_ha \000event=0x40,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 3693072 }, /* unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3694856 }, /* unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3696640 }, /* unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3698424 }, /* unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3700168 }, /* unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3701870 }, /* unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3703572 }, /* unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3705274 }, /* unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and special requests such as ISOCH reads.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3739531 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*Fwd*WB. Unit: uncore_ha \000event=0x21,umask=0x20\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3740517 }, /* unc_h_snoop_resp.rsp_wb\000uncore_ha\000uncore cache\000Snoop Responses Received; Rsp*WB. Unit: uncore_ha \000event=0x21,umask=0x10\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3741525 }, /* unc_h_snoop_resp.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received; RSPCNFLCT*. Unit: uncore_ha \000event=0x21,umask=0x40\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3742665 }, /* unc_h_snoop_resp.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received; RspI. Unit: uncore_ha \000event=0x21,umask=0x1\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3744395 }, /* unc_h_snoop_resp.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspIFwd. Unit: uncore_ha \000event=0x21,umask=0x4\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3746136 }, /* unc_h_snoop_resp.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received; RspS. Unit: uncore_ha \000event=0x21,umask=0x2\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3749380 }, /* unc_h_snoop_resp.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received; RspSFwd. Unit: uncore_ha \000event=0x21,umask=0x8\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3751926 }, /* unc_h_snp_resp_recv_local.other\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Other. Unit: uncore_ha \000event=0x60,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for all other snoop responses\000 */
{ 3752158 }, /* unc_h_snp_resp_recv_local.rspcnflct\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_ha \000event=0x60,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3752627 }, /* unc_h_snp_resp_recv_local.rspi\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_ha \000event=0x60,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3753011 }, /* unc_h_snp_resp_recv_local.rspifwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_ha \000event=0x60,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3753465 }, /* unc_h_snp_resp_recv_local.rsps\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_ha \000event=0x60,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3754303 }, /* unc_h_snp_resp_recv_local.rspsfwd\000uncore_ha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_ha \000event=0x60,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3754721 }, /* unc_h_snp_resp_recv_local.rspxfwdxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_ha \000event=0x60,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3755195 }, /* unc_h_snp_resp_recv_local.rspxwb\000uncore_ha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_ha \000event=0x60,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3763538 }, /* unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 0\000 */
{ 3765043 }, /* unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 1\000 */
{ 3766548 }, /* unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 2\000 */
{ 3768053 }, /* unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 3\000 */
{ 3769559 }, /* unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 4\000 */
{ 3771066 }, /* unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 5\000 */
{ 3772573 }, /* unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 6\000 */
{ 3774080 }, /* unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 7\000 */
{ 3775589 }, /* unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 10\000 */
{ 3777101 }, /* unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 11\000 */
{ 3778611 }, /* unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 8\000 */
{ 3780118 }, /* unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for Monroe systems that use the TAD to enable individual channels to enter self-refresh to save power.; Filters request made to TAD Region 9\000 */
{ 3798110 }, /* unc_h_tracker_cycles_ne\000uncore_ha\000uncore cache\000Tracker Cycles Not Empty. Unit: uncore_ha \000event=0x3\000\00001\000Counts the number of cycles when the local HA tracker pool is not empty.  This can be used with edge detect to identify the number of situations when the pool became empty.  This should not be confused with RTID credit usage -- which must be tracked inside each cbo individually -- but represents the actual tracker buffer structure.  In other words, this buffer could be completely empty, but there may still be credits in use by the CBos.  This stat can be used in conjunction with the occupancy accumulation stat in order to calculate average queue occpancy.  HA trackers are allocated as soon as a request enters the HA if an HT (Home Tracker) entry is available and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3804496 }, /* unc_h_txr_ad.hom\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x4\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details.; Filter for outbound NDR transactions sent on the AD ring.  NDR stands for non-data response and is generally used for completions that do not include data.  AD NDR is used for transactions to remote sockets\000 */
{ 3805581 }, /* unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000AD Egress Full; Cycles full from both schedulers\000 */
{ 3805861 }, /* unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3806176 }, /* unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000AD Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3806491 }, /* unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000AD Egress Not Empty; Cycles full from both schedulers\000 */
{ 3806782 }, /* unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000AD Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3807113 }, /* unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000AD Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3807443 }, /* unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000AD Egress Allocations; Allocations from both schedulers\000 */
{ 3807736 }, /* unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3808063 }, /* unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000AD Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3808509 }, /* unc_h_txr_ad_occupancy.sched0\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x28,umask=0x1\000\00001\000AD Egress Occupancy; Filter for occupancy from scheduler bank 0\000 */
{ 3808832 }, /* unc_h_txr_ad_occupancy.sched1\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x28,umask=0x2\000\00001\000AD Egress Occupancy; Filter for occupancy from scheduler bank 1\000 */
{ 3809155 }, /* unc_h_txr_ak.crd_cbo\000uncore_ha\000uncore cache\000Outbound Ring Transactions on AK: CRD Transactions to Cbo. Unit: uncore_ha \000event=0xe,umask=0x2\000\00001\000\000 */
{ 3809300 }, /* unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000AK Egress Full; Cycles full from both schedulers\000 */
{ 3809580 }, /* unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3809895 }, /* unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000AK Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3810210 }, /* unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000AK Egress Not Empty; Cycles full from both schedulers\000 */
{ 3810501 }, /* unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000AK Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3810832 }, /* unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000AK Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3811162 }, /* unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000AK Egress Allocations; Allocations from both schedulers\000 */
{ 3811455 }, /* unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3811782 }, /* unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000AK Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3812548 }, /* unc_h_txr_ak_occupancy.sched0\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x30,umask=0x1\000\00001\000AK Egress Occupancy; Filter for occupancy from scheduler bank 0\000 */
{ 3812871 }, /* unc_h_txr_ak_occupancy.sched1\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x30,umask=0x2\000\00001\000AK Egress Occupancy; Filter for occupancy from scheduler bank 1\000 */
{ 3813194 }, /* unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to the cache\000 */
{ 3813726 }, /* unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent directly to the requesting core\000 */
{ 3814273 }, /* unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination.; Filter for data being sent to a remote socket over QPI\000 */
{ 3814812 }, /* unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000BL Egress Full; Cycles full from both schedulers\000 */
{ 3815092 }, /* unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 0\000 */
{ 3815407 }, /* unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000BL Egress Full; Filter for cycles full  from scheduler bank 1\000 */
{ 3815722 }, /* unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000BL Egress Not Empty; Cycles full from both schedulers\000 */
{ 3816013 }, /* unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000BL Egress Not Empty; Filter for cycles not empty  from scheduler bank 0\000 */
{ 3816344 }, /* unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000BL Egress Not Empty; Filter for cycles not empty from scheduler bank 1\000 */
{ 3816674 }, /* unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000BL Egress Allocations; Allocations from both schedulers\000 */
{ 3816967 }, /* unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 0\000 */
{ 3817294 }, /* unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000BL Egress Allocations; Filter for allocations from scheduler bank 1\000 */
{ 3817621 }, /* unc_h_txr_bl_occupancy.all\000uncore_ha\000uncore cache\000BL Egress Occupancy: All. Unit: uncore_ha \000event=0x34,umask=0x3\000\00001\000\000 */
{ 3817859 }, /* unc_h_txr_bl_occupancy.sched0\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x34,umask=0x1\000\00001\000BL Egress Occupancy; Filter for occupancy from scheduler bank 0\000 */
{ 3818182 }, /* unc_h_txr_bl_occupancy.sched1\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x34,umask=0x2\000\00001\000BL Egress Occupancy; Filter for occupancy from scheduler bank 1\000 */
{ 3843414 }, /* unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3845224 }, /* unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3847034 }, /* unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3848844 }, /* unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no regular credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3850614 }, /* unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 0 only\000 */
{ 3852342 }, /* unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 1 only\000 */
{ 3854070 }, /* unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 2 only\000 */
{ 3855798 }, /* unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no special credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and special requests such as ISOCH writes.  This count only tracks the special credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time.; Filter for memory controller channel 3 only\000 */
{ 3862554 }, /* unc_i_address_match.merge_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Merges. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache.; When two requests to the same address from the same source are received back to back, it is possible to merge the two of them together\000 */
{ 3863309 }, /* unc_i_address_match.stall_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Stalls. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache.; When it is not possible to merge two conflicting requests, a stall event occurs.  This is bad for performance\000 */
{ 3864039 }, /* unc_i_cache_ack_pending_occupancy.any\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Any Source. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3865485 }, /* unc_i_cache_ack_pending_occupancy.source\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Select Source. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements.; Tracks all requests from any source port\000 */
{ 3866768 }, /* unc_i_cache_own_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Any Source. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned.; Tracks all requests from any source port\000 */
{ 3867797 }, /* unc_i_cache_own_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Select Source. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3869013 }, /* unc_i_cache_read_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Any Source. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned.; Tracks all requests from any source port\000 */
{ 3869912 }, /* unc_i_cache_read_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Select Source. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3871403 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3873716 }, /* unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3874582 }, /* unc_i_cache_write_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Any Source. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore.; Tracks all requests from any source port\000 */
{ 3875573 }, /* unc_i_cache_write_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Select Source. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore.; Tracks only those requests that come from the port specified in the IRP_PmonFilter.OrderingQ register.  This register allows one to select one specific queue.  It is not possible to monitor multiple queues at a time\000 */
{ 3876751 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000 */
{ 3895014 }, /* unc_i_rxr_ak_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xb\000\00001\000Counts the number of cycles when the AK Ingress is full.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895230 }, /* unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895461 }, /* unc_i_rxr_ak_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the occupancy of the AK Ingress in each cycles.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3896003 }, /* unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896298 }, /* unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896938 }, /* unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897559 }, /* unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897854 }, /* unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898494 }, /* unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899115 }, /* unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899410 }, /* unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3900050 }, /* unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3904426 }, /* unc_i_tickles.lost_ownership\000uncore_irp\000uncore interconnect\000Tickle Count; Ownership Lost. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles.; Tracks the number of requests that lost ownership as a result of a tickle.  When a tickle comes in, if the request is not at the head of the queue in the switch, then that request as well as any requests behind it in the switch queue will lose ownership and have to re-acquire it later when they get to the head of the queue.  This will therefore track the number of requests that lost ownership and not just the number of tickles\000 */
{ 3905379 }, /* unc_i_tickles.top_of_queue\000uncore_irp\000uncore interconnect\000Tickle Count; Data Returned. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles.; Tracks the number of cases when a tickle was received but the requests was at the head of the queue in the switch.  In this case, data is returned rather than releasing ownership\000 */
{ 3909133 }, /* unc_i_transactions.pd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count: Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000 */
{ 3911061 }, /* unc_i_transactions.rd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3912521 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3916171 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3921293 }, /* unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3921548 }, /* unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3921798 }, /* unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3921985 }, /* unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3922522 }, /* unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumultes the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjuection with the allocations event in order to calculate average latency of outbound requests\000 */
{ 3924404 }, /* unc_i_write_ordering_stall_cycles\000uncore_irp\000uncore interconnect\000Write Ordering Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number of cycles when there are pending write ACK's in the switch but the switch->IRP pipeline is not utilized\000 */
{ 5689388 }, /* unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/8th the GT/s speed of the QPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  JKT does not support dynamic link speeds, so this frequency is fixed\000 */
{ 5689710 }, /* unc_q_cto_count\000uncore_qpi\000uncore interconnect\000Count of CTO Events. Unit: uncore_qpi \000event=0x38\000\00001\000Counts the number of CTO (cluster trigger outs) events that were asserted across the two slots.  If both slots trigger in a given cycle, the event will increment by 2.  You can use edge detect to count the number of cases when both events triggered\000 */
{ 5690060 }, /* unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits.  Had there been enough credits, the spawn would have worked as the RBT bit was set and the RBT tag matched\000 */
{ 5691288 }, /* unc_q_direct2core.failure_credits_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x20\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and there weren't enough Egress credits.   The valid bit was set\000 */
{ 5691945 }, /* unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because there were not enough Egress credits AND the RBT bit was not set, but the RBT tag matched\000 */
{ 5693134 }, /* unc_q_direct2core.failure_credits_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT Miss, Invalid. Unit: uncore_qpi \000event=0x13,umask=0x80\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match, the valid bit was not set and there weren't enough Egress credits\000 */
{ 5693806 }, /* unc_q_direct2core.failure_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss. Unit: uncore_qpi \000event=0x13,umask=0x10\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match although the valid bit was set and there were enough Egress credits\000 */
{ 5694968 }, /* unc_q_direct2core.failure_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Invalid. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the route-back table (RBT) specified that the transaction should not trigger a direct2core transaction.  This is common for IO transactions.  There were enough Egress credits and the RBT tag matched but the valid bit was not set\000 */
{ 5695749 }, /* unc_q_direct2core.failure_rbt_miss\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Miss and Invalid. Unit: uncore_qpi \000event=0x13,umask=0x40\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn failed because the RBT tag did not match and the valid bit was not set although there were enough Egress credits\000 */
{ 5696913 }, /* unc_q_direct2core.success_rbt_hit\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos.; The spawn was successful.  There were sufficient credits, the RBT valid bit was set and there was an RBT tag match.  The message was marked to spawn direct2core\000 */
{ 5697587 }, /* unc_q_l1_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L1. Unit: uncore_qpi \000event=0x12\000\00001\000Number of QPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a QPI link.  Use edge detect to count the number of instances when the QPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 5698087 }, /* unc_q_match_mask\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698169 }, /* unc_q_message.drs.anydatac\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698456 }, /* unc_q_message.drs.anyresp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698261 }, /* unc_q_message.drs.anyresp11flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698359 }, /* unc_q_message.drs.anyresp9flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698547 }, /* unc_q_message.drs.datac_e\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698638 }, /* unc_q_message.drs.datac_e_cmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698733 }, /* unc_q_message.drs.datac_e_frcackcnflt\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698836 }, /* unc_q_message.drs.datac_f\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5698927 }, /* unc_q_message.drs.datac_f_cmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699022 }, /* unc_q_message.drs.datac_f_frcackcnflt\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699125 }, /* unc_q_message.drs.datac_m\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699216 }, /* unc_q_message.drs.wbedata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699307 }, /* unc_q_message.drs.wbidata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699398 }, /* unc_q_message.drs.wbsdata\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699489 }, /* unc_q_message.hom.anyreq\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699579 }, /* unc_q_message.hom.anyresp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699670 }, /* unc_q_message.hom.respfwd\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699761 }, /* unc_q_message.hom.respfwdi\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699853 }, /* unc_q_message.hom.respfwdiwb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5699947 }, /* unc_q_message.hom.respfwds\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700039 }, /* unc_q_message.hom.respfwdswb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700133 }, /* unc_q_message.hom.respiwb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700224 }, /* unc_q_message.hom.respswb\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700315 }, /* unc_q_message.ncb.anyint\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700598 }, /* unc_q_message.ncb.anymsg\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700405 }, /* unc_q_message.ncb.anymsg11flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700502 }, /* unc_q_message.ncb.anymsg9flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700688 }, /* unc_q_message.ncs.anymsg1or2flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700787 }, /* unc_q_message.ncs.anymsg3flits\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700883 }, /* unc_q_message.ncs.ncrd\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5700971 }, /* unc_q_message.ndr.anycmp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5701061 }, /* unc_q_message.snp.anysnp\000uncore_qpi\000uncore interconnect\000Unit: uncore_qpi \000event=0x38\000\00001\000\000 */
{ 5701151 }, /* unc_q_rxl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xf\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5701702 }, /* unc_q_rxl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0x10\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5702372 }, /* unc_q_rxl_bypassed\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x9\000\00001\000Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 5702855 }, /* unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during link initialization\000 */
{ 5703862 }, /* unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; Normal Operations. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it).; CRC errors detected during normal operation\000 */
{ 5705021 }, /* unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the DRS message class\000 */
{ 5705718 }, /* unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the HOM message class\000 */
{ 5706415 }, /* unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCB message class\000 */
{ 5707112 }, /* unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NCS message class\000 */
{ 5707809 }, /* unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the NDR message class\000 */
{ 5708508 }, /* unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN0 credit for the SNP message class\000 */
{ 5709207 }, /* unc_q_rxl_credits_consumed_vn1.drs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x39,umask=0x1\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the DRS message class\000 */
{ 5709575 }, /* unc_q_rxl_credits_consumed_vn1.hom\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x39,umask=0x8\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the HOM message class\000 */
{ 5709943 }, /* unc_q_rxl_credits_consumed_vn1.ncb\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x39,umask=0x2\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCB message class\000 */
{ 5710311 }, /* unc_q_rxl_credits_consumed_vn1.ncs\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x39,umask=0x4\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NCS message class\000 */
{ 5710679 }, /* unc_q_rxl_credits_consumed_vn1.ndr\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x39,umask=0x20\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the NDR message class\000 */
{ 5711048 }, /* unc_q_rxl_credits_consumed_vn1.snp\000uncore_qpi\000uncore interconnect\000VN1 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x39,umask=0x10\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed.; VN1 credit for the SNP message class\000 */
{ 5711417 }, /* unc_q_rxl_credits_consumed_vna\000uncore_qpi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_qpi \000event=0x1d\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5711727 }, /* unc_q_rxl_cycles_ne\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty. Unit: uncore_qpi \000event=0xa\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy\000 */
{ 5712262 }, /* unc_q_rxl_cycles_ne_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN0. Unit: uncore_qpi \000event=0xf,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5712861 }, /* unc_q_rxl_cycles_ne_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - DRS; for VN1. Unit: uncore_qpi \000event=0xf,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors DRS flits only\000 */
{ 5713460 }, /* unc_q_rxl_cycles_ne_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN0. Unit: uncore_qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714060 }, /* unc_q_rxl_cycles_ne_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - HOM; for VN1. Unit: uncore_qpi \000event=0x12,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors HOM flits only\000 */
{ 5714660 }, /* unc_q_rxl_cycles_ne_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN0. Unit: uncore_qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715260 }, /* unc_q_rxl_cycles_ne_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCB; for VN1. Unit: uncore_qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCB flits only\000 */
{ 5715860 }, /* unc_q_rxl_cycles_ne_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN0. Unit: uncore_qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5716460 }, /* unc_q_rxl_cycles_ne_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NCS; for VN1. Unit: uncore_qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NCS flits only\000 */
{ 5717060 }, /* unc_q_rxl_cycles_ne_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN0. Unit: uncore_qpi \000event=0x14,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5717660 }, /* unc_q_rxl_cycles_ne_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - NDR; for VN1. Unit: uncore_qpi \000event=0x14,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors NDR flits only\000 */
{ 5718260 }, /* unc_q_rxl_cycles_ne_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN0. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5718860 }, /* unc_q_rxl_cycles_ne_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty - SNP; for VN1. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy.  This monitors SNP flits only\000 */
{ 5720685 }, /* unc_q_rxl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits received over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 5723528 }, /* unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of flits received over QPI that do not hold protocol payload.  When QPI is not in a power saving state, it continuously transmits flits across the link.  When there are no protocol flits to send, it will send IDLE and NULL flits  across.  These flits sometimes do carry a payload, such as credit returns, but are generally not considered part of the QPI bandwidth\000 */
{ 5726356 }, /* unc_q_rxl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits received across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 5729146 }, /* unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data\000 */
{ 5731892 }, /* unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5734688 }, /* unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits received over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits received over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5737511 }, /* unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits received over QPI on the home channel\000 */
{ 5740071 }, /* unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits received over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5742745 }, /* unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request received over QPI on the home channel.  This basically counts the number of remote memory requests received over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5745489 }, /* unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits received over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are received on the home channel\000 */
{ 5748168 }, /* unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5750790 }, /* unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5753552 }, /* unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5756302 }, /* unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits received over QPI.    This includes extended headers\000 */
{ 5758922 }, /* unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5761696 }, /* unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits received over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5763199 }, /* unc_q_rxl_inserts\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x8\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5764941 }, /* unc_q_rxl_inserts_drs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS. Unit: uncore_qpi \000event=0x9\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5763737 }, /* unc_q_rxl_inserts_drs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN0. Unit: uncore_qpi \000event=0x9,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5764339 }, /* unc_q_rxl_inserts_drs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS; for VN1. Unit: uncore_qpi \000event=0x9,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5766724 }, /* unc_q_rxl_inserts_hom\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM. Unit: uncore_qpi \000event=0xc\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5765520 }, /* unc_q_rxl_inserts_hom.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN0. Unit: uncore_qpi \000event=0xc,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5766122 }, /* unc_q_rxl_inserts_hom.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM; for VN1. Unit: uncore_qpi \000event=0xc,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5768507 }, /* unc_q_rxl_inserts_ncb\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB. Unit: uncore_qpi \000event=0xa\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5767303 }, /* unc_q_rxl_inserts_ncb.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN0. Unit: uncore_qpi \000event=0xa,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5767905 }, /* unc_q_rxl_inserts_ncb.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB; for VN1. Unit: uncore_qpi \000event=0xa,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5770290 }, /* unc_q_rxl_inserts_ncs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS. Unit: uncore_qpi \000event=0xb\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5769086 }, /* unc_q_rxl_inserts_ncs.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN0. Unit: uncore_qpi \000event=0xb,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5769688 }, /* unc_q_rxl_inserts_ncs.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS; for VN1. Unit: uncore_qpi \000event=0xb,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5772073 }, /* unc_q_rxl_inserts_ndr\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR. Unit: uncore_qpi \000event=0xe\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5770869 }, /* unc_q_rxl_inserts_ndr.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN0. Unit: uncore_qpi \000event=0xe,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5771471 }, /* unc_q_rxl_inserts_ndr.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR; for VN1. Unit: uncore_qpi \000event=0xe,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5773856 }, /* unc_q_rxl_inserts_snp\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP. Unit: uncore_qpi \000event=0xd\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5772652 }, /* unc_q_rxl_inserts_snp.vn0\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN0. Unit: uncore_qpi \000event=0xd,umask=0x1\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5773254 }, /* unc_q_rxl_inserts_snp.vn1\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP; for VN1. Unit: uncore_qpi \000event=0xd,umask=0x2\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5774435 }, /* unc_q_rxl_occupancy\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - All Packets. Unit: uncore_qpi \000event=0xb\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 5776337 }, /* unc_q_rxl_occupancy_drs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS. Unit: uncore_qpi \000event=0x15\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5775035 }, /* unc_q_rxl_occupancy_drs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x15,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5775686 }, /* unc_q_rxl_occupancy_drs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x15,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5778267 }, /* unc_q_rxl_occupancy_hom\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM. Unit: uncore_qpi \000event=0x18\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5776965 }, /* unc_q_rxl_occupancy_hom.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x18,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5777616 }, /* unc_q_rxl_occupancy_hom.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x18,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5780197 }, /* unc_q_rxl_occupancy_ncb\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB. Unit: uncore_qpi \000event=0x16\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5778895 }, /* unc_q_rxl_occupancy_ncb.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x16,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5779546 }, /* unc_q_rxl_occupancy_ncb.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x16,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5782127 }, /* unc_q_rxl_occupancy_ncs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS. Unit: uncore_qpi \000event=0x17\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5780825 }, /* unc_q_rxl_occupancy_ncs.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x17,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5781476 }, /* unc_q_rxl_occupancy_ncs.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x17,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5784057 }, /* unc_q_rxl_occupancy_ndr\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR. Unit: uncore_qpi \000event=0x1a\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5782755 }, /* unc_q_rxl_occupancy_ndr.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN0. Unit: uncore_qpi \000event=0x1a,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5783406 }, /* unc_q_rxl_occupancy_ndr.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR; for VN1. Unit: uncore_qpi \000event=0x1a,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5785987 }, /* unc_q_rxl_occupancy_snp\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP. Unit: uncore_qpi \000event=0x19\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5784685 }, /* unc_q_rxl_occupancy_snp.vn0\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x19,umask=0x1\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5785336 }, /* unc_q_rxl_occupancy_snp.vn1\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x19,umask=0x2\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5788063 }, /* unc_q_rxl_stalls_vn0.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788473 }, /* unc_q_rxl_stalls_vn0.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5788883 }, /* unc_q_rxl_stalls_vn0.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789293 }, /* unc_q_rxl_stalls_vn0.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5789703 }, /* unc_q_rxl_stalls_vn0.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790114 }, /* unc_q_rxl_stalls_vn0.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5790525 }, /* unc_q_rxl_stalls_vn0.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled a packet because there were insufficient BGF credits.  For details on a message class granularity, use the Egress Credit Occupancy events\000 */
{ 5790893 }, /* unc_q_rxl_stalls_vn0.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN0; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 0; Stalled because a GV transition (frequency transition) was taking place\000 */
{ 5791163 }, /* unc_q_rxl_stalls_vn1.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - HOM. Unit: uncore_qpi \000event=0x3a,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the HOM message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791574 }, /* unc_q_rxl_stalls_vn1.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - DRS. Unit: uncore_qpi \000event=0x3a,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the DRS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5791985 }, /* unc_q_rxl_stalls_vn1.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - SNP. Unit: uncore_qpi \000event=0x3a,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the SNP message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792396 }, /* unc_q_rxl_stalls_vn1.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NDR. Unit: uncore_qpi \000event=0x3a,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NDR message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5792807 }, /* unc_q_rxl_stalls_vn1.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCS. Unit: uncore_qpi \000event=0x3a,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCS message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793219 }, /* unc_q_rxl_stalls_vn1.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI on VN1; BGF Stall - NCB. Unit: uncore_qpi \000event=0x3a,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI on Virtual Network 1.; Stalled a packet from the NCB message class because there were not enough BGF credits.  In bypass mode, we will stall on the packet boundary, while in RxQ mode we will stall on the flit boundary\000 */
{ 5793631 }, /* unc_q_txl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xc\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5794182 }, /* unc_q_txl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0xd\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5794851 }, /* unc_q_txl_bypassed\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x5\000\00001\000Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the QPI Link. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5795291 }, /* unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is almost full, we block some but not all packets\000 */
{ 5795874 }, /* unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall.; When LLR is totally full, we are not allowed to send any packets\000 */
{ 5796435 }, /* unc_q_txl_cycles_ne\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Cycles not Empty. Unit: uncore_qpi \000event=0x6\000\00001\000Counts the number of cycles when the TxQ is not empty. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5798047 }, /* unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of data flits transmitted over QPI.  Each flit contains 64b of data.  This includes both DRS and NCB data flits (coherent and non-coherent).  This can be used to calculate the data bandwidth of the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This does not include the header flits that go in data packets\000 */
{ 5802153 }, /* unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p.; Number of non-NULL non-data flits transmitted across QPI.  This basically tracks the protocol overhead on the QPI link.  One can get a good picture of the QPI-link characteristics by evaluating the protocol flits, data flits, and idle/null flits.  This includes the header flits for data packets\000 */
{ 5804958 }, /* unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency\000 */
{ 5807622 }, /* unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of data flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the data flits (not the header)\000 */
{ 5810436 }, /* unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of protocol flits transmitted over QPI on the DRS (Data Response) channel.  DRS flits are used to transmit data with coherency.  This does not count data flits transmitted over the NCB channel which transmits non-coherent data.  This includes only the header flits (not the data).  This includes extended headers\000 */
{ 5813277 }, /* unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of flits transmitted over QPI on the home channel\000 */
{ 5815852 }, /* unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of non-request flits transmitted over QPI on the home channel.  These are most commonly snoop responses, and this event can be used as a proxy for that\000 */
{ 5818541 }, /* unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of data request transmitted over QPI on the home channel.  This basically counts the number of remote memory requests transmitted over QPI.  In conjunction with the local read count in the Home Agent, one can calculate the number of LLC Misses\000 */
{ 5821303 }, /* unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the number of snoop request flits transmitted over QPI.  These requests are contained in the snoop channel.  This does not include snoop responses, which are transmitted on the home channel\000 */
{ 5824009 }, /* unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass flits.  These packets are generally used to transmit non-coherent data across QPI\000 */
{ 5826654 }, /* unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass data flits.  These flits are generally used to transmit non-coherent data across QPI.  This does not include a count of the DRS (coherent) data flits.  This only counts the data flits, not the NCB headers\000 */
{ 5829432 }, /* unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of Non-Coherent Bypass non-data flits.  These packets are generally used to transmit non-coherent data across QPI, and the flits counted here are for headers and other non-data flits.  This includes extended headers\000 */
{ 5832198 }, /* unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Number of NCS (non-coherent standard) flits transmitted over QPI.    This includes extended headers\000 */
{ 5834837 }, /* unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets to the local socket which use the AK ring\000 */
{ 5837630 }, /* unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three groups that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each flit is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four fits, each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI speed (for example, 8.0 GT/s), the transfers here refer to fits.  Therefore, in L0, the system will transfer 1 flit at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as data bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual data and an additional 16 bits of other information.  To calculate data bandwidth, one should therefore do: data flits * 8B / time.; Counts the total number of flits transmitted over the NDR (Non-Data Response) channel.  This channel is used to send a variety of protocol flits including grants and completions.  This is only for NDR packets destined for Route-thru to a remote socket\000 */
{ 5839144 }, /* unc_q_txl_inserts\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x4\000\00001\000Number of allocations into the QPI Tx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5839647 }, /* unc_q_txl_occupancy\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_qpi \000event=0x7\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 5840151 }, /* unc_q_txr_ad_hom_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN0. Unit: uncore_qpi \000event=0x26,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840446 }, /* unc_q_txr_ad_hom_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - HOM; for VN1. Unit: uncore_qpi \000event=0x26,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle. Flow Control FIFO for Home messages on AD\000 */
{ 5840741 }, /* unc_q_txr_ad_hom_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN0. Unit: uncore_qpi \000event=0x22,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841076 }, /* unc_q_txr_ad_hom_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD HOM; for VN1. Unit: uncore_qpi \000event=0x22,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for HOM messages on AD\000 */
{ 5841411 }, /* unc_q_txr_ad_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x28,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5841709 }, /* unc_q_txr_ad_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x28,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for NDR messages on AD\000 */
{ 5842007 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN0. Unit: uncore_qpi \000event=0x24,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842342 }, /* unc_q_txr_ad_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD NDR; for VN1. Unit: uncore_qpi \000event=0x24,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle. Flow Control FIFO  for NDR messages on AD\000 */
{ 5842677 }, /* unc_q_txr_ad_snp_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN0. Unit: uncore_qpi \000event=0x27,umask=0x1\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5842974 }, /* unc_q_txr_ad_snp_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - SNP; for VN1. Unit: uncore_qpi \000event=0x27,umask=0x2\000\00001\000Number of link layer credits into the R3 (for transactions across the BGF) acquired each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843271 }, /* unc_q_txr_ad_snp_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN0. Unit: uncore_qpi \000event=0x23,umask=0x1\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5843608 }, /* unc_q_txr_ad_snp_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AD SNP; for VN1. Unit: uncore_qpi \000event=0x23,umask=0x2\000\00001\000Occupancy event that tracks the number of link layer credits into the R3 (for transactions across the BGF) available in each cycle.  Flow Control FIFO for Snoop messages on AD\000 */
{ 5844509 }, /* unc_q_txr_ak_ndr_credit_acquired\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x29\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000 */
{ 5843945 }, /* unc_q_txr_ak_ndr_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN0. Unit: uncore_qpi \000event=0x29,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000 */
{ 5844227 }, /* unc_q_txr_ak_ndr_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN1. Unit: uncore_qpi \000event=0x29,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. Local NDR message class to AK Egress\000 */
{ 5845408 }, /* unc_q_txr_ak_ndr_credit_occupancy\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR. Unit: uncore_qpi \000event=0x25\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000 */
{ 5844768 }, /* unc_q_txr_ak_ndr_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN0. Unit: uncore_qpi \000event=0x25,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000 */
{ 5845088 }, /* unc_q_txr_ak_ndr_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - AK NDR: for VN1. Unit: uncore_qpi \000event=0x25,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  Local NDR message class to AK Egress\000 */
{ 5845705 }, /* unc_q_txr_bl_drs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN0. Unit: uncore_qpi \000event=0x2a,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5845978 }, /* unc_q_txr_bl_drs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for VN1. Unit: uncore_qpi \000event=0x2a,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846251 }, /* unc_q_txr_bl_drs_credit_acquired.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - DRS; for Shared VN. Unit: uncore_qpi \000event=0x2a,umask=0x4\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. DRS message class to BL Egress\000 */
{ 5846533 }, /* unc_q_txr_bl_drs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN0. Unit: uncore_qpi \000event=0x1f,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5846847 }, /* unc_q_txr_bl_drs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for VN1. Unit: uncore_qpi \000event=0x1f,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847161 }, /* unc_q_txr_bl_drs_credit_occupancy.vn_shr\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL DRS; for Shared VN. Unit: uncore_qpi \000event=0x1f,umask=0x4\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  DRS message class to BL Egress\000 */
{ 5847484 }, /* unc_q_txr_bl_ncb_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN0. Unit: uncore_qpi \000event=0x2b,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5847757 }, /* unc_q_txr_bl_ncb_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCB; for VN1. Unit: uncore_qpi \000event=0x2b,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCB message class to BL Egress\000 */
{ 5848030 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN0. Unit: uncore_qpi \000event=0x20,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848344 }, /* unc_q_txr_bl_ncb_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCB; for VN1. Unit: uncore_qpi \000event=0x20,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCB message class to BL Egress\000 */
{ 5848658 }, /* unc_q_txr_bl_ncs_credit_acquired.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN0. Unit: uncore_qpi \000event=0x2c,umask=0x1\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5848931 }, /* unc_q_txr_bl_ncs_credit_acquired.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - NCS; for VN1. Unit: uncore_qpi \000event=0x2c,umask=0x2\000\00001\000Number of credits into the R3 (for transactions across the BGF) acquired each cycle. NCS message class to BL Egress\000 */
{ 5849204 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn0\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN0. Unit: uncore_qpi \000event=0x21,umask=0x1\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849518 }, /* unc_q_txr_bl_ncs_credit_occupancy.vn1\000uncore_qpi\000uncore interconnect\000R3QPI Egress Credit Occupancy - BL NCS; for VN1. Unit: uncore_qpi \000event=0x21,umask=0x2\000\00001\000Occupancy event that tracks the number of credits into the R3 (for transactions across the BGF) available in each cycle.  NCS message class to BL Egress\000 */
{ 5849832 }, /* unc_q_vna_credit_return_occupancy\000uncore_qpi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_qpi \000event=0x1b\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 5850059 }, /* unc_q_vna_credit_returns\000uncore_qpi\000uncore interconnect\000VNA Credits Returned. Unit: uncore_qpi \000event=0x1c\000\00001\000Number of VNA credits returned\000 */
{ 5902597 }, /* unc_r3_c_hi_ad_credits_empty.cbo10\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 10\000 */
{ 5903037 }, /* unc_r3_c_hi_ad_credits_empty.cbo11\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 11\000 */
{ 5903478 }, /* unc_r3_c_hi_ad_credits_empty.cbo12\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 12\000 */
{ 5903920 }, /* unc_r3_c_hi_ad_credits_empty.cbo13\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 13\000 */
{ 5904141 }, /* unc_r3_c_hi_ad_credits_empty.cbo14\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 14&16\000 */
{ 5904810 }, /* unc_r3_c_hi_ad_credits_empty.cbo8\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 8\000 */
{ 5905246 }, /* unc_r3_c_hi_ad_credits_empty.cbo9\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2c,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes); Cbox 9\000 */
{ 5905909 }, /* unc_r3_c_lo_ad_credits_empty.cbo0\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 0\000 */
{ 5906343 }, /* unc_r3_c_lo_ad_credits_empty.cbo1\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 1\000 */
{ 5906777 }, /* unc_r3_c_lo_ad_credits_empty.cbo2\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 2\000 */
{ 5907211 }, /* unc_r3_c_lo_ad_credits_empty.cbo3\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 3\000 */
{ 5907646 }, /* unc_r3_c_lo_ad_credits_empty.cbo4\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x10\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 4\000 */
{ 5908082 }, /* unc_r3_c_lo_ad_credits_empty.cbo5\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x20\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 5\000 */
{ 5908518 }, /* unc_r3_c_lo_ad_credits_empty.cbo6\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x40\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 6\000 */
{ 5908954 }, /* unc_r3_c_lo_ad_credits_empty.cbo7\000uncore_r3qpi\000uncore interconnect\000CBox AD Credits Empty. Unit: uncore_r3qpi \000event=0x2b,umask=0x80\000\00001\000No credits available to send to Cbox on the AD Ring (covers lower CBoxes); Cbox 7\000 */
{ 5909172 }, /* unc_r3_clockticks\000uncore_r3qpi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_r3qpi \000event=0x1\000\00001\000Counts the number of uclks in the QPI uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the QPI Agent is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5909754 }, /* unc_r3_ha_r2_bl_credits_empty.ha0\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x1\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA0\000 */
{ 5910162 }, /* unc_r3_ha_r2_bl_credits_empty.ha1\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x2\000\00001\000No credits available to send to either HA or R2 on the BL Ring; HA1\000 */
{ 5910585 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncb\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x4\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCB Messages\000 */
{ 5911023 }, /* unc_r3_ha_r2_bl_credits_empty.r2_ncs\000uncore_r3qpi\000uncore interconnect\000HA/R2 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2f,umask=0x8\000\00001\000No credits available to send to either HA or R2 on the BL Ring; R2 NCS Messages\000 */
{ 5917606 }, /* unc_r3_qpi0_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x2\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 HOM Messages\000 */
{ 5918022 }, /* unc_r3_qpi0_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x8\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 NDR Messages\000 */
{ 5918438 }, /* unc_r3_qpi0_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x4\000\00001\000No credits available to send to QPI0 on the AD Ring; VN0 SNP Messages\000 */
{ 5918855 }, /* unc_r3_qpi0_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x10\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 HOM Messages\000 */
{ 5919273 }, /* unc_r3_qpi0_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x40\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 NDR Messages\000 */
{ 5919691 }, /* unc_r3_qpi0_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x20\000\00001\000No credits available to send to QPI0 on the AD Ring; VN1 SNP Messages\000 */
{ 5920091 }, /* unc_r3_qpi0_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 AD Credits Empty. Unit: uncore_r3qpi \000event=0x29,umask=0x1\000\00001\000No credits available to send to QPI0 on the AD Ring; VNA\000 */
{ 5920282 }, /* unc_r3_qpi0_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x2\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 HOM Messages\000 */
{ 5920490 }, /* unc_r3_qpi0_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x8\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 NDR Messages\000 */
{ 5920698 }, /* unc_r3_qpi0_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x4\000\00001\000No credits available to send to QPI0 on the BL Ring; VN0 SNP Messages\000 */
{ 5921115 }, /* unc_r3_qpi0_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x10\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 HOM Messages\000 */
{ 5921533 }, /* unc_r3_qpi0_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x40\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 NDR Messages\000 */
{ 5921951 }, /* unc_r3_qpi0_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x20\000\00001\000No credits available to send to QPI0 on the BL Ring; VN1 SNP Messages\000 */
{ 5922351 }, /* unc_r3_qpi0_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI0 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2d,umask=0x1\000\00001\000No credits available to send to QPI0 on the BL Ring; VNA\000 */
{ 5922542 }, /* unc_r3_qpi1_ad_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x2\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 HOM Messages\000 */
{ 5922750 }, /* unc_r3_qpi1_ad_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x8\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 NDR Messages\000 */
{ 5922958 }, /* unc_r3_qpi1_ad_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x4\000\00001\000No credits available to send to QPI1 on the AD Ring; VN0 SNP Messages\000 */
{ 5923166 }, /* unc_r3_qpi1_ad_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x10\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 HOM Messages\000 */
{ 5923584 }, /* unc_r3_qpi1_ad_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x40\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 NDR Messages\000 */
{ 5924002 }, /* unc_r3_qpi1_ad_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x20\000\00001\000No credits available to send to QPI1 on the AD Ring; VN1 SNP Messages\000 */
{ 5924420 }, /* unc_r3_qpi1_ad_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 AD Credits Empty. Unit: uncore_r3qpi \000event=0x2a,umask=0x1\000\00001\000No credits available to send to QPI1 on the AD Ring; VNA\000 */
{ 5924802 }, /* unc_r3_qpi1_bl_credits_empty.vn0_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x2\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 HOM Messages\000 */
{ 5925218 }, /* unc_r3_qpi1_bl_credits_empty.vn0_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x8\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 NDR Messages\000 */
{ 5925634 }, /* unc_r3_qpi1_bl_credits_empty.vn0_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x4\000\00001\000No credits available to send to QPI1 on the BL Ring; VN0 SNP Messages\000 */
{ 5926050 }, /* unc_r3_qpi1_bl_credits_empty.vn1_hom\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x10\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 HOM Messages\000 */
{ 5926468 }, /* unc_r3_qpi1_bl_credits_empty.vn1_ndr\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x40\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 NDR Messages\000 */
{ 5926886 }, /* unc_r3_qpi1_bl_credits_empty.vn1_snp\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x20\000\00001\000No credits available to send to QPI1 on the BL Ring; VN1 SNP Messages\000 */
{ 5927304 }, /* unc_r3_qpi1_bl_credits_empty.vna\000uncore_r3qpi\000uncore interconnect\000QPI1 BL Credits Empty. Unit: uncore_r3qpi \000event=0x2e,umask=0x1\000\00001\000No credits available to send to QPI1 on the BL Ring; VNA\000 */
{ 5928393 }, /* unc_r3_ring_ad_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x7,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5930361 }, /* unc_r3_ring_ad_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5930826 }, /* unc_r3_ring_ad_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5931288 }, /* unc_r3_ring_ad_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x7,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5933554 }, /* unc_r3_ring_ad_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5934004 }, /* unc_r3_ring_ad_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5935158 }, /* unc_r3_ring_ak_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x8,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5937126 }, /* unc_r3_ring_ak_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5937591 }, /* unc_r3_ring_ak_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5938053 }, /* unc_r3_ring_ak_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x8,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5940319 }, /* unc_r3_ring_ak_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5940769 }, /* unc_r3_ring_ak_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5941923 }, /* unc_r3_ring_bl_used.ccw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0x9,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5943891 }, /* unc_r3_ring_bl_used.ccw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5944356 }, /* unc_r3_ring_bl_used.ccw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5944818 }, /* unc_r3_ring_bl_used.cw\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0x9,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5947084 }, /* unc_r3_ring_bl_used.cw_vr0_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5947534 }, /* unc_r3_ring_bl_used.cw_vr0_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5947981 }, /* unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xff\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters any polarity\000 */
{ 5949462 }, /* unc_r3_ring_iv_used.ccw\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r3qpi \000event=0xa,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Counterclockwise polarity\000 */
{ 5950071 }, /* unc_r3_ring_iv_used.cw\000uncore_r3qpi\000uncore interconnect\000R2 IV Ring in Use; Clockwise. Unit: uncore_r3qpi \000event=0xa,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Clockwise polarity\000 */
{ 5951203 }, /* unc_r3_rxr_ad_bypassed\000uncore_r3qpi\000uncore interconnect\000AD Ingress Bypassed. Unit: uncore_r3qpi \000event=0x12\000\00001\000Counts the number of times when the AD Ingress was bypassed and an incoming transaction was bypassed directly across the BGF and into the qfclk domain\000 */
{ 5951466 }, /* unc_r3_rxr_bypassed.ad\000uncore_r3qpi\000uncore interconnect\000Ingress Bypassed. Unit: uncore_r3qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of times when the Ingress was bypassed and an incoming transaction was bypassed directly across the BGF and into the qfclk domain\000 */
{ 5952208 }, /* unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5954130 }, /* unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5955100 }, /* unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5959150 }, /* unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; DRS Ingress Queue\000 */
{ 5960086 }, /* unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; HOM Ingress Queue\000 */
{ 5961022 }, /* unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5961960 }, /* unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5962898 }, /* unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NDR Ingress Queue\000 */
{ 5963834 }, /* unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; SNP Ingress Queue\000 */
{ 5967748 }, /* unc_r3_rxr_occupancy.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5968630 }, /* unc_r3_rxr_occupancy.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; HOM Ingress Queue\000 */
{ 5969512 }, /* unc_r3_rxr_occupancy.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NCB Ingress Queue\000 */
{ 5970396 }, /* unc_r3_rxr_occupancy.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NCS Ingress Queue\000 */
{ 5971280 }, /* unc_r3_rxr_occupancy.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; NDR Ingress Queue\000 */
{ 5972162 }, /* unc_r3_rxr_occupancy.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency.; SNP Ingress Queue\000 */
{ 5979508 }, /* unc_r3_txr_nack_ccw.ad\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AK CCW. Unit: uncore_r3qpi \000event=0x28,umask=0x1\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5979663 }, /* unc_r3_txr_nack_ccw.ak\000uncore_r3qpi\000uncore interconnect\000Egress NACK; BL CW. Unit: uncore_r3qpi \000event=0x28,umask=0x2\000\00001\000AD Clockwise Egress Queue\000 */
{ 5979810 }, /* unc_r3_txr_nack_ccw.bl\000uncore_r3qpi\000uncore interconnect\000Egress NACK; BL CCW. Unit: uncore_r3qpi \000event=0x28,umask=0x4\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5979965 }, /* unc_r3_txr_nack_cw.ad\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AD CW. Unit: uncore_r3qpi \000event=0x26,umask=0x1\000\00001\000AD Clockwise Egress Queue\000 */
{ 5980111 }, /* unc_r3_txr_nack_cw.ak\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AD CCW. Unit: uncore_r3qpi \000event=0x26,umask=0x2\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5980265 }, /* unc_r3_txr_nack_cw.bl\000uncore_r3qpi\000uncore interconnect\000Egress NACK; AK CW. Unit: uncore_r3qpi \000event=0x26,umask=0x4\000\00001\000BL Clockwise Egress Queue\000 */
{ 5980411 }, /* unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5982203 }, /* unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5983926 }, /* unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5985675 }, /* unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5987347 }, /* unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5989049 }, /* unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 5990780 }, /* unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 5992862 }, /* unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 5994875 }, /* unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5996914 }, /* unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 5998876 }, /* unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6000868 }, /* unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6002889 }, /* unc_r3_vn1_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x8\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6003877 }, /* unc_r3_vn1_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x1\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6004796 }, /* unc_r3_vn1_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x10\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6005740 }, /* unc_r3_vn1_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x20\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6006607 }, /* unc_r3_vn1_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x4\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6007505 }, /* unc_r3_vn1_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x39,umask=0x2\000\00001\000Number of times a request failed to acquire a VN1 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN1 credit and is delayed.  This should generally be a rare situation.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6008432 }, /* unc_r3_vn1_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x8\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6009569 }, /* unc_r3_vn1_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x1\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6010637 }, /* unc_r3_vn1_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x10\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6011730 }, /* unc_r3_vn1_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x20\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Non-Coherent Standard (NCS).  NCS is commonly used for ?\000 */
{ 6012746 }, /* unc_r3_vn1_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x4\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6013793 }, /* unc_r3_vn1_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN1 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x38,umask=0x2\000\00001\000Number of times a VN1 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6014869 }, /* unc_r3_vna_credit_cycles_out\000uncore_r3qpi\000uncore interconnect\000Cycles with no VNA credits available. Unit: uncore_r3qpi \000event=0x31\000\00001\000Number of QPI uclk cycles when the transmitted has no VNA credits available and therefore cannot send any requests on this channel.  Note that this does not mean that no flits can be transmitted, as those holding VN0 credits will still (potentially) be able to transmit.  Generally it is the goal of the uncore that VNA credits should not run out, as this can substantially throttle back useful QPI bandwidth\000 */
{ 6015413 }, /* unc_r3_vna_credit_cycles_used\000uncore_r3qpi\000uncore interconnect\000Cycles with 1 or more VNA credits in use. Unit: uncore_r3qpi \000event=0x32\000\00001\000Number of QPI uclk cycles with one or more VNA credits in use.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average number of used VNA credits\000 */
{ 6017643 }, /* unc_r3_vna_credits_acquired\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions. Unit: uncore_r3qpi \000event=0x33\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event\000 */
{ 6015739 }, /* unc_r3_vna_credits_acquired.ad\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x1\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6016691 }, /* unc_r3_vna_credits_acquired.bl\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions; HOM Message Class. Unit: uncore_r3qpi \000event=0x33,umask=0x4\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6018440 }, /* unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Data Response (DRS).  DRS is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using DRS\000 */
{ 6020284 }, /* unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for the Home (HOM) message class.  HOM is generally used to send requests, request responses, and snoop responses\000 */
{ 6022059 }, /* unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Broadcast (NCB).  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 6023860 }, /* unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Non-Coherent Standard (NCS)\000 */
{ 6025555 }, /* unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; NDR packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 6027309 }, /* unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough.; Filter for Snoop (SNP) message class.  SNP is used for outgoing snoops.  Note that snoop responses flow on the HOM message class\000 */
{ 6073609 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Unit: uncore_ubox \000event=0\000\00001\000\000 */
{ 6074014 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6074623 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6075264 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076060 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076708 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076954 }, /* unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077187 }, /* unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077419 }, /* unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077656 }, /* unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6078090 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6081974 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6083190 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000\000 */
{ 6083291 }, /* unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6083494 }, /* unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6083890 }, /* unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084282 }, /* unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6084686 }, /* unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores; Filter by core\000 */
{ 6085090 }, /* unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores; PREQ, PSMI, P2U, Thermal, PCUSMI, PMI\000 */
{ 6085499 }, /* unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085682 }, /* unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 5850201 }, /* unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5851083 }, /* unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5852294 }, /* unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5853507 }, /* unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5854720 }, /* unc_r2_iio_credits_reject.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; DRS. Unit: uncore_r2pcie \000event=0x34,umask=0x8\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5856769 }, /* unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the DRS message class\000 */
{ 5857982 }, /* unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCB message class\000 */
{ 5859197 }, /* unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly).; Credits to the IIO for the NCS message class\000 */
{ 5861103 }, /* unc_r2_ring_ad_used.ccw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x7,umask=0xcc\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5863031 }, /* unc_r2_ring_ad_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5863488 }, /* unc_r2_ring_ad_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5863942 }, /* unc_r2_ring_ad_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x40\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5864400 }, /* unc_r2_ring_ad_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x80\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5864855 }, /* unc_r2_ring_ad_used.cw\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x7,umask=0x33\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5867073 }, /* unc_r2_ring_ad_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5867515 }, /* unc_r2_ring_ad_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5867954 }, /* unc_r2_ring_ad_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x10\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5868397 }, /* unc_r2_ring_ad_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x7,umask=0x20\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5869924 }, /* unc_r2_ring_ak_used.ccw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x8,umask=0xcc\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5871852 }, /* unc_r2_ring_ak_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5872309 }, /* unc_r2_ring_ak_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5872763 }, /* unc_r2_ring_ak_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x40\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5873221 }, /* unc_r2_ring_ak_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x80\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5873676 }, /* unc_r2_ring_ak_used.cw\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x8,umask=0x33\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5875894 }, /* unc_r2_ring_ak_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5876336 }, /* unc_r2_ring_ak_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5876775 }, /* unc_r2_ring_ak_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x10\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5877218 }, /* unc_r2_ring_ak_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x8,umask=0x20\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5878349 }, /* unc_r2_ring_bl_used.ccw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0x9,umask=0xcc\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5880277 }, /* unc_r2_ring_bl_used.ccw_vr0_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5880734 }, /* unc_r2_ring_bl_used.ccw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5881188 }, /* unc_r2_ring_bl_used.ccw_vr1_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x40\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5881646 }, /* unc_r2_ring_bl_used.ccw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x80\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Counterclockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5882101 }, /* unc_r2_ring_bl_used.cw\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0x9,umask=0x33\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5884319 }, /* unc_r2_ring_bl_used.cw_vr0_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 0\000 */
{ 5884761 }, /* unc_r2_ring_bl_used.cw_vr0_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd on VRing 0. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 0\000 */
{ 5885200 }, /* unc_r2_ring_bl_used.cw_vr1_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x10\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Even ring polarity on Virtual Ring 1\000 */
{ 5885643 }, /* unc_r2_ring_bl_used.cw_vr1_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd on VRing 1. Unit: uncore_r2pcie \000event=0x9,umask=0x20\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.; Filters for the Clockwise and Odd ring polarity on Virtual Ring 1\000 */
{ 5886969 }, /* unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xff\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters any polarity\000 */
{ 5887892 }, /* unc_r2_ring_iv_used.ccw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Counterclockwise. Unit: uncore_r2pcie \000event=0xa,umask=0xcc\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Counterclockwise polarity\000 */
{ 5888493 }, /* unc_r2_ring_iv_used.cw\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Clockwise. Unit: uncore_r2pcie \000event=0xa,umask=0x33\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time.; Filters for Clockwise polarity\000 */
{ 5889839 }, /* unc_r2_rxr_ak_bounces\000uncore_r2pcie\000uncore io\000AK Ingress Bounced. Unit: uncore_r2pcie \000event=0x12\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5889423 }, /* unc_r2_rxr_ak_bounces.ccw\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Counterclockwise. Unit: uncore_r2pcie \000event=0x12,umask=0x2\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5889635 }, /* unc_r2_rxr_ak_bounces.cw\000uncore_r2pcie\000uncore io\000AK Ingress Bounced; Clockwise. Unit: uncore_r2pcie \000event=0x12,umask=0x1\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5890495 }, /* unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5891469 }, /* unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5892443 }, /* unc_r2_rxr_inserts.ncb\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCB. Unit: uncore_r2pcie \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCB Ingress Queue\000 */
{ 5892923 }, /* unc_r2_rxr_inserts.ncs\000uncore_r2pcie\000uncore io\000Ingress Allocations; NCS. Unit: uncore_r2pcie \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the R2PCIe Ingress.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; NCS Ingress Queue\000 */
{ 5893403 }, /* unc_r2_rxr_occupancy.drs\000uncore_r2pcie\000uncore io\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r2pcie \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given R2PCIe Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the R2PCIe Ingress Not Empty event to calculate average occupancy or the R2PCIe Ingress Allocations event in order to calculate average queuing latency.; DRS Ingress Queue\000 */
{ 5895645 }, /* unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AD Egress Queue\000 */
{ 5896035 }, /* unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; AK Egress Queue\000 */
{ 5896425 }, /* unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full.; BL Egress Queue\000 */
{ 5896815 }, /* unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AD Egress Queue\000 */
{ 5897859 }, /* unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; AK Egress Queue\000 */
{ 5898903 }, /* unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity.; BL Egress Queue\000 */
{ 5899947 }, /* unc_r2_txr_nack_ccw.ad\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AD CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x1\000\00001\000AD CounterClockwise Egress Queue\000 */
{ 5900098 }, /* unc_r2_txr_nack_ccw.ak\000uncore_r2pcie\000uncore io\000Egress CCW NACK; AK CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x2\000\00001\000AK CounterClockwise Egress Queue\000 */
{ 5900249 }, /* unc_r2_txr_nack_ccw.bl\000uncore_r2pcie\000uncore io\000Egress CCW NACK; BL CCW. Unit: uncore_r2pcie \000event=0x28,umask=0x4\000\00001\000BL CounterClockwise Egress Queue\000 */
{ 5900400 }, /* unc_r2_txr_nack_cw.ad\000uncore_r2pcie\000uncore io\000Egress CW NACK; AD CW. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000AD Clockwise Egress Queue\000 */
{ 5900541 }, /* unc_r2_txr_nack_cw.ak\000uncore_r2pcie\000uncore io\000Egress CW NACK; AK CW. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000AK Clockwise Egress Queue\000 */
{ 5900682 }, /* unc_r2_txr_nack_cw.bl\000uncore_r2pcie\000uncore io\000Egress CW NACK; BL CW. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000BL Clockwise Egress Queue\000 */
{ 5376386 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377260 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Write. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5380151 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5382226 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Read CAS commands issued on this channel (including underfills)\000 */
{ 5385713 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5386574 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5386724 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the number of underfill reads that are issued by the memory controller.  This will generally be about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ.  While it is possible for underfills to be issed in both WMM and RMM, this event counts both\000 */
{ 5388684 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5389726 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5391708 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392506 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000DRAM RD_CAS and WR_CAS Commands; Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5395982 }, /* unc_m_dclockticks\000uncore_imc\000uncore memory\000DRAM Clockticks. Unit: uncore_imc \000event=0\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417303 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430201 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5430855 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5439445 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of page misses.  This does not include explicit precharge commands sent with CAS commands in Auto-Precharge mode.  This does not include PRE commands sent as a result of the page close counter expiration\000 */
{ 5442207 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to read. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5444600 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to write. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449654 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000\000 */
{ 5452079 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000\000 */
{ 5452492 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000\000 */
{ 5452905 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000\000 */
{ 5453032 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000\000 */
{ 5453446 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x20\000\00001\000\000 */
{ 5453860 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x40\000\00001\000\000 */
{ 5454560 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x80\000\00001\000\000 */
{ 5456948 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000\000 */
{ 5459373 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000\000 */
{ 5459786 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000\000 */
{ 5460199 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000\000 */
{ 5460326 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000\000 */
{ 5460740 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x20\000\00001\000\000 */
{ 5461154 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x40\000\00001\000\000 */
{ 5461854 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x80\000\00001\000\000 */
{ 5464073 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2,umask=0x1\000\00001\000\000 */
{ 5465367 }, /* unc_m_rd_cas_rank2.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xb2,umask=0x2\000\00001\000\000 */
{ 5465621 }, /* unc_m_rd_cas_rank2.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xb2,umask=0x4\000\00001\000\000 */
{ 5465875 }, /* unc_m_rd_cas_rank2.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xb2,umask=0x8\000\00001\000\000 */
{ 5466002 }, /* unc_m_rd_cas_rank2.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xb2,umask=0x10\000\00001\000\000 */
{ 5466257 }, /* unc_m_rd_cas_rank2.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xb2,umask=0x20\000\00001\000\000 */
{ 5466512 }, /* unc_m_rd_cas_rank2.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xb2,umask=0x40\000\00001\000\000 */
{ 5466894 }, /* unc_m_rd_cas_rank2.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xb2,umask=0x80\000\00001\000\000 */
{ 5468001 }, /* unc_m_rd_cas_rank3.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xb3,umask=0x1\000\00001\000\000 */
{ 5469146 }, /* unc_m_rd_cas_rank3.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xb3,umask=0x2\000\00001\000\000 */
{ 5469400 }, /* unc_m_rd_cas_rank3.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xb3,umask=0x4\000\00001\000\000 */
{ 5469654 }, /* unc_m_rd_cas_rank3.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xb3,umask=0x8\000\00001\000\000 */
{ 5469781 }, /* unc_m_rd_cas_rank3.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xb3,umask=0x10\000\00001\000\000 */
{ 5470036 }, /* unc_m_rd_cas_rank3.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xb3,umask=0x20\000\00001\000\000 */
{ 5470291 }, /* unc_m_rd_cas_rank3.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xb3,umask=0x40\000\00001\000\000 */
{ 5470673 }, /* unc_m_rd_cas_rank3.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xb3,umask=0x80\000\00001\000\000 */
{ 5471949 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000\000 */
{ 5474374 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000\000 */
{ 5474787 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000\000 */
{ 5475200 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000\000 */
{ 5475327 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000\000 */
{ 5475741 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x20\000\00001\000\000 */
{ 5476155 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x40\000\00001\000\000 */
{ 5476855 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x80\000\00001\000\000 */
{ 5479243 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000\000 */
{ 5481668 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000\000 */
{ 5482081 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000\000 */
{ 5482494 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000\000 */
{ 5482621 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000\000 */
{ 5483035 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x20\000\00001\000\000 */
{ 5483449 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x40\000\00001\000\000 */
{ 5484149 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x80\000\00001\000\000 */
{ 5486537 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000\000 */
{ 5488962 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000\000 */
{ 5489375 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000\000 */
{ 5489788 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000\000 */
{ 5489915 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000\000 */
{ 5490329 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x20\000\00001\000\000 */
{ 5490743 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x40\000\00001\000\000 */
{ 5491443 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x80\000\00001\000\000 */
{ 5493831 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000\000 */
{ 5496256 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000\000 */
{ 5496669 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000\000 */
{ 5497082 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000\000 */
{ 5497209 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000\000 */
{ 5497623 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x20\000\00001\000\000 */
{ 5498037 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x40\000\00001\000\000 */
{ 5498737 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x80\000\00001\000\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5508571 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5534086 }, /* unc_m_vmse_mxb_wr_occupancy\000uncore_imc\000uncore memory\000VMSE MXB write buffer occupancy. Unit: uncore_imc \000event=0x91\000\00001\000\000 */
{ 5534206 }, /* unc_m_vmse_wr_push.rmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in RMM. Unit: uncore_imc \000event=0x90,umask=0x2\000\00001\000\000 */
{ 5534350 }, /* unc_m_vmse_wr_push.wmm\000uncore_imc\000uncore memory\000VMSE WR PUSH issued; VMSE write PUSH issued in WMM. Unit: uncore_imc \000event=0x90,umask=0x1\000\00001\000\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5534994 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5540700 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5543870 }, /* unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556798 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000\000 */
{ 5559223 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000\000 */
{ 5559636 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000\000 */
{ 5560049 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000\000 */
{ 5560176 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000\000 */
{ 5560590 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x20\000\00001\000\000 */
{ 5561004 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x40\000\00001\000\000 */
{ 5561704 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x80\000\00001\000\000 */
{ 5564092 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000\000 */
{ 5566517 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000\000 */
{ 5566930 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000\000 */
{ 5567343 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000\000 */
{ 5567470 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000\000 */
{ 5567884 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x20\000\00001\000\000 */
{ 5568298 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x40\000\00001\000\000 */
{ 5568998 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x80\000\00001\000\000 */
{ 5571217 }, /* unc_m_wr_cas_rank2.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xba,umask=0x1\000\00001\000\000 */
{ 5572362 }, /* unc_m_wr_cas_rank2.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xba,umask=0x2\000\00001\000\000 */
{ 5572616 }, /* unc_m_wr_cas_rank2.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xba,umask=0x4\000\00001\000\000 */
{ 5572870 }, /* unc_m_wr_cas_rank2.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xba,umask=0x8\000\00001\000\000 */
{ 5572997 }, /* unc_m_wr_cas_rank2.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xba,umask=0x10\000\00001\000\000 */
{ 5573252 }, /* unc_m_wr_cas_rank2.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xba,umask=0x20\000\00001\000\000 */
{ 5573507 }, /* unc_m_wr_cas_rank2.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xba,umask=0x40\000\00001\000\000 */
{ 5573889 }, /* unc_m_wr_cas_rank2.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xba,umask=0x80\000\00001\000\000 */
{ 5574996 }, /* unc_m_wr_cas_rank3.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xbb,umask=0x1\000\00001\000\000 */
{ 5576141 }, /* unc_m_wr_cas_rank3.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xbb,umask=0x2\000\00001\000\000 */
{ 5576395 }, /* unc_m_wr_cas_rank3.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xbb,umask=0x4\000\00001\000\000 */
{ 5576649 }, /* unc_m_wr_cas_rank3.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xbb,umask=0x8\000\00001\000\000 */
{ 5576776 }, /* unc_m_wr_cas_rank3.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xbb,umask=0x10\000\00001\000\000 */
{ 5577031 }, /* unc_m_wr_cas_rank3.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xbb,umask=0x20\000\00001\000\000 */
{ 5577286 }, /* unc_m_wr_cas_rank3.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xbb,umask=0x40\000\00001\000\000 */
{ 5577668 }, /* unc_m_wr_cas_rank3.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xbb,umask=0x80\000\00001\000\000 */
{ 5578944 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000\000 */
{ 5581369 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000\000 */
{ 5581782 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000\000 */
{ 5582195 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000\000 */
{ 5582322 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000\000 */
{ 5582736 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x20\000\00001\000\000 */
{ 5583150 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x40\000\00001\000\000 */
{ 5583850 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x80\000\00001\000\000 */
{ 5586238 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000\000 */
{ 5588663 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000\000 */
{ 5589076 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000\000 */
{ 5589489 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000\000 */
{ 5589616 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000\000 */
{ 5590030 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x20\000\00001\000\000 */
{ 5590444 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x40\000\00001\000\000 */
{ 5591144 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x80\000\00001\000\000 */
{ 5593532 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000\000 */
{ 5595957 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000\000 */
{ 5596370 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000\000 */
{ 5596783 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000\000 */
{ 5596910 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000\000 */
{ 5597324 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x20\000\00001\000\000 */
{ 5597738 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x40\000\00001\000\000 */
{ 5598438 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x80\000\00001\000\000 */
{ 5600826 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000\000 */
{ 5603251 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000\000 */
{ 5603664 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000\000 */
{ 5604077 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000\000 */
{ 5604204 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000\000 */
{ 5604618 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x20\000\00001\000\000 */
{ 5605032 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x40\000\00001\000\000 */
{ 5605732 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x80\000\00001\000\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5642030 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 800 MHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5642356 }, /* unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core 0 C State Transition Cycles. Unit: uncore_pcu \000event=0x70\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5642981 }, /* unc_p_core10_transition_cycles\000uncore_pcu\000uncore power\000Core 10 C State Transition Cycles. Unit: uncore_pcu \000event=0x7a\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643402 }, /* unc_p_core11_transition_cycles\000uncore_pcu\000uncore power\000Core 11 C State Transition Cycles. Unit: uncore_pcu \000event=0x7b\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5643823 }, /* unc_p_core12_transition_cycles\000uncore_pcu\000uncore power\000Core 12 C State Transition Cycles. Unit: uncore_pcu \000event=0x7c\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644244 }, /* unc_p_core13_transition_cycles\000uncore_pcu\000uncore power\000Core 13 C State Transition Cycles. Unit: uncore_pcu \000event=0x7d\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5644665 }, /* unc_p_core14_transition_cycles\000uncore_pcu\000uncore power\000Core 14 C State Transition Cycles. Unit: uncore_pcu \000event=0x7e\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645713 }, /* unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core 1 C State Transition Cycles. Unit: uncore_pcu \000event=0x71\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646338 }, /* unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core 2 C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646963 }, /* unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core 3 C State Transition Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647588 }, /* unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core 4 C State Transition Cycles. Unit: uncore_pcu \000event=0x74\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648213 }, /* unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core 5 C State Transition Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648838 }, /* unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core 6 C State Transition Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649463 }, /* unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core 7 C State Transition Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650088 }, /* unc_p_core8_transition_cycles\000uncore_pcu\000uncore power\000Core 8 C State Transition Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5650506 }, /* unc_p_core9_transition_cycles\000uncore_pcu\000uncore power\000Core 9 C State Transition Cycles. Unit: uncore_pcu \000event=0x79\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5651041 }, /* unc_p_delayed_c_state_abort_core0\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 0. Unit: uncore_pcu \000event=0x17\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5653169 }, /* unc_p_delayed_c_state_abort_core1\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 1. Unit: uncore_pcu \000event=0x18\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5651394 }, /* unc_p_delayed_c_state_abort_core10\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 10. Unit: uncore_pcu \000event=0x21\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5651749 }, /* unc_p_delayed_c_state_abort_core11\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 11. Unit: uncore_pcu \000event=0x22\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5652104 }, /* unc_p_delayed_c_state_abort_core12\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 12. Unit: uncore_pcu \000event=0x23\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5652459 }, /* unc_p_delayed_c_state_abort_core13\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 13. Unit: uncore_pcu \000event=0x24\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5652814 }, /* unc_p_delayed_c_state_abort_core14\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 14. Unit: uncore_pcu \000event=0x25\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5653522 }, /* unc_p_delayed_c_state_abort_core2\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 2. Unit: uncore_pcu \000event=0x19\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5653875 }, /* unc_p_delayed_c_state_abort_core3\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 3. Unit: uncore_pcu \000event=0x1a\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5654228 }, /* unc_p_delayed_c_state_abort_core4\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 4. Unit: uncore_pcu \000event=0x1b\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5654581 }, /* unc_p_delayed_c_state_abort_core5\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 5. Unit: uncore_pcu \000event=0x1c\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5654934 }, /* unc_p_delayed_c_state_abort_core6\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 6. Unit: uncore_pcu \000event=0x1d\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5655287 }, /* unc_p_delayed_c_state_abort_core7\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 7. Unit: uncore_pcu \000event=0x1e\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5655640 }, /* unc_p_delayed_c_state_abort_core8\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 8. Unit: uncore_pcu \000event=0x1f\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5655993 }, /* unc_p_delayed_c_state_abort_core9\000uncore_pcu\000uncore power\000Deep C State Rejection - Core 9. Unit: uncore_pcu \000event=0x20\000\00001\000Number of times that a deep C state was requested, but the delayed C state algorithm rejected the deep sleep state.  In other words, a wake event occurred before the timer expired that causes a transition into the deeper C state\000 */
{ 5656437 }, /* unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core 0 C State Demotions. Unit: uncore_pcu \000event=0x1e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659331 }, /* unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core 1 C State Demotions. Unit: uncore_pcu \000event=0x1f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5656976 }, /* unc_p_demotions_core10\000uncore_pcu\000uncore power\000Core 10 C State Demotions. Unit: uncore_pcu \000event=0x42\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657339 }, /* unc_p_demotions_core11\000uncore_pcu\000uncore power\000Core 11 C State Demotions. Unit: uncore_pcu \000event=0x43\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5657702 }, /* unc_p_demotions_core12\000uncore_pcu\000uncore power\000Core 12 C State Demotions. Unit: uncore_pcu \000event=0x44\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658065 }, /* unc_p_demotions_core13\000uncore_pcu\000uncore power\000Core 13 C State Demotions. Unit: uncore_pcu \000event=0x45\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5658428 }, /* unc_p_demotions_core14\000uncore_pcu\000uncore power\000Core 14 C State Demotions. Unit: uncore_pcu \000event=0x46\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659870 }, /* unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core 2 C State Demotions. Unit: uncore_pcu \000event=0x20\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660409 }, /* unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core 3 C State Demotions. Unit: uncore_pcu \000event=0x21\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660948 }, /* unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core 4 C State Demotions. Unit: uncore_pcu \000event=0x22\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661487 }, /* unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core 5 C State Demotions. Unit: uncore_pcu \000event=0x23\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662026 }, /* unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core 6 C State Demotions. Unit: uncore_pcu \000event=0x24\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662565 }, /* unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core 7 C State Demotions. Unit: uncore_pcu \000event=0x25\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663104 }, /* unc_p_demotions_core8\000uncore_pcu\000uncore power\000Core 8 C State Demotions. Unit: uncore_pcu \000event=0x40\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5663464 }, /* unc_p_demotions_core9\000uncore_pcu\000uncore power\000Core 9 C State Demotions. Unit: uncore_pcu \000event=0x41\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5665096 }, /* unc_p_freq_band0_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xb\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5665711 }, /* unc_p_freq_band1_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xc\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666326 }, /* unc_p_freq_band2_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xd\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666941 }, /* unc_p_freq_band3_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xe\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5667772 }, /* unc_p_freq_max_current_cycles\000uncore_pcu\000uncore power\000Current Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x7\000\00001\000Counts the number of cycles when current is the upper limit on frequency\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668753 }, /* unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5669856 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x61\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5671824 }, /* unc_p_freq_min_perf_p_cycles\000uncore_pcu\000uncore power\000Perf P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x62\000\00001\000Counts the number of cycles when Perf P Limit is preventing us from dropping the frequency lower.  Perf P Limit is an algorithm that takes input from remote sockets when determining if a socket should drop it's frequency down.  This is largely to minimize increases in snoop and remote read latencies\000 */
{ 5672638 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x60\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5674586 }, /* unc_p_pkg_c_exit_latency\000uncore_pcu\000uncore power\000Package C State Exit Latency. Unit: uncore_pcu \000event=0x26\000\00001\000Counts the number of cycles that the package is transitioning from package C2 to C3\000 */
{ 5674782 }, /* unc_p_pkg_c_exit_latency_sel\000uncore_pcu\000uncore power\000Package C State Exit Latency. Unit: uncore_pcu \000event=0x26\000\00001\000Counts the number of cycles that the package is transitioning from package C2 to C3\000 */
{ 5674982 }, /* unc_p_pkg_c_state_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles that the package is in C0\000 */
{ 5675163 }, /* unc_p_pkg_c_state_residency_c2_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles that the package is in C2\000 */
{ 5675344 }, /* unc_p_pkg_c_state_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles that the package is in C3\000 */
{ 5675525 }, /* unc_p_pkg_c_state_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles that the package is in C6\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685649 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x63\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5686823 }, /* unc_p_volt_trans_cycles_change\000uncore_pcu\000uncore power\000Cycles Changing Voltage. Unit: uncore_pcu \000event=0x3\000\00001\000Counts the number of cycles when the system is changing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition.  This event is calculated by or'ing together the increasing and decreasing events\000 */
{ 5687295 }, /* unc_p_volt_trans_cycles_decrease\000uncore_pcu\000uncore power\000Cycles Decreasing Voltage. Unit: uncore_pcu \000event=0x2\000\00001\000Counts the number of cycles when the system is decreasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000 */
{ 5687690 }, /* unc_p_volt_trans_cycles_increase\000uncore_pcu\000uncore power\000Cycles Increasing Voltage. Unit: uncore_pcu \000event=0x1\000\00001\000Counts the number of cycles when the system is increasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000 */
{ 5688085 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x32\000\00001\000\000 */
{ 787101 }, /* dtlb_load_misses.demand_ld_walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0x82\000\00000\000\000 */
{ 787316 }, /* dtlb_load_misses.demand_ld_walk_duration\000\000virtual memory\000Demand load cycles page miss handler (PMH) is busy with this walk\000event=0x8,period=2000003,umask=0x84\000\00000\000\000 */
{ 787480 }, /* dtlb_load_misses.large_page_walk_completed\000\000virtual memory\000Page walk for a large page completed for Demand load\000event=0x8,period=100003,umask=0x88\000\00000\000\000 */
{ 787758 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes an page walk of any page size\000event=0x8,period=100003,umask=0x81\000\00000\000Misses in all TLB levels that cause a page walk of any page size from demand loads\000 */
{ 789915 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x5f,period=100003,umask=0x4\000\00000\000Counts load operations that missed 1st level DTLB but hit the 2nd level\000 */
{ 794873 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Demand load Miss in all translation lookaside buffer (TLB) levels causes a page walk that completes of any page size\000event=0x8,period=100003,umask=0x82\000\00000\000Misses in all TLB levels that caused page walk completed of any size by demand loads\000 */
{ 806932 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Demand load cycles page miss handler (PMH) is busy with this walk\000event=0x8,period=2000003,umask=0x84\000\00000\000Cycle PMH is busy with a walk due to demand loads\000 */
{ 810986 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Miss in all TLB levels causes a page walk of any page size (4K/2M/4M/1G)\000 */
{ 812051 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000 */
{ 817084 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000Miss in all TLB levels causes a page walk that completes of any page size (4K/2M/4M/1G)\000 */
{ 828731 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000Cycles PMH is busy with this walk\000 */
{ 832947 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1078052 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of ITLB flushes, includes 4k/2M/4M pages\000 */
{ 1079859 }, /* itlb_misses.large_page_walk_completed\000\000virtual memory\000Completed page walks in ITLB due to STLB load misses for large pages\000event=0x85,period=100003,umask=0x80\000\00000\000Completed page walks in ITLB due to STLB load misses for large pages\000 */
{ 1081396 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Misses in all ITLB levels that cause page walks\000 */
{ 1083030 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000Number of cache load STLB hits. No page walk\000 */
{ 1087648 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000Misses in all ITLB levels that cause completed page walks\000 */
{ 1096296 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000Cycle PMH is busy with a walk\000 */
{ 2540513 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000DTLB flush attempts of the thread-specific entries\000 */
{ 2541163 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Count number of STLB flush attempts\000 */
};

static const struct compact_pmu_event pmu_metrics__ivytown[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51887 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5) / (3 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00002 */
{ 55794 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * OTHER_ASSISTS.ANY_WB_ASSIST / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 76455 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00002 */
{ 92570 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(60 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) + 43 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 105306 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00043 * (MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 120903 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 125933 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 129662 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 138383 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * DTLB_STORE_MISSES.STLB_HIT + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_UOPS_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load\000100%\000\000\000\00000 */
{ 145955 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(200 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_MISS.REMOTE_HITM + 60 * OFFCORE_RESPONSE.DEMAND_RFO.LLC_HIT.HITM_OTHER_CORE) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 155428 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00001 */
{ 159069 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 171419 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 174786 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_EXECUTED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 194894 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE.IFETCH_STALL / tma_info_thread_clks - tma_itlb_misses\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000\000100%\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219516 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 224070 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225245 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 230525 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\0001 / (tma_fp_scalar + tma_fp_vector)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240831 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242111 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_UOPS_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243671 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246761 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 247680 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248902 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_UOPS_RETIRED.LLC_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249310 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_UOPS_RETIRED.L1_MISS + MEM_LOAD_UOPS_RETIRED.HIT_LFB)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00001 */
{ 250232 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00001 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252139 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\0000\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 253557 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_DURATION + DTLB_LOAD_MISSES.WALK_DURATION + DTLB_STORE_MISSES.WALK_DURATION) / tma_info_core_core_clks\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258687 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 261800 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267423 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182\\,thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 270482 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_INSERTS.MISS_OPCODE@filter_opc\\=0x182@) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275234 }, /* \000tma_info_system_socket_clks\000SoC\000cbox_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 281284 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(12 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 287936 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) - CYCLE_ACTIVITY.STALLS_L1D_PENDING) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_UOPS_RETIRED.L1_HIT_PS;MEM_LOAD_UOPS_RETIRED.HIT_LFB_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 290473 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L1D_PENDING - CYCLE_ACTIVITY.STALLS_L2_PENDING) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L2_HIT_PS\000100%\000\000\000\00000 */
{ 297708 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 307218 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00041 * (MEM_LOAD_UOPS_RETIRED.LLC_HIT * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS. Related metrics: tma_mem_latency\000100%\000\000\000\00001 */
{ 311704 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317465 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00002 */
{ 321002 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\000200 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00001 */
{ 327416 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_UOPS_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 335504 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 339154 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 346683 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 357035 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 379797 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382600 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 387139 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 398843 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) + UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - (UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC if tma_info_thread_ipc > 1.8 else UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_LDM_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 401522 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,inv\\,cmask\\=1@ / 2 if #SMT_on else (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_EXECUTE) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0)) / tma_info_core_core_clks)\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 405006 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=1@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_1_UOP_EXEC - UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 411919 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((cpu@UOPS_EXECUTED.CORE\\,cmask\\=2@ - cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@) / 2 if #SMT_on else (UOPS_EXECUTED.CYCLES_GE_2_UOPS_EXEC - UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks)\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 418342 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(cpu@UOPS_EXECUTED.CORE\\,cmask\\=3@ / 2 if #SMT_on else UOPS_EXECUTED.CYCLES_GE_3_UOPS_EXEC) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 423367 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(200 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) + 180 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD)))) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00001 */
{ 430480 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000310 * (MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_UOPS_RETIRED.HIT_LFB / (MEM_LOAD_UOPS_RETIRED.L2_HIT + MEM_LOAD_UOPS_RETIRED.LLC_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HIT + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_HITM + MEM_LOAD_UOPS_LLC_HIT_RETIRED.XSNP_MISS + MEM_LOAD_UOPS_LLC_MISS_RETIRED.LOCAL_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_DRAM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_HITM + MEM_LOAD_UOPS_LLC_MISS_RETIRED.REMOTE_FWD))) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_UOPS_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00001 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 440028 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_UOPS_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00001 */
{ 443184 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\0002 * MEM_UOPS_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_UOPS_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444921 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 454162 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) + (1 - MEM_UOPS_RETIRED.LOCK_LOADS / MEM_UOPS_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00001 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 463482 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__jaketown[] = {
{ 1099902 }, /* l1d.all_m_replacement\000\000cache\000Cache lines in M state evicted out of L1D due to Snoop HitM or dirty line replacement\000event=0x51,period=2000003,umask=0x8\000\00000\000\000 */
{ 1100058 }, /* l1d.allocated_in_m\000\000cache\000Allocated L1D data cache lines in M state\000event=0x51,period=2000003,umask=0x2\000\00000\000\000 */
{ 1100167 }, /* l1d.eviction\000\000cache\000L1D data cache lines in M state evicted due to replacement\000event=0x51,period=2000003,umask=0x4\000\00000\000\000 */
{ 1101743 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements.  Replacements occur when a new line is brought into the cache, causing eviction of a line loaded earlier\000 */
{ 1102693 }, /* l1d_blocks.bank_conflict_cycles\000\000cache\000Cycles when dispatched loads are cancelled due to L1D bank conflicts with other load ports\000event=0xbf,cmask=1,period=100003,umask=0x5\000\00000\000\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1109165 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1125021 }, /* l2_l1d_wb_rqsts.all\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in any state\000event=0x28,period=200003,umask=0xf\000\00000\000\000 */
{ 1125344 }, /* l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000\000 */
{ 1125667 }, /* l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000\000 */
{ 1125798 }, /* l2_l1d_wb_rqsts.hit_s\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in S state\000event=0x28,period=200003,umask=0x2\000\00000\000\000 */
{ 1126135 }, /* l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000\000 */
{ 1128996 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines brought into the L2 cache.  Lines are filled into the L2 cache when there was an L2 miss\000 */
{ 1130115 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000\000 */
{ 1130664 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000\000 */
{ 1131108 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000\000 */
{ 1131801 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000\000 */
{ 1132435 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000\000 */
{ 1132957 }, /* l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000\000 */
{ 1135252 }, /* l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000\000 */
{ 1135528 }, /* l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000\000 */
{ 1157116 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000\000 */
{ 1158415 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000\000 */
{ 1161234 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000\000 */
{ 1161984 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000\000 */
{ 1163136 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000\000 */
{ 1164107 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000\000 */
{ 1165282 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000\000 */
{ 1171330 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000\000 */
{ 1171892 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000\000 */
{ 1173957 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000\000 */
{ 1175303 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000\000 */
{ 1178721 }, /* l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000\000 */
{ 1178834 }, /* l2_store_lock_rqsts.hit_e\000\000cache\000RFOs that hit cache lines in E state\000event=0x27,period=200003,umask=0x4\000\00000\000\000 */
{ 1179090 }, /* l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000\000 */
{ 1179325 }, /* l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000\000 */
{ 1179940 }, /* l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000\000 */
{ 1180373 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000\000 */
{ 1180812 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000\000 */
{ 1181450 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000\000 */
{ 1181856 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000\000 */
{ 1182254 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000\000 */
{ 1182778 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000\000 */
{ 1183333 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000\000 */
{ 1245886 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000\000 */
{ 1248025 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000\000 */
{ 1251819 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000\000 */
{ 1347536 }, /* mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a non-modified state\000 */
{ 1349027 }, /* mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a modified state, so the line had to be invalidated in that L2 cache and transferred to the requesting L2\000 */
{ 1350104 }, /* mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1350675 }, /* mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1350840 }, /* mem_load_uops_llc_miss_retired.local_dram\000\000cache\000Data from local DRAM either Snoop not needed or Snoop Miss (RspI)\000event=0xd3,period=100007,umask=0x1\000\00000\000\000 */
{ 1351459 }, /* mem_load_uops_llc_miss_retired.remote_dram\000\000cache\000Data from remote DRAM either Snoop not needed or Snoop Miss (RspI)\000event=0xd3,period=100007,umask=0x4\000\00000\000\000 */
{ 1354625 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357660 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1360709 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1365443 }, /* mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level (L3) cache without snoops required\000 */
{ 1365854 }, /* mem_load_uops_retired.llc_miss\000\000cache\000Miss in last-level (L3) cache. Excludes Unknown data-source\000event=0xd1,period=100007,umask=0x20\000\00000\000\000 */
{ 1388769 }, /* mem_uops_retired.all_loads\000\000cache\000All retired load uops (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000This event counts the number of load uops retired (Precise event)\000 */
{ 1391374 }, /* mem_uops_retired.all_stores\000\000cache\000All retired store uops (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000This event counts the number of store uops retired (Precise event)\000 */
{ 1416001 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1418411 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K) (Precise event)\000 */
{ 1420184 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K) (Precise event)\000 */
{ 1422180 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423253 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745682 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000\000 */
{ 1748737 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000\000 */
{ 1750715 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000\000 */
{ 1751785 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000\000 */
{ 1753235 }, /* offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1757135 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000\000 */
{ 1760174 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1764176 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1767583 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1774876 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000\000 */
{ 1775481 }, /* offcore_requests_outstanding.demand_data_rd_c6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777696 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000\000 */
{ 1784697 }, /* offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000105B3\000\00000\000\000 */
{ 1805176 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0091\000\00000\000\000 */
{ 1805720 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0091\000\00000\000\000 */
{ 1805994 }, /* offcore_response.all_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0091\000\00000\000\000 */
{ 1806301 }, /* offcore_response.all_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0091\000\00000\000\000 */
{ 1838310 }, /* offcore_response.all_pf_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch data reads that hit the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0090\000\00000\000\000 */
{ 1838483 }, /* offcore_response.all_pf_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0090\000\00000\000\000 */
{ 1838749 }, /* offcore_response.all_pf_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0090\000\00000\000\000 */
{ 1839017 }, /* offcore_response.all_pf_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0090\000\00000\000\000 */
{ 1839318 }, /* offcore_response.all_pf_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0090\000\00000\000\000 */
{ 1866683 }, /* offcore_response.all_reads.any_response\000\000cache\000Counts all data/code/rfo references (demand & prefetch)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000107F7\000\00000\000\000 */
{ 1880720 }, /* offcore_response.all_reads.llc_hit.any_response\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c03f7\000\00000\000\000 */
{ 1881190 }, /* offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c03f7\000\00000\000\000 */
{ 1882037 }, /* offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c03f7\000\00000\000\000 */
{ 1882607 }, /* offcore_response.all_reads.llc_hit.no_snoop_needed\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c03f7\000\00000\000\000 */
{ 1883243 }, /* offcore_response.all_reads.llc_hit.snoop_miss\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c03f7\000\00000\000\000 */
{ 1889947 }, /* offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch prefetch RFOs\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010122\000\00000\000\000 */
{ 1999322 }, /* offcore_response.corewb.any_response\000\000cache\000Counts all writebacks from the core to the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 2025769 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010004\000\00000\000\000 */
{ 2062524 }, /* offcore_response.demand_code_rd.llc_hit.any_response\000\000cache\000Counts all demand code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0004\000\00000\000\000 */
{ 2079519 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts all demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010001\000\00000\000\000 */
{ 2116118 }, /* offcore_response.demand_data_rd.llc_hit.any_response\000\000cache\000Counts all demand data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0001\000\00000\000\000 */
{ 2116550 }, /* offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0001\000\00000\000\000 */
{ 2117074 }, /* offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0001\000\00000\000\000 */
{ 2117340 }, /* offcore_response.demand_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0001\000\00000\000\000 */
{ 2117639 }, /* offcore_response.demand_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoop returned a clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0001\000\00000\000\000 */
{ 2138060 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand rfo's\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010002\000\00000\000\000 */
{ 2220710 }, /* offcore_response.other.lru_hints\000\000cache\000Counts L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803c8000\000\00000\000\000 */
{ 2221884 }, /* offcore_response.other.portio_mmio_uc\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23ffc08000\000\00000\000\000 */
{ 2297503 }, /* offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0040\000\00000\000\000 */
{ 2327830 }, /* offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0010\000\00000\000\000 */
{ 2328025 }, /* offcore_response.pf_l2_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0010\000\00000\000\000 */
{ 2328314 }, /* offcore_response.pf_l2_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0010\000\00000\000\000 */
{ 2328605 }, /* offcore_response.pf_l2_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0010\000\00000\000\000 */
{ 2328929 }, /* offcore_response.pf_l2_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0010\000\00000\000\000 */
{ 2423713 }, /* offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0200\000\00000\000\000 */
{ 2426342 }, /* offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0080\000\00000\000\000 */
{ 2426544 }, /* offcore_response.pf_llc_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0080\000\00000\000\000 */
{ 2426840 }, /* offcore_response.pf_llc_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0080\000\00000\000\000 */
{ 2427138 }, /* offcore_response.pf_llc_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0080\000\00000\000\000 */
{ 2427469 }, /* offcore_response.pf_llc_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0080\000\00000\000\000 */
{ 2446094 }, /* offcore_response.split_lock_uc_lock.any_response\000\000cache\000Counts requests where the address of an atomic lock instruction spans a cache line boundary or the lock instruction is executed on uncacheable address\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 2447058 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts non-temporal stores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 902501 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000\000 */
{ 903610 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000\000 */
{ 904281 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000\000 */
{ 904877 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000\000 */
{ 905451 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000\000 */
{ 906471 }, /* fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000\000 */
{ 906924 }, /* fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000\000 */
{ 907361 }, /* fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000\000 */
{ 907814 }, /* fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000\000 */
{ 908615 }, /* fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULs and IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000\000 */
{ 2462917 }, /* other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000\000 */
{ 2463621 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 2464364 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable\000event=0xc1,period=100003,umask=0x20\000\00000\000\000 */
{ 2523515 }, /* simd_fp_256.packed_double\000\000floating point\000Number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000\000 */
{ 2523897 }, /* simd_fp_256.packed_single\000\000floating point\000Number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000\000 */
{ 477106 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000 */
{ 781845 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000\000 */
{ 785275 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts the cycles attributed to a switch from the Decoded Stream Buffer (DSB), which holds decoded instructions, to the legacy decode pipeline.  It excludes cycles when the back-end cannot  accept new micro-ops.  The penalty for these switches is potentially several cycles of instruction starvation, where no micro-ops are delivered to the back-end\000 */
{ 786315 }, /* dsb_fill.all_cancel\000\000frontend\000Cases of cancelling valid Decode Stream Buffer (DSB) fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0xa\000\00000\000\000 */
{ 786689 }, /* dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000\000 */
{ 786865 }, /* dsb_fill.other_cancel\000\000frontend\000Cases of cancelling valid DSB fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0x2\000\00000\000\000 */
{ 986835 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000\000 */
{ 990163 }, /* icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes unchacheable accesses\000 */
{ 998803 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000\000 */
{ 999880 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000\000 */
{ 1000957 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000\000 */
{ 1002208 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000\000 */
{ 1003345 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1007144 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000\000 */
{ 1008329 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000\000 */
{ 1008981 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000\000 */
{ 1010000 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1013205 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000\000 */
{ 1015423 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance.  See the Intel? 64 and IA-32 Architectures Optimization Reference Manual for more information\000 */
{ 1019000 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020351 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1021671 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000\000 */
{ 1023239 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026879 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000\000 */
{ 1030856 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled \000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to the back-end per cycle, per thread, when the back-end was not stalled.  In the ideal case 4 uops can be delivered each cycle.  The event counts the undelivered uops - so if 3 were delivered in one cycle, the counter would be incremented by 1 for that cycle (4 - 3). If the back-end is stalled, the count for this event is not incremented even when uops were not delivered, because the back-end would not have been able to accept them.  This event is used in determining the front-end bound category of the top-down pipeline slots characterization\000 */
{ 1035047 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1037850 }, /* idq_uops_not_delivered.cycles_ge_1_uop_deliv.core\000\000frontend\000Cycles when 1 or more uops were delivered to the by the front end\000event=0x9c,cmask=4,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039076 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1294406 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from memory disambiguation, external snoops, or cross SMT-HW-thread snoop (stores) hitting load buffers.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1369719 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000 */
{ 1371663 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000 */
{ 1373605 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000 */
{ 1375551 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000\000 */
{ 1377280 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4  (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000 */
{ 1379423 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000 */
{ 1381365 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000 */
{ 1383291 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000 */
{ 1384715 }, /* mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only. (Precise Event - PEBS) (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000 */
{ 1428803 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000\000 */
{ 1431002 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000\000 */
{ 1812268 }, /* offcore_response.all_demand_mlc_pref_reads.llc_miss.any_response\000\000memory\000This event counts all LLC misses for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC20077\000\00000\000\000 */
{ 1812501 }, /* offcore_response.all_demand_mlc_pref_reads.llc_miss.local_dram\000\000memory\000Counts all local dram accesses for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400077\000\00000\000\000 */
{ 1812729 }, /* offcore_response.all_demand_mlc_pref_reads.llc_miss.remote_hitm_hit_forward\000\000memory\000This event counts all remote cache-to-cache transfers (includes HITM and HIT-Forward) for all demand and L2 prefetches. LLC prefetches are excluded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x187FC20077\000\00000\000\000 */
{ 2064450 }, /* offcore_response.demand_code_rd.llc_miss.any_response\000\000memory\000Counts all demand code reads that miss the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20004\000\00000\000\000 */
{ 2065023 }, /* offcore_response.demand_code_rd.llc_miss.local_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400004\000\00000\000\000 */
{ 2065233 }, /* offcore_response.demand_code_rd.llc_miss.remote_dram\000\000memory\000Counts all demand code reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800004\000\00000\000\000 */
{ 2065445 }, /* offcore_response.demand_code_rd.llc_miss.remote_hit_forward\000\000memory\000Counts all demand code reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820004\000\00000\000\000 */
{ 2065666 }, /* offcore_response.demand_code_rd.llc_miss.remote_hitm\000\000memory\000Counts all demand code reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00004\000\00000\000\000 */
{ 2119217 }, /* offcore_response.demand_data_rd.llc_miss.any_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00001\000\00000\000\000 */
{ 2119597 }, /* offcore_response.demand_data_rd.llc_miss.any_response\000\000memory\000Counts demand data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20001\000\00000\000\000 */
{ 2120165 }, /* offcore_response.demand_data_rd.llc_miss.local_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400001\000\00000\000\000 */
{ 2120371 }, /* offcore_response.demand_data_rd.llc_miss.remote_dram\000\000memory\000Counts demand data reads that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800001\000\00000\000\000 */
{ 2120579 }, /* offcore_response.demand_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts demand data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820001\000\00000\000\000 */
{ 2120796 }, /* offcore_response.demand_data_rd.llc_miss.remote_hitm\000\000memory\000Counts demand data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00001\000\00000\000\000 */
{ 2299056 }, /* offcore_response.pf_l2_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to L2) code reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20040\000\00000\000\000 */
{ 2329180 }, /* offcore_response.pf_l2_data_rd.llc_miss.any_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from remote & local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67fc00010\000\00000\000\000 */
{ 2329610 }, /* offcore_response.pf_l2_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20010\000\00000\000\000 */
{ 2330026 }, /* offcore_response.pf_l2_data_rd.llc_miss.local_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x600400010\000\00000\000\000 */
{ 2330257 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_dram\000\000memory\000Counts prefetch (that bring data to L2) data reads  that miss the LLC  and the data returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x67f800010\000\00000\000\000 */
{ 2330491 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  and the data forwarded from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x87f820010\000\00000\000\000 */
{ 2330733 }, /* offcore_response.pf_l2_data_rd.llc_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC  the data is found in M state in remote cache and forwarded from there\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x107fc00010\000\00000\000\000 */
{ 2425298 }, /* offcore_response.pf_llc_code_rd.llc_miss.any_response\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads that miss in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20200\000\00000\000\000 */
{ 2427930 }, /* offcore_response.pf_llc_data_rd.llc_miss.any_response\000\000memory\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3fffc20080\000\00000\000\000 */
{ 581493 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000\000 */
{ 582214 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000\000 */
{ 582753 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000\000 */
{ 979004 }, /* hw_pre_req.dl1_miss\000\000other\000Hardware Prefetch requests that miss the L1D cache. This accounts for both L1 streamer and IP-based (IPP) HW prefetchers. A request is being counted each time it access the cache & miss it, including if a block is applicable or if hit the Fill Buffer for \000event=0x4e,period=2000003,umask=0x2\000\00000\000\000 */
{ 1064704 }, /* insts_written_to_iq.insts\000\000other\000Valid instructions written to IQ per cycle\000event=0x17,period=2000003,umask=0x1\000\00000\000\000 */
{ 1246723 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000\000 */
{ 465980 }, /* agu_bypass_cancel.count\000\000pipeline\000This event counts executed load operations with all the following traits: 1. addressing of the format [base + offset], 2. the offset is between 1 and 2047, 3. the address specified in the base register is in one page and the address [base+offset] is in an\000event=0xb6,period=100003,umask=0x1\000\00000\000\000 */
{ 469746 }, /* arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000This event counts the number of the divide operations executed\000 */
{ 470590 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000\000 */
{ 488060 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000\000 */
{ 488587 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000\000 */
{ 489261 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000\000 */
{ 489802 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000\000 */
{ 490448 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 492202 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000\000 */
{ 492945 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000\000 */
{ 493664 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000\000 */
{ 494226 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000\000 */
{ 494883 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000\000 */
{ 495474 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000\000 */
{ 496089 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000\000 */
{ 496754 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000\000 */
{ 500115 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 505985 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000 */
{ 508755 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000\000 */
{ 515672 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 518283 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000 */
{ 519723 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000 */
{ 522612 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000\000 */
{ 529125 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000\000 */
{ 529734 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000\000 */
{ 529878 }, /* br_misp_exec.all_direct_near_call\000\000pipeline\000Speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0xd0\000\00000\000\000 */
{ 530485 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532301 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000\000 */
{ 533148 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000\000 */
{ 533300 }, /* br_misp_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0x90\000\00000\000\000 */
{ 534014 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 535066 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000\000 */
{ 537126 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000\000 */
{ 542028 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000 */
{ 546808 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 554339 }, /* br_misp_retired.near_call\000\000pipeline\000Direct and indirect mispredicted near call instructions retired (Precise event)\000event=0xc5,period=100007,umask=0x2\000\00000\000\000 */
{ 559441 }, /* br_misp_retired.not_taken\000\000pipeline\000Mispredicted not taken branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000\000 */
{ 562769 }, /* br_misp_retired.taken\000\000pipeline\000Mispredicted taken branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 607176 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 608338 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000 */
{ 609165 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 618365 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 630691 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 639130 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000 */
{ 639929 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 642083 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 648143 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 749849 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread, increment by 1. Note this is in DCU and connected to Umask 1. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 751456 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 753495 }, /* cycle_activity.cycles_no_dispatch\000\000pipeline\000Each cycle there was no dispatch for this thread, increment by 1. Note this is connect to Umask 2. No dispatch can be deduced from the UOPS_EXECUTED event\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 754960 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread and no uops dispatched, increment by 1. Note this is in DCU and connected to Umask 1 and 2. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 756441 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load and no uops dispatched on this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0 and 2\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 1040806 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000\000 */
{ 1042873 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000\000 */
{ 1049369 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers\000 */
{ 1054885 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1058954 }, /* inst_retired.prec_dist\000\000pipeline\000Instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000\000 */
{ 1067647 }, /* int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x40\000\00000\000\000 */
{ 1070200 }, /* int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1072089 }, /* int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1192341 }, /* ld_blocks.all_block\000\000pipeline\000Number of cases where any load ends up with a valid block-code written to the load buffer (including blocks due to Memory Order Buffer (MOB), Data Cache Unit (DCU), TLB, but load has no DCU miss)\000event=0x3,period=100003,umask=0x10\000\00000\000\000 */
{ 1193189 }, /* ld_blocks.data_unknown\000\000pipeline\000Loads delayed due to SB blocks, preceding store operations with known addresses but unknown data\000event=0x3,period=100003,umask=0x1\000\00000\000\000 */
{ 1195150 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000 */
{ 1197724 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store.  See the table of not supported store forwards in the Intel? 64 and IA-32 Architectures Optimization Reference Manual.  The penalty for blocked store forwarding is that the load must wait for the store to complete before it can be issued\000 */
{ 1202912 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline.  The enhanced address check typically has a performance penalty of 5 cycles\000 */
{ 1203747 }, /* ld_blocks_partial.all_sta_block\000\000pipeline\000This event counts the number of times that load operations are temporarily blocked because of older stores, with addresses that are not yet known. A load operation may incur more than one block of this type\000event=0x7,period=100003,umask=0x8\000\00000\000\000 */
{ 1229615 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000\000 */
{ 1230906 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1293258 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000 */
{ 1301984 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event is incremented when self-modifying code (SMC) is detected, which causes a machine clear.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 2463776 }, /* other_assists.itlb_miss_retired\000\000pipeline\000Retired instructions experiencing ITLB misses\000event=0xc1,period=100003,umask=0x2\000\00000\000\000 */
{ 2477071 }, /* partial_rat_stalls.flags_merge_uop\000\000pipeline\000Increments the number of flags-merge uops in flight each cycle\000event=0x59,period=2000003,umask=0x20\000\00000\000\000 */
{ 2477624 }, /* partial_rat_stalls.flags_merge_uop_cycles\000\000pipeline\000Performance sensitive flags-merging uops added by Sandy Bridge u-arch\000event=0x59,cmask=1,period=2000003,umask=0x20\000\00000\000This event counts the number of cycles spent executing performance-sensitive flags-merging uops. For example, shift CL (merge_arith_flags). For more details, See the Intel? 64 and IA-32 Architectures Optimization Reference Manual\000 */
{ 2478025 }, /* partial_rat_stalls.mul_single_uop\000\000pipeline\000Multiply packed/scalar single precision uops allocated\000event=0x59,period=2000003,umask=0x80\000\00000\000\000 */
{ 2479099 }, /* partial_rat_stalls.slow_lea_window\000\000pipeline\000Cycles with at least one slow LEA uop being allocated\000event=0x59,period=2000003,umask=0x40\000\00000\000This event counts the number of cycles with at least one slow LEA uop being allocated. A uop is generally considered as slow LEA if it has three sources (for example, two sources and immediate) regardless of whether it is a result of LEA instruction or not. Examples of the slow LEA uop are or uops with base, index, and offset source operands using base and index reqisters, where base is EBR/RBP/R13, using RIP relative or 16-bit addressing modes. See the Intel? 64 and IA-32 Architectures Optimization Reference Manual for more details about slow LEA instructions\000 */
{ 2501812 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000\000 */
{ 2502138 }, /* resource_stalls.lb\000\000pipeline\000Counts the cycles of stall due to lack of load buffers\000event=0xa2,period=2000003,umask=0x2\000\00000\000\000 */
{ 2502263 }, /* resource_stalls.lb_sb\000\000pipeline\000Resource stalls due to load or store buffers all being in use\000event=0xa2,period=2000003,umask=0xa\000\00000\000\000 */
{ 2502495 }, /* resource_stalls.mem_rs\000\000pipeline\000Resource stalls due to memory buffers or Reservation Station (RS) being fully utilized\000event=0xa2,period=2000003,umask=0xe\000\00000\000\000 */
{ 2502756 }, /* resource_stalls.ooo_rsrc\000\000pipeline\000Resource stalls due to Rob being full, FCSW, MXCSR and OTHER\000event=0xa2,period=2000003,umask=0xf0\000\00000\000\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2505724 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000\000 */
{ 2506644 }, /* resource_stalls2.all_fl_empty\000\000pipeline\000Cycles with either free list is empty\000event=0x5b,period=2000003,umask=0xc\000\00000\000\000 */
{ 2506763 }, /* resource_stalls2.all_prf_control\000\000pipeline\000Resource stalls2 control structures full for physical registers\000event=0x5b,period=2000003,umask=0xf\000\00000\000\000 */
{ 2506911 }, /* resource_stalls2.bob_full\000\000pipeline\000Cycles when Allocator is stalled if BOB is full and new branch needs it\000event=0x5b,period=2000003,umask=0x40\000\00000\000\000 */
{ 2507061 }, /* resource_stalls2.ooo_rsrc\000\000pipeline\000Resource stalls out of order resources full\000event=0x5b,period=2000003,umask=0x4f\000\00000\000\000 */
{ 2507718 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000\000 */
{ 2512104 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000\000 */
{ 2512599 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6179412 }, /* uops_dispatched.core\000\000pipeline\000Uops dispatched from any thread\000event=0xb1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6183531 }, /* uops_dispatched.thread\000\000pipeline\000Uops dispatched per thread\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6183883 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6184850 }, /* uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6185165 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6186132 }, /* uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6186459 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187247 }, /* uops_dispatched_port.port_2_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187756 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000\000 */
{ 6188761 }, /* uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 6189090 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6190062 }, /* uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6190379 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6191351 }, /* uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198933 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6214840 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the front-end of the pipeilne to the back-end\000 */
{ 6216475 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6220517 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6225920 }, /* uops_retired.all\000\000pipeline\000Actually retired uops (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired (Precise event)\000 */
{ 6228167 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6234250 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 micro-ops or 4 instructions could retire each cycle.  This event is used in determining the 'Retiring' category of the Top-Down pipeline slots characterization (Precise event)\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240056 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 2592164 }, /* unc_c_clockticks\000uncore_cbox\000uncore cache\000Uncore Clocks. Unit: uncore_cbox \000event=0\000\00001\000\000 */
{ 2592390 }, /* unc_c_counter0_occupancy\000uncore_cbox\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cbox \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2593287 }, /* unc_c_ismq_drd_miss_occ\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x21\000\00001\000\000 */
{ 2596303 }, /* unc_c_llc_lookup.data_read\000uncore_cbox\000uncore cache\000Cache Lookups; Data Read Request. Unit: uncore_cbox \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000 */
{ 2599424 }, /* unc_c_llc_lookup.nid\000uncore_cbox\000uncore cache\000Cache Lookups; RTID. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000 */
{ 2601446 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cbox\000uncore cache\000Cache Lookups; External Snoop Request. Unit: uncore_cbox \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000 */
{ 2603590 }, /* unc_c_llc_lookup.write\000uncore_cbox\000uncore cache\000Cache Lookups; Write Requests. Unit: uncore_cbox \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set filter mask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CBoGlCtrl[22:18] bits correspond to [FMESI] state\000 */
{ 2605021 }, /* unc_c_llc_victims.e_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cbox \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2606246 }, /* unc_c_llc_victims.m_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cbox \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607153 }, /* unc_c_llc_victims.miss\000uncore_cbox\000uncore cache\000Lines Victimized. Unit: uncore_cbox \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2607843 }, /* unc_c_llc_victims.nid\000uncore_cbox\000uncore cache\000Lines Victimized; Victimized Lines that Match NID. Unit: uncore_cbox \000event=0x37,umask=0x40\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2608272 }, /* unc_c_llc_victims.s_state\000uncore_cbox\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cbox \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2609552 }, /* unc_c_misc.rfo_hit_s\000uncore_cbox\000uncore cache\000Cbo Misc; RFO HitS. Unit: uncore_cbox \000event=0x39,umask=0x8\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610015 }, /* unc_c_misc.rspi_was_fse\000uncore_cbox\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cbox \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610173 }, /* unc_c_misc.started\000uncore_cbox\000uncore cache\000Cbo Misc. Unit: uncore_cbox \000event=0x39,umask=0x4\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2610646 }, /* unc_c_misc.wc_aliasing\000uncore_cbox\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cbox \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2621049 }, /* unc_c_ring_ad_used.down_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1b,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2623698 }, /* unc_c_ring_ad_used.down_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2632569 }, /* unc_c_ring_ad_used.up_even\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1b,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2635202 }, /* unc_c_ring_ad_used.up_odd\000uncore_cbox\000uncore cache\000AD Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1b,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2648249 }, /* unc_c_ring_ak_used.down_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Even. Unit: uncore_cbox \000event=0x1c,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2650892 }, /* unc_c_ring_ak_used.down_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Down and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2658910 }, /* unc_c_ring_ak_used.up_even\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Even. Unit: uncore_cbox \000event=0x1c,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2661537 }, /* unc_c_ring_ak_used.up_odd\000uncore_cbox\000uncore cache\000AK Ring In Use; Up and Odd. Unit: uncore_cbox \000event=0x1c,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2672782 }, /* unc_c_ring_bl_used.down_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Even. Unit: uncore_cbox \000event=0x1d,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2675432 }, /* unc_c_ring_bl_used.down_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Down and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2683457 }, /* unc_c_ring_bl_used.up_even\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Even. Unit: uncore_cbox \000event=0x1d,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2686091 }, /* unc_c_ring_bl_used.up_odd\000uncore_cbox\000uncore cache\000BL Ring in Use; Up and Odd. Unit: uncore_cbox \000event=0x1d,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the 'UP' direction is on the clockwise ring and 'DN' is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2693187 }, /* unc_c_ring_bounces.ak_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Acknowledgements to core. Unit: uncore_cbox \000event=0x5,umask=0x2\000\00001\000\000 */
{ 2693843 }, /* unc_c_ring_bounces.bl_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Data Responses to core. Unit: uncore_cbox \000event=0x5,umask=0x4\000\00001\000\000 */
{ 2694362 }, /* unc_c_ring_bounces.iv_core\000uncore_cbox\000uncore cache\000Number of LLC responses that bounced on the Ring.; Snoops of processor's cache. Unit: uncore_cbox \000event=0x5,umask=0x8\000\00001\000\000 */
{ 2695648 }, /* unc_c_ring_iv_used.any\000uncore_cbox\000uncore cache\000BL Ring in Use; Any. Unit: uncore_cbox \000event=0x1e,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring in JKT.  Therefore, if one wants to monitor the 'Even' ring, they should select both UP_EVEN and DN_EVEN.  To monitor the 'Odd' ring, they should select both UP_ODD and DN_ODD\000 */
{ 2700835 }, /* unc_c_ring_sink_starved.ad_cache\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x1\000\00001\000\000 */
{ 2701361 }, /* unc_c_ring_sink_starved.ak_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x2\000\00001\000\000 */
{ 2701686 }, /* unc_c_ring_sink_starved.bl_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x4\000\00001\000\000 */
{ 2702108 }, /* unc_c_ring_sink_starved.iv_core\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x6,umask=0x8\000\00001\000\000 */
{ 2702393 }, /* unc_c_ring_src_thrtl\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x7\000\00001\000\000 */
{ 2702940 }, /* unc_c_rxr_ext_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IRQ. Unit: uncore_cbox \000event=0x12,umask=0x2\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2703510 }, /* unc_c_rxr_ext_starved.irq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; IPQ. Unit: uncore_cbox \000event=0x12,umask=0x1\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2703762 }, /* unc_c_rxr_ext_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ. Unit: uncore_cbox \000event=0x12,umask=0x4\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2704315 }, /* unc_c_rxr_ext_starved.ismq_bids\000uncore_cbox\000uncore cache\000Ingress Arbiter Blocking Cycles; ISMQ_BID. Unit: uncore_cbox \000event=0x12,umask=0x8\000\00001\000Counts cycles in external starvation.  This occurs when one of the ingress queues is being starved by the other queues\000 */
{ 2705019 }, /* unc_c_rxr_inserts.ipq\000uncore_cbox\000uncore cache\000Ingress Allocations; IPQ. Unit: uncore_cbox \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705208 }, /* unc_c_rxr_inserts.irq\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ. Unit: uncore_cbox \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2705806 }, /* unc_c_rxr_inserts.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Allocations; IRQ Rejected. Unit: uncore_cbox \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2707154 }, /* unc_c_rxr_inserts.vfifo\000uncore_cbox\000uncore cache\000Ingress Allocations; VFIFO. Unit: uncore_cbox \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 2707688 }, /* unc_c_rxr_int_starved.ipq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IPQ. Unit: uncore_cbox \000event=0x14,umask=0x4\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2708323 }, /* unc_c_rxr_int_starved.irq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; IRQ. Unit: uncore_cbox \000event=0x14,umask=0x1\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2708961 }, /* unc_c_rxr_int_starved.ismq\000uncore_cbox\000uncore cache\000Ingress Internal Starvation Cycles; ISMQ. Unit: uncore_cbox \000event=0x14,umask=0x8\000\00001\000Counts cycles in internal starvation.  This occurs when one (or more) of the entries in the ingress queue are being starved out by other entries in that queue\000 */
{ 2710212 }, /* unc_c_rxr_ipq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Probe Queue Retries; Address Conflict. Unit: uncore_cbox \000event=0x31,umask=0x4\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2710882 }, /* unc_c_rxr_ipq_retry.any\000uncore_cbox\000uncore cache\000Probe Queue Retries; Any Reject. Unit: uncore_cbox \000event=0x31,umask=0x1\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2711615 }, /* unc_c_rxr_ipq_retry.full\000uncore_cbox\000uncore cache\000Probe Queue Retries; No Egress Credits. Unit: uncore_cbox \000event=0x31,umask=0x2\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2711860 }, /* unc_c_rxr_ipq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Probe Queue Retries; No QPI Credits. Unit: uncore_cbox \000event=0x31,umask=0x10\000\00001\000Number of times a snoop (probe) request had to retry.  Filters exist to cover some of the common cases retries\000 */
{ 2713777 }, /* unc_c_rxr_irq_retry.addr_conflict\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Address Conflict. Unit: uncore_cbox \000event=0x32,umask=0x4\000\00001\000\000 */
{ 2714367 }, /* unc_c_rxr_irq_retry.any\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; Any Reject. Unit: uncore_cbox \000event=0x32,umask=0x1\000\00001\000\000 */
{ 2715009 }, /* unc_c_rxr_irq_retry.full\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No Egress Credits. Unit: uncore_cbox \000event=0x32,umask=0x2\000\00001\000\000 */
{ 2716171 }, /* unc_c_rxr_irq_retry.qpi_credits\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No QPI Credits. Unit: uncore_cbox \000event=0x32,umask=0x10\000\00001\000\000 */
{ 2717061 }, /* unc_c_rxr_irq_retry.rtid\000uncore_cbox\000uncore cache\000Ingress Request Queue Rejects; No RTIDs. Unit: uncore_cbox \000event=0x32,umask=0x8\000\00001\000\000 */
{ 2718861 }, /* unc_c_rxr_ismq_retry.any\000uncore_cbox\000uncore cache\000ISMQ Retries; Any Reject. Unit: uncore_cbox \000event=0x33,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2719926 }, /* unc_c_rxr_ismq_retry.full\000uncore_cbox\000uncore cache\000ISMQ Retries; No Egress Credits. Unit: uncore_cbox \000event=0x33,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2720970 }, /* unc_c_rxr_ismq_retry.iio_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No IIO Credits. Unit: uncore_cbox \000event=0x33,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2721848 }, /* unc_c_rxr_ismq_retry.qpi_credits\000uncore_cbox\000uncore cache\000ISMQ Retries; No QPI Credits. Unit: uncore_cbox \000event=0x33,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2722886 }, /* unc_c_rxr_ismq_retry.rtid\000uncore_cbox\000uncore cache\000ISMQ Retries; No RTIDs. Unit: uncore_cbox \000event=0x33,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 2725045 }, /* unc_c_rxr_occupancy.ipq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IPQ. Unit: uncore_cbox \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725232 }, /* unc_c_rxr_occupancy.irq\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ. Unit: uncore_cbox \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2725805 }, /* unc_c_rxr_occupancy.irq_rejected\000uncore_cbox\000uncore cache\000Ingress Occupancy; IRQ Rejected. Unit: uncore_cbox \000event=0x11,umask=0x2\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2727074 }, /* unc_c_rxr_occupancy.vfifo\000uncore_cbox\000uncore cache\000Ingress Occupancy; VFIFO. Unit: uncore_cbox \000event=0x11,umask=0x10\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 2729647 }, /* unc_c_tor_inserts.eviction\000uncore_cbox\000uncore cache\000TOR Inserts; Evictions. Unit: uncore_cbox \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2736045 }, /* unc_c_tor_inserts.miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; Miss All. Unit: uncore_cbox \000event=0x35,umask=0xa\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2738061 }, /* unc_c_tor_inserts.miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Miss Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x3\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2740776 }, /* unc_c_tor_inserts.nid_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched. Unit: uncore_cbox \000event=0x35,umask=0x48\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2742192 }, /* unc_c_tor_inserts.nid_eviction\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Evictions. Unit: uncore_cbox \000event=0x35,umask=0x44\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2743462 }, /* unc_c_tor_inserts.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Miss All. Unit: uncore_cbox \000event=0x35,umask=0x4a\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2744736 }, /* unc_c_tor_inserts.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x35,umask=0x43\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2746039 }, /* unc_c_tor_inserts.nid_opcode\000uncore_cbox\000uncore cache\000TOR Inserts; NID and Opcode Matched. Unit: uncore_cbox \000event=0x35,umask=0x41\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2747317 }, /* unc_c_tor_inserts.nid_wb\000uncore_cbox\000uncore cache\000TOR Inserts; NID Matched Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x50\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2748574 }, /* unc_c_tor_inserts.opcode\000uncore_cbox\000uncore cache\000TOR Inserts; Opcode Match. Unit: uncore_cbox \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2752571 }, /* unc_c_tor_inserts.wb\000uncore_cbox\000uncore cache\000TOR Inserts; Writebacks. Unit: uncore_cbox \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent.  There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc  to DRD (0x182)\000 */
{ 2754122 }, /* unc_c_tor_occupancy.all\000uncore_cbox\000uncore cache\000TOR Occupancy; Any. Unit: uncore_cbox \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2756118 }, /* unc_c_tor_occupancy.eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; Evictions. Unit: uncore_cbox \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2761553 }, /* unc_c_tor_occupancy.miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss All. Unit: uncore_cbox \000event=0x36,umask=0xa\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2764287 }, /* unc_c_tor_occupancy.miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Miss Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x3\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2767018 }, /* unc_c_tor_occupancy.nid_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x48\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2768438 }, /* unc_c_tor_occupancy.nid_eviction\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched Evictions. Unit: uncore_cbox \000event=0x36,umask=0x44\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2769753 }, /* unc_c_tor_occupancy.nid_miss_all\000uncore_cbox\000uncore cache\000TOR Occupancy; NID Matched. Unit: uncore_cbox \000event=0x36,umask=0x4a\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2771044 }, /* unc_c_tor_occupancy.nid_miss_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched Miss. Unit: uncore_cbox \000event=0x36,umask=0x43\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2772387 }, /* unc_c_tor_occupancy.nid_opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; NID and Opcode Matched. Unit: uncore_cbox \000event=0x36,umask=0x41\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2774336 }, /* unc_c_tor_occupancy.opcode\000uncore_cbox\000uncore cache\000TOR Occupancy; Opcode Match. Unit: uncore_cbox \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select 'MISS_OPC_MATCH' and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182)\000 */
{ 2778528 }, /* unc_c_txr_ads_used\000uncore_cbox\000uncore cache\000Unit: uncore_cbox \000event=0x4\000\00001\000\000 */
{ 2778981 }, /* unc_c_txr_inserts.ad_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x1\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2779557 }, /* unc_c_txr_inserts.ad_core\000uncore_cbox\000uncore cache\000Egress Allocations; AD - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x10\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2780148 }, /* unc_c_txr_inserts.ak_cache\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x2\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2780770 }, /* unc_c_txr_inserts.ak_core\000uncore_cbox\000uncore cache\000Egress Allocations; AK - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x20\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2781377 }, /* unc_c_txr_inserts.bl_cache\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Cacheno. Unit: uncore_cbox \000event=0x2,umask=0x4\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2781976 }, /* unc_c_txr_inserts.bl_core\000uncore_cbox\000uncore cache\000Egress Allocations; BL - Corebo. Unit: uncore_cbox \000event=0x2,umask=0x40\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2782555 }, /* unc_c_txr_inserts.iv_cache\000uncore_cbox\000uncore cache\000Egress Allocations; IV - Cachebo. Unit: uncore_cbox \000event=0x2,umask=0x8\000\00001\000Number of allocations into the Cbo Egress.  The Egress is used to queue up requests destined for the ring\000 */
{ 2783125 }, /* unc_c_txr_starved.ak\000uncore_cbox\000uncore cache\000Injection Starvation; Onto AK Ring. Unit: uncore_cbox \000event=0x3,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 2783713 }, /* unc_c_txr_starved.bl\000uncore_cbox\000uncore cache\000Injection Starvation; Onto BL Ring. Unit: uncore_cbox \000event=0x3,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the Egress cannot send a transaction onto the ring for a long period of time\000 */
{ 3584766 }, /* unc_h_bypass_imc.not_taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Not Taken. Unit: uncore_ha \000event=0x14,umask=0x2\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not\000 */
{ 3585548 }, /* unc_h_bypass_imc.taken\000uncore_ha\000uncore cache\000HA to iMC Bypass; Taken. Unit: uncore_ha \000event=0x14,umask=0x1\000\00001\000Counts the number of times when the HA was able to bypass was attempted.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filted by when the bypass was taken and when it was not\000 */
{ 3587414 }, /* unc_h_clockticks\000uncore_ha\000uncore cache\000uclks. Unit: uncore_ha \000event=0\000\00001\000Counts the number of uclks in the HA.  This will be slightly different than the count in the Ubox because of enable/freeze delays.  The HA is on the other side of the die from the fixed Ubox uclk counter, so the drift could be somewhat larger than in units that are closer like the QPI Agent\000 */
{ 3588334 }, /* unc_h_conflict_cycles.conflict\000uncore_ha\000uncore cache\000Conflict Checks; Conflict Detected. Unit: uncore_ha \000event=0xb,umask=0x2\000\00001\000\000 */
{ 3588829 }, /* unc_h_conflict_cycles.no_conflict\000uncore_ha\000uncore cache\000Conflict Checks; No Conflict. Unit: uncore_ha \000event=0xb,umask=0x1\000\00001\000\000 */
{ 3592593 }, /* unc_h_direct2core_count\000uncore_ha\000uncore cache\000Direct2Core Messages Sent. Unit: uncore_ha \000event=0x11\000\00001\000Number of Direct2Core messages sent\000 */
{ 3592735 }, /* unc_h_direct2core_cycles_disabled\000uncore_ha\000uncore cache\000Cycles when Direct2Core was Disabled. Unit: uncore_ha \000event=0x12\000\00001\000Number of cycles in which Direct2Core was disabled\000 */
{ 3592913 }, /* unc_h_direct2core_txn_override\000uncore_ha\000uncore cache\000Number of Reads that had Direct2Core Overridden. Unit: uncore_ha \000event=0x13\000\00001\000Number of Reads where Direct2Core overridden\000 */
{ 3594075 }, /* unc_h_directory_lookup.no_snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Not Needed. Unit: uncore_ha \000event=0xc,umask=0x2\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3595241 }, /* unc_h_directory_lookup.snp\000uncore_ha\000uncore cache\000Directory Lookups; Snoop Needed. Unit: uncore_ha \000event=0xc,umask=0x1\000\00001\000Counts the number of transactions that looked up the directory.  Can be filtered by requests that had to snoop and those that did not have to\000 */
{ 3596877 }, /* unc_h_directory_update.any\000uncore_ha\000uncore cache\000Directory Updates; Any Directory Update. Unit: uncore_ha \000event=0xd,umask=0x3\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3597571 }, /* unc_h_directory_update.clear\000uncore_ha\000uncore cache\000Directory Updates; Directory Clear. Unit: uncore_ha \000event=0xd,umask=0x2\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3599426 }, /* unc_h_directory_update.set\000uncore_ha\000uncore cache\000Directory Updates; Directory Set. Unit: uncore_ha \000event=0xd,umask=0x1\000\00001\000Counts the number of directory updates that were required.  These result in writes to the memory controller.  This can be filtered by directory sets and directory clears\000 */
{ 3627792 }, /* unc_h_igr_no_credit_cycles.ad_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x1\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628119 }, /* unc_h_igr_no_credit_cycles.ad_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; AD to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x2\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3628774 }, /* unc_h_igr_no_credit_cycles.bl_qpi0\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 0. Unit: uncore_ha \000event=0x22,umask=0x4\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3629101 }, /* unc_h_igr_no_credit_cycles.bl_qpi1\000uncore_ha\000uncore cache\000Cycles without QPI Ingress Credits; BL to QPI Link 1. Unit: uncore_ha \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the HA does not have credits to send messages to the QPI Agent.  This can be filtered by the different credit pools and the different links\000 */
{ 3630382 }, /* unc_h_imc_retry\000uncore_ha\000uncore cache\000Retry Events. Unit: uncore_ha \000event=0x1e\000\00001\000\000 */
{ 3630468 }, /* unc_h_imc_writes.all\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; All Writes. Unit: uncore_ha \000event=0x1a,umask=0xf\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3630784 }, /* unc_h_imc_writes.full\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x1\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631110 }, /* unc_h_imc_writes.full_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Full Line. Unit: uncore_ha \000event=0x1a,umask=0x4\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631438 }, /* unc_h_imc_writes.partial\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; Partial Non-ISOCH. Unit: uncore_ha \000event=0x1a,umask=0x2\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3631765 }, /* unc_h_imc_writes.partial_isoch\000uncore_ha\000uncore cache\000HA to iMC Full Line Writes Issued; ISOCH Partial. Unit: uncore_ha \000event=0x1a,umask=0x8\000\00001\000Counts the total number of full line writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 3658458 }, /* unc_h_requests.reads\000uncore_ha\000uncore cache\000Read and Write Requests; Reads. Unit: uncore_ha \000event=0x1,umask=0x3\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3660380 }, /* unc_h_requests.writes\000uncore_ha\000uncore cache\000Read and Write Requests; Writes. Unit: uncore_ha \000event=0x1,umask=0xc\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3662801 }, /* unc_h_ring_ad_used.ccw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3663578 }, /* unc_h_ring_ad_used.ccw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3666824 }, /* unc_h_ring_ad_used.cw_even\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3e,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3667578 }, /* unc_h_ring_ad_used.cw_odd\000uncore_ha\000uncore cache\000HA AD Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3e,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3671121 }, /* unc_h_ring_ak_used.ccw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3671898 }, /* unc_h_ring_ak_used.ccw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3675144 }, /* unc_h_ring_ak_used.cw_even\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x3f,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3675898 }, /* unc_h_ring_ak_used.cw_odd\000uncore_ha\000uncore cache\000HA AK Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x3f,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3679441 }, /* unc_h_ring_bl_used.ccw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3680218 }, /* unc_h_ring_bl_used.ccw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Counterclockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3683464 }, /* unc_h_ring_bl_used.cw_even\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Even. Unit: uncore_ha \000event=0x40,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3684218 }, /* unc_h_ring_bl_used.cw_odd\000uncore_ha\000uncore cache\000HA BL Ring in Use; Clockwise and Odd. Unit: uncore_ha \000event=0x40,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 3692201 }, /* unc_h_rpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x15,umask=0x1\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3693985 }, /* unc_h_rpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x15,umask=0x2\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3695769 }, /* unc_h_rpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x15,umask=0x4\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3697553 }, /* unc_h_rpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x15,umask=0x8\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3699337 }, /* unc_h_rpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x16,umask=0x1\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3701039 }, /* unc_h_rpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x16,umask=0x2\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3702741 }, /* unc_h_rpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x16,umask=0x4\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3704443 }, /* unc_h_rpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000iMC RPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x16,umask=0x8\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting reads from the HA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's RPQ (read pending queue).  This queue is broken into regular credits/buffers that are used by general reads, and 'special' requests such as ISOCH reads.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3762804 }, /* unc_h_tad_requests_g0.region0\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 0. Unit: uncore_ha \000event=0x1b,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3764309 }, /* unc_h_tad_requests_g0.region1\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 1. Unit: uncore_ha \000event=0x1b,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3765814 }, /* unc_h_tad_requests_g0.region2\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 2. Unit: uncore_ha \000event=0x1b,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3767319 }, /* unc_h_tad_requests_g0.region3\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 3. Unit: uncore_ha \000event=0x1b,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3768824 }, /* unc_h_tad_requests_g0.region4\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 4. Unit: uncore_ha \000event=0x1b,umask=0x10\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3770331 }, /* unc_h_tad_requests_g0.region5\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 5. Unit: uncore_ha \000event=0x1b,umask=0x20\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3771838 }, /* unc_h_tad_requests_g0.region6\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 6. Unit: uncore_ha \000event=0x1b,umask=0x40\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3773345 }, /* unc_h_tad_requests_g0.region7\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 0; TAD Region 7. Unit: uncore_ha \000event=0x1b,umask=0x80\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 0 to 7.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3774852 }, /* unc_h_tad_requests_g1.region10\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 10. Unit: uncore_ha \000event=0x1c,umask=0x4\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3776364 }, /* unc_h_tad_requests_g1.region11\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 11. Unit: uncore_ha \000event=0x1c,umask=0x8\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3777876 }, /* unc_h_tad_requests_g1.region8\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 8. Unit: uncore_ha \000event=0x1c,umask=0x1\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3779383 }, /* unc_h_tad_requests_g1.region9\000uncore_ha\000uncore cache\000HA Requests to a TAD Region - Group 1; TAD Region 9. Unit: uncore_ha \000event=0x1c,umask=0x2\000\00001\000Counts the number of HA requests to a given TAD region.  There are up to 11 TAD (target address decode) regions in each home agent.  All requests destined for the memory controller must first be decoded to determine which TAD region they are in.  This event is filtered based on the TAD region ID, and covers regions 8 to 10.  This event is useful for understanding how applications are using the memory that is spread across the different memory regions.  It is particularly useful for 'Monroe' systems that use the TAD to enable individual channels to enter self-refresh to save power\000 */
{ 3799012 }, /* unc_h_tracker_inserts.all\000uncore_ha\000uncore cache\000Tracker Allocations; All Requests. Unit: uncore_ha \000event=0x6,umask=0x3\000\00001\000Counts the number of allocations into the local HA tracker pool.  This can be used in conjunction with the occupancy accumulation event in order to calculate average latency.  One cannot filter between reads and writes.  HA trackers are allocated as soon as a request enters the HA and is released after the snoop response and data return (or post in the case of a write) and the response is returned on the ring\000 */
{ 3805001 }, /* unc_h_txr_ad.ndr\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Non-data Responses. Unit: uncore_ha \000event=0xf,umask=0x1\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details\000 */
{ 3805297 }, /* unc_h_txr_ad.snp\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions; Snoops. Unit: uncore_ha \000event=0xf,umask=0x2\000\00001\000Counts the number of outbound transactions on the AD ring.  This can be filtered by the NDR and SNP message classes.  See the filter descriptions for more details\000 */
{ 3805745 }, /* unc_h_txr_ad_cycles_full.all\000uncore_ha\000uncore cache\000AD Egress Full; All. Unit: uncore_ha \000event=0x2a,umask=0x3\000\00001\000\000 */
{ 3806049 }, /* unc_h_txr_ad_cycles_full.sched0\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 3806364 }, /* unc_h_txr_ad_cycles_full.sched1\000uncore_ha\000uncore cache\000AD Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 3806663 }, /* unc_h_txr_ad_cycles_ne.all\000uncore_ha\000uncore cache\000AD Egress Not Empty; All. Unit: uncore_ha \000event=0x29,umask=0x3\000\00001\000\000 */
{ 3806983 }, /* unc_h_txr_ad_cycles_ne.sched0\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x29,umask=0x1\000\00001\000\000 */
{ 3807313 }, /* unc_h_txr_ad_cycles_ne.sched1\000uncore_ha\000uncore cache\000AD Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x29,umask=0x2\000\00001\000\000 */
{ 3807617 }, /* unc_h_txr_ad_inserts.all\000uncore_ha\000uncore cache\000AD Egress Allocations; All. Unit: uncore_ha \000event=0x27,umask=0x3\000\00001\000\000 */
{ 3807933 }, /* unc_h_txr_ad_inserts.sched0\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x27,umask=0x1\000\00001\000\000 */
{ 3808260 }, /* unc_h_txr_ad_inserts.sched1\000uncore_ha\000uncore cache\000AD Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x27,umask=0x2\000\00001\000\000 */
{ 3808390 }, /* unc_h_txr_ad_occupancy.all\000uncore_ha\000uncore cache\000AD Egress Occupancy; All. Unit: uncore_ha \000event=0x28,umask=0x3\000\00001\000\000 */
{ 3808702 }, /* unc_h_txr_ad_occupancy.sched0\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x28,umask=0x1\000\00001\000\000 */
{ 3809025 }, /* unc_h_txr_ad_occupancy.sched1\000uncore_ha\000uncore cache\000AD Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x28,umask=0x2\000\00001\000\000 */
{ 3809464 }, /* unc_h_txr_ak_cycles_full.all\000uncore_ha\000uncore cache\000AK Egress Full; All. Unit: uncore_ha \000event=0x32,umask=0x3\000\00001\000\000 */
{ 3809768 }, /* unc_h_txr_ak_cycles_full.sched0\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x32,umask=0x1\000\00001\000\000 */
{ 3810083 }, /* unc_h_txr_ak_cycles_full.sched1\000uncore_ha\000uncore cache\000AK Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x32,umask=0x2\000\00001\000\000 */
{ 3810382 }, /* unc_h_txr_ak_cycles_ne.all\000uncore_ha\000uncore cache\000AK Egress Not Empty; All. Unit: uncore_ha \000event=0x31,umask=0x3\000\00001\000\000 */
{ 3810702 }, /* unc_h_txr_ak_cycles_ne.sched0\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x31,umask=0x1\000\00001\000\000 */
{ 3811032 }, /* unc_h_txr_ak_cycles_ne.sched1\000uncore_ha\000uncore cache\000AK Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x31,umask=0x2\000\00001\000\000 */
{ 3811336 }, /* unc_h_txr_ak_inserts.all\000uncore_ha\000uncore cache\000AK Egress Allocations; All. Unit: uncore_ha \000event=0x2f,umask=0x3\000\00001\000\000 */
{ 3811652 }, /* unc_h_txr_ak_inserts.sched0\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x2f,umask=0x1\000\00001\000\000 */
{ 3811979 }, /* unc_h_txr_ak_inserts.sched1\000uncore_ha\000uncore cache\000AK Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x2f,umask=0x2\000\00001\000\000 */
{ 3812109 }, /* unc_h_txr_ak_ndr\000uncore_ha\000uncore cache\000Outbound NDR Ring Transactions. Unit: uncore_ha \000event=0xe\000\00001\000Counts the number of outbound NDR transactions sent on the AK ring.  NDR stands for 'non-data response' and is generally used for completions that do not include data.  AK NDR is used for messages to the local socket\000 */
{ 3812429 }, /* unc_h_txr_ak_occupancy.all\000uncore_ha\000uncore cache\000AK Egress Occupancy; All. Unit: uncore_ha \000event=0x30,umask=0x3\000\00001\000\000 */
{ 3812741 }, /* unc_h_txr_ak_occupancy.sched0\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x30,umask=0x1\000\00001\000\000 */
{ 3813064 }, /* unc_h_txr_ak_occupancy.sched1\000uncore_ha\000uncore cache\000AK Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x30,umask=0x2\000\00001\000\000 */
{ 3813481 }, /* unc_h_txr_bl.drs_cache\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_ha \000event=0x10,umask=0x1\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000 */
{ 3814030 }, /* unc_h_txr_bl.drs_core\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_ha \000event=0x10,umask=0x2\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000 */
{ 3814571 }, /* unc_h_txr_bl.drs_qpi\000uncore_ha\000uncore cache\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_ha \000event=0x10,umask=0x4\000\00001\000Counts the number of DRS messages sent out on the BL ring.   This can be filtered by the destination\000 */
{ 3814976 }, /* unc_h_txr_bl_cycles_full.all\000uncore_ha\000uncore cache\000BL Egress Full; All. Unit: uncore_ha \000event=0x36,umask=0x3\000\00001\000\000 */
{ 3815280 }, /* unc_h_txr_bl_cycles_full.sched0\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 0. Unit: uncore_ha \000event=0x36,umask=0x1\000\00001\000\000 */
{ 3815595 }, /* unc_h_txr_bl_cycles_full.sched1\000uncore_ha\000uncore cache\000BL Egress Full; Scheduler 1. Unit: uncore_ha \000event=0x36,umask=0x2\000\00001\000\000 */
{ 3815894 }, /* unc_h_txr_bl_cycles_ne.all\000uncore_ha\000uncore cache\000BL Egress Not Empty; All. Unit: uncore_ha \000event=0x35,umask=0x3\000\00001\000\000 */
{ 3816214 }, /* unc_h_txr_bl_cycles_ne.sched0\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 0. Unit: uncore_ha \000event=0x35,umask=0x1\000\00001\000\000 */
{ 3816544 }, /* unc_h_txr_bl_cycles_ne.sched1\000uncore_ha\000uncore cache\000BL Egress Not Empty; Scheduler 1. Unit: uncore_ha \000event=0x35,umask=0x2\000\00001\000\000 */
{ 3816848 }, /* unc_h_txr_bl_inserts.all\000uncore_ha\000uncore cache\000BL Egress Allocations; All. Unit: uncore_ha \000event=0x33,umask=0x3\000\00001\000\000 */
{ 3817164 }, /* unc_h_txr_bl_inserts.sched0\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 0. Unit: uncore_ha \000event=0x33,umask=0x1\000\00001\000\000 */
{ 3817491 }, /* unc_h_txr_bl_inserts.sched1\000uncore_ha\000uncore cache\000BL Egress Allocations; Scheduler 1. Unit: uncore_ha \000event=0x33,umask=0x2\000\00001\000\000 */
{ 3817740 }, /* unc_h_txr_bl_occupancy.all\000uncore_ha\000uncore cache\000BL Egress Occupancy; All. Unit: uncore_ha \000event=0x34,umask=0x3\000\00001\000\000 */
{ 3818052 }, /* unc_h_txr_bl_occupancy.sched0\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 0. Unit: uncore_ha \000event=0x34,umask=0x1\000\00001\000\000 */
{ 3818375 }, /* unc_h_txr_bl_occupancy.sched1\000uncore_ha\000uncore cache\000BL Egress Occupancy; Scheduler 1. Unit: uncore_ha \000event=0x34,umask=0x2\000\00001\000\000 */
{ 3842530 }, /* unc_h_wpq_cycles_no_reg_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 0. Unit: uncore_ha \000event=0x18,umask=0x1\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3844340 }, /* unc_h_wpq_cycles_no_reg_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 1. Unit: uncore_ha \000event=0x18,umask=0x2\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3846150 }, /* unc_h_wpq_cycles_no_reg_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 2. Unit: uncore_ha \000event=0x18,umask=0x4\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3847960 }, /* unc_h_wpq_cycles_no_reg_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Regular; Channel 3. Unit: uncore_ha \000event=0x18,umask=0x8\000\00001\000Counts the number of cycles when there are no 'regular' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the regular credits  Common high banwidth workloads should be able to make use of all of the regular buffers, but it will be difficult (and uncommon) to make use of both the regular and special buffers at the same time.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3849770 }, /* unc_h_wpq_cycles_no_spec_credits.chn0\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 0. Unit: uncore_ha \000event=0x19,umask=0x1\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3851498 }, /* unc_h_wpq_cycles_no_spec_credits.chn1\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 1. Unit: uncore_ha \000event=0x19,umask=0x2\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3853226 }, /* unc_h_wpq_cycles_no_spec_credits.chn2\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 2. Unit: uncore_ha \000event=0x19,umask=0x4\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3854954 }, /* unc_h_wpq_cycles_no_spec_credits.chn3\000uncore_ha\000uncore cache\000HA iMC CHN0 WPQ Credits Empty - Special; Channel 3. Unit: uncore_ha \000event=0x19,umask=0x8\000\00001\000Counts the number of cycles when there are no 'special' credits available for posting writes from the HA into the iMC.  In order to send writes into the memory controller, the HA must first acquire a credit for the iMC's WPQ (write pending queue).  This queue is broken into regular credits/buffers that are used by general writes, and 'special' requests such as ISOCH writes.  This count only tracks the 'special' credits.  This statistic is generally not interesting for general IA workloads, but may be of interest for understanding the characteristics of systems using ISOCH.  One can filter based on the memory controller channel.  One or more channels can be tracked at a given time\000 */
{ 3863000 }, /* unc_i_address_match.merge_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Merges. Unit: uncore_irp \000event=0x17,umask=0x2\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache\000 */
{ 3863730 }, /* unc_i_address_match.stall_count\000uncore_irp\000uncore interconnect\000Address Match (Conflict) Count; Conflict Stalls. Unit: uncore_irp \000event=0x17,umask=0x1\000\00001\000Counts the number of times when an inbound write (from a device to memory or another device) had an address match with another request in the write cache\000 */
{ 3864871 }, /* unc_i_cache_ack_pending_occupancy.any\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Any Source. Unit: uncore_irp \000event=0x14,umask=0x1\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements\000 */
{ 3866148 }, /* unc_i_cache_ack_pending_occupancy.source\000uncore_irp\000uncore interconnect\000Write Ack Pending Occupancy; Select Source. Unit: uncore_irp \000event=0x14,umask=0x2\000\00001\000Accumulates the number of writes that have acquired ownership but have not yet returned their data to the uncore.  These writes are generally queued up in the switch trying to get to the head of their queues so that they can post their data.  The queue occuapancy increments when the ACK is received, and decrements when either the data is returned OR a tickle is received and ownership is released.  Note that a single tickle can result in multiple decrements\000 */
{ 3867304 }, /* unc_i_cache_own_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Any Source. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned\000 */
{ 3868514 }, /* unc_i_cache_own_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Ownership Occupancy; Select Source. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches) that are outstanding in the uncore trying to acquire ownership in each cycle.  This can be used with the write transaction count to calculate the average write latency in the uncore.  The occupancy increments when a write request is issued, and decrements when the data is returned\000 */
{ 3869484 }, /* unc_i_cache_read_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Any Source. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned\000 */
{ 3870564 }, /* unc_i_cache_read_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Read Occupancy; Select Source. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Accumulates the number of reads that are outstanding in the uncore in each cycle.  This can be used with the read transaction count to calculate the average read latency in the uncore.  The occupancy increments when a read request is issued, and decrements when the data is returned\000 */
{ 3871764 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3874258 }, /* unc_i_cache_total_occupancy.source\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Select Source. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3875099 }, /* unc_i_cache_write_occupancy.any\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Any Source. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore\000 */
{ 3876271 }, /* unc_i_cache_write_occupancy.source\000uncore_irp\000uncore interconnect\000Outstanding Write Occupancy; Select Source. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Accumulates the number of writes (and write prefetches)  that are outstanding in the uncore in each cycle.  This can be used with the transaction count event to calculate the average latency in the uncore.  The occupancy increments when the ownership fetch/prefetch is issued, and decrements the data is returned to the uncore\000 */
{ 3876751 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clocks in the IRP. Unit: uncore_irp \000event=0\000\00001\000Number of clocks in the IRP\000 */
{ 3895014 }, /* unc_i_rxr_ak_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xb\000\00001\000Counts the number of cycles when the AK Ingress is full.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895230 }, /* unc_i_rxr_ak_inserts\000uncore_irp\000uncore interconnect\000AK Ingress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000Counts the number of allocations into the AK Ingress.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3895461 }, /* unc_i_rxr_ak_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the occupancy of the AK Ingress in each cycles.  This queue is where the IRP receives responses from R2PCIe (the ring)\000 */
{ 3896003 }, /* unc_i_rxr_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x4\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896298 }, /* unc_i_rxr_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - DRS. Unit: uncore_irp \000event=0x1\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3896938 }, /* unc_i_rxr_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x7\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897559 }, /* unc_i_rxr_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x5\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3897854 }, /* unc_i_rxr_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCB. Unit: uncore_irp \000event=0x2\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3898494 }, /* unc_i_rxr_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x8\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899115 }, /* unc_i_rxr_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x6\000\00001\000Counts the number of cycles when the BL Ingress is full.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3899410 }, /* unc_i_rxr_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL Ingress Occupancy - NCS. Unit: uncore_irp \000event=0x3\000\00001\000Counts the number of allocations into the BL Ingress.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3900050 }, /* unc_i_rxr_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000Unit: uncore_irp \000event=0x9\000\00001\000Accumulates the occupancy of the BL Ingress in each cycles.  This queue is where the IRP receives data from R2PCIe (the ring).  It is used for data returns from read requets as well as outbound MMIO writes\000 */
{ 3905119 }, /* unc_i_tickles.lost_ownership\000uncore_irp\000uncore interconnect\000Tickle Count; Ownership Lost. Unit: uncore_irp \000event=0x16,umask=0x1\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles\000 */
{ 3905817 }, /* unc_i_tickles.top_of_queue\000uncore_irp\000uncore interconnect\000Tickle Count; Data Returned. Unit: uncore_irp \000event=0x16,umask=0x2\000\00001\000Counts the number of tickles that are received.  This is for both explicit (from Cbo) and implicit (internal conflict) tickles\000 */
{ 3909598 }, /* unc_i_transactions.pd_prefetches\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x15,umask=0x4\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000 */
{ 3912072 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x15,umask=0x1\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000 */
{ 3915720 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x15,umask=0x2\000\00001\000Counts the number of 'Inbound' transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID\000 */
{ 3921293 }, /* unc_i_txr_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x18\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3921548 }, /* unc_i_txr_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x19\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3921798 }, /* unc_i_txr_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3921985 }, /* unc_i_txr_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xf\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3922172 }, /* unc_i_txr_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xd\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 3924404 }, /* unc_i_write_ordering_stall_cycles\000uncore_irp\000uncore interconnect\000Write Ordering Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number of cycles when there are pending write ACK's in the switch but the switch->IRP pipeline is not utilized\000 */
{ 5689064 }, /* unc_q_clockticks\000uncore_qpi\000uncore interconnect\000Number of qfclks. Unit: uncore_qpi \000event=0x14\000\00001\000Counts the number of clocks in the QPI LL.  This clock runs at 1/8th the 'GT/s' speed of the QPI link.  For example, a 8GT/s link will have qfclk or 1GHz.  JKT does not support dynamic link speeds, so this frequency is fixed\000 */
{ 5689710 }, /* unc_q_cto_count\000uncore_qpi\000uncore interconnect\000Count of CTO Events. Unit: uncore_qpi \000event=0x38\000\00001\000Counts the number of CTO (cluster trigger outs) events that were asserted across the two slots.  If both slots trigger in a given cycle, the event will increment by 2.  You can use edge detect to count the number of cases when both events triggered\000 */
{ 5690760 }, /* unc_q_direct2core.failure_credits\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress Credits. Unit: uncore_qpi \000event=0x13,umask=0x2\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 5692602 }, /* unc_q_direct2core.failure_credits_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - Egress and RBT. Unit: uncore_qpi \000event=0x13,umask=0x8\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 5694447 }, /* unc_q_direct2core.failure_rbt\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Failure - RBT Not Set. Unit: uncore_qpi \000event=0x13,umask=0x4\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 5696410 }, /* unc_q_direct2core.success\000uncore_qpi\000uncore interconnect\000Direct 2 Core Spawning; Spawn Success. Unit: uncore_qpi \000event=0x13,umask=0x1\000\00001\000Counts the number of DRS packets that we attempted to do direct2core on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 5697587 }, /* unc_q_l1_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L1. Unit: uncore_qpi \000event=0x12\000\00001\000Number of QPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a QPI link.  Use edge detect to count the number of instances when the QPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 5701151 }, /* unc_q_rxl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xf\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5701702 }, /* unc_q_rxl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0x10\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5702372 }, /* unc_q_rxl_bypassed\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x9\000\00001\000Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 5703383 }, /* unc_q_rxl_crc_errors.link_init\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; LinkInit. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000 */
{ 5704396 }, /* unc_q_rxl_crc_errors.normal_op\000uncore_qpi\000uncore interconnect\000CRC Errors Detected; Normal Operations. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Number of CRC errors detected in the QPI Agent.  Each QPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the QPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000 */
{ 5705389 }, /* unc_q_rxl_credits_consumed_vn0.drs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; DRS. Unit: uncore_qpi \000event=0x1e,umask=0x1\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5706086 }, /* unc_q_rxl_credits_consumed_vn0.hom\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; HOM. Unit: uncore_qpi \000event=0x1e,umask=0x8\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5706783 }, /* unc_q_rxl_credits_consumed_vn0.ncb\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCB. Unit: uncore_qpi \000event=0x1e,umask=0x2\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5707480 }, /* unc_q_rxl_credits_consumed_vn0.ncs\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NCS. Unit: uncore_qpi \000event=0x1e,umask=0x4\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5708178 }, /* unc_q_rxl_credits_consumed_vn0.ndr\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; NDR. Unit: uncore_qpi \000event=0x1e,umask=0x20\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5708877 }, /* unc_q_rxl_credits_consumed_vn0.snp\000uncore_qpi\000uncore interconnect\000VN0 Credit Consumed; SNP. Unit: uncore_qpi \000event=0x1e,umask=0x10\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5711417 }, /* unc_q_rxl_credits_consumed_vna\000uncore_qpi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_qpi \000event=0x1d\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 5711727 }, /* unc_q_rxl_cycles_ne\000uncore_qpi\000uncore interconnect\000RxQ Cycles Not Empty. Unit: uncore_qpi \000event=0xa\000\00001\000Counts the number of cycles that the QPI RxQ was not empty.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy Accumulator event to calculate the average occupancy\000 */
{ 5719460 }, /* unc_q_rxl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5722297 }, /* unc_q_rxl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5725114 }, /* unc_q_rxl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5727875 }, /* unc_q_rxl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0x2,umask=0x18\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5730635 }, /* unc_q_rxl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0x2,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5733425 }, /* unc_q_rxl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0x2,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5736264 }, /* unc_q_rxl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Flits. Unit: uncore_qpi \000event=0x2,umask=0x6\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5738805 }, /* unc_q_rxl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5741486 }, /* unc_q_rxl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5744242 }, /* unc_q_rxl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Received - Group 1; SNP Flits. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5746909 }, /* unc_q_rxl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0xc\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5749521 }, /* unc_q_rxl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x4\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5752276 }, /* unc_q_rxl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent non-data Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x8\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5755033 }, /* unc_q_rxl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Coherent standard Rx Flits. Unit: uncore_qpi \000event=0x3,umask=0x10\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5757650 }, /* unc_q_rxl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AD. Unit: uncore_qpi \000event=0x3,umask=0x1\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5760424 }, /* unc_q_rxl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Received - Group 2; Non-Data Response Rx Flits - AK. Unit: uncore_qpi \000event=0x3,umask=0x2\000\00001\000Counts the number of flits received from the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5763199 }, /* unc_q_rxl_inserts\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x8\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5764941 }, /* unc_q_rxl_inserts_drs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - DRS. Unit: uncore_qpi \000event=0x9\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only DRS flits\000 */
{ 5766724 }, /* unc_q_rxl_inserts_hom\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - HOM. Unit: uncore_qpi \000event=0xc\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only HOM flits\000 */
{ 5768507 }, /* unc_q_rxl_inserts_ncb\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCB. Unit: uncore_qpi \000event=0xa\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCB flits\000 */
{ 5770290 }, /* unc_q_rxl_inserts_ncs\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NCS. Unit: uncore_qpi \000event=0xb\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NCS flits\000 */
{ 5772073 }, /* unc_q_rxl_inserts_ndr\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - NDR. Unit: uncore_qpi \000event=0xe\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only NDR flits\000 */
{ 5773856 }, /* unc_q_rxl_inserts_snp\000uncore_qpi\000uncore interconnect\000Rx Flit Buffer Allocations - SNP. Unit: uncore_qpi \000event=0xd\000\00001\000Number of allocations into the QPI Rx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime.  This monitors only SNP flits\000 */
{ 5774435 }, /* unc_q_rxl_occupancy\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - All Packets. Unit: uncore_qpi \000event=0xb\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 5776337 }, /* unc_q_rxl_occupancy_drs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - DRS. Unit: uncore_qpi \000event=0x15\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors DRS flits only\000 */
{ 5778267 }, /* unc_q_rxl_occupancy_hom\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - HOM. Unit: uncore_qpi \000event=0x18\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors HOM flits only\000 */
{ 5780197 }, /* unc_q_rxl_occupancy_ncb\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCB. Unit: uncore_qpi \000event=0x16\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCB flits only\000 */
{ 5782127 }, /* unc_q_rxl_occupancy_ncs\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NCS. Unit: uncore_qpi \000event=0x17\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NCS flits only\000 */
{ 5784057 }, /* unc_q_rxl_occupancy_ndr\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - NDR. Unit: uncore_qpi \000event=0x1a\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors NDR flits only\000 */
{ 5785987 }, /* unc_q_rxl_occupancy_snp\000uncore_qpi\000uncore interconnect\000RxQ Occupancy - SNP. Unit: uncore_qpi \000event=0x19\000\00001\000Accumulates the number of elements in the QPI RxQ in each cycle.  Generally, when data is transmitted across QPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime.  This monitors SNP flits only\000 */
{ 5786615 }, /* unc_q_rxl_stalls.bgf_drs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - HOM. Unit: uncore_qpi \000event=0x35,umask=0x1\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5786797 }, /* unc_q_rxl_stalls.bgf_hom\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - DRS. Unit: uncore_qpi \000event=0x35,umask=0x8\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5786979 }, /* unc_q_rxl_stalls.bgf_ncb\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - SNP. Unit: uncore_qpi \000event=0x35,umask=0x2\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5787161 }, /* unc_q_rxl_stalls.bgf_ncs\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NDR. Unit: uncore_qpi \000event=0x35,umask=0x4\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5787343 }, /* unc_q_rxl_stalls.bgf_ndr\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NCS. Unit: uncore_qpi \000event=0x35,umask=0x20\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5787526 }, /* unc_q_rxl_stalls.bgf_snp\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; BGF Stall - NCB. Unit: uncore_qpi \000event=0x35,umask=0x10\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5787709 }, /* unc_q_rxl_stalls.egress_credits\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; Egress Credits. Unit: uncore_qpi \000event=0x35,umask=0x40\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5787898 }, /* unc_q_rxl_stalls.gv\000uncore_qpi\000uncore interconnect\000Stalls Sending to R3QPI; GV. Unit: uncore_qpi \000event=0x35,umask=0x80\000\00001\000Number of stalls trying to send to R3QPI\000 */
{ 5793631 }, /* unc_q_txl0_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0. Unit: uncore_qpi \000event=0xc\000\00001\000Number of QPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 5794182 }, /* unc_q_txl0p_power_cycles\000uncore_qpi\000uncore interconnect\000Cycles in L0p. Unit: uncore_qpi \000event=0xd\000\00001\000Number of QPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the QPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize QPI for snoops and their responses.  Use edge detect to count the number of instances when the QPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 5794851 }, /* unc_q_txl_bypassed\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_qpi \000event=0x5\000\00001\000Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the QPI Link. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5795613 }, /* unc_q_txl_crc_no_credits.almost_full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is almost full. Unit: uncore_qpi \000event=0x2,umask=0x2\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall\000 */
{ 5796188 }, /* unc_q_txl_crc_no_credits.full\000uncore_qpi\000uncore interconnect\000Cycles Stalled with no LLR Credits; LLR is full. Unit: uncore_qpi \000event=0x2,umask=0x1\000\00001\000Number of cycles when the Tx side ran out of Link Layer Retry credits, causing the Tx to stall\000 */
{ 5796435 }, /* unc_q_txl_cycles_ne\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Cycles not Empty. Unit: uncore_qpi \000event=0x6\000\00001\000Counts the number of cycles when the TxQ is not empty. Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 5796816 }, /* unc_q_txl_flits_g0.data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Data Tx Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5799668 }, /* unc_q_txl_flits_g0.idle\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Idle and Null Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5800905 }, /* unc_q_txl_flits_g0.non_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 0; Non-Data protocol Tx Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  It includes filters for Idle, protocol, and Data Flits.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time (for L0) or 4B instead of 8B for L0p\000 */
{ 5803681 }, /* unc_q_txl_flits_g1.drs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Flits (both Header and Data). Unit: uncore_qpi \000event=0,umask=0x18\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5806359 }, /* unc_q_txl_flits_g1.drs_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Data Flits. Unit: uncore_qpi \000event=0,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5809167 }, /* unc_q_txl_flits_g1.drs_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; DRS Header Flits. Unit: uncore_qpi \000event=0,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5812024 }, /* unc_q_txl_flits_g1.hom\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Flits. Unit: uncore_qpi \000event=0,umask=0x6\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5814580 }, /* unc_q_txl_flits_g1.hom_nonreq\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Non-Request Flits. Unit: uncore_qpi \000event=0,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5817276 }, /* unc_q_txl_flits_g1.hom_req\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; HOM Request Flits. Unit: uncore_qpi \000event=0,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5820050 }, /* unc_q_txl_flits_g1.snp\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 1; SNP Flits. Unit: uncore_qpi \000event=0,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for SNP, HOM, and DRS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5822735 }, /* unc_q_txl_flits_g2.ncb\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent Bypass Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0xc\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5825377 }, /* unc_q_txl_flits_g2.ncb_data\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x4\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5828148 }, /* unc_q_txl_flits_g2.ncb_nondata\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent non-data Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x8\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5830921 }, /* unc_q_txl_flits_g2.ncs\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Coherent standard Tx Flits. Unit: uncore_qpi \000event=0x1,umask=0x10\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5833557 }, /* unc_q_txl_flits_g2.ndr_ad\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AD. Unit: uncore_qpi \000event=0x1,umask=0x1\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5836350 }, /* unc_q_txl_flits_g2.ndr_ak\000uncore_qpi\000uncore interconnect\000Flits Transferred - Group 2; Non-Data Response Tx Flits - AK. Unit: uncore_qpi \000event=0x1,umask=0x2\000\00001\000Counts the number of flits transmitted across the QPI Link.  This is one of three 'groups' that allow us to track flits.  It includes filters for NDR, NCB, and NCS message classes.  Each 'flit' is made up of 80 bits of information (in addition to some ECC data).  In full-width (L0) mode, flits are made up of four 'fits', each of which contains 20 bits of data (along with some additional ECC data).   In half-width (L0p) mode, the fits are only 10 bits, and therefore it takes twice as many fits to transmit a flit.  When one talks about QPI 'speed' (for example, 8.0 GT/s), the 'transfers' here refer to 'fits'.  Therefore, in L0, the system will transfer 1 'flit' at the rate of 1/4th the QPI speed.  One can calculate the bandwidth of the link by taking: flits*80b/time.  Note that this is not the same as 'data' bandwidth.  For example, when we are transferring a 64B cacheline across QPI, we will break it into 9 flits -- 1 with header information and 8 with 64 bits of actual 'data' and an additional 16 bits of other information.  To calculate 'data' bandwidth, one should therefore do: data flits * 8B / time\000 */
{ 5839144 }, /* unc_q_txl_inserts\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_qpi \000event=0x4\000\00001\000Number of allocations into the QPI Tx Flit Buffer.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 5839647 }, /* unc_q_txl_occupancy\000uncore_qpi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_qpi \000event=0x7\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across QPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 5849832 }, /* unc_q_vna_credit_return_occupancy\000uncore_qpi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_qpi \000event=0x1b\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 5850059 }, /* unc_q_vna_credit_returns\000uncore_qpi\000uncore interconnect\000VNA Credits Returned. Unit: uncore_qpi \000event=0x1c\000\00001\000Number of VNA credits returned\000 */
{ 5909172 }, /* unc_r3_clockticks\000uncore_r3qpi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_r3qpi \000event=0x1\000\00001\000Counts the number of uclks in the QPI uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the QPI Agent is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5911242 }, /* unc_r3_iio_credits_acquired.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x8\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5911804 }, /* unc_r3_iio_credits_acquired.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x10\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5912367 }, /* unc_r3_iio_credits_acquired.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Acquired. Unit: uncore_r3qpi \000event=0x20,umask=0x20\000\00001\000Counts the number of times the NCS/NCB/DRS credit is acquired in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5912930 }, /* unc_r3_iio_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x8\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5913562 }, /* unc_r3_iio_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x10\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5914195 }, /* unc_r3_iio_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit Rejected. Unit: uncore_r3qpi \000event=0x21,umask=0x20\000\00001\000Counts the number of times that a request attempted to acquire an NCS/NCB/DRS credit in the QPI for sending messages on BL to the IIO but was rejected because no credit was available.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5914828 }, /* unc_r3_iio_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x8\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5915388 }, /* unc_r3_iio_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x10\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5915949 }, /* unc_r3_iio_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000to IIO BL Credit In Use. Unit: uncore_r3qpi \000event=0x22,umask=0x20\000\00001\000Counts the number of cycles when the NCS/NCB/DRS credit is in use in the QPI for sending messages on BL to the IIO.  There is one credit for each of these three message classes (three credits total).  NCS is used for reads to PCIe space, NCB is used for transferring data without coherency, and DRS is used for transferring data with coherency (cacheable PCI transactions).  This event can only track one message class at a time\000 */
{ 5929186 }, /* unc_r3_ring_ad_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5929989 }, /* unc_r3_ring_ad_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5932410 }, /* unc_r3_ring_ad_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5933190 }, /* unc_r3_ring_ad_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AD Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5935519 }, /* unc_r3_ring_ak_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5936325 }, /* unc_r3_ring_ak_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5938758 }, /* unc_r3_ring_ak_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5939541 }, /* unc_r3_ring_ak_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 AK Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop\000 */
{ 5942716 }, /* unc_r3_ring_bl_used.ccw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5943519 }, /* unc_r3_ring_bl_used.ccw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5945940 }, /* unc_r3_ring_bl_used.cw_even\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Even. Unit: uncore_r3qpi \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5946720 }, /* unc_r3_ring_bl_used.cw_odd\000uncore_r3qpi\000uncore interconnect\000R3 BL Ring in Use; Clockwise and Odd. Unit: uncore_r3qpi \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5948560 }, /* unc_r3_ring_iv_used.any\000uncore_r3qpi\000uncore interconnect\000R3 IV Ring in Use; Any. Unit: uncore_r3qpi \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sent, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time\000 */
{ 5951466 }, /* unc_r3_rxr_bypassed.ad\000uncore_r3qpi\000uncore interconnect\000Ingress Bypassed. Unit: uncore_r3qpi \000event=0x12,umask=0x1\000\00001\000Counts the number of times when the Ingress was bypassed and an incoming transaction was bypassed directly across the BGF and into the qfclk domain\000 */
{ 5951733 }, /* unc_r3_rxr_cycles_ne.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; DRS. Unit: uncore_r3qpi \000event=0x10,umask=0x8\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5952703 }, /* unc_r3_rxr_cycles_ne.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; HOM. Unit: uncore_r3qpi \000event=0x10,umask=0x1\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5953178 }, /* unc_r3_rxr_cycles_ne.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NCB. Unit: uncore_r3qpi \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5953654 }, /* unc_r3_rxr_cycles_ne.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NCS. Unit: uncore_r3qpi \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5954625 }, /* unc_r3_rxr_cycles_ne.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; NDR. Unit: uncore_r3qpi \000event=0x10,umask=0x4\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5955595 }, /* unc_r3_rxr_cycles_ne.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Cycles Not Empty; SNP. Unit: uncore_r3qpi \000event=0x10,umask=0x2\000\00001\000Counts the number of cycles when the QPI Ingress is not empty.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5959628 }, /* unc_r3_rxr_inserts.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; DRS. Unit: uncore_r3qpi \000event=0x11,umask=0x8\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5960564 }, /* unc_r3_rxr_inserts.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; HOM. Unit: uncore_r3qpi \000event=0x11,umask=0x1\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5961501 }, /* unc_r3_rxr_inserts.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCB. Unit: uncore_r3qpi \000event=0x11,umask=0x10\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5962439 }, /* unc_r3_rxr_inserts.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NCS. Unit: uncore_r3qpi \000event=0x11,umask=0x20\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5963376 }, /* unc_r3_rxr_inserts.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; NDR. Unit: uncore_r3qpi \000event=0x11,umask=0x4\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5964312 }, /* unc_r3_rxr_inserts.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Allocations; SNP. Unit: uncore_r3qpi \000event=0x11,umask=0x2\000\00001\000Counts the number of allocations into the QPI Ingress.  This tracks one of the three rings that are used by the QPI agent.  This can be used in conjunction with the QPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5968199 }, /* unc_r3_rxr_occupancy.drs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; DRS. Unit: uncore_r3qpi \000event=0x13,umask=0x8\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5969081 }, /* unc_r3_rxr_occupancy.hom\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; HOM. Unit: uncore_r3qpi \000event=0x13,umask=0x1\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5969964 }, /* unc_r3_rxr_occupancy.ncb\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCB. Unit: uncore_r3qpi \000event=0x13,umask=0x10\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5970848 }, /* unc_r3_rxr_occupancy.ncs\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NCS. Unit: uncore_r3qpi \000event=0x13,umask=0x20\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5971731 }, /* unc_r3_rxr_occupancy.ndr\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; NDR. Unit: uncore_r3qpi \000event=0x13,umask=0x4\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5972613 }, /* unc_r3_rxr_occupancy.snp\000uncore_r3qpi\000uncore interconnect\000Ingress Occupancy Accumulator; SNP. Unit: uncore_r3qpi \000event=0x13,umask=0x2\000\00001\000Accumulates the occupancy of a given QPI Ingress queue in each cycles.  This tracks one of the three ring Ingress buffers.  This can be used with the QPI Ingress Not Empty event to calculate average occupancy or the QPI Ingress Allocations event in order to calculate average queuing latency\000 */
{ 5981403 }, /* unc_r3_vn0_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; DRS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x8\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5983126 }, /* unc_r3_vn0_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; HOM Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x1\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5984874 }, /* unc_r3_vn0_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCB Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x10\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5986546 }, /* unc_r3_vn0_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NCS Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x20\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5988249 }, /* unc_r3_vn0_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; NDR Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x4\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5989980 }, /* unc_r3_vn0_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Acquisition Failed on DRS; SNP Message Class. Unit: uncore_r3qpi \000event=0x37,umask=0x2\000\00001\000Number of times a request failed to acquire a DRS VN0 credit.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This therefore counts the number of times when a request failed to acquire either a VNA or VN0 credit and is delayed.  This should generally be a rare situation\000 */
{ 5991917 }, /* unc_r3_vn0_credits_used.drs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; DRS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 5993930 }, /* unc_r3_vn0_credits_used.hom\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; HOM Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 5995968 }, /* unc_r3_vn0_credits_used.ncb\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCB Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 5997930 }, /* unc_r3_vn0_credits_used.ncs\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NCS Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 5999923 }, /* unc_r3_vn0_credits_used.ndr\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; NDR Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 6001944 }, /* unc_r3_vn0_credits_used.snp\000uncore_r3qpi\000uncore interconnect\000VN0 Credit Used; SNP Message Class. Unit: uncore_r3qpi \000event=0x36,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers\000 */
{ 6014869 }, /* unc_r3_vna_credit_cycles_out\000uncore_r3qpi\000uncore interconnect\000Cycles with no VNA credits available. Unit: uncore_r3qpi \000event=0x31\000\00001\000Number of QPI uclk cycles when the transmitted has no VNA credits available and therefore cannot send any requests on this channel.  Note that this does not mean that no flits can be transmitted, as those holding VN0 credits will still (potentially) be able to transmit.  Generally it is the goal of the uncore that VNA credits should not run out, as this can substantially throttle back useful QPI bandwidth\000 */
{ 6015413 }, /* unc_r3_vna_credit_cycles_used\000uncore_r3qpi\000uncore interconnect\000Cycles with 1 or more VNA credits in use. Unit: uncore_r3qpi \000event=0x32\000\00001\000Number of QPI uclk cycles with one or more VNA credits in use.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average number of used VNA credits\000 */
{ 6017643 }, /* unc_r3_vna_credits_acquired\000uncore_r3qpi\000uncore interconnect\000VNA credit Acquisitions. Unit: uncore_r3qpi \000event=0x33\000\00001\000Number of QPI VNA Credit acquisitions.  This event can be used in conjunction with the VNA In-Use Accumulator to calculate the average lifetime of a credit holder.  VNA credits are used by all message classes in order to communicate across QPI.  If a packet is unable to acquire credits, it will then attempt to use credits from the VN0 pool.  Note that a single packet may require multiple flit buffers (i.e. when data is being transferred).  Therefore, this event will increment by the number of credits acquired in each cycle.  Filtering based on message class is not provided.  One can count the number of packets transferred in a given message class using an qfclk event\000 */
{ 6019458 }, /* unc_r3_vna_credits_reject.drs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; DRS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x8\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6021233 }, /* unc_r3_vna_credits_reject.hom\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; HOM Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x1\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6023033 }, /* unc_r3_vna_credits_reject.ncb\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCB Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x10\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6024728 }, /* unc_r3_vna_credits_reject.ncs\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NCS Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x20\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6026483 }, /* unc_r3_vna_credits_reject.ndr\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; NDR Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x4\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6028266 }, /* unc_r3_vna_credits_reject.snp\000uncore_r3qpi\000uncore interconnect\000VNA Credit Reject; SNP Message Class. Unit: uncore_r3qpi \000event=0x34,umask=0x2\000\00001\000Number of attempted VNA credit acquisitions that were rejected because the VNA credit pool was full (or almost full).  It is possible to filter this event by message class.  Some packets use more than one flit buffer, and therefore must acquire multiple credits.  Therefore, one could get a reject even if the VNA credits were not fully used up.  The VNA pool is generally used to provide the bulk of the QPI bandwidth (as opposed to the VN0 pool which is used to guarantee forward progress).  VNA credits can run out if the flit buffer on the receiving side starts to queue up substantially.  This can happen if the rest of the uncore is unable to drain the requests fast enough\000 */
{ 6073609 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Unit: uncore_ubox \000event=0\000\00001\000\000 */
{ 6074014 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6074623 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6075264 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076060 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076708 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000VLW Received. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.   Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6076954 }, /* unc_u_filter_match.disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x2\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077187 }, /* unc_u_filter_match.enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x1\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077419 }, /* unc_u_filter_match.u2c_disable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x8\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6077656 }, /* unc_u_filter_match.u2c_enable\000uncore_ubox\000uncore interconnect\000Filter Match. Unit: uncore_ubox \000event=0x41,umask=0x4\000\00001\000Filter match per thread (w/ or w/o Filter Enable).  Specify the thread to filter on using NCUPMONCTRLGLCTR.ThreadID\000 */
{ 6078090 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6081064 }, /* unc_u_msg_chnl_size_count.4b\000uncore_ubox\000uncore interconnect\000MsgCh Requests by Size; 4B Requests. Unit: uncore_ubox \000event=0x47,umask=0x1\000\00001\000Number of transactions on the message channel filtered by request size.  This includes both reads and writes\000 */
{ 6081315 }, /* unc_u_msg_chnl_size_count.8b\000uncore_ubox\000uncore interconnect\000MsgCh Requests by Size; 8B Requests. Unit: uncore_ubox \000event=0x47,umask=0x2\000\00001\000Number of transactions on the message channel filtered by request size.  This includes both reads and writes\000 */
{ 6081566 }, /* unc_u_phold_cycles.ack_to_deassert\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; ACK to Deassert. Unit: uncore_ubox \000event=0x45,umask=0x2\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6081974 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles.  Filter from source CoreID\000 */
{ 6082722 }, /* unc_u_racu_requests.count\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46,umask=0x1\000\00001\000\000 */
{ 6083291 }, /* unc_u_u2c_events.cmc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Correctable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x10\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6083700 }, /* unc_u_u2c_events.livelock\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Livelock. Unit: uncore_ubox \000event=0x43,umask=0x4\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6084094 }, /* unc_u_u2c_events.lterror\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; LTError. Unit: uncore_ubox \000event=0x43,umask=0x8\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6084492 }, /* unc_u_u2c_events.monitor_t0\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T0. Unit: uncore_ubox \000event=0x43,umask=0x1\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6084896 }, /* unc_u_u2c_events.monitor_t1\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Monitor T1. Unit: uncore_ubox \000event=0x43,umask=0x2\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085314 }, /* unc_u_u2c_events.other\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Other. Unit: uncore_ubox \000event=0x43,umask=0x80\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085499 }, /* unc_u_u2c_events.trap\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Trap. Unit: uncore_ubox \000event=0x43,umask=0x40\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 6085682 }, /* unc_u_u2c_events.umc\000uncore_ubox\000uncore interconnect\000Monitor Sent to T0; Uncorrectable Machine Check. Unit: uncore_ubox \000event=0x43,umask=0x20\000\00001\000Events coming from Uncore can be sent to one or all cores\000 */
{ 5850201 }, /* unc_r2_clockticks\000uncore_r2pcie\000uncore io\000Number of uclks in domain. Unit: uncore_r2pcie \000event=0x1\000\00001\000Counts the number of uclks in the R2PCIe uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the R2PCIe is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 5851712 }, /* unc_r2_iio_credits_acquired.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; DRS. Unit: uncore_r2pcie \000event=0x33,umask=0x8\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5852924 }, /* unc_r2_iio_credits_acquired.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCB. Unit: uncore_r2pcie \000event=0x33,umask=0x10\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5854137 }, /* unc_r2_iio_credits_acquired.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credit Acquired; NCS. Unit: uncore_r2pcie \000event=0x33,umask=0x20\000\00001\000Counts the number of credits that are acquired in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5855267 }, /* unc_r2_iio_credits_reject.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; DRS. Unit: uncore_r2pcie \000event=0x34,umask=0x8\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5855767 }, /* unc_r2_iio_credits_reject.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; NCB. Unit: uncore_r2pcie \000event=0x34,umask=0x10\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5856268 }, /* unc_r2_iio_credits_reject.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Failed to Acquire a Credit; NCS. Unit: uncore_r2pcie \000event=0x34,umask=0x20\000\00001\000Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5857399 }, /* unc_r2_iio_credits_used.drs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; DRS. Unit: uncore_r2pcie \000event=0x32,umask=0x8\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5858613 }, /* unc_r2_iio_credits_used.ncb\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCB. Unit: uncore_r2pcie \000event=0x32,umask=0x10\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5859828 }, /* unc_r2_iio_credits_used.ncs\000uncore_r2pcie\000uncore io\000R2PCIe IIO Credits in Use; NCS. Unit: uncore_r2pcie \000event=0x32,umask=0x20\000\00001\000Counts the number of cycles when one or more credits in the R2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly)\000 */
{ 5861880 }, /* unc_r2_ring_ad_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x4\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5862667 }, /* unc_r2_ring_ad_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x8\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5865953 }, /* unc_r2_ring_ad_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x7,umask=0x1\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5866717 }, /* unc_r2_ring_ad_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AD Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x7,umask=0x2\000\00001\000Counts the number of cycles that the AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5870701 }, /* unc_r2_ring_ak_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x4\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5871488 }, /* unc_r2_ring_ak_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x8\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5874774 }, /* unc_r2_ring_ak_used.cw_even\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x8,umask=0x1\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5875538 }, /* unc_r2_ring_ak_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 AK Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x8,umask=0x2\000\00001\000Counts the number of cycles that the AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5879126 }, /* unc_r2_ring_bl_used.ccw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x4\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5879913 }, /* unc_r2_ring_bl_used.ccw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Counterclockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x8\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5883199 }, /* unc_r2_ring_bl_used.cw_even\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Even. Unit: uncore_r2pcie \000event=0x9,umask=0x1\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5883963 }, /* unc_r2_ring_bl_used.cw_odd\000uncore_r2pcie\000uncore io\000R2 BL Ring in Use; Clockwise and Odd. Unit: uncore_r2pcie \000event=0x9,umask=0x2\000\00001\000Counts the number of cycles that the BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop\000 */
{ 5886422 }, /* unc_r2_ring_iv_used.any\000uncore_r2pcie\000uncore io\000R2 IV Ring in Use; Any. Unit: uncore_r2pcie \000event=0xa,umask=0xf\000\00001\000Counts the number of cycles that the IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sunk into the ring stop.  The IV ring is unidirectional.  Whether UP or DN is used is dependent on the system programming.  Thereofore, one should generally set both the UP and DN bits for a given polarity (or both) at a given time\000 */
{ 5889839 }, /* unc_r2_rxr_ak_bounces\000uncore_r2pcie\000uncore io\000AK Ingress Bounced. Unit: uncore_r2pcie \000event=0x12\000\00001\000Counts the number of times when a request destined for the AK ingress bounced\000 */
{ 5890019 }, /* unc_r2_rxr_cycles_ne.drs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; DRS. Unit: uncore_r2pcie \000event=0x10,umask=0x8\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5890992 }, /* unc_r2_rxr_cycles_ne.ncb\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCB. Unit: uncore_r2pcie \000event=0x10,umask=0x10\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5891966 }, /* unc_r2_rxr_cycles_ne.ncs\000uncore_r2pcie\000uncore io\000Ingress Cycles Not Empty; NCS. Unit: uncore_r2pcie \000event=0x10,umask=0x20\000\00001\000Counts the number of cycles when the R2PCIe Ingress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters\000 */
{ 5895849 }, /* unc_r2_txr_cycles_full.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AD. Unit: uncore_r2pcie \000event=0x25,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000 */
{ 5896239 }, /* unc_r2_txr_cycles_full.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Full; AK. Unit: uncore_r2pcie \000event=0x25,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000 */
{ 5896629 }, /* unc_r2_txr_cycles_full.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Full; BL. Unit: uncore_r2pcie \000event=0x25,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress buffer is full\000 */
{ 5897346 }, /* unc_r2_txr_cycles_ne.ad\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AD. Unit: uncore_r2pcie \000event=0x23,umask=0x1\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5898390 }, /* unc_r2_txr_cycles_ne.ak\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; AK. Unit: uncore_r2pcie \000event=0x23,umask=0x2\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5899434 }, /* unc_r2_txr_cycles_ne.bl\000uncore_r2pcie\000uncore io\000Egress Cycles Not Empty; BL. Unit: uncore_r2pcie \000event=0x23,umask=0x4\000\00001\000Counts the number of cycles when the R2PCIe Egress is not empty.  This tracks one of the three rings that are used by the R2PCIe agent.  This can be used in conjunction with the R2PCIe Egress Occupancy Accumulator event in order to calculate average queue occupancy.  Only a single Egress queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5901735 }, /* unc_r2_txr_nacks.ad\000uncore_r2pcie\000uncore io\000Egress NACK; AD. Unit: uncore_r2pcie \000event=0x26,umask=0x1\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000 */
{ 5901949 }, /* unc_r2_txr_nacks.ak\000uncore_r2pcie\000uncore io\000Egress NACK; AK. Unit: uncore_r2pcie \000event=0x26,umask=0x2\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000 */
{ 5902163 }, /* unc_r2_txr_nacks.bl\000uncore_r2pcie\000uncore io\000Egress NACK; BL. Unit: uncore_r2pcie \000event=0x26,umask=0x4\000\00001\000Counts the number of times that the Egress received a NACK from the ring and could not issue a transaction\000 */
{ 5378098 }, /* unc_m_act_count\000uncore_imc\000uncore memory\000DRAM Activate Count. Unit: uncore_imc \000event=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5380414 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000\000 */
{ 5382513 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM Reads (RD_CAS + Underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000\000 */
{ 5386248 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM RD_CAS (w/ and w/out auto-pre). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000\000 */
{ 5387219 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; Underfill Read Issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000\000 */
{ 5389983 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; All DRAM WR_CAS (both Modes). Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000\000 */
{ 5392034 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000\000 */
{ 5392820 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000\000 */
{ 5395287 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000uclks. Unit: uncore_imc \000event=0\000\00001\000Uncore Fixed Counter - uclks\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5400513 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000 */
{ 5401274 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000 */
{ 5402012 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000 */
{ 5402909 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5417303 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430855 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5433165 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438879 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5439943 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharges due to page miss. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446888 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency\000 */
{ 5448111 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency\000 */
{ 5502958 }, /* unc_m_rpq_cycles_full\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5508571 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5509732 }, /* unc_m_rpq_occupancy\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5534994 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5539772 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5543154 }, /* unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC\000 */
{ 5545247 }, /* unc_m_wpq_occupancy\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the 'not posted' filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The 'posted' filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5642030 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 800 MHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5642566 }, /* unc_p_core0_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x3\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5645923 }, /* unc_p_core1_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5646548 }, /* unc_p_core2_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5647381 }, /* unc_p_core3_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648006 }, /* unc_p_core4_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x7\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5648631 }, /* unc_p_core5_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x8\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649256 }, /* unc_p_core6_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0x9\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5649881 }, /* unc_p_core7_transition_cycles\000uncore_pcu\000uncore power\000Core C State Transition Cycles. Unit: uncore_pcu \000event=0xa\000\00001\000Number of cycles spent performing core C state transitions.  There is one event per core\000 */
{ 5656618 }, /* unc_p_demotions_core0\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x1e\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5659512 }, /* unc_p_demotions_core1\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x1f\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660051 }, /* unc_p_demotions_core2\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x20\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5660590 }, /* unc_p_demotions_core3\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x21\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661129 }, /* unc_p_demotions_core4\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x22\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5661668 }, /* unc_p_demotions_core5\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x23\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662207 }, /* unc_p_demotions_core6\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x24\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5662746 }, /* unc_p_demotions_core7\000uncore_pcu\000uncore power\000Core C State Demotions. Unit: uncore_pcu \000event=0x25\000\00001\000Counts the number of times when a configurable cores had a C-state demotion\000 */
{ 5665096 }, /* unc_p_freq_band0_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xb\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5665711 }, /* unc_p_freq_band1_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xc\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666326 }, /* unc_p_freq_band2_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xd\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5666941 }, /* unc_p_freq_band3_cycles\000uncore_pcu\000uncore power\000Frequency Residency. Unit: uncore_pcu \000event=0xe\000\00001\000Counts the number of cycles that the uncore was running at a frequency greater than or equal to the frequency that is configured in the filter.  One can use all four counters with this event, so it is possible to track up to 4 configurable bands.  One can use edge detect in conjunction with this event to track the number of times that we transitioned into a frequency greater than or equal to the configurable frequency. One can also use inversion to track cycles when we were less than the configured frequency\000 */
{ 5667772 }, /* unc_p_freq_max_current_cycles\000uncore_pcu\000uncore power\000Current Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x7\000\00001\000Counts the number of cycles when current is the upper limit on frequency\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668753 }, /* unc_p_freq_max_os_cycles\000uncore_pcu\000uncore power\000OS Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x6\000\00001\000Counts the number of cycles when the OS is the upper limit on frequency\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5669358 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x1\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5671395 }, /* unc_p_freq_min_perf_p_cycles\000uncore_pcu\000uncore power\000Perf P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x2\000\00001\000Counts the number of cycles when Perf P Limit is preventing us from dropping the frequency lower.  Perf P Limit is an algorithm that takes input from remote sockets when determining if a socket should drop it's frequency down.  This is largely to minimize increases in snoop and remote read latencies\000 */
{ 5672254 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5680233 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681467 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682722 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in C0.  It can be used by itself to get the average number of cores in C0, with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5686291 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0xb\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5686823 }, /* unc_p_volt_trans_cycles_change\000uncore_pcu\000uncore power\000Cycles Changing Voltage. Unit: uncore_pcu \000event=0x3\000\00001\000Counts the number of cycles when the system is changing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition.  This event is calculated by or'ing together the increasing and decreasing events\000 */
{ 5687295 }, /* unc_p_volt_trans_cycles_decrease\000uncore_pcu\000uncore power\000Cycles Decreasing Voltage. Unit: uncore_pcu \000event=0x2\000\00001\000Counts the number of cycles when the system is decreasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000 */
{ 5687690 }, /* unc_p_volt_trans_cycles_increase\000uncore_pcu\000uncore power\000Cycles Increasing Voltage. Unit: uncore_pcu \000event=0x1\000\00001\000Counts the number of cycles when the system is increasing voltage.  There is no filtering supported with this event.  One can use it as a simple event, or use it conjunction with the occupancy events to monitor the number of cores or threads that were impacted by the transition\000 */
{ 5688085 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x32\000\00001\000\000 */
{ 788831 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000\000 */
{ 790162 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=100003,umask=0x10\000\00000\000This event counts load operations that miss the first DTLB level but hit the second and do not cause any page walks. The penalty in this case is approximately 7 cycles\000 */
{ 796139 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load misses at all DTLB levels that cause completed page walks\000event=0x8,period=100003,umask=0x2\000\00000\000\000 */
{ 806696 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000 */
{ 811205 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000\000 */
{ 812322 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000\000 */
{ 817324 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000\000 */
{ 828893 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000\000 */
{ 832947 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1078837 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000\000 */
{ 1081578 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000\000 */
{ 1083245 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000\000 */
{ 1087846 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000\000 */
{ 1096448 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000This event count cycles when Page Miss Handler (PMH) is servicing page walks caused by ITLB misses\000 */
{ 2540903 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000\000 */
{ 2541700 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__jaketown[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 120903 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 126842 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000\000\00000 */
{ 130701 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 159852 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 170835 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 174074 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219516 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 223534 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_DISPATCHED.THREAD / (cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225687 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_lcp\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 259027 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_mem_bandwidth\000\000\000\000\00000 */
{ 261800 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267423 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182\\,thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 270482 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_C_TOR_OCCUPANCY.MISS_OPCODE@filter_opc\\=0x182@ / UNC_C_TOR_INSERTS.MISS_OPCODE@filter_opc\\=0x182@) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275234 }, /* \000tma_info_system_socket_clks\000SoC\000cbox_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276493 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_DISPATCHED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 281284 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(12 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 297708 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 312331 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 331622 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 336602 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_info_system_dram_bw_use\000100%\000\000\000\00000 */
{ 337674 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: \000100%\000\000\000\00000 */
{ 345532 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 396135 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 462958 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_DISPATCHED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__knightslanding[] = {
{ 574356 }, /* core_reject_l2q.all\000\000cache\000Counts the number of MEC requests that were not accepted into the L2Q because of any L2  queue reject condition. There is no concept of at-ret here. It might include requests due to instructions in the speculative path\000event=0x31,period=200003\000\00000\000\000 */
{ 850764 }, /* fetch_stall.icache_fill_pending_cycles\000\000cache\000Counts the number of core cycles the fetch stalls because of an icache miss. This is a cumulative count of core cycles the fetch stalled for all icache misses\000event=0x86,period=200003,umask=0x4\000\00000\000This event counts the number of core cycles the fetch stalls because of an icache miss. This is a cumulative count of cycles the NIP stalled for all icache misses\000 */
{ 1156443 }, /* l2_requests.miss\000\000cache\000Counts the number of L2 cache misses\000event=0x2e,period=200003,umask=0x41\000\00000\000\000 */
{ 1156545 }, /* l2_requests.reference\000\000cache\000Counts the total number of L2 cache references\000event=0x2e,period=200003,umask=0x4f\000\00000\000\000 */
{ 1156662 }, /* l2_requests_reject.all\000\000cache\000Counts the number of MEC requests from the L2Q that reference a cache line (cacheable requests) excluding SW prefetches filling only to L2 cache and L1 evictions (automatically exlcudes L2HWP, UC, WC) that were rejected - Multiple repeated rejects should be counted multiple times\000event=0x30,period=200003\000\00000\000\000 */
{ 1389282 }, /* mem_uops_retired.all_loads\000\000cache\000Counts all the load micro-ops retired\000event=0x4,period=200003,umask=0x40\000\00000\000This event counts the number of load micro-ops retired\000 */
{ 1391903 }, /* mem_uops_retired.all_stores\000\000cache\000Counts all the store micro-ops retired\000event=0x4,period=200003,umask=0x80\000\00000\000This event counts the number of store micro-ops retired\000 */
{ 1395785 }, /* mem_uops_retired.hitm\000\000cache\000Counts the loads retired that get the data from the other core in the same tile in M state  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x20\000\00000\000\000 */
{ 1396232 }, /* mem_uops_retired.l1_miss_loads\000\000cache\000Counts the number of load micro-ops retired that miss in L1 D cache\000event=0x4,period=200003,umask=0x1\000\00000\000This event counts the number of load micro-ops retired that miss in L1 Data cache. Note that prefetch misses will not be counted\000 */
{ 1396720 }, /* mem_uops_retired.l2_hit_loads\000\000cache\000Counts the number of load micro-ops retired that hit in the L2  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x2\000\00000\000\000 */
{ 1397094 }, /* mem_uops_retired.l2_miss_loads\000\000cache\000Counts the number of load micro-ops retired that miss in the L2  Supports address when precise (Precise event)\000event=0x4,period=100007,umask=0x4\000\00000\000\000 */
{ 1425209 }, /* mem_uops_retired.utlb_miss_loads\000\000cache\000Counts the number of load micro-ops retired that caused micro TLB miss\000event=0x4,period=200003,umask=0x10\000\00000\000\000 */
{ 2459669 }, /* offcore_response\000\000cache\000Counts the matrix events specified by MSR_OFFCORE_RESPx\000event=0xb7,period=100007,umask=0x1\000\00000\000\000 */
{ 1914887 }, /* offcore_response.any_code_rd.any_response\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010044\000\00000\000\000 */
{ 1915924 }, /* offcore_response.any_code_rd.l2_hit_far_tile\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400044\000\00000\000\000 */
{ 1916285 }, /* offcore_response.any_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400044\000\00000\000\000 */
{ 1916654 }, /* offcore_response.any_code_rd.l2_hit_far_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400044\000\00000\000\000 */
{ 1916985 }, /* offcore_response.any_code_rd.l2_hit_near_tile\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180044\000\00000\000\000 */
{ 1917275 }, /* offcore_response.any_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080044\000\00000\000\000 */
{ 1917571 }, /* offcore_response.any_code_rd.l2_hit_near_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080044\000\00000\000\000 */
{ 1917863 }, /* offcore_response.any_code_rd.l2_hit_this_tile_e\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000044\000\00000\000\000 */
{ 1918118 }, /* offcore_response.any_code_rd.l2_hit_this_tile_f\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000044\000\00000\000\000 */
{ 1918373 }, /* offcore_response.any_code_rd.l2_hit_this_tile_m\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000044\000\00000\000\000 */
{ 1918628 }, /* offcore_response.any_code_rd.l2_hit_this_tile_s\000\000cache\000Counts Demand code reads and prefetch code read requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000044\000\00000\000\000 */
{ 1920470 }, /* offcore_response.any_code_rd.outstanding\000\000cache\000Counts Demand code reads and prefetch code read requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000044\000\00000\000\000 */
{ 1926344 }, /* offcore_response.any_data_rd.any_response\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000\000 */
{ 1928446 }, /* offcore_response.any_data_rd.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800403091\000\00000\000\000 */
{ 1928814 }, /* offcore_response.any_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800403091\000\00000\000\000 */
{ 1929190 }, /* offcore_response.any_data_rd.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000403091\000\00000\000\000 */
{ 1929528 }, /* offcore_response.any_data_rd.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800183091\000\00000\000\000 */
{ 1929825 }, /* offcore_response.any_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800083091\000\00000\000\000 */
{ 1930128 }, /* offcore_response.any_data_rd.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000083091\000\00000\000\000 */
{ 1930427 }, /* offcore_response.any_data_rd.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004003091\000\00000\000\000 */
{ 1930689 }, /* offcore_response.any_data_rd.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010003091\000\00000\000\000 */
{ 1930951 }, /* offcore_response.any_data_rd.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002003091\000\00000\000\000 */
{ 1931213 }, /* offcore_response.any_data_rd.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008003091\000\00000\000\000 */
{ 1935831 }, /* offcore_response.any_data_rd.outstanding\000\000cache\000Counts Demand cacheable data and L1 prefetch data read requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000003091\000\00000\000\000 */
{ 1946752 }, /* offcore_response.any_pf_l2.any_response\000\000cache\000Counts any Prefetch requests that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010070\000\00000\000\000 */
{ 1947295 }, /* offcore_response.any_pf_l2.l2_hit_far_tile\000\000cache\000Counts any Prefetch requests that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400070\000\00000\000\000 */
{ 1947625 }, /* offcore_response.any_pf_l2.l2_hit_far_tile_e_f\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400070\000\00000\000\000 */
{ 1947963 }, /* offcore_response.any_pf_l2.l2_hit_far_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400070\000\00000\000\000 */
{ 1948263 }, /* offcore_response.any_pf_l2.l2_hit_near_tile\000\000cache\000Counts any Prefetch requests that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180070\000\00000\000\000 */
{ 1948522 }, /* offcore_response.any_pf_l2.l2_hit_near_tile_e_f\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080070\000\00000\000\000 */
{ 1948787 }, /* offcore_response.any_pf_l2.l2_hit_near_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080070\000\00000\000\000 */
{ 1949048 }, /* offcore_response.any_pf_l2.l2_hit_this_tile_e\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000070\000\00000\000\000 */
{ 1949272 }, /* offcore_response.any_pf_l2.l2_hit_this_tile_f\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000070\000\00000\000\000 */
{ 1949496 }, /* offcore_response.any_pf_l2.l2_hit_this_tile_m\000\000cache\000Counts any Prefetch requests that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000070\000\00000\000\000 */
{ 1950318 }, /* offcore_response.any_pf_l2.outstanding\000\000cache\000Counts any Prefetch requests that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000070\000\00000\000\000 */
{ 1950622 }, /* offcore_response.any_read.any_response\000\000cache\000Counts any Read request  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00000132f7\000\00000\000\000 */
{ 1952654 }, /* offcore_response.any_read.l2_hit_far_tile\000\000cache\000Counts any Read request  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x18004032f7\000\00000\000\000 */
{ 1952979 }, /* offcore_response.any_read.l2_hit_far_tile_e_f\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x08004032f7\000\00000\000\000 */
{ 1953312 }, /* offcore_response.any_read.l2_hit_far_tile_m\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10004032f7\000\00000\000\000 */
{ 1953607 }, /* offcore_response.any_read.l2_hit_near_tile\000\000cache\000Counts any Read request  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x18001832f7\000\00000\000\000 */
{ 1953861 }, /* offcore_response.any_read.l2_hit_near_tile_e_f\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x08000832f7\000\00000\000\000 */
{ 1954121 }, /* offcore_response.any_read.l2_hit_near_tile_m\000\000cache\000Counts any Read request  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x10000832f7\000\00000\000\000 */
{ 1954377 }, /* offcore_response.any_read.l2_hit_this_tile_e\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00040032f7\000\00000\000\000 */
{ 1954596 }, /* offcore_response.any_read.l2_hit_this_tile_f\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00100032f7\000\00000\000\000 */
{ 1954815 }, /* offcore_response.any_read.l2_hit_this_tile_m\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00020032f7\000\00000\000\000 */
{ 1955034 }, /* offcore_response.any_read.l2_hit_this_tile_s\000\000cache\000Counts any Read request  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00080032f7\000\00000\000\000 */
{ 1959158 }, /* offcore_response.any_read.outstanding\000\000cache\000Counts any Read request  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x40000032f7\000\00000\000\000 */
{ 1961450 }, /* offcore_response.any_request.any_response\000\000cache\000Counts any request that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018000\000\00000\000\000 */
{ 1964088 }, /* offcore_response.any_request.l2_hit_far_tile\000\000cache\000Counts any request that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800408000\000\00000\000\000 */
{ 1964410 }, /* offcore_response.any_request.l2_hit_far_tile_e_f\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800408000\000\00000\000\000 */
{ 1964740 }, /* offcore_response.any_request.l2_hit_far_tile_m\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000408000\000\00000\000\000 */
{ 1965032 }, /* offcore_response.any_request.l2_hit_near_tile\000\000cache\000Counts any request that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800188000\000\00000\000\000 */
{ 1965283 }, /* offcore_response.any_request.l2_hit_near_tile_e_f\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800088000\000\00000\000\000 */
{ 1965540 }, /* offcore_response.any_request.l2_hit_near_tile_m\000\000cache\000Counts any request that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000 */
{ 1965793 }, /* offcore_response.any_request.l2_hit_this_tile_e\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004008000\000\00000\000\000 */
{ 1966009 }, /* offcore_response.any_request.l2_hit_this_tile_f\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010008000\000\00000\000\000 */
{ 1966225 }, /* offcore_response.any_request.l2_hit_this_tile_m\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002008000\000\00000\000\000 */
{ 1966441 }, /* offcore_response.any_request.l2_hit_this_tile_s\000\000cache\000Counts any request that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008008000\000\00000\000\000 */
{ 1972990 }, /* offcore_response.any_request.outstanding\000\000cache\000Counts any request that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000008000\000\00000\000\000 */
{ 1976588 }, /* offcore_response.any_rfo.any_response\000\000cache\000Counts Demand cacheable data write requests  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000\000 */
{ 1979030 }, /* offcore_response.any_rfo.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400022\000\00000\000\000 */
{ 1979374 }, /* offcore_response.any_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400022\000\00000\000\000 */
{ 1979726 }, /* offcore_response.any_rfo.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400022\000\00000\000\000 */
{ 1980040 }, /* offcore_response.any_rfo.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180022\000\00000\000\000 */
{ 1980313 }, /* offcore_response.any_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080022\000\00000\000\000 */
{ 1980592 }, /* offcore_response.any_rfo.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080022\000\00000\000\000 */
{ 1980867 }, /* offcore_response.any_rfo.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000022\000\00000\000\000 */
{ 1981105 }, /* offcore_response.any_rfo.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000022\000\00000\000\000 */
{ 1981343 }, /* offcore_response.any_rfo.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000022\000\00000\000\000 */
{ 1981581 }, /* offcore_response.any_rfo.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data write requests  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000022\000\00000\000\000 */
{ 1988679 }, /* offcore_response.any_rfo.outstanding\000\000cache\000Counts Demand cacheable data write requests  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000022\000\00000\000\000 */
{ 1990922 }, /* offcore_response.bus_locks.any_response\000\000cache\000Counts Bus locks and split lock requests that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010400\000\00000\000\000 */
{ 1992829 }, /* offcore_response.bus_locks.l2_hit_far_tile\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400400\000\00000\000\000 */
{ 1993171 }, /* offcore_response.bus_locks.l2_hit_far_tile_e_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400400\000\00000\000\000 */
{ 1993521 }, /* offcore_response.bus_locks.l2_hit_far_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400400\000\00000\000\000 */
{ 1993833 }, /* offcore_response.bus_locks.l2_hit_near_tile\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180400\000\00000\000\000 */
{ 1994104 }, /* offcore_response.bus_locks.l2_hit_near_tile_e_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080400\000\00000\000\000 */
{ 1994381 }, /* offcore_response.bus_locks.l2_hit_near_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080400\000\00000\000\000 */
{ 1994654 }, /* offcore_response.bus_locks.l2_hit_this_tile_e\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000400\000\00000\000\000 */
{ 1994890 }, /* offcore_response.bus_locks.l2_hit_this_tile_f\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000400\000\00000\000\000 */
{ 1995126 }, /* offcore_response.bus_locks.l2_hit_this_tile_m\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000400\000\00000\000\000 */
{ 1995362 }, /* offcore_response.bus_locks.l2_hit_this_tile_s\000\000cache\000Counts Bus locks and split lock requests that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000400\000\00000\000\000 */
{ 1997183 }, /* offcore_response.bus_locks.outstanding\000\000cache\000Counts Bus locks and split lock requests that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000400\000\00000\000\000 */
{ 2026111 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand code reads and prefetch code reads that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000\000 */
{ 2028530 }, /* offcore_response.demand_code_rd.l2_hit_far_tile\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400004\000\00000\000\000 */
{ 2028885 }, /* offcore_response.demand_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400004\000\00000\000\000 */
{ 2029248 }, /* offcore_response.demand_code_rd.l2_hit_far_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400004\000\00000\000\000 */
{ 2029573 }, /* offcore_response.demand_code_rd.l2_hit_near_tile\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180004\000\00000\000\000 */
{ 2029857 }, /* offcore_response.demand_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080004\000\00000\000\000 */
{ 2030147 }, /* offcore_response.demand_code_rd.l2_hit_near_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000 */
{ 2030433 }, /* offcore_response.demand_code_rd.l2_hit_this_tile_e\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000004\000\00000\000\000 */
{ 2030682 }, /* offcore_response.demand_code_rd.l2_hit_this_tile_f\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000004\000\00000\000\000 */
{ 2030931 }, /* offcore_response.demand_code_rd.l2_hit_this_tile_m\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000004\000\00000\000\000 */
{ 2031180 }, /* offcore_response.demand_code_rd.l2_hit_this_tile_s\000\000cache\000Counts demand code reads and prefetch code reads that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000004\000\00000\000\000 */
{ 2066851 }, /* offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand code reads and prefetch code reads that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000\000 */
{ 2079849 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000\000 */
{ 2082703 }, /* offcore_response.demand_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400001\000\00000\000\000 */
{ 2083073 }, /* offcore_response.demand_data_rd.l2_hit_far_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400001\000\00000\000\000 */
{ 2083405 }, /* offcore_response.demand_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080001\000\00000\000\000 */
{ 2083702 }, /* offcore_response.demand_data_rd.l2_hit_near_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000 */
{ 2083995 }, /* offcore_response.demand_data_rd.l2_hit_this_tile_e\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000001\000\00000\000\000 */
{ 2084251 }, /* offcore_response.demand_data_rd.l2_hit_this_tile_f\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000001\000\00000\000\000 */
{ 2084507 }, /* offcore_response.demand_data_rd.l2_hit_this_tile_m\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000001\000\00000\000\000 */
{ 2084763 }, /* offcore_response.demand_data_rd.l2_hit_this_tile_s\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000001\000\00000\000\000 */
{ 2123358 }, /* offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand cacheable data and L1 prefetch data reads that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000\000 */
{ 2137403 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts Demand cacheable data writes that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010002\000\00000\000\000 */
{ 2140652 }, /* offcore_response.demand_rfo.l2_hit_far_tile\000\000cache\000Counts Demand cacheable data writes that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400002\000\00000\000\000 */
{ 2140990 }, /* offcore_response.demand_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400002\000\00000\000\000 */
{ 2141336 }, /* offcore_response.demand_rfo.l2_hit_far_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400002\000\00000\000\000 */
{ 2141644 }, /* offcore_response.demand_rfo.l2_hit_near_tile\000\000cache\000Counts Demand cacheable data writes that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180002\000\00000\000\000 */
{ 2141911 }, /* offcore_response.demand_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080002\000\00000\000\000 */
{ 2142184 }, /* offcore_response.demand_rfo.l2_hit_near_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000 */
{ 2142453 }, /* offcore_response.demand_rfo.l2_hit_this_tile_e\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000002\000\00000\000\000 */
{ 2142685 }, /* offcore_response.demand_rfo.l2_hit_this_tile_f\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000002\000\00000\000\000 */
{ 2142917 }, /* offcore_response.demand_rfo.l2_hit_this_tile_m\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000002\000\00000\000\000 */
{ 2143149 }, /* offcore_response.demand_rfo.l2_hit_this_tile_s\000\000cache\000Counts Demand cacheable data writes that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000002\000\00000\000\000 */
{ 2181306 }, /* offcore_response.demand_rfo.outstanding\000\000cache\000Counts Demand cacheable data writes that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000\000 */
{ 2188008 }, /* offcore_response.full_streaming_stores.any_response\000\000cache\000Counts Full streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010800\000\00000\000\000 */
{ 2226269 }, /* offcore_response.partial_reads.any_response\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010080\000\00000\000\000 */
{ 2227226 }, /* offcore_response.partial_reads.l2_hit_far_tile\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400080\000\00000\000\000 */
{ 2227613 }, /* offcore_response.partial_reads.l2_hit_far_tile_e_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400080\000\00000\000\000 */
{ 2228008 }, /* offcore_response.partial_reads.l2_hit_far_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400080\000\00000\000\000 */
{ 2228365 }, /* offcore_response.partial_reads.l2_hit_near_tile\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180080\000\00000\000\000 */
{ 2228681 }, /* offcore_response.partial_reads.l2_hit_near_tile_e_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080080\000\00000\000\000 */
{ 2229003 }, /* offcore_response.partial_reads.l2_hit_near_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080080\000\00000\000\000 */
{ 2229321 }, /* offcore_response.partial_reads.l2_hit_this_tile_e\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000080\000\00000\000\000 */
{ 2229602 }, /* offcore_response.partial_reads.l2_hit_this_tile_f\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000080\000\00000\000\000 */
{ 2229883 }, /* offcore_response.partial_reads.l2_hit_this_tile_m\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000080\000\00000\000\000 */
{ 2230164 }, /* offcore_response.partial_reads.l2_hit_this_tile_s\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000080\000\00000\000\000 */
{ 2232193 }, /* offcore_response.partial_reads.outstanding\000\000cache\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000080\000\00000\000\000 */
{ 2232554 }, /* offcore_response.partial_streaming_stores.any_response\000\000cache\000Counts Partial streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014000\000\00000\000\000 */
{ 2235506 }, /* offcore_response.partial_writes.any_response\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010100\000\00000\000\000 */
{ 2236193 }, /* offcore_response.partial_writes.l2_hit_far_tile\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400100\000\00000\000\000 */
{ 2236571 }, /* offcore_response.partial_writes.l2_hit_far_tile_e_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400100\000\00000\000\000 */
{ 2236957 }, /* offcore_response.partial_writes.l2_hit_far_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400100\000\00000\000\000 */
{ 2237305 }, /* offcore_response.partial_writes.l2_hit_near_tile\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180100\000\00000\000\000 */
{ 2237612 }, /* offcore_response.partial_writes.l2_hit_near_tile_e_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080100\000\00000\000\000 */
{ 2237925 }, /* offcore_response.partial_writes.l2_hit_near_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080100\000\00000\000\000 */
{ 2238234 }, /* offcore_response.partial_writes.l2_hit_this_tile_e\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000100\000\00000\000\000 */
{ 2238506 }, /* offcore_response.partial_writes.l2_hit_this_tile_f\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000100\000\00000\000\000 */
{ 2238778 }, /* offcore_response.partial_writes.l2_hit_this_tile_m\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000100\000\00000\000\000 */
{ 2239050 }, /* offcore_response.partial_writes.l2_hit_this_tile_s\000\000cache\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000100\000\00000\000\000 */
{ 2260709 }, /* offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts L1 data HW prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000\000 */
{ 2262726 }, /* offcore_response.pf_l1_data_rd.l2_hit_far_tile\000\000cache\000Counts L1 data HW prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800402000\000\00000\000\000 */
{ 2263060 }, /* offcore_response.pf_l1_data_rd.l2_hit_far_tile_e_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800402000\000\00000\000\000 */
{ 2263402 }, /* offcore_response.pf_l1_data_rd.l2_hit_far_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000402000\000\00000\000\000 */
{ 2263706 }, /* offcore_response.pf_l1_data_rd.l2_hit_near_tile\000\000cache\000Counts L1 data HW prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800182000\000\00000\000\000 */
{ 2263969 }, /* offcore_response.pf_l1_data_rd.l2_hit_near_tile_e_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800082000\000\00000\000\000 */
{ 2264238 }, /* offcore_response.pf_l1_data_rd.l2_hit_near_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000082000\000\00000\000\000 */
{ 2264503 }, /* offcore_response.pf_l1_data_rd.l2_hit_this_tile_e\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004002000\000\00000\000\000 */
{ 2264731 }, /* offcore_response.pf_l1_data_rd.l2_hit_this_tile_f\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010002000\000\00000\000\000 */
{ 2264959 }, /* offcore_response.pf_l1_data_rd.l2_hit_this_tile_m\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002002000\000\00000\000\000 */
{ 2265187 }, /* offcore_response.pf_l1_data_rd.l2_hit_this_tile_s\000\000cache\000Counts L1 data HW prefetches that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008002000\000\00000\000\000 */
{ 2269949 }, /* offcore_response.pf_l1_data_rd.outstanding\000\000cache\000Counts L1 data HW prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000002000\000\00000\000\000 */
{ 2289868 }, /* offcore_response.pf_l2_code_rd.any_response\000\000cache\000Counts L2 code HW prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010040\000\00000\000\000 */
{ 2290808 }, /* offcore_response.pf_l2_code_rd.l2_hit_far_tile\000\000cache\000Counts L2 code HW prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800400040\000\00000\000\000 */
{ 2291142 }, /* offcore_response.pf_l2_code_rd.l2_hit_far_tile_e_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400040\000\00000\000\000 */
{ 2291484 }, /* offcore_response.pf_l2_code_rd.l2_hit_far_tile_m\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400040\000\00000\000\000 */
{ 2291788 }, /* offcore_response.pf_l2_code_rd.l2_hit_near_tile\000\000cache\000Counts L2 code HW prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180040\000\00000\000\000 */
{ 2292051 }, /* offcore_response.pf_l2_code_rd.l2_hit_near_tile_e_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080040\000\00000\000\000 */
{ 2292320 }, /* offcore_response.pf_l2_code_rd.l2_hit_near_tile_m\000\000cache\000Counts L2 code HW prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080040\000\00000\000\000 */
{ 2292585 }, /* offcore_response.pf_l2_code_rd.l2_hit_this_tile_e\000\000cache\000Counts L2 code HW prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000040\000\00000\000\000 */
{ 2292813 }, /* offcore_response.pf_l2_code_rd.l2_hit_this_tile_f\000\000cache\000Counts L2 code HW prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000040\000\00000\000\000 */
{ 2300142 }, /* offcore_response.pf_l2_code_rd.outstanding\000\000cache\000Counts L2 code HW prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000040\000\00000\000\000 */
{ 2335026 }, /* offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010020\000\00000\000\000 */
{ 2337651 }, /* offcore_response.pf_l2_rfo.l2_hit_far_tile_e_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400020\000\00000\000\000 */
{ 2338023 }, /* offcore_response.pf_l2_rfo.l2_hit_far_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400020\000\00000\000\000 */
{ 2338357 }, /* offcore_response.pf_l2_rfo.l2_hit_near_tile\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180020\000\00000\000\000 */
{ 2338650 }, /* offcore_response.pf_l2_rfo.l2_hit_near_tile_e_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080020\000\00000\000\000 */
{ 2338949 }, /* offcore_response.pf_l2_rfo.l2_hit_near_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080020\000\00000\000\000 */
{ 2339244 }, /* offcore_response.pf_l2_rfo.l2_hit_this_tile_e\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000020\000\00000\000\000 */
{ 2339502 }, /* offcore_response.pf_l2_rfo.l2_hit_this_tile_f\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000020\000\00000\000\000 */
{ 2339760 }, /* offcore_response.pf_l2_rfo.l2_hit_this_tile_m\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000020\000\00000\000\000 */
{ 2340018 }, /* offcore_response.pf_l2_rfo.l2_hit_this_tile_s\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000020\000\00000\000\000 */
{ 2370128 }, /* offcore_response.pf_l2_rfo.supplier_none\000\000cache\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that provides no supplier details\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000020020\000\00000\000\000 */
{ 2436205 }, /* offcore_response.pf_software.any_response\000\000cache\000Counts Software Prefetches that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000011000\000\00000\000\000 */
{ 2436934 }, /* offcore_response.pf_software.l2_hit_far_tile\000\000cache\000Counts Software Prefetches that accounts for responses from snoop request hit with data forwarded from it Far(not in the same quadrant as the request)-other tile L2 in E/F/M state. Valid only in SNC4 Cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800401000\000\00000\000\000 */
{ 2437264 }, /* offcore_response.pf_software.l2_hit_far_tile_e_f\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800401000\000\00000\000\000 */
{ 2437602 }, /* offcore_response.pf_software.l2_hit_far_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000401000\000\00000\000\000 */
{ 2437902 }, /* offcore_response.pf_software.l2_hit_near_tile\000\000cache\000Counts Software Prefetches that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800181000\000\00000\000\000 */
{ 2438161 }, /* offcore_response.pf_software.l2_hit_near_tile_e_f\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800081000\000\00000\000\000 */
{ 2438426 }, /* offcore_response.pf_software.l2_hit_near_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000081000\000\00000\000\000 */
{ 2438687 }, /* offcore_response.pf_software.l2_hit_this_tile_e\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004001000\000\00000\000\000 */
{ 2438911 }, /* offcore_response.pf_software.l2_hit_this_tile_f\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010001000\000\00000\000\000 */
{ 2439135 }, /* offcore_response.pf_software.l2_hit_this_tile_m\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002001000\000\00000\000\000 */
{ 2439359 }, /* offcore_response.pf_software.l2_hit_this_tile_s\000\000cache\000Counts Software Prefetches that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008001000\000\00000\000\000 */
{ 2440181 }, /* offcore_response.pf_software.outstanding\000\000cache\000Counts Software Prefetches that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000001000\000\00000\000\000 */
{ 2446361 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts all streaming stores (WC and should be programmed on PMC1) that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000014800\000\00000\000\000 */
{ 2455039 }, /* offcore_response.uc_code_reads.any_response\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for any response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010200\000\00000\000\000 */
{ 2455928 }, /* offcore_response.uc_code_reads.l2_hit_far_tile_e_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in E/F state. Valid only for SNC4 cluster mode\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800400200\000\00000\000\000 */
{ 2456306 }, /* offcore_response.uc_code_reads.l2_hit_far_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Far(not in the same quadrant as the request)-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000400200\000\00000\000\000 */
{ 2456646 }, /* offcore_response.uc_code_reads.l2_hit_near_tile\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from snoop request hit with data forwarded from its Near-other tile L2 in E/F/M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1800180200\000\00000\000\000 */
{ 2456945 }, /* offcore_response.uc_code_reads.l2_hit_near_tile_e_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in E/F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0800080200\000\00000\000\000 */
{ 2457250 }, /* offcore_response.uc_code_reads.l2_hit_near_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from a snoop request hit with data forwarded from its Near-other tile's L2 in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000080200\000\00000\000\000 */
{ 2457551 }, /* offcore_response.uc_code_reads.l2_hit_this_tile_e\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in E state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0004000200\000\00000\000\000 */
{ 2457815 }, /* offcore_response.uc_code_reads.l2_hit_this_tile_f\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in F state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0010000200\000\00000\000\000 */
{ 2458079 }, /* offcore_response.uc_code_reads.l2_hit_this_tile_m\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in M state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0002000200\000\00000\000\000 */
{ 2458343 }, /* offcore_response.uc_code_reads.l2_hit_this_tile_s\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses which hit its own tile's L2 with data in S state\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0008000200\000\00000\000\000 */
{ 2459325 }, /* offcore_response.uc_code_reads.outstanding\000\000cache\000Counts UC code reads (valid only for Outstanding response type)  that are outstanding, per weighted cycle, from the time of the request to when any response is received. The outstanding response should be programmed only on PMC0\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000200\000\00000\000\000 */
{ 1291060 }, /* machine_clears.fp_assist\000\000floating point\000Counts the number of floating operations retired that required microcode assists\000event=0xc3,period=200003,umask=0x4\000\00000\000This event counts the number of times that the pipeline stalled due to FP operations needing assists\000 */
{ 6233387 }, /* uops_retired.packed_simd\000\000floating point\000Counts the number of vector SSE, AVX, AVX2, AVX-512 micro-ops retired. More specifically, it counts packed SSE, AVX, AVX2, AVX-512 micro-ops (both floating point and integer) except for loads (memory-to-register mov-type micro-ops), packed byte and word multiplies\000event=0xc2,period=200003,umask=0x40\000\00000\000This event counts the number of packed vector SSE, AVX, AVX2, and AVX-512 micro-ops retired (floating point, integer and store) except for loads (memory-to-register mov-type micro-ops), packed byte and word multiplies\000 */
{ 6235715 }, /* uops_retired.scalar_simd\000\000floating point\000Counts the number of scalar SSE, AVX, AVX2, AVX-512 micro-ops retired. More specifically, it counts scalar SSE, AVX, AVX2, AVX-512 micro-ops except for loads (memory-to-register mov-type micro ops), division, sqrt\000event=0xc2,period=200003,umask=0x20\000\00000\000This event counts the number of scalar SSE, AVX, AVX2, AVX-512 micro-ops retired (floating point, integer and store) except for loads (memory-to-register mov-type micro ops), division, sqrt\000 */
{ 474681 }, /* baclears.all\000\000frontend\000Counts the number of times the front end resteers for any branch as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x1\000\00000\000\000 */
{ 479495 }, /* baclears.cond\000\000frontend\000Counts the number of times the front end resteers for conditional branches as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x10\000\00000\000\000 */
{ 480472 }, /* baclears.return\000\000frontend\000Counts the number of times the front end resteers for RET branches as a result of another branch handling mechanism in the front end\000event=0xe6,period=200003,umask=0x8\000\00000\000\000 */
{ 982731 }, /* icache.accesses\000\000frontend\000Counts all instruction fetches, including uncacheable fetches\000event=0x80,period=200003,umask=0x3\000\00000\000\000 */
{ 985330 }, /* icache.hit\000\000frontend\000Counts all instruction fetches that hit the instruction cache\000event=0x80,period=200003,umask=0x1\000\00000\000\000 */
{ 988540 }, /* icache.misses\000\000frontend\000Counts all instruction fetches that miss the instruction cache or produce memory requests. An instruction fetch miss is counted only once and not once for every cycle it is outstanding\000event=0x80,period=200003,umask=0x2\000\00000\000\000 */
{ 1435501 }, /* ms_decoded.ms_entry\000\000frontend\000Counts the number of times the MSROM starts a flow of uops\000event=0xe7,period=200003,umask=0x1\000\00000\000\000 */
{ 1296131 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of times the machine clears due to memory ordering hazards\000event=0xc3,period=200003,umask=0x2\000\00000\000\000 */
{ 1915274 }, /* offcore_response.any_code_rd.ddr\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800044\000\00000\000\000 */
{ 1915491 }, /* offcore_response.any_code_rd.ddr_far\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000044\000\00000\000\000 */
{ 1915706 }, /* offcore_response.any_code_rd.ddr_near\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800044\000\00000\000\000 */
{ 1919779 }, /* offcore_response.any_code_rd.mcdram\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600044\000\00000\000\000 */
{ 1920002 }, /* offcore_response.any_code_rd.mcdram_far\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400044\000\00000\000\000 */
{ 1920247 }, /* offcore_response.any_code_rd.mcdram_near\000\000memory\000Counts Demand code reads and prefetch code read requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200044\000\00000\000\000 */
{ 1927137 }, /* offcore_response.any_data_rd.ddr\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181803091\000\00000\000\000 */
{ 1927361 }, /* offcore_response.any_data_rd.ddr_far\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101003091\000\00000\000\000 */
{ 1927583 }, /* offcore_response.any_data_rd.ddr_near\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080803091\000\00000\000\000 */
{ 1935119 }, /* offcore_response.any_data_rd.mcdram\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180603091\000\00000\000\000 */
{ 1935349 }, /* offcore_response.any_data_rd.mcdram_far\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100403091\000\00000\000\000 */
{ 1935601 }, /* offcore_response.any_data_rd.mcdram_near\000\000memory\000Counts Demand cacheable data and L1 prefetch data read requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080203091\000\00000\000\000 */
{ 1946924 }, /* offcore_response.any_pf_l2.ddr_far\000\000memory\000Counts any Prefetch requests that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000070\000\00000\000\000 */
{ 1947108 }, /* offcore_response.any_pf_l2.ddr_near\000\000memory\000Counts any Prefetch requests that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800070\000\00000\000\000 */
{ 1949720 }, /* offcore_response.any_pf_l2.mcdram\000\000memory\000Counts any Prefetch requests that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600070\000\00000\000\000 */
{ 1949912 }, /* offcore_response.any_pf_l2.mcdram_far\000\000memory\000Counts any Prefetch requests that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400070\000\00000\000\000 */
{ 1950126 }, /* offcore_response.any_pf_l2.mcdram_near\000\000memory\000Counts any Prefetch requests that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200070\000\00000\000\000 */
{ 1951284 }, /* offcore_response.any_read.ddr\000\000memory\000Counts any Read request  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01818032f7\000\00000\000\000 */
{ 1951465 }, /* offcore_response.any_read.ddr_far\000\000memory\000Counts any Read request  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01010032f7\000\00000\000\000 */
{ 1951644 }, /* offcore_response.any_read.ddr_near\000\000memory\000Counts any Read request  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00808032f7\000\00000\000\000 */
{ 1958575 }, /* offcore_response.any_read.mcdram\000\000memory\000Counts any Read request  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01806032f7\000\00000\000\000 */
{ 1958762 }, /* offcore_response.any_read.mcdram_far\000\000memory\000Counts any Read request  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x01004032f7\000\00000\000\000 */
{ 1958971 }, /* offcore_response.any_read.mcdram_near\000\000memory\000Counts any Read request  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x00802032f7\000\00000\000\000 */
{ 1962593 }, /* offcore_response.any_request.ddr\000\000memory\000Counts any request that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181808000\000\00000\000\000 */
{ 1962771 }, /* offcore_response.any_request.ddr_far\000\000memory\000Counts any request that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101008000\000\00000\000\000 */
{ 1962947 }, /* offcore_response.any_request.ddr_near\000\000memory\000Counts any request that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080808000\000\00000\000\000 */
{ 1972249 }, /* offcore_response.any_request.mcdram\000\000memory\000Counts any request that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180608000\000\00000\000\000 */
{ 1972433 }, /* offcore_response.any_request.mcdram_far\000\000memory\000Counts any request that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100408000\000\00000\000\000 */
{ 1972639 }, /* offcore_response.any_request.mcdram_near\000\000memory\000Counts any request that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080208000\000\00000\000\000 */
{ 1977397 }, /* offcore_response.any_rfo.ddr\000\000memory\000Counts Demand cacheable data write requests  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800022\000\00000\000\000 */
{ 1977597 }, /* offcore_response.any_rfo.ddr_far\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000022\000\00000\000\000 */
{ 1977795 }, /* offcore_response.any_rfo.ddr_near\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800022\000\00000\000\000 */
{ 1987880 }, /* offcore_response.any_rfo.mcdram\000\000memory\000Counts Demand cacheable data write requests  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600022\000\00000\000\000 */
{ 1988086 }, /* offcore_response.any_rfo.mcdram_far\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400022\000\00000\000\000 */
{ 1988314 }, /* offcore_response.any_rfo.mcdram_near\000\000memory\000Counts Demand cacheable data write requests  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200022\000\00000\000\000 */
{ 1991920 }, /* offcore_response.bus_locks.ddr\000\000memory\000Counts Bus locks and split lock requests that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800400\000\00000\000\000 */
{ 1992118 }, /* offcore_response.bus_locks.ddr_far\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000400\000\00000\000\000 */
{ 1992314 }, /* offcore_response.bus_locks.ddr_near\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800400\000\00000\000\000 */
{ 1996549 }, /* offcore_response.bus_locks.mcdram\000\000memory\000Counts Bus locks and split lock requests that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600400\000\00000\000\000 */
{ 1996753 }, /* offcore_response.bus_locks.mcdram_far\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400400\000\00000\000\000 */
{ 1996979 }, /* offcore_response.bus_locks.mcdram_near\000\000memory\000Counts Bus locks and split lock requests that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200400\000\00000\000\000 */
{ 2027018 }, /* offcore_response.demand_code_rd.ddr\000\000memory\000Counts demand code reads and prefetch code reads that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800004\000\00000\000\000 */
{ 2027229 }, /* offcore_response.demand_code_rd.ddr_far\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000004\000\00000\000\000 */
{ 2027438 }, /* offcore_response.demand_code_rd.ddr_near\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800004\000\00000\000\000 */
{ 2065910 }, /* offcore_response.demand_code_rd.mcdram\000\000memory\000Counts demand code reads and prefetch code reads that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600004\000\00000\000\000 */
{ 2066127 }, /* offcore_response.demand_code_rd.mcdram_far\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400004\000\00000\000\000 */
{ 2066366 }, /* offcore_response.demand_code_rd.mcdram_near\000\000memory\000Counts demand code reads and prefetch code reads that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200004\000\00000\000\000 */
{ 2081004 }, /* offcore_response.demand_data_rd.ddr\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800001\000\00000\000\000 */
{ 2081222 }, /* offcore_response.demand_data_rd.ddr_far\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000001\000\00000\000\000 */
{ 2081438 }, /* offcore_response.demand_data_rd.ddr_near\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800001\000\00000\000\000 */
{ 2122235 }, /* offcore_response.demand_data_rd.mcdram\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600001\000\00000\000\000 */
{ 2122459 }, /* offcore_response.demand_data_rd.mcdram_far\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400001\000\00000\000\000 */
{ 2122705 }, /* offcore_response.demand_data_rd.mcdram_near\000\000memory\000Counts demand cacheable data and L1 prefetch data reads that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200001\000\00000\000\000 */
{ 2138887 }, /* offcore_response.demand_rfo.ddr\000\000memory\000Counts Demand cacheable data writes that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800002\000\00000\000\000 */
{ 2139081 }, /* offcore_response.demand_rfo.ddr_far\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000002\000\00000\000\000 */
{ 2139273 }, /* offcore_response.demand_rfo.ddr_near\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800002\000\00000\000\000 */
{ 2180519 }, /* offcore_response.demand_rfo.mcdram\000\000memory\000Counts Demand cacheable data writes that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600002\000\00000\000\000 */
{ 2180719 }, /* offcore_response.demand_rfo.mcdram_far\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400002\000\00000\000\000 */
{ 2180941 }, /* offcore_response.demand_rfo.mcdram_near\000\000memory\000Counts Demand cacheable data writes that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200002\000\00000\000\000 */
{ 2226498 }, /* offcore_response.partial_reads.ddr\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800080\000\00000\000\000 */
{ 2226741 }, /* offcore_response.partial_reads.ddr_far\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000080\000\00000\000\000 */
{ 2226982 }, /* offcore_response.partial_reads.ddr_near\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800080\000\00000\000\000 */
{ 2231135 }, /* offcore_response.partial_reads.mcdram\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600080\000\00000\000\000 */
{ 2231384 }, /* offcore_response.partial_reads.mcdram_far\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400080\000\00000\000\000 */
{ 2231655 }, /* offcore_response.partial_reads.mcdram_near\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200080\000\00000\000\000 */
{ 2231904 }, /* offcore_response.partial_reads.non_dram\000\000memory\000Counts Partial reads (UC or WC and is valid only for Outstanding response type).  that accounts for responses from any NON_DRAM system address. This includes MMIO transactions\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x2000020080\000\00000\000\000 */
{ 2235726 }, /* offcore_response.partial_writes.ddr_far\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000100\000\00000\000\000 */
{ 2235958 }, /* offcore_response.partial_writes.ddr_near\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800100\000\00000\000\000 */
{ 2240178 }, /* offcore_response.partial_writes.mcdram\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600100\000\00000\000\000 */
{ 2240418 }, /* offcore_response.partial_writes.mcdram_far\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400100\000\00000\000\000 */
{ 2240680 }, /* offcore_response.partial_writes.mcdram_near\000\000memory\000Counts Partial writes (UC or WT or WP and should be programmed on PMC1) that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200100\000\00000\000\000 */
{ 2261363 }, /* offcore_response.pf_l1_data_rd.ddr\000\000memory\000Counts L1 data HW prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181802000\000\00000\000\000 */
{ 2261553 }, /* offcore_response.pf_l1_data_rd.ddr_far\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101002000\000\00000\000\000 */
{ 2261741 }, /* offcore_response.pf_l1_data_rd.ddr_near\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080802000\000\00000\000\000 */
{ 2269535 }, /* offcore_response.pf_l1_data_rd.mcdram_far\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100402000\000\00000\000\000 */
{ 2269753 }, /* offcore_response.pf_l1_data_rd.mcdram_near\000\000memory\000Counts L1 data HW prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080202000\000\00000\000\000 */
{ 2290239 }, /* offcore_response.pf_l2_code_rd.ddr\000\000memory\000Counts L2 code HW prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800040\000\00000\000\000 */
{ 2290429 }, /* offcore_response.pf_l2_code_rd.ddr_far\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000040\000\00000\000\000 */
{ 2290617 }, /* offcore_response.pf_l2_code_rd.ddr_near\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800040\000\00000\000\000 */
{ 2299728 }, /* offcore_response.pf_l2_code_rd.mcdram_far\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400040\000\00000\000\000 */
{ 2299946 }, /* offcore_response.pf_l2_code_rd.mcdram_near\000\000memory\000Counts L2 code HW prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200040\000\00000\000\000 */
{ 2336234 }, /* offcore_response.pf_l2_rfo.ddr\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800020\000\00000\000\000 */
{ 2336454 }, /* offcore_response.pf_l2_rfo.ddr_far\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000020\000\00000\000\000 */
{ 2336672 }, /* offcore_response.pf_l2_rfo.ddr_near\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800020\000\00000\000\000 */
{ 2365262 }, /* offcore_response.pf_l2_rfo.mcdram\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600020\000\00000\000\000 */
{ 2365488 }, /* offcore_response.pf_l2_rfo.mcdram_far\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400020\000\00000\000\000 */
{ 2365736 }, /* offcore_response.pf_l2_rfo.mcdram_near\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200020\000\00000\000\000 */
{ 2365962 }, /* offcore_response.pf_l2_rfo.non_dram\000\000memory\000Counts L2 data RFO prefetches (includes PREFETCHW instruction) that accounts for responses from any NON_DRAM system address. This includes MMIO transactions\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x2000020020\000\00000\000\000 */
{ 2436377 }, /* offcore_response.pf_software.ddr\000\000memory\000Counts Software Prefetches that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181801000\000\00000\000\000 */
{ 2436563 }, /* offcore_response.pf_software.ddr_far\000\000memory\000Counts Software Prefetches that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101001000\000\00000\000\000 */
{ 2436747 }, /* offcore_response.pf_software.ddr_near\000\000memory\000Counts Software Prefetches that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080801000\000\00000\000\000 */
{ 2439583 }, /* offcore_response.pf_software.mcdram\000\000memory\000Counts Software Prefetches that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180601000\000\00000\000\000 */
{ 2439775 }, /* offcore_response.pf_software.mcdram_far\000\000memory\000Counts Software Prefetches that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100401000\000\00000\000\000 */
{ 2439989 }, /* offcore_response.pf_software.mcdram_near\000\000memory\000Counts Software Prefetches that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080201000\000\00000\000\000 */
{ 2455251 }, /* offcore_response.uc_code_reads.ddr\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from DDR (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0181800200\000\00000\000\000 */
{ 2455477 }, /* offcore_response.uc_code_reads.ddr_far\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from DRAM Far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0101000200\000\00000\000\000 */
{ 2455701 }, /* offcore_response.uc_code_reads.ddr_near\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from DRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080800200\000\00000\000\000 */
{ 2458607 }, /* offcore_response.uc_code_reads.mcdram\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for responses from MCDRAM (local and far)\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0180600200\000\00000\000\000 */
{ 2458839 }, /* offcore_response.uc_code_reads.mcdram_far\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from MCDRAM Far or Other tile L2 hit far\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0100400200\000\00000\000\000 */
{ 2459093 }, /* offcore_response.uc_code_reads.mcdram_near\000\000memory\000Counts UC code reads (valid only for Outstanding response type)  that accounts for data responses from MCDRAM Local\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080200200\000\00000\000\000 */
{ 497034 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the number of branch instructions retired (Precise event)\000event=0xc4,period=200003\000\00000\000\000 */
{ 502234 }, /* br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 507498 }, /* br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 510375 }, /* br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000 */
{ 513180 }, /* br_inst_retired.jcc\000\000pipeline\000Counts the number of branch instructions retired that were conditional jumps (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000 */
{ 520212 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of branch instructions retired that were near indirect CALL or near indirect JMP (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000 */
{ 523776 }, /* br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000\000 */
{ 525103 }, /* br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000 */
{ 525922 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of branch instructions retired that were conditional jumps and predicted taken (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000 */
{ 537958 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the number of mispredicted branch instructions retired (Precise event)\000event=0xc5,period=200003\000\00000\000\000 */
{ 542201 }, /* br_misp_retired.call\000\000pipeline\000Counts the number of mispredicted near CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf9\000\00000\000\000 */
{ 547261 }, /* br_misp_retired.far_branch\000\000pipeline\000Counts the number of mispredicted far branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xbf\000\00000\000\000 */
{ 548123 }, /* br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 553385 }, /* br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were conditional jumps (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 557140 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were near indirect CALL or near indirect JMP (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 559752 }, /* br_misp_retired.rel_call\000\000pipeline\000Counts the number of mispredicted near relative CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfd\000\00000\000\000 */
{ 562117 }, /* br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 563065 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted branch instructions retired that were conditional jumps and predicted taken (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000 */
{ 619772 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Counts the number of unhalted reference clock cycles\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 624035 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 643889 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter\000 */
{ 647092 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000 */
{ 760429 }, /* cycles_div_busy.all\000\000pipeline\000Cycles the number of core cycles when divider is busy.  Does not imply a stall waiting for the divider\000event=0xcd,period=2000003,umask=0x1\000\00000\000This event counts cycles when the divider is busy. More specifically cycles when the divide unit is unable to accept a new divide uop because it is busy processing a previously dispatched uop. The cycles will be counted irrespective of whether or not another divide uop is waiting to enter the divide unit (from the RS). This event counts integer divides, x87 divides, divss, divsd, sqrtss, sqrtsd event and does not count vector divides\000 */
{ 1045764 }, /* inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire.  For instructions that consist of multiple micro-ops, this event counts exactly once, as the last micro-op of the instruction retires.  The event continues counting while instructions retire, including during interrupt service routines caused by hardware interrupts, faults or traps\000 */
{ 1052656 }, /* inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1288535 }, /* machine_clears.all\000\000pipeline\000Counts all nukes\000event=0xc3,period=200003,umask=0x8\000\00000\000\000 */
{ 1300120 }, /* machine_clears.smc\000\000pipeline\000Counts the number of times that the machine clears due to program modifying data within 1K of a recently fetched code page\000event=0xc3,period=200003,umask=0x1\000\00000\000\000 */
{ 1436813 }, /* no_alloc_cycles.all\000\000pipeline\000Counts the total number of core cycles when no micro-ops are allocated for any reason\000event=0xca,period=200003,umask=0x7f\000\00000\000\000 */
{ 1436970 }, /* no_alloc_cycles.mispredicts\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and the alloc pipe is stalled waiting for a mispredicted branch to retire\000event=0xca,period=200003,umask=0x4\000\00000\000This event counts the number of core cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted branch to retire\000 */
{ 1437918 }, /* no_alloc_cycles.not_delivered\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated, the IQ is empty, and no other condition is blocking allocation\000event=0xca,period=200003,umask=0x90\000\00000\000This event counts the number of core cycles when no uops are allocated, the instruction queue is empty and the alloc pipe is stalled waiting for instructions to be fetched\000 */
{ 1439928 }, /* no_alloc_cycles.rat_stall\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and a RATstall (caused by reservation station full) is asserted\000event=0xca,period=200003,umask=0x20\000\00000\000\000 */
{ 1440293 }, /* no_alloc_cycles.rob_full\000\000pipeline\000Counts the number of core cycles when no micro-ops are allocated and the ROB is full\000event=0xca,period=200003,umask=0x1\000\00000\000\000 */
{ 2484470 }, /* recycleq.any_ld\000\000pipeline\000Counts any retired load that was pushed into the recycle queue for any reason\000event=0x3,period=200003,umask=0x40\000\00000\000\000 */
{ 2484614 }, /* recycleq.any_st\000\000pipeline\000Counts any retired store that was pushed into the recycle queue for any reason\000event=0x3,period=200003,umask=0x80\000\00000\000\000 */
{ 2484759 }, /* recycleq.ld_block_st_forward\000\000pipeline\000Counts the number of occurrences a retired load gets blocked because its address partially overlaps with a store  Supports address when precise (Precise event)\000event=0x3,period=200003,umask=0x1\000\00000\000\000 */
{ 2484997 }, /* recycleq.ld_block_std_notready\000\000pipeline\000Counts the number of occurrences a retired load gets blocked because its address overlaps with a store whose data is not ready\000event=0x3,period=200003,umask=0x2\000\00000\000\000 */
{ 2485204 }, /* recycleq.ld_splits\000\000pipeline\000Counts the number of occurrences a retired load that is a cache line split. Each split should be counted only once  Supports address when precise (Precise event)\000event=0x3,period=200003,umask=0x8\000\00000\000\000 */
{ 2485434 }, /* recycleq.lock\000\000pipeline\000Counts all the retired locked loads. It does not include stores because we would double count if we count stores\000event=0x3,period=200003,umask=0x10\000\00000\000\000 */
{ 2485611 }, /* recycleq.st_splits\000\000pipeline\000Counts the number of occurrences a retired store that is a cache line split. Each split should be counted only once\000event=0x3,period=200003,umask=0x4\000\00000\000This event counts the number of retired store that experienced a cache line boundary split(Precise Event). Note that each spilt should be counted only once\000 */
{ 2485950 }, /* recycleq.sta_full\000\000pipeline\000Counts the store micro-ops retired that were pushed in the rehad queue because the store address buffer is full\000event=0x3,period=200003,umask=0x20\000\00000\000\000 */
{ 2513647 }, /* rs_full_stall.all\000\000pipeline\000Counts the total number of core cycles the Alloc pipeline is stalled when any one of the reservation stations is full\000event=0xcb,period=200003,umask=0x1f\000\00000\000\000 */
{ 2513834 }, /* rs_full_stall.mec\000\000pipeline\000Counts the number of core cycles when allocation pipeline is stalled and is waiting for a free MEC reservation station entry\000event=0xcb,period=200003,umask=0x1\000\00000\000\000 */
{ 6226303 }, /* uops_retired.all\000\000pipeline\000Counts the number of micro-ops retired\000event=0xc2,period=2000003,umask=0x10\000\00000\000This event counts the number of micro-ops (uops) retired. The processor decodes complex macro instructions into a sequence of simpler uops. Most instructions are composed of one or two uops. Some instructions are decoded into longer sequences such as repeat instructions, floating point transcendental instructions, and assists\000 */
{ 6231326 }, /* uops_retired.ms\000\000pipeline\000Counts the number of micro-ops retired that are from the complex flows issued by the micro-sequencer (MS)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired that were supplied from MSROM\000 */
{ 2731478 }, /* unc_c_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x18\000\00001\000\000 */
{ 2731817 }, /* unc_c_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x28\000\00001\000\000 */
{ 2732318 }, /* unc_c_tor_inserts.irq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x11\000\00001\000\000 */
{ 2732704 }, /* unc_c_tor_inserts.irq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x21\000\00001\000\000 */
{ 2733093 }, /* unc_c_tor_inserts.loc_all\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ or PRQ. Unit: uncore_cha \000event=0x35,umask=0x37\000\00001\000\000 */
{ 2750012 }, /* unc_c_tor_inserts.prq_hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x14\000\00001\000\000 */
{ 2750398 }, /* unc_c_tor_inserts.prq_miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x24\000\00001\000\000 */
{ 3551330 }, /* unc_h_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000\000 */
{ 3551656 }, /* unc_h_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000\000 */
{ 3551982 }, /* unc_h_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000\000 */
{ 3552308 }, /* unc_h_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000\000 */
{ 3552634 }, /* unc_h_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000\000 */
{ 3552962 }, /* unc_h_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000\000 */
{ 3553290 }, /* unc_h_ag0_ad_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x80,umask=0x40\000\00001\000\000 */
{ 3553439 }, /* unc_h_ag0_ad_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x80,umask=0x80\000\00001\000\000 */
{ 3553588 }, /* unc_h_ag0_ad_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x81,umask=0x2\000\00001\000\000 */
{ 3553759 }, /* unc_h_ag0_ad_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x81,umask=0x1\000\00001\000\000 */
{ 3553911 }, /* unc_h_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000\000 */
{ 3554241 }, /* unc_h_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000\000 */
{ 3554571 }, /* unc_h_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000\000 */
{ 3554901 }, /* unc_h_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000\000 */
{ 3555231 }, /* unc_h_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000\000 */
{ 3555563 }, /* unc_h_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000\000 */
{ 3555895 }, /* unc_h_ag0_ad_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x82,umask=0x40\000\00001\000\000 */
{ 3556046 }, /* unc_h_ag0_ad_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x82,umask=0x80\000\00001\000\000 */
{ 3556197 }, /* unc_h_ag0_ad_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x83,umask=0x2\000\00001\000\000 */
{ 3556370 }, /* unc_h_ag0_ad_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x83,umask=0x1\000\00001\000\000 */
{ 3556524 }, /* unc_h_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000\000 */
{ 3556850 }, /* unc_h_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000\000 */
{ 3557176 }, /* unc_h_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000\000 */
{ 3557502 }, /* unc_h_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000\000 */
{ 3557828 }, /* unc_h_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000\000 */
{ 3558156 }, /* unc_h_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000\000 */
{ 3558484 }, /* unc_h_ag0_bl_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x88,umask=0x40\000\00001\000\000 */
{ 3558633 }, /* unc_h_ag0_bl_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x88,umask=0x80\000\00001\000\000 */
{ 3558782 }, /* unc_h_ag0_bl_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x89,umask=0x2\000\00001\000\000 */
{ 3558953 }, /* unc_h_ag0_bl_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x89,umask=0x1\000\00001\000\000 */
{ 3559105 }, /* unc_h_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000\000 */
{ 3559435 }, /* unc_h_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000\000 */
{ 3559765 }, /* unc_h_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000\000 */
{ 3560095 }, /* unc_h_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000\000 */
{ 3560425 }, /* unc_h_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000\000 */
{ 3560757 }, /* unc_h_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000\000 */
{ 3561089 }, /* unc_h_ag0_bl_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x8a,umask=0x40\000\00001\000\000 */
{ 3561240 }, /* unc_h_ag0_bl_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x8a,umask=0x80\000\00001\000\000 */
{ 3561391 }, /* unc_h_ag0_bl_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x8b,umask=0x2\000\00001\000\000 */
{ 3561564 }, /* unc_h_ag0_bl_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x8b,umask=0x1\000\00001\000\000 */
{ 3561718 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000\000 */
{ 3561881 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000\000 */
{ 3562044 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000\000 */
{ 3562207 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000\000 */
{ 3562370 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000\000 */
{ 3562534 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000\000 */
{ 3562698 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd0,umask=0x40\000\00001\000\000 */
{ 3562862 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd0,umask=0x80\000\00001\000\000 */
{ 3563026 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd1,umask=0x2\000\00001\000\000 */
{ 3563212 }, /* unc_h_ag0_stall_no_crd_egress_horz_ad_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd1,umask=0x1\000\00001\000\000 */
{ 3563379 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000\000 */
{ 3563542 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000\000 */
{ 3563705 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000\000 */
{ 3563868 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000\000 */
{ 3564031 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000\000 */
{ 3564195 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000\000 */
{ 3564359 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd4,umask=0x40\000\00001\000\000 */
{ 3564523 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd4,umask=0x80\000\00001\000\000 */
{ 3564687 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd5,umask=0x2\000\00001\000\000 */
{ 3564873 }, /* unc_h_ag0_stall_no_crd_egress_horz_bl_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd5,umask=0x1\000\00001\000\000 */
{ 3565040 }, /* unc_h_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000\000 */
{ 3565366 }, /* unc_h_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000\000 */
{ 3565692 }, /* unc_h_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000\000 */
{ 3566018 }, /* unc_h_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000\000 */
{ 3566344 }, /* unc_h_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000\000 */
{ 3566672 }, /* unc_h_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000\000 */
{ 3567000 }, /* unc_h_ag1_ad_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x84,umask=0x40\000\00001\000\000 */
{ 3567149 }, /* unc_h_ag1_ad_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x84,umask=0x80\000\00001\000\000 */
{ 3567298 }, /* unc_h_ag1_ad_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x85,umask=0x2\000\00001\000\000 */
{ 3567469 }, /* unc_h_ag1_ad_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x85,umask=0x1\000\00001\000\000 */
{ 3567621 }, /* unc_h_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000\000 */
{ 3567951 }, /* unc_h_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000\000 */
{ 3568281 }, /* unc_h_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000\000 */
{ 3568611 }, /* unc_h_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000\000 */
{ 3568941 }, /* unc_h_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000\000 */
{ 3569273 }, /* unc_h_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000\000 */
{ 3569605 }, /* unc_h_ag1_ad_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x86,umask=0x40\000\00001\000\000 */
{ 3569756 }, /* unc_h_ag1_ad_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x86,umask=0x80\000\00001\000\000 */
{ 3569907 }, /* unc_h_ag1_ad_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x87,umask=0x2\000\00001\000\000 */
{ 3570080 }, /* unc_h_ag1_ad_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x87,umask=0x1\000\00001\000\000 */
{ 3570234 }, /* unc_h_ag1_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000\000 */
{ 3570382 }, /* unc_h_ag1_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000\000 */
{ 3570530 }, /* unc_h_ag1_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000\000 */
{ 3570678 }, /* unc_h_ag1_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000\000 */
{ 3570826 }, /* unc_h_ag1_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000\000 */
{ 3570975 }, /* unc_h_ag1_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000\000 */
{ 3571124 }, /* unc_h_ag1_bl_crd_acquired.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 6. Unit: uncore_cha \000event=0x8c,umask=0x40\000\00001\000\000 */
{ 3571273 }, /* unc_h_ag1_bl_crd_acquired.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 7. Unit: uncore_cha \000event=0x8c,umask=0x80\000\00001\000\000 */
{ 3571422 }, /* unc_h_ag1_bl_crd_acquired_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 0-7. Unit: uncore_cha \000event=0x8d,umask=0x2\000\00001\000\000 */
{ 3571593 }, /* unc_h_ag1_bl_crd_acquired_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired For Transgress 8. Unit: uncore_cha \000event=0x8d,umask=0x1\000\00001\000\000 */
{ 3571745 }, /* unc_h_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000\000 */
{ 3572075 }, /* unc_h_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000\000 */
{ 3572405 }, /* unc_h_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000\000 */
{ 3572735 }, /* unc_h_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000\000 */
{ 3573065 }, /* unc_h_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000\000 */
{ 3573397 }, /* unc_h_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000\000 */
{ 3573729 }, /* unc_h_ag1_bl_crd_occupancy.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 6. Unit: uncore_cha \000event=0x8e,umask=0x40\000\00001\000\000 */
{ 3573880 }, /* unc_h_ag1_bl_crd_occupancy.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 7. Unit: uncore_cha \000event=0x8e,umask=0x80\000\00001\000\000 */
{ 3574031 }, /* unc_h_ag1_bl_crd_occupancy_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 0-7. Unit: uncore_cha \000event=0x8f,umask=0x2\000\00001\000\000 */
{ 3574204 }, /* unc_h_ag1_bl_crd_occupancy_ext.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy For Transgress 8. Unit: uncore_cha \000event=0x8f,umask=0x1\000\00001\000\000 */
{ 3575476 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000\000 */
{ 3575639 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000\000 */
{ 3575802 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000\000 */
{ 3575965 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000\000 */
{ 3576128 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000\000 */
{ 3576292 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000\000 */
{ 3576456 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd2,umask=0x40\000\00001\000\000 */
{ 3576620 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd2,umask=0x80\000\00001\000\000 */
{ 3576784 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd3,umask=0x2\000\00001\000\000 */
{ 3576970 }, /* unc_h_ag1_stall_no_crd_egress_horz_ad_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd3,umask=0x1\000\00001\000\000 */
{ 3577137 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000\000 */
{ 3577300 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000\000 */
{ 3577463 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000\000 */
{ 3577626 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000\000 */
{ 3577789 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000\000 */
{ 3577953 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000\000 */
{ 3578117 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 6. Unit: uncore_cha \000event=0xd6,umask=0x40\000\00001\000\000 */
{ 3578281 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 7. Unit: uncore_cha \000event=0xd6,umask=0x80\000\00001\000\000 */
{ 3578445 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl_ext.any_of_tgr0_thru_tgr7\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 0-7. Unit: uncore_cha \000event=0xd7,umask=0x2\000\00001\000\000 */
{ 3578631 }, /* unc_h_ag1_stall_no_crd_egress_horz_bl_ext.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Transgress Credits For Transgress 8. Unit: uncore_cha \000event=0xd7,umask=0x1\000\00001\000\000 */
{ 3585904 }, /* unc_h_cache_lines_victimized.e_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000\000 */
{ 3586179 }, /* unc_h_cache_lines_victimized.f_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ. Unit: uncore_cha \000event=0x37,umask=0x8\000\00001\000\000 */
{ 3586467 }, /* unc_h_cache_lines_victimized.local\000uncore_cha\000uncore cache\000Lines Victimized that Match NID. Unit: uncore_cha \000event=0x37,umask=0x20\000\00001\000\000 */
{ 3586604 }, /* unc_h_cache_lines_victimized.m_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Read transactions. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000\000 */
{ 3586792 }, /* unc_h_cache_lines_victimized.remote\000uncore_cha\000uncore cache\000Lines Victimized that Does Not Match NID. Unit: uncore_cha \000event=0x37,umask=0x80\000\00001\000\000 */
{ 3586939 }, /* unc_h_cache_lines_victimized.s_state\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for only snoop requests coming from the remote socket(s) through the IPQ. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000\000 */
{ 3587329 }, /* unc_h_clock\000uncore_cha\000uncore cache\000Uncore Clocks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 3599721 }, /* unc_h_egress_horz_ads_used.ad\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000\000 */
{ 3599844 }, /* unc_h_egress_horz_ads_used.ak\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000\000 */
{ 3599967 }, /* unc_h_egress_horz_ads_used.bl\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000\000 */
{ 3600090 }, /* unc_h_egress_horz_bypass.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. AD ring. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00001\000\000 */
{ 3600225 }, /* unc_h_egress_horz_bypass.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. AK ring. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00001\000\000 */
{ 3600360 }, /* unc_h_egress_horz_bypass.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. BL ring. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00001\000\000 */
{ 3600495 }, /* unc_h_egress_horz_bypass.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Bypass. IV ring. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00001\000\000 */
{ 3600630 }, /* unc_h_egress_horz_cycles_full.ad\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full AD. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000\000 */
{ 3600778 }, /* unc_h_egress_horz_cycles_full.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full AK. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000\000 */
{ 3600926 }, /* unc_h_egress_horz_cycles_full.bl\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full BL. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000\000 */
{ 3601074 }, /* unc_h_egress_horz_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full IV. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000\000 */
{ 3601222 }, /* unc_h_egress_horz_cycles_ne.ad\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty AD. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000\000 */
{ 3601373 }, /* unc_h_egress_horz_cycles_ne.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty AK. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000\000 */
{ 3601524 }, /* unc_h_egress_horz_cycles_ne.bl\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty BL. Unit: uncore_cha \000event=0x97,umask=0x4\000\00001\000\000 */
{ 3601675 }, /* unc_h_egress_horz_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty IV. Unit: uncore_cha \000event=0x97,umask=0x8\000\00001\000\000 */
{ 3601826 }, /* unc_h_egress_horz_inserts.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts AD. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000\000 */
{ 3601957 }, /* unc_h_egress_horz_inserts.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts AK. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000\000 */
{ 3602088 }, /* unc_h_egress_horz_inserts.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts BL. Unit: uncore_cha \000event=0x95,umask=0x4\000\00001\000\000 */
{ 3602219 }, /* unc_h_egress_horz_inserts.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts IV. Unit: uncore_cha \000event=0x95,umask=0x8\000\00001\000\000 */
{ 3602350 }, /* unc_h_egress_horz_nack.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000\000 */
{ 3602473 }, /* unc_h_egress_horz_nack.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000\000 */
{ 3602596 }, /* unc_h_egress_horz_nack.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x4\000\00001\000\000 */
{ 3602719 }, /* unc_h_egress_horz_nack.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs. Unit: uncore_cha \000event=0x99,umask=0x8\000\00001\000\000 */
{ 3602842 }, /* unc_h_egress_horz_occupancy.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy AD. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000\000 */
{ 3602977 }, /* unc_h_egress_horz_occupancy.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy AK. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000\000 */
{ 3603112 }, /* unc_h_egress_horz_occupancy.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy BL. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000\000 */
{ 3603247 }, /* unc_h_egress_horz_occupancy.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy IV. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000\000 */
{ 3603382 }, /* unc_h_egress_horz_starved.ad\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000\000 */
{ 3603523 }, /* unc_h_egress_horz_starved.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000\000 */
{ 3603664 }, /* unc_h_egress_horz_starved.bl\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000\000 */
{ 3603805 }, /* unc_h_egress_horz_starved.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00001\000\000 */
{ 3604322 }, /* unc_h_egress_ordering.iv_snp_go_dn\000uncore_cha\000uncore cache\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements. Unit: uncore_cha \000event=0xae,umask=0x4\000\00001\000\000 */
{ 3604519 }, /* unc_h_egress_ordering.iv_snp_go_up\000uncore_cha\000uncore cache\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements. Unit: uncore_cha \000event=0xae,umask=0x1\000\00001\000\000 */
{ 3604716 }, /* unc_h_egress_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000\000 */
{ 3604841 }, /* unc_h_egress_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000\000 */
{ 3604967 }, /* unc_h_egress_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00001\000\000 */
{ 3605092 }, /* unc_h_egress_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00001\000\000 */
{ 3605218 }, /* unc_h_egress_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000\000 */
{ 3605343 }, /* unc_h_egress_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000\000 */
{ 3605469 }, /* unc_h_egress_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AD ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000\000 */
{ 3605614 }, /* unc_h_egress_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AD ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00001\000\000 */
{ 3605760 }, /* unc_h_egress_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AK ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000\000 */
{ 3605905 }, /* unc_h_egress_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. AK ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00001\000\000 */
{ 3606051 }, /* unc_h_egress_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. BL ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00001\000\000 */
{ 3606196 }, /* unc_h_egress_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. BL ring agent 1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00001\000\000 */
{ 3606342 }, /* unc_h_egress_vert_bypass.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress Bypass. IV ring agent 0. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00001\000\000 */
{ 3606483 }, /* unc_h_egress_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000\000 */
{ 3606643 }, /* unc_h_egress_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000\000 */
{ 3606804 }, /* unc_h_egress_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000\000 */
{ 3606964 }, /* unc_h_egress_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000\000 */
{ 3607125 }, /* unc_h_egress_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000\000 */
{ 3607285 }, /* unc_h_egress_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000\000 */
{ 3607446 }, /* unc_h_egress_vert_cycles_full.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full IV - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000\000 */
{ 3607606 }, /* unc_h_egress_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AD - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000\000 */
{ 3607769 }, /* unc_h_egress_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AD - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00001\000\000 */
{ 3607933 }, /* unc_h_egress_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AK - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000\000 */
{ 3608096 }, /* unc_h_egress_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty AK - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00001\000\000 */
{ 3608260 }, /* unc_h_egress_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty BL - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00001\000\000 */
{ 3608423 }, /* unc_h_egress_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty BL - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00001\000\000 */
{ 3608587 }, /* unc_h_egress_vert_cycles_ne.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty IV - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x8\000\00001\000\000 */
{ 3608750 }, /* unc_h_egress_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AD - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000\000 */
{ 3608893 }, /* unc_h_egress_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AD - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00001\000\000 */
{ 3609037 }, /* unc_h_egress_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AK - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000\000 */
{ 3609180 }, /* unc_h_egress_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations AK - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00001\000\000 */
{ 3609324 }, /* unc_h_egress_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations BL - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00001\000\000 */
{ 3609467 }, /* unc_h_egress_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations BL - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00001\000\000 */
{ 3609611 }, /* unc_h_egress_vert_inserts.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations IV - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x8\000\00001\000\000 */
{ 3609754 }, /* unc_h_egress_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000\000 */
{ 3609879 }, /* unc_h_egress_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000\000 */
{ 3610005 }, /* unc_h_egress_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs Onto AK Ring. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000\000 */
{ 3610143 }, /* unc_h_egress_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000\000 */
{ 3610269 }, /* unc_h_egress_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs Onto BL Ring. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000\000 */
{ 3610407 }, /* unc_h_egress_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000\000 */
{ 3610533 }, /* unc_h_egress_vert_nack.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000\000 */
{ 3610658 }, /* unc_h_egress_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000\000 */
{ 3610801 }, /* unc_h_egress_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000\000 */
{ 3610945 }, /* unc_h_egress_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000\000 */
{ 3611088 }, /* unc_h_egress_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000\000 */
{ 3611232 }, /* unc_h_egress_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000\000 */
{ 3611375 }, /* unc_h_egress_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000\000 */
{ 3611519 }, /* unc_h_egress_vert_occupancy.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy IV - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000\000 */
{ 3611662 }, /* unc_h_egress_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000\000 */
{ 3611805 }, /* unc_h_egress_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000\000 */
{ 3611949 }, /* unc_h_egress_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation Onto AK Ring. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000\000 */
{ 3612105 }, /* unc_h_egress_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000\000 */
{ 3612249 }, /* unc_h_egress_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation Onto BL Ring. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000\000 */
{ 3612405 }, /* unc_h_egress_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000\000 */
{ 3612549 }, /* unc_h_egress_vert_starved.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000\000 */
{ 3612692 }, /* unc_h_fast_asserted.horz\000uncore_cha\000uncore cache\000Counts cycles source throttling is asserted - horizontal. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000\000 */
{ 3612843 }, /* unc_h_fast_asserted.vert\000uncore_cha\000uncore cache\000Counts cycles source throttling is asserted - vertical. Unit: uncore_cha \000event=0xa5\000\00001\000\000 */
{ 3621490 }, /* unc_h_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000\000 */
{ 3621887 }, /* unc_h_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000\000 */
{ 3622280 }, /* unc_h_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000\000 */
{ 3622681 }, /* unc_h_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000\000 */
{ 3623078 }, /* unc_h_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00001\000\000 */
{ 3623475 }, /* unc_h_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00001\000\000 */
{ 3623868 }, /* unc_h_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00001\000\000 */
{ 3624269 }, /* unc_h_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00001\000\000 */
{ 3624666 }, /* unc_h_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Left and Even. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000\000 */
{ 3625063 }, /* unc_h_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Left and Odd. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000\000 */
{ 3625456 }, /* unc_h_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Right and Even. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000\000 */
{ 3625857 }, /* unc_h_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop - Right and Odd. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000\000 */
{ 3626254 }, /* unc_h_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop - Left. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000\000 */
{ 3626627 }, /* unc_h_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop - Right. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000\000 */
{ 3633198 }, /* unc_h_ingress_inserts.ipq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000\000 */
{ 3633393 }, /* unc_h_ingress_inserts.irq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000\000 */
{ 3633588 }, /* unc_h_ingress_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000\000 */
{ 3633796 }, /* unc_h_ingress_inserts.prq\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000\000 */
{ 3633992 }, /* unc_h_ingress_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress Allocations. Counts number of allocations per cycle into the specified Ingress queue. - PRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000\000 */
{ 3634201 }, /* unc_h_ingress_int_starved.ipq\000uncore_cha\000uncore cache\000Cycles with the IPQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x4\000\00001\000\000 */
{ 3634343 }, /* unc_h_ingress_int_starved.irq\000uncore_cha\000uncore cache\000Cycles with the IRQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x1\000\00001\000\000 */
{ 3634485 }, /* unc_h_ingress_int_starved.ismq\000uncore_cha\000uncore cache\000Cycles with the ISMQ in Internal Starvation. Unit: uncore_cha \000event=0x14,umask=0x8\000\00001\000\000 */
{ 3634629 }, /* unc_h_ingress_int_starved.prq\000uncore_cha\000uncore cache\000Ingress internal starvation cycles. Counts cycles in internal starvation. This occurs when one or more of the entries in the ingress queue are being starved out by other entries in the queue. Unit: uncore_cha \000event=0x14,umask=0x10\000\00001\000\000 */
{ 3634920 }, /* unc_h_ingress_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000\000 */
{ 3635113 }, /* unc_h_ingress_occupancy.irq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000\000 */
{ 3635306 }, /* unc_h_ingress_occupancy.irq_rej\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - IRQ Rejected. Unit: uncore_cha \000event=0x11,umask=0x2\000\00001\000\000 */
{ 3635512 }, /* unc_h_ingress_occupancy.prq\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - PRQ. Unit: uncore_cha \000event=0x11,umask=0x10\000\00001\000\000 */
{ 3635706 }, /* unc_h_ingress_occupancy.prq_rej\000uncore_cha\000uncore cache\000Ingress Occupancy. Counts number of entries in the specified Ingress queue in each cycle. - PRQ Rejected. Unit: uncore_cha \000event=0x11,umask=0x20\000\00001\000\000 */
{ 3635913 }, /* unc_h_ingress_retry_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000\000 */
{ 3636053 }, /* unc_h_ingress_retry_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000\000 */
{ 3636193 }, /* unc_h_ingress_retry_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000\000 */
{ 3636334 }, /* unc_h_ingress_retry_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000\000 */
{ 3636475 }, /* unc_h_ingress_retry_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000\000 */
{ 3636616 }, /* unc_h_ingress_retry_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000\000 */
{ 3636756 }, /* unc_h_ingress_retry_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000\000 */
{ 3636895 }, /* unc_h_ingress_retry_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000\000 */
{ 3637036 }, /* unc_h_ingress_retry_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000 */
{ 3637176 }, /* unc_h_ingress_retry_ipq1_reject.any_reject_ipq0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000\000 */
{ 3637321 }, /* unc_h_ingress_retry_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000\000 */
{ 3637460 }, /* unc_h_ingress_retry_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000\000 */
{ 3637599 }, /* unc_h_ingress_retry_ipq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000\000 */
{ 3637736 }, /* unc_h_ingress_retry_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000\000 */
{ 3637878 }, /* unc_h_ingress_retry_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000\000 */
{ 3638020 }, /* unc_h_ingress_retry_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000\000 */
{ 3638163 }, /* unc_h_ingress_retry_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000\000 */
{ 3638306 }, /* unc_h_ingress_retry_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000\000 */
{ 3638449 }, /* unc_h_ingress_retry_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000\000 */
{ 3638591 }, /* unc_h_ingress_retry_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000\000 */
{ 3638732 }, /* unc_h_ingress_retry_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000\000 */
{ 3638875 }, /* unc_h_ingress_retry_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3639017 }, /* unc_h_ingress_retry_irq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000\000 */
{ 3639164 }, /* unc_h_ingress_retry_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3639305 }, /* unc_h_ingress_retry_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000\000 */
{ 3639446 }, /* unc_h_ingress_retry_irq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000\000 */
{ 3639585 }, /* unc_h_ingress_retry_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000\000 */
{ 3639711 }, /* unc_h_ingress_retry_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000\000 */
{ 3639837 }, /* unc_h_ingress_retry_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000\000 */
{ 3639964 }, /* unc_h_ingress_retry_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000\000 */
{ 3640091 }, /* unc_h_ingress_retry_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000\000 */
{ 3640218 }, /* unc_h_ingress_retry_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000\000 */
{ 3640344 }, /* unc_h_ingress_retry_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000\000 */
{ 3640469 }, /* unc_h_ingress_retry_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000\000 */
{ 3640596 }, /* unc_h_ingress_retry_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000\000 */
{ 3640721 }, /* unc_h_ingress_retry_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000\000 */
{ 3640846 }, /* unc_h_ingress_retry_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000\000 */
{ 3640972 }, /* unc_h_ingress_retry_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000\000 */
{ 3641098 }, /* unc_h_ingress_retry_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000\000 */
{ 3641224 }, /* unc_h_ingress_retry_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000\000 */
{ 3641349 }, /* unc_h_ingress_retry_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000\000 */
{ 3641473 }, /* unc_h_ingress_retry_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000\000 */
{ 3641599 }, /* unc_h_ingress_retry_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000\000 */
{ 3641732 }, /* unc_h_ingress_retry_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000\000 */
{ 3641865 }, /* unc_h_ingress_retry_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000\000 */
{ 3641999 }, /* unc_h_ingress_retry_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000\000 */
{ 3642133 }, /* unc_h_ingress_retry_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000\000 */
{ 3642267 }, /* unc_h_ingress_retry_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000\000 */
{ 3642400 }, /* unc_h_ingress_retry_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000\000 */
{ 3642532 }, /* unc_h_ingress_retry_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000\000 */
{ 3642666 }, /* unc_h_ingress_retry_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000\000 */
{ 3642799 }, /* unc_h_ingress_retry_other1_retry.any_reject_irq0\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000\000 */
{ 3642937 }, /* unc_h_ingress_retry_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000\000 */
{ 3643069 }, /* unc_h_ingress_retry_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000\000 */
{ 3643201 }, /* unc_h_ingress_retry_other1_retry.sf_way\000uncore_cha\000uncore cache\000Other Queue Retries. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000\000 */
{ 3643331 }, /* unc_h_ingress_retry_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3643473 }, /* unc_h_ingress_retry_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3643615 }, /* unc_h_ingress_retry_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000\000 */
{ 3643758 }, /* unc_h_ingress_retry_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000\000 */
{ 3643901 }, /* unc_h_ingress_retry_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000\000 */
{ 3644044 }, /* unc_h_ingress_retry_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3644186 }, /* unc_h_ingress_retry_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000\000 */
{ 3644327 }, /* unc_h_ingress_retry_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000\000 */
{ 3644470 }, /* unc_h_ingress_retry_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3644612 }, /* unc_h_ingress_retry_prq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000\000 */
{ 3644759 }, /* unc_h_ingress_retry_prq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000\000 */
{ 3644900 }, /* unc_h_ingress_retry_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000\000 */
{ 3645041 }, /* unc_h_ingress_retry_prq1_reject.sf_way\000uncore_cha\000uncore cache\000Ingress Request Queue Rejects. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000\000 */
{ 3645180 }, /* unc_h_ingress_retry_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 3645368 }, /* unc_h_ingress_retry_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 3645556 }, /* unc_h_ingress_retry_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 3645745 }, /* unc_h_ingress_retry_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 3645934 }, /* unc_h_ingress_retry_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 3646123 }, /* unc_h_ingress_retry_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 3646311 }, /* unc_h_ingress_retry_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 3646498 }, /* unc_h_ingress_retry_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 3646687 }, /* unc_h_ingress_retry_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000\000 */
{ 3646875 }, /* unc_h_ingress_retry_req_q1_retry.any_reject_irq0\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000\000 */
{ 3647068 }, /* unc_h_ingress_retry_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000\000 */
{ 3647255 }, /* unc_h_ingress_retry_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000\000 */
{ 3647442 }, /* unc_h_ingress_retry_req_q1_retry.sf_way\000uncore_cha\000uncore cache\000REQUESTQ'' includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ). Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000\000 */
{ 3650921 }, /* unc_h_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000\000 */
{ 3651234 }, /* unc_h_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000\000 */
{ 3651546 }, /* unc_h_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. RFO HitS. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000\000 */
{ 3651836 }, /* unc_h_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000\000 */
{ 3652148 }, /* unc_h_misc.wc_aliasing\000uncore_cha\000uncore cache\000Miscellaneous events in the Cbo. Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000\000 */
{ 3686313 }, /* unc_h_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 3686664 }, /* unc_h_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Acknowledgements to core. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 3687042 }, /* unc_h_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Data Responses to core. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 3687418 }, /* unc_h_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Number of incoming messages from the Horizontal ring that were bounced, by ring type - Snoops of processor's cache. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000\000 */
{ 3687799 }, /* unc_h_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 3688148 }, /* unc_h_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Acknowledgements to core. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 3688524 }, /* unc_h_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Data Responses to core. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 3688898 }, /* unc_h_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Number of incoming messages from the Vertical ring that were bounced, by ring type - Snoops of processor's cache. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 3689277 }, /* unc_h_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - AD ring. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 3689606 }, /* unc_h_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - AK ring. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 3690124 }, /* unc_h_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - BL ring. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 3690453 }, /* unc_h_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Horizontal ring sink starvation count - IV ring. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 3690962 }, /* unc_h_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - AD ring. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 3691289 }, /* unc_h_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - AK ring. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 3691616 }, /* unc_h_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - BL ring. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 3691943 }, /* unc_h_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Vertical ring sink starvation count - IV ring. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 3692090 }, /* unc_h_ring_src_thrtl\000uncore_cha\000uncore cache\000Counts cycles in throttle mode. Unit: uncore_cha \000event=0xa4\000\00001\000\000 */
{ 3735461 }, /* unc_h_sf_lookup.any\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ. Unit: uncore_cha \000event=0x34,umask=0x11\000\00001\000\000 */
{ 3735733 }, /* unc_h_sf_lookup.data_read\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Read transactions. Unit: uncore_cha \000event=0x34,umask=0x3\000\00001\000\000 */
{ 3735910 }, /* unc_h_sf_lookup.remote_snoop\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Filters for only snoop requests coming from the remote socket(s) through the IPQ. Unit: uncore_cha \000event=0x34,umask=0x9\000\00001\000\000 */
{ 3736153 }, /* unc_h_sf_lookup.write\000uncore_cha\000uncore cache\000Cache Lookups. Counts the number of times the LLC was accessed. Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC. Unit: uncore_cha \000event=0x34,umask=0x5\000\00001\000\000 */
{ 3780890 }, /* unc_h_tg_ingress_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000\000 */
{ 3781268 }, /* unc_h_tg_ingress_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00001\000\000 */
{ 3781647 }, /* unc_h_tg_ingress_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000\000 */
{ 3782025 }, /* unc_h_tg_ingress_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00001\000\000 */
{ 3782404 }, /* unc_h_tg_ingress_bypass.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000\000 */
{ 3782576 }, /* unc_h_tg_ingress_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x10\000\00001\000\000 */
{ 3782749 }, /* unc_h_tg_ingress_bypass.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000\000 */
{ 3782921 }, /* unc_h_tg_ingress_bypass.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000\000 */
{ 3783093 }, /* unc_h_tg_ingress_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x40\000\00001\000\000 */
{ 3783266 }, /* unc_h_tg_ingress_bypass.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass. Number of packets bypassing the CMS Ingress . Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000\000 */
{ 3783438 }, /* unc_h_tg_ingress_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000\000 */
{ 3783827 }, /* unc_h_tg_ingress_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00001\000\000 */
{ 3784217 }, /* unc_h_tg_ingress_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00001\000\000 */
{ 3784606 }, /* unc_h_tg_ingress_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000\000 */
{ 3784995 }, /* unc_h_tg_ingress_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00001\000\000 */
{ 3785385 }, /* unc_h_tg_ingress_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00001\000\000 */
{ 3785772 }, /* unc_h_tg_ingress_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00001\000\000 */
{ 3786161 }, /* unc_h_tg_ingress_inserts.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000\000 */
{ 3786402 }, /* unc_h_tg_ingress_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00001\000\000 */
{ 3786644 }, /* unc_h_tg_ingress_inserts.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000\000 */
{ 3786885 }, /* unc_h_tg_ingress_inserts.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000\000 */
{ 3787126 }, /* unc_h_tg_ingress_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00001\000\000 */
{ 3787368 }, /* unc_h_tg_ingress_inserts.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations. Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000\000 */
{ 3787609 }, /* unc_h_tg_ingress_occupancy.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000\000 */
{ 3787858 }, /* unc_h_tg_ingress_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00001\000\000 */
{ 3788108 }, /* unc_h_tg_ingress_occupancy.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000\000 */
{ 3788357 }, /* unc_h_tg_ingress_occupancy.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000\000 */
{ 3788606 }, /* unc_h_tg_ingress_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00001\000\000 */
{ 3788856 }, /* unc_h_tg_ingress_occupancy.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy. Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000\000 */
{ 3789105 }, /* unc_h_tor_inserts.evict\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x32\000\00001\000\000 */
{ 3789334 }, /* unc_h_tor_inserts.hit\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -Hit (Not a Miss). Unit: uncore_cha \000event=0x35,umask=0x1f\000\00001\000\000 */
{ 3789561 }, /* unc_h_tor_inserts.ipq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x35,umask=0x38\000\00001\000\000 */
{ 3789775 }, /* unc_h_tor_inserts.irq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -IRQ. Unit: uncore_cha \000event=0x35,umask=0x31\000\00001\000\000 */
{ 3789989 }, /* unc_h_tor_inserts.miss\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -Miss. Unit: uncore_cha \000event=0x35,umask=0x2f\000\00001\000\000 */
{ 3790205 }, /* unc_h_tor_inserts.prq\000uncore_cha\000uncore cache\000Counts the number of entries successfully inserted into the TOR that match  qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x35,umask=0x34\000\00001\000\000 */
{ 3790419 }, /* unc_h_tor_occupancy.evict\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x32\000\00001\000\000 */
{ 3790663 }, /* unc_h_tor_occupancy.hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -Hit (Not a Miss). Unit: uncore_cha \000event=0x36,umask=0x1f\000\00001\000\000 */
{ 3790905 }, /* unc_h_tor_occupancy.ipq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ. Unit: uncore_cha \000event=0x36,umask=0x38\000\00001\000\000 */
{ 3791134 }, /* unc_h_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ hit. Unit: uncore_cha \000event=0x36,umask=0x18\000\00001\000\000 */
{ 3791371 }, /* unc_h_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IPQ miss. Unit: uncore_cha \000event=0x36,umask=0x28\000\00001\000\000 */
{ 3791610 }, /* unc_h_tor_occupancy.irq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ. Unit: uncore_cha \000event=0x36,umask=0x31\000\00001\000\000 */
{ 3791846 }, /* unc_h_tor_occupancy.irq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ hit. Unit: uncore_cha \000event=0x36,umask=0x11\000\00001\000\000 */
{ 3792090 }, /* unc_h_tor_occupancy.irq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -IRQ or PRQ miss. Unit: uncore_cha \000event=0x36,umask=0x21\000\00001\000\000 */
{ 3792336 }, /* unc_h_tor_occupancy.miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -Miss. Unit: uncore_cha \000event=0x36,umask=0x2f\000\00001\000\000 */
{ 3792567 }, /* unc_h_tor_occupancy.prq\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ. Unit: uncore_cha \000event=0x36,umask=0x34\000\00001\000\000 */
{ 3792796 }, /* unc_h_tor_occupancy.prq_hit\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ hit. Unit: uncore_cha \000event=0x36,umask=0x14\000\00001\000\000 */
{ 3793033 }, /* unc_h_tor_occupancy.prq_miss\000uncore_cha\000uncore cache\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent -PRQ miss. Unit: uncore_cha \000event=0x36,umask=0x24\000\00001\000\000 */
{ 3836757 }, /* unc_h_u_clockticks\000uncore_cha\000uncore cache\000Uncore Clocks. Unit: uncore_cha \000event=0\000\00001\000\000 */
{ 3836846 }, /* unc_h_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000\000 */
{ 3837235 }, /* unc_h_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00001\000\000 */
{ 3837620 }, /* unc_h_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000\000 */
{ 3838007 }, /* unc_h_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00001\000\000 */
{ 3838390 }, /* unc_h_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00001\000\000 */
{ 3838779 }, /* unc_h_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00001\000\000 */
{ 3839164 }, /* unc_h_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00001\000\000 */
{ 3839551 }, /* unc_h_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00001\000\000 */
{ 3839934 }, /* unc_h_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Down and Even. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000\000 */
{ 3840323 }, /* unc_h_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Down and Odd. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000\000 */
{ 3840708 }, /* unc_h_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Up and Even. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000\000 */
{ 3841095 }, /* unc_h_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop - Up and Odd. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000\000 */
{ 3841478 }, /* unc_h_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop - Down. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000\000 */
{ 3841843 }, /* unc_h_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop - Up. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000\000 */
{ 4710117 }, /* unc_m2p_egress_cycles_full.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AD_0. Unit: uncore_m2pcie \000event=0x25,umask=0x1\000\00001\000\000 */
{ 4710316 }, /* unc_m2p_egress_cycles_full.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AD_1. Unit: uncore_m2pcie \000event=0x25,umask=0x8\000\00001\000\000 */
{ 4710515 }, /* unc_m2p_egress_cycles_full.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AK_0. Unit: uncore_m2pcie \000event=0x25,umask=0x2\000\00001\000\000 */
{ 4710714 }, /* unc_m2p_egress_cycles_full.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  AK_1. Unit: uncore_m2pcie \000event=0x25,umask=0x10\000\00001\000\000 */
{ 4710914 }, /* unc_m2p_egress_cycles_full.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  BL_0. Unit: uncore_m2pcie \000event=0x25,umask=0x4\000\00001\000\000 */
{ 4711113 }, /* unc_m2p_egress_cycles_full.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Counts the number of cycles when the M2PCIe Egress is full.  BL_1. Unit: uncore_m2pcie \000event=0x25,umask=0x20\000\00001\000\000 */
{ 4711313 }, /* unc_m2p_egress_cycles_ne.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AD_0. Unit: uncore_m2pcie \000event=0x23,umask=0x1\000\00001\000\000 */
{ 4711520 }, /* unc_m2p_egress_cycles_ne.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AD_1. Unit: uncore_m2pcie \000event=0x23,umask=0x8\000\00001\000\000 */
{ 4711727 }, /* unc_m2p_egress_cycles_ne.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AK_0. Unit: uncore_m2pcie \000event=0x23,umask=0x2\000\00001\000\000 */
{ 4711934 }, /* unc_m2p_egress_cycles_ne.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  AK_1. Unit: uncore_m2pcie \000event=0x23,umask=0x10\000\00001\000\000 */
{ 4712142 }, /* unc_m2p_egress_cycles_ne.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  BL_0. Unit: uncore_m2pcie \000event=0x23,umask=0x4\000\00001\000\000 */
{ 4712349 }, /* unc_m2p_egress_cycles_ne.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Counts the number of cycles when the M2PCIe Egress is not empty.  BL_1. Unit: uncore_m2pcie \000event=0x23,umask=0x20\000\00001\000\000 */
{ 4712557 }, /* unc_m2p_egress_inserts.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AD_0. Unit: uncore_m2pcie \000event=0x24,umask=0x1\000\00001\000\000 */
{ 4712771 }, /* unc_m2p_egress_inserts.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AD_1. Unit: uncore_m2pcie \000event=0x24,umask=0x10\000\00001\000\000 */
{ 4712986 }, /* unc_m2p_egress_inserts.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_0. Unit: uncore_m2pcie \000event=0x24,umask=0x2\000\00001\000\000 */
{ 4713200 }, /* unc_m2p_egress_inserts.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_1. Unit: uncore_m2pcie \000event=0x24,umask=0x20\000\00001\000\000 */
{ 4713415 }, /* unc_m2p_egress_inserts.ak_crd_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_CRD_0. Unit: uncore_m2pcie \000event=0x24,umask=0x8\000\00001\000\000 */
{ 4713637 }, /* unc_m2p_egress_inserts.ak_crd_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. AK_CRD_1. Unit: uncore_m2pcie \000event=0x24,umask=0x80\000\00001\000\000 */
{ 4713860 }, /* unc_m2p_egress_inserts.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. BL_0. Unit: uncore_m2pcie \000event=0x24,umask=0x4\000\00001\000\000 */
{ 4714074 }, /* unc_m2p_egress_inserts.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Counts the number of number of messages inserted into the  the M2PCIe Egress queue. BL_1. Unit: uncore_m2pcie \000event=0x24,umask=0x40\000\00001\000\000 */
{ 4741254 }, /* unc_m2p_ingress_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.ALL. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000\000 */
{ 4741458 }, /* unc_m2p_ingress_cycles_ne.cbo_idi\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_IDI. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000\000 */
{ 4741669 }, /* unc_m2p_ingress_cycles_ne.cbo_ncb\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_NCB. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000\000 */
{ 4741880 }, /* unc_m2p_ingress_cycles_ne.cbo_ncs\000uncore_m2pcie\000uncore io\000Ingress Queue Cycles Not Empty. Counts the number of cycles when the M2PCIe Ingress is not empty.CBO_NCS. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000\000 */
{ 3549029 }, /* unc_e_e_clockticks\000uncore_edc_eclk\000uncore memory\000ECLK count. Unit: uncore_edc_eclk \000event=0\000\00001\000\000 */
{ 3549126 }, /* unc_e_edc_access.hit_clean\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that hit in MCDRAM cache and the data in MCDRAM is clean with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x1\000\00001\000\000 */
{ 3549423 }, /* unc_e_edc_access.hit_dirty\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that hit in MCDRAM cache and the data in MCDRAM is dirty with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x2\000\00001\000\000 */
{ 3549720 }, /* unc_e_edc_access.miss_clean\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that miss in MCDRAM cache and the data evicted from the MCDRAM is clean with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x4\000\00001\000\000 */
{ 3550033 }, /* unc_e_edc_access.miss_dirty\000uncore_edc_uclk\000uncore memory\000Counts the number of read requests and streaming stores that miss in MCDRAM cache and the data evicted from the MCDRAM is dirty with respect to DDR. This event is only valid in cache and hybrid memory mode. Unit: uncore_edc_uclk \000event=0x2,umask=0x8\000\00001\000\000 */
{ 3550346 }, /* unc_e_edc_access.miss_invalid\000uncore_edc_uclk\000uncore memory\000Number of EDC Hits or Misses. Miss I. Unit: uncore_edc_uclk \000event=0x2,umask=0x10\000\00001\000\000 */
{ 3550493 }, /* unc_e_rpq_inserts\000uncore_edc_eclk\000uncore memory\000Counts the number of read requests received by the MCDRAM controller. This event is valid in all three memory modes: flat, cache and hybrid. In cache and hybrid memory mode, this event counts all read requests as well as streaming stores that hit or miss in the MCDRAM cache. Unit: uncore_edc_eclk \000event=0x1,umask=0x1\000\00001\000\000 */
{ 3550865 }, /* unc_e_u_clockticks\000uncore_edc_uclk\000uncore memory\000UCLK count. Unit: uncore_edc_uclk \000event=0\000\00001\000\000 */
{ 3550962 }, /* unc_e_wpq_inserts\000uncore_edc_eclk\000uncore memory\000Counts the number of write requests received by the MCDRAM controller. This event is valid in all three memory modes: flat, cache and hybrid. In cache and hybrid memory mode, this event counts all streaming stores, writebacks and, read requests that miss in MCDRAM cache. Unit: uncore_edc_eclk \000event=0x2,umask=0x1\000\00001\000\000 */
{ 5380577 }, /* unc_m_cas_count.all\000uncore_imc_dclk\000uncore memory\000CAS All. Unit: uncore_imc_dclk \000event=0x3,umask=0x3\000\00001\000\000 */
{ 5382672 }, /* unc_m_cas_count.rd\000uncore_imc_dclk\000uncore memory\000CAS Reads. Unit: uncore_imc_dclk \000event=0x3,umask=0x1\000\00001\000\000 */
{ 5390134 }, /* unc_m_cas_count.wr\000uncore_imc_dclk\000uncore memory\000CAS Writes. Unit: uncore_imc_dclk \000event=0x3,umask=0x2\000\00001\000\000 */
{ 5395885 }, /* unc_m_d_clockticks\000uncore_imc_dclk\000uncore memory\000DCLK count. Unit: uncore_imc_dclk \000event=0\000\00001\000\000 */
{ 5533559 }, /* unc_m_u_clockticks\000uncore_imc_uclk\000uncore memory\000UCLK count. Unit: uncore_imc_uclk \000event=0\000\00001\000\000 */
{ 1394355 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Counts the number of load micro-ops retired that cause a DTLB miss  Supports address when precise (Precise event)\000event=0x4,period=200003,umask=0x8\000\00000\000\000 */
{ 2472097 }, /* page_walks.cycles\000\000virtual memory\000Counts the total number of core cycles for all the page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x3\000\00000\000This event counts every cycle when a data (D) page walk or instruction (I) page walk is in progress\000 */
{ 2473075 }, /* page_walks.d_side_cycles\000\000virtual memory\000Counts the total number of core cycles for all the D-side page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x1\000\00000\000\000 */
{ 2473939 }, /* page_walks.d_side_walks\000\000virtual memory\000Counts the total D-side page walks that are completed or started. The page walks started in the speculative path will also be counted\000event=0x5,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 2474558 }, /* page_walks.i_side_cycles\000\000virtual memory\000Counts the total number of core cycles for all the I-side page walks. The cycles for page walks started in speculative path will also be included\000event=0x5,period=200003,umask=0x2\000\00000\000This event counts every cycle when an I-side (walks due to an instruction fetch) page walk is in progress\000 */
{ 2475546 }, /* page_walks.i_side_walks\000\000virtual memory\000Counts the total I-side page walks that are completed\000event=0x5,edge=1,period=100003,umask=0x2\000\00000\000\000 */
{ 2476354 }, /* page_walks.walks\000\000virtual memory\000Counts the total page walks that are completed (I-side and D-side)\000event=0x5,edge=1,period=100003,umask=0x3\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__meteorlake[] = {
{ 1100364 }, /* l1d.hwpf_miss\000cpu_core\000cache\000L1D.HWPF_MISS. Unit: cpu_core \000event=0x51,period=1000003,umask=0x20\000\00000\000\000 */
{ 1102201 }, /* l1d.replacement\000cpu_core\000cache\000Counts the number of cache lines replaced in L1 data cache. Unit: cpu_core \000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1106236 }, /* l1d_pend_miss.fb_full\000cpu_core\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106980 }, /* l1d_pend_miss.fb_full_periods\000cpu_core\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Unit: cpu_core \000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1111558 }, /* l1d_pend_miss.pending\000cpu_core\000cache\000Number of L1D misses that are outstanding. Unit: cpu_core \000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1113017 }, /* l1d_pend_miss.pending_cycles\000cpu_core\000cache\000Cycles with L1D load Misses outstanding. Unit: cpu_core \000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1129403 }, /* l2_lines_in.all\000cpu_core\000cache\000L2 cache lines filling L2. Unit: cpu_core \000event=0x25,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1134744 }, /* l2_lines_out.non_silent\000cpu_core\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill. Unit: cpu_core \000event=0x26,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000 */
{ 1137326 }, /* l2_lines_out.silent\000cpu_core\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill. Unit: cpu_core \000event=0x26,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1150207 }, /* l2_request.all\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_RQSTS.REFERENCES]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.REFERENCES]\000 */
{ 1150849 }, /* l2_request.hit\000cpu_core\000cache\000All requests that hit L2 cache. [This event is alias to L2_RQSTS.HIT]. Unit: cpu_core \000event=0x24,period=200003,umask=0xdf\000\00000\000Counts all requests that hit L2 cache. [This event is alias to L2_RQSTS.HIT]\000 */
{ 1151715 }, /* l2_request.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache [This event is alias to L2_RQSTS.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000 */
{ 1157584 }, /* l2_rqsts.all_code_rd\000cpu_core\000cache\000L2 code requests. Unit: cpu_core \000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1159075 }, /* l2_rqsts.all_demand_data_rd\000cpu_core\000cache\000Demand Data Read access L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1159993 }, /* l2_rqsts.all_demand_miss\000cpu_core\000cache\000Demand requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1160737 }, /* l2_rqsts.all_demand_references\000cpu_core\000cache\000Demand requests to L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000 */
{ 1160987 }, /* l2_rqsts.all_hwpf\000cpu_core\000cache\000L2_RQSTS.ALL_HWPF. Unit: cpu_core \000event=0x24,period=200003,umask=0xf0\000\00000\000\000 */
{ 1162694 }, /* l2_rqsts.all_rfo\000cpu_core\000cache\000RFO requests to L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163734 }, /* l2_rqsts.code_rd_hit\000cpu_core\000cache\000L2 cache hits when fetching instructions, code reads. Unit: cpu_core \000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164662 }, /* l2_rqsts.code_rd_miss\000cpu_core\000cache\000L2 cache misses when fetching instructions. Unit: cpu_core \000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165833 }, /* l2_rqsts.demand_data_rd_hit\000cpu_core\000cache\000Demand Data Read requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1167001 }, /* l2_rqsts.demand_data_rd_miss\000cpu_core\000cache\000Demand Data Read miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1167291 }, /* l2_rqsts.hit\000cpu_core\000cache\000All requests that hit L2 cache. [This event is alias to L2_REQUEST.HIT]. Unit: cpu_core \000event=0x24,period=200003,umask=0xdf\000\00000\000Counts all requests that hit L2 cache. [This event is alias to L2_REQUEST.HIT]\000 */
{ 1167613 }, /* l2_rqsts.hwpf_miss\000cpu_core\000cache\000L2_RQSTS.HWPF_MISS. Unit: cpu_core \000event=0x24,period=200003,umask=0x30\000\00000\000\000 */
{ 1170211 }, /* l2_rqsts.miss\000cpu_core\000cache\000Read requests with true-miss in L2 cache [This event is alias to L2_REQUEST.MISS]. Unit: cpu_core \000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000 */
{ 1173430 }, /* l2_rqsts.references\000cpu_core\000cache\000All accesses to L2 cache [This event is alias to L2_REQUEST.ALL]. Unit: cpu_core \000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.ALL]\000 */
{ 1174463 }, /* l2_rqsts.rfo_hit\000cpu_core\000cache\000RFO requests that hit L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1175400 }, /* l2_rqsts.rfo_miss\000cpu_core\000cache\000RFO requests that miss L2 cache. Unit: cpu_core \000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1182876 }, /* l2_trans.l2_wb\000cpu_core\000cache\000L2 writebacks that access L2 cache. Unit: cpu_core \000event=0x23,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1249567 }, /* longest_lat_cache.miss\000cpu_atom\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1250061 }, /* longest_lat_cache.miss\000cpu_core\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1253409 }, /* longest_lat_cache.reference\000cpu_atom\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis. Unit: cpu_atom \000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1253906 }, /* longest_lat_cache.reference\000cpu_core\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3). Unit: cpu_core \000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1308382 }, /* mem_bound_stalls_ifetch.all\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an instruction cache or TLB miss. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x6f\000\00000\000\000 */
{ 1308586 }, /* mem_bound_stalls_ifetch.l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x1\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000 */
{ 1308948 }, /* mem_bound_stalls_ifetch.llc_hit\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an icache or itlb miss which hit in the LLC. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x6\000\00000\000\000 */
{ 1309166 }, /* mem_bound_stalls_ifetch.llc_miss\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an icache or itlb miss which missed all the caches. Unit: cpu_atom \000event=0x35,period=1000003,umask=0x68\000\00000\000\000 */
{ 1309393 }, /* mem_bound_stalls_load.all\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to an L1 demand load miss. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x6f\000\00000\000\000 */
{ 1309585 }, /* mem_bound_stalls_load.l2_hit\000cpu_atom\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x1\000\00000\000Counts the number of cycles a core is stalled due to a demand load which hit in the L2 cache\000 */
{ 1309874 }, /* mem_bound_stalls_load.llc_hit\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to a demand load miss which hit in the LLC. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x6\000\00000\000\000 */
{ 1310086 }, /* mem_bound_stalls_load.llc_miss\000cpu_atom\000cache\000Counts the number of unhalted cycles when the core is stalled due to a demand load miss which missed all the local caches. Unit: cpu_atom \000event=0x34,period=1000003,umask=0x68\000\00000\000\000 */
{ 1310969 }, /* mem_inst_retired.all_loads\000cpu_core\000cache\000Retired load instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311792 }, /* mem_inst_retired.all_stores\000cpu_core\000cache\000Retired store instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312558 }, /* mem_inst_retired.any\000cpu_core\000cache\000All retired memory instructions  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315828 }, /* mem_inst_retired.lock_loads\000cpu_core\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316426 }, /* mem_inst_retired.split_loads\000cpu_core\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1317068 }, /* mem_inst_retired.split_stores\000cpu_core\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1317403 }, /* mem_inst_retired.stlb_hit_loads\000cpu_core\000cache\000Retired load instructions that hit the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x9\000\00000\000Number of retired load instructions with a clean hit in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1317725 }, /* mem_inst_retired.stlb_hit_stores\000cpu_core\000cache\000Retired store instructions that hit the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0xa\000\00000\000Number of retired store instructions that hit in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318345 }, /* mem_inst_retired.stlb_miss_loads\000cpu_core\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318979 }, /* mem_inst_retired.stlb_miss_stores\000cpu_core\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1319707 }, /* mem_load_completed.l1_miss_any\000cpu_core\000cache\000Completed demand load uops that miss the L1 d-cache. Unit: cpu_core \000event=0x43,period=1000003,umask=0xfd\000\00000\000Number of completed demand load requests that missed the L1 data cache including shadow misses (FB hits, merge to an ongoing L1D miss)\000 */
{ 1320891 }, /* mem_load_l3_hit_retired.xsnp_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1322213 }, /* mem_load_l3_hit_retired.xsnp_hit\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1323495 }, /* mem_load_l3_hit_retired.xsnp_hitm\000cpu_core\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1325784 }, /* mem_load_l3_hit_retired.xsnp_no_fwd\000cpu_core\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326886 }, /* mem_load_l3_hit_retired.xsnp_none\000cpu_core\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327606 }, /* mem_load_l3_miss_retired.local_dram\000cpu_core\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1331574 }, /* mem_load_misc_retired.uc\000cpu_core\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1333255 }, /* mem_load_retired.fb_hit\000cpu_core\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1334781 }, /* mem_load_retired.l1_hit\000cpu_core\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335820 }, /* mem_load_retired.l1_miss\000cpu_core\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1337106 }, /* mem_load_retired.l2_hit\000cpu_core\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1338102 }, /* mem_load_retired.l2_miss\000cpu_core\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1339025 }, /* mem_load_retired.l3_hit\000cpu_core\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339968 }, /* mem_load_retired.l3_miss\000cpu_core\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event). Unit: cpu_core \000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1352548 }, /* mem_load_uops_misc_retired.local_dram\000cpu_atom\000cache\000Counts the number of load ops retired that miss the L3 cache and hit in DRAM (Precise event). Unit: cpu_atom \000event=0xd4,period=1000003,umask=0x2\000\00000\000\000 */
{ 1357976 }, /* mem_load_uops_retired.l1_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit the L1 data cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x1\000\00000\000\000 */
{ 1359489 }, /* mem_load_uops_retired.l1_miss\000cpu_atom\000cache\000Counts the number of load ops retired that miss in the L1 data cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x40\000\00000\000\000 */
{ 1361023 }, /* mem_load_uops_retired.l2_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit in the L2 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x2\000\00000\000\000 */
{ 1362749 }, /* mem_load_uops_retired.l2_miss\000cpu_atom\000cache\000Counts the number of load ops retired that miss in the L2 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x80\000\00000\000\000 */
{ 1363937 }, /* mem_load_uops_retired.l3_hit\000cpu_atom\000cache\000Counts the number of load ops retired that hit in the L3 cache (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x1c\000\00000\000\000 */
{ 1367022 }, /* mem_load_uops_retired.wcb_hit\000cpu_atom\000cache\000Counts the number of loads that hit in a write combining buffer (WCB), excluding the first load that caused the WCB to allocate (Precise event). Unit: cpu_atom \000event=0xd1,period=200003,umask=0x20\000\00000\000\000 */
{ 1367461 }, /* mem_scheduler_block.all\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked for any of the following reasons:  load buffer, store buffer or RSV full. Unit: cpu_atom \000event=0x4,period=20003,umask=0x7\000\00000\000\000 */
{ 1367836 }, /* mem_scheduler_block.ld_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a load buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x2\000\00000\000\000 */
{ 1368167 }, /* mem_scheduler_block.rsv\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to an RSV full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x4\000\00000\000\000 */
{ 1368499 }, /* mem_scheduler_block.st_buf\000cpu_atom\000cache\000Counts the number of cycles that uops are blocked due to a store buffer full condition. Unit: cpu_atom \000event=0x4,period=20003,umask=0x1\000\00000\000\000 */
{ 1387792 }, /* mem_uop_retired.any\000cpu_core\000cache\000Retired memory uops for any access. Unit: cpu_core \000event=0xe5,period=1000003,umask=0x3\000\00000\000Number of retired micro-operations (uops) for load or store memory accesses\000 */
{ 1390777 }, /* mem_uops_retired.all_loads\000cpu_atom\000cache\000Counts the number of load ops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x81\000\00000\000\000 */
{ 1393239 }, /* mem_uops_retired.all_stores\000cpu_atom\000cache\000Counts the number of store ops retired  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x82\000\00000\000\000 */
{ 1397774 }, /* mem_uops_retired.load_latency_gt_1024\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x400\000\00000\000\000 */
{ 1399079 }, /* mem_uops_retired.load_latency_gt_128\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000\000 */
{ 1401087 }, /* mem_uops_retired.load_latency_gt_16\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000\000 */
{ 1402413 }, /* mem_uops_retired.load_latency_gt_2048\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x800\000\00000\000\000 */
{ 1403720 }, /* mem_uops_retired.load_latency_gt_256\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000\000 */
{ 1405730 }, /* mem_uops_retired.load_latency_gt_32\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000\000 */
{ 1407728 }, /* mem_uops_retired.load_latency_gt_4\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000\000 */
{ 1409732 }, /* mem_uops_retired.load_latency_gt_512\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000\000 */
{ 1411742 }, /* mem_uops_retired.load_latency_gt_64\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000\000 */
{ 1413740 }, /* mem_uops_retired.load_latency_gt_8\000cpu_atom\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000\000 */
{ 1416413 }, /* mem_uops_retired.lock_loads\000cpu_atom\000cache\000Counts the number of load uops retired that performed one or more locks  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x21\000\00000\000\000 */
{ 1417133 }, /* mem_uops_retired.split\000cpu_atom\000cache\000Counts the number of memory uops retired that were splits  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x43\000\00000\000\000 */
{ 1419232 }, /* mem_uops_retired.split_loads\000cpu_atom\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x41\000\00000\000\000 */
{ 1421343 }, /* mem_uops_retired.split_stores\000cpu_atom\000cache\000Counts the number of retired split store uops  Supports address when precise (Precise event). Unit: cpu_atom \000event=0xd0,period=200003,umask=0x42\000\00000\000\000 */
{ 1424343 }, /* mem_uops_retired.store_latency\000cpu_atom\000cache\000Counts the number of  stores uops retired same as MEM_UOPS_RETIRED.ALL_STORES  Supports address when precise (Must be precise). Unit: cpu_atom \000event=0xd0,period=1000003,umask=0x6\000\00000\000\000 */
{ 1548348 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches which forwarded the unmodified data to the requesting core. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1550049 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand data reads that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1578520 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000cpu_core\000cache\000Counts demand read for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit in another cores caches, data forwarding is required as the data is modified. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1746694 }, /* offcore_requests.all_requests\000cpu_core\000cache\000Any memory transaction that reached the SQ. Unit: cpu_core \000event=0x21,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000 */
{ 1747690 }, /* offcore_requests.data_rd\000cpu_core\000cache\000Demand and prefetch data reads. Unit: cpu_core \000event=0x21,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1750835 }, /* offcore_requests.demand_data_rd\000cpu_core\000cache\000Demand Data Read requests sent to uncore. Unit: cpu_core \000event=0x21,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751916 }, /* offcore_requests.demand_rfo\000cpu_core\000cache\000Demand RFO requests including regular RFOs, locks, ItoM. Unit: cpu_core \000event=0x21,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 2531144 }, /* sq_misc.bus_lock\000cpu_core\000cache\000Counts bus locks, accounts for cache line split locks and UC locks. Unit: cpu_core \000event=0x2c,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2568120 }, /* topdown_fe_bound.icache\000cpu_atom\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to an icache miss. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x20\000\00000\000\000 */
{ 469573 }, /* arith.fpdiv_active\000cpu_core\000floating point\000This event counts the cycles the floating point divider is busy. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 472431 }, /* assists.fp\000cpu_core\000floating point\000Counts all microcode FP assists. Unit: cpu_core \000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 472999 }, /* assists.sse_avx_mix\000cpu_core\000floating point\000ASSISTS.SSE_AVX_MIX. Unit: cpu_core \000event=0xc1,period=1000003,umask=0x10\000\00000\000\000 */
{ 853719 }, /* fp_arith_dispatched.port_0\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_0. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x1\000\00000\000\000 */
{ 853966 }, /* fp_arith_dispatched.port_1\000cpu_core\000floating point\000FP_ARITH_DISPATCHED.PORT_1. Unit: cpu_core \000event=0xb3,period=2000003,umask=0x2\000\00000\000\000 */
{ 857340 }, /* fp_arith_inst_retired.128b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 861484 }, /* fp_arith_inst_retired.128b_packed_single\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 865542 }, /* fp_arith_inst_retired.256b_packed_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 869687 }, /* fp_arith_inst_retired.256b_packed_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 874503 }, /* fp_arith_inst_retired.4_flops\000cpu_core\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 889239 }, /* fp_arith_inst_retired.scalar\000cpu_core\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element. Unit: cpu_core \000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 892915 }, /* fp_arith_inst_retired.scalar_double\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 896651 }, /* fp_arith_inst_retired.scalar_single\000cpu_core\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. Unit: cpu_core \000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898730 }, /* fp_arith_inst_retired.vector\000cpu_core\000floating point\000Number of any Vector retired FP arithmetic instructions. Unit: cpu_core \000event=0xc7,period=1000003,umask=0xfc\000\00000\000Number of any Vector retired FP arithmetic instructions.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 1292564 }, /* machine_clears.fp_assist\000cpu_atom\000floating point\000Counts the number of floating point operations retired that required microcode assist. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000 */
{ 6229475 }, /* uops_retired.fpdiv\000cpu_atom\000floating point\000Counts the number of floating point divide uops retired (x87 and sse, including x87 sqrt) (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x8\000\00000\000\000 */
{ 477876 }, /* baclears.any\000cpu_atom\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches. Unit: cpu_atom \000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 478394 }, /* baclears.any\000cpu_core\000frontend\000Clears due to Unknown Branches. Unit: cpu_core \000event=0x60,period=100003,umask=0x1\000\00000\000Number of times the front-end is resteered when it finds a branch instruction in a fetch line. This is called Unknown Branch which occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 776818 }, /* decode.lcp\000cpu_core\000frontend\000Stalls caused by changing prefix length of the instruction. Unit: cpu_core \000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk\000 */
{ 777470 }, /* decode.ms_busy\000cpu_core\000frontend\000Cycles the Microcode Sequencer is busy. Unit: cpu_core \000event=0x87,period=500009,umask=0x2\000\00000\000\000 */
{ 785927 }, /* dsb2mite_switches.penalty_cycles\000cpu_core\000frontend\000DSB-to-MITE switch true penalty cycles. Unit: cpu_core \000event=0x61,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940499 }, /* frontend_retired.any_ant\000cpu_core\000frontend\000Retired ANT branches (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x9\000\00000\000Always Not Taken (ANT) conditional retired branches (no BTB entry and not mispredicted) (Precise event)\000 */
{ 942386 }, /* frontend_retired.itlb_miss\000cpu_atom\000frontend\000Counts the number of instructions retired that were tagged because empty issue slots were seen before the uop due to ITLB miss (Precise event). Unit: cpu_atom \000event=0xc6,period=1000003,umask=0x10\000\00000\000\000 */
{ 942910 }, /* frontend_retired.itlb_miss\000cpu_core\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943914 }, /* frontend_retired.l1i_miss\000cpu_core\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 950992 }, /* frontend_retired.latency_ge_1\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 946651 }, /* frontend_retired.latency_ge_128\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 949001 }, /* frontend_retired.latency_ge_16\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 955028 }, /* frontend_retired.latency_ge_2\000cpu_core\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 953111 }, /* frontend_retired.latency_ge_256\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 956504 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 959513 }, /* frontend_retired.latency_ge_32\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 961697 }, /* frontend_retired.latency_ge_4\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 963912 }, /* frontend_retired.latency_ge_512\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 966122 }, /* frontend_retired.latency_ge_64\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 968457 }, /* frontend_retired.latency_ge_8\000cpu_core\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 968936 }, /* frontend_retired.misp_ant\000cpu_core\000frontend\000Mispredicted Retired ANT branches (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x2,frontend=0x9\000\00000\000ANT retired branches that got just mispredicted (Precise event)\000 */
{ 969450 }, /* frontend_retired.ms_flows\000cpu_core\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x8\000\00000\000\000 */
{ 970476 }, /* frontend_retired.unknown_branch\000cpu_core\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event). Unit: cpu_core \000event=0xc6,period=100007,umask=0x3,frontend=0x17\000\00000\000\000 */
{ 984515 }, /* icache.accesses\000cpu_atom\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump. Unit: cpu_atom \000event=0x80,period=200003,umask=0x3\000\00000\000\000 */
{ 991687 }, /* icache.misses\000cpu_atom\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump and the instruction cache registers bytes are not present. -. Unit: cpu_atom \000event=0x80,period=200003,umask=0x2\000\00000\000\000 */
{ 994759 }, /* icache_data.stall_periods\000cpu_core\000frontend\000ICACHE_DATA.STALL_PERIODS. Unit: cpu_core \000event=0x80,cmask=1,edge=1,period=500009,umask=0x4\000\00000\000\000 */
{ 995558 }, /* icache_data.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. Unit: cpu_core \000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The decode pipeline works at a 32 Byte granularity\000 */
{ 995858 }, /* icache_tag.hit\000cpu_core\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Unit: cpu_core \000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 996965 }, /* icache_tag.stalls\000cpu_core\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. Unit: cpu_core \000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss\000 */
{ 1004194 }, /* idq.dsb_cycles_any\000cpu_core\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1005608 }, /* idq.dsb_cycles_ok\000cpu_core\000frontend\000Cycles DSB is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1007298 }, /* idq.dsb_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010489 }, /* idq.mite_cycles_any\000cpu_core\000frontend\000Cycles MITE is delivering any Uop. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1011572 }, /* idq.mite_cycles_ok\000cpu_core\000frontend\000Cycles MITE is delivering optimal number of Uops. Unit: cpu_core \000event=0x79,cmask=6,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1013334 }, /* idq.mite_uops\000cpu_core\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path. Unit: cpu_core \000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1017370 }, /* idq.ms_cycles_any\000cpu_core\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy. Unit: cpu_core \000event=0x79,cmask=1,period=2000003,umask=0x20\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024670 }, /* idq.ms_switches\000cpu_core\000frontend\000Number of switches from DSB or MITE to the MS. Unit: cpu_core \000event=0x79,cmask=1,edge=1,period=100003,umask=0x20\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1027492 }, /* idq.ms_uops\000cpu_core\000frontend\000Uops initiated by MITE or Decode Stream Buffer (DSB) and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy. Unit: cpu_core \000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE or Decode Stream Buffer (DSB) and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1028916 }, /* idq_bubbles.core\000cpu_core\000frontend\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations. Unit: cpu_core \000event=0x9c,period=1000003,umask=0x1\000\00000\000This event counts a subset of the Topdown Slots event that were no operation was delivered to the back-end pipeline due to instruction fetch limitations when the back-end could have accepted more operations. Common examples include instruction cache misses or x86 instruction decode limitations.\nThe count may be distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Frontend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 1033407 }, /* idq_uops_not_delivered.core\000cpu_core\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036114 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000cpu_core\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled. Unit: cpu_core \000event=0x9c,cmask=6,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1037389 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000cpu_core\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled. Unit: cpu_core \000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 752041 }, /* cycle_activity.cycles_l3_miss\000cpu_core\000memory\000Cycles while L3 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=2,period=1000003,umask=0x2\000\00000\000\000 */
{ 757847 }, /* cycle_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 1204325 }, /* ld_head.any_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to any number of reasons, including an L1 miss, WCB full, pagewalk, store address block or store data block, on a load that retires. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xff\000\00000\000\000 */
{ 1205362 }, /* ld_head.l1_bound_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer is stalled due to a core bound stall including a store address match, a DTLB miss or a page walk that detains the load from retiring. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xf4\000\00000\000\000 */
{ 1205865 }, /* ld_head.l1_miss_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DL1 miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x81\000\00000\000\000 */
{ 1206460 }, /* ld_head.other_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xc0\000\00000\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to other block cases such as pipeline conflicts, fences, etc\000 */
{ 1207054 }, /* ld_head.pgwalk_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a pagewalk. Unit: cpu_atom \000event=0x5,period=1000003,umask=0xa0\000\00000\000\000 */
{ 1207483 }, /* ld_head.st_addr_at_ret\000cpu_atom\000memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a store address match. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x84\000\00000\000\000 */
{ 1370486 }, /* mem_trans_retired.load_latency_gt_128\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372426 }, /* mem_trans_retired.load_latency_gt_16\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374372 }, /* mem_trans_retired.load_latency_gt_256\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376317 }, /* mem_trans_retired.load_latency_gt_32\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378247 }, /* mem_trans_retired.load_latency_gt_4\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380190 }, /* mem_trans_retired.load_latency_gt_512\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382125 }, /* mem_trans_retired.load_latency_gt_64\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1384048 }, /* mem_trans_retired.load_latency_gt_8\000cpu_core\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1385440 }, /* mem_trans_retired.store_sample\000cpu_core\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise). Unit: cpu_core \000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000 */
{ 1425824 }, /* memory_activity.stalls_l1d_miss\000cpu_core\000memory\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0x47,cmask=3,period=1000003,umask=0x3\000\00000\000\000 */
{ 1426316 }, /* memory_activity.stalls_l2_miss\000cpu_core\000memory\000Execution stalls while L2 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=5,period=1000003,umask=0x5\000\00000\000Execution stalls while L2 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1426969 }, /* memory_activity.stalls_l3_miss\000cpu_core\000memory\000Execution stalls while L3 cache miss demand cacheable load request is outstanding. Unit: cpu_core \000event=0x47,cmask=9,period=1000003,umask=0x9\000\00000\000Execution stalls while L3 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1428228 }, /* misalign_mem_ref.load_page_split\000cpu_atom\000memory\000Counts misaligned loads that are 4K page splits (Precise event). Unit: cpu_atom \000event=0x13,period=200003,umask=0x2\000\00000\000\000 */
{ 1430203 }, /* misalign_mem_ref.store_page_split\000cpu_atom\000memory\000Counts misaligned stores that are 4K page splits (Precise event). Unit: cpu_atom \000event=0x13,period=200003,umask=0x4\000\00000\000\000 */
{ 1752737 }, /* offcore_requests.l3_miss_demand_data_rd\000cpu_core\000memory\000Counts demand data read requests that miss the L3 cache. Unit: cpu_core \000event=0x21,period=100003,umask=0x10\000\00000\000\000 */
{ 1738893 }, /* ocr.streaming_wr.any_response\000cpu_core\000other\000Counts streaming stores that have any type of response. Unit: cpu_core \000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2508798 }, /* rs.empty\000cpu_core\000other\000Cycles when Reservation Station (RS) is empty for the thread. Unit: cpu_core \000event=0xa5,period=1000003,umask=0x7\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into starvation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2509501 }, /* rs.empty_count\000cpu_core\000other\000Counts end of periods where the Reservation Station (RS) was empty. Unit: cpu_core \000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2521456 }, /* serialization.c01_ms_scb\000cpu_atom\000other\000Counts the number of issue slots in a UMWAIT or TPAUSE instruction where no uop issues due to the instruction putting the CPU into the C0.1 activity state. For Tremont, UMWAIT and TPAUSE will only put the CPU into C0.1 activity state (not C0.2 activity state). Unit: cpu_atom \000event=0x75,period=200003,umask=0x4\000\00000\000\000 */
{ 6243662 }, /* xq.full_cycles\000cpu_core\000other\000Cycles the uncore cannot take further requests. Unit: cpu_core \000event=0x2d,cmask=1,period=1000003,umask=0x1\000\00000\000number of cycles when the thread is active and the uncore cannot take any further requests (for example prefetches, loads or stores initiated by the Core that miss the L2 cache)\000 */
{ 467764 }, /* arith.div_active\000cpu_core\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 470852 }, /* arith.idiv_active\000cpu_core\000pipeline\000This event counts the cycles the integer divider is busy. Unit: cpu_core \000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00000\000\000 */
{ 471982 }, /* assists.any\000cpu_core\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware. Unit: cpu_core \000event=0xc1,period=100003,umask=0x1b\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware. Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 498699 }, /* br_inst_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 499133 }, /* br_inst_retired.all_branches\000cpu_core\000pipeline\000All branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 503904 }, /* br_inst_retired.cond\000cpu_core\000pipeline\000Conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504526 }, /* br_inst_retired.cond_ntaken\000cpu_core\000pipeline\000Not taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 505336 }, /* br_inst_retired.cond_taken\000cpu_core\000pipeline\000Taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 509150 }, /* br_inst_retired.far_branch\000cpu_atom\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 509393 }, /* br_inst_retired.far_branch\000cpu_core\000pipeline\000Far branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511781 }, /* br_inst_retired.indirect\000cpu_core\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 516104 }, /* br_inst_retired.near_call\000cpu_atom\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 516281 }, /* br_inst_retired.near_call\000cpu_core\000pipeline\000Direct and indirect near call instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 518729 }, /* br_inst_retired.near_return\000cpu_core\000pipeline\000Return instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 520003 }, /* br_inst_retired.near_taken\000cpu_core\000pipeline\000Taken branch instructions retired (Precise event). Unit: cpu_core \000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 539295 }, /* br_misp_retired.all_branches\000cpu_atom\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event). Unit: cpu_atom \000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 540131 }, /* br_misp_retired.all_branches\000cpu_core\000pipeline\000All mispredicted branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 540679 }, /* br_misp_retired.all_branches_cost\000cpu_core\000pipeline\000All mispredicted branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x44\000\00000\000\000 */
{ 542973 }, /* br_misp_retired.cond\000cpu_atom\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 543179 }, /* br_misp_retired.cond\000cpu_core\000pipeline\000Mispredicted conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 543420 }, /* br_misp_retired.cond_cost\000cpu_core\000pipeline\000Mispredicted conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x51\000\00000\000\000 */
{ 544359 }, /* br_misp_retired.cond_ntaken\000cpu_core\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 544680 }, /* br_misp_retired.cond_ntaken_cost\000cpu_core\000pipeline\000Mispredicted non-taken conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x50\000\00000\000\000 */
{ 545945 }, /* br_misp_retired.cond_taken\000cpu_core\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 546215 }, /* br_misp_retired.cond_taken_cost\000cpu_core\000pipeline\000Mispredicted taken conditional branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x41\000\00000\000\000 */
{ 549816 }, /* br_misp_retired.indirect\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 550036 }, /* br_misp_retired.indirect\000cpu_core\000pipeline\000Miss-predicted near indirect branch instructions retired (excluding returns) (Precise event). Unit: cpu_core \000event=0xc5,period=100003,umask=0x80\000\00000\000Counts miss-predicted near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 551327 }, /* br_misp_retired.indirect_call\000cpu_atom\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 551530 }, /* br_misp_retired.indirect_call\000cpu_core\000pipeline\000Mispredicted indirect CALL retired (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 551814 }, /* br_misp_retired.indirect_call_cost\000cpu_core\000pipeline\000Mispredicted indirect CALL retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x42\000\00000\000\000 */
{ 552153 }, /* br_misp_retired.indirect_cost\000cpu_core\000pipeline\000Mispredicted near indirect branch instructions retired (excluding returns). This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=100003,umask=0xc0\000\00000\000\000 */
{ 556494 }, /* br_misp_retired.near_taken\000cpu_core\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 556787 }, /* br_misp_retired.near_taken_cost\000cpu_core\000pipeline\000Mispredicted taken near branch instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=400009,umask=0x60\000\00000\000\000 */
{ 561107 }, /* br_misp_retired.ret_cost\000cpu_core\000pipeline\000Mispredicted ret instructions retired. This precise event may be used to get the misprediction cost via the Retire_Latency field of PEBS. It fires on the instruction that immediately follows the mispredicted branch (Precise event). Unit: cpu_core \000event=0xc5,period=100007,umask=0x48\000\00000\000\000 */
{ 562583 }, /* br_misp_retired.return\000cpu_atom\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event). Unit: cpu_atom \000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 614579 }, /* cpu_clk_unhalted.core\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000 */
{ 616044 }, /* cpu_clk_unhalted.core_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.THREAD_P]. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000 */
{ 617223 }, /* cpu_clk_unhalted.distributed\000cpu_core\000pipeline\000Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 618529 }, /* cpu_clk_unhalted.one_thread_active\000cpu_core\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted. Unit: cpu_core \000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 621589 }, /* cpu_clk_unhalted.ref_distributed\000cpu_core\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 632637 }, /* cpu_clk_unhalted.ref_tsc\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles. Unit: cpu_atom \000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 632803 }, /* cpu_clk_unhalted.ref_tsc\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 636170 }, /* cpu_clk_unhalted.ref_tsc_p\000cpu_atom\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. Unit: cpu_atom \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 636697 }, /* cpu_clk_unhalted.ref_tsc_p\000cpu_core\000pipeline\000Reference cycles when the core is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 645171 }, /* cpu_clk_unhalted.thread\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000 */
{ 645324 }, /* cpu_clk_unhalted.thread\000cpu_core\000pipeline\000Core cycles when the thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 648257 }, /* cpu_clk_unhalted.thread_p\000cpu_atom\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.CORE_P]. Unit: cpu_atom \000event=0x3c,period=2000003\000\00000\000\000 */
{ 648920 }, /* cpu_clk_unhalted.thread_p\000cpu_core\000pipeline\000Thread cycles when thread is not in halt state. Unit: cpu_core \000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 749020 }, /* cycle_activity.cycles_l1d_miss\000cpu_core\000pipeline\000Cycles while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750584 }, /* cycle_activity.cycles_l2_miss\000cpu_core\000pipeline\000Cycles while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 753325 }, /* cycle_activity.cycles_mem_any\000cpu_core\000pipeline\000Cycles while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754780 }, /* cycle_activity.stalls_l1d_miss\000cpu_core\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 756263 }, /* cycle_activity.stalls_l2_miss\000cpu_core\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding. Unit: cpu_core \000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 759422 }, /* cycle_activity.stalls_total\000cpu_core\000pipeline\000Total execution stalls. Unit: cpu_core \000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 845109 }, /* exe_activity.1_ports_util\000cpu_core\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845686 }, /* exe_activity.2_ports_util\000cpu_core\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846244 }, /* exe_activity.3_ports_util\000cpu_core\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846780 }, /* exe_activity.4_ports_util\000cpu_core\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty. Unit: cpu_core \000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847497 }, /* exe_activity.bound_on_loads\000cpu_core\000pipeline\000Execution stalls while memory subsystem has an outstanding load. Unit: cpu_core \000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000\000 */
{ 848069 }, /* exe_activity.bound_on_stores\000cpu_core\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall. Unit: cpu_core \000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 849014 }, /* exe_activity.exe_bound_0_ports\000cpu_core\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load. Unit: cpu_core \000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000 */
{ 1043723 }, /* inst_decoded.decoders\000cpu_core\000pipeline\000Instruction decoders utilized in a cycle. Unit: cpu_core \000event=0x75,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1051385 }, /* inst_retired.any\000cpu_atom\000pipeline\000Fixed Counter: Counts the number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000\000 */
{ 1051541 }, /* inst_retired.any\000cpu_core\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1056339 }, /* inst_retired.any_p\000cpu_atom\000pipeline\000Counts the number of instructions retired (Precise event). Unit: cpu_atom \000event=0xc0,period=2000003\000\00000\000\000 */
{ 1056980 }, /* inst_retired.any_p\000cpu_core\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event). Unit: cpu_core \000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057610 }, /* inst_retired.macro_fused\000cpu_core\000pipeline\000INST_RETIRED.MACRO_FUSED. Unit: cpu_core \000event=0xc0,period=2000003,umask=0x10\000\00000\000\000 */
{ 1061466 }, /* inst_retired.prec_dist\000cpu_core\000pipeline\000Precise instruction retired with PEBS precise-distribution (Precise event). Unit: cpu_core \000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a precise distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR++) feature to fix bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1065136 }, /* int_misc.all_recovery_cycles\000cpu_core\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall. Unit: cpu_core \000event=0xad,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000 */
{ 1066343 }, /* int_misc.clear_resteer_cycles\000cpu_core\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path. Unit: cpu_core \000event=0xad,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1070519 }, /* int_misc.recovery_cycles\000cpu_core\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread. Unit: cpu_core \000event=0xad,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072553 }, /* int_misc.unknown_branch_cycles\000cpu_core\000pipeline\000INT_MISC.UNKNOWN_BRANCH_CYCLES. Unit: cpu_core \000event=0xad,period=1000003,umask=0x40,frontend=0x7\000\00000\000\000 */
{ 1073132 }, /* int_misc.uop_dropping\000cpu_core\000pipeline\000TMA slots where uops got dropped. Unit: cpu_core \000event=0xad,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1073469 }, /* int_vec_retired.128bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.128BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x13\000\00000\000\000 */
{ 1073690 }, /* int_vec_retired.256bit\000cpu_core\000pipeline\000INT_VEC_RETIRED.256BIT. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xac\000\00000\000\000 */
{ 1074028 }, /* int_vec_retired.add_128\000cpu_core\000pipeline\000integer ADD, SUB, SAD 128-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x3\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 128-bit vector instructions\000 */
{ 1074483 }, /* int_vec_retired.add_256\000cpu_core\000pipeline\000integer ADD, SUB, SAD 256-bit vector instructions. Unit: cpu_core \000event=0xe7,period=1000003,umask=0xc\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 256-bit vector instructions\000 */
{ 1074823 }, /* int_vec_retired.mul_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.MUL_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x80\000\00000\000\000 */
{ 1075050 }, /* int_vec_retired.shuffles\000cpu_core\000pipeline\000INT_VEC_RETIRED.SHUFFLES. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x40\000\00000\000\000 */
{ 1075279 }, /* int_vec_retired.vnni_128\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_128. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x10\000\00000\000\000 */
{ 1075508 }, /* int_vec_retired.vnni_256\000cpu_core\000pipeline\000INT_VEC_RETIRED.VNNI_256. Unit: cpu_core \000event=0xe7,period=1000003,umask=0x20\000\00000\000\000 */
{ 1191280 }, /* ld_blocks.address_alias\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1193358 }, /* ld_blocks.data_unknown\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x1\000\00000\000\000 */
{ 1200432 }, /* ld_blocks.store_forward\000cpu_atom\000pipeline\000Counts the number of retired loads that are blocked because its address partially overlapped with an older store (Precise event). Unit: cpu_atom \000event=0x3,period=1000003,umask=0x2\000\00000\000\000 */
{ 1284548 }, /* lsd.cycles_active\000cpu_core\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder. Unit: cpu_core \000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285612 }, /* lsd.cycles_ok\000cpu_core\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder. Unit: cpu_core \000event=0xa8,cmask=6,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286583 }, /* lsd.uops\000cpu_core\000pipeline\000Number of Uops delivered by the LSD. Unit: cpu_core \000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1289143 }, /* machine_clears.count\000cpu_core\000pipeline\000Number of machine clears (nukes) of any type. Unit: cpu_core \000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1290829 }, /* machine_clears.disambiguation\000cpu_atom\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x8\000\00000\000\000 */
{ 1299052 }, /* machine_clears.page_fault\000cpu_atom\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x20\000\00000\000\000 */
{ 1299627 }, /* machine_clears.slow\000cpu_atom\000pipeline\000Counts the number of machine clears that flush the pipeline and restart the machine with the use of microcode due to SMC, MEMORY_ORDERING, FP_ASSISTS, PAGE_FAULT, DISAMBIGUATION, and FPC_VIRTUAL_TRAP. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x6f\000\00000\000\000 */
{ 1302278 }, /* machine_clears.smc\000cpu_atom\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page. Unit: cpu_atom \000event=0xc3,period=20003,umask=0x1\000\00000\000\000 */
{ 2506369 }, /* resource_stalls.scoreboard\000cpu_core\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations. Unit: cpu_core \000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2545027 }, /* topdown.backend_bound_slots\000cpu_core\000pipeline\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that were not consumed by the back-end pipeline due to lack of back-end resources, as a result of memory subsystem delays, execution units limitations, or other conditions.\nThe count is distributed among unhalted logical processors (hyper-threads) who share the same physical core, in processors that support Intel Hyper-Threading Technology. Software can use this event as the numerator for the Backend Bound metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 2546169 }, /* topdown.bad_spec_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculations. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x4\000\00000\000Number of slots of TMA method that were wasted due to incorrect speculation. It covers all types of control-flow or data-related mis-speculations\000 */
{ 2547731 }, /* topdown.br_mispredict_slots\000cpu_core\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of speculative operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548278 }, /* topdown.memory_bound_slots\000cpu_core\000pipeline\000TOPDOWN.MEMORY_BOUND_SLOTS. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x10\000\00000\000\000 */
{ 2549042 }, /* topdown.slots\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event. Unit: cpu_core \000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2550166 }, /* topdown.slots_p\000cpu_core\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event. Unit: cpu_core \000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 2553240 }, /* topdown_bad_speculation.all\000cpu_atom\000pipeline\000Counts the number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Unit: cpu_atom \000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window, including relevant microcode flows, and while uops are not yet available in the instruction queue (IQ) or until an FE_BOUND event occurs besides OTHER and CISC. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2555255 }, /* topdown_bad_speculation.fastnuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to Fast Nukes such as  Memory Ordering Machine clears and MRN nukes. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2556376 }, /* topdown_bad_speculation.machine_clears\000cpu_atom\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation. Unit: cpu_atom \000event=0x73,period=1000003,umask=0x3\000\00000\000\000 */
{ 2557460 }, /* topdown_bad_speculation.nuke\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to a machine clear (nuke). Unit: cpu_atom \000event=0x73,period=1000003,umask=0x1\000\00000\000\000 */
{ 2557986 }, /* topdown_be_bound.all\000cpu_atom\000pipeline\000Counts the number of retirement slots not consumed due to backend stalls. Unit: cpu_atom \000event=0x74,period=1000003\000\00000\000\000 */
{ 2558787 }, /* topdown_be_bound.alloc_restrictions\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to due to certain allocation restrictions. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x1\000\00000\000\000 */
{ 2560469 }, /* topdown_be_bound.register\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to mrbl stall.  A 'marble' refers to a physical register file entry, also known as the physical destination (PDST). Unit: cpu_atom \000event=0x74,period=1000003,umask=0x20\000\00000\000\000 */
{ 2561768 }, /* topdown_be_bound.serialization\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to iq/jeu scoreboards or ms scb. Unit: cpu_atom \000event=0x74,period=1000003,umask=0x10\000\00000\000\000 */
{ 2562710 }, /* topdown_fe_bound.all\000cpu_atom\000pipeline\000Counts the number of retirement slots not consumed due to front end stalls. Unit: cpu_atom \000event=0x71,period=1000003\000\00000\000\000 */
{ 2564176 }, /* topdown_fe_bound.branch_detect\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BAClear. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x2\000\00000\000\000 */
{ 2565126 }, /* topdown_fe_bound.branch_resteer\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTClear. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x40\000\00000\000\000 */
{ 2565529 }, /* topdown_fe_bound.cisc\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ms. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x1\000\00000\000\000 */
{ 2566122 }, /* topdown_fe_bound.decode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stall. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8\000\00000\000\000 */
{ 2566799 }, /* topdown_fe_bound.frontend_bandwidth\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to frontend bandwidth restrictions due to decode, predecode, cisc, and other limitations. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x8d\000\00000\000\000 */
{ 2567643 }, /* topdown_fe_bound.frontend_latency\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to latency related stalls including BACLEARs, BTCLEARs, ITLB misses, and ICache misses. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x72\000\00000\000\000 */
{ 2569201 }, /* topdown_fe_bound.itlb\000cpu_atom\000pipeline\000This event is deprecated. [This event is alias to TOPDOWN_FE_BOUND.ITLB_MISS]. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00010\000\000 */
{ 2569378 }, /* topdown_fe_bound.itlb_miss\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to itlb miss [This event is alias to TOPDOWN_FE_BOUND.ITLB]. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x10\000\00000\000\000 */
{ 2570267 }, /* topdown_fe_bound.predecode\000cpu_atom\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to predecode wrong. Unit: cpu_atom \000event=0x71,period=1000003,umask=0x4\000\00000\000\000 */
{ 2570976 }, /* topdown_retiring.all\000cpu_atom\000pipeline\000Counts the number of consumed retirement slots.  Similar to UOPS_RETIRED.ALL (Precise event). Unit: cpu_atom \000event=0x72,period=1000003\000\00000\000\000 */
{ 6178613 }, /* uops_decoded.dec0_uops\000cpu_core\000pipeline\000Number of non dec-by-all uops decoded by decoder. Unit: cpu_core \000event=0x76,period=1000003,umask=0x1\000\00000\000This event counts the number of not dec-by-all uops decoded by decoder 0\000 */
{ 6179893 }, /* uops_dispatched.port_0\000cpu_core\000pipeline\000Uops executed on port 0. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x1\000\00000\000Number of uops dispatch to execution  port 0\000 */
{ 6180437 }, /* uops_dispatched.port_1\000cpu_core\000pipeline\000Uops executed on port 1. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x2\000\00000\000Number of uops dispatch to execution  port 1\000 */
{ 6181022 }, /* uops_dispatched.port_2_3_10\000cpu_core\000pipeline\000Uops executed on ports 2, 3 and 10. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x4\000\00000\000Number of uops dispatch to execution ports 2, 3 and 10\000 */
{ 6181624 }, /* uops_dispatched.port_4_9\000cpu_core\000pipeline\000Uops executed on ports 4 and 9. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x10\000\00000\000Number of uops dispatch to execution ports 4 and 9\000 */
{ 6182204 }, /* uops_dispatched.port_5_11\000cpu_core\000pipeline\000Uops executed on ports 5 and 11. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x20\000\00000\000Number of uops dispatch to execution ports 5 and 11\000 */
{ 6182769 }, /* uops_dispatched.port_6\000cpu_core\000pipeline\000Uops executed on port 6. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x40\000\00000\000Number of uops dispatch to execution  port 6\000 */
{ 6183347 }, /* uops_dispatched.port_7_8\000cpu_core\000pipeline\000Uops executed on ports 7 and 8. Unit: cpu_core \000event=0xb2,period=2000003,umask=0x80\000\00000\000Number of uops dispatch to execution  ports 7 and 8\000 */
{ 6193478 }, /* uops_executed.core\000cpu_core\000pipeline\000Number of uops executed on the core. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000 */
{ 6194788 }, /* uops_executed.core_cycles_ge_1\000cpu_core\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195889 }, /* uops_executed.core_cycles_ge_2\000cpu_core\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196992 }, /* uops_executed.core_cycles_ge_3\000cpu_core\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6198095 }, /* uops_executed.core_cycles_ge_4\000cpu_core\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200192 }, /* uops_executed.cycles_ge_1\000cpu_core\000pipeline\000Cycles where at least 1 uop was executed per-thread. Unit: cpu_core \000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201247 }, /* uops_executed.cycles_ge_2\000cpu_core\000pipeline\000Cycles where at least 2 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202318 }, /* uops_executed.cycles_ge_3\000cpu_core\000pipeline\000Cycles where at least 3 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203391 }, /* uops_executed.cycles_ge_4\000cpu_core\000pipeline\000Cycles where at least 4 uops were executed per-thread. Unit: cpu_core \000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6206666 }, /* uops_executed.stalls\000cpu_core\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread. Unit: cpu_core \000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207515 }, /* uops_executed.thread\000cpu_core\000pipeline\000Counts the number of uops to be executed per-thread each cycle. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207824 }, /* uops_executed.x87\000cpu_core\000pipeline\000Counts the number of x87 uops dispatched. Unit: cpu_core \000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6215406 }, /* uops_issued.any\000cpu_atom\000pipeline\000Counts the number of uops issued by the front end every cycle. Unit: cpu_atom \000event=0xe,period=1000003\000\00000\000Counts the number of uops issued by the front end every cycle. When 4-uops are requested and only 2-uops are delivered, the event counts 2.  Uops_issued correlates to the number of ROB entries.  If uop takes 2 ROB slots it counts as 2 uops_issued\000 */
{ 6215795 }, /* uops_issued.any\000cpu_core\000pipeline\000Uops that RAT issues to RS. Unit: cpu_core \000event=0xae,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6216683 }, /* uops_issued.cycles\000cpu_core\000pipeline\000UOPS_ISSUED.CYCLES. Unit: cpu_core \000event=0xae,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6220713 }, /* uops_issued.stalls\000cpu_core\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread. Unit: cpu_core \000event=0xae,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6229986 }, /* uops_retired.heavy\000cpu_core\000pipeline\000Retired uops except the last uop of each instruction. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of retired micro-operations (uops) except the last uop of each instruction. An instruction that is decoded into less than two uops does not contribute to the count\000 */
{ 6230863 }, /* uops_retired.idiv\000cpu_atom\000pipeline\000Counts the number of integer divide uops retired (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x10\000\00000\000\000 */
{ 6232968 }, /* uops_retired.ms\000cpu_atom\000pipeline\000Counts the number of uops that are from the complex flows issued by the micro-sequencer (MS).  This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x1\000\00000\000\000 */
{ 6233266 }, /* uops_retired.ms\000cpu_core\000pipeline\000UOPS_RETIRED.MS. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x4,frontend=0x8\000\00000\000\000 */
{ 6237272 }, /* uops_retired.slots\000cpu_core\000pipeline\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric. Unit: cpu_core \000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts a subset of the Topdown Slots event that are utilized by operations that eventually get retired (committed) by the processor pipeline. Usually, this event positively correlates with higher performance  for example, as measured by the instructions-per-cycle metric.\nSoftware can use this event as the numerator for the Retiring metric (or top-level category) of the Top-down Microarchitecture Analysis method\000 */
{ 6240963 }, /* uops_retired.total_cycles\000cpu_core\000pipeline\000Cycles with less than 10 actually retired uops. Unit: cpu_core \000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 6241562 }, /* uops_retired.x87\000cpu_atom\000pipeline\000Counts the number of x87 uops retired, includes those in ms flows (Precise event). Unit: cpu_atom \000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 3862204 }, /* unc_hac_cbo_tor_allocation.all\000uncore_hac_cbo\000uncore cache\000Number of all entries allocated. Includes also retries. Unit: uncore_hac_cbo \000event=0x35,umask=0x8\000\00001\000\000 */
{ 3862367 }, /* unc_hac_cbo_tor_allocation.drd\000uncore_hac_cbo\000uncore cache\000Asserted on coherent DRD + DRdPref  allocations into the queue. Cacheable only. Unit: uncore_hac_cbo \000event=0x35,umask=0x1\000\00001\000\000 */
{ 3861366 }, /* unc_hac_arb_req_trk_request.drd\000uncore_hac_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. Unit: uncore_hac_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 3861551 }, /* unc_hac_arb_transactions.all\000uncore_hac_arb\000uncore interconnect\000Number of all CMI transactions. Unit: uncore_hac_arb \000event=0x8a,umask=0x1\000\00001\000\000 */
{ 3861695 }, /* unc_hac_arb_transactions.reads\000uncore_hac_arb\000uncore interconnect\000Number of all CMI reads. Unit: uncore_hac_arb \000event=0x8a,umask=0x2\000\00001\000\000 */
{ 3861834 }, /* unc_hac_arb_transactions.writes\000uncore_hac_arb\000uncore interconnect\000Number of all CMI writes not including Mflush. Unit: uncore_hac_arb \000event=0x8a,umask=0x4\000\00001\000\000 */
{ 3861996 }, /* unc_hac_arb_trk_requests.all\000uncore_hac_arb\000uncore interconnect\000Total number of all outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_hac_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 5378499 }, /* unc_m_act_count_rd\000uncore_imc\000uncore memory\000ACT command for a read request sent to DRAM. Unit: uncore_imc \000event=0x24\000\00001\000\000 */
{ 5378622 }, /* unc_m_act_count_total\000uncore_imc\000uncore memory\000ACT command sent to DRAM. Unit: uncore_imc \000event=0x26\000\00001\000\000 */
{ 5378729 }, /* unc_m_act_count_wr\000uncore_imc\000uncore memory\000ACT command for a write request sent to DRAM. Unit: uncore_imc \000event=0x25\000\00001\000\000 */
{ 5393002 }, /* unc_m_cas_count_rd\000uncore_imc\000uncore memory\000Read CAS command sent to DRAM. Unit: uncore_imc \000event=0x22\000\00001\000\000 */
{ 5393111 }, /* unc_m_cas_count_wr\000uncore_imc\000uncore memory\000Write CAS command sent to DRAM. Unit: uncore_imc \000event=0x23\000\00001\000\000 */
{ 5445969 }, /* unc_m_pre_count_idle\000uncore_imc\000uncore memory\000PRE command sent to DRAM due to page table idle timer expiration. Unit: uncore_imc \000event=0x28\000\00001\000\000 */
{ 5446115 }, /* unc_m_pre_count_page_miss\000uncore_imc\000uncore memory\000PRE command sent to DRAM for a read/write request. Unit: uncore_imc \000event=0x27\000\00001\000\000 */
{ 5500822 }, /* unc_m_rd_data\000uncore_imc\000uncore memory\000Number of bytes read from DRAM, in 32B chunks. Counter increments by 1 after receiving 32B chunk data. Unit: uncore_imc \000event=0x3a\000\00001\000\000 */
{ 5533341 }, /* unc_m_total_data\000uncore_imc\000uncore memory\000Total number of read and write byte transfers to/from DRAM, in 32B chunks. Counter increments by 1 after sending or receiving 32B chunk data. Unit: uncore_imc \000event=0x3c\000\00001\000\000 */
{ 5607817 }, /* unc_m_wr_data\000uncore_imc\000uncore memory\000Number of bytes written to DRAM, in 32B chunks. Counter increments by 1 after sending 32B chunk data. Unit: uncore_imc \000event=0x3b\000\00001\000\000 */
{ 5608419 }, /* unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every CAS read command sent from the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000Counts every CAS read command sent from the Memory Controller 0 to DRAM (sum of all channels). Each CAS commands can be for 32B or 64B of data\000 */
{ 5609481 }, /* unc_mc0_total_reqcount_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every read and write request entering the Memory Controller 0. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x10\000\00001\000Counts every read and write request entering the Memory Controller 0 (sum of all channels). All requests are counted as one, whether they are 32B or 64B Read/Write or partial/full line writes. Some write requests to the same address may merge to a single write command to DRAM. Therefore, the total request count may be higher than total DRAM BW\000 */
{ 5610440 }, /* unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every CAS write command sent from the Memory Controller 0 to DRAM (sum of all channels). Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000Counts every CAS write command sent from the Memory Controller 0 to DRAM (sum of all channels).  Each CAS commands can be for 32B or 64B of data\000 */
{ 5611389 }, /* unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every CAS read command sent from the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000Counts every CAS read command sent from the Memory Controller 1 to DRAM (sum of all channels). Each CAS commands can be for 32B or 64B of data\000 */
{ 5612451 }, /* unc_mc1_total_reqcount_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every read and write request entering the Memory Controller 1. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x10\000\00001\000Counts every read and write request entering the Memory Controller 1 (sum of all channels). All requests are counted as one, whether they are 32B or 64B Read/Write or partial/full line writes. Some write requests to the same address may merge to a single write command to DRAM. Therefore, the total request count may be higher than total DRAM BW\000 */
{ 5613410 }, /* unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every CAS write command sent from the Memory Controller 1 to DRAM (sum of all channels). Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000Counts every CAS write command sent from the Memory Controller 1 to DRAM (sum of all channels).  Each CAS commands can be for 32B or 64B of data\000 */
{ 791511 }, /* dtlb_load_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to a demand load that did not start a page walk. Accounts for all page sizes. Will result in a DTLB write from STLB. Unit: cpu_atom \000event=0x8,period=200003,umask=0x20\000\00000\000\000 */
{ 791804 }, /* dtlb_load_misses.stlb_hit\000cpu_core\000virtual memory\000Loads that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x12,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793668 }, /* dtlb_load_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load. Unit: cpu_core \000event=0x12,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 796717 }, /* dtlb_load_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses. Unit: cpu_atom \000event=0x8,period=200003,umask=0xe\000\00000\000\000 */
{ 796895 }, /* dtlb_load_misses.walk_completed\000cpu_core\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 799203 }, /* dtlb_load_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 1G page. Unit: cpu_core \000event=0x12,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802463 }, /* dtlb_load_misses.walk_completed_2m_4m\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 2M or 4M page. Unit: cpu_atom \000event=0x8,period=200003,umask=0x4\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages. Includes page walks that page fault\000 */
{ 802900 }, /* dtlb_load_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page. Unit: cpu_core \000event=0x12,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805730 }, /* dtlb_load_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data load to a 4K page. Unit: cpu_core \000event=0x12,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 808808 }, /* dtlb_load_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding for Loads (demand or SW prefetch) in PMH every cycle. Unit: cpu_atom \000event=0x8,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for Loads (demand or SW prefetch) in PMH every cycle.  A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 809250 }, /* dtlb_load_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle. Unit: cpu_core \000event=0x12,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813551 }, /* dtlb_store_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to stores that did not start a page walk. Accounts for all pages sizes. Will result in a DTLB write from STLB. Unit: cpu_atom \000event=0x49,period=2000003,umask=0x20\000\00000\000\000 */
{ 813841 }, /* dtlb_store_misses.stlb_hit\000cpu_core\000virtual memory\000Stores that miss the DTLB and hit the STLB. Unit: cpu_core \000event=0x13,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815698 }, /* dtlb_store_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. Unit: cpu_core \000event=0x13,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818427 }, /* dtlb_store_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page. Unit: cpu_atom \000event=0x49,period=2000003,umask=0xe\000\00000\000\000 */
{ 819030 }, /* dtlb_store_misses.walk_completed\000cpu_core\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 821337 }, /* dtlb_store_misses.walk_completed_1g\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 1G page. Unit: cpu_core \000event=0x13,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 824814 }, /* dtlb_store_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page. Unit: cpu_core \000event=0x13,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 827875 }, /* dtlb_store_misses.walk_completed_4k\000cpu_core\000virtual memory\000Page walks completed due to a demand data store to a 4K page. Unit: cpu_core \000event=0x13,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 830652 }, /* dtlb_store_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle. Unit: cpu_atom \000event=0x49,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle. A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 831097 }, /* dtlb_store_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle. Unit: cpu_core \000event=0x13,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1080403 }, /* itlb_misses.miss_caused_walk\000cpu_atom\000virtual memory\000Counts the number of page walks initiated by a instruction fetch that missed the first and second level TLBs. Unit: cpu_atom \000event=0x85,period=1000003,umask=0x1\000\00000\000\000 */
{ 1083797 }, /* itlb_misses.stlb_hit\000cpu_atom\000virtual memory\000Counts the number of first level TLB misses but second level hits due to an instruction fetch that did not start a page walk. Account for all pages sizes. Will result in an ITLB write from STLB. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x20\000\00000\000\000 */
{ 1084095 }, /* itlb_misses.stlb_hit\000cpu_core\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB. Unit: cpu_core \000event=0x11,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085949 }, /* itlb_misses.walk_active\000cpu_core\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. Unit: cpu_core \000event=0x11,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1088173 }, /* itlb_misses.walk_completed\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size. Unit: cpu_atom \000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1088594 }, /* itlb_misses.walk_completed\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes). Unit: cpu_core \000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1092575 }, /* itlb_misses.walk_completed_2m_4m\000cpu_atom\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 2M or 4M page. Unit: cpu_atom \000event=0x85,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000 */
{ 1093006 }, /* itlb_misses.walk_completed_2m_4m\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M). Unit: cpu_core \000event=0x11,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1095351 }, /* itlb_misses.walk_completed_4k\000cpu_core\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K). Unit: cpu_core \000event=0x11,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1098450 }, /* itlb_misses.walk_pending\000cpu_atom\000virtual memory\000Counts the number of page walks outstanding for iside in PMH every cycle. Unit: cpu_atom \000event=0x85,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for iside in PMH every cycle.  A PMH page walk is outstanding from page walk start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals.  Walks could be counted by edge detecting on this event, but would count restarted suspended walks\000 */
{ 1098940 }, /* itlb_misses.walk_pending\000cpu_core\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle. Unit: cpu_core \000event=0x11,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 1204848 }, /* ld_head.dtlb_miss_at_ret\000cpu_atom\000virtual memory\000Counts the number of cycles that the head (oldest load) of the load buffer and retirement are both stalled due to a DTLB miss. Unit: cpu_atom \000event=0x5,period=1000003,umask=0x90\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__nehalemep[] = {
{ 571421 }, /* cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000 */
{ 571509 }, /* cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000 */
{ 1100466 }, /* l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000 */
{ 1100562 }, /* l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000 */
{ 1100662 }, /* l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000 */
{ 1100773 }, /* l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000 */
{ 1102488 }, /* l1d_all_ref.any\000\000cache\000All references to the L1 data cache\000event=0x43,period=2000000,umask=0x1\000\00000\000\000 */
{ 1102588 }, /* l1d_all_ref.cacheable\000\000cache\000L1 data cacheable reads and writes\000event=0x43,period=2000000,umask=0x2\000\00000\000\000 */
{ 1103564 }, /* l1d_cache_ld.e_state\000\000cache\000L1 data cache read in E state\000event=0x40,period=2000000,umask=0x4\000\00000\000\000 */
{ 1103663 }, /* l1d_cache_ld.i_state\000\000cache\000L1 data cache read in I state (misses)\000event=0x40,period=2000000,umask=0x1\000\00000\000\000 */
{ 1103771 }, /* l1d_cache_ld.m_state\000\000cache\000L1 data cache read in M state\000event=0x40,period=2000000,umask=0x8\000\00000\000\000 */
{ 1103870 }, /* l1d_cache_ld.mesi\000\000cache\000L1 data cache reads\000event=0x40,period=2000000,umask=0xf\000\00000\000\000 */
{ 1103956 }, /* l1d_cache_ld.s_state\000\000cache\000L1 data cache read in S state\000event=0x40,period=2000000,umask=0x2\000\00000\000\000 */
{ 1104055 }, /* l1d_cache_lock.e_state\000\000cache\000L1 data cache load locks in E state\000event=0x42,period=2000000,umask=0x4\000\00000\000\000 */
{ 1104162 }, /* l1d_cache_lock.hit\000\000cache\000L1 data cache load lock hits\000event=0x42,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104258 }, /* l1d_cache_lock.m_state\000\000cache\000L1 data cache load locks in M state\000event=0x42,period=2000000,umask=0x8\000\00000\000\000 */
{ 1104365 }, /* l1d_cache_lock.s_state\000\000cache\000L1 data cache load locks in S state\000event=0x42,period=2000000,umask=0x2\000\00000\000\000 */
{ 1104472 }, /* l1d_cache_lock_fb_hit\000\000cache\000L1D load lock accepted in fill buffer\000event=0x53,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104580 }, /* l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104706 }, /* l1d_cache_st.e_state\000\000cache\000L1 data cache stores in E state\000event=0x41,period=2000000,umask=0x4\000\00000\000\000 */
{ 1104807 }, /* l1d_cache_st.m_state\000\000cache\000L1 data cache stores in M state\000event=0x41,period=2000000,umask=0x8\000\00000\000\000 */
{ 1104908 }, /* l1d_cache_st.s_state\000\000cache\000L1 data cache stores in S state\000event=0x41,period=2000000,umask=0x2\000\00000\000\000 */
{ 1113958 }, /* l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000 */
{ 1114052 }, /* l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000 */
{ 1114152 }, /* l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000 */
{ 1114262 }, /* l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000 */
{ 1114358 }, /* l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000 */
{ 1114463 }, /* l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000 */
{ 1114559 }, /* l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000 */
{ 1114645 }, /* l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000 */
{ 1121826 }, /* l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000 */
{ 1121913 }, /* l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000 */
{ 1122021 }, /* l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000 */
{ 1122138 }, /* l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000 */
{ 1122246 }, /* l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000 */
{ 1122343 }, /* l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000 */
{ 1122451 }, /* l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1122560 }, /* l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000 */
{ 1122682 }, /* l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000 */
{ 1122791 }, /* l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000 */
{ 1122890 }, /* l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000 */
{ 1129601 }, /* l2_lines_in.any\000\000cache\000L2 lines alloacated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000 */
{ 1130213 }, /* l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000 */
{ 1131206 }, /* l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000 */
{ 1131570 }, /* l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000 */
{ 1132175 }, /* l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000 */
{ 1132697 }, /* l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000 */
{ 1135641 }, /* l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000 */
{ 1135755 }, /* l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000 */
{ 1167724 }, /* l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000 */
{ 1167818 }, /* l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000 */
{ 1167915 }, /* l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000 */
{ 1168737 }, /* l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000 */
{ 1168813 }, /* l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000 */
{ 1168892 }, /* l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000 */
{ 1168966 }, /* l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000 */
{ 1172018 }, /* l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1172105 }, /* l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000 */
{ 1172195 }, /* l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000 */
{ 1172443 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000 */
{ 1173756 }, /* l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000 */
{ 1174646 }, /* l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000 */
{ 1175586 }, /* l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000 */
{ 1183427 }, /* l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000 */
{ 1183515 }, /* l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000 */
{ 1183605 }, /* l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000 */
{ 1183709 }, /* l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000 */
{ 1183813 }, /* l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000 */
{ 1183902 }, /* l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000 */
{ 1183999 }, /* l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000 */
{ 1184086 }, /* l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000 */
{ 1184856 }, /* l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000 */
{ 1184957 }, /* l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000 */
{ 1185066 }, /* l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000 */
{ 1185176 }, /* l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000 */
{ 1185277 }, /* l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000 */
{ 1185368 }, /* l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000 */
{ 1185469 }, /* l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000 */
{ 1185577 }, /* l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000 */
{ 1185686 }, /* l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000 */
{ 1185786 }, /* l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000 */
{ 1185876 }, /* l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000 */
{ 1249469 }, /* longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000 */
{ 1253301 }, /* longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1312836 }, /* mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000 */
{ 1312997 }, /* mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000 */
{ 1313161 }, /* mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000 */
{ 1313488 }, /* mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000 */
{ 1313323 }, /* mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000 */
{ 1313649 }, /* mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000 */
{ 1313812 }, /* mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000 */
{ 1314139 }, /* mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000 */
{ 1313974 }, /* mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000 */
{ 1314463 }, /* mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000 */
{ 1314299 }, /* mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000 */
{ 1314621 }, /* mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000 */
{ 1314783 }, /* mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000 */
{ 1315107 }, /* mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000 */
{ 1314943 }, /* mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000 */
{ 1315265 }, /* mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1319310 }, /* mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000 */
{ 1333824 }, /* mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000 */
{ 1336151 }, /* mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1336860 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000 */
{ 1340299 }, /* mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000 */
{ 1340426 }, /* mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000 */
{ 1341515 }, /* mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000 */
{ 1386170 }, /* mem_uncore_retired.local_dram\000\000cache\000Load instructions retired with a data source of local DRAM or locally homed remote hitm (Precise Event)\000event=0xf,period=10000,umask=0x20\000\00000\000\000 */
{ 1386689 }, /* mem_uncore_retired.other_core_l2_hitm\000\000cache\000Load instructions retired that HIT modified data in sibling core (Precise Event)\000event=0xf,period=40000,umask=0x2\000\00000\000\000 */
{ 1386853 }, /* mem_uncore_retired.remote_cache_local_home_hit\000\000cache\000Load instructions retired remote cache HIT data source (Precise Event)\000event=0xf,period=20000,umask=0x8\000\00000\000\000 */
{ 1387016 }, /* mem_uncore_retired.remote_dram\000\000cache\000Load instructions retired remote DRAM and remote home-remote cache HITM (Precise Event)\000event=0xf,period=10000,umask=0x10\000\00000\000\000 */
{ 1387493 }, /* mem_uncore_retired.uncacheable\000\000cache\000Load instructions retired IO (Precise Event)\000event=0xf,period=4000,umask=0x80\000\00000\000\000 */
{ 1752159 }, /* offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000 */
{ 1780856 }, /* offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000 */
{ 1921008 }, /* offcore_response.any_data.any_cache_dram\000\000cache\000Offcore data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F11\000\00000\000\000 */
{ 1921952 }, /* offcore_response.any_data.any_location\000\000cache\000All offcore data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF11\000\00000\000\000 */
{ 1922237 }, /* offcore_response.any_data.io_csr_mmio\000\000cache\000Offcore data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000 */
{ 1922551 }, /* offcore_response.any_data.llc_hit_no_other_core\000\000cache\000Offcore data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000 */
{ 1922910 }, /* offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000Offcore data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000 */
{ 1923266 }, /* offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000Offcore data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000 */
{ 1923627 }, /* offcore_response.any_data.local_cache\000\000cache\000Offcore data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000 */
{ 1924087 }, /* offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4711\000\00000\000\000 */
{ 1924913 }, /* offcore_response.any_data.remote_cache\000\000cache\000Offcore data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1811\000\00000\000\000 */
{ 1925065 }, /* offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3811\000\00000\000\000 */
{ 1925409 }, /* offcore_response.any_data.remote_cache_hit\000\000cache\000Offcore data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000 */
{ 1925564 }, /* offcore_response.any_data.remote_cache_hitm\000\000cache\000Offcore data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000 */
{ 1936832 }, /* offcore_response.any_ifetch.any_cache_dram\000\000cache\000Offcore code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F44\000\00000\000\000 */
{ 1937779 }, /* offcore_response.any_ifetch.any_location\000\000cache\000All offcore code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF44\000\00000\000\000 */
{ 1938065 }, /* offcore_response.any_ifetch.io_csr_mmio\000\000cache\000Offcore code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000 */
{ 1938380 }, /* offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000 */
{ 1938740 }, /* offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000 */
{ 1939097 }, /* offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000 */
{ 1939459 }, /* offcore_response.any_ifetch.local_cache\000\000cache\000Offcore code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000 */
{ 1939922 }, /* offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4744\000\00000\000\000 */
{ 1940752 }, /* offcore_response.any_ifetch.remote_cache\000\000cache\000Offcore code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1844\000\00000\000\000 */
{ 1940906 }, /* offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3844\000\00000\000\000 */
{ 1941254 }, /* offcore_response.any_ifetch.remote_cache_hit\000\000cache\000Offcore code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000 */
{ 1941411 }, /* offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000Offcore code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000 */
{ 1960213 }, /* offcore_response.any_request.any_cache_dram\000\000cache\000Offcore requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FFF\000\00000\000\000 */
{ 1961163 }, /* offcore_response.any_request.any_location\000\000cache\000All offcore requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFFFF\000\00000\000\000 */
{ 1963126 }, /* offcore_response.any_request.io_csr_mmio\000\000cache\000Offcore requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80FF\000\00000\000\000 */
{ 1969757 }, /* offcore_response.any_request.llc_hit_no_other_core\000\000cache\000Offcore requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1FF\000\00000\000\000 */
{ 1970118 }, /* offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000Offcore requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2FF\000\00000\000\000 */
{ 1970476 }, /* offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000Offcore requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4FF\000\00000\000\000 */
{ 1971122 }, /* offcore_response.any_request.local_cache\000\000cache\000Offcore requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FF\000\00000\000\000 */
{ 1971585 }, /* offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x47FF\000\00000\000\000 */
{ 1973747 }, /* offcore_response.any_request.remote_cache\000\000cache\000Offcore requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x18FF\000\00000\000\000 */
{ 1973900 }, /* offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x38FF\000\00000\000\000 */
{ 1974246 }, /* offcore_response.any_request.remote_cache_hit\000\000cache\000Offcore requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10FF\000\00000\000\000 */
{ 1974402 }, /* offcore_response.any_request.remote_cache_hitm\000\000cache\000Offcore requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8FF\000\00000\000\000 */
{ 1975383 }, /* offcore_response.any_rfo.any_cache_dram\000\000cache\000Offcore RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F22\000\00000\000\000 */
{ 1976309 }, /* offcore_response.any_rfo.any_location\000\000cache\000All offcore RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF22\000\00000\000\000 */
{ 1977996 }, /* offcore_response.any_rfo.io_csr_mmio\000\000cache\000Offcore RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000 */
{ 1985711 }, /* offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000Offcore RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000 */
{ 1986064 }, /* offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000Offcore RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000 */
{ 1986414 }, /* offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000 */
{ 1986769 }, /* offcore_response.any_rfo.local_cache\000\000cache\000Offcore RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000 */
{ 1987224 }, /* offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4722\000\00000\000\000 */
{ 1989498 }, /* offcore_response.any_rfo.remote_cache\000\000cache\000Offcore RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1822\000\00000\000\000 */
{ 1989651 }, /* offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3822\000\00000\000\000 */
{ 1989997 }, /* offcore_response.any_rfo.remote_cache_hit\000\000cache\000Offcore RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000 */
{ 1990153 }, /* offcore_response.any_rfo.remote_cache_hitm\000\000cache\000Offcore RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000 */
{ 1998153 }, /* offcore_response.corewb.any_cache_dram\000\000cache\000Offcore writebacks to any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F08\000\00000\000\000 */
{ 1999047 }, /* offcore_response.corewb.any_location\000\000cache\000All offcore writebacks\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF08\000\00000\000\000 */
{ 2000260 }, /* offcore_response.corewb.io_csr_mmio\000\000cache\000Offcore writebacks to the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000 */
{ 2007876 }, /* offcore_response.corewb.llc_hit_no_other_core\000\000cache\000Offcore writebacks to the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000 */
{ 2008383 }, /* offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000Offcore writebacks to the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000 */
{ 2008724 }, /* offcore_response.corewb.local_cache\000\000cache\000Offcore writebacks to the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000 */
{ 2009152 }, /* offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4708\000\00000\000\000 */
{ 2010460 }, /* offcore_response.corewb.remote_cache\000\000cache\000Offcore writebacks to a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1808\000\00000\000\000 */
{ 2010600 }, /* offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3808\000\00000\000\000 */
{ 2010920 }, /* offcore_response.corewb.remote_cache_hit\000\000cache\000Offcore writebacks that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000 */
{ 2011073 }, /* offcore_response.corewb.remote_cache_hitm\000\000cache\000Offcore writebacks that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000 */
{ 2013167 }, /* offcore_response.data_ifetch.any_cache_dram\000\000cache\000Offcore code or data read requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F77\000\00000\000\000 */
{ 2014171 }, /* offcore_response.data_ifetch.any_location\000\000cache\000All offcore code or data read requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF77\000\00000\000\000 */
{ 2014476 }, /* offcore_response.data_ifetch.io_csr_mmio\000\000cache\000Offcore code or data read requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000 */
{ 2014810 }, /* offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code or data read requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000 */
{ 2015189 }, /* offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code or data read requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000 */
{ 2015565 }, /* offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code or data read requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000 */
{ 2015946 }, /* offcore_response.data_ifetch.local_cache\000\000cache\000Offcore code or data read requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000 */
{ 2016445 }, /* offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4777\000\00000\000\000 */
{ 2017330 }, /* offcore_response.data_ifetch.remote_cache\000\000cache\000Offcore code or data read requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1877\000\00000\000\000 */
{ 2017501 }, /* offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3877\000\00000\000\000 */
{ 2017883 }, /* offcore_response.data_ifetch.remote_cache_hit\000\000cache\000Offcore code or data read requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000 */
{ 2018057 }, /* offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000Offcore code or data read requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000 */
{ 2019092 }, /* offcore_response.data_in.any_cache_dram\000\000cache\000Offcore request = all data, response = any cache_dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F33\000\00000\000\000 */
{ 2020036 }, /* offcore_response.data_in.any_location\000\000cache\000Offcore request = all data, response = any location\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF33\000\00000\000\000 */
{ 2020500 }, /* offcore_response.data_in.io_csr_mmio\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000 */
{ 2020828 }, /* offcore_response.data_in.llc_hit_no_other_core\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000 */
{ 2021201 }, /* offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000 */
{ 2021571 }, /* offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000 */
{ 2021946 }, /* offcore_response.data_in.local_cache\000\000cache\000Offcore request = all data, response = local cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000 */
{ 2022413 }, /* offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4733\000\00000\000\000 */
{ 2023271 }, /* offcore_response.data_in.remote_cache\000\000cache\000Offcore request = all data, response = remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1833\000\00000\000\000 */
{ 2023427 }, /* offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3833\000\00000\000\000 */
{ 2023765 }, /* offcore_response.data_in.remote_cache_hit\000\000cache\000Offcore data reads, RFOs, and prefetches that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000 */
{ 2023941 }, /* offcore_response.data_in.remote_cache_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000 */
{ 2072246 }, /* offcore_response.demand_data.any_cache_dram\000\000cache\000Offcore demand data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F03\000\00000\000\000 */
{ 2073232 }, /* offcore_response.demand_data.any_location\000\000cache\000All offcore demand data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF03\000\00000\000\000 */
{ 2073531 }, /* offcore_response.demand_data.io_csr_mmio\000\000cache\000Offcore demand data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000 */
{ 2073859 }, /* offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000Offcore demand data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000 */
{ 2074232 }, /* offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000Offcore demand data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000 */
{ 2074602 }, /* offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000Offcore demand data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000 */
{ 2074977 }, /* offcore_response.demand_data.local_cache\000\000cache\000Offcore demand data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000 */
{ 2075464 }, /* offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4703\000\00000\000\000 */
{ 2076331 }, /* offcore_response.demand_data.remote_cache\000\000cache\000Offcore demand data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1803\000\00000\000\000 */
{ 2076496 }, /* offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3803\000\00000\000\000 */
{ 2076866 }, /* offcore_response.demand_data.remote_cache_hit\000\000cache\000Offcore demand data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000 */
{ 2077034 }, /* offcore_response.demand_data.remote_cache_hitm\000\000cache\000Offcore demand data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000 */
{ 2078065 }, /* offcore_response.demand_data_rd.any_cache_dram\000\000cache\000Offcore demand data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F01\000\00000\000\000 */
{ 2079069 }, /* offcore_response.demand_data_rd.any_location\000\000cache\000All offcore demand data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF01\000\00000\000\000 */
{ 2081657 }, /* offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000Offcore demand data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000 */
{ 2118081 }, /* offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000Offcore demand data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000 */
{ 2118460 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore demand data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000 */
{ 2118836 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore demand data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000 */
{ 2121036 }, /* offcore_response.demand_data_rd.local_cache\000\000cache\000Offcore demand data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000 */
{ 2121529 }, /* offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4701\000\00000\000\000 */
{ 2125385 }, /* offcore_response.demand_data_rd.remote_cache\000\000cache\000Offcore demand data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1801\000\00000\000\000 */
{ 2125550 }, /* offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3801\000\00000\000\000 */
{ 2125920 }, /* offcore_response.demand_data_rd.remote_cache_hit\000\000cache\000Offcore demand data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000 */
{ 2126088 }, /* offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000Offcore demand data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000 */
{ 2130096 }, /* offcore_response.demand_ifetch.any_cache_dram\000\000cache\000Offcore demand code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F04\000\00000\000\000 */
{ 2131091 }, /* offcore_response.demand_ifetch.any_location\000\000cache\000All offcore demand code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF04\000\00000\000\000 */
{ 2131393 }, /* offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000Offcore demand code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000 */
{ 2131724 }, /* offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000Offcore demand code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000 */
{ 2132100 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore demand code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000 */
{ 2132473 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore demand code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000 */
{ 2133046 }, /* offcore_response.demand_ifetch.local_cache\000\000cache\000Offcore demand code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000 */
{ 2133535 }, /* offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4704\000\00000\000\000 */
{ 2134407 }, /* offcore_response.demand_ifetch.remote_cache\000\000cache\000Offcore demand code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1804\000\00000\000\000 */
{ 2134571 }, /* offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3804\000\00000\000\000 */
{ 2134939 }, /* offcore_response.demand_ifetch.remote_cache_hit\000\000cache\000Offcore demand code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000 */
{ 2135106 }, /* offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000Offcore demand code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000 */
{ 2136134 }, /* offcore_response.demand_rfo.any_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F02\000\00000\000\000 */
{ 2137108 }, /* offcore_response.demand_rfo.any_location\000\000cache\000All offcore demand RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF02\000\00000\000\000 */
{ 2139468 }, /* offcore_response.demand_rfo.io_csr_mmio\000\000cache\000Offcore demand RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000 */
{ 2177181 }, /* offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000Offcore demand RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000 */
{ 2177550 }, /* offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000Offcore demand RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000 */
{ 2177916 }, /* offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore demand RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000 */
{ 2179346 }, /* offcore_response.demand_rfo.local_cache\000\000cache\000Offcore demand RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000 */
{ 2179827 }, /* offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4702\000\00000\000\000 */
{ 2183680 }, /* offcore_response.demand_rfo.remote_cache\000\000cache\000Offcore demand RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1802\000\00000\000\000 */
{ 2183843 }, /* offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3802\000\00000\000\000 */
{ 2184209 }, /* offcore_response.demand_rfo.remote_cache_hit\000\000cache\000Offcore demand RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000 */
{ 2184375 }, /* offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000Offcore demand RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000 */
{ 2194549 }, /* offcore_response.other.any_cache_dram\000\000cache\000Offcore other requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F80\000\00000\000\000 */
{ 2195463 }, /* offcore_response.other.any_location\000\000cache\000All offcore other requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF80\000\00000\000\000 */
{ 2196350 }, /* offcore_response.other.io_csr_mmio\000\000cache\000Offcore other requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000 */
{ 2218865 }, /* offcore_response.other.llc_hit_no_other_core\000\000cache\000Offcore other requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000 */
{ 2219214 }, /* offcore_response.other.llc_hit_other_core_hit\000\000cache\000Offcore other requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000 */
{ 2219560 }, /* offcore_response.other.llc_hit_other_core_hitm\000\000cache\000Offcore other requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000 */
{ 2219911 }, /* offcore_response.other.local_cache\000\000cache\000Offcore other requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000 */
{ 2220362 }, /* offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4780\000\00000\000\000 */
{ 2222084 }, /* offcore_response.other.remote_cache\000\000cache\000Offcore other requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1880\000\00000\000\000 */
{ 2222237 }, /* offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3880\000\00000\000\000 */
{ 2222583 }, /* offcore_response.other.remote_cache_hit\000\000cache\000Offcore other requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000 */
{ 2222739 }, /* offcore_response.other.remote_cache_hitm\000\000cache\000Offcore other requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000 */
{ 2241116 }, /* offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F30\000\00000\000\000 */
{ 2242550 }, /* offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF30\000\00000\000\000 */
{ 2242978 }, /* offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8030\000\00000\000\000 */
{ 2243466 }, /* offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x130\000\00000\000\000 */
{ 2244025 }, /* offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x230\000\00000\000\000 */
{ 2244576 }, /* offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x430\000\00000\000\000 */
{ 2245135 }, /* offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x730\000\00000\000\000 */
{ 2245764 }, /* offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4730\000\00000\000\000 */
{ 2246609 }, /* offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1830\000\00000\000\000 */
{ 2246935 }, /* offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3830\000\00000\000\000 */
{ 2247301 }, /* offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1030\000\00000\000\000 */
{ 2247633 }, /* offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x830\000\00000\000\000 */
{ 2248801 }, /* offcore_response.pf_data_rd.any_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F10\000\00000\000\000 */
{ 2249775 }, /* offcore_response.pf_data_rd.any_location\000\000cache\000All offcore prefetch data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF10\000\00000\000\000 */
{ 2250070 }, /* offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000Offcore prefetch data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000 */
{ 2250394 }, /* offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000Offcore prefetch data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000 */
{ 2250763 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000 */
{ 2251129 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000 */
{ 2251689 }, /* offcore_response.pf_data_rd.local_cache\000\000cache\000Offcore prefetch data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000 */
{ 2252170 }, /* offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4710\000\00000\000\000 */
{ 2253027 }, /* offcore_response.pf_data_rd.remote_cache\000\000cache\000Offcore prefetch data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1810\000\00000\000\000 */
{ 2253190 }, /* offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3810\000\00000\000\000 */
{ 2253556 }, /* offcore_response.pf_data_rd.remote_cache_hit\000\000cache\000Offcore prefetch data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000 */
{ 2253722 }, /* offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000Offcore prefetch data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000 */
{ 2254730 }, /* offcore_response.pf_ifetch.any_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F40\000\00000\000\000 */
{ 2255686 }, /* offcore_response.pf_ifetch.any_location\000\000cache\000All offcore prefetch code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF40\000\00000\000\000 */
{ 2256127 }, /* offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000Offcore prefetch code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000 */
{ 2256445 }, /* offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000 */
{ 2256808 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000 */
{ 2257168 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000 */
{ 2257717 }, /* offcore_response.pf_ifetch.local_cache\000\000cache\000Offcore prefetch code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000 */
{ 2258191 }, /* offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4740\000\00000\000\000 */
{ 2259035 }, /* offcore_response.pf_ifetch.remote_cache\000\000cache\000Offcore prefetch code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1840\000\00000\000\000 */
{ 2259197 }, /* offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3840\000\00000\000\000 */
{ 2259561 }, /* offcore_response.pf_ifetch.remote_cache_hit\000\000cache\000Offcore prefetch code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000 */
{ 2259726 }, /* offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000Offcore prefetch code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000 */
{ 2430767 }, /* offcore_response.pf_rfo.any_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F20\000\00000\000\000 */
{ 2431720 }, /* offcore_response.pf_rfo.any_location\000\000cache\000All offcore prefetch RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF20\000\00000\000\000 */
{ 2432008 }, /* offcore_response.pf_rfo.io_csr_mmio\000\000cache\000Offcore prefetch RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000 */
{ 2432325 }, /* offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000 */
{ 2432687 }, /* offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000 */
{ 2433046 }, /* offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000 */
{ 2433410 }, /* offcore_response.pf_rfo.local_cache\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000 */
{ 2433882 }, /* offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4720\000\00000\000\000 */
{ 2434723 }, /* offcore_response.pf_rfo.remote_cache\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1820\000\00000\000\000 */
{ 2434884 }, /* offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3820\000\00000\000\000 */
{ 2435246 }, /* offcore_response.pf_rfo.remote_cache_hit\000\000cache\000Offcore prefetch RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000 */
{ 2435410 }, /* offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000Offcore prefetch RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000 */
{ 2440683 }, /* offcore_response.prefetch.any_cache_dram\000\000cache\000Offcore prefetch requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F70\000\00000\000\000 */
{ 2441633 }, /* offcore_response.prefetch.any_location\000\000cache\000All offcore prefetch requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF70\000\00000\000\000 */
{ 2441920 }, /* offcore_response.prefetch.io_csr_mmio\000\000cache\000Offcore prefetch requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000 */
{ 2442236 }, /* offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000 */
{ 2442597 }, /* offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000 */
{ 2442955 }, /* offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000 */
{ 2443318 }, /* offcore_response.prefetch.local_cache\000\000cache\000Offcore prefetch requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000 */
{ 2443787 }, /* offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4770\000\00000\000\000 */
{ 2444624 }, /* offcore_response.prefetch.remote_cache\000\000cache\000Offcore prefetch requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1870\000\00000\000\000 */
{ 2444783 }, /* offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3870\000\00000\000\000 */
{ 2445141 }, /* offcore_response.prefetch.remote_cache_hit\000\000cache\000Offcore prefetch requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000 */
{ 2445303 }, /* offcore_response.prefetch.remote_cache_hitm\000\000cache\000Offcore prefetch requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000 */
{ 2532073 }, /* sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000 */
{ 2536735 }, /* store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000 */
{ 2536845 }, /* store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000 */
{ 901660 }, /* fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000 */
{ 902741 }, /* fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000 */
{ 902880 }, /* fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000 */
{ 905570 }, /* fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 905656 }, /* fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000 */
{ 905760 }, /* fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000 */
{ 905885 }, /* fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000 */
{ 905986 }, /* fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000 */
{ 906093 }, /* fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000 */
{ 907996 }, /* fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000 */
{ 908121 }, /* fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 910502 }, /* fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000 */
{ 910623 }, /* fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000 */
{ 910751 }, /* fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524990 }, /* simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000 */
{ 2525101 }, /* simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000 */
{ 2525227 }, /* simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000 */
{ 2525352 }, /* simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000 */
{ 2525473 }, /* simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000 */
{ 2525593 }, /* simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000 */
{ 2525721 }, /* simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000 */
{ 2525836 }, /* simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000 */
{ 2525945 }, /* simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000 */
{ 2526069 }, /* simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000 */
{ 2526192 }, /* simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000 */
{ 2526318 }, /* simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000 */
{ 2526436 }, /* simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000 */
{ 2526562 }, /* simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000 */
{ 1302909 }, /* macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000 */
{ 1303001 }, /* macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000 */
{ 2571312 }, /* two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000 */
{ 1921326 }, /* offcore_response.any_data.any_dram\000\000memory\000Offcore data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6011\000\00000\000\000 */
{ 1921649 }, /* offcore_response.any_data.any_llc_miss\000\000memory\000Offcore data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF811\000\00000\000\000 */
{ 1924401 }, /* offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000 */
{ 1925886 }, /* offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000 */
{ 1937151 }, /* offcore_response.any_ifetch.any_dram\000\000memory\000Offcore code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6044\000\00000\000\000 */
{ 1937475 }, /* offcore_response.any_ifetch.any_llc_miss\000\000memory\000Offcore code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF844\000\00000\000\000 */
{ 1940240 }, /* offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000 */
{ 1941734 }, /* offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000 */
{ 1960533 }, /* offcore_response.any_request.any_dram\000\000memory\000Offcore requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x60FF\000\00000\000\000 */
{ 1960858 }, /* offcore_response.any_request.any_llc_miss\000\000memory\000Offcore requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF8FF\000\00000\000\000 */
{ 1971901 }, /* offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000 */
{ 1974726 }, /* offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000 */
{ 1975695 }, /* offcore_response.any_rfo.any_dram\000\000memory\000Offcore RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6022\000\00000\000\000 */
{ 1976012 }, /* offcore_response.any_rfo.any_llc_miss\000\000memory\000Offcore RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF822\000\00000\000\000 */
{ 1987540 }, /* offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000 */
{ 1990469 }, /* offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000 */
{ 1998451 }, /* offcore_response.corewb.any_dram\000\000memory\000Offcore writebacks to any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6008\000\00000\000\000 */
{ 1998754 }, /* offcore_response.corewb.any_llc_miss\000\000memory\000Offcore writebacks that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF808\000\00000\000\000 */
{ 2009442 }, /* offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000 */
{ 2011385 }, /* offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000 */
{ 2013505 }, /* offcore_response.data_ifetch.any_dram\000\000memory\000Offcore code or data read requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6077\000\00000\000\000 */
{ 2013848 }, /* offcore_response.data_ifetch.any_llc_miss\000\000memory\000Offcore code or data read requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF877\000\00000\000\000 */
{ 2016797 }, /* offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000 */
{ 2018399 }, /* offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000 */
{ 2019406 }, /* offcore_response.data_in.any_dram\000\000memory\000Offcore request = all data, response = any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6033\000\00000\000\000 */
{ 2019728 }, /* offcore_response.data_in.any_llc_miss\000\000memory\000Offcore request = all data, response = any LLC miss\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF833\000\00000\000\000 */
{ 2022752 }, /* offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000 */
{ 2024277 }, /* offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000 */
{ 2072578 }, /* offcore_response.demand_data.any_dram\000\000memory\000Offcore demand data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6003\000\00000\000\000 */
{ 2072915 }, /* offcore_response.demand_data.any_llc_miss\000\000memory\000Offcore demand data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF803\000\00000\000\000 */
{ 2075804 }, /* offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000 */
{ 2077370 }, /* offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000 */
{ 2078403 }, /* offcore_response.demand_data_rd.any_dram\000\000memory\000Offcore demand data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6001\000\00000\000\000 */
{ 2078746 }, /* offcore_response.demand_data_rd.any_llc_miss\000\000memory\000Offcore demand data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF801\000\00000\000\000 */
{ 2121869 }, /* offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000 */
{ 2126430 }, /* offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000 */
{ 2130431 }, /* offcore_response.demand_ifetch.any_dram\000\000memory\000Offcore demand code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6004\000\00000\000\000 */
{ 2130771 }, /* offcore_response.demand_ifetch.any_llc_miss\000\000memory\000Offcore demand code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF804\000\00000\000\000 */
{ 2133873 }, /* offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000 */
{ 2135445 }, /* offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000 */
{ 2136462 }, /* offcore_response.demand_rfo.any_dram\000\000memory\000Offcore demand RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6002\000\00000\000\000 */
{ 2136795 }, /* offcore_response.demand_rfo.any_llc_miss\000\000memory\000Offcore demand RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF802\000\00000\000\000 */
{ 2180163 }, /* offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000 */
{ 2184707 }, /* offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000 */
{ 2194857 }, /* offcore_response.other.any_dram\000\000memory\000Offcore other requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6080\000\00000\000\000 */
{ 2195170 }, /* offcore_response.other.any_llc_miss\000\000memory\000Offcore other requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF880\000\00000\000\000 */
{ 2223051 }, /* offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000 */
{ 2241606 }, /* offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6030\000\00000\000\000 */
{ 2242087 }, /* offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF830\000\00000\000\000 */
{ 2246100 }, /* offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4030\000\00000\000\000 */
{ 2248126 }, /* offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2030\000\00000\000\000 */
{ 2249129 }, /* offcore_response.pf_data_rd.any_dram\000\000memory\000Offcore prefetch data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6010\000\00000\000\000 */
{ 2249462 }, /* offcore_response.pf_data_rd.any_llc_miss\000\000memory\000Offcore prefetch data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF810\000\00000\000\000 */
{ 2252506 }, /* offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000 */
{ 2254054 }, /* offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000 */
{ 2255052 }, /* offcore_response.pf_ifetch.any_dram\000\000memory\000Offcore prefetch code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6040\000\00000\000\000 */
{ 2255379 }, /* offcore_response.pf_ifetch.any_llc_miss\000\000memory\000Offcore prefetch code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF840\000\00000\000\000 */
{ 2258525 }, /* offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000 */
{ 2260052 }, /* offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000 */
{ 2431088 }, /* offcore_response.pf_rfo.any_dram\000\000memory\000Offcore prefetch RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6020\000\00000\000\000 */
{ 2431414 }, /* offcore_response.pf_rfo.any_llc_miss\000\000memory\000Offcore prefetch RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF820\000\00000\000\000 */
{ 2434214 }, /* offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000 */
{ 2435735 }, /* offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000 */
{ 2441003 }, /* offcore_response.prefetch.any_dram\000\000memory\000Offcore prefetch requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6070\000\00000\000\000 */
{ 2441328 }, /* offcore_response.prefetch.any_llc_miss\000\000memory\000Offcore prefetch requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF870\000\00000\000\000 */
{ 2444115 }, /* offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000 */
{ 2445627 }, /* offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000 */
{ 835049 }, /* es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000 */
{ 1075635 }, /* io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114741 }, /* l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000 */
{ 1114843 }, /* l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114927 }, /* l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000 */
{ 1115015 }, /* l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000 */
{ 1189817 }, /* large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1228719 }, /* load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000 */
{ 1228806 }, /* load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000 */
{ 1228902 }, /* load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1229004 }, /* load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000 */
{ 2476952 }, /* partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000 */
{ 2521171 }, /* sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000 */
{ 2521260 }, /* seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000 */
{ 2528735 }, /* snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000 */
{ 2528831 }, /* snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000 */
{ 2528929 }, /* snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000 */
{ 2530255 }, /* sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000 */
{ 467271 }, /* arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 467371 }, /* arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 471330 }, /* arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000 */
{ 473654 }, /* baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000 */
{ 473765 }, /* baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 473868 }, /* baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000 */
{ 487276 }, /* bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000 */
{ 487380 }, /* bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000 */
{ 487482 }, /* bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 491001 }, /* br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000 */
{ 491098 }, /* br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000 */
{ 491207 }, /* br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000 */
{ 491309 }, /* br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000 */
{ 491426 }, /* br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000 */
{ 491540 }, /* br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000 */
{ 491656 }, /* br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000 */
{ 491753 }, /* br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000 */
{ 492324 }, /* br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000 */
{ 492432 }, /* br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000 */
{ 498319 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000 */
{ 506620 }, /* br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000 */
{ 515982 }, /* br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000 */
{ 530639 }, /* br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000 */
{ 530737 }, /* br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000 */
{ 530847 }, /* br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000 */
{ 530961 }, /* br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000 */
{ 531333 }, /* br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000 */
{ 531459 }, /* br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000 */
{ 531587 }, /* br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000 */
{ 531696 }, /* br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000 */
{ 532460 }, /* br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000 */
{ 532571 }, /* br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000 */
{ 554975 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000 */
{ 620914 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 622158 }, /* cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000 */
{ 643775 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000 */
{ 647207 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000 */
{ 649803 }, /* cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000 */
{ 1040461 }, /* ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000 */
{ 1040570 }, /* ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000 */
{ 1040907 }, /* ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 1042997 }, /* ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 1043097 }, /* ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000 */
{ 1043183 }, /* inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000 */
{ 1043960 }, /* inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000 */
{ 1044092 }, /* inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000 */
{ 1047147 }, /* inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053554 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1057737 }, /* inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000 */
{ 1063146 }, /* inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1063652 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1064586 }, /* inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000 */
{ 1231057 }, /* load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000 */
{ 1283188 }, /* lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1285888 }, /* lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1286788 }, /* lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000 */
{ 1289354 }, /* machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000 */
{ 1293852 }, /* machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000 */
{ 1300312 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000 */
{ 2483994 }, /* rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000 */
{ 2484081 }, /* rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2484167 }, /* rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2484269 }, /* rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2484373 }, /* rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2501064 }, /* resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2502029 }, /* resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000 */
{ 2502398 }, /* resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2502656 }, /* resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000 */
{ 2502894 }, /* resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000 */
{ 2503359 }, /* resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000 */
{ 2504132 }, /* resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2506545 }, /* resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2536082 }, /* ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000 */
{ 2536212 }, /* ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000 */
{ 2536342 }, /* ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000 */
{ 2536472 }, /* ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000 */
{ 2536602 }, /* ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000 */
{ 6178001 }, /* uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178955 }, /* uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6179066 }, /* uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6179169 }, /* uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6179294 }, /* uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6193659 }, /* uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6193804 }, /* uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199088 }, /* uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199380 }, /* uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199692 }, /* uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199843 }, /* uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6204390 }, /* uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6204143 }, /* uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204248 }, /* uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204485 }, /* uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6204580 }, /* uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000 */
{ 6204696 }, /* uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6204815 }, /* uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6204934 }, /* uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000 */
{ 6205054 }, /* uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000 */
{ 6213590 }, /* uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216019 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216805 }, /* uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6217626 }, /* uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000 */
{ 6219127 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6225258 }, /* uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6227775 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000 */
{ 6231023 }, /* uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000 */
{ 6233951 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000 */
{ 6238074 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6240810 }, /* uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 787008 }, /* dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000 */
{ 789416 }, /* dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000 */
{ 789810 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000 */
{ 794527 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000 */
{ 809538 }, /* dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000 */
{ 810055 }, /* dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000 */
{ 810178 }, /* dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000 */
{ 1079563 }, /* itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000 */
{ 1079644 }, /* itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000 */
{ 1079777 }, /* itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000 */
{ 1087383 }, /* itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000 */
{ 1331956 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000 */
{ 1368683 }, /* mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__nehalemex[] = {
{ 571421 }, /* cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000 */
{ 571509 }, /* cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000 */
{ 1100466 }, /* l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000 */
{ 1100562 }, /* l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000 */
{ 1100662 }, /* l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000 */
{ 1100773 }, /* l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000 */
{ 1102488 }, /* l1d_all_ref.any\000\000cache\000All references to the L1 data cache\000event=0x43,period=2000000,umask=0x1\000\00000\000\000 */
{ 1102588 }, /* l1d_all_ref.cacheable\000\000cache\000L1 data cacheable reads and writes\000event=0x43,period=2000000,umask=0x2\000\00000\000\000 */
{ 1103564 }, /* l1d_cache_ld.e_state\000\000cache\000L1 data cache read in E state\000event=0x40,period=2000000,umask=0x4\000\00000\000\000 */
{ 1103663 }, /* l1d_cache_ld.i_state\000\000cache\000L1 data cache read in I state (misses)\000event=0x40,period=2000000,umask=0x1\000\00000\000\000 */
{ 1103771 }, /* l1d_cache_ld.m_state\000\000cache\000L1 data cache read in M state\000event=0x40,period=2000000,umask=0x8\000\00000\000\000 */
{ 1103870 }, /* l1d_cache_ld.mesi\000\000cache\000L1 data cache reads\000event=0x40,period=2000000,umask=0xf\000\00000\000\000 */
{ 1103956 }, /* l1d_cache_ld.s_state\000\000cache\000L1 data cache read in S state\000event=0x40,period=2000000,umask=0x2\000\00000\000\000 */
{ 1104055 }, /* l1d_cache_lock.e_state\000\000cache\000L1 data cache load locks in E state\000event=0x42,period=2000000,umask=0x4\000\00000\000\000 */
{ 1104162 }, /* l1d_cache_lock.hit\000\000cache\000L1 data cache load lock hits\000event=0x42,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104258 }, /* l1d_cache_lock.m_state\000\000cache\000L1 data cache load locks in M state\000event=0x42,period=2000000,umask=0x8\000\00000\000\000 */
{ 1104365 }, /* l1d_cache_lock.s_state\000\000cache\000L1 data cache load locks in S state\000event=0x42,period=2000000,umask=0x2\000\00000\000\000 */
{ 1104472 }, /* l1d_cache_lock_fb_hit\000\000cache\000L1D load lock accepted in fill buffer\000event=0x53,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104580 }, /* l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104706 }, /* l1d_cache_st.e_state\000\000cache\000L1 data cache stores in E state\000event=0x41,period=2000000,umask=0x4\000\00000\000\000 */
{ 1104807 }, /* l1d_cache_st.m_state\000\000cache\000L1 data cache stores in M state\000event=0x41,period=2000000,umask=0x8\000\00000\000\000 */
{ 1104908 }, /* l1d_cache_st.s_state\000\000cache\000L1 data cache stores in S state\000event=0x41,period=2000000,umask=0x2\000\00000\000\000 */
{ 1113958 }, /* l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000 */
{ 1114052 }, /* l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000 */
{ 1114152 }, /* l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000 */
{ 1114262 }, /* l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000 */
{ 1114358 }, /* l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000 */
{ 1114463 }, /* l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000 */
{ 1114559 }, /* l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000 */
{ 1114645 }, /* l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000 */
{ 1121826 }, /* l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000 */
{ 1121913 }, /* l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000 */
{ 1122021 }, /* l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000 */
{ 1122138 }, /* l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000 */
{ 1122246 }, /* l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000 */
{ 1122343 }, /* l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000 */
{ 1122451 }, /* l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1122560 }, /* l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000 */
{ 1122682 }, /* l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000 */
{ 1122791 }, /* l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000 */
{ 1122890 }, /* l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000 */
{ 1129601 }, /* l2_lines_in.any\000\000cache\000L2 lines alloacated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000 */
{ 1130213 }, /* l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000 */
{ 1131206 }, /* l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000 */
{ 1131570 }, /* l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000 */
{ 1132175 }, /* l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000 */
{ 1132697 }, /* l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000 */
{ 1135641 }, /* l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000 */
{ 1135755 }, /* l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000 */
{ 1167724 }, /* l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000 */
{ 1167818 }, /* l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000 */
{ 1167915 }, /* l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000 */
{ 1168737 }, /* l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000 */
{ 1168813 }, /* l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000 */
{ 1168892 }, /* l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000 */
{ 1168966 }, /* l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000 */
{ 1172018 }, /* l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1172105 }, /* l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000 */
{ 1172195 }, /* l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000 */
{ 1172443 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000 */
{ 1173756 }, /* l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000 */
{ 1174646 }, /* l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000 */
{ 1175586 }, /* l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000 */
{ 1183427 }, /* l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000 */
{ 1183515 }, /* l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000 */
{ 1183605 }, /* l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000 */
{ 1183709 }, /* l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000 */
{ 1183813 }, /* l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000 */
{ 1183902 }, /* l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000 */
{ 1183999 }, /* l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000 */
{ 1184086 }, /* l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000 */
{ 1184856 }, /* l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000 */
{ 1184957 }, /* l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000 */
{ 1185066 }, /* l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000 */
{ 1185176 }, /* l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000 */
{ 1185277 }, /* l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000 */
{ 1185368 }, /* l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000 */
{ 1185469 }, /* l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000 */
{ 1185577 }, /* l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000 */
{ 1185686 }, /* l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000 */
{ 1185786 }, /* l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000 */
{ 1185876 }, /* l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000 */
{ 1249469 }, /* longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000 */
{ 1253301 }, /* longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1312836 }, /* mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000 */
{ 1312997 }, /* mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000 */
{ 1313161 }, /* mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000 */
{ 1313488 }, /* mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000 */
{ 1313323 }, /* mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000 */
{ 1313649 }, /* mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000 */
{ 1313812 }, /* mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000 */
{ 1314139 }, /* mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000 */
{ 1313974 }, /* mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000 */
{ 1314463 }, /* mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000 */
{ 1314299 }, /* mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000 */
{ 1314621 }, /* mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000 */
{ 1314783 }, /* mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000 */
{ 1315107 }, /* mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000 */
{ 1314943 }, /* mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000 */
{ 1315265 }, /* mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1319310 }, /* mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000 */
{ 1333824 }, /* mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000 */
{ 1336151 }, /* mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1336860 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000 */
{ 1340299 }, /* mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000 */
{ 1340426 }, /* mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000 */
{ 1341515 }, /* mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000 */
{ 1752159 }, /* offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000 */
{ 1780856 }, /* offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000 */
{ 1921008 }, /* offcore_response.any_data.any_cache_dram\000\000cache\000Offcore data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F11\000\00000\000\000 */
{ 1921952 }, /* offcore_response.any_data.any_location\000\000cache\000All offcore data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF11\000\00000\000\000 */
{ 1922237 }, /* offcore_response.any_data.io_csr_mmio\000\000cache\000Offcore data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000 */
{ 1922551 }, /* offcore_response.any_data.llc_hit_no_other_core\000\000cache\000Offcore data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000 */
{ 1922910 }, /* offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000Offcore data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000 */
{ 1923266 }, /* offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000Offcore data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000 */
{ 1923627 }, /* offcore_response.any_data.local_cache\000\000cache\000Offcore data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000 */
{ 1924087 }, /* offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4711\000\00000\000\000 */
{ 1924913 }, /* offcore_response.any_data.remote_cache\000\000cache\000Offcore data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1811\000\00000\000\000 */
{ 1925065 }, /* offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3811\000\00000\000\000 */
{ 1925409 }, /* offcore_response.any_data.remote_cache_hit\000\000cache\000Offcore data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000 */
{ 1925564 }, /* offcore_response.any_data.remote_cache_hitm\000\000cache\000Offcore data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000 */
{ 1936832 }, /* offcore_response.any_ifetch.any_cache_dram\000\000cache\000Offcore code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F44\000\00000\000\000 */
{ 1937779 }, /* offcore_response.any_ifetch.any_location\000\000cache\000All offcore code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF44\000\00000\000\000 */
{ 1938065 }, /* offcore_response.any_ifetch.io_csr_mmio\000\000cache\000Offcore code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000 */
{ 1938380 }, /* offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000 */
{ 1938740 }, /* offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000 */
{ 1939097 }, /* offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000 */
{ 1939459 }, /* offcore_response.any_ifetch.local_cache\000\000cache\000Offcore code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000 */
{ 1939922 }, /* offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4744\000\00000\000\000 */
{ 1940752 }, /* offcore_response.any_ifetch.remote_cache\000\000cache\000Offcore code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1844\000\00000\000\000 */
{ 1940906 }, /* offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3844\000\00000\000\000 */
{ 1941254 }, /* offcore_response.any_ifetch.remote_cache_hit\000\000cache\000Offcore code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000 */
{ 1941411 }, /* offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000Offcore code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000 */
{ 1960213 }, /* offcore_response.any_request.any_cache_dram\000\000cache\000Offcore requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FFF\000\00000\000\000 */
{ 1961163 }, /* offcore_response.any_request.any_location\000\000cache\000All offcore requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFFFF\000\00000\000\000 */
{ 1963126 }, /* offcore_response.any_request.io_csr_mmio\000\000cache\000Offcore requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80FF\000\00000\000\000 */
{ 1969757 }, /* offcore_response.any_request.llc_hit_no_other_core\000\000cache\000Offcore requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1FF\000\00000\000\000 */
{ 1970118 }, /* offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000Offcore requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2FF\000\00000\000\000 */
{ 1970476 }, /* offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000Offcore requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4FF\000\00000\000\000 */
{ 1971122 }, /* offcore_response.any_request.local_cache\000\000cache\000Offcore requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FF\000\00000\000\000 */
{ 1971585 }, /* offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x47FF\000\00000\000\000 */
{ 1973747 }, /* offcore_response.any_request.remote_cache\000\000cache\000Offcore requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x18FF\000\00000\000\000 */
{ 1973900 }, /* offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x38FF\000\00000\000\000 */
{ 1974246 }, /* offcore_response.any_request.remote_cache_hit\000\000cache\000Offcore requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10FF\000\00000\000\000 */
{ 1974402 }, /* offcore_response.any_request.remote_cache_hitm\000\000cache\000Offcore requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8FF\000\00000\000\000 */
{ 1975383 }, /* offcore_response.any_rfo.any_cache_dram\000\000cache\000Offcore RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F22\000\00000\000\000 */
{ 1976309 }, /* offcore_response.any_rfo.any_location\000\000cache\000All offcore RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF22\000\00000\000\000 */
{ 1977996 }, /* offcore_response.any_rfo.io_csr_mmio\000\000cache\000Offcore RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000 */
{ 1985711 }, /* offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000Offcore RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000 */
{ 1986064 }, /* offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000Offcore RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000 */
{ 1986414 }, /* offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000 */
{ 1986769 }, /* offcore_response.any_rfo.local_cache\000\000cache\000Offcore RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000 */
{ 1987224 }, /* offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4722\000\00000\000\000 */
{ 1989498 }, /* offcore_response.any_rfo.remote_cache\000\000cache\000Offcore RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1822\000\00000\000\000 */
{ 1989651 }, /* offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3822\000\00000\000\000 */
{ 1989997 }, /* offcore_response.any_rfo.remote_cache_hit\000\000cache\000Offcore RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000 */
{ 1990153 }, /* offcore_response.any_rfo.remote_cache_hitm\000\000cache\000Offcore RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000 */
{ 1998153 }, /* offcore_response.corewb.any_cache_dram\000\000cache\000Offcore writebacks to any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F08\000\00000\000\000 */
{ 1999047 }, /* offcore_response.corewb.any_location\000\000cache\000All offcore writebacks\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF08\000\00000\000\000 */
{ 2000260 }, /* offcore_response.corewb.io_csr_mmio\000\000cache\000Offcore writebacks to the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000 */
{ 2007876 }, /* offcore_response.corewb.llc_hit_no_other_core\000\000cache\000Offcore writebacks to the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000 */
{ 2008383 }, /* offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000Offcore writebacks to the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000 */
{ 2008724 }, /* offcore_response.corewb.local_cache\000\000cache\000Offcore writebacks to the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000 */
{ 2009152 }, /* offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4708\000\00000\000\000 */
{ 2010460 }, /* offcore_response.corewb.remote_cache\000\000cache\000Offcore writebacks to a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1808\000\00000\000\000 */
{ 2010600 }, /* offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3808\000\00000\000\000 */
{ 2010920 }, /* offcore_response.corewb.remote_cache_hit\000\000cache\000Offcore writebacks that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000 */
{ 2011073 }, /* offcore_response.corewb.remote_cache_hitm\000\000cache\000Offcore writebacks that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000 */
{ 2013167 }, /* offcore_response.data_ifetch.any_cache_dram\000\000cache\000Offcore code or data read requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F77\000\00000\000\000 */
{ 2014171 }, /* offcore_response.data_ifetch.any_location\000\000cache\000All offcore code or data read requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF77\000\00000\000\000 */
{ 2014476 }, /* offcore_response.data_ifetch.io_csr_mmio\000\000cache\000Offcore code or data read requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000 */
{ 2014810 }, /* offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code or data read requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000 */
{ 2015189 }, /* offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code or data read requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000 */
{ 2015565 }, /* offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code or data read requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000 */
{ 2015946 }, /* offcore_response.data_ifetch.local_cache\000\000cache\000Offcore code or data read requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000 */
{ 2016445 }, /* offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4777\000\00000\000\000 */
{ 2017330 }, /* offcore_response.data_ifetch.remote_cache\000\000cache\000Offcore code or data read requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1877\000\00000\000\000 */
{ 2017501 }, /* offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3877\000\00000\000\000 */
{ 2017883 }, /* offcore_response.data_ifetch.remote_cache_hit\000\000cache\000Offcore code or data read requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000 */
{ 2018057 }, /* offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000Offcore code or data read requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000 */
{ 2019092 }, /* offcore_response.data_in.any_cache_dram\000\000cache\000Offcore request = all data, response = any cache_dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F33\000\00000\000\000 */
{ 2020036 }, /* offcore_response.data_in.any_location\000\000cache\000Offcore request = all data, response = any location\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF33\000\00000\000\000 */
{ 2020500 }, /* offcore_response.data_in.io_csr_mmio\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000 */
{ 2020828 }, /* offcore_response.data_in.llc_hit_no_other_core\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000 */
{ 2021201 }, /* offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000 */
{ 2021571 }, /* offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000 */
{ 2021946 }, /* offcore_response.data_in.local_cache\000\000cache\000Offcore request = all data, response = local cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000 */
{ 2022413 }, /* offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4733\000\00000\000\000 */
{ 2023271 }, /* offcore_response.data_in.remote_cache\000\000cache\000Offcore request = all data, response = remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1833\000\00000\000\000 */
{ 2023427 }, /* offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3833\000\00000\000\000 */
{ 2023765 }, /* offcore_response.data_in.remote_cache_hit\000\000cache\000Offcore data reads, RFOs, and prefetches that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000 */
{ 2023941 }, /* offcore_response.data_in.remote_cache_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000 */
{ 2072246 }, /* offcore_response.demand_data.any_cache_dram\000\000cache\000Offcore demand data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F03\000\00000\000\000 */
{ 2073232 }, /* offcore_response.demand_data.any_location\000\000cache\000All offcore demand data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF03\000\00000\000\000 */
{ 2073531 }, /* offcore_response.demand_data.io_csr_mmio\000\000cache\000Offcore demand data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000 */
{ 2073859 }, /* offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000Offcore demand data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000 */
{ 2074232 }, /* offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000Offcore demand data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000 */
{ 2074602 }, /* offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000Offcore demand data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000 */
{ 2074977 }, /* offcore_response.demand_data.local_cache\000\000cache\000Offcore demand data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000 */
{ 2075464 }, /* offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4703\000\00000\000\000 */
{ 2076331 }, /* offcore_response.demand_data.remote_cache\000\000cache\000Offcore demand data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1803\000\00000\000\000 */
{ 2076496 }, /* offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3803\000\00000\000\000 */
{ 2076866 }, /* offcore_response.demand_data.remote_cache_hit\000\000cache\000Offcore demand data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000 */
{ 2077034 }, /* offcore_response.demand_data.remote_cache_hitm\000\000cache\000Offcore demand data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000 */
{ 2078065 }, /* offcore_response.demand_data_rd.any_cache_dram\000\000cache\000Offcore demand data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F01\000\00000\000\000 */
{ 2079069 }, /* offcore_response.demand_data_rd.any_location\000\000cache\000All offcore demand data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF01\000\00000\000\000 */
{ 2081657 }, /* offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000Offcore demand data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000 */
{ 2118081 }, /* offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000Offcore demand data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000 */
{ 2118460 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore demand data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000 */
{ 2118836 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore demand data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000 */
{ 2121036 }, /* offcore_response.demand_data_rd.local_cache\000\000cache\000Offcore demand data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000 */
{ 2121529 }, /* offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4701\000\00000\000\000 */
{ 2125385 }, /* offcore_response.demand_data_rd.remote_cache\000\000cache\000Offcore demand data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1801\000\00000\000\000 */
{ 2125550 }, /* offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3801\000\00000\000\000 */
{ 2125920 }, /* offcore_response.demand_data_rd.remote_cache_hit\000\000cache\000Offcore demand data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000 */
{ 2126088 }, /* offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000Offcore demand data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000 */
{ 2130096 }, /* offcore_response.demand_ifetch.any_cache_dram\000\000cache\000Offcore demand code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F04\000\00000\000\000 */
{ 2131091 }, /* offcore_response.demand_ifetch.any_location\000\000cache\000All offcore demand code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF04\000\00000\000\000 */
{ 2131393 }, /* offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000Offcore demand code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000 */
{ 2131724 }, /* offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000Offcore demand code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000 */
{ 2132100 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore demand code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000 */
{ 2132473 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore demand code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000 */
{ 2133046 }, /* offcore_response.demand_ifetch.local_cache\000\000cache\000Offcore demand code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000 */
{ 2133535 }, /* offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4704\000\00000\000\000 */
{ 2134407 }, /* offcore_response.demand_ifetch.remote_cache\000\000cache\000Offcore demand code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1804\000\00000\000\000 */
{ 2134571 }, /* offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3804\000\00000\000\000 */
{ 2134939 }, /* offcore_response.demand_ifetch.remote_cache_hit\000\000cache\000Offcore demand code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000 */
{ 2135106 }, /* offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000Offcore demand code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000 */
{ 2136134 }, /* offcore_response.demand_rfo.any_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F02\000\00000\000\000 */
{ 2137108 }, /* offcore_response.demand_rfo.any_location\000\000cache\000All offcore demand RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF02\000\00000\000\000 */
{ 2139468 }, /* offcore_response.demand_rfo.io_csr_mmio\000\000cache\000Offcore demand RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000 */
{ 2177181 }, /* offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000Offcore demand RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000 */
{ 2177550 }, /* offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000Offcore demand RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000 */
{ 2177916 }, /* offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore demand RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000 */
{ 2179346 }, /* offcore_response.demand_rfo.local_cache\000\000cache\000Offcore demand RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000 */
{ 2179827 }, /* offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4702\000\00000\000\000 */
{ 2183680 }, /* offcore_response.demand_rfo.remote_cache\000\000cache\000Offcore demand RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1802\000\00000\000\000 */
{ 2183843 }, /* offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3802\000\00000\000\000 */
{ 2184209 }, /* offcore_response.demand_rfo.remote_cache_hit\000\000cache\000Offcore demand RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000 */
{ 2184375 }, /* offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000Offcore demand RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000 */
{ 2194549 }, /* offcore_response.other.any_cache_dram\000\000cache\000Offcore other requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F80\000\00000\000\000 */
{ 2195463 }, /* offcore_response.other.any_location\000\000cache\000All offcore other requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF80\000\00000\000\000 */
{ 2196350 }, /* offcore_response.other.io_csr_mmio\000\000cache\000Offcore other requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000 */
{ 2218865 }, /* offcore_response.other.llc_hit_no_other_core\000\000cache\000Offcore other requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000 */
{ 2219214 }, /* offcore_response.other.llc_hit_other_core_hit\000\000cache\000Offcore other requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000 */
{ 2219560 }, /* offcore_response.other.llc_hit_other_core_hitm\000\000cache\000Offcore other requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000 */
{ 2219911 }, /* offcore_response.other.local_cache\000\000cache\000Offcore other requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000 */
{ 2220362 }, /* offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4780\000\00000\000\000 */
{ 2222084 }, /* offcore_response.other.remote_cache\000\000cache\000Offcore other requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1880\000\00000\000\000 */
{ 2222237 }, /* offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3880\000\00000\000\000 */
{ 2222583 }, /* offcore_response.other.remote_cache_hit\000\000cache\000Offcore other requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000 */
{ 2222739 }, /* offcore_response.other.remote_cache_hitm\000\000cache\000Offcore other requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000 */
{ 2241116 }, /* offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F30\000\00000\000\000 */
{ 2242550 }, /* offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF30\000\00000\000\000 */
{ 2242978 }, /* offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8030\000\00000\000\000 */
{ 2243466 }, /* offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x130\000\00000\000\000 */
{ 2244025 }, /* offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x230\000\00000\000\000 */
{ 2244576 }, /* offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x430\000\00000\000\000 */
{ 2245135 }, /* offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x730\000\00000\000\000 */
{ 2245764 }, /* offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4730\000\00000\000\000 */
{ 2246609 }, /* offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1830\000\00000\000\000 */
{ 2246935 }, /* offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3830\000\00000\000\000 */
{ 2247301 }, /* offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1030\000\00000\000\000 */
{ 2247633 }, /* offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x830\000\00000\000\000 */
{ 2248801 }, /* offcore_response.pf_data_rd.any_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F10\000\00000\000\000 */
{ 2249775 }, /* offcore_response.pf_data_rd.any_location\000\000cache\000All offcore prefetch data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF10\000\00000\000\000 */
{ 2250070 }, /* offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000Offcore prefetch data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000 */
{ 2250394 }, /* offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000Offcore prefetch data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000 */
{ 2250763 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000 */
{ 2251129 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000 */
{ 2251689 }, /* offcore_response.pf_data_rd.local_cache\000\000cache\000Offcore prefetch data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000 */
{ 2252170 }, /* offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4710\000\00000\000\000 */
{ 2253027 }, /* offcore_response.pf_data_rd.remote_cache\000\000cache\000Offcore prefetch data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1810\000\00000\000\000 */
{ 2253190 }, /* offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3810\000\00000\000\000 */
{ 2253556 }, /* offcore_response.pf_data_rd.remote_cache_hit\000\000cache\000Offcore prefetch data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000 */
{ 2253722 }, /* offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000Offcore prefetch data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000 */
{ 2254730 }, /* offcore_response.pf_ifetch.any_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F40\000\00000\000\000 */
{ 2255686 }, /* offcore_response.pf_ifetch.any_location\000\000cache\000All offcore prefetch code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF40\000\00000\000\000 */
{ 2256127 }, /* offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000Offcore prefetch code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000 */
{ 2256445 }, /* offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000 */
{ 2256808 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000 */
{ 2257168 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000 */
{ 2257717 }, /* offcore_response.pf_ifetch.local_cache\000\000cache\000Offcore prefetch code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000 */
{ 2258191 }, /* offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4740\000\00000\000\000 */
{ 2259035 }, /* offcore_response.pf_ifetch.remote_cache\000\000cache\000Offcore prefetch code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1840\000\00000\000\000 */
{ 2259197 }, /* offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3840\000\00000\000\000 */
{ 2259561 }, /* offcore_response.pf_ifetch.remote_cache_hit\000\000cache\000Offcore prefetch code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000 */
{ 2259726 }, /* offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000Offcore prefetch code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000 */
{ 2430767 }, /* offcore_response.pf_rfo.any_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F20\000\00000\000\000 */
{ 2431720 }, /* offcore_response.pf_rfo.any_location\000\000cache\000All offcore prefetch RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF20\000\00000\000\000 */
{ 2432008 }, /* offcore_response.pf_rfo.io_csr_mmio\000\000cache\000Offcore prefetch RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000 */
{ 2432325 }, /* offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000 */
{ 2432687 }, /* offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000 */
{ 2433046 }, /* offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000 */
{ 2433410 }, /* offcore_response.pf_rfo.local_cache\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000 */
{ 2433882 }, /* offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4720\000\00000\000\000 */
{ 2434723 }, /* offcore_response.pf_rfo.remote_cache\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1820\000\00000\000\000 */
{ 2434884 }, /* offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3820\000\00000\000\000 */
{ 2435246 }, /* offcore_response.pf_rfo.remote_cache_hit\000\000cache\000Offcore prefetch RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000 */
{ 2435410 }, /* offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000Offcore prefetch RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000 */
{ 2440683 }, /* offcore_response.prefetch.any_cache_dram\000\000cache\000Offcore prefetch requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F70\000\00000\000\000 */
{ 2441633 }, /* offcore_response.prefetch.any_location\000\000cache\000All offcore prefetch requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF70\000\00000\000\000 */
{ 2441920 }, /* offcore_response.prefetch.io_csr_mmio\000\000cache\000Offcore prefetch requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000 */
{ 2442236 }, /* offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000 */
{ 2442597 }, /* offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000 */
{ 2442955 }, /* offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000 */
{ 2443318 }, /* offcore_response.prefetch.local_cache\000\000cache\000Offcore prefetch requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000 */
{ 2443787 }, /* offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4770\000\00000\000\000 */
{ 2444624 }, /* offcore_response.prefetch.remote_cache\000\000cache\000Offcore prefetch requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1870\000\00000\000\000 */
{ 2444783 }, /* offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3870\000\00000\000\000 */
{ 2445141 }, /* offcore_response.prefetch.remote_cache_hit\000\000cache\000Offcore prefetch requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000 */
{ 2445303 }, /* offcore_response.prefetch.remote_cache_hitm\000\000cache\000Offcore prefetch requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000 */
{ 2532073 }, /* sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000 */
{ 2536735 }, /* store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000 */
{ 2536845 }, /* store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000 */
{ 901660 }, /* fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000 */
{ 902741 }, /* fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000 */
{ 902880 }, /* fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000 */
{ 905570 }, /* fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 905656 }, /* fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000 */
{ 905760 }, /* fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000 */
{ 905885 }, /* fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000 */
{ 905986 }, /* fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000 */
{ 906093 }, /* fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000 */
{ 907996 }, /* fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000 */
{ 908121 }, /* fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 910502 }, /* fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000 */
{ 910623 }, /* fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000 */
{ 910751 }, /* fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524990 }, /* simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000 */
{ 2525101 }, /* simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000 */
{ 2525227 }, /* simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000 */
{ 2525352 }, /* simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000 */
{ 2525473 }, /* simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000 */
{ 2525593 }, /* simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000 */
{ 2525721 }, /* simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000 */
{ 2525836 }, /* simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000 */
{ 2525945 }, /* simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000 */
{ 2526069 }, /* simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000 */
{ 2526192 }, /* simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000 */
{ 2526318 }, /* simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000 */
{ 2526436 }, /* simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000 */
{ 2526562 }, /* simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000 */
{ 1302909 }, /* macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000 */
{ 1303001 }, /* macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000 */
{ 2571312 }, /* two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000 */
{ 1921326 }, /* offcore_response.any_data.any_dram\000\000memory\000Offcore data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6011\000\00000\000\000 */
{ 1921649 }, /* offcore_response.any_data.any_llc_miss\000\000memory\000Offcore data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF811\000\00000\000\000 */
{ 1924401 }, /* offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000 */
{ 1925886 }, /* offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000 */
{ 1937151 }, /* offcore_response.any_ifetch.any_dram\000\000memory\000Offcore code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6044\000\00000\000\000 */
{ 1937475 }, /* offcore_response.any_ifetch.any_llc_miss\000\000memory\000Offcore code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF844\000\00000\000\000 */
{ 1940240 }, /* offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000 */
{ 1941734 }, /* offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000 */
{ 1960533 }, /* offcore_response.any_request.any_dram\000\000memory\000Offcore requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x60FF\000\00000\000\000 */
{ 1960858 }, /* offcore_response.any_request.any_llc_miss\000\000memory\000Offcore requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF8FF\000\00000\000\000 */
{ 1971901 }, /* offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000 */
{ 1974726 }, /* offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000 */
{ 1975695 }, /* offcore_response.any_rfo.any_dram\000\000memory\000Offcore RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6022\000\00000\000\000 */
{ 1976012 }, /* offcore_response.any_rfo.any_llc_miss\000\000memory\000Offcore RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF822\000\00000\000\000 */
{ 1987540 }, /* offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000 */
{ 1990469 }, /* offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000 */
{ 1998451 }, /* offcore_response.corewb.any_dram\000\000memory\000Offcore writebacks to any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6008\000\00000\000\000 */
{ 1998754 }, /* offcore_response.corewb.any_llc_miss\000\000memory\000Offcore writebacks that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF808\000\00000\000\000 */
{ 2009442 }, /* offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000 */
{ 2011385 }, /* offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000 */
{ 2013505 }, /* offcore_response.data_ifetch.any_dram\000\000memory\000Offcore code or data read requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6077\000\00000\000\000 */
{ 2013848 }, /* offcore_response.data_ifetch.any_llc_miss\000\000memory\000Offcore code or data read requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF877\000\00000\000\000 */
{ 2016797 }, /* offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000 */
{ 2018399 }, /* offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000 */
{ 2019406 }, /* offcore_response.data_in.any_dram\000\000memory\000Offcore request = all data, response = any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6033\000\00000\000\000 */
{ 2019728 }, /* offcore_response.data_in.any_llc_miss\000\000memory\000Offcore request = all data, response = any LLC miss\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF833\000\00000\000\000 */
{ 2022752 }, /* offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000 */
{ 2024277 }, /* offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000 */
{ 2072578 }, /* offcore_response.demand_data.any_dram\000\000memory\000Offcore demand data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6003\000\00000\000\000 */
{ 2072915 }, /* offcore_response.demand_data.any_llc_miss\000\000memory\000Offcore demand data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF803\000\00000\000\000 */
{ 2075804 }, /* offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000 */
{ 2077370 }, /* offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000 */
{ 2078403 }, /* offcore_response.demand_data_rd.any_dram\000\000memory\000Offcore demand data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6001\000\00000\000\000 */
{ 2078746 }, /* offcore_response.demand_data_rd.any_llc_miss\000\000memory\000Offcore demand data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF801\000\00000\000\000 */
{ 2121869 }, /* offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000 */
{ 2126430 }, /* offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000 */
{ 2130431 }, /* offcore_response.demand_ifetch.any_dram\000\000memory\000Offcore demand code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6004\000\00000\000\000 */
{ 2130771 }, /* offcore_response.demand_ifetch.any_llc_miss\000\000memory\000Offcore demand code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF804\000\00000\000\000 */
{ 2133873 }, /* offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000 */
{ 2135445 }, /* offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000 */
{ 2136462 }, /* offcore_response.demand_rfo.any_dram\000\000memory\000Offcore demand RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6002\000\00000\000\000 */
{ 2136795 }, /* offcore_response.demand_rfo.any_llc_miss\000\000memory\000Offcore demand RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF802\000\00000\000\000 */
{ 2180163 }, /* offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000 */
{ 2184707 }, /* offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000 */
{ 2194857 }, /* offcore_response.other.any_dram\000\000memory\000Offcore other requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6080\000\00000\000\000 */
{ 2195170 }, /* offcore_response.other.any_llc_miss\000\000memory\000Offcore other requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF880\000\00000\000\000 */
{ 2223051 }, /* offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000 */
{ 2241606 }, /* offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6030\000\00000\000\000 */
{ 2242087 }, /* offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF830\000\00000\000\000 */
{ 2246100 }, /* offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4030\000\00000\000\000 */
{ 2248126 }, /* offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2030\000\00000\000\000 */
{ 2249129 }, /* offcore_response.pf_data_rd.any_dram\000\000memory\000Offcore prefetch data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6010\000\00000\000\000 */
{ 2249462 }, /* offcore_response.pf_data_rd.any_llc_miss\000\000memory\000Offcore prefetch data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF810\000\00000\000\000 */
{ 2252506 }, /* offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000 */
{ 2254054 }, /* offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000 */
{ 2255052 }, /* offcore_response.pf_ifetch.any_dram\000\000memory\000Offcore prefetch code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6040\000\00000\000\000 */
{ 2255379 }, /* offcore_response.pf_ifetch.any_llc_miss\000\000memory\000Offcore prefetch code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF840\000\00000\000\000 */
{ 2258525 }, /* offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000 */
{ 2260052 }, /* offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000 */
{ 2431088 }, /* offcore_response.pf_rfo.any_dram\000\000memory\000Offcore prefetch RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6020\000\00000\000\000 */
{ 2431414 }, /* offcore_response.pf_rfo.any_llc_miss\000\000memory\000Offcore prefetch RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF820\000\00000\000\000 */
{ 2434214 }, /* offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000 */
{ 2435735 }, /* offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000 */
{ 2441003 }, /* offcore_response.prefetch.any_dram\000\000memory\000Offcore prefetch requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6070\000\00000\000\000 */
{ 2441328 }, /* offcore_response.prefetch.any_llc_miss\000\000memory\000Offcore prefetch requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF870\000\00000\000\000 */
{ 2444115 }, /* offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000 */
{ 2445627 }, /* offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000 */
{ 835049 }, /* es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000 */
{ 1075635 }, /* io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114741 }, /* l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000 */
{ 1114843 }, /* l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114927 }, /* l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000 */
{ 1115015 }, /* l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000 */
{ 1189817 }, /* large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1228719 }, /* load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000 */
{ 1228806 }, /* load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000 */
{ 1228902 }, /* load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1229004 }, /* load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000 */
{ 2476952 }, /* partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000 */
{ 2521171 }, /* sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000 */
{ 2521260 }, /* seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000 */
{ 2528735 }, /* snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000 */
{ 2528831 }, /* snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000 */
{ 2528929 }, /* snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000 */
{ 2530255 }, /* sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000 */
{ 467271 }, /* arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 467371 }, /* arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 471330 }, /* arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000 */
{ 473654 }, /* baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000 */
{ 473765 }, /* baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 473868 }, /* baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000 */
{ 487276 }, /* bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000 */
{ 487380 }, /* bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000 */
{ 487482 }, /* bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 491001 }, /* br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000 */
{ 491098 }, /* br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000 */
{ 491207 }, /* br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000 */
{ 491309 }, /* br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000 */
{ 491426 }, /* br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000 */
{ 491540 }, /* br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000 */
{ 491656 }, /* br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000 */
{ 491753 }, /* br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000 */
{ 492324 }, /* br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000 */
{ 492432 }, /* br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000 */
{ 498319 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000 */
{ 506620 }, /* br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000 */
{ 515982 }, /* br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000 */
{ 530639 }, /* br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000 */
{ 530737 }, /* br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000 */
{ 530847 }, /* br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000 */
{ 530961 }, /* br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000 */
{ 531333 }, /* br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000 */
{ 531459 }, /* br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000 */
{ 531587 }, /* br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000 */
{ 531696 }, /* br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000 */
{ 532460 }, /* br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000 */
{ 532571 }, /* br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000 */
{ 554975 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000 */
{ 620914 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 622158 }, /* cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000 */
{ 643775 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000 */
{ 647207 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000 */
{ 649803 }, /* cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000 */
{ 1040461 }, /* ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000 */
{ 1040570 }, /* ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000 */
{ 1040907 }, /* ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 1042997 }, /* ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 1043097 }, /* ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000 */
{ 1043183 }, /* inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000 */
{ 1043960 }, /* inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000 */
{ 1044092 }, /* inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000 */
{ 1047147 }, /* inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053554 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1057737 }, /* inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000 */
{ 1063146 }, /* inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1063652 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1064586 }, /* inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000 */
{ 1231057 }, /* load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000 */
{ 1283188 }, /* lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1285888 }, /* lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1286788 }, /* lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000 */
{ 1289354 }, /* machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000 */
{ 1293852 }, /* machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000 */
{ 1300312 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000 */
{ 2483994 }, /* rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000 */
{ 2484081 }, /* rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2484167 }, /* rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2484269 }, /* rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2484373 }, /* rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2501064 }, /* resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2502029 }, /* resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000 */
{ 2502398 }, /* resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2502656 }, /* resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000 */
{ 2502894 }, /* resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000 */
{ 2503359 }, /* resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000 */
{ 2504132 }, /* resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2506545 }, /* resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2536082 }, /* ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000 */
{ 2536212 }, /* ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000 */
{ 2536342 }, /* ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000 */
{ 2536472 }, /* ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000 */
{ 2536602 }, /* ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000 */
{ 6178001 }, /* uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178955 }, /* uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6179066 }, /* uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6179169 }, /* uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6179294 }, /* uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6193659 }, /* uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6193804 }, /* uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199088 }, /* uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199380 }, /* uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199692 }, /* uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199843 }, /* uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6204390 }, /* uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6204143 }, /* uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204248 }, /* uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204485 }, /* uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6204580 }, /* uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000 */
{ 6204696 }, /* uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6204815 }, /* uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6204934 }, /* uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000 */
{ 6205054 }, /* uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000 */
{ 6213590 }, /* uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216019 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216805 }, /* uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6217626 }, /* uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000 */
{ 6219127 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6225258 }, /* uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6227775 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000 */
{ 6231023 }, /* uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000 */
{ 6233951 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000 */
{ 6238074 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6240810 }, /* uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 787008 }, /* dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000 */
{ 789416 }, /* dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000 */
{ 789810 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000 */
{ 794527 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000 */
{ 809538 }, /* dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000 */
{ 810055 }, /* dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000 */
{ 810178 }, /* dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000 */
{ 1079563 }, /* itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000 */
{ 1079644 }, /* itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000 */
{ 1079777 }, /* itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000 */
{ 1087383 }, /* itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000 */
{ 1331956 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000 */
{ 1368683 }, /* mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__rocketlake[] = {
{ 1100860 }, /* l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105377 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106609 }, /* l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107376 }, /* l1d_pend_miss.l2_stall\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1110782 }, /* l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112359 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1134424 }, /* l2_lines_out.non_silent\000\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000 */
{ 1136984 }, /* l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1137997 }, /* l2_lines_out.useless_hwpf\000\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses\000event=0xf2,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159594 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1160355 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165401 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1169342 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts all requests that miss L2 cache\000 */
{ 1172626 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all L2 requests\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177137 }, /* l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177638 }, /* l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312052 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315394 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1321627 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1322950 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1324093 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326535 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1330329 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or Bus Lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1332237 }, /* mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1333977 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335514 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336567 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337424 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338416 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339662 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1516538 }, /* ocr.demand_code_rd.l3_hit.any\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0004\000\00000\000\000 */
{ 1517912 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 1518919 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1520231 }, /* ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 1520925 }, /* ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 1521460 }, /* ocr.demand_code_rd.l3_hit.snoop_sent\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0004\000\00000\000\000 */
{ 1544094 }, /* ocr.demand_data_rd.l3_hit.any\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0001\000\00000\000\000 */
{ 1545403 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1548626 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1550484 }, /* ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 1551071 }, /* ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 1551504 }, /* ocr.demand_data_rd.l3_hit.snoop_sent\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0001\000\00000\000\000 */
{ 1574428 }, /* ocr.demand_rfo.l3_hit.any\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0002\000\00000\000\000 */
{ 1576127 }, /* ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 1577226 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1579321 }, /* ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 1580087 }, /* ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 1580389 }, /* ocr.demand_rfo.l3_hit.snoop_sent\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0002\000\00000\000\000 */
{ 1603778 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.any\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0400\000\00000\000\000 */
{ 1604338 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_miss\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0400\000\00000\000\000 */
{ 1604617 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_not_needed\000\000cache\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000 */
{ 1610636 }, /* ocr.hwpf_l2_data_rd.l3_hit.any\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0010\000\00000\000\000 */
{ 1611153 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 1612023 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 1612585 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 1613117 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 1613377 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch data reads (which bring data to L2)  that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0010\000\00000\000\000 */
{ 1615598 }, /* ocr.hwpf_l2_rfo.l3_hit.any\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0020\000\00000\000\000 */
{ 1616094 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 1616933 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 1617474 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 1617985 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 1618234 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_sent\000\000cache\000Counts hardware prefetch RFOs (which bring data to L2) that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C0020\000\00000\000\000 */
{ 1620260 }, /* ocr.hwpf_l3.l3_hit.any\000\000cache\000Counts hardware prefetches to the L3 only that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C2380\000\00000\000\000 */
{ 1626136 }, /* ocr.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop hit in another core, data forwarding is not required\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C8000\000\00000\000\000 */
{ 1626694 }, /* ocr.other.l3_hit.snoop_miss\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent but no other cores had the data\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C8000\000\00000\000\000 */
{ 1627100 }, /* ocr.other.l3_hit.snoop_not_needed\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was not needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C8000\000\00000\000\000 */
{ 1627357 }, /* ocr.other.l3_hit.snoop_sent\000\000cache\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that hit a cacheline in the L3 where a snoop was sent\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1E003C8000\000\00000\000\000 */
{ 1739218 }, /* ocr.streaming_wr.l3_hit.any\000\000cache\000Counts streaming stores that hit a cacheline in the L3 where a snoop was sent or not\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC03C0800\000\00000\000\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1746303 }, /* offcore_requests.all_requests\000\000cache\000Counts memory transactions sent to the uncore\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions sent to the uncore including requests initiated by the core, all L3 prefetches, reads resulting from page walks, and snoop responses\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1754378 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000For every cycle, increments by the number of outstanding data read requests pending\000event=0x60,period=1000003,umask=0x8\000\00000\000For every cycle, increments by the number of outstanding data read requests pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1760397 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles where at least 1 outstanding data read request is pending\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Cycles where at least 1 outstanding data read request is pending.  Data read requests include cacheable demand reads and L2 prefetches, but do not include RFOs, code reads or prefetches to the L3.  Reads due to page walks resulting from any request type will also be counted.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1764791 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles where at least 1 outstanding Demand RFO request is pending\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Cycles where at least 1 outstanding Demand RFO request is pending.   RFOs are initiated by a core as part of a data store operation.  Demand RFO requests include RFOs, locks, and ItoM transactions.  Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1772768 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x60,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 1778347 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Store Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x4\000\00000\000Counts the number of off-core outstanding read-for-ownership (RFO) store transactions every cycle. An RFO transaction is considered to be in the Off-core outstanding state between L2 cache miss and transaction completion\000 */
{ 2530749 }, /* sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2532185 }, /* sq_misc.sq_full\000\000cache\000Cycles the queue waiting for offcore responses is full\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the queue waiting for responses from the uncore cannot take any more entries\000 */
{ 2537136 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2537780 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538434 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539067 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 472289 }, /* assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 854349 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 860385 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 862608 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 866643 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 872056 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 875751 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 878977 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 883416 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 887276 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 890230 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 893916 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898444 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775692 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781964 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE transitions count\000event=0xab,cmask=1,edge=1,period=100003,umask=0x2\000\00000\000Counts the number of Decode Stream Buffer (DSB a.k.a. Uop Cache)-to-MITE speculative transitions\000 */
{ 782565 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0xab,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943187 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944203 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 949857 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 945210 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x508006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 947605 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x501006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 953608 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 951670 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x510006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 958117 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x502006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 960274 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 962471 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x520006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 964690 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x504006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967070 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992514 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_DATA.STALLS]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_DATA.STALLS]\000 */
{ 993172 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 993710 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000Counts instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 994253 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000 */
{ 994901 }, /* icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_16B.IFDATA_STALL]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_16B.IFDATA_STALL]\000 */
{ 996232 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000 */
{ 1003938 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1004475 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1006310 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010161 }, /* idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1010842 }, /* idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1012316 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1017043 }, /* idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024432 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025109 }, /* idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=100003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1029922 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1035288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=5,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036953 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 751759 }, /* cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=1000003,umask=0x2\000\00000\000\000 */
{ 757545 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 971248 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one)\000event=0xc8,period=100003,umask=0x4\000\00000\000Counts the number of times HLE abort was triggered\000 */
{ 971465 }, /* hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=100003,umask=0x80\000\00000\000Counts the number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000 */
{ 971889 }, /* hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=100003,umask=0x8\000\00000\000Counts the number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000 */
{ 974829 }, /* hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=100003,umask=0x20\000\00000\000Counts the number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000 */
{ 975537 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=100003,umask=0x2\000\00000\000Counts the number of times HLE commit succeeded\000 */
{ 975991 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an HLE region. Does not count nested transactions\000 */
{ 1296966 }, /* machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1529201 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00004\000\00000\000\000 */
{ 1559278 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00001\000\00000\000\000 */
{ 1589461 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00002\000\00000\000\000 */
{ 1605163 }, /* ocr.hwpf_l1d_and_swpf.l3_miss\000\000memory\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00400\000\00000\000\000 */
{ 1614029 }, /* ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts hardware prefetch data reads (which bring data to L2)  that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00010\000\00000\000\000 */
{ 1618855 }, /* ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts hardware prefetch RFOs (which bring data to L2) that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00020\000\00000\000\000 */
{ 1633820 }, /* ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC08000\000\00000\000\000 */
{ 1740302 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that was not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFFC00800\000\00000\000\000 */
{ 1752416 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000\000 */
{ 1768078 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles where at least one demand data read request known to have missed the L3 cache is pending\000event=0x60,cmask=1,period=1000003,umask=0x10\000\00000\000Cycles where at least one demand data read request known to have missed the L3 cache is pending.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known to have missed the L3 cache\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2515369 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2515927 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516525 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519396 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2572419 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=100003,umask=0x2\000\00000\000Counts Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2573092 }, /* tx_exec.misc3\000\000memory\000Number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=100003,umask=0x4\000\00000\000Counts Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 2576510 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=100003,umask=0x10\000\00000\000Counts the number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577677 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=100003,umask=0x8\000\00000\000Counts the number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2578735 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=100003,umask=0x20\000\00000\000Counts the number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2579607 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=100003,umask=0x4\000\00000\000Counts the number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2580724 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=100003,umask=0x40\000\00000\000Counts the number of times we could not allocate Lock Buffer\000 */
{ 572304 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Counts Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 573029 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Counts Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573765 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server microarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 1515566 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1515766 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1533808 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543304 }, /* ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1564662 }, /* ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1572540 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1573743 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1595303 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1603145 }, /* ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1603360 }, /* ocr.hwpf_l1d_and_swpf.dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000 */
{ 1605929 }, /* ocr.hwpf_l1d_and_swpf.local_dram\000\000other\000Counts L1 data cache prefetch requests and software prefetches (except PREFETCHW) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000400\000\00000\000\000 */
{ 1610055 }, /* ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 1610447 }, /* ocr.hwpf_l2_data_rd.dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614657 }, /* ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts hardware prefetch data reads (which bring data to L2)  that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1615049 }, /* ocr.hwpf_l2_rfo.any_response\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 1615420 }, /* ocr.hwpf_l2_rfo.dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619452 }, /* ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts hardware prefetch RFOs (which bring data to L2) that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1624769 }, /* ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1624959 }, /* ocr.other.dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000 */
{ 1637626 }, /* ocr.other.local_dram\000\000other\000Counts miscellaneous requests, such as I/O and un-cacheable accesses that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184008000\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1739070 }, /* ocr.streaming_wr.dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000 */
{ 1741244 }, /* ocr.streaming_wr.local_dram\000\000other\000Counts streaming stores that DRAM supplied the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000800\000\00000\000\000 */
{ 468280 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0x14,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 471702 }, /* assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x7\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502931 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504333 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 504924 }, /* br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 508295 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511305 }, /* br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 515219 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 517928 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 519163 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 535753 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=50021\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542758 }, /* br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 544064 }, /* br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545483 }, /* br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 548979 }, /* br_misp_retired.indirect\000\000pipeline\000All miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000event=0xc5,period=50021,umask=0x80\000\00000\000Counts all miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000 */
{ 550538 }, /* br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 555535 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 560471 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=50021,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 616704 }, /* cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 617767 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 621045 }, /* cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 626122 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638164 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000Counts core crystal clock cycles when the thread is unhalted\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 748732 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750161 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 752892 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754470 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 755810 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 758739 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=1000003,umask=0x14\000\00000\000\000 */
{ 759202 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847674 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 1041607 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1050414 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055840 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057998 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1060581 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with a reduced effect of PEBS shadow in IP distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1062948 }, /* inst_retired.stall_cycles\000\000pipeline\000Cycles without actually retired instructions\000event=0xc0,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000This event counts cycles without actually retired instructions\000 */
{ 1064821 }, /* int_misc.all_recovery_cycles\000\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000 */
{ 1065804 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xd,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1067113 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1069580 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xd,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072919 }, /* int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xd,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1194117 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1201415 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies due to partial compare on address\000 */
{ 1231173 }, /* load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285110 }, /* lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=5,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286007 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1288826 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431801 }, /* misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR to be enabled properly\000 */
{ 1432509 }, /* misc_retired.pause_inst\000\000pipeline\000Number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000event=0xcc,period=100003,umask=0x40\000\00000\000Counts number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000 */
{ 2504245 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506218 }, /* resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2510439 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=1000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into stravation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2513050 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty\000event=0x5e,cmask=1,edge=1,inv=1,period=100003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2543188 }, /* topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Counts the number of Top-down Microarchitecture Analysis (TMA) method's  slots where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2546876 }, /* topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by branch mispredictions. This event estimates number of operations that were issued but not retired from the speculative path as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6178334 }, /* uops_decoded.dec0\000\000pipeline\000Number of uops decoded out of instructions exclusively fetched by decoder 0\000event=0x56,period=1000003,umask=0x1\000\00000\000Uops exclusively fetched by decoder 0\000 */
{ 6179516 }, /* uops_dispatched.port_0\000\000pipeline\000Number of uops executed on port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6180060 }, /* uops_dispatched.port_1\000\000pipeline\000Number of uops executed on port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6180604 }, /* uops_dispatched.port_2_3\000\000pipeline\000Number of uops executed on port 2 and 3\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 2 and 3\000 */
{ 6181215 }, /* uops_dispatched.port_4_9\000\000pipeline\000Number of uops executed on port 4 and 9\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 5 and 9\000 */
{ 6181807 }, /* uops_dispatched.port_5\000\000pipeline\000Number of uops executed on port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6182390 }, /* uops_dispatched.port_6\000\000pipeline\000Number of uops executed on port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6182937 }, /* uops_dispatched.port_7_8\000\000pipeline\000Number of uops executed on port 7 and 8\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 7 and 8\000 */
{ 6193009 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000 */
{ 6194148 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195247 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196350 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6197453 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200004 }, /* uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201055 }, /* uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202126 }, /* uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203199 }, /* uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207380 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6213867 }, /* uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6219243 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread\000event=0xe,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6221020 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to 'Mixing Intel AVX and Intel SSE Code' section of the Optimization Guide\000 */
{ 6236200 }, /* uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6238210 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6239807 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2582207 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop,  etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2582856 }, /* unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2583336 }, /* unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000 */
{ 2584516 }, /* unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2585084 }, /* unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2586171 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from its allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2589284 }, /* unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2590033 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Total number of all outgoing entries allocated. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591436 }, /* unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches. This event is not supported on ICL products but is supported on RKL products. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 3540688 }, /* unc_clock.socket\000uncore_clock\000uncore other\000UNC_CLOCK.SOCKET. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 791106 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793108 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802110 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x8,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805386 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x8,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 808161 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x8,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813152 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815445 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 823499 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 826601 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 830031 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x49,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1082642 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085650 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1097779 }, /* itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x85,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__rocketlake[] = {
{ 3582 }, /* \000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 4490 }, /* \000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000 */
{ 4591 }, /* \000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 50452 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5 + UOPS_DISPATCHED.PORT_6) / (4 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 53706 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * ASSISTS.ANY / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 59207 }, /* \000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 5 * cpu@INT_MISC.RECOVERY_CYCLES\\,cmask\\=1\\,edge@ / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 64724 }, /* \000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 68110 }, /* \000tma_branch_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * BR_INST_RETIRED.ALL_BRANCHES / (tma_retiring * tma_info_thread_slots)\000tma_branch_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions\000\000100%\000\000\000\00000 */
{ 69335 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 81165 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(29 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM + 23.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98081 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000 */
{ 100830 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00023.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 114219 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122993 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124667 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 134887 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 139263 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 147700 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00032.5 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 153696 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 158121 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 163606 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000(5 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE - INT_MISC.UOP_DROPPING) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 172771 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 177787 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180064 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 182343 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 184622 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 186270 }, /* \000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 192366 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer + tma_retiring * (UOPS_DECODED.DEC0 - cpu@UOPS_DECODED.DEC0\\,cmask\\=1@) / IDQ.MITE_UOPS\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 195231 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_16B.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197105 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 198371 }, /* \000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198640 }, /* \000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198902 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199501 }, /* \000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 200566 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 202880 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 207397 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 211900 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 214466 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216037 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216577 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 217012 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000 */
{ 217249 }, /* \000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000 */
{ 217937 }, /* \000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219831 }, /* \000tma_info_core_flopc\000Flops;Ret\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 222547 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 226105 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 5 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 227202 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227819 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229446 }, /* \000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232323 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239974 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242664 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 11\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251156 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251574 }, /* \000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,umask\\=0x10@ / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 254261 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256405 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257211 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 262284 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 266484 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / cpu@UNC_ARB_DAT_OCCUPANCY.RD\\,cmask\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 269302 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\000(UNC_ARB_TRK_OCCUPANCY.RD + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.RD\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 270925 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 272373 }, /* \000tma_info_system_power_license0_utilization\000Power\000CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 273292 }, /* \000tma_info_system_power_license1_utilization\000Power\000CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274252 }, /* \000tma_info_system_power_license2_utilization\000Power\000CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274904 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277349 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277503 }, /* \000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000 */
{ 277851 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278166 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 7.5\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 291636 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + L1D_PEND_MISS.FB_FULL_PERIODS) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 309429 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0009 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 314141 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317952 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3 / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 318802 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 325792 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 328183 }, /* \000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(LSD.CYCLES_ACTIVE - LSD.CYCLES_OK) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000 */
{ 329816 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 342540 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000 */
{ 348825 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001 */
{ 352279 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 357790 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 359354 }, /* \000tma_mite_4wide\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_mite_group\000(cpu@IDQ.MITE_UOPS\\,cmask\\=4@ - cpu@IDQ.MITE_UOPS\\,cmask\\=5@) / tma_info_thread_clks\000tma_mite_4wide > 0.05 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where (only) 4 uops were delivered by the MITE pipeline\000\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 366608 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369076 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_branch_instructions + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 377934 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 380965 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 385354 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 388354 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 392550 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 402317 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 408697 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 416142 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 419352 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 432289 }, /* \000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 436702 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 437735 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000140 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000 */
{ 440531 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 446331 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000L1D_PEND_MISS.L2_STALL / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 451466 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 455967 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 457909 }, /* \000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 458764 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\00010 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__sandybridge[] = {
{ 1099902 }, /* l1d.all_m_replacement\000\000cache\000Cache lines in M state evicted out of L1D due to Snoop HitM or dirty line replacement\000event=0x51,period=2000003,umask=0x8\000\00000\000\000 */
{ 1100058 }, /* l1d.allocated_in_m\000\000cache\000Allocated L1D data cache lines in M state\000event=0x51,period=2000003,umask=0x2\000\00000\000\000 */
{ 1100167 }, /* l1d.eviction\000\000cache\000L1D data cache lines in M state evicted due to replacement\000event=0x51,period=2000003,umask=0x4\000\00000\000\000 */
{ 1101743 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000This event counts L1D data line replacements.  Replacements occur when a new line is brought into the cache, causing eviction of a line loaded earlier\000 */
{ 1102693 }, /* l1d_blocks.bank_conflict_cycles\000\000cache\000Cycles when dispatched loads are cancelled due to L1D bank conflicts with other load ports\000event=0xbf,cmask=1,period=100003,umask=0x5\000\00000\000\000 */
{ 1105228 }, /* l1d_pend_miss.fb_full\000\000cache\000Cycles a demand request was blocked due to Fill Buffers unavailability\000event=0x48,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 1109165 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstanding duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000\000 */
{ 1112892 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1125021 }, /* l2_l1d_wb_rqsts.all\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in any state\000event=0x28,period=200003,umask=0xf\000\00000\000\000 */
{ 1125344 }, /* l2_l1d_wb_rqsts.hit_e\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in E state\000event=0x28,period=200003,umask=0x4\000\00000\000\000 */
{ 1125667 }, /* l2_l1d_wb_rqsts.hit_m\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in M state\000event=0x28,period=200003,umask=0x8\000\00000\000\000 */
{ 1125798 }, /* l2_l1d_wb_rqsts.hit_s\000\000cache\000Not rejected writebacks from L1D to L2 cache lines in S state\000event=0x28,period=200003,umask=0x2\000\00000\000\000 */
{ 1126135 }, /* l2_l1d_wb_rqsts.miss\000\000cache\000Count the number of modified Lines evicted from L1 and missed L2. (Non-rejected WBs from the DCU.)\000event=0x28,period=200003,umask=0x1\000\00000\000\000 */
{ 1128996 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x7\000\00000\000This event counts the number of L2 cache lines brought into the L2 cache.  Lines are filled into the L2 cache when there was an L2 miss\000 */
{ 1130115 }, /* l2_lines_in.e\000\000cache\000L2 cache lines in E state filling L2\000event=0xf1,period=100003,umask=0x4\000\00000\000\000 */
{ 1130664 }, /* l2_lines_in.i\000\000cache\000L2 cache lines in I state filling L2\000event=0xf1,period=100003,umask=0x1\000\00000\000\000 */
{ 1131108 }, /* l2_lines_in.s\000\000cache\000L2 cache lines in S state filling L2\000event=0xf1,period=100003,umask=0x2\000\00000\000\000 */
{ 1131801 }, /* l2_lines_out.demand_clean\000\000cache\000Clean L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x1\000\00000\000\000 */
{ 1132435 }, /* l2_lines_out.demand_dirty\000\000cache\000Dirty L2 cache lines evicted by demand\000event=0xf2,period=100003,umask=0x2\000\00000\000\000 */
{ 1132957 }, /* l2_lines_out.dirty_all\000\000cache\000Dirty L2 cache lines filling the L2\000event=0xf2,period=100003,umask=0xa\000\00000\000\000 */
{ 1135252 }, /* l2_lines_out.pf_clean\000\000cache\000Clean L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x4\000\00000\000\000 */
{ 1135528 }, /* l2_lines_out.pf_dirty\000\000cache\000Dirty L2 cache lines evicted by L2 prefetch\000event=0xf2,period=100003,umask=0x8\000\00000\000\000 */
{ 1157116 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0x30\000\00000\000\000 */
{ 1158415 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0x3\000\00000\000\000 */
{ 1161234 }, /* l2_rqsts.all_pf\000\000cache\000Requests from L2 hardware prefetchers\000event=0x24,period=200003,umask=0xc0\000\00000\000\000 */
{ 1161984 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xc\000\00000\000\000 */
{ 1163136 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0x10\000\00000\000\000 */
{ 1164107 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x20\000\00000\000\000 */
{ 1165282 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0x1\000\00000\000\000 */
{ 1171330 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L2 hardware prefetchers that hit L2 cache\000event=0x24,period=200003,umask=0x40\000\00000\000\000 */
{ 1171892 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L2 hardware prefetchers that miss L2 cache\000event=0x24,period=200003,umask=0x80\000\00000\000\000 */
{ 1173957 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0x4\000\00000\000\000 */
{ 1175303 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x8\000\00000\000\000 */
{ 1178721 }, /* l2_store_lock_rqsts.all\000\000cache\000RFOs that access cache lines in any state\000event=0x27,period=200003,umask=0xf\000\00000\000\000 */
{ 1178834 }, /* l2_store_lock_rqsts.hit_e\000\000cache\000RFOs that hit cache lines in E state\000event=0x27,period=200003,umask=0x4\000\00000\000\000 */
{ 1179090 }, /* l2_store_lock_rqsts.hit_m\000\000cache\000RFOs that hit cache lines in M state\000event=0x27,period=200003,umask=0x8\000\00000\000\000 */
{ 1179325 }, /* l2_store_lock_rqsts.miss\000\000cache\000RFOs that miss cache lines\000event=0x27,period=200003,umask=0x1\000\00000\000\000 */
{ 1179940 }, /* l2_trans.all_pf\000\000cache\000L2 or LLC HW prefetches that access L2 cache\000event=0xf0,period=200003,umask=0x8\000\00000\000\000 */
{ 1180373 }, /* l2_trans.all_requests\000\000cache\000Transactions accessing L2 pipe\000event=0xf0,period=200003,umask=0x80\000\00000\000\000 */
{ 1180812 }, /* l2_trans.code_rd\000\000cache\000L2 cache accesses when fetching instructions\000event=0xf0,period=200003,umask=0x4\000\00000\000\000 */
{ 1181450 }, /* l2_trans.demand_data_rd\000\000cache\000Demand Data Read requests that access L2 cache\000event=0xf0,period=200003,umask=0x1\000\00000\000\000 */
{ 1181856 }, /* l2_trans.l1d_wb\000\000cache\000L1D writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x10\000\00000\000\000 */
{ 1182254 }, /* l2_trans.l2_fill\000\000cache\000L2 fill requests that access L2 cache\000event=0xf0,period=200003,umask=0x20\000\00000\000\000 */
{ 1182778 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000\000 */
{ 1183333 }, /* l2_trans.rfo\000\000cache\000RFO requests that access L2 cache\000event=0xf0,period=200003,umask=0x2\000\00000\000\000 */
{ 1245886 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000\000 */
{ 1248025 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed LLC\000event=0x2e,period=100003,umask=0x41\000\00000\000\000 */
{ 1251819 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to LLC\000event=0x2e,period=100003,umask=0x4f\000\00000\000\000 */
{ 1346871 }, /* mem_load_uops_llc_hit_retired.xsnp_hit\000\000cache\000Retired load uops which data sources were LLC and cross-core snoop hits in on-pkg core cache. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a non-modified state. (Precise Event - PEBS) (Precise event)\000 */
{ 1348296 }, /* mem_load_uops_llc_hit_retired.xsnp_hitm\000\000cache\000Retired load uops which data sources were HitM responses from shared LLC. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level cache (L3) and were found in a non-modified state in a neighboring core's private cache (same package).  Since the last level cache is inclusive, hits to the L3 may require snooping the private L2 caches of any cores on the same socket that have the line.  In this case, a snoop was required, and another L2 had the line in a modified state, so the line had to be invalidated in that L2 cache and transferred to the requesting L2. (Precise Event - PEBS) (Precise event)\000 */
{ 1349879 }, /* mem_load_uops_llc_hit_retired.xsnp_miss\000\000cache\000Retired load uops which data sources were LLC hit and cross-core snoop missed in on-pkg core cache. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1350470 }, /* mem_load_uops_llc_hit_retired.xsnp_none\000\000cache\000Retired load uops which data sources were hits in LLC without snoops required. (Precise Event - PEBS) (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000\000 */
{ 1352054 }, /* mem_load_uops_misc_retired.llc_miss\000\000cache\000Retired load uops with unknown information as data source in cache serviced the load. (Precise Event - PEBS) (Precise event)\000event=0xd4,period=100007,umask=0x2\000\00000\000This event counts retired demand loads that missed the  last-level (L3) cache. This means that the load is usually satisfied from memory in a client system or possibly from the remote socket in a server. Demand loads are non speculative load uops. (Precise Event - PEBS) (Precise event)\000 */
{ 1354857 }, /* mem_load_uops_retired.hit_lfb\000\000cache\000Retired load uops which data sources were load uops missed L1 but hit FB due to preceding miss to the same cache line with data not ready. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=100003,umask=0x40\000\00000\000\000 */
{ 1357806 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Retired load uops with L1 cache hits as data sources. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1360854 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Retired load uops with L2 cache hits as data sources. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000\000 */
{ 1365107 }, /* mem_load_uops_retired.llc_hit\000\000cache\000Retired load uops which data sources were data hits in LLC without snoops required. (Precise Event - PEBS) (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000This event counts retired load uops that hit in the last-level (L3) cache without snoops required. (Precise Event - PEBS) (Precise event)\000 */
{ 1388948 }, /* mem_uops_retired.all_loads\000\000cache\000All retired load uops. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000This event counts the number of load uops retired (Precise Event) (Precise event)\000 */
{ 1391556 }, /* mem_uops_retired.all_stores\000\000cache\000All retired store uops. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000This event counts the number of store uops retired. (Precise Event - PEBS) (Precise event)\000 */
{ 1416130 }, /* mem_uops_retired.lock_loads\000\000cache\000Retired load uops with locked access. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1418722 }, /* mem_uops_retired.split_loads\000\000cache\000Retired load uops that split across a cacheline boundary. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000This event counts line-splitted load uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K). (Precise Event - PEBS) (Precise event)\000 */
{ 1420498 }, /* mem_uops_retired.split_stores\000\000cache\000Retired store uops that split across a cacheline boundary. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000This event counts line-splitted store uops retired to the architected path. A line split is across 64B cache-line which includes a page split (4K). (Precise Event - PEBS) (Precise event)\000 */
{ 1422314 }, /* mem_uops_retired.stlb_miss_loads\000\000cache\000Retired load uops that miss the STLB. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000\000 */
{ 1423389 }, /* mem_uops_retired.stlb_miss_stores\000\000cache\000Retired store uops that miss the STLB. (Precise Event - PEBS) (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000\000 */
{ 1745682 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000\000 */
{ 1749193 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and noncacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000\000 */
{ 1750715 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000\000 */
{ 1751785 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000\000 */
{ 1753235 }, /* offcore_requests_buffer.sq_full\000\000cache\000Cases when offcore requests buffer cannot take more entries for core\000event=0xb2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1757135 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000\000 */
{ 1760174 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1764176 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1767583 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1774876 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000\000 */
{ 1775481 }, /* offcore_requests_outstanding.demand_data_rd_c6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777696 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding RFO store transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x4\000\00000\000\000 */
{ 1782089 }, /* offcore_response.all_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0244\000\00000\000\000 */
{ 1782363 }, /* offcore_response.all_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0244\000\00000\000\000 */
{ 1782670 }, /* offcore_response.all_code_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0244\000\00000\000\000 */
{ 1784697 }, /* offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000105B3\000\00000\000\000 */
{ 1804724 }, /* offcore_response.all_data_rd.llc_hit.any_response\000\000cache\000Counts all demand & prefetch data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0091\000\00000\000\000 */
{ 1805176 }, /* offcore_response.all_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0091\000\00000\000\000 */
{ 1805720 }, /* offcore_response.all_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0091\000\00000\000\000 */
{ 1805994 }, /* offcore_response.all_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0091\000\00000\000\000 */
{ 1806525 }, /* offcore_response.all_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0091\000\00000\000\000 */
{ 1816073 }, /* offcore_response.all_pf_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0240\000\00000\000\000 */
{ 1816249 }, /* offcore_response.all_pf_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0240\000\00000\000\000 */
{ 1816515 }, /* offcore_response.all_pf_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0240\000\00000\000\000 */
{ 1816783 }, /* offcore_response.all_pf_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0240\000\00000\000\000 */
{ 1817084 }, /* offcore_response.all_pf_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0240\000\00000\000\000 */
{ 1838134 }, /* offcore_response.all_pf_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0090\000\00000\000\000 */
{ 1838483 }, /* offcore_response.all_pf_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0090\000\00000\000\000 */
{ 1838749 }, /* offcore_response.all_pf_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0090\000\00000\000\000 */
{ 1839017 }, /* offcore_response.all_pf_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0090\000\00000\000\000 */
{ 1839536 }, /* offcore_response.all_pf_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0090\000\00000\000\000 */
{ 1861923 }, /* offcore_response.all_pf_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0120\000\00000\000\000 */
{ 1862089 }, /* offcore_response.all_pf_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0120\000\00000\000\000 */
{ 1862345 }, /* offcore_response.all_pf_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0120\000\00000\000\000 */
{ 1862603 }, /* offcore_response.all_pf_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0120\000\00000\000\000 */
{ 1862894 }, /* offcore_response.all_pf_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0120\000\00000\000\000 */
{ 1866516 }, /* offcore_response.all_reads.any_response\000\000cache\000Counts all data/code/rfo references (demand & prefetch) \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x000107F7\000\00000\000\000 */
{ 1880720 }, /* offcore_response.all_reads.llc_hit.any_response\000\000cache\000Counts all data/code/rfo reads (demand & prefetch) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c03f7\000\00000\000\000 */
{ 1881475 }, /* offcore_response.all_reads.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c03f7\000\00000\000\000 */
{ 1882324 }, /* offcore_response.all_reads.llc_hit.hitm_other_core\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c03f7\000\00000\000\000 */
{ 1882927 }, /* offcore_response.all_reads.llc_hit.no_snoop_needed\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c03f7\000\00000\000\000 */
{ 1883480 }, /* offcore_response.all_reads.llc_hit.snoop_miss\000\000cache\000Counts data/code/rfo reads (demand & prefetch) that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c03f7\000\00000\000\000 */
{ 1889795 }, /* offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch prefetch RFOs \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010122\000\00000\000\000 */
{ 1909149 }, /* offcore_response.all_rfo.llc_hit.any_response\000\000cache\000Counts all demand & prefetch RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0122\000\00000\000\000 */
{ 1909581 }, /* offcore_response.all_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0122\000\00000\000\000 */
{ 1910105 }, /* offcore_response.all_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0122\000\00000\000\000 */
{ 1910369 }, /* offcore_response.all_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0122\000\00000\000\000 */
{ 1910666 }, /* offcore_response.all_rfo.llc_hit.snoop_miss\000\000cache\000Counts demand & prefetch RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0122\000\00000\000\000 */
{ 2000119 }, /* offcore_response.corewb.any_response\000\000cache\000OFFCORE_RESPONSE.COREWB.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10008\000\00000\000\000 */
{ 2020342 }, /* offcore_response.data_in.any_response\000\000cache\000REQUEST = DATA_INTO_CORE and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10433\000\00000\000\000 */
{ 2025769 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010004\000\00000\000\000 */
{ 2062524 }, /* offcore_response.demand_code_rd.llc_hit.any_response\000\000cache\000Counts all demand code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0004\000\00000\000\000 */
{ 2062960 }, /* offcore_response.demand_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0004\000\00000\000\000 */
{ 2063488 }, /* offcore_response.demand_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0004\000\00000\000\000 */
{ 2063754 }, /* offcore_response.demand_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0004\000\00000\000\000 */
{ 2064053 }, /* offcore_response.demand_code_rd.llc_hit.snoop_miss\000\000cache\000Counts demand code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0004\000\00000\000\000 */
{ 2079374 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts all demand data reads \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010001\000\00000\000\000 */
{ 2116118 }, /* offcore_response.demand_data_rd.llc_hit.any_response\000\000cache\000Counts all demand data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0001\000\00000\000\000 */
{ 2116550 }, /* offcore_response.demand_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0001\000\00000\000\000 */
{ 2117074 }, /* offcore_response.demand_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0001\000\00000\000\000 */
{ 2117340 }, /* offcore_response.demand_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0001\000\00000\000\000 */
{ 2117855 }, /* offcore_response.demand_data_rd.llc_hit.snoop_miss\000\000cache\000Counts demand data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0001\000\00000\000\000 */
{ 2137924 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand rfo's \000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x00010002\000\00000\000\000 */
{ 2175220 }, /* offcore_response.demand_rfo.llc_hit.any_response\000\000cache\000Counts all demand data writes (RFOs) that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0002\000\00000\000\000 */
{ 2175664 }, /* offcore_response.demand_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0002\000\00000\000\000 */
{ 2176200 }, /* offcore_response.demand_rfo.llc_hit.hitm_other_core\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0002\000\00000\000\000 */
{ 2176470 }, /* offcore_response.demand_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0002\000\00000\000\000 */
{ 2176773 }, /* offcore_response.demand_rfo.llc_hit.snoop_miss\000\000cache\000Counts demand data writes (RFOs) that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0002\000\00000\000\000 */
{ 2177003 }, /* offcore_response.demand_rfo.llc_hit_m.hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_M and SNOOP = HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000 */
{ 2195890 }, /* offcore_response.other.any_response\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses. It also includes L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 2220710 }, /* offcore_response.other.lru_hints\000\000cache\000Counts L2 hints sent to LLC to keep a line from being evicted out of the core caches\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x803c8000\000\00000\000\000 */
{ 2221684 }, /* offcore_response.other.portio_mmio_uc\000\000cache\000Counts miscellaneous accesses that include port i/o, MMIO and uncacheable memory accesses\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2380408000\000\00000\000\000 */
{ 2255975 }, /* offcore_response.pf_ifetch.any_response\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000 */
{ 2297503 }, /* offcore_response.pf_l2_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0040\000\00000\000\000 */
{ 2297901 }, /* offcore_response.pf_l2_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0040\000\00000\000\000 */
{ 2298190 }, /* offcore_response.pf_l2_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0040\000\00000\000\000 */
{ 2298481 }, /* offcore_response.pf_l2_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0040\000\00000\000\000 */
{ 2298805 }, /* offcore_response.pf_l2_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0040\000\00000\000\000 */
{ 2327442 }, /* offcore_response.pf_l2_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0010\000\00000\000\000 */
{ 2328025 }, /* offcore_response.pf_l2_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0010\000\00000\000\000 */
{ 2328314 }, /* offcore_response.pf_l2_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0010\000\00000\000\000 */
{ 2328605 }, /* offcore_response.pf_l2_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0010\000\00000\000\000 */
{ 2328929 }, /* offcore_response.pf_l2_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0010\000\00000\000\000 */
{ 2363559 }, /* offcore_response.pf_l2_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0020\000\00000\000\000 */
{ 2363748 }, /* offcore_response.pf_l2_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0020\000\00000\000\000 */
{ 2364027 }, /* offcore_response.pf_l2_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0020\000\00000\000\000 */
{ 2364308 }, /* offcore_response.pf_l2_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0020\000\00000\000\000 */
{ 2364622 }, /* offcore_response.pf_l2_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to L2) RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0020\000\00000\000\000 */
{ 2423001 }, /* offcore_response.pf_l_data_rd.any_response\000\000cache\000REQUEST = PF_LLC_DATA_RD and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000 */
{ 2423359 }, /* offcore_response.pf_l_ifetch.any_response\000\000cache\000REQUEST = PF_LLC_IFETCH and RESPONSE = ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10200\000\00000\000\000 */
{ 2423713 }, /* offcore_response.pf_llc_code_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) code reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0200\000\00000\000\000 */
{ 2424115 }, /* offcore_response.pf_llc_code_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0200\000\00000\000\000 */
{ 2424411 }, /* offcore_response.pf_llc_code_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0200\000\00000\000\000 */
{ 2424709 }, /* offcore_response.pf_llc_code_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0200\000\00000\000\000 */
{ 2425040 }, /* offcore_response.pf_llc_code_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) code reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0200\000\00000\000\000 */
{ 2426136 }, /* offcore_response.pf_llc_data_rd.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0080\000\00000\000\000 */
{ 2426544 }, /* offcore_response.pf_llc_data_rd.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0080\000\00000\000\000 */
{ 2426840 }, /* offcore_response.pf_llc_data_rd.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0080\000\00000\000\000 */
{ 2427138 }, /* offcore_response.pf_llc_data_rd.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0080\000\00000\000\000 */
{ 2427469 }, /* offcore_response.pf_llc_data_rd.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) data reads that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0080\000\00000\000\000 */
{ 2428818 }, /* offcore_response.pf_llc_rfo.llc_hit.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the LLC\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3f803c0100\000\00000\000\000 */
{ 2429014 }, /* offcore_response.pf_llc_rfo.llc_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003c0100\000\00000\000\000 */
{ 2429300 }, /* offcore_response.pf_llc_rfo.llc_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003c0100\000\00000\000\000 */
{ 2429588 }, /* offcore_response.pf_llc_rfo.llc_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003c0100\000\00000\000\000 */
{ 2429909 }, /* offcore_response.pf_llc_rfo.llc_hit.snoop_miss\000\000cache\000Counts prefetch (that bring data to LLC only) RFOs that hit in the LLC and the snoops sent to sibling cores return clean response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003c0100\000\00000\000\000 */
{ 2446094 }, /* offcore_response.split_lock_uc_lock.any_response\000\000cache\000Counts requests where the address of an atomic lock instruction spans a cache line boundary or the lock instruction is executed on uncacheable address\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 2447058 }, /* offcore_response.streaming_stores.any_response\000\000cache\000Counts non-temporal stores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 2531988 }, /* sq_misc.split_lock\000\000cache\000Split locks in SQ\000event=0xf4,period=100003,umask=0x10\000\00000\000\000 */
{ 902501 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000\000 */
{ 903610 }, /* fp_assist.simd_input\000\000floating point\000Number of SIMD FP assists due to input values\000event=0xca,period=100003,umask=0x10\000\00000\000\000 */
{ 904281 }, /* fp_assist.simd_output\000\000floating point\000Number of SIMD FP assists due to Output values\000event=0xca,period=100003,umask=0x8\000\00000\000\000 */
{ 904877 }, /* fp_assist.x87_input\000\000floating point\000Number of X87 assists due to input value\000event=0xca,period=100003,umask=0x4\000\00000\000\000 */
{ 905451 }, /* fp_assist.x87_output\000\000floating point\000Number of X87 assists due to output value\000event=0xca,period=100003,umask=0x2\000\00000\000\000 */
{ 906471 }, /* fp_comp_ops_exe.sse_packed_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x10\000\00000\000\000 */
{ 906924 }, /* fp_comp_ops_exe.sse_packed_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational packed single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x40\000\00000\000\000 */
{ 907361 }, /* fp_comp_ops_exe.sse_scalar_double\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar double-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x80\000\00000\000\000 */
{ 907814 }, /* fp_comp_ops_exe.sse_scalar_single\000\000floating point\000Number of SSE* or AVX-128 FP Computational scalar single-precision uops issued this cycle\000event=0x10,period=2000003,umask=0x20\000\00000\000\000 */
{ 908615 }, /* fp_comp_ops_exe.x87\000\000floating point\000Number of FP Computational Uops Executed this cycle. The number of FADD, FSUB, FCOM, FMULs, integer MULs and IMULs, FDIVs, FPREMs, FSQRTS, integer DIVs, and IDIVs. This event does not distinguish an FADD used in the middle of a transcendental flow from a s\000event=0x10,period=2000003,umask=0x1\000\00000\000\000 */
{ 2462917 }, /* other_assists.avx_store\000\000floating point\000Number of GSSE memory assist for stores. GSSE microcode assist is being invoked whenever the hardware is unable to properly handle GSSE-256b operations\000event=0xc1,period=100003,umask=0x8\000\00000\000\000 */
{ 2463621 }, /* other_assists.avx_to_sse\000\000floating point\000Number of transitions from AVX-256 to legacy SSE when penalty applicable\000event=0xc1,period=100003,umask=0x10\000\00000\000\000 */
{ 2464364 }, /* other_assists.sse_to_avx\000\000floating point\000Number of transitions from SSE to AVX-256 when penalty applicable\000event=0xc1,period=100003,umask=0x20\000\00000\000\000 */
{ 2523515 }, /* simd_fp_256.packed_double\000\000floating point\000Number of AVX-256 Computational FP double precision uops issued this cycle\000event=0x11,period=2000003,umask=0x2\000\00000\000\000 */
{ 2523897 }, /* simd_fp_256.packed_single\000\000floating point\000Number of GSSE-256 Computational FP single precision uops issued this cycle\000event=0x11,period=2000003,umask=0x1\000\00000\000\000 */
{ 477106 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1f\000\00000\000\000 */
{ 781845 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000\000 */
{ 785275 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000This event counts the cycles attributed to a switch from the Decoded Stream Buffer (DSB), which holds decoded instructions, to the legacy decode pipeline.  It excludes cycles when the back-end cannot  accept new micro-ops.  The penalty for these switches is potentially several cycles of instruction starvation, where no micro-ops are delivered to the back-end\000 */
{ 786315 }, /* dsb_fill.all_cancel\000\000frontend\000Cases of cancelling valid Decode Stream Buffer (DSB) fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0xa\000\00000\000\000 */
{ 786689 }, /* dsb_fill.exceed_dsb_lines\000\000frontend\000Cycles when Decode Stream Buffer (DSB) fill encounter more than 3 Decode Stream Buffer (DSB) lines\000event=0xac,period=2000003,umask=0x8\000\00000\000\000 */
{ 786865 }, /* dsb_fill.other_cancel\000\000frontend\000Cases of cancelling valid DSB fill not because of exceeding way limit\000event=0xac,period=2000003,umask=0x2\000\00000\000\000 */
{ 986835 }, /* icache.hit\000\000frontend\000Number of Instruction Cache, Streaming Buffer and Victim Cache Reads. both cacheable and noncacheable, including UC fetches\000event=0x80,period=2000003,umask=0x1\000\00000\000\000 */
{ 990163 }, /* icache.misses\000\000frontend\000Instruction cache, streaming buffer and victim cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts the number of instruction cache, streaming buffer and victim cache misses. Counting includes unchacheable accesses\000 */
{ 998803 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000\000 */
{ 999880 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000\000 */
{ 1000957 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000\000 */
{ 1002208 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000\000 */
{ 1003345 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000\000 */
{ 1007144 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000\000 */
{ 1008329 }, /* idq.empty\000\000frontend\000Instruction Decode Queue (IDQ) empty cycles\000event=0x79,period=2000003,umask=0x2\000\00000\000\000 */
{ 1008981 }, /* idq.mite_all_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x3c\000\00000\000\000 */
{ 1010000 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000\000 */
{ 1013205 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000\000 */
{ 1014852 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000This event counts cycles during which the microcode sequencer assisted the front-end in delivering uops.  Microcode assists are used for complex instructions or scenarios that can't be handled by the standard decoder.  Using other instructions, if possible, will usually improve performance.  See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual for more information\000 */
{ 1019000 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1020351 }, /* idq.ms_dsb_occur\000\000frontend\000Deliveries to Instruction Decode Queue (IDQ) initiated by Decode Stream Buffer (DSB) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1021671 }, /* idq.ms_dsb_uops\000\000frontend\000Uops initiated by Decode Stream Buffer (DSB) that are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x10\000\00000\000\000 */
{ 1023239 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000\000 */
{ 1024000 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 1026879 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000\000 */
{ 1030856 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled \000event=0x9c,period=2000003,umask=0x1\000\00000\000This event counts the number of uops not delivered to the back-end per cycle, per thread, when the back-end was not stalled.  In the ideal case 4 uops can be delivered each cycle.  The event counts the undelivered uops - so if 3 were delivered in one cycle, the counter would be incremented by 1 for that cycle (4 - 3). If the back-end is stalled, the count for this event is not incremented even when uops were not delivered, because the back-end would not have been able to accept them.  This event is used in determining the front-end bound category of the top-down pipeline slots characterization\000 */
{ 1035047 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1037850 }, /* idq_uops_not_delivered.cycles_ge_1_uop_deliv.core\000\000frontend\000Cycles when 1 or more uops were delivered to the by the front end\000event=0x9c,cmask=4,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039076 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000\000 */
{ 1039725 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000\000 */
{ 1040296 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1294406 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000This event counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from memory disambiguation, external snoops, or cross SMT-HW-thread snoop (stores) hitting load buffers.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 1369719 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Loads with latency value being above 128 (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000\000 */
{ 1371663 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Loads with latency value being above 16 (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000\000 */
{ 1373605 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Loads with latency value being above 256 (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000\000 */
{ 1375551 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Loads with latency value being above 32 (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000\000 */
{ 1377280 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Loads with latency value being above 4  (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000\000 */
{ 1379423 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Loads with latency value being above 512 (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000\000 */
{ 1381365 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Loads with latency value being above 64 (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000\000 */
{ 1383291 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Loads with latency value being above 8 (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000\000 */
{ 1384715 }, /* mem_trans_retired.precise_store\000\000memory\000Sample stores and collect precise store operation via PEBS record. PMC3 only. (Precise Event - PEBS) (Must be precise)\000event=0xcd,period=2000003,umask=0x2\000\00000\000\000 */
{ 1428803 }, /* misalign_mem_ref.loads\000\000memory\000Speculative cache line split load uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x1\000\00000\000\000 */
{ 1431002 }, /* misalign_mem_ref.stores\000\000memory\000Speculative cache line split STA uops dispatched to L1 cache\000event=0x5,period=2000003,umask=0x2\000\00000\000\000 */
{ 1783265 }, /* offcore_response.all_code_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400244\000\00000\000\000 */
{ 1807120 }, /* offcore_response.all_data_rd.llc_miss.dram\000\000memory\000Counts all demand & prefetch data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400091\000\00000\000\000 */
{ 1817312 }, /* offcore_response.all_pf_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400240\000\00000\000\000 */
{ 1839764 }, /* offcore_response.all_pf_data_rd.llc_miss.dram\000\000memory\000Counts all prefetch data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400090\000\00000\000\000 */
{ 1863112 }, /* offcore_response.all_pf_rfo.llc_miss.dram\000\000memory\000Counts all prefetch RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400120\000\00000\000\000 */
{ 1884101 }, /* offcore_response.all_reads.llc_miss.dram\000\000memory\000Counts all data/code/rfo reads (demand & prefetch) that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3004003f7\000\00000\000\000 */
{ 1911059 }, /* offcore_response.all_rfo.llc_miss.dram\000\000memory\000Counts all demand & prefetch RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400122\000\00000\000\000 */
{ 1970839 }, /* offcore_response.any_request.llc_miss_local.dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80408fff\000\00000\000This event counts any requests that miss the LLC where the data was returned from local DRAM\000 */
{ 2024774 }, /* offcore_response.data_in_socket.llc_miss.local_dram\000\000memory\000Counts LLC replacements\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x6004001b3\000\00000\000This event counts all data requests (demand/prefetch data reads and demand data writes (RFOs) that miss the LLC  where the data is returned from local DRAM\000 */
{ 2025225 }, /* offcore_response.data_in_socket.llc_miss_local.any_llc_hit\000\000memory\000REQUEST = DATA_IN_SOCKET and RESPONSE = LLC_MISS_LOCAL and SNOOP = ANY_LLC_HIT\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x17004001b3\000\00000\000\000 */
{ 2064624 }, /* offcore_response.demand_code_rd.llc_miss.dram\000\000memory\000Counts demand code reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400004\000\00000\000\000 */
{ 2119770 }, /* offcore_response.demand_data_rd.llc_miss.dram\000\000memory\000Counts demand data reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400001\000\00000\000\000 */
{ 2132851 }, /* offcore_response.demand_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400004\000\00000\000\000 */
{ 2178462 }, /* offcore_response.demand_rfo.llc_miss.dram\000\000memory\000Counts demand data writes (RFOs) that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400002\000\00000\000\000 */
{ 2251500 }, /* offcore_response.pf_data_rd.llc_miss_local.dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400010\000\00000\000\000 */
{ 2257533 }, /* offcore_response.pf_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400040\000\00000\000\000 */
{ 2299505 }, /* offcore_response.pf_l2_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to L2) code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400040\000\00000\000\000 */
{ 2329808 }, /* offcore_response.pf_l2_data_rd.llc_miss.dram\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the LLC and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400010\000\00000\000\000 */
{ 2365049 }, /* offcore_response.pf_l2_rfo.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400020\000\00000\000\000 */
{ 2423164 }, /* offcore_response.pf_l_data_rd.llc_miss_local.dram\000\000memory\000REQUEST = PF_LLC_DATA_RD and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400080\000\00000\000\000 */
{ 2423520 }, /* offcore_response.pf_l_ifetch.llc_miss_local.dram\000\000memory\000REQUEST = PF_LLC_IFETCH and RESPONSE = LLC_MISS_LOCAL and SNOOP = DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1f80400200\000\00000\000\000 */
{ 2425706 }, /* offcore_response.pf_llc_code_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) code reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400200\000\00000\000\000 */
{ 2428398 }, /* offcore_response.pf_llc_data_rd.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400080\000\00000\000\000 */
{ 2430350 }, /* offcore_response.pf_llc_rfo.llc_miss.dram\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the LLC  and the data returned from dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x300400100\000\00000\000\000 */
{ 2476088 }, /* page_walks.llc_miss\000\000memory\000Number of any page walk that had a miss in LLC. Does not necessary cause a SUSPEND\000event=0xbe,period=100003,umask=0x1\000\00000\000\000 */
{ 581493 }, /* cpl_cycles.ring0\000\000other\000Unhalted core cycles when the thread is in ring 0\000event=0x5c,period=2000003,umask=0x1\000\00000\000\000 */
{ 582214 }, /* cpl_cycles.ring0_trans\000\000other\000Number of intervals between processor halts while thread is in ring 0\000event=0x5c,cmask=1,edge=1,period=100007,umask=0x1\000\00000\000\000 */
{ 582753 }, /* cpl_cycles.ring123\000\000other\000Unhalted core cycles when thread is in rings 1, 2, or 3\000event=0x5c,period=2000003,umask=0x2\000\00000\000\000 */
{ 979004 }, /* hw_pre_req.dl1_miss\000\000other\000Hardware Prefetch requests that miss the L1D cache. This accounts for both L1 streamer and IP-based (IPP) HW prefetchers. A request is being counted each time it access the cache & miss it, including if a block is applicable or if hit the Fill Buffer for \000event=0x4e,period=2000003,umask=0x2\000\00000\000\000 */
{ 1064704 }, /* insts_written_to_iq.insts\000\000other\000Valid instructions written to IQ per cycle\000event=0x17,period=2000003,umask=0x1\000\00000\000\000 */
{ 1246723 }, /* lock_cycles.split_lock_uc_lock_duration\000\000other\000Cycles when L1 and L2 are locked due to UC or split lock\000event=0x63,period=2000003,umask=0x1\000\00000\000\000 */
{ 465980 }, /* agu_bypass_cancel.count\000\000pipeline\000This event counts executed load operations with all the following traits: 1. addressing of the format [base + offset], 2. the offset is between 1 and 2047, 3. the address specified in the base register is in one page and the address [base+offset] is in an\000event=0xb6,period=100003,umask=0x1\000\00000\000\000 */
{ 469746 }, /* arith.fpu_div\000\000pipeline\000Divide operations executed\000event=0x14,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000This event counts the number of the divide operations executed\000 */
{ 470590 }, /* arith.fpu_div_active\000\000pipeline\000Cycles when divider is busy executing divide operations\000event=0x14,period=2000003,umask=0x1\000\00000\000\000 */
{ 488060 }, /* br_inst_exec.all_branches\000\000pipeline\000Speculative and retired  branches\000event=0x88,period=200003,umask=0xff\000\00000\000\000 */
{ 488587 }, /* br_inst_exec.all_conditional\000\000pipeline\000Speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0xc1\000\00000\000\000 */
{ 489261 }, /* br_inst_exec.all_direct_jmp\000\000pipeline\000Speculative and retired macro-unconditional branches excluding calls and indirects\000event=0x88,period=200003,umask=0xc2\000\00000\000\000 */
{ 489802 }, /* br_inst_exec.all_direct_near_call\000\000pipeline\000Speculative and retired direct near calls\000event=0x88,period=200003,umask=0xd0\000\00000\000\000 */
{ 490448 }, /* br_inst_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0xc4\000\00000\000\000 */
{ 490863 }, /* br_inst_exec.all_indirect_near_return\000\000pipeline\000Speculative and retired indirect return branches\000event=0x88,period=200003,umask=0xc8\000\00000\000\000 */
{ 492202 }, /* br_inst_exec.nontaken_conditional\000\000pipeline\000Not taken macro-conditional branches\000event=0x88,period=200003,umask=0x41\000\00000\000\000 */
{ 492945 }, /* br_inst_exec.taken_conditional\000\000pipeline\000Taken speculative and retired macro-conditional branches\000event=0x88,period=200003,umask=0x81\000\00000\000\000 */
{ 493664 }, /* br_inst_exec.taken_direct_jump\000\000pipeline\000Taken speculative and retired macro-conditional branch instructions excluding calls and indirects\000event=0x88,period=200003,umask=0x82\000\00000\000\000 */
{ 494226 }, /* br_inst_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired direct near calls\000event=0x88,period=200003,umask=0x90\000\00000\000\000 */
{ 494883 }, /* br_inst_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired indirect branches excluding calls and returns\000event=0x88,period=200003,umask=0x84\000\00000\000\000 */
{ 495474 }, /* br_inst_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired indirect calls\000event=0x88,period=200003,umask=0xa0\000\00000\000\000 */
{ 496089 }, /* br_inst_exec.taken_indirect_near_return\000\000pipeline\000Taken speculative and retired indirect branches with return mnemonic\000event=0x88,period=200003,umask=0x88\000\00000\000\000 */
{ 496754 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired\000event=0xc4,period=400009\000\00000\000\000 */
{ 500115 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000\000 */
{ 506119 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000\000 */
{ 508755 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired\000event=0xc4,period=100007,umask=0x40\000\00000\000\000 */
{ 515815 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 517162 }, /* br_inst_retired.near_call_r3\000\000pipeline\000Direct and indirect macro near call instructions retired (captured in ring 3). (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000\000 */
{ 518405 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000\000 */
{ 519851 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000\000 */
{ 522612 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired\000event=0xc4,period=400009,umask=0x10\000\00000\000\000 */
{ 529125 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000\000 */
{ 529734 }, /* br_misp_exec.all_conditional\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xc1\000\00000\000\000 */
{ 529878 }, /* br_misp_exec.all_direct_near_call\000\000pipeline\000Speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0xd0\000\00000\000\000 */
{ 530485 }, /* br_misp_exec.all_indirect_jump_non_call_ret\000\000pipeline\000Mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0xc4\000\00000\000\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 532301 }, /* br_misp_exec.nontaken_conditional\000\000pipeline\000Not taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x41\000\00000\000\000 */
{ 533148 }, /* br_misp_exec.taken_conditional\000\000pipeline\000Taken speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0x81\000\00000\000\000 */
{ 533300 }, /* br_misp_exec.taken_direct_near_call\000\000pipeline\000Taken speculative and retired mispredicted direct near calls\000event=0x89,period=200003,umask=0x90\000\00000\000\000 */
{ 534014 }, /* br_misp_exec.taken_indirect_jump_non_call_ret\000\000pipeline\000Taken speculative and retired mispredicted indirect branches excluding calls and returns\000event=0x89,period=200003,umask=0x84\000\00000\000\000 */
{ 534404 }, /* br_misp_exec.taken_indirect_near_call\000\000pipeline\000Taken speculative and retired mispredicted indirect calls\000event=0x89,period=200003,umask=0xa0\000\00000\000\000 */
{ 535066 }, /* br_misp_exec.taken_return_near\000\000pipeline\000Taken speculative and retired mispredicted indirect branches with return mnemonic\000event=0x89,period=200003,umask=0x88\000\00000\000\000 */
{ 537126 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000\000 */
{ 542028 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000\000 */
{ 546955 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000\000 */
{ 554495 }, /* br_misp_retired.near_call\000\000pipeline\000Direct and indirect mispredicted near call instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=100007,umask=0x2\000\00000\000\000 */
{ 559585 }, /* br_misp_retired.not_taken\000\000pipeline\000Mispredicted not taken branch instructions retired.(Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000\000 */
{ 562905 }, /* br_misp_retired.taken\000\000pipeline\000Mispredicted taken branch instructions retired. (Precise Event - PEBS) (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 607176 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 608338 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000 */
{ 609165 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 618365 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Count XClk pulses when this thread is unhalted and the other thread is halted\000event=0x3c,period=2000003,umask=0x2\000\00000\000\000 */
{ 630691 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000This event counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 639130 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Reference cycles when the thread is unhalted (counts at 100 MHz rate)\000event=0x3c,period=2000003,umask=0x1\000\00000\000\000 */
{ 639929 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Reference cycles when the at least one thread on the physical core is unhalted (counts at 100 MHz rate)\000event=0x3c,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 642083 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 648143 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 749849 }, /* cycle_activity.cycles_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread, increment by 1. Note this is in DCU and connected to Umask 1. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 751456 }, /* cycle_activity.cycles_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 753495 }, /* cycle_activity.cycles_no_dispatch\000\000pipeline\000Each cycle there was no dispatch for this thread, increment by 1. Note this is connect to Umask 2. No dispatch can be deduced from the UOPS_EXECUTED event\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 754960 }, /* cycle_activity.stalls_l1d_pending\000\000pipeline\000Each cycle there was a miss-pending demand load this thread and no uops dispatched, increment by 1. Note this is in DCU and connected to Umask 1 and 2. Miss Pending demand load should be deduced by OR-ing increment bits of DCACHE_MISS_PEND.PENDING\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 756441 }, /* cycle_activity.stalls_l2_pending\000\000pipeline\000Each cycle there was a MLC-miss pending demand load and no uops dispatched on this thread (i.e. Non-completed valid SQ entry allocated for demand load and waiting for Uncore), increment by 1. Note this is in MLC and connected to Umask 0 and 2\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 1040806 }, /* ild_stall.iq_full\000\000pipeline\000Stall cycles because IQ is full\000event=0x87,period=2000003,umask=0x4\000\00000\000\000 */
{ 1042873 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=2000003,umask=0x1\000\00000\000\000 */
{ 1049369 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers\000 */
{ 1054885 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter   - architectural event\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1058954 }, /* inst_retired.prec_dist\000\000pipeline\000Instructions retired. (Precise Event - PEBS) (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000\000 */
{ 1067647 }, /* int_misc.rat_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) external stall is sent to Instruction Decode Queue (IDQ) for the thread\000event=0xd,period=2000003,umask=0x40\000\00000\000\000 */
{ 1070200 }, /* int_misc.recovery_cycles\000\000pipeline\000Number of cycles waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1071258 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,cmask=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1072089 }, /* int_misc.recovery_stalls_count\000\000pipeline\000Number of occurrences waiting for the checkpoints in Resource Allocation Table (RAT) to be recovered after Nuke due to all other cases except JEClear (e.g. whenever a ucode assist is needed like SSE exception, memory disambiguation, etc...)\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x3\000\00000\000\000 */
{ 1192341 }, /* ld_blocks.all_block\000\000pipeline\000Number of cases where any load ends up with a valid block-code written to the load buffer (including blocks due to Memory Order Buffer (MOB), Data Cache Unit (DCU), TLB, but load has no DCU miss)\000event=0x3,period=100003,umask=0x10\000\00000\000\000 */
{ 1193189 }, /* ld_blocks.data_unknown\000\000pipeline\000Loads delayed due to SB blocks, preceding store operations with known addresses but unknown data\000event=0x3,period=100003,umask=0x1\000\00000\000\000 */
{ 1195150 }, /* ld_blocks.no_sr\000\000pipeline\000This event counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000\000 */
{ 1197030 }, /* ld_blocks.store_forward\000\000pipeline\000Cases when loads get true Block-on-Store blocking code preventing store forwarding\000event=0x3,period=100003,umask=0x2\000\00000\000This event counts loads that followed a store to the same address, where the data could not be forwarded inside the pipeline from the store to the load.  The most common reason why store forwarding would be blocked is when a load's address range overlaps with a preceding smaller uncompleted store.  See the table of not supported store forwards in the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual.  The penalty for blocked store forwarding is that the load must wait for the store to complete before it can be issued\000 */
{ 1202912 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare\000event=0x7,period=100003,umask=0x1\000\00000\000Aliasing occurs when a load is issued after a store and their memory addresses are offset by 4K.  This event counts the number of loads that aliased with a preceding store, resulting in an extended address check in the pipeline.  The enhanced address check typically has a performance penalty of 5 cycles\000 */
{ 1203747 }, /* ld_blocks_partial.all_sta_block\000\000pipeline\000This event counts the number of times that load operations are temporarily blocked because of older stores, with addresses that are not yet known. A load operation may incur more than one block of this type\000event=0x7,period=100003,umask=0x8\000\00000\000\000 */
{ 1229615 }, /* load_hit_pre.hw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for hardware prefetch\000event=0x4c,period=100003,umask=0x2\000\00000\000\000 */
{ 1230906 }, /* load_hit_pre.sw_pf\000\000pipeline\000Not software-prefetch load dispatches that hit FB allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000\000 */
{ 1283818 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000\000 */
{ 1284404 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1286487 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1293258 }, /* machine_clears.maskmov\000\000pipeline\000This event counts the number of executed Intel AVX masked load operations that refer to an illegal address range with the mask bits set to 0\000event=0xc3,period=100003,umask=0x20\000\00000\000Maskmov false fault - counts number of time ucode passes through Maskmov flow due to instruction's mask being 0 while the flow was completed without raising a fault\000 */
{ 1301984 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000This event is incremented when self-modifying code (SMC) is detected, which causes a machine clear.  Machine clears can have a significant performance impact if they are happening frequently\000 */
{ 2463776 }, /* other_assists.itlb_miss_retired\000\000pipeline\000Retired instructions experiencing ITLB misses\000event=0xc1,period=100003,umask=0x2\000\00000\000\000 */
{ 2477071 }, /* partial_rat_stalls.flags_merge_uop\000\000pipeline\000Increments the number of flags-merge uops in flight each cycle\000event=0x59,period=2000003,umask=0x20\000\00000\000\000 */
{ 2477221 }, /* partial_rat_stalls.flags_merge_uop_cycles\000\000pipeline\000Performance sensitive flags-merging uops added by Sandy Bridge u-arch\000event=0x59,cmask=1,period=2000003,umask=0x20\000\00000\000This event counts the number of cycles spent executing performance-sensitive flags-merging uops. For example, shift CL (merge_arith_flags). For more details, See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual\000 */
{ 2478025 }, /* partial_rat_stalls.mul_single_uop\000\000pipeline\000Multiply packed/scalar single precision uops allocated\000event=0x59,period=2000003,umask=0x80\000\00000\000\000 */
{ 2478390 }, /* partial_rat_stalls.slow_lea_window\000\000pipeline\000Cycles with at least one slow LEA uop being allocated\000event=0x59,period=2000003,umask=0x40\000\00000\000This event counts the number of cycles with at least one slow LEA uop being allocated. A uop is generally considered as slow LEA if it has three sources (for example, two sources and immediate) regardless of whether it is a result of LEA instruction or not. Examples of the slow LEA uop are or uops with base, index, and offset source operands using base and index reqisters, where base is EBR/RBP/R13, using RIP relative or 16-bit addressing modes. See the Intel(R) 64 and IA-32 Architectures Optimization Reference Manual for more details about slow LEA instructions\000 */
{ 2501812 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000\000 */
{ 2502138 }, /* resource_stalls.lb\000\000pipeline\000Counts the cycles of stall due to lack of load buffers\000event=0xa2,period=2000003,umask=0x2\000\00000\000\000 */
{ 2502263 }, /* resource_stalls.lb_sb\000\000pipeline\000Resource stalls due to load or store buffers all being in use\000event=0xa2,period=2000003,umask=0xa\000\00000\000\000 */
{ 2502495 }, /* resource_stalls.mem_rs\000\000pipeline\000Resource stalls due to memory buffers or Reservation Station (RS) being fully utilized\000event=0xa2,period=2000003,umask=0xe\000\00000\000\000 */
{ 2502756 }, /* resource_stalls.ooo_rsrc\000\000pipeline\000Resource stalls due to Rob being full, FCSW, MXCSR and OTHER\000event=0xa2,period=2000003,umask=0xf0\000\00000\000\000 */
{ 2503244 }, /* resource_stalls.rob\000\000pipeline\000Cycles stalled due to re-order buffer full\000event=0xa2,period=2000003,umask=0x10\000\00000\000\000 */
{ 2504009 }, /* resource_stalls.rs\000\000pipeline\000Cycles stalled due to no eligible RS entry available\000event=0xa2,period=2000003,umask=0x4\000\00000\000\000 */
{ 2505724 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000\000 */
{ 2506644 }, /* resource_stalls2.all_fl_empty\000\000pipeline\000Cycles with either free list is empty\000event=0x5b,period=2000003,umask=0xc\000\00000\000\000 */
{ 2506763 }, /* resource_stalls2.all_prf_control\000\000pipeline\000Resource stalls2 control structures full for physical registers\000event=0x5b,period=2000003,umask=0xf\000\00000\000\000 */
{ 2506911 }, /* resource_stalls2.bob_full\000\000pipeline\000Cycles when Allocator is stalled if BOB is full and new branch needs it\000event=0x5b,period=2000003,umask=0x40\000\00000\000\000 */
{ 2507061 }, /* resource_stalls2.ooo_rsrc\000\000pipeline\000Resource stalls out of order resources full\000event=0x5b,period=2000003,umask=0x4f\000\00000\000\000 */
{ 2507718 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Count cases of saving new LBR\000event=0xcc,period=2000003,umask=0x20\000\00000\000\000 */
{ 2512104 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000\000 */
{ 2512599 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6179412 }, /* uops_dispatched.core\000\000pipeline\000Uops dispatched from any thread\000event=0xb1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6183531 }, /* uops_dispatched.thread\000\000pipeline\000Uops dispatched per thread\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6183883 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are dispatched to port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6184850 }, /* uops_dispatched_port.port_0_core\000\000pipeline\000Cycles per core when uops are dispatched to port 0\000event=0xa1,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6185165 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are dispatched to port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6186132 }, /* uops_dispatched_port.port_1_core\000\000pipeline\000Cycles per core when uops are dispatched to port 1\000event=0xa1,any=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6186459 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 2\000event=0xa1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187247 }, /* uops_dispatched_port.port_2_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 2\000event=0xa1,any=1,period=2000003,umask=0xc\000\00000\000\000 */
{ 6187756 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when load or STA uops are dispatched to port 3\000event=0xa1,period=2000003,umask=0x30\000\00000\000\000 */
{ 6188761 }, /* uops_dispatched_port.port_3_core\000\000pipeline\000Cycles per core when load or STA uops are dispatched to port 3\000event=0xa1,any=1,period=2000003,umask=0x30\000\00000\000\000 */
{ 6189090 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are dispatched to port 4\000event=0xa1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6190062 }, /* uops_dispatched_port.port_4_core\000\000pipeline\000Cycles per core when uops are dispatched to port 4\000event=0xa1,any=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 6190379 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are dispatched to port 5\000event=0xa1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6191351 }, /* uops_dispatched_port.port_5_core\000\000pipeline\000Cycles per core when uops are dispatched to port 5\000event=0xa1,any=1,period=2000003,umask=0x80\000\00000\000\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198933 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6214840 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000This event counts the number of Uops issued by the front-end of the pipeilne to the back-end\000 */
{ 6216475 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for all threads\000event=0xe,any=1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6220517 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6226091 }, /* uops_retired.all\000\000pipeline\000Actually retired uops. (Precise Event - PEBS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired. (Precise Event) (Precise event)\000 */
{ 6228167 }, /* uops_retired.core_stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6235108 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used. (Precise Event - PEBS) (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000This event counts the number of retirement slots used each cycle.  There are potentially 4 slots that can be used each cycle - meaning, 4 micro-ops or 4 instructions could retire each cycle.  This event is used in determining the 'Retiring' category of the Top-Down pipeline slots characterization. (Precise Event - PEBS) (Precise event)\000 */
{ 6238574 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6240056 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 2784864 }, /* unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000\000 */
{ 2785265 }, /* unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000\000 */
{ 2785660 }, /* unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000\000 */
{ 2786064 }, /* unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000\000 */
{ 2786235 }, /* unc_cbo_cache_lookup.extsnp_es\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x46\000\00001\000\000 */
{ 2786420 }, /* unc_cbo_cache_lookup.extsnp_i\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x48\000\00001\000\000 */
{ 2786599 }, /* unc_cbo_cache_lookup.extsnp_m\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x41\000\00001\000\000 */
{ 2786778 }, /* unc_cbo_cache_lookup.extsnp_mesi\000uncore_cbox\000uncore cache\000L3 Lookup external snoop request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x4f\000\00001\000\000 */
{ 2787207 }, /* unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000\000 */
{ 2787613 }, /* unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000\000 */
{ 2788013 }, /* unc_cbo_cache_lookup.read_m\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x11\000\00001\000\000 */
{ 2788430 }, /* unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000\000 */
{ 2788854 }, /* unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000\000 */
{ 2789029 }, /* unc_cbo_cache_lookup.write_i\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x28\000\00001\000\000 */
{ 2789434 }, /* unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000\000 */
{ 2789848 }, /* unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000\000 */
{ 2790023 }, /* unc_cbo_xsnp_response.hit_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x84\000\00001\000\000 */
{ 2790229 }, /* unc_cbo_xsnp_response.hit_external\000uncore_cbox\000uncore cache\000An external snoop hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x24\000\00001\000\000 */
{ 2790402 }, /* unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000 */
{ 2790639 }, /* unc_cbo_xsnp_response.hitm_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x88\000\00001\000\000 */
{ 2790842 }, /* unc_cbo_xsnp_response.hitm_external\000uncore_cbox\000uncore cache\000An external snoop hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x28\000\00001\000\000 */
{ 2791012 }, /* unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000 */
{ 2791246 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000 */
{ 2791698 }, /* unc_cbo_xsnp_response.miss_external\000uncore_cbox\000uncore cache\000An external snoop misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x21\000\00001\000\000 */
{ 2791854 }, /* unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000 */
{ 2581513 }, /* unc_arb_coh_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Cycles weighted by number of requests pending in Coherency Tracker. Unit: uncore_arb \000event=0x83,umask=0x1\000\00001\000\000 */
{ 2582567 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of requests allocated in Coherency Tracker. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2585257 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Counts cycles weighted by the number of requests waiting for data returning from the memory controller. Accounts for coherent and non-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2587134 }, /* unc_arb_trk_occupancy.cycles_over_half_full\000uncore_arb\000uncore interconnect\000Cycles with at least half of the requests outstanding are waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=10,umask=0x1\000\00001\000\000 */
{ 2587471 }, /* unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000 */
{ 2589625 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000Counts the number of coherent and in-coherent requests initiated by IA cores, processor graphic units, or LLC. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591061 }, /* unc_arb_trk_requests.evictions\000uncore_arb\000uncore interconnect\000Counts the number of LLC evictions allocated. Unit: uncore_arb \000event=0x81,umask=0x80\000\00001\000\000 */
{ 2591683 }, /* unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Counts the number of allocated write entries, include full, partial, and LLC evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000 */
{ 3540250 }, /* unc_clock.socket\000uncore_arb\000uncore interconnect\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_arb \000event=0xff\000\00001\000\000 */
{ 788831 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000\000 */
{ 790162 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Load operations that miss the first DTLB level but hit the second and do not cause page walks\000event=0x8,period=100003,umask=0x10\000\00000\000This event counts load operations that miss the first DTLB level but hit the second and do not cause any page walks. The penalty in this case is approximately 7 cycles\000 */
{ 796139 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load misses at all DTLB levels that cause completed page walks\000event=0x8,period=100003,umask=0x2\000\00000\000\000 */
{ 806696 }, /* dtlb_load_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x8,period=2000003,umask=0x4\000\00000\000This event counts cycles when the  page miss handler (PMH) is servicing page walks caused by DTLB load misses\000 */
{ 811205 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000\000 */
{ 812322 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Store operations that miss the first TLB level but hit the second and do not cause page walks\000event=0x49,period=100003,umask=0x10\000\00000\000\000 */
{ 817324 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all DTLB levels that cause completed page walks\000event=0x49,period=100003,umask=0x2\000\00000\000\000 */
{ 828893 }, /* dtlb_store_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x49,period=2000003,umask=0x4\000\00000\000\000 */
{ 832947 }, /* ept.walk_cycles\000\000virtual memory\000Cycle count for an Extended Page table walk.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000event=0x4f,period=2000003,umask=0x10\000\00000\000\000 */
{ 1078837 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000\000 */
{ 1081578 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000\000 */
{ 1083245 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Operations that miss the first ITLB level but hit the second and do not cause any page walks\000event=0x85,period=100003,umask=0x10\000\00000\000\000 */
{ 1087846 }, /* itlb_misses.walk_completed\000\000virtual memory\000Misses in all ITLB levels that cause completed page walks\000event=0x85,period=100003,umask=0x2\000\00000\000\000 */
{ 1096448 }, /* itlb_misses.walk_duration\000\000virtual memory\000Cycles when PMH is busy with page walks\000event=0x85,period=2000003,umask=0x4\000\00000\000This event count cycles when Page Miss Handler (PMH) is servicing page walks caused by ITLB misses\000 */
{ 2540903 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000\000 */
{ 2541700 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__sandybridge[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 62006 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - (tma_frontend_bound + tma_bad_speculation + tma_retiring)\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00002 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 71007 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73206 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\00012 * (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT + BACLEARS.ANY) / tma_info_thread_clks\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 117798 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.FPU_DIV_ACTIVE / tma_info_core_core_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_UOPS\000100%\000\000\000\00000 */
{ 120256 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(1 - MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_MISC_RETIRED.LLC_MISS)) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_MISS_PS\000100%\000\000\000\00003 */
{ 126842 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Related metrics: tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000\000\00000 */
{ 130701 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000(7 * DTLB_LOAD_MISSES.STLB_HIT + DTLB_LOAD_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_dtlb_load > 0.1\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_UOPS_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store\000100%\000\000\000\00000 */
{ 159852 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Related metrics: tma_dsb_switches, tma_info_frontend_dsb_coverage, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 165697 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * min(CPU_CLK_UNHALTED.THREAD, IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: RS_EVENTS.EMPTY_END\000100%\000\000TopdownL2\000\00000 */
{ 169131 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00000 */
{ 170835 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 174074 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) / UOPS_DISPATCHED.THREAD\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_512b, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 188788 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound\000100%\000\000TopdownL1\000\00000 */
{ 193003 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219516 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00000 */
{ 223534 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_DISPATCHED.THREAD / (cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@ / 2 if #SMT_on else cpu@UOPS_DISPATCHED.CORE\\,cmask\\=1@)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 225687 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + LSD.UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_lcp\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257973 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_mem_bandwidth\000\000\000\000\00000 */
{ 261800 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_COMP_OPS_EXE.SSE_SCALAR_SINGLE + FP_COMP_OPS_EXE.SSE_SCALAR_DOUBLE + 2 * FP_COMP_OPS_EXE.SSE_PACKED_DOUBLE + 4 * (FP_COMP_OPS_EXE.SSE_PACKED_SINGLE + SIMD_FP_256.PACKED_DOUBLE) + 8 * SIMD_FP_256.PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 267776 }, /* \000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000 */
{ 271339 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276493 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_DISPATCHED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 281284 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(12 * ITLB_MISSES.STLB_HIT + ITLB_MISSES.WALK_DURATION) / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: ITLB_MISSES.WALK_COMPLETED\000100%\000\000\000\00000 */
{ 296986 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_UOPS_RETIRED.LLC_HIT / (MEM_LOAD_UOPS_RETIRED.LLC_HIT + 7 * MEM_LOAD_UOPS_MISC_RETIRED.LLC_MISS) * CYCLE_ACTIVITY.STALLS_L2_PENDING / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_UOPS_RETIRED.L3_HIT_PS\000100%\000\000\000\00003 */
{ 312331 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 331622 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 336602 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=6@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_info_system_dram_bw_use\000100%\000\000\000\00000 */
{ 337674 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: \000100%\000\000\000\00000 */
{ 345532 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING) + RESOURCE_STALLS.SB) / (min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 396135 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000(min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.CYCLES_NO_DISPATCH) + cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=1@ - (cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=3@ if tma_info_thread_ipc > 1.8 else cpu@UOPS_DISPATCHED.THREAD\\,cmask\\=2@) - (RS_EVENTS.EMPTY_CYCLES if tma_fetch_latency > 0.1 else 0) + RESOURCE_STALLS.SB - RESOURCE_STALLS.SB - min(CPU_CLK_UNHALTED.THREAD, CYCLE_ACTIVITY.STALLS_L1D_PENDING)) / tma_info_thread_clks\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00001 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 449269 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000RESOURCE_STALLS.SB / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_UOPS_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 462958 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000UOPS_RETIRED.RETIRE_SLOTS * FP_COMP_OPS_EXE.X87 / UOPS_DISPATCHED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__sapphirerapids[] = {
{ 1100287 }, /* l1d.hwpf_miss\000\000cache\000L1D.HWPF_MISS\000event=0x51,period=1000003,umask=0x20\000\00000\000\000 */
{ 1100860 }, /* l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105377 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106609 }, /* l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107717 }, /* l1d_pend_miss.l2_stall\000\000cache\000This event is deprecated. Refer to new event L1D_PEND_MISS.L2_STALLS\000event=0x48,period=1000003,umask=0x4\000\00010\000\000 */
{ 1108022 }, /* l1d_pend_miss.l2_stalls\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1110782 }, /* l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112359 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1128536 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0x25,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1134329 }, /* l2_lines_out.non_silent\000\000cache\000L2_LINES_OUT.NON_SILENT\000event=0x26,period=200003,umask=0x2\000\00000\000\000 */
{ 1136642 }, /* l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0x26,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1137693 }, /* l2_lines_out.useless_hwpf\000\000cache\000Cache lines that have been L2 hardware prefetched but not used by demand accesses\000event=0x26,period=200003,umask=0x4\000\00000\000Counts the number of cache lines that have been prefetched by the L2 hardware prefetcher but not used by demand access when evicted from the L2 cache\000 */
{ 1149610 }, /* l2_request.all\000\000cache\000All accesses to L2 cache [This event is alias to L2_RQSTS.REFERENCES]\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.REFERENCES]\000 */
{ 1151397 }, /* l2_request.miss\000\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_RQSTS.MISS]\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_RQSTS.MISS]\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1157738 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read access L2 cache\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1159594 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Counts demand requests that miss L2 cache\000 */
{ 1160355 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Counts demand requests to L2 cache\000 */
{ 1160903 }, /* l2_rqsts.all_hwpf\000\000cache\000L2_RQSTS.ALL_HWPF\000event=0x24,period=200003,umask=0xf0\000\00000\000\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165401 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1166073 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2 cache\000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1167527 }, /* l2_rqsts.hwpf_miss\000\000cache\000L2_RQSTS.HWPF_MISS\000event=0x24,period=200003,umask=0x30\000\00000\000\000 */
{ 1169568 }, /* l2_rqsts.miss\000\000cache\000Read requests with true-miss in L2 cache. [This event is alias to L2_REQUEST.MISS]\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.MISS]\000 */
{ 1172816 }, /* l2_rqsts.references\000\000cache\000All accesses to L2 cache [This event is alias to L2_REQUEST.ALL]\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. [This event is alias to L2_REQUEST.ALL]\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177137 }, /* l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177638 }, /* l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1251955 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable requests that refer to L3 (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312052 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315394 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1319441 }, /* mem_load_completed.l1_miss_any\000\000cache\000Completed demand load uops that miss the L1 d-cache\000event=0x43,period=1000003,umask=0xfd\000\00000\000Number of completed demand load requests that missed the L1 data cache including shadow misses (FB hits, merge to an ongoing L1D miss)\000 */
{ 1319998 }, /* mem_load_l3_hit_retired.xsnp_fwd\000\000cache\000Retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions whose data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1324093 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1324910 }, /* mem_load_l3_hit_retired.xsnp_no_fwd\000\000cache\000Retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions whose data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1326535 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327262 }, /* mem_load_l3_miss_retired.local_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1327975 }, /* mem_load_l3_miss_retired.remote_dram\000\000cache\000MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM  Supports address when precise (Precise event)\000event=0xd3,period=1000003,umask=0x2\000\00000\000\000 */
{ 1328360 }, /* mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000 */
{ 1328996 }, /* mem_load_l3_miss_retired.remote_hitm\000\000cache\000MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM  Supports address when precise (Precise event)\000event=0xd3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1329971 }, /* mem_load_l3_miss_retired.remote_pmm\000\000cache\000Retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches\000event=0xd3,period=100007,umask=0x10\000\00000\000Counts retired load instructions with remote Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3\000 */
{ 1331036 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access (Bus Lock)  Supports address when precise (Precise event)\000 */
{ 1332237 }, /* mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1333977 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335514 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336567 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337424 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338416 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339662 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1340577 }, /* mem_load_retired.local_pmm\000\000cache\000Retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source where the data request missed all caches  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x80\000\00000\000Counts retired load instructions with local Intel(R) Optane(TM) DC persistent memory as the data source and the data request missed L3  Supports address when precise (Precise event)\000 */
{ 1368816 }, /* mem_store_retired.l2_hit\000\000cache\000MEM_STORE_RETIRED.L2_HIT\000event=0x44,period=200003,umask=0x1\000\00000\000\000 */
{ 1387614 }, /* mem_uop_retired.any\000\000cache\000Retired memory uops for any access\000event=0xe5,period=1000003,umask=0x3\000\00000\000Number of retired micro-operations (uops) for load or store memory accesses\000 */
{ 1521693 }, /* ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000 */
{ 1519224 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1535508 }, /* ocr.demand_code_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000004\000\00000\000\000 */
{ 1536222 }, /* ocr.demand_code_rd.snc_cache.hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000004\000\00000\000\000 */
{ 1551692 }, /* ocr.demand_data_rd.l3_hit\000\000cache\000Counts demand data reads that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 1545640 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads that resulted in a snoop that hit in another core, which did not forward the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1546796 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1548886 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1566844 }, /* ocr.demand_data_rd.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x830000001\000\00000\000\000 */
{ 1567440 }, /* ocr.demand_data_rd.remote_cache.snoop_hitm\000\000cache\000Counts demand data reads that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1030000001\000\00000\000\000 */
{ 1568706 }, /* ocr.demand_data_rd.snc_cache.hit_with_fwd\000\000cache\000Counts demand data reads that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000001\000\00000\000\000 */
{ 1569330 }, /* ocr.demand_data_rd.snc_cache.hitm\000\000cache\000Counts demand data reads that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000001\000\00000\000\000 */
{ 1581115 }, /* ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 1577566 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1598100 }, /* ocr.demand_rfo.snc_cache.hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808000002\000\00000\000\000 */
{ 1598884 }, /* ocr.demand_rfo.snc_cache.hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008000002\000\00000\000\000 */
{ 1620458 }, /* ocr.hwpf_l3.l3_hit\000\000cache\000Counts hardware prefetches to the L3 only that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x80082380\000\00000\000\000 */
{ 1723827 }, /* ocr.reads_to_core.l3_hit\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F003C4477\000\00000\000\000 */
{ 1720236 }, /* ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop that hit in another core, which did not forward the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x4003C4477\000\00000\000\000 */
{ 1721199 }, /* ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x8003C4477\000\00000\000\000 */
{ 1722240 }, /* ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that resulted in a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10003C4477\000\00000\000\000 */
{ 1731529 }, /* ocr.reads_to_core.remote_cache.snoop_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop was sent and data was returned (Modified or Not Modified)\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1830004477\000\00000\000\000 */
{ 1732245 }, /* ocr.reads_to_core.remote_cache.snoop_hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit in another core's caches which forwarded the unmodified data to the requesting core\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x830004477\000\00000\000\000 */
{ 1733037 }, /* ocr.reads_to_core.remote_cache.snoop_hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by a cache on a remote socket where a snoop hit a modified line in another core's caches which forwarded the data\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1030004477\000\00000\000\000 */
{ 1735467 }, /* ocr.reads_to_core.snc_cache.hit_with_fwd\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that either hit a non-modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x808004477\000\00000\000\000 */
{ 1736287 }, /* ocr.reads_to_core.snc_cache.hitm\000\000cache\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that hit a modified line in a distant L3 Cache or were snooped from a distant core's L1/L2 caches on this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1008004477\000\00000\000\000 */
{ 1738104 }, /* ocr.rfo_to_core.l3_hit_m\000\000cache\000Counts demand reads for ownership (RFO), hardware prefetch RFOs (which bring data to L2), and software prefetches for exclusive ownership (PREFETCHW) that hit to a (M)odified cacheline in the L3 or snoop filter\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x1F80040022\000\00000\000\000 */
{ 1739403 }, /* ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that hit in the L3 or were snooped from another core's caches on the same socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x80080800\000\00000\000\000 */
{ 1746586 }, /* offcore_requests.all_requests\000\000cache\000OFFCORE_REQUESTS.ALL_REQUESTS\000event=0x21,period=100003,umask=0x80\000\00000\000\000 */
{ 1747380 }, /* offcore_requests.data_rd\000\000cache\000Demand and prefetch data reads\000event=0x21,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1749731 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0x21,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1757318 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000This event is deprecated. Refer to new event OFFCORE_REQUESTS_OUTSTANDING.DATA_RD\000event=0x20,period=1000003,umask=0x8\000\00010\000\000 */
{ 1760989 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000event=0x20,cmask=1,period=1000003,umask=0x8\000\00000\000\000 */
{ 1764398 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles where at least 1 outstanding demand data read request is pending\000event=0x20,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1766321 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO\000event=0x20,cmask=1,period=1000003,umask=0x4\000\00000\000\000 */
{ 1768754 }, /* offcore_requests_outstanding.data_rd\000\000cache\000OFFCORE_REQUESTS_OUTSTANDING.DATA_RD\000event=0x20,period=1000003,umask=0x8\000\00000\000\000 */
{ 1772346 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000For every cycle, increments by the number of outstanding demand data read requests pending\000event=0x20,period=1000003,umask=0x1\000\00000\000For every cycle, increments by the number of outstanding demand data read requests pending.   Requests are considered outstanding from the time they miss the core's L2 cache until the transaction completion message is sent to the requestor\000 */
{ 2530354 }, /* sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0x2c,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2537419 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x40,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2538069 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x40,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538712 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x40,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539393 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x40,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 469342 }, /* arith.fpdiv_active\000\000floating point\000ARITH.FPDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 472289 }, /* assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 472901 }, /* assists.sse_avx_mix\000\000floating point\000ASSISTS.SSE_AVX_MIX\000event=0xc1,period=1000003,umask=0x10\000\00000\000\000 */
{ 853608 }, /* fp_arith_dispatched.port_0\000\000floating point\000FP_ARITH_DISPATCHED.PORT_0\000event=0xb3,period=2000003,umask=0x1\000\00000\000\000 */
{ 853855 }, /* fp_arith_dispatched.port_1\000\000floating point\000FP_ARITH_DISPATCHED.PORT_1\000event=0xb3,period=2000003,umask=0x2\000\00000\000\000 */
{ 854102 }, /* fp_arith_dispatched.port_5\000\000floating point\000FP_ARITH_DISPATCHED.PORT_5\000event=0xb3,period=2000003,umask=0x4\000\00000\000\000 */
{ 854349 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 860385 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 862608 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 866643 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 872056 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 875751 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 878977 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 883416 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 886310 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 890230 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 893916 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898161 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000Number of any Vector retired FP arithmetic instructions.  The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 899038 }, /* fp_arith_inst_retired2.128b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.128B_PACKED_HALF\000event=0xcf,period=100003,umask=0x4\000\00000\000\000 */
{ 899682 }, /* fp_arith_inst_retired2.256b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.256B_PACKED_HALF\000event=0xcf,period=100003,umask=0x8\000\00000\000\000 */
{ 900325 }, /* fp_arith_inst_retired2.512b_packed_half\000\000floating point\000FP_ARITH_INST_RETIRED2.512B_PACKED_HALF\000event=0xcf,period=100003,umask=0x10\000\00000\000\000 */
{ 900970 }, /* fp_arith_inst_retired2.complex_scalar_half\000\000floating point\000FP_ARITH_INST_RETIRED2.COMPLEX_SCALAR_HALF\000event=0xcf,period=100003,umask=0x2\000\00000\000\000 */
{ 901112 }, /* fp_arith_inst_retired2.scalar\000\000floating point\000Number of all Scalar Half-Precision FP arithmetic instructions(1) retired - regular and complex\000event=0xcf,period=100003,umask=0x3\000\00000\000FP_ARITH_INST_RETIRED2.SCALAR\000 */
{ 901323 }, /* fp_arith_inst_retired2.scalar_half\000\000floating point\000FP_ARITH_INST_RETIRED2.SCALAR_HALF\000event=0xcf,period=100003,umask=0x1\000\00000\000\000 */
{ 901449 }, /* fp_arith_inst_retired2.vector\000\000floating point\000Number of all Vector (also called packed) Half-Precision FP arithmetic instructions(1) retired\000event=0xcf,period=100003,umask=0x1c\000\00000\000FP_ARITH_INST_RETIRED2.VECTOR\000 */
{ 474957 }, /* baclears.any\000\000frontend\000Clears due to Unknown Branches\000event=0x60,period=100003,umask=0x1\000\00000\000Number of times the front-end is resteered when it finds a branch instruction in a fetch line. This is called Unknown Branch which occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 776295 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk\000 */
{ 777366 }, /* decode.ms_busy\000\000frontend\000Cycles the Microcode Sequencer is busy\000event=0x87,period=500009,umask=0x2\000\00000\000\000 */
{ 782202 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0x61,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943187 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944203 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 950227 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 945682 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x608006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 948062 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x601006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 953980 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 952142 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x610006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 958574 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x602006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 960740 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 962943 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x620006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 965159 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x604006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967524 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x600806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969163 }, /* frontend_retired.ms_flows\000\000frontend\000FRONTEND_RETIRED.MS_FLOWS (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x8\000\00000\000\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 970163 }, /* frontend_retired.unknown_branch\000\000frontend\000FRONTEND_RETIRED.UNKNOWN_BRANCH (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x17\000\00000\000\000 */
{ 995283 }, /* icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The decode pipeline works at a 32 Byte granularity\000 */
{ 996743 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss\000 */
{ 1003938 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1004838 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=6,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1006310 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010161 }, /* idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1011207 }, /* idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=6,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1012316 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1016716 }, /* idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x20\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024194 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x20\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1024933 }, /* idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=1000003,umask=0x20\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS)\000 */
{ 1029922 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1035701 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=6,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036953 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 757545 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 1296966 }, /* machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1384915 }, /* mem_trans_retired.store_sample\000\000memory\000Retired memory store access operations. A PDist event for PEBS Store Latency Facility  Supports address when precise (Must be precise)\000event=0xcd,period=1000003,umask=0x2\000\00000\000Counts Retired memory accesses with at least 1 store operation. This PEBS event is the precisely-distributed (PDist) trigger covering all stores uops for sampling by the PEBS Store Latency Facility. The facility is described in Intel SDM Volume 3 section 19.9.8  Supports address when precise (Must be precise)\000 */
{ 1425360 }, /* memory_activity.cycles_l1d_miss\000\000memory\000Cycles while L1 cache miss demand load is outstanding\000event=0x47,cmask=2,period=1000003,umask=0x2\000\00000\000\000 */
{ 1425671 }, /* memory_activity.stalls_l1d_miss\000\000memory\000Execution stalls while L1 cache miss demand load is outstanding\000event=0x47,cmask=3,period=1000003,umask=0x3\000\00000\000\000 */
{ 1426002 }, /* memory_activity.stalls_l2_miss\000\000memory\000Execution stalls while L2 cache miss demand cacheable load request is outstanding\000event=0x47,cmask=5,period=1000003,umask=0x5\000\00000\000Execution stalls while L2 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1426655 }, /* memory_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand cacheable load request is outstanding\000event=0x47,cmask=9,period=1000003,umask=0x9\000\00000\000Execution stalls while L3 cache miss demand cacheable load request is outstanding (will not count for uncacheable demand requests e.g. bus lock)\000 */
{ 1529618 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00004\000\00000\000\000 */
{ 1559769 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1589704 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FC00002\000\00000\000\000 */
{ 1620882 }, /* ocr.hwpf_l3.l3_miss\000\000memory\000Counts hardware prefetches to the L3 only that missed the local socket's L1, L2, and L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x94002380\000\00000\000\000 */
{ 1621254 }, /* ocr.hwpf_l3.l3_miss_local\000\000memory\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x84002380\000\00000\000\000 */
{ 1724675 }, /* ocr.reads_to_core.l3_miss\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FC04477\000\00000\000\000 */
{ 1725503 }, /* ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F04C04477\000\00000\000\000 */
{ 1726422 }, /* ocr.reads_to_core.l3_miss_local_socket\000\000memory\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that missed the L3 Cache and were supplied by the local socket (DRAM or PMM), whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM or DRAM accesses that are controlled by the close or distant SNC Cluster.  It does not count misses to the L3 which go to Local CXL Type 2 Memory or Local Non DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x70CC04477\000\00000\000\000 */
{ 1739956 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that missed the local socket's L1, L2, and L3 caches\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x94000800\000\00000\000\000 */
{ 1740790 }, /* ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline is homed locally\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x84000800\000\00000\000\000 */
{ 1752271 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Counts demand data read requests that miss the L3 cache\000event=0x21,period=100003,umask=0x10\000\00000\000\000 */
{ 1778929 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache\000event=0x20,period=2000003,umask=0x10\000\00000\000For every cycle, increments by the number of demand data read requests pending that are known to have missed the L3 cache.  Note that this does not capture all elapsed cycles while requests are outstanding - only cycles from when the requests were known by the requesting core to have missed the L3 cache\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2515369 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2515927 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516525 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519396 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 472704 }, /* assists.page_fault\000\000other\000ASSISTS.PAGE_FAULT\000event=0xc1,period=1000003,umask=0x8\000\00000\000\000 */
{ 844678 }, /* exe.amx_busy\000\000other\000Counts the cycles where the AMX (Advance Matrix Extension) unit is busy performing an operation\000event=0xb7,period=2000003,umask=0x2\000\00000\000\000 */
{ 1515366 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1515962 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000004\000\00000\000\000 */
{ 1534010 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000 */
{ 1536900 }, /* ocr.demand_code_rd.snc_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000004\000\00000\000\000 */
{ 1542449 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1543455 }, /* ocr.demand_data_rd.dram\000\000other\000Counts demand data reads that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000001\000\00000\000\000 */
{ 1564819 }, /* ocr.demand_data_rd.local_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 1567986 }, /* ocr.demand_data_rd.remote_dram\000\000other\000Counts demand data reads that were supplied by DRAM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x730000001\000\00000\000\000 */
{ 1568348 }, /* ocr.demand_data_rd.remote_pmm\000\000other\000Counts demand data reads that were supplied by PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x703000001\000\00000\000\000 */
{ 1569918 }, /* ocr.demand_data_rd.snc_dram\000\000other\000Counts demand data reads that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000001\000\00000\000\000 */
{ 1572300 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FFC0002\000\00000\000\000 */
{ 1573974 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C000002\000\00000\000\000 */
{ 1595540 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000 */
{ 1599632 }, /* ocr.demand_rfo.snc_dram\000\000other\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708000002\000\00000\000\000 */
{ 1602729 }, /* ocr.hwpf_l1d.any_response\000\000other\000Counts data load hardware prefetch requests to the L1 data cache that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1606685 }, /* ocr.hwpf_l2.any_response\000\000other\000Counts hardware prefetches (which bring data to L2) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10070\000\00000\000\000 */
{ 1619930 }, /* ocr.hwpf_l3.any_response\000\000other\000Counts hardware prefetches to the L3 only that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x12380\000\00000\000\000 */
{ 1621734 }, /* ocr.hwpf_l3.remote\000\000other\000Counts hardware prefetches to the L3 only that were not supplied by the local socket's L1, L2, or L3 caches and the cacheline was homed in a remote socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x90002380\000\00000\000\000 */
{ 1624264 }, /* ocr.modified_write.any_response\000\000other\000Counts writebacks of modified cachelines and streaming stores that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10808\000\00000\000\000 */
{ 1718756 }, /* ocr.reads_to_core.any_response\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F3FFC4477\000\00000\000\000 */
{ 1719513 }, /* ocr.reads_to_core.dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x73C004477\000\00000\000\000 */
{ 1727425 }, /* ocr.reads_to_core.local_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, unless in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts only those DRAM accesses that are controlled by the close SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x104004477\000\00000\000\000 */
{ 1728873 }, /* ocr.reads_to_core.local_socket_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts DRAM accesses that are controlled by the close or distant SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x70C004477\000\00000\000\000 */
{ 1729711 }, /* ocr.reads_to_core.local_socket_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to this socket, whether or not in Sub NUMA Cluster(SNC) Mode.  In SNC Mode counts PMM accesses that are controlled by the close or distant SNC Cluster\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x700C04477\000\00000\000\000 */
{ 1730881 }, /* ocr.reads_to_core.remote\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the local socket's L1, L2, or L3 caches and were supplied by a remote socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x3F33004477\000\00000\000\000 */
{ 1733779 }, /* ocr.reads_to_core.remote_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x730004477\000\00000\000\000 */
{ 1734337 }, /* ocr.reads_to_core.remote_memory\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM or PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x733004477\000\00000\000\000 */
{ 1734913 }, /* ocr.reads_to_core.remote_pmm\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by PMM attached to another socket\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x703004477\000\00000\000\000 */
{ 1737071 }, /* ocr.reads_to_core.snc_dram\000\000other\000Counts all (cacheable) data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM on a distant memory controller of this socket when the system is in SNC (sub-NUMA cluster) mode\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x708004477\000\00000\000\000 */
{ 1738412 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1744379 }, /* ocr.write_estimate.memory\000\000other\000Counts Demand RFOs, ItoM's, PREFECTHW's, Hardware RFO Prefetches to the L1/L2 and Streaming stores that likely resulted in a store to Memory (DRAM or PMM)\000event=0x2a,period=100003,umask=0x1,offcore_rsp=0xFBFF80822\000\00000\000\000 */
{ 2508461 }, /* rs.empty\000\000other\000Cycles when Reservation Station (RS) is empty for the thread\000event=0xa5,period=1000003,umask=0x7\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into starvation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2509160 }, /* rs.empty_count\000\000other\000Counts end of periods where the Reservation Station (RS) was empty\000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2509867 }, /* rs_empty.count\000\000other\000This event is deprecated. Refer to new event RS.EMPTY_COUNT\000event=0xa5,cmask=1,edge=1,inv=1,period=100003,umask=0x7\000\00010\000\000 */
{ 2510178 }, /* rs_empty.cycles\000\000other\000This event is deprecated. Refer to new event RS.EMPTY\000event=0xa5,period=1000003,umask=0x7\000\00010\000\000 */
{ 6243367 }, /* xq.full_cycles\000\000other\000Cycles the uncore cannot take further requests\000event=0x2d,cmask=1,period=1000003,umask=0x1\000\00000\000number of cycles when the thread is active and the uncore cannot take any further requests (for example prefetches, loads or stores initiated by the Core that miss the L2 cache)\000 */
{ 466720 }, /* amx_ops_retired.bf16\000\000pipeline\000AMX retired arithmetic BF16 operations\000event=0xce,period=1000003,umask=0x2\000\00000\000Number of AMX-based retired arithmetic bfloat16 (BF16) floating-point operations. Counts TDPBF16PS FP instructions. SW to use operation multiplier of 4\000 */
{ 466982 }, /* amx_ops_retired.int8\000\000pipeline\000AMX retired arithmetic integer 8-bit operations\000event=0xce,period=1000003,umask=0x1\000\00000\000Number of AMX-based retired arithmetic integer operations of 8-bit width source operands. Counts TDPB[SS,UU,US,SU]D instructions. SW should use operation multiplier of 8\000 */
{ 467480 }, /* arith.div_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 468568 }, /* arith.divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.DIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x9\000\00010\000\000 */
{ 469023 }, /* arith.fp_divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.FPDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x1\000\00010\000\000 */
{ 470718 }, /* arith.idiv_active\000\000pipeline\000This event counts the cycles the integer divider is busy\000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00000\000\000 */
{ 471011 }, /* arith.int_divider_active\000\000pipeline\000This event is deprecated. Refer to new event ARITH.IDIV_ACTIVE\000event=0xb0,cmask=1,period=1000003,umask=0x8\000\00010\000\000 */
{ 471420 }, /* assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x1b\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware. Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502931 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504333 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 504924 }, /* br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 508295 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511305 }, /* br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 515219 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 517928 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 519163 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 535230 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542542 }, /* br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 543768 }, /* br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545238 }, /* br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 549517 }, /* br_misp_retired.indirect\000\000pipeline\000Miss-predicted near indirect branch instructions retired (excluding returns) (Precise event)\000event=0xc5,period=100003,umask=0x80\000\00000\000Counts miss-predicted near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 551068 }, /* br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 555097 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 560165 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 609668 }, /* cpu_clk_unhalted.c01\000\000pipeline\000Core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state\000event=0xec,period=2000003,umask=0x10\000\00000\000Counts core clocks when the thread is in the C0.1 light-weight slower wakeup time but more power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000 */
{ 610435 }, /* cpu_clk_unhalted.c02\000\000pipeline\000Core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state\000event=0xec,period=2000003,umask=0x20\000\00000\000Counts core clocks when the thread is in the C0.2 light-weight faster wakeup time but less power saving optimized state.  This state can be entered via the TPAUSE or UMWAIT instructions\000 */
{ 611202 }, /* cpu_clk_unhalted.c0_wait\000\000pipeline\000Core clocks when the thread is in the C0.1 or C0.2 or running a PAUSE in C0 ACPI state\000event=0xec,period=2000003,umask=0x70\000\00000\000Counts core clocks when the thread is in the C0.1 or C0.2 power saving optimized states (TPAUSE or UMWAIT instructions) or running the PAUSE instruction\000 */
{ 616704 }, /* cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 617767 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 618819 }, /* cpu_clk_unhalted.pause\000\000pipeline\000CPU_CLK_UNHALTED.PAUSE\000event=0xec,period=2000003,umask=0x40\000\00000\000\000 */
{ 619040 }, /* cpu_clk_unhalted.pause_inst\000\000pipeline\000CPU_CLK_UNHALTED.PAUSE_INST\000event=0xec,cmask=1,edge=1,period=2000003,umask=0x40\000\00000\000\000 */
{ 621045 }, /* cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 624724 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 634728 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 748732 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750161 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 752892 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754470 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 755810 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 759202 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847345 }, /* exe_activity.bound_on_loads\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000\000 */
{ 847674 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 848345 }, /* exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load\000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000 */
{ 1043511 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x75,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1049915 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055337 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1057508 }, /* inst_retired.macro_fused\000\000pipeline\000INST_RETIRED.MACRO_FUSED\000event=0xc0,period=2000003,umask=0x10\000\00000\000\000 */
{ 1058295 }, /* inst_retired.nop\000\000pipeline\000Retired NOP instructions\000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions\000 */
{ 1061046 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired with PEBS precise-distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a precise distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR++) feature to fix bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1061911 }, /* inst_retired.rep_iteration\000\000pipeline\000Iterations of Repeat string retired instructions\000event=0xc0,period=2000003,umask=0x8\000\00000\000Number of iterations of Repeat (REP) string retired instructions such as MOVS, CMPS, and SCAS. Each has a byte, word, and doubleword version and string instructions can be repeated using a repetition prefix, REP, that allows their architectural execution to be repeated a number of times as specified by the RCX register. Note the number of iterations is implementation-dependent\000 */
{ 1065477 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xad,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1066695 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xad,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1067555 }, /* int_misc.mba_stalls\000\000pipeline\000INT_MISC.MBA_STALLS\000event=0xad,period=1000003,umask=0x20\000\00000\000\000 */
{ 1069276 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xad,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072426 }, /* int_misc.unknown_branch_cycles\000\000pipeline\000INT_MISC.UNKNOWN_BRANCH_CYCLES\000event=0xad,period=1000003,umask=0x40,frontend=0x7\000\00000\000\000 */
{ 1072705 }, /* int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xad,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1073371 }, /* int_vec_retired.128bit\000\000pipeline\000INT_VEC_RETIRED.128BIT\000event=0xe7,period=1000003,umask=0x13\000\00000\000\000 */
{ 1073592 }, /* int_vec_retired.256bit\000\000pipeline\000INT_VEC_RETIRED.256BIT\000event=0xe7,period=1000003,umask=0xac\000\00000\000\000 */
{ 1073813 }, /* int_vec_retired.add_128\000\000pipeline\000integer ADD, SUB, SAD 128-bit vector instructions\000event=0xe7,period=1000003,umask=0x3\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 128-bit vector instructions\000 */
{ 1074268 }, /* int_vec_retired.add_256\000\000pipeline\000integer ADD, SUB, SAD 256-bit vector instructions\000event=0xe7,period=1000003,umask=0xc\000\00000\000Number of retired integer ADD/SUB (regular or horizontal), SAD 256-bit vector instructions\000 */
{ 1074723 }, /* int_vec_retired.mul_256\000\000pipeline\000INT_VEC_RETIRED.MUL_256\000event=0xe7,period=1000003,umask=0x80\000\00000\000\000 */
{ 1074948 }, /* int_vec_retired.shuffles\000\000pipeline\000INT_VEC_RETIRED.SHUFFLES\000event=0xe7,period=1000003,umask=0x40\000\00000\000\000 */
{ 1075177 }, /* int_vec_retired.vnni_128\000\000pipeline\000INT_VEC_RETIRED.VNNI_128\000event=0xe7,period=1000003,umask=0x10\000\00000\000\000 */
{ 1075406 }, /* int_vec_retired.vnni_256\000\000pipeline\000INT_VEC_RETIRED.VNNI_256\000event=0xe7,period=1000003,umask=0x20\000\00000\000\000 */
{ 1191035 }, /* ld_blocks.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x3,period=100003,umask=0x4\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000 */
{ 1193773 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x88\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1199071 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x82\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1231173 }, /* load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285361 }, /* lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=6,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286007 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1288826 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431135 }, /* misc2_retired.lfence\000\000pipeline\000LFENCE instructions retired\000event=0xe0,period=400009,umask=0x20\000\00000\000number of LFENCE retired instructions\000 */
{ 1431434 }, /* misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 2504245 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506218 }, /* resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2543542 }, /* topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Number of slots in TMA method where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2545902 }, /* topdown.bad_spec_slots\000\000pipeline\000TMA slots wasted due to incorrect speculations\000event=0xa4,period=10000003,umask=0x4\000\00000\000Number of slots of TMA method that were wasted due to incorrect speculation. It covers all types of control-flow or data-related mis-speculations\000 */
{ 2546461 }, /* topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by (any type of) branch mispredictions. This event estimates number of speculative operations that were issued but not retired as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548171 }, /* topdown.memory_bound_slots\000\000pipeline\000TOPDOWN.MEMORY_BOUND_SLOTS\000event=0xa4,period=10000003,umask=0x10\000\00000\000\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6178516 }, /* uops_decoded.dec0_uops\000\000pipeline\000UOPS_DECODED.DEC0_UOPS\000event=0x76,period=1000003,umask=0x1\000\00000\000\000 */
{ 6179751 }, /* uops_dispatched.port_0\000\000pipeline\000Uops executed on port 0\000event=0xb2,period=2000003,umask=0x1\000\00000\000Number of uops dispatch to execution  port 0\000 */
{ 6180295 }, /* uops_dispatched.port_1\000\000pipeline\000Uops executed on port 1\000event=0xb2,period=2000003,umask=0x2\000\00000\000Number of uops dispatch to execution  port 1\000 */
{ 6180854 }, /* uops_dispatched.port_2_3_10\000\000pipeline\000Uops executed on ports 2, 3 and 10\000event=0xb2,period=2000003,umask=0x4\000\00000\000Number of uops dispatch to execution ports 2, 3 and 10\000 */
{ 6181466 }, /* uops_dispatched.port_4_9\000\000pipeline\000Uops executed on ports 4 and 9\000event=0xb2,period=2000003,umask=0x10\000\00000\000Number of uops dispatch to execution ports 4 and 9\000 */
{ 6182043 }, /* uops_dispatched.port_5_11\000\000pipeline\000Uops executed on ports 5 and 11\000event=0xb2,period=2000003,umask=0x20\000\00000\000Number of uops dispatch to execution ports 5 and 11\000 */
{ 6182626 }, /* uops_dispatched.port_6\000\000pipeline\000Uops executed on port 6\000event=0xb2,period=2000003,umask=0x40\000\00000\000Number of uops dispatch to execution  port 6\000 */
{ 6183188 }, /* uops_dispatched.port_7_8\000\000pipeline\000Uops executed on ports 7 and 8\000event=0xb2,period=2000003,umask=0x80\000\00000\000Number of uops dispatch to execution  ports 7 and 8\000 */
{ 6193009 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000 */
{ 6194148 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195247 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196350 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6197453 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200004 }, /* uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201055 }, /* uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202126 }, /* uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203199 }, /* uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6206066 }, /* uops_executed.stall_cycles\000\000pipeline\000This event is deprecated. Refer to new event UOPS_EXECUTED.STALLS\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00010\000\000 */
{ 6206407 }, /* uops_executed.stalls\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207380 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6213668 }, /* uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xae,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6228300 }, /* uops_retired.cycles\000\000pipeline\000Cycles with retired uop(s)\000event=0xc2,cmask=1,period=1000003,umask=0x2\000\00000\000Counts cycles where at least one uop has retired\000 */
{ 6229682 }, /* uops_retired.heavy\000\000pipeline\000Retired uops except the last uop of each instruction\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of retired micro-operations (uops) except the last uop of each instruction. An instruction that is decoded into less than two uops does not contribute to the count\000 */
{ 6232471 }, /* uops_retired.ms\000\000pipeline\000UOPS_RETIRED.MS\000event=0xc2,period=2000003,umask=0x4,frontend=0x8\000\00000\000\000 */
{ 6236200 }, /* uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6238884 }, /* uops_retired.stall_cycles\000\000pipeline\000This event is deprecated. Refer to new event UOPS_RETIRED.STALLS\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00010\000\000 */
{ 6239329 }, /* uops_retired.stalls\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 2829064 }, /* unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000CHA to iMC Bypass : Intermediate bypass Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the intermediate bypass\000 */
{ 2830078 }, /* unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000CHA to iMC Bypass : Not Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000 */
{ 2831272 }, /* unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000CHA to iMC Bypass : Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the full bypass\000 */
{ 2832196 }, /* unc_cha_clockticks\000uncore_cha\000uncore cache\000CHA Clockticks. Unit: uncore_cha \000event=0x1\000\00001\000Number of CHA clock cycles while the event is enabled\000 */
{ 2832961 }, /* unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 2833673 }, /* unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xf2\000\00001\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2835204 }, /* unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xf1\000\00001\000Core Cross Snoops Issued : Any Single Snoop : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2837419 }, /* unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Core Cross Snoops Issued : Multiple Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2838928 }, /* unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Core Cross Snoops Issued : Single Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2841161 }, /* unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Core Cross Snoops Issued : Multiple Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2842657 }, /* unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Core Cross Snoops Issued : Single Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2844874 }, /* unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Core Cross Snoops Issued : Multiple External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2846387 }, /* unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Core Cross Snoops Issued : Single External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2848625 }, /* unc_cha_core_snp.remote_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote. Unit: uncore_cha \000event=0x33,umask=0x12\000\00001\000Core Cross Snoops Issued : Multiple Snoop Targets from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2849432 }, /* unc_cha_core_snp.remote_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Snoop Target from Remote. Unit: uncore_cha \000event=0x33,umask=0x11\000\00001\000Core Cross Snoops Issued : Single Snoop Target from Remote : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2851249 }, /* unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Counts transactions that looked into the multi-socket cacheline Directory state, and therefore did not send a snoop because the Directory indicated it was not needed\000 */
{ 2852041 }, /* unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Counts  transactions that looked into the multi-socket cacheline Directory state, and sent one or more snoops, because the Directory indicated it was needed\000 */
{ 2852809 }, /* unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from the HA pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline Directory state updates memory writes issued from the HA pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2853605 }, /* unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline Directory state updates due to memory writes issued from the TOR pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2854609 }, /* unc_cha_direct_go.ha_suppress_drd\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x4\000\00001\000\000 */
{ 2854722 }, /* unc_cha_direct_go.ha_suppress_no_d2c\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x2\000\00001\000\000 */
{ 2854838 }, /* unc_cha_direct_go.ha_tor_dealloc\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x1\000\00001\000\000 */
{ 2854950 }, /* unc_cha_direct_go_opc.extcmp\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x1\000\00001\000\000 */
{ 2855058 }, /* unc_cha_direct_go_opc.fast_go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x10\000\00001\000\000 */
{ 2855168 }, /* unc_cha_direct_go_opc.fast_go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x20\000\00001\000\000 */
{ 2855283 }, /* unc_cha_direct_go_opc.go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x4\000\00001\000\000 */
{ 2855387 }, /* unc_cha_direct_go_opc.go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x8\000\00001\000\000 */
{ 2855496 }, /* unc_cha_direct_go_opc.idle_due_suppress\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x80\000\00001\000\000 */
{ 2855616 }, /* unc_cha_direct_go_opc.nop\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x40\000\00001\000\000 */
{ 2855722 }, /* unc_cha_direct_go_opc.pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x2\000\00001\000\000 */
{ 2858632 }, /* unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_cha \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859187 }, /* unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_cha \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2860254 }, /* unc_cha_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000Read request from a remote socket which hit in the HitMe Cache to a line In the E state. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00001\000Counts read requests from a remote socket which hit in the HitME cache (used to cache the multi-socket Directory state) to a line in the E(Exclusive) state.  This includes the following read opcodes (RdCode, RdData, RdDataMigratory, RdCur, RdInv*, Inv*)\000 */
{ 2861029 }, /* unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : Shared hit and op is RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000\000 */
{ 2861557 }, /* unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : op is WbMtoE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000 */
{ 2862158 }, /* unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache : op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000\000 */
{ 2862843 }, /* unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000\000 */
{ 2863606 }, /* unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed : op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000\000 */
{ 2864001 }, /* unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : No SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000\000 */
{ 2865043 }, /* unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000\000 */
{ 2865757 }, /* unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache : SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000\000 */
{ 2866114 }, /* unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000 */
{ 2866513 }, /* unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a local request : Received RspFwdI* for a local request, but converted HitME$ to SF entry\000 */
{ 2867185 }, /* unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000 */
{ 2867594 }, /* unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Counts the number of Allocate/Update to HitMe Cache : op is RspIFwd or RspIFwdWb for a remote request : Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000 */
{ 2868249 }, /* unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache : Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000 */
{ 2896137 }, /* unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000 */
{ 2896411 }, /* unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued : ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000HA to iMC Reads Issued : ISOCH : Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 2897239 }, /* unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to the any of the memory controller channels\000 */
{ 2897842 }, /* unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Full Line : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2898479 }, /* unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2899475 }, /* unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Partial : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2901580 }, /* unc_cha_llc_lookup.all\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x1fffff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2902299 }, /* unc_cha_llc_lookup.all_remote\000uncore_cha\000uncore cache\000Cache Lookups : All transactions from Remote Agents. Unit: uncore_cha \000event=0x34,umask=0x17e0ff\000\00001\000Cache Lookups : All transactions from Remote Agents : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2904862 }, /* unc_cha_llc_lookup.any_f\000uncore_cha\000uncore cache\000Cache Lookups : All Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : All Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local or remote transaction to the LLC, including prefetch\000 */
{ 2905473 }, /* unc_cha_llc_lookup.code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2907665 }, /* unc_cha_llc_lookup.code_read_f\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2910431 }, /* unc_cha_llc_lookup.corepref_or_dmnd_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local non-prefetch requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local non-prefetch requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local transaction to the LLC, not including prefetch\000 */
{ 2911738 }, /* unc_cha_llc_lookup.data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2913797 }, /* unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000Cache Lookups : Data Reads. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00001\000Cache Lookups : Data Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2915272 }, /* unc_cha_llc_lookup.data_read_f\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Request. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Data Read Request : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Read transactions\000 */
{ 2915854 }, /* unc_cha_llc_lookup.data_read_local\000uncore_cha\000uncore cache\000Cache Lookups : Demand Data Reads, Core and LLC prefetches. Unit: uncore_cha \000event=0x34,umask=0x841ff\000\00001\000Cache Lookups : Demand Data Reads, Core and LLC prefetches : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2917749 }, /* unc_cha_llc_lookup.data_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1fc101\000\00001\000Cache Lookups : Data Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2919750 }, /* unc_cha_llc_lookup.e\000uncore_cha\000uncore cache\000Cache Lookups : E State. Unit: uncore_cha \000event=0x34,umask=0x20\000\00001\000Cache Lookups : E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Exclusive State\000 */
{ 2920879 }, /* unc_cha_llc_lookup.f\000uncore_cha\000uncore cache\000Cache Lookups : F State. Unit: uncore_cha \000event=0x34,umask=0x80\000\00001\000Cache Lookups : F State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Forward State\000 */
{ 2921442 }, /* unc_cha_llc_lookup.flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests. Unit: uncore_cha \000event=0x34,umask=0x1a44ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2923839 }, /* unc_cha_llc_lookup.flush_or_inv_f\000uncore_cha\000uncore cache\000Cache Lookups : Flush. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2924929 }, /* unc_cha_llc_lookup.i\000uncore_cha\000uncore cache\000Cache Lookups : I State. Unit: uncore_cha \000event=0x34,umask=0x1\000\00001\000Cache Lookups : I State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Miss\000 */
{ 2927017 }, /* unc_cha_llc_lookup.llcpref_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local LLC prefetch requests (from LLC). Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local LLC prefetch requests (from LLC) : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Any local LLC prefetch to the LLC\000 */
{ 2928894 }, /* unc_cha_llc_lookup.local_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19d0ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2929586 }, /* unc_cha_llc_lookup.local_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2930271 }, /* unc_cha_llc_lookup.local_dmnd_code\000uncore_cha\000uncore cache\000Cache Lookups : Demand CRd Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1850ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2930975 }, /* unc_cha_llc_lookup.local_dmnd_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Demand Data Reads that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1841ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2931665 }, /* unc_cha_llc_lookup.local_dmnd_rfo\000uncore_cha\000uncore cache\000Cache Lookups : Demand RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1848ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2933011 }, /* unc_cha_llc_lookup.local_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000 */
{ 2933639 }, /* unc_cha_llc_lookup.local_flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1844ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2934269 }, /* unc_cha_llc_lookup.local_llc_pf\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Prefetch requests to the LLC that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x189dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2934964 }, /* unc_cha_llc_lookup.local_pf\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x199dff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2935647 }, /* unc_cha_llc_lookup.local_pf_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1910ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2936344 }, /* unc_cha_llc_lookup.local_pf_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1981ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2937035 }, /* unc_cha_llc_lookup.local_pf_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Prefetches that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x1908ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2937731 }, /* unc_cha_llc_lookup.local_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from the local socket (usually the core). Unit: uncore_cha \000event=0x34,umask=0x19c8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2938422 }, /* unc_cha_llc_lookup.locally_homed_address\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally. Unit: uncore_cha \000event=0x34,umask=0xbdfff\000\00001\000Cache Lookups : Transactions homed locally : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000 */
{ 2939829 }, /* unc_cha_llc_lookup.m\000uncore_cha\000uncore cache\000Cache Lookups : M State. Unit: uncore_cha \000event=0x34,umask=0x40\000\00001\000Cache Lookups : M State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Modified State\000 */
{ 2940953 }, /* unc_cha_llc_lookup.miss_all\000uncore_cha\000uncore cache\000Cache Lookups : All Misses. Unit: uncore_cha \000event=0x34,umask=0x1fe001\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2942152 }, /* unc_cha_llc_lookup.other_req_f\000uncore_cha\000uncore cache\000Cache Lookups : Write Requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2943470 }, /* unc_cha_llc_lookup.pref_or_dmnd_remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote non-snoop requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote non-snoop requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Remote non-snoop transactions to the LLC\000 */
{ 2950871 }, /* unc_cha_llc_lookup.remote_code\000uncore_cha\000uncore cache\000Cache Lookups : CRd Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a10ff\000\00001\000Cache Lookups : CRd Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2951544 }, /* unc_cha_llc_lookup.remote_data_rd\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a01ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2952856 }, /* unc_cha_llc_lookup.remote_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000 */
{ 2953486 }, /* unc_cha_llc_lookup.remote_flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a04ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2954097 }, /* unc_cha_llc_lookup.remote_other\000uncore_cha\000uncore cache\000Cache Lookups : Filters Requests for those that write info into the cache that come from a remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a02ff\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2954850 }, /* unc_cha_llc_lookup.remote_rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests that come from a Remote socket. Unit: uncore_cha \000event=0x34,umask=0x1a08ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2956855 }, /* unc_cha_llc_lookup.remote_snoop_f\000uncore_cha\000uncore cache\000Cache Lookups : Remote snoop requests. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Remote snoop requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Remote snoop transactions to the LLC\000 */
{ 2957467 }, /* unc_cha_llc_lookup.remote_snp\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Snoop Requests from a Remote Socket. Unit: uncore_cha \000event=0x34,umask=0x1c19ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2958217 }, /* unc_cha_llc_lookup.remotely_homed_address\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed remotely. Unit: uncore_cha \000event=0x34,umask=0x15dfff\000\00001\000Cache Lookups : Transactions homed remotely : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Transaction whose address resides in a remote MC\000 */
{ 2959064 }, /* unc_cha_llc_lookup.rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests. Unit: uncore_cha \000event=0x34,umask=0x1bc8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2960332 }, /* unc_cha_llc_lookup.rfo_f\000uncore_cha\000uncore cache\000Cache Lookups : RFO Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2960929 }, /* unc_cha_llc_lookup.rfo_local\000uncore_cha\000uncore cache\000Cache Lookups : Locally HOMed RFOs - Demand and Prefetches. Unit: uncore_cha \000event=0x34,umask=0x9c8ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2964159 }, /* unc_cha_llc_lookup.s\000uncore_cha\000uncore cache\000Cache Lookups : S State. Unit: uncore_cha \000event=0x34,umask=0x10\000\00001\000Cache Lookups : S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Hit Shared State\000 */
{ 2965320 }, /* unc_cha_llc_lookup.sf_e\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - E State. Unit: uncore_cha \000event=0x34,umask=0x4\000\00001\000Cache Lookups : SnoopFilter - E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit Exclusive State\000 */
{ 2966513 }, /* unc_cha_llc_lookup.sf_h\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - H State. Unit: uncore_cha \000event=0x34,umask=0x8\000\00001\000Cache Lookups : SnoopFilter - H State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit HitMe State\000 */
{ 2967703 }, /* unc_cha_llc_lookup.sf_s\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - S State. Unit: uncore_cha \000event=0x34,umask=0x2\000\00001\000Cache Lookups : SnoopFilter - S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : SF Hit Shared State\000 */
{ 2969004 }, /* unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000Cache Lookups : Writes. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Requests that install or change a line in the LLC.    Examples:  Writebacks from Core L2's and UPI.  Prefetches into the LLC\000 */
{ 2969975 }, /* unc_cha_llc_lookup.write_remote\000uncore_cha\000uncore cache\000Cache Lookups : Remote Writes. Unit: uncore_cha \000event=0x34,umask=0x17c2ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2971715 }, /* unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Lines Victimized : Lines in E state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2972340 }, /* unc_cha_llc_victims.ia\000uncore_cha\000uncore cache\000Lines Victimized : IA traffic. Unit: uncore_cha \000event=0x37,umask=0x20\000\00001\000Lines Victimized : IA traffic : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2972609 }, /* unc_cha_llc_victims.io\000uncore_cha\000uncore cache\000Lines Victimized : IO traffic. Unit: uncore_cha \000event=0x37,umask=0x10\000\00001\000Lines Victimized : IO traffic : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2972878 }, /* unc_cha_llc_victims.io_e\000uncore_cha\000uncore cache\000All LLC lines in E state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x12\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2973160 }, /* unc_cha_llc_victims.io_fs\000uncore_cha\000uncore cache\000All LLC lines in F or S state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x1c\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2973448 }, /* unc_cha_llc_victims.io_m\000uncore_cha\000uncore cache\000All LLC lines in M state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x11\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2973730 }, /* unc_cha_llc_victims.io_mesf\000uncore_cha\000uncore cache\000All LLC lines in any state that are victimized on a fill from an IO device. Unit: uncore_cha \000event=0x37,umask=0x1f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2974430 }, /* unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized; Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x200f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975236 }, /* unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2002\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976300 }, /* unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2001\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976805 }, /* unc_cha_llc_victims.local_only\000uncore_cha\000uncore cache\000Lines Victimized : Local Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Local Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977375 }, /* unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x2004\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977880 }, /* unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Lines Victimized : Lines in M state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2978803 }, /* unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized; Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x800f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2979616 }, /* unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8002\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980688 }, /* unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8001\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2981196 }, /* unc_cha_llc_victims.remote_only\000uncore_cha\000uncore cache\000Lines Victimized : Remote Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Remote Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2981772 }, /* unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0x8004\000\00001\000Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982280 }, /* unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Lines Victimized : Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982735 }, /* unc_cha_llc_victims.total_e\000uncore_cha\000uncore cache\000All LLC lines in E state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2983493 }, /* unc_cha_llc_victims.total_m\000uncore_cha\000uncore cache\000All LLC lines in M state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984005 }, /* unc_cha_llc_victims.total_s\000uncore_cha\000uncore cache\000All LLC lines in S state that are victimized on a fill. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984517 }, /* unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Cbo Misc : CV0 Prefetch Miss : Miscellaneous events in the Cbo\000 */
{ 2984861 }, /* unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Cbo Misc : CV0 Prefetch Victim : Miscellaneous events in the Cbo\000 */
{ 2985209 }, /* unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000 */
{ 2985457 }, /* unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc : Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Cbo Misc : Silent Snoop Eviction : Miscellaneous events in the Cbo. : Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2986136 }, /* unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc : Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Cbo Misc : Write Combining Aliasing : Miscellaneous events in the Cbo. : Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2987234 }, /* unc_cha_osb.local_invitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local InvItoE. Unit: uncore_cha \000event=0x55,umask=0x1\000\00001\000OSB Snoop Broadcast : Local InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2987540 }, /* unc_cha_osb.local_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Local Rd. Unit: uncore_cha \000event=0x55,umask=0x2\000\00001\000OSB Snoop Broadcast : Local Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2987833 }, /* unc_cha_osb.off_pwrheuristic\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Off. Unit: uncore_cha \000event=0x55,umask=0x20\000\00001\000OSB Snoop Broadcast : Off : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988123 }, /* unc_cha_osb.remote_read\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd. Unit: uncore_cha \000event=0x55,umask=0x4\000\00001\000OSB Snoop Broadcast : Remote Rd : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988419 }, /* unc_cha_osb.remote_readinvitoe\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : Remote Rd InvItoE. Unit: uncore_cha \000event=0x55,umask=0x8\000\00001\000OSB Snoop Broadcast : Remote Rd InvItoE : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2988738 }, /* unc_cha_osb.rfo_hits_snp_bcast\000uncore_cha\000uncore cache\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast. Unit: uncore_cha \000event=0x55,umask=0x10\000\00001\000OSB Snoop Broadcast : RFO HitS Snoop Broadcast : Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 2995175 }, /* unc_cha_pmm_memmode_nm_invitox.local\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.LOCAL. Unit: uncore_cha \000event=0x65,umask=0x1\000\00001\000\000 */
{ 2995318 }, /* unc_cha_pmm_memmode_nm_invitox.remote\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.REMOTE. Unit: uncore_cha \000event=0x65,umask=0x2\000\00001\000\000 */
{ 2995463 }, /* unc_cha_pmm_memmode_nm_invitox.setconflict\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_INVITOX.SETCONFLICT. Unit: uncore_cha \000event=0x65,umask=0x4\000\00001\000\000 */
{ 2996163 }, /* unc_cha_pmm_memmode_nm_setconflicts.llc\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near Memory set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x2\000\00001\000Near Memory evictions due to another read to the same Near Memory set in the LLC\000 */
{ 2997089 }, /* unc_cha_pmm_memmode_nm_setconflicts.sf\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near memory set conflict in SF/LLC. Unit: uncore_cha \000event=0x64,umask=0x1\000\00001\000Near Memory evictions due to another read to the same Near Memory set in the SF\000 */
{ 2998020 }, /* unc_cha_pmm_memmode_nm_setconflicts.tor\000uncore_cha\000uncore cache\000Memory Mode related events; Counts the number of times CHA saw a Near Memory set conflict in TOR. Unit: uncore_cha \000event=0x64,umask=0x4\000\00001\000No Reject in the CHA due to a pending read to the same Near Memory set in the TOR\000 */
{ 2998995 }, /* unc_cha_pmm_memmode_nm_setconflicts2.iodc\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.IODC. Unit: uncore_cha \000event=0x70,umask=0x1\000\00001\000\000 */
{ 2999148 }, /* unc_cha_pmm_memmode_nm_setconflicts2.memwr\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWR. Unit: uncore_cha \000event=0x70,umask=0x2\000\00001\000\000 */
{ 2999303 }, /* unc_cha_pmm_memmode_nm_setconflicts2.memwrni\000uncore_cha\000uncore cache\000UNC_CHA_PMM_MEMMODE_NM_SETCONFLICTS2.MEMWRNI. Unit: uncore_cha \000event=0x70,umask=0x4\000\00001\000\000 */
{ 2999462 }, /* unc_cha_pmm_qos.ddr4_fast_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.DDR4_FAST_INSERT. Unit: uncore_cha \000event=0x66,umask=0x2\000\00001\000\000 */
{ 2999597 }, /* unc_cha_pmm_qos.rej_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.REJ_IRQ. Unit: uncore_cha \000event=0x66,umask=0x8\000\00001\000\000 */
{ 2999714 }, /* unc_cha_pmm_qos.slow_insert\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOW_INSERT. Unit: uncore_cha \000event=0x66,umask=0x1\000\00001\000\000 */
{ 2999839 }, /* unc_cha_pmm_qos.slowtorq_skip\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.SLOWTORQ_SKIP. Unit: uncore_cha \000event=0x66,umask=0x40\000\00001\000\000 */
{ 2999969 }, /* unc_cha_pmm_qos.throttle\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE. Unit: uncore_cha \000event=0x66,umask=0x4\000\00001\000\000 */
{ 3000088 }, /* unc_cha_pmm_qos.throttle_irq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_IRQ. Unit: uncore_cha \000event=0x66,umask=0x20\000\00001\000\000 */
{ 3000216 }, /* unc_cha_pmm_qos.throttle_prq\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS.THROTTLE_PRQ. Unit: uncore_cha \000event=0x66,umask=0x10\000\00001\000\000 */
{ 3000344 }, /* unc_cha_pmm_qos_occupancy.ddr_fast_fifo\000uncore_cha\000uncore cache\000UNC_CHA_PMM_QOS_OCCUPANCY.DDR_FAST_FIFO. Unit: uncore_cha \000event=0x67,umask=0x2\000\00001\000: count # of FAST TOR Request inserted to ha_tor_req_fifo\000 */
{ 3000550 }, /* unc_cha_pmm_qos_occupancy.ddr_slow_fifo\000uncore_cha\000uncore cache\000Number of SLOW TOR Request inserted to ha_pmm_tor_req_fifo. Unit: uncore_cha \000event=0x67,umask=0x1\000\00001\000\000 */
{ 3002566 }, /* unc_cha_read_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000CHA iMC CHNx READ Credits Empty : MC0 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 0 only\000 */
{ 3005144 }, /* unc_cha_read_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000CHA iMC CHNx READ Credits Empty : MC1 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 1 only\000 */
{ 3005990 }, /* unc_cha_read_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000CHA iMC CHNx READ Credits Empty : MC2 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 2 only\000 */
{ 3006429 }, /* unc_cha_read_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000CHA iMC CHNx READ Credits Empty : MC3 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 3 only\000 */
{ 3006868 }, /* unc_cha_read_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000CHA iMC CHNx READ Credits Empty : MC4 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 4 only\000 */
{ 3007308 }, /* unc_cha_read_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000CHA iMC CHNx READ Credits Empty : MC5 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 5 only\000 */
{ 3009896 }, /* unc_cha_requests.invitoe\000uncore_cha\000uncore cache\000Requests for exclusive ownership of a cache line without receiving data. Unit: uncore_cha \000event=0x50,umask=0x30\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3010612 }, /* unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3011635 }, /* unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Remote requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3012286 }, /* unc_cha_requests.reads\000uncore_cha\000uncore cache\000Read requests made into the CHA. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000 */
{ 3013130 }, /* unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Read requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3013437 }, /* unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Read requests from a remote socket. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3014364 }, /* unc_cha_requests.writes\000uncore_cha\000uncore cache\000Write requests made into the CHA. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015208 }, /* unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Write Requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015517 }, /* unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Read and Write Requests; Writes Remote. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3023930 }, /* unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Ingress (from CMS) Allocations : IPQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024370 }, /* unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Ingress (from CMS) Allocations : IRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024810 }, /* unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Ingress (from CMS) Allocations : IRQ Rejected : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025285 }, /* unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025727 }, /* unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026177 }, /* unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Ingress (from CMS) Allocations : RRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026619 }, /* unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Ingress (from CMS) Allocations : WBQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3027061 }, /* unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3027469 }, /* unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3027878 }, /* unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3028290 }, /* unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3028683 }, /* unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3029076 }, /* unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3029485 }, /* unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3029890 }, /* unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3030302 }, /* unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000 */
{ 3030606 }, /* unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IPQ0 Reject counter was true\000 */
{ 3030990 }, /* unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000 */
{ 3031260 }, /* unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000 */
{ 3031735 }, /* unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000 */
{ 3032037 }, /* unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000 */
{ 3032461 }, /* unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000IPQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3032859 }, /* unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000IPQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000 */
{ 3033147 }, /* unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3033568 }, /* unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3033990 }, /* unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3034415 }, /* unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3034821 }, /* unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3035227 }, /* unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3035649 }, /* unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3036067 }, /* unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3036492 }, /* unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3036809 }, /* unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IRQ0 Reject counter was true\000 */
{ 3037206 }, /* unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000 */
{ 3037489 }, /* unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way : Way conflict with another request that caused the reject\000 */
{ 3037977 }, /* unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000 */
{ 3038292 }, /* unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3038451 }, /* unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3038862 }, /* unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000 */
{ 3039163 }, /* unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000ISMQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3040032 }, /* unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000ISMQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3040902 }, /* unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000ISMQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3041775 }, /* unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000ISMQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3042629 }, /* unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000ISMQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3043483 }, /* unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000ISMQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3044353 }, /* unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000ISMQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3045219 }, /* unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000ISMQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3046092 }, /* unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000ISMQ Retries - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3046959 }, /* unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000ISMQ Retries - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3047827 }, /* unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000ISMQ Retries - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3048698 }, /* unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000ISMQ Retries - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3049550 }, /* unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000ISMQ Retries - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3050402 }, /* unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000ISMQ Retries - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3051270 }, /* unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000ISMQ Retries - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3052134 }, /* unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000ISMQ Retries - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3053005 }, /* unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000ISMQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3053851 }, /* unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000ISMQ Rejects - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3054626 }, /* unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000ISMQ Retries - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3055470 }, /* unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000ISMQ Retries - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3056243 }, /* unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Occupancy : IPQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057111 }, /* unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Occupancy : RRQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057547 }, /* unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Occupancy : WBQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057983 }, /* unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Other Retries - Set 0 : AD REQ on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a request\000 */
{ 3058590 }, /* unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Other Retries - Set 0 : AD RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a response\000 */
{ 3059198 }, /* unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Other Retries - Set 0 : Non UPI AK Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject AK ring message\000 */
{ 3059809 }, /* unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Other Retries - Set 0 : BL NCB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCB\000 */
{ 3060401 }, /* unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Other Retries - Set 0 : BL NCS on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCS\000 */
{ 3060993 }, /* unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Other Retries - Set 0 : BL RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a response\000 */
{ 3061601 }, /* unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Other Retries - Set 0 : BL WB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a writeback\000 */
{ 3062205 }, /* unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Other Retries - Set 0 : Non UPI IV Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject IV ring message\000 */
{ 3062816 }, /* unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Other Retries - Set 1 : Allow Snoop : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063373 }, /* unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Other Retries - Set 1 : ANY0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Any condition listed in the Other0 Reject counter was true\000 */
{ 3063958 }, /* unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Other Retries - Set 1 : HA : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064472 }, /* unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Other Retries - Set 1 : LLC OR SF Way : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Way conflict with another request that caused the reject\000 */
{ 3065146 }, /* unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Other Retries - Set 1 : LLC Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3065700 }, /* unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Other Retries - Set 1 : PhyAddr Match : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Address match with an outstanding request that was rejected\000 */
{ 3066323 }, /* unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Other Retries - Set 1 : SF Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Requests did not generate Snoop filter victim\000 */
{ 3066920 }, /* unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Other Retries - Set 1 : Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067616 }, /* unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3068037 }, /* unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3068465 }, /* unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3068885 }, /* unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3069291 }, /* unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3069696 }, /* unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3070116 }, /* unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3070542 }, /* unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3070959 }, /* unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3071263 }, /* unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the PRQ0 Reject counter was true\000 */
{ 3071656 }, /* unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000 */
{ 3071962 }, /* unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000 */
{ 3072399 }, /* unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000 */
{ 3072716 }, /* unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000 */
{ 3073149 }, /* unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3073555 }, /* unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000 */
{ 3073706 }, /* unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000Request Queue Retries - Set 0 : AD REQ on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a request\000 */
{ 3074235 }, /* unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000Request Queue Retries - Set 0 : AD RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a response\000 */
{ 3074765 }, /* unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000Request Queue Retries - Set 0 : Non UPI AK Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject AK ring message\000 */
{ 3075298 }, /* unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000Request Queue Retries - Set 0 : BL NCB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCB\000 */
{ 3075812 }, /* unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000Request Queue Retries - Set 0 : BL NCS on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCS\000 */
{ 3076326 }, /* unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000Request Queue Retries - Set 0 : BL RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a response\000 */
{ 3076856 }, /* unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000Request Queue Retries - Set 0 : BL WB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a writeback\000 */
{ 3077382 }, /* unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000Request Queue Retries - Set 0 : Non UPI IV Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject IV ring message\000 */
{ 3077915 }, /* unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000Request Queue Retries - Set 1 : Allow Snoop : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078394 }, /* unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000Request Queue Retries - Set 1 : ANY0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Any condition listed in the WBQ0 Reject counter was true\000 */
{ 3078899 }, /* unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000Request Queue Retries - Set 1 : HA : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079335 }, /* unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000Request Queue Retries - Set 1 : LLC OR SF Way : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Way conflict with another request that caused the reject\000 */
{ 3079931 }, /* unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000Request Queue Retries - Set 1 : LLC Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080407 }, /* unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000Request Queue Retries - Set 1 : PhyAddr Match : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Address match with an outstanding request that was rejected\000 */
{ 3080952 }, /* unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000Request Queue Retries - Set 1 : SF Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Requests did not generate Snoop filter victim\000 */
{ 3081471 }, /* unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000Request Queue Retries - Set 1 : Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081929 }, /* unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000RRQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a request\000 */
{ 3082463 }, /* unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000RRQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No AD VN0 credit for generating a response\000 */
{ 3082998 }, /* unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000RRQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject AK ring message\000 */
{ 3083536 }, /* unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000RRQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCB\000 */
{ 3084055 }, /* unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000RRQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for NCS\000 */
{ 3084574 }, /* unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000RRQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a response\000 */
{ 3085109 }, /* unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000RRQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : No BL VN0 credit for generating a writeback\000 */
{ 3085640 }, /* unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000RRQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Can't inject IV ring message\000 */
{ 3086178 }, /* unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000RRQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086661 }, /* unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000RRQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Any condition listed in the RRQ0 Reject counter was true\000 */
{ 3087171 }, /* unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000RRQ Rejects - Set 1 : HA : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087611 }, /* unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000RRQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Way conflict with another request that caused the reject\000 */
{ 3088212 }, /* unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000RRQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3088692 }, /* unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000RRQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Address match with an outstanding request that was rejected\000 */
{ 3089242 }, /* unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000RRQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry. : Requests did not generate Snoop filter victim\000 */
{ 3089766 }, /* unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000RRQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090228 }, /* unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000WBQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a request\000 */
{ 3090750 }, /* unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000WBQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No AD VN0 credit for generating a response\000 */
{ 3091273 }, /* unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000WBQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject AK ring message\000 */
{ 3091799 }, /* unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000WBQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCB\000 */
{ 3092306 }, /* unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000WBQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for NCS\000 */
{ 3092813 }, /* unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000WBQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a response\000 */
{ 3093336 }, /* unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000WBQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : No BL VN0 credit for generating a writeback\000 */
{ 3093855 }, /* unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000WBQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Can't inject IV ring message\000 */
{ 3094381 }, /* unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000WBQ Rejects - Set 1 : Allow Snoop : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094852 }, /* unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000WBQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Any condition listed in the WBQ0 Reject counter was true\000 */
{ 3095350 }, /* unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000WBQ Rejects - Set 1 : HA : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095778 }, /* unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000WBQ Rejects - Set 1 : LLC OR SF Way : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Way conflict with another request that caused the reject\000 */
{ 3096367 }, /* unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000WBQ Rejects - Set 1 : LLC Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096835 }, /* unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000WBQ Rejects - Set 1 : PhyAddr Match : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Address match with an outstanding request that was rejected\000 */
{ 3097373 }, /* unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000WBQ Rejects - Set 1 : SF Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry. : Requests did not generate Snoop filter victim\000 */
{ 3097885 }, /* unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects - Set 1 : Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000WBQ Rejects - Set 1 : Victim : Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3125406 }, /* unc_cha_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received : RSPCNFLCT*. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Snoop Responses Received : RSPCNFLCT* : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoops responses of RspConflict.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3126689 }, /* unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received : RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Snoop Responses Received : RspFwd : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3128307 }, /* unc_cha_snoop_resp.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*Fwd*WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Snoop Responses Received : Rsp*Fwd*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of Rsp*Fwd*WB.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3129170 }, /* unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000RspI Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000 */
{ 3129964 }, /* unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000RspIFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000 */
{ 3131096 }, /* unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000RspS Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Counts when a transaction with the opcode type RspS Snoop Response was received which indicates when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3132693 }, /* unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000RspSFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000 */
{ 3133515 }, /* unc_cha_snoop_resp.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received : Rsp*WB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Snoop Responses Received : Rsp*WB : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for a snoop response of RspIWB or RspSWB.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3135401 }, /* unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Snoop Responses Received Local : RspCnflct : Number of snoop responses received for a Local  request : Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3136430 }, /* unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Snoop Responses Received Local : RspFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3137368 }, /* unc_cha_snoop_resp_local.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Snoop Responses Received Local : Rsp*FWD*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3137910 }, /* unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Snoop Responses Received Local : RspI : Number of snoop responses received for a Local  request : Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3138764 }, /* unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Snoop Responses Received Local : RspIFwd : Number of snoop responses received for a Local  request : Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3139761 }, /* unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Snoop Responses Received Local : RspS : Number of snoop responses received for a Local  request : Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3140691 }, /* unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Snoop Responses Received Local : RspSFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3142097 }, /* unc_cha_snoop_resp_local.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Snoop Responses Received Local : Rsp*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3142653 }, /* unc_cha_snoop_rsp_misc.mtoi_rspdatam\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIDataM. Unit: uncore_cha \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 3142806 }, /* unc_cha_snoop_rsp_misc.mtoi_rspifwdm\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIFwdM. Unit: uncore_cha \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 3142958 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x20\000\00001\000\000 */
{ 3143130 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x10\000\00001\000\000 */
{ 3143300 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x8\000\00001\000\000 */
{ 3143462 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x4\000\00001\000\000 */
{ 3143622 }, /* unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent : All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Snoops Sent : All : Counts the number of snoops issued by the HA\000 */
{ 3143951 }, /* unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoop for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Snoops Sent : Broadcast snoop for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3145300 }, /* unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Snoops Sent : Broadcast snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA.This filter includes only requests coming from remote sockets\000 */
{ 3146318 }, /* unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Snoops Sent : Directed snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3147334 }, /* unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Snoops Sent : Directed snoops for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA. This filter includes only requests coming from remote sockets\000 */
{ 3148020 }, /* unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast or directed Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Snoops Sent : Broadcast or directed Snoops sent for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the local socket\000 */
{ 3149123 }, /* unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast or directed Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Snoops Sent : Broadcast or directed Snoops sent for Remote Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the remote socket\000 */
{ 3172946 }, /* unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts : All. Unit: uncore_cha \000event=0x35,umask=0xc001ffff\000\00001\000TOR Inserts : All : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3174351 }, /* unc_cha_tor_inserts.ddr\000uncore_cha\000uncore cache\000TOR Inserts : DDR Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : DDR Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3175347 }, /* unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts : SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000TOR Inserts : SF/LLC Evictions : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3176338 }, /* unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts : Just Hits. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Hits : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3177338 }, /* unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests from IA Cores\000 */
{ 3178296 }, /* unc_cha_tor_inserts.ia_clflush\000uncore_cha\000uncore cache\000TOR Inserts;CLFlush from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc8c7ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; CLFlush events that are initiated from the Core\000 */
{ 3178989 }, /* unc_cha_tor_inserts.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Inserts;CLFlushOpt from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc8d7ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; CLFlushOpt events that are initiated from the Core\000 */
{ 3179670 }, /* unc_cha_tor_inserts.ia_crd\000uncore_cha\000uncore cache\000TOR Inserts; CRd from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80fff01\000\00001\000TOR Inserts; Code read from local IA that misses in the snoop filter\000 */
{ 3179872 }, /* unc_cha_tor_inserts.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88fff01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3180459 }, /* unc_cha_tor_inserts.ia_drd\000uncore_cha\000uncore cache\000TOR Inserts; DRd from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817ff01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3181039 }, /* unc_cha_tor_inserts.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827ff01\000\00001\000TOR Inserts; Data read opt from local IA that misses in the snoop filter\000 */
{ 3181646 }, /* unc_cha_tor_inserts.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7ff01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that misses in the snoop filter\000 */
{ 3182260 }, /* unc_cha_tor_inserts.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897ff01\000\00001\000TOR Inserts; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3182481 }, /* unc_cha_tor_inserts.ia_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc837ff01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3183283 }, /* unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001fd01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3184595 }, /* unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts; CRd hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80ffd01\000\00001\000TOR Inserts; Code read from local IA that hits in the snoop filter\000 */
{ 3185223 }, /* unc_cha_tor_inserts.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88ffd01\000\00001\000TOR Inserts; Code read prefetch from local IA that hits in the snoop filter\000 */
{ 3185451 }, /* unc_cha_tor_inserts.ia_hit_cxl_acc\000uncore_cha\000uncore cache\000All requests issued from IA cores to CXL accelerator memory regions that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x10c0018101\000\00001\000\000 */
{ 3185649 }, /* unc_cha_tor_inserts.ia_hit_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008101\000\00001\000\000 */
{ 3186641 }, /* unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts; DRd hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817fd01\000\00001\000TOR Inserts; Data read from local IA that hits in the snoop filter\000 */
{ 3187266 }, /* unc_cha_tor_inserts.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827fd01\000\00001\000TOR Inserts; Data read opt from local IA that hits in the snoop filter\000 */
{ 3187918 }, /* unc_cha_tor_inserts.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7fd01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that hits in the snoop filter\000 */
{ 3188577 }, /* unc_cha_tor_inserts.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897fd01\000\00001\000TOR Inserts; Data read prefetch from local IA that hits in the snoop filter\000 */
{ 3188805 }, /* unc_cha_tor_inserts.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fd01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to page walks that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3189238 }, /* unc_cha_tor_inserts.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fd01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3190408 }, /* unc_cha_tor_inserts.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccffd01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA that hits in the snoop filter\000 */
{ 3191445 }, /* unc_cha_tor_inserts.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7fd01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA that hits in the snoop filter\000 */
{ 3192912 }, /* unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7fd01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that hits in the snoop filter\000 */
{ 3193988 }, /* unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807fd01\000\00001\000TOR Inserts; Read for ownership from local IA that hits in the snoop filter\000 */
{ 3194625 }, /* unc_cha_tor_inserts.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO Pref hits from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887fd01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that hits in the snoop filter\000 */
{ 3195656 }, /* unc_cha_tor_inserts.ia_itom\000uncore_cha\000uncore cache\000TOR Inserts;ItoM from Local IA. Unit: uncore_cha \000event=0x35,umask=0xcc47ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; ItoM events that are initiated from the Core\000 */
{ 3195953 }, /* unc_cha_tor_inserts.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xcd47ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3197083 }, /* unc_cha_tor_inserts.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccfff01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA\000 */
{ 3197683 }, /* unc_cha_tor_inserts.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7ff01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA\000 */
{ 3198280 }, /* unc_cha_tor_inserts.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7ff01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000 */
{ 3199351 }, /* unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts; misses from Local IA. Unit: uncore_cha \000event=0x35,umask=0xc001fe01\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3200569 }, /* unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts for CRd misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc80ffe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode CRd\000 */
{ 3200814 }, /* unc_cha_tor_inserts.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc80efe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3202059 }, /* unc_cha_tor_inserts.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88ffe01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3202292 }, /* unc_cha_tor_inserts.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc88efe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3203139 }, /* unc_cha_tor_inserts.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc88f7e01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3203991 }, /* unc_cha_tor_inserts.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Inserts : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc80f7e01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3204815 }, /* unc_cha_tor_inserts.ia_miss_crdmorph_cxl_acc\000uncore_cha\000uncore cache\000CRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c80b8201\000\00001\000\000 */
{ 3205053 }, /* unc_cha_tor_inserts.ia_miss_cxl_acc\000uncore_cha\000uncore cache\000All requests issued from IA cores to CXL accelerator memory regions that miss the LLC. Unit: uncore_cha \000event=0x35,umask=0x10c0018201\000\00001\000\000 */
{ 3205253 }, /* unc_cha_tor_inserts.ia_miss_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008201\000\00001\000\000 */
{ 3206261 }, /* unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc817fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd\000 */
{ 3206506 }, /* unc_cha_tor_inserts.ia_miss_drd_cxl_acc\000uncore_cha\000uncore cache\000DRds issued from an IA core which miss the L3 and target memory in a CXL type 2 memory expander card. Unit: uncore_cha \000event=0x35,umask=0x10c8178201\000\00001\000\000 */
{ 3206725 }, /* unc_cha_tor_inserts.ia_miss_drd_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8168201\000\00001\000\000 */
{ 3207360 }, /* unc_cha_tor_inserts.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Inserts for DRds issued by IA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178601\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target DDR memory\000 */
{ 3208124 }, /* unc_cha_tor_inserts.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA targeting local memory. Unit: uncore_cha \000event=0x35,umask=0xc816fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target local memory\000 */
{ 3208429 }, /* unc_cha_tor_inserts.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3209313 }, /* unc_cha_tor_inserts.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8168a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3210618 }, /* unc_cha_tor_inserts.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc827fe01\000\00001\000TOR Inserts; Data read opt from local IA that misses in the snoop filter\000 */
{ 3210844 }, /* unc_cha_tor_inserts.ia_miss_drd_opt_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_OPT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8268201\000\00001\000\000 */
{ 3211474 }, /* unc_cha_tor_inserts.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts; DRd Opt Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8a7fe01\000\00001\000TOR Inserts; Data read opt prefetch from local IA that misses in the snoop filter\000 */
{ 3211719 }, /* unc_cha_tor_inserts.ia_miss_drd_opt_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_OPT_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8a68201\000\00001\000\000 */
{ 3212372 }, /* unc_cha_tor_inserts.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Inserts for DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8178a01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target PMM memory\000 */
{ 3213113 }, /* unc_cha_tor_inserts.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc897fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF\000 */
{ 3213373 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_cxl_acc\000uncore_cha\000uncore cache\000L2 data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8978201\000\00001\000\000 */
{ 3213602 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8968201\000\00001\000\000 */
{ 3213796 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3214645 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA targeting local memory. Unit: uncore_cha \000event=0x35,umask=0xc896fe01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF, and target local memory\000 */
{ 3215198 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3216107 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8968a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3217016 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8978a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3217865 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts for DRd Pref misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8977e01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRD_PREF, and target remote memory\000 */
{ 3218423 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3219337 }, /* unc_cha_tor_inserts.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8970a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3220703 }, /* unc_cha_tor_inserts.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Inserts for DRd misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x35,umask=0xc8177e01\000\00001\000Inserts into the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and target remote memory\000 */
{ 3221005 }, /* unc_cha_tor_inserts.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3221894 }, /* unc_cha_tor_inserts.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8170a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3222783 }, /* unc_cha_tor_inserts.ia_miss_drdmorph_cxl_acc\000uncore_cha\000uncore cache\000DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8138201\000\00001\000\000 */
{ 3223021 }, /* unc_cha_tor_inserts.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fe01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3225778 }, /* unc_cha_tor_inserts.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xcc47fe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3226966 }, /* unc_cha_tor_inserts.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefCode misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xcccffe01\000\00001\000TOR Inserts; Last level cache prefetch code read from local IA that misses in the snoop filter\000 */
{ 3227222 }, /* unc_cha_tor_inserts.ia_miss_llcprefcode_cxl_acc\000uncore_cha\000uncore cache\000LLC Prefetch Code transactions issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10cccf8201\000\00001\000\000 */
{ 3228063 }, /* unc_cha_tor_inserts.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefData misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xccd7fe01\000\00001\000TOR Inserts; Last level cache prefetch data read from local IA that misses in the snoop filter\000 */
{ 3228319 }, /* unc_cha_tor_inserts.ia_miss_llcprefdata_cxl_acc\000uncore_cha\000uncore cache\000LLC data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10ccd78201\000\00001\000\000 */
{ 3228552 }, /* unc_cha_tor_inserts.ia_miss_llcprefdata_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFDATA_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccd68201\000\00001\000\000 */
{ 3229786 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts; LLCPrefRFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xccc7fe01\000\00001\000TOR Inserts; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000 */
{ 3230049 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo_cxl_acc\000uncore_cha\000uncore cache\000L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8878201\000\00001\000\000 */
{ 3230279 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFRFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8868201\000\00001\000\000 */
{ 3230477 }, /* unc_cha_tor_inserts.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3231354 }, /* unc_cha_tor_inserts.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc86e8a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3232231 }, /* unc_cha_tor_inserts.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3233113 }, /* unc_cha_tor_inserts.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x35,umask=0xc8668a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3236331 }, /* unc_cha_tor_inserts.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3237213 }, /* unc_cha_tor_inserts.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc86f0a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3238095 }, /* unc_cha_tor_inserts.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3239477 }, /* unc_cha_tor_inserts.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x35,umask=0xc8670a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3240706 }, /* unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807fe01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3240929 }, /* unc_cha_tor_inserts.ia_miss_rfo_cxl_acc\000uncore_cha\000uncore cache\000RFOs issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8078201\000\00001\000\000 */
{ 3241139 }, /* unc_cha_tor_inserts.ia_miss_rfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_RFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8068201\000\00001\000\000 */
{ 3241772 }, /* unc_cha_tor_inserts.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Inserts RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc806fe01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3242426 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO pref misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887fe01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3242668 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_cxl_acc\000uncore_cha\000uncore cache\000LLC RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10ccc78201\000\00001\000\000 */
{ 3242897 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_RFO_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccc68201\000\00001\000\000 */
{ 3243555 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Inserts; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc886fe01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3244274 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Inserts; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8877e01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3244979 }, /* unc_cha_tor_inserts.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc8077e01\000\00001\000TOR Inserts Read for ownership from local IA that misses in the snoop filter\000 */
{ 3245208 }, /* unc_cha_tor_inserts.ia_miss_rfomorph_cxl_acc\000uncore_cha\000uncore cache\000RFO and L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x35,umask=0x10c8038201\000\00001\000\000 */
{ 3245870 }, /* unc_cha_tor_inserts.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc877de01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3246630 }, /* unc_cha_tor_inserts.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3247397 }, /* unc_cha_tor_inserts.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3248214 }, /* unc_cha_tor_inserts.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86f8a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3249031 }, /* unc_cha_tor_inserts.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3249800 }, /* unc_cha_tor_inserts.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678601\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3250622 }, /* unc_cha_tor_inserts.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Inserts : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8678a01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3251444 }, /* unc_cha_tor_inserts.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Inserts : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc87fde01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3252560 }, /* unc_cha_tor_inserts.ia_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO from local IA. Unit: uncore_cha \000event=0x35,umask=0xc807ff01\000\00001\000TOR Inserts; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3253152 }, /* unc_cha_tor_inserts.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts; RFO pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc887ff01\000\00001\000TOR Inserts; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3253763 }, /* unc_cha_tor_inserts.ia_specitom\000uncore_cha\000uncore cache\000TOR Inserts;SpecItoM from Local IA. Unit: uncore_cha \000event=0x35,umask=0xcc57ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; SpecItoM events that are initiated from the Core\000 */
{ 3254072 }, /* unc_cha_tor_inserts.ia_wbeftoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc3fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3254494 }, /* unc_cha_tor_inserts.ia_wbeftoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc37ff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3255338 }, /* unc_cha_tor_inserts.ia_wbmtoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc2fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3256178 }, /* unc_cha_tor_inserts.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by an iA Cores. Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc27ff01\000\00001\000WbMtoIs issued by iA Cores .  (Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3256589 }, /* unc_cha_tor_inserts.ia_wbstoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc67ff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3257429 }, /* unc_cha_tor_inserts.ia_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc86fff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3258126 }, /* unc_cha_tor_inserts.ia_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc867ff01\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3259471 }, /* unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts; All from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3259786 }, /* unc_cha_tor_inserts.io_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8c3ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3261161 }, /* unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3261892 }, /* unc_cha_tor_inserts.io_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3262222 }, /* unc_cha_tor_inserts.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fd04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3263147 }, /* unc_cha_tor_inserts.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur and FsRdCur hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3fd04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3263966 }, /* unc_cha_tor_inserts.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO hits from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803fd04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3264667 }, /* unc_cha_tor_inserts.io_itom\000uncore_cha\000uncore cache\000TOR Inserts for ItoM from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43ff04\000\00001\000Inserts into the TOR from local IO with the opcode ItoM\000 */
{ 3266133 }, /* unc_cha_tor_inserts.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts for ItoMCacheNears from IO devices. Unit: uncore_cha \000event=0x35,umask=0xcd43ff04\000\00001\000Inserts into the TOR from local IO devices with the opcode ItoMCacheNears.  This event indicates a partial write request\000 */
{ 3268067 }, /* unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc001fe04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3269195 }, /* unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xcc43fe04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3269528 }, /* unc_cha_tor_inserts.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fe04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3270467 }, /* unc_cha_tor_inserts.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur and FsRdCur misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3fe04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3272038 }, /* unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803fe04\000\00001\000TOR Inserts : RFOs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3272816 }, /* unc_cha_tor_inserts.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts for RdCur from local IO. Unit: uncore_cha \000event=0x35,umask=0xc8f3ff04\000\00001\000Inserts into the TOR from local IO with the opcode RdCur\000 */
{ 3273386 }, /* unc_cha_tor_inserts.io_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO from local IO. Unit: uncore_cha \000event=0x35,umask=0xc803ff04\000\00001\000TOR Inserts : RFOs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3273747 }, /* unc_cha_tor_inserts.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc23ff04\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3274776 }, /* unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts : IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000TOR Inserts : IPQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3276067 }, /* unc_cha_tor_inserts.irq_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - iA. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000TOR Inserts : IRQ - iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : From an iA Core\000 */
{ 3276687 }, /* unc_cha_tor_inserts.irq_non_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - Non iA. Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000TOR Inserts : IRQ - Non iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3277278 }, /* unc_cha_tor_inserts.isoc\000uncore_cha\000uncore cache\000TOR Inserts : Just ISOC. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just ISOC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3277930 }, /* unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff05\000\00001\000TOR Inserts : All from Local iA and IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally initiated requests\000 */
{ 3278788 }, /* unc_cha_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA. Unit: uncore_cha \000event=0x35,umask=0xc000ff01\000\00001\000TOR Inserts : All from Local iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally initiated requests from iA Cores\000 */
{ 3279510 }, /* unc_cha_tor_inserts.loc_io\000uncore_cha\000uncore cache\000TOR Inserts : All from Local IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff04\000\00001\000TOR Inserts : All from Local IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All locally generated IO traffic\000 */
{ 3280172 }, /* unc_cha_tor_inserts.local_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Local Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Local Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3280862 }, /* unc_cha_tor_inserts.match_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3281533 }, /* unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts : Just Misses. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Misses : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3282843 }, /* unc_cha_tor_inserts.mmcfg\000uncore_cha\000uncore cache\000TOR Inserts : MMCFG Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMCFG Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3283099 }, /* unc_cha_tor_inserts.mmio\000uncore_cha\000uncore cache\000TOR Inserts : MMIO Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMIO Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3283680 }, /* unc_cha_tor_inserts.nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3284273 }, /* unc_cha_tor_inserts.noncoh\000uncore_cha\000uncore cache\000TOR Inserts : Just NonCoherent. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NonCoherent : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3284876 }, /* unc_cha_tor_inserts.not_nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NotNearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NotNearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3285144 }, /* unc_cha_tor_inserts.pmm\000uncore_cha\000uncore cache\000TOR Inserts : PMM Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : PM Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3286156 }, /* unc_cha_tor_inserts.premorph_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3287111 }, /* unc_cha_tor_inserts.prq_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - IOSF. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000TOR Inserts : PRQ - IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : From a PCIe Device\000 */
{ 3287746 }, /* unc_cha_tor_inserts.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - Non IOSF. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000TOR Inserts : PRQ - Non IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3288024 }, /* unc_cha_tor_inserts.rem_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ffc8\000\00001\000TOR Inserts : All from Remote : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All remote requests (e.g. snoops, writebacks) that came from remote sockets\000 */
{ 3288507 }, /* unc_cha_tor_inserts.rem_snps\000uncore_cha\000uncore cache\000TOR Inserts : All Snoops from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ff08\000\00001\000TOR Inserts : All Snoops from Remote : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. : All snoops to this LLC that came from remote sockets\000 */
{ 3289204 }, /* unc_cha_tor_inserts.remote_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Remote Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Remote Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3289796 }, /* unc_cha_tor_inserts.rrq\000uncore_cha\000uncore cache\000TOR Inserts : RRQ. Unit: uncore_cha \000event=0x35,umask=0x40\000\00001\000TOR Inserts : RRQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3290290 }, /* unc_cha_tor_inserts.snps_from_rem\000uncore_cha\000uncore cache\000TOR Inserts; All Snoops from Remote. Unit: uncore_cha \000event=0x35,umask=0xc001ff08\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent. All snoops to this LLC that came from remote sockets\000 */
{ 3290922 }, /* unc_cha_tor_inserts.wbq\000uncore_cha\000uncore cache\000TOR Inserts : WBQ. Unit: uncore_cha \000event=0x35,umask=0x80\000\00001\000TOR Inserts : WBQ : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3291416 }, /* unc_cha_tor_occupancy.all\000uncore_cha\000uncore cache\000TOR Occupancy : All. Unit: uncore_cha \000event=0x36,umask=0xc001ffff\000\00001\000TOR Occupancy : All : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3293214 }, /* unc_cha_tor_occupancy.ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DDR Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : DDR Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent\000 */
{ 3294274 }, /* unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy : SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000TOR Occupancy : SF/LLC Evictions : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3295333 }, /* unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy : Just Hits. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Hits : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3296710 }, /* unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy; All from local IA. Unit: uncore_cha \000event=0x36,umask=0xc001ff01\000\00001\000TOR Occupancy : All requests from iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297090 }, /* unc_cha_tor_occupancy.ia_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8c7ff01\000\00001\000TOR Occupancy : CLFlushes issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297492 }, /* unc_cha_tor_occupancy.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8d7ff01\000\00001\000TOR Occupancy : CLFlushOpts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3298289 }, /* unc_cha_tor_occupancy.ia_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80fff01\000\00001\000TOR Occupancy; Code read from local IA that misses in the snoop filter\000 */
{ 3298497 }, /* unc_cha_tor_occupancy.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88fff01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3299112 }, /* unc_cha_tor_occupancy.ia_drd\000uncore_cha\000uncore cache\000TOR Occupancy; DRd from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817ff01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3299720 }, /* unc_cha_tor_occupancy.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827ff01\000\00001\000TOR Occupancy; Data read opt from local IA that misses in the snoop filter\000 */
{ 3300355 }, /* unc_cha_tor_occupancy.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7ff01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that misses in the snoop filter\000 */
{ 3300997 }, /* unc_cha_tor_occupancy.ia_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897ff01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3301224 }, /* unc_cha_tor_occupancy.ia_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837ff01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3302823 }, /* unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc001fd01\000\00001\000TOR Occupancy : All requests from iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3304087 }, /* unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80ffd01\000\00001\000TOR Occupancy; Code read from local IA that hits in the snoop filter\000 */
{ 3304743 }, /* unc_cha_tor_occupancy.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88ffd01\000\00001\000TOR Occupancy; Code read prefetch from local IA that hits in the snoop filter\000 */
{ 3304977 }, /* unc_cha_tor_occupancy.ia_hit_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for All requests issued from IA cores to CXL accelerator memory regions that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x10c0018101\000\00001\000\000 */
{ 3305195 }, /* unc_cha_tor_occupancy.ia_hit_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008101\000\00001\000\000 */
{ 3306235 }, /* unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy; DRd hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817fd01\000\00001\000TOR Occupancy; Data read from local IA that hits in the snoop filter\000 */
{ 3306888 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827fd01\000\00001\000TOR Occupancy; Data read opt from local IA that hits in the snoop filter\000 */
{ 3307568 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7fd01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that hits in the snoop filter\000 */
{ 3308255 }, /* unc_cha_tor_occupancy.ia_hit_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897fd01\000\00001\000TOR Occupancy; Data read prefetch from local IA that hits in the snoop filter\000 */
{ 3308489 }, /* unc_cha_tor_occupancy.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837fd01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3309469 }, /* unc_cha_tor_occupancy.ia_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fd01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Hit LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3310338 }, /* unc_cha_tor_occupancy.ia_hit_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccffd01\000\00001\000TOR Occupancy; Last level cache prefetch code read from local IA that hits in the snoop filter\000 */
{ 3311209 }, /* unc_cha_tor_occupancy.ia_hit_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7fd01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that hits in the snoop filter\000 */
{ 3312532 }, /* unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7fd01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that hits in the snoop filter\000 */
{ 3313658 }, /* unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807fd01\000\00001\000TOR Occupancy; Read for ownership from local IA that hits in the snoop filter\000 */
{ 3314323 }, /* unc_cha_tor_occupancy.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO Pref hits from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887fd01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that hits in the snoop filter\000 */
{ 3314566 }, /* unc_cha_tor_occupancy.ia_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc47ff01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3314957 }, /* unc_cha_tor_occupancy.ia_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcd47ff01\000\00001\000TOR Occupancy : ItoMCacheNears issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3315785 }, /* unc_cha_tor_occupancy.ia_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccfff01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA\000 */
{ 3316413 }, /* unc_cha_tor_occupancy.ia_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7ff01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that misses in the snoop filter\000 */
{ 3317070 }, /* unc_cha_tor_occupancy.ia_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7ff01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000 */
{ 3317762 }, /* unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local IA. Unit: uncore_cha \000event=0x36,umask=0xc001fe01\000\00001\000TOR Occupancy : All requests from iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3319316 }, /* unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy; CRd misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc80ffe01\000\00001\000TOR Occupancy; Code read from local IA that misses in the snoop filter\000 */
{ 3319536 }, /* unc_cha_tor_occupancy.ia_miss_crd_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc80efe01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3320453 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88ffe01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3320692 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc88efe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3321178 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc88f7e01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3321667 }, /* unc_cha_tor_occupancy.ia_miss_crd_remote\000uncore_cha\000uncore cache\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc80f7e01\000\00001\000TOR Occupancy : CRd issued by iA Cores that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3322139 }, /* unc_cha_tor_occupancy.ia_miss_crdmorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for CRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c80b8201\000\00001\000\000 */
{ 3322397 }, /* unc_cha_tor_occupancy.ia_miss_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for All requests issued from IA cores to CXL accelerator memory regions that miss the LLC. Unit: uncore_cha \000event=0x36,umask=0x10c0018201\000\00001\000\000 */
{ 3322617 }, /* unc_cha_tor_occupancy.ia_miss_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c0008201\000\00001\000\000 */
{ 3323673 }, /* unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc817fe01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd\000 */
{ 3323942 }, /* unc_cha_tor_occupancy.ia_miss_drd_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 memory expander card. Unit: uncore_cha \000event=0x36,umask=0x10c8178201\000\00001\000\000 */
{ 3324204 }, /* unc_cha_tor_occupancy.ia_miss_drd_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8168201\000\00001\000\000 */
{ 3324865 }, /* unc_cha_tor_occupancy.ia_miss_drd_ddr\000uncore_cha\000uncore cache\000TOR Occupancy for DRds issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178601\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target DDR memory\000 */
{ 3325675 }, /* unc_cha_tor_occupancy.ia_miss_drd_local\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA targeting local memory. Unit: uncore_cha \000event=0x36,umask=0xc816fe01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target local memory\000 */
{ 3326004 }, /* unc_cha_tor_occupancy.ia_miss_drd_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3326515 }, /* unc_cha_tor_occupancy.ia_miss_drd_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8168a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3327469 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc827fe01\000\00001\000TOR Occupancy; Data read opt from local IA that misses in the snoop filter\000 */
{ 3327701 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_OPT_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8268201\000\00001\000\000 */
{ 3328357 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Opt Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8a7fe01\000\00001\000TOR Occupancy; Data read opt prefetch from local IA that misses in the snoop filter\000 */
{ 3328608 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_OPT_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8a68201\000\00001\000\000 */
{ 3329287 }, /* unc_cha_tor_occupancy.ia_miss_drd_pmm\000uncore_cha\000uncore cache\000TOR Occupancy for DRds issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8178a01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target PMM memory\000 */
{ 3330074 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc897fe01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3330313 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for L2 data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8978201\000\00001\000\000 */
{ 3330562 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8968201\000\00001\000\000 */
{ 3330760 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3331248 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc896fe01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3331493 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3332019 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_local_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8968a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3332545 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8978a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3333033 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy; DRd Pref misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8977e01\000\00001\000TOR Occupancy; Data read prefetch from local IA that misses in the snoop filter\000 */
{ 3333279 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970601\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3333808 }, /* unc_cha_tor_occupancy.ia_miss_drd_pref_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8970a01\000\00001\000TOR Occupancy : DRd_Prefs issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3334811 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote\000uncore_cha\000uncore cache\000TOR Occupancy for DRd misses from local IA targeting remote memory. Unit: uncore_cha \000event=0x36,umask=0xc8177e01\000\00001\000Number of cycles for elements in the TOR from local IA cores which miss the LLC and snoop filter with the opcode DRd, and which target remote memory\000 */
{ 3335143 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170601\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting DDR Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3335657 }, /* unc_cha_tor_occupancy.ia_miss_drd_remote_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8170a01\000\00001\000TOR Occupancy : DRds issued by iA Cores targeting PMM Mem that Missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3336171 }, /* unc_cha_tor_occupancy.ia_miss_drdmorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for DRds and equivalent opcodes issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8138201\000\00001\000\000 */
{ 3336429 }, /* unc_cha_tor_occupancy.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xc837fe01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3339125 }, /* unc_cha_tor_occupancy.ia_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xcc47fe01\000\00001\000TOR Occupancy : ItoMs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3340008 }, /* unc_cha_tor_occupancy.ia_miss_llcprefcode\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefCode misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xcccffe01\000\00001\000TOR Occupancy; Last level cache prefetch code read from local IA that misses in the snoop filter\000 */
{ 3340270 }, /* unc_cha_tor_occupancy.ia_miss_llcprefcode_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC Prefetch Code transactions issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10cccf8201\000\00001\000\000 */
{ 3341157 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdata\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefData misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xccd7fe01\000\00001\000TOR Occupancy; Last level cache prefetch data read from local IA that misses in the snoop filter\000 */
{ 3341419 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdata_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC data prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10ccd78201\000\00001\000\000 */
{ 3341672 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdata_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LLCPREFDATA_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccd68201\000\00001\000\000 */
{ 3342958 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy; LLCPrefRFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xccc7fe01\000\00001\000TOR Occupancy; Last level cache prefetch read for ownership from local IA that misses in the snoop filter\000 */
{ 3343227 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8878201\000\00001\000\000 */
{ 3343477 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LLCPREFRFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8868201\000\00001\000\000 */
{ 3343679 }, /* unc_cha_tor_occupancy.ia_miss_local_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3344185 }, /* unc_cha_tor_occupancy.ia_miss_local_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc86e8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3344691 }, /* unc_cha_tor_occupancy.ia_miss_local_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3345200 }, /* unc_cha_tor_occupancy.ia_miss_local_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally. Unit: uncore_cha \000event=0x36,umask=0xc8668a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed locally : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3347425 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3347934 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc86f0a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3348443 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3348955 }, /* unc_cha_tor_occupancy.ia_miss_remote_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely. Unit: uncore_cha \000event=0x36,umask=0xc8670a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC - HOMed remotely : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3350343 }, /* unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807fe01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3350572 }, /* unc_cha_tor_occupancy.ia_miss_rfo_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for RFOs issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8078201\000\00001\000\000 */
{ 3350802 }, /* unc_cha_tor_occupancy.ia_miss_rfo_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_RFO_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10c8068201\000\00001\000\000 */
{ 3351461 }, /* unc_cha_tor_occupancy.ia_miss_rfo_local\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc806fe01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3352144 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887fe01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3352396 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for LLC RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10ccc78201\000\00001\000\000 */
{ 3352645 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_cxl_acc_local\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_RFO_PREF_CXL_ACC_LOCAL. Unit: uncore_cha \000event=0x35,ch_mask=0x000,umask=0x10ccc68201\000\00001\000\000 */
{ 3353329 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_local\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc886fe01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3354076 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref_remote\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8877e01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3354809 }, /* unc_cha_tor_occupancy.ia_miss_rfo_remote\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc8077e01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3355045 }, /* unc_cha_tor_occupancy.ia_miss_rfomorph_cxl_acc\000uncore_cha\000uncore cache\000TOR Occupancy for RFO and L2 RFO prefetches issued from an IA core which miss the L3 and target memory in a CXL type 2 accelerator. Unit: uncore_cha \000event=0x36,umask=0x10c8038201\000\00001\000\000 */
{ 3355744 }, /* unc_cha_tor_occupancy.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc877de01\000\00001\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3356175 }, /* unc_cha_tor_occupancy.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3356611 }, /* unc_cha_tor_occupancy.ia_miss_wcil_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8601\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357079 }, /* unc_cha_tor_occupancy.ia_miss_wcil_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86f8a01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357547 }, /* unc_cha_tor_occupancy.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357984 }, /* unc_cha_tor_occupancy.ia_miss_wcilf_ddr\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678601\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting DDR that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3358455 }, /* unc_cha_tor_occupancy.ia_miss_wcilf_pmm\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8678a01\000\00001\000TOR Occupancy : WCiLFs issued by iA Cores targeting PMM that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3358926 }, /* unc_cha_tor_occupancy.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc87fde01\000\00001\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3359739 }, /* unc_cha_tor_occupancy.ia_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO from local IA. Unit: uncore_cha \000event=0x36,umask=0xc807ff01\000\00001\000TOR Occupancy; Read for ownership from local IA that misses in the snoop filter\000 */
{ 3360359 }, /* unc_cha_tor_occupancy.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy; RFO prefetch from local IA. Unit: uncore_cha \000event=0x36,umask=0xc887ff01\000\00001\000TOR Occupancy; Read for ownership prefetch from local IA that misses in the snoop filter\000 */
{ 3360599 }, /* unc_cha_tor_occupancy.ia_specitom\000uncore_cha\000uncore cache\000TOR Occupancy : SpecItoMs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc57ff01\000\00001\000TOR Occupancy : SpecItoMs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361002 }, /* unc_cha_tor_occupancy.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc27ff01\000\00001\000TOR Occupancy : WbMtoIs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361399 }, /* unc_cha_tor_occupancy.ia_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc86fff01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361790 }, /* unc_cha_tor_occupancy.ia_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc867ff01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3362872 }, /* unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy; All from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001ff04\000\00001\000TOR Occupancy : All requests from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3363254 }, /* unc_cha_tor_occupancy.io_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8c3ff04\000\00001\000TOR Occupancy : CLFlushes issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3364359 }, /* unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001fd04\000\00001\000TOR Occupancy : All requests from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3365196 }, /* unc_cha_tor_occupancy.io_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43fd04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3365608 }, /* unc_cha_tor_occupancy.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fd04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3366577 }, /* unc_cha_tor_occupancy.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3fd04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3367440 }, /* unc_cha_tor_occupancy.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO hits from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803fd04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3368244 }, /* unc_cha_tor_occupancy.io_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43ff04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3368630 }, /* unc_cha_tor_occupancy.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x36,ch_mask=0x00000000,fc_mask=0x00000000,umask=0xcd43ff04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3370349 }, /* unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc001fe04\000\00001\000TOR Occupancy : All requests from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3371597 }, /* unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy; ITOM misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xcc43fe04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372015 }, /* unc_cha_tor_occupancy.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fe04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372998 }, /* unc_cha_tor_occupancy.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3fe04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3374644 }, /* unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; RFO misses from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803fe04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3375466 }, /* unc_cha_tor_occupancy.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy; RdCur and FsRdCur from local IO. Unit: uncore_cha \000event=0x36,umask=0xc8f3ff04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3376265 }, /* unc_cha_tor_occupancy.io_rfo\000uncore_cha\000uncore cache\000TOR Occupancy; ItoM from local IO. Unit: uncore_cha \000event=0x36,umask=0xc803ff04\000\00001\000TOR Occupancy : RFOs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3376649 }, /* unc_cha_tor_occupancy.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc23ff04\000\00001\000TOR Occupancy : WbMtoIs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3377388 }, /* unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy : IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000TOR Occupancy : IPQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3378776 }, /* unc_cha_tor_occupancy.irq_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - iA. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000TOR Occupancy : IRQ - iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : From an iA Core\000 */
{ 3379442 }, /* unc_cha_tor_occupancy.irq_non_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - Non iA. Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000TOR Occupancy : IRQ - Non iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3380080 }, /* unc_cha_tor_occupancy.isoc\000uncore_cha\000uncore cache\000TOR Occupancy : Just ISOC. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just ISOC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3380779 }, /* unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA and IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff05\000\00001\000TOR Occupancy : All from Local iA and IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally initiated requests\000 */
{ 3381740 }, /* unc_cha_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA. Unit: uncore_cha \000event=0x36,umask=0xc000ff01\000\00001\000TOR Occupancy : All from Local iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally initiated requests from iA Cores\000 */
{ 3382508 }, /* unc_cha_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff04\000\00001\000TOR Occupancy : All from Local IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All locally generated IO traffic\000 */
{ 3383216 }, /* unc_cha_tor_occupancy.local_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Local Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Local Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3383953 }, /* unc_cha_tor_occupancy.match_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3384671 }, /* unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy : Just Misses. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Misses : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3386050 }, /* unc_cha_tor_occupancy.mmcfg\000uncore_cha\000uncore cache\000TOR Occupancy : MMCFG Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMCFG Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3386331 }, /* unc_cha_tor_occupancy.mmio\000uncore_cha\000uncore cache\000TOR Occupancy : MMIO Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMIO Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3386959 }, /* unc_cha_tor_occupancy.nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3387599 }, /* unc_cha_tor_occupancy.noncoh\000uncore_cha\000uncore cache\000TOR Occupancy : Just NonCoherent. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NonCoherent : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3388249 }, /* unc_cha_tor_occupancy.not_nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NotNearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NotNearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3388884 }, /* unc_cha_tor_occupancy.pmm\000uncore_cha\000uncore cache\000TOR Occupancy : PMM Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : PMM Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent\000 */
{ 3389619 }, /* unc_cha_tor_occupancy.premorph_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3390391 }, /* unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - IOSF. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000TOR Occupancy : PRQ - IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : From a PCIe Device\000 */
{ 3391315 }, /* unc_cha_tor_occupancy.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - Non IOSF. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000TOR Occupancy : PRQ - Non IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3391618 }, /* unc_cha_tor_occupancy.rem_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ffc8\000\00001\000TOR Occupancy : All from Remote : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All remote requests (e.g. snoops, writebacks) that came from remote sockets\000 */
{ 3392002 }, /* unc_cha_tor_occupancy.rem_snps\000uncore_cha\000uncore cache\000TOR Occupancy : All Snoops from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ff08\000\00001\000TOR Occupancy : All Snoops from Remote : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T : All snoops to this LLC that came from remote sockets\000 */
{ 3392745 }, /* unc_cha_tor_occupancy.remote_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Remote Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Remote Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3393045 }, /* unc_cha_tor_occupancy.rrq\000uncore_cha\000uncore cache\000TOR Occupancy : RRQ. Unit: uncore_cha \000event=0x36,umask=0x40\000\00001\000TOR Occupancy : RRQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3393317 }, /* unc_cha_tor_occupancy.snps_from_rem\000uncore_cha\000uncore cache\000TOR Occupancy; All Snoops from Remote. Unit: uncore_cha \000event=0x36,umask=0xc001ff08\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   All snoops to this LLC that came from remote sockets\000 */
{ 3393652 }, /* unc_cha_tor_occupancy.wbq\000uncore_cha\000uncore cache\000TOR Occupancy : WBQ. Unit: uncore_cha \000event=0x36,umask=0x80\000\00001\000TOR Occupancy : WBQ : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3516248 }, /* unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000WbPushMtoI : Pushed to LLC : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was able to push WbPushMToI to LLC\000 */
{ 3516797 }, /* unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000WbPushMtoI : Pushed to Memory : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000 */
{ 3519063 }, /* unc_cha_write_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC0 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 0 only\000 */
{ 3521670 }, /* unc_cha_write_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC1 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 1 only\000 */
{ 3522525 }, /* unc_cha_write_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC2 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 2 only\000 */
{ 3522969 }, /* unc_cha_write_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC3 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 3 only\000 */
{ 3523413 }, /* unc_cha_write_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC4 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 4 only\000 */
{ 3523858 }, /* unc_cha_write_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC5 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 5 only\000 */
{ 3526061 }, /* unc_cha_xpt_pref.drop0_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x8\000\00001\000XPT Prefetches : Dropped (on 0?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526320 }, /* unc_cha_xpt_pref.drop0_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x4\000\00001\000XPT Prefetches : Dropped (on 0?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3526581 }, /* unc_cha_xpt_pref.drop1_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x80\000\00001\000XPT Prefetches : Dropped (on 1?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526841 }, /* unc_cha_xpt_pref.drop1_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x40\000\00001\000XPT Prefetches : Dropped (on 1?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3527103 }, /* unc_cha_xpt_pref.sent0\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 0?). Unit: uncore_cha \000event=0x6f,umask=0x1\000\00001\000XPT Prefetches : Sent (on 0?) : Number of XPT prefetches sent\000 */
{ 3527286 }, /* unc_cha_xpt_pref.sent1\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 1?). Unit: uncore_cha \000event=0x6f,umask=0x10\000\00001\000XPT Prefetches : Sent (on 1?) : Number of XPT prefetches sent\000 */
{ 3540785 }, /* unc_cxlcm_clockticks\000uncore_cxlcm\000uncore cxl\000Counts the number of lfclk ticks. Unit: uncore_cxlcm \000event=0x1,umask=0x2\000\00001\000\000 */
{ 3540909 }, /* unc_cxlcm_rxc_agf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx AGF 0. Unit: uncore_cxlcm \000event=0x43,umask=0x8\000\00001\000\000 */
{ 3541055 }, /* unc_cxlcm_rxc_agf_inserts.cache_req0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req AGF0. Unit: uncore_cxlcm \000event=0x43,umask=0x1\000\00001\000\000 */
{ 3541202 }, /* unc_cxlcm_rxc_agf_inserts.cache_req1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x2\000\00001\000\000 */
{ 3541348 }, /* unc_cxlcm_rxc_agf_inserts.cache_rsp0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x4\000\00001\000\000 */
{ 3541495 }, /* unc_cxlcm_rxc_agf_inserts.cache_rsp1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x40\000\00001\000\000 */
{ 3541642 }, /* unc_cxlcm_rxc_agf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req AGF 1. Unit: uncore_cxlcm \000event=0x43,umask=0x20\000\00001\000\000 */
{ 3541789 }, /* unc_cxlcm_rxc_agf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data AGF. Unit: uncore_cxlcm \000event=0x43,umask=0x10\000\00001\000\000 */
{ 3541932 }, /* unc_cxlcm_rxc_flits.ak_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with AK set. Unit: uncore_cxlcm \000event=0x4b,umask=0x10\000\00001\000\000 */
{ 3542069 }, /* unc_cxlcm_rxc_flits.be_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with BE set. Unit: uncore_cxlcm \000event=0x4b,umask=0x20\000\00001\000\000 */
{ 3542206 }, /* unc_cxlcm_rxc_flits.ctrl\000uncore_cxlcm\000uncore cxl\000Count the number of control flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 3542345 }, /* unc_cxlcm_rxc_flits.no_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Headerless flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 3542489 }, /* unc_cxlcm_rxc_flits.prot\000uncore_cxlcm\000uncore cxl\000Count the number of protocol flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 3542629 }, /* unc_cxlcm_rxc_flits.sz_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with SZ set. Unit: uncore_cxlcm \000event=0x4b,umask=0x40\000\00001\000\000 */
{ 3542766 }, /* unc_cxlcm_rxc_flits.valid\000uncore_cxlcm\000uncore cxl\000Count the number of flits received. Unit: uncore_cxlcm \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 3542898 }, /* unc_cxlcm_rxc_flits.valid_msg\000uncore_cxlcm\000uncore cxl\000Count the number of valid messages in the flit. Unit: uncore_cxlcm \000event=0x4b,umask=0x80\000\00001\000\000 */
{ 3543047 }, /* unc_cxlcm_rxc_misc.crc_errors\000uncore_cxlcm\000uncore cxl\000Count the number of CRC errors detected. Unit: uncore_cxlcm \000event=0x40,umask=0x8\000\00001\000\000 */
{ 3543188 }, /* unc_cxlcm_rxc_misc.init\000uncore_cxlcm\000uncore cxl\000Count the number of Init flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x4\000\00001\000\000 */
{ 3543319 }, /* unc_cxlcm_rxc_misc.llcrd\000uncore_cxlcm\000uncore cxl\000Count the number of LLCRD flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x1\000\00001\000\000 */
{ 3543452 }, /* unc_cxlcm_rxc_misc.retry\000uncore_cxlcm\000uncore cxl\000Count the number of Retry flits sent. Unit: uncore_cxlcm \000event=0x40,umask=0x2\000\00001\000\000 */
{ 3543585 }, /* unc_cxlcm_rxc_pack_buf_full.cache_data\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x4\000\00001\000\000 */
{ 3543739 }, /* unc_cxlcm_rxc_pack_buf_full.cache_req\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x1\000\00001\000\000 */
{ 3543892 }, /* unc_cxlcm_rxc_pack_buf_full.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x2\000\00001\000\000 */
{ 3544045 }, /* unc_cxlcm_rxc_pack_buf_full.mem_data\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x10\000\00001\000\000 */
{ 3544198 }, /* unc_cxlcm_rxc_pack_buf_full.mem_req\000uncore_cxlcm\000uncore cxl\000Number of cycles the Packing Buffer is Full. Unit: uncore_cxlcm \000event=0x52,umask=0x8\000\00001\000\000 */
{ 3544349 }, /* unc_cxlcm_rxc_pack_buf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x4\000\00001\000\000 */
{ 3544512 }, /* unc_cxlcm_rxc_pack_buf_inserts.cache_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x1\000\00001\000\000 */
{ 3544673 }, /* unc_cxlcm_rxc_pack_buf_inserts.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x2\000\00001\000\000 */
{ 3544834 }, /* unc_cxlcm_rxc_pack_buf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x10\000\00001\000\000 */
{ 3544994 }, /* unc_cxlcm_rxc_pack_buf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x41,umask=0x8\000\00001\000\000 */
{ 3545151 }, /* unc_cxlcm_rxc_pack_buf_ne.cache_data\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x4\000\00001\000\000 */
{ 3545319 }, /* unc_cxlcm_rxc_pack_buf_ne.cache_req\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x1\000\00001\000\000 */
{ 3545485 }, /* unc_cxlcm_rxc_pack_buf_ne.cache_rsp\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Cache Rsp Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x2\000\00001\000\000 */
{ 3545651 }, /* unc_cxlcm_rxc_pack_buf_ne.mem_data\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x10\000\00001\000\000 */
{ 3545816 }, /* unc_cxlcm_rxc_pack_buf_ne.mem_req\000uncore_cxlcm\000uncore cxl\000Number of cycles of Not Empty for Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x42,umask=0x8\000\00001\000\000 */
{ 3545978 }, /* unc_cxlcm_txc_flits.ak_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with AK set. Unit: uncore_cxlcm \000event=0x5,umask=0x10\000\00001\000\000 */
{ 3546114 }, /* unc_cxlcm_txc_flits.be_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with BE set. Unit: uncore_cxlcm \000event=0x5,umask=0x20\000\00001\000\000 */
{ 3546250 }, /* unc_cxlcm_txc_flits.ctrl\000uncore_cxlcm\000uncore cxl\000Count the number of control flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x4\000\00001\000\000 */
{ 3546386 }, /* unc_cxlcm_txc_flits.no_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Headerless flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x8\000\00001\000\000 */
{ 3546527 }, /* unc_cxlcm_txc_flits.prot\000uncore_cxlcm\000uncore cxl\000Count the number of protocol flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x2\000\00001\000\000 */
{ 3546664 }, /* unc_cxlcm_txc_flits.sz_hdr\000uncore_cxlcm\000uncore cxl\000Count the number of Flits with SZ set. Unit: uncore_cxlcm \000event=0x5,umask=0x40\000\00001\000\000 */
{ 3546800 }, /* unc_cxlcm_txc_flits.valid\000uncore_cxlcm\000uncore cxl\000Count the number of flits packed. Unit: uncore_cxlcm \000event=0x5,umask=0x1\000\00001\000\000 */
{ 3546929 }, /* unc_cxlcm_txc_pack_buf_inserts.cache_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Data Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x4\000\00001\000\000 */
{ 3547091 }, /* unc_cxlcm_txc_pack_buf_inserts.cache_req0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x1\000\00001\000\000 */
{ 3547252 }, /* unc_cxlcm_txc_pack_buf_inserts.cache_req1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp1 Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x40\000\00001\000\000 */
{ 3547415 }, /* unc_cxlcm_txc_pack_buf_inserts.cache_rsp0\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Rsp0 Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x2\000\00001\000\000 */
{ 3547577 }, /* unc_cxlcm_txc_pack_buf_inserts.cache_rsp1\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Cache Req Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x20\000\00001\000\000 */
{ 3547739 }, /* unc_cxlcm_txc_pack_buf_inserts.mem_data\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Data Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x10\000\00001\000\000 */
{ 3547898 }, /* unc_cxlcm_txc_pack_buf_inserts.mem_req\000uncore_cxlcm\000uncore cxl\000Number of Allocation to Mem Rxx Packing buffer. Unit: uncore_cxlcm \000event=0x2,umask=0x8\000\00001\000\000 */
{ 3548054 }, /* unc_cxldp_clockticks\000uncore_cxldp\000uncore cxl\000Counts the number of uclk ticks. Unit: uncore_cxldp \000event=0x1,umask=0x1\000\00001\000\000 */
{ 3548177 }, /* unc_cxldp_txc_agf_inserts.m2s_data\000uncore_cxldp\000uncore cxl\000Number of Allocation to M2S Data AGF. Unit: uncore_cxldp \000event=0x2,umask=0x20\000\00001\000\000 */
{ 3548320 }, /* unc_cxldp_txc_agf_inserts.m2s_req\000uncore_cxldp\000uncore cxl\000Number of Allocation to M2S Req AGF. Unit: uncore_cxldp \000event=0x2,umask=0x10\000\00001\000\000 */
{ 3548461 }, /* unc_cxldp_txc_agf_inserts.u2c_data\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Data AGF. Unit: uncore_cxldp \000event=0x2,umask=0x8\000\00001\000\000 */
{ 3548603 }, /* unc_cxldp_txc_agf_inserts.u2c_req\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Req AGF. Unit: uncore_cxldp \000event=0x2,umask=0x1\000\00001\000\000 */
{ 3548743 }, /* unc_cxldp_txc_agf_inserts.u2c_rsp0\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Rsp AGF 0. Unit: uncore_cxldp \000event=0x2,umask=0x2\000\00001\000\000 */
{ 3548886 }, /* unc_cxldp_txc_agf_inserts.u2c_rsp1\000uncore_cxldp\000uncore cxl\000Number of Allocation to U2C Rsp AGF 1. Unit: uncore_cxldp \000event=0x2,umask=0x4\000\00001\000\000 */
{ 3873110 }, /* unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests to coherent memory. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests to coherent memory.  This is effectively the sum of read occupancy and write occupancy\000 */
{ 3877096 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000IRP Clockticks. Unit: uncore_irp \000event=0x1\000\00001\000Number of IRP clock cycles while the event is enabled\000 */
{ 3881278 }, /* unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000 */
{ 3881371 }, /* unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000FAF - request insert from TC. Unit: uncore_irp \000event=0x18\000\00001\000\000 */
{ 3881807 }, /* unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000FAF occupancy. Unit: uncore_irp \000event=0x19\000\00001\000\000 */
{ 3882126 }, /* unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000 */
{ 3882245 }, /* unc_i_irp_all.evicts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3882382 }, /* unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3882674 }, /* unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3882966 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x10\000\00001\000\000 */
{ 3883580 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x4\000\00001\000\000 */
{ 3884171 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x8\000\00001\000\000 */
{ 3884766 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Rejects. Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 3885218 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Requests. Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 3885674 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x20\000\00001\000\000 */
{ 3886244 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x40\000\00001\000\000 */
{ 3887083 }, /* unc_i_misc0.slowpath_fwpf_no_prf\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Slow path fwpf didn't find prefetch. Unit: uncore_irp \000event=0x1e,umask=0x80\000\00001\000\000 */
{ 3887536 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Lost Forward. Unit: uncore_irp \000event=0x1f,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888161 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Invalid. Unit: uncore_irp \000event=0x1f,umask=0x20\000\00001\000Misc Events - Set 1 : Received Invalid : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3888836 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Valid. Unit: uncore_irp \000event=0x1f,umask=0x40\000\00001\000Misc Events - Set 1 : Received Valid : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889485 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of E Line. Unit: uncore_irp \000event=0x1f,umask=0x4\000\00001\000Misc Events - Set 1 : Slow Transfer of E Line : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890149 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of I Line. Unit: uncore_irp \000event=0x1f,umask=0x1\000\00001\000Misc Events - Set 1 : Slow Transfer of I Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3890819 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of M Line. Unit: uncore_irp \000event=0x1f,umask=0x8\000\00001\000Misc Events - Set 1 : Slow Transfer of M Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3891489 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of S Line. Unit: uncore_irp \000event=0x1f,umask=0x2\000\00001\000Misc Events - Set 1 : Slow Transfer of S Line : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3900346 }, /* unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000 */
{ 3900612 }, /* unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000 */
{ 3900881 }, /* unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000 */
{ 3901139 }, /* unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000 */
{ 3901397 }, /* unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000 */
{ 3901636 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000 */
{ 3902049 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000 */
{ 3902439 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000 */
{ 3902829 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses : Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000 */
{ 3903212 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000 */
{ 3903619 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000 */
{ 3904026 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000 */
{ 3914035 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000 */
{ 3918099 }, /* unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000 */
{ 3918207 }, /* unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000 */
{ 3918327 }, /* unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000 */
{ 3918439 }, /* unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000 */
{ 3918555 }, /* unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000 */
{ 3918675 }, /* unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000 */
{ 3918787 }, /* unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000 */
{ 3918903 }, /* unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000 */
{ 3919023 }, /* unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000 */
{ 3919135 }, /* unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000 */
{ 3919588 }, /* unc_i_txr2_ad01_stall_credit_cycles\000uncore_irp\000uncore interconnect\000UNC_I_TxR2_AD01_STALL_CREDIT_CYCLES. Unit: uncore_irp \000event=0x1c\000\00001\000: Counts the number times when it is not possible to issue a request to the M2PCIe because there are no Egress Credits available on AD0, A1 or AD0AD1 both. Stalls on both AD0 and AD1 will count as 2\000 */
{ 3919924 }, /* unc_i_txr2_ad0_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD0 Egress Credits Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000No AD0 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD0 Egress Credits available\000 */
{ 3920215 }, /* unc_i_txr2_ad1_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD1 Egress Credits Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000No AD1 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD1 Egress Credits available\000 */
{ 3921013 }, /* unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1d\000\00001\000No BL Egress Credit Stalls : Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3923058 }, /* unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923457 }, /* unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3924019 }, /* unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Outbound Request Queue Occupancy : Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 4367980 }, /* unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000M2M Clockticks. Unit: uncore_m2m \000event=0x1\000\00001\000Clockticks of the mesh to memory (M2M)\000 */
{ 4368117 }, /* unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000 */
{ 4368625 }, /* unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2m \000event=0x17,umask=0x7\000\00001\000\000 */
{ 4368221 }, /* unc_m2m_direct2core_not_taken_dirstate.non_cisgress\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress : Counts the number of time non cisgress D2C was not honoured by egress due to directory state constraints\000 */
{ 4369236 }, /* unc_m2m_direct2core_not_taken_notforked\000uncore_m2m\000uncore interconnect\000Counts the time when FM didn't do d2c for fill reads (cross tile case). Unit: uncore_m2m \000event=0x4a\000\00001\000\000 */
{ 4370322 }, /* unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4369765 }, /* unc_m2m_direct2core_txn_override.cisgress\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden : Cisgress. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4369961 }, /* unc_m2m_direct2core_txn_override.pmm_hit\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden : 2LM Hit?. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4370767 }, /* unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2m \000event=0x1b,umask=0x7\000\00001\000\000 */
{ 4372554 }, /* unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to Intel UPI was disabled. Unit: uncore_m2m \000event=0x1a,umask=0x7\000\00001\000\000 */
{ 4371446 }, /* unc_m2m_direct2upi_not_taken_dirstate.cisgress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored. Unit: uncore_m2m \000event=0x1a,umask=0x4\000\00001\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored : Counts cisgress d2K that was not honored due to directory constraints\000 */
{ 4371758 }, /* unc_m2m_direct2upi_not_taken_dirstate.egress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U. Unit: uncore_m2m \000event=0x1a,umask=0x1\000\00001\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U : Counts the number of time D2K was not honoured by egress due to directory state constraints\000 */
{ 4372086 }, /* unc_m2m_direct2upi_not_taken_dirstate.non_cisgress\000uncore_m2m\000uncore interconnect\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored. Unit: uncore_m2m \000event=0x1a,umask=0x2\000\00001\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored : Counts non cisgress d2K that was not honored due to directory constraints\000 */
{ 4372992 }, /* unc_m2m_direct2upi_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to the Intel UPI. Unit: uncore_m2m \000event=0x19,umask=0x7\000\00001\000Counts the number of times egress did D2K (Direct to KTI)\000 */
{ 4373593 }, /* unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x3\000\00001\000\000 */
{ 4373417 }, /* unc_m2m_direct2upi_txn_override.cisgress\000uncore_m2m\000uncore interconnect\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4374264 }, /* unc_m2m_direct2upitxn_override.pmm_hit\000uncore_m2m\000uncore interconnect\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000Number of times a direct to UPI transaction was overridden. : Counts the number of times D2K wasn't honored even though the incoming request had d2k set\000 */
{ 4374590 }, /* unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 4375042 }, /* unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 4375494 }, /* unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 4375946 }, /* unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 4376398 }, /* unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2m \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 4376838 }, /* unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4377278 }, /* unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2m \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 4377718 }, /* unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4378325 }, /* unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000Counts the number of hit data returns to egress with any directory to non persistent memory\000 */
{ 4379068 }, /* unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2m \000event=0x20,umask=0x8\000\00001\000Counts the number of hit data returns to egress with directory A to non persistent memory\000 */
{ 4380030 }, /* unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000Counts the number of hit data returns to egress with directory I to non persistent memory\000 */
{ 4380979 }, /* unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2m \000event=0x20,umask=0x4\000\00001\000Counts the number of hit data returns to egress with directory S to non persistent memory\000 */
{ 4381784 }, /* unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2m \000event=0x1e,umask=0x80\000\00001\000\000 */
{ 4382242 }, /* unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2m \000event=0x1e,umask=0x10\000\00001\000\000 */
{ 4382700 }, /* unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2m \000event=0x1e,umask=0x40\000\00001\000\000 */
{ 4383158 }, /* unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2m \000event=0x1e,umask=0x20\000\00001\000\000 */
{ 4383616 }, /* unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2m \000event=0x1e,umask=0x8\000\00001\000\000 */
{ 4384062 }, /* unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2m \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 4384508 }, /* unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2m \000event=0x1e,umask=0x4\000\00001\000\000 */
{ 4384954 }, /* unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2m \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 4385400 }, /* unc_m2m_directory_update.a2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2m \000event=0x21,umask=0x320\000\00001\000\000 */
{ 4385837 }, /* unc_m2m_directory_update.a2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2m \000event=0x21,umask=0x340\000\00001\000\000 */
{ 4386273 }, /* unc_m2m_directory_update.a_to_i_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x120\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to I to non persistent memory (DRAM or HBM)\000 */
{ 4386560 }, /* unc_m2m_directory_update.a_to_i_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x220\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to I to non persistent memory (DRAM or HBM)\000 */
{ 4386842 }, /* unc_m2m_directory_update.a_to_s_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x140\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to S to non persistent memory (DRAM or HBM)\000 */
{ 4387129 }, /* unc_m2m_directory_update.a_to_s_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x240\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to S to non persistent memory (DRAM or HBM)\000 */
{ 4387623 }, /* unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2m \000event=0x21,umask=0x301\000\00001\000\000 */
{ 4388047 }, /* unc_m2m_directory_update.hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x101\000\00001\000Counts any 1lm or 2lm hit data return that would result in directory update to non persistent memory (DRAM or HBM)\000 */
{ 4388317 }, /* unc_m2m_directory_update.i2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2m \000event=0x21,umask=0x304\000\00001\000\000 */
{ 4388753 }, /* unc_m2m_directory_update.i2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2m \000event=0x21,umask=0x302\000\00001\000\000 */
{ 4389187 }, /* unc_m2m_directory_update.i_to_a_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x104\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to A to non persistent memory (DRAM or HBM)\000 */
{ 4389474 }, /* unc_m2m_directory_update.i_to_a_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x204\000\00001\000Counts 2lm miss  data returns that would result in directory update from I to A to non persistent memory (DRAM or HBM)\000 */
{ 4389756 }, /* unc_m2m_directory_update.i_to_s_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x102\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to S to non persistent memory (DRAM or HBM)\000 */
{ 4390043 }, /* unc_m2m_directory_update.i_to_s_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x202\000\00001\000Counts  2lm miss  data returns that would result in directory update from I to S to non persistent memory (DRAM or HBM)\000 */
{ 4390326 }, /* unc_m2m_directory_update.miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x201\000\00001\000Counts any 2lm miss data return that would result in directory update to non persistent memory (DRAM or HBM)\000 */
{ 4390591 }, /* unc_m2m_directory_update.s2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2m \000event=0x21,umask=0x310\000\00001\000\000 */
{ 4391027 }, /* unc_m2m_directory_update.s2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2m \000event=0x21,umask=0x308\000\00001\000\000 */
{ 4391461 }, /* unc_m2m_directory_update.s_to_a_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x110\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to A to non persistent memory (DRAM or HBM)\000 */
{ 4391748 }, /* unc_m2m_directory_update.s_to_a_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x210\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to A to non persistent memory (DRAM or HBM)\000 */
{ 4392030 }, /* unc_m2m_directory_update.s_to_i_hit_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x108\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to I to non persistent memory (DRAM or HBM)\000 */
{ 4392317 }, /* unc_m2m_directory_update.s_to_i_miss_non_pmm\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory Updates. Unit: uncore_m2m \000event=0x21,umask=0x208\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to I to non persistent memory (DRAM or HBM)\000 */
{ 4396003 }, /* unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2m \000event=0xba,umask=0x80000004\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4396887 }, /* unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2m \000event=0xba,umask=0x80000001\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4425742 }, /* unc_m2m_igr_starve_winner.mask7\000uncore_m2m\000uncore interconnect\000Count when Starve Glocab counter is at 7. Unit: uncore_m2m \000event=0x44,umask=0x80\000\00001\000\000 */
{ 4426062 }, /* unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000Reads to iMC issued. Unit: uncore_m2m \000event=0x24,umask=0x304\000\00001\000\000 */
{ 4426380 }, /* unc_m2m_imc_reads.ch0.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x108\000\00001\000\000 */
{ 4426520 }, /* unc_m2m_imc_reads.ch0.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0.TO_NMCache. Unit: uncore_m2m \000event=0x24,umask=0x110\000\00001\000\000 */
{ 4426829 }, /* unc_m2m_imc_reads.ch0_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_ALL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000\000 */
{ 4427147 }, /* unc_m2m_imc_reads.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x140\000\00001\000\000 */
{ 4427443 }, /* unc_m2m_imc_reads.ch0_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x102\000\00001\000\000 */
{ 4427732 }, /* unc_m2m_imc_reads.ch0_normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_NORMAL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000\000 */
{ 4428075 }, /* unc_m2m_imc_reads.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x110\000\00001\000\000 */
{ 4428379 }, /* unc_m2m_imc_reads.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x108\000\00001\000\000 */
{ 4428775 }, /* unc_m2m_imc_reads.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH0_TO_PMM. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x120\000\00001\000\000 */
{ 4428949 }, /* unc_m2m_imc_reads.ch1.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x208\000\00001\000\000 */
{ 4429089 }, /* unc_m2m_imc_reads.ch1.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1.TO_NMCache. Unit: uncore_m2m \000event=0x24,umask=0x210\000\00001\000\000 */
{ 4429398 }, /* unc_m2m_imc_reads.ch1_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_ALL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000\000 */
{ 4429716 }, /* unc_m2m_imc_reads.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x240\000\00001\000\000 */
{ 4430012 }, /* unc_m2m_imc_reads.ch1_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x202\000\00001\000\000 */
{ 4430301 }, /* unc_m2m_imc_reads.ch1_normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_NORMAL. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000\000 */
{ 4430644 }, /* unc_m2m_imc_reads.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x210\000\00001\000\000 */
{ 4430948 }, /* unc_m2m_imc_reads.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x208\000\00001\000\000 */
{ 4431344 }, /* unc_m2m_imc_reads.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.CH1_TO_PMM. Unit: uncore_m2m \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x220\000\00001\000\000 */
{ 4431823 }, /* unc_m2m_imc_reads.from_tgr\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.FROM_TGR. Unit: uncore_m2m \000event=0x24,umask=0x340\000\00001\000\000 */
{ 4432423 }, /* unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.ISOCH. Unit: uncore_m2m \000event=0x24,umask=0x302\000\00001\000\000 */
{ 4433003 }, /* unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.NORMAL. Unit: uncore_m2m \000event=0x24,umask=0x301\000\00001\000\000 */
{ 4433305 }, /* unc_m2m_imc_reads.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_DDR_AS_CACHE. Unit: uncore_m2m \000event=0x24,umask=0x310\000\00001\000\000 */
{ 4433606 }, /* unc_m2m_imc_reads.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x24,umask=0x308\000\00001\000\000 */
{ 4433748 }, /* unc_m2m_imc_reads.to_nm1lm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_NM1LM. Unit: uncore_m2m \000event=0x24,umask=0x308\000\00001\000\000 */
{ 4433880 }, /* unc_m2m_imc_reads.to_nmcache\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_NMCACHE. Unit: uncore_m2m \000event=0x24,umask=0x310\000\00001\000\000 */
{ 4434402 }, /* unc_m2m_imc_reads.to_pmm\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_READS.TO_PMM. Unit: uncore_m2m \000event=0x24,umask=0x320\000\00001\000\000 */
{ 4434530 }, /* unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000All Writes - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1810\000\00001\000\000 */
{ 4435015 }, /* unc_m2m_imc_writes.ch0.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4435276 }, /* unc_m2m_imc_writes.ch0_all\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_ALL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x810\000\00001\000\000 */
{ 4435446 }, /* unc_m2m_imc_writes.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4435858 }, /* unc_m2m_imc_writes.ch0_full\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_FULL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x801\000\00001\000\000 */
{ 4436191 }, /* unc_m2m_imc_writes.ch0_full_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_FULL_ISOCH. Unit: uncore_m2m \000event=0x25,umask=0x804\000\00001\000\000 */
{ 4436476 }, /* unc_m2m_imc_writes.ch0_ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4436737 }, /* unc_m2m_imc_writes.ch0_ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - Ch0. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4437019 }, /* unc_m2m_imc_writes.ch0_partial\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_PARTIAL. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x802\000\00001\000\000 */
{ 4437359 }, /* unc_m2m_imc_writes.ch0_partial_isoch\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_PARTIAL_ISOCH. Unit: uncore_m2m \000event=0x25,umask=0x808\000\00001\000\000 */
{ 4437511 }, /* unc_m2m_imc_writes.ch0_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - Ch0. Unit: uncore_m2m \000event=0x25,umask=0x840\000\00001\000\000 */
{ 4437978 }, /* unc_m2m_imc_writes.ch0_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000UNC_M2M_IMC_WRITES.CH0_TO_DDR_AS_MEM. Unit: uncore_m2m \000event=0x25,umask=0x820\000\00001\000\000 */
{ 4438393 }, /* unc_m2m_imc_writes.ch0_to_pmm\000uncore_m2m\000uncore interconnect\000PMM - Ch0. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x880\000\00001\000PMM - Ch0 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000 */
{ 4438640 }, /* unc_m2m_imc_writes.ch1.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4438752 }, /* unc_m2m_imc_writes.ch1_all\000uncore_m2m\000uncore interconnect\000All Writes - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1010\000\00001\000\000 */
{ 4439062 }, /* unc_m2m_imc_writes.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4439315 }, /* unc_m2m_imc_writes.ch1_full\000uncore_m2m\000uncore interconnect\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1001\000\00001\000\000 */
{ 4439645 }, /* unc_m2m_imc_writes.ch1_full_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Full Line - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1004\000\00001\000\000 */
{ 4440080 }, /* unc_m2m_imc_writes.ch1_ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4440341 }, /* unc_m2m_imc_writes.ch1_ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - Ch1. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4440623 }, /* unc_m2m_imc_writes.ch1_partial\000uncore_m2m\000uncore interconnect\000Partial Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1002\000\00001\000\000 */
{ 4440795 }, /* unc_m2m_imc_writes.ch1_partial_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Partial - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1008\000\00001\000\000 */
{ 4441093 }, /* unc_m2m_imc_writes.ch1_to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1040\000\00001\000\000 */
{ 4441409 }, /* unc_m2m_imc_writes.ch1_to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000DDR - Ch1. Unit: uncore_m2m \000event=0x25,umask=0x1020\000\00001\000\000 */
{ 4441950 }, /* unc_m2m_imc_writes.ch1_to_pmm\000uncore_m2m\000uncore interconnect\000PMM - Ch1. Unit: uncore_m2m \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1080\000\00001\000PMM - Ch1 : Counts all PMM dimm writes requests(full line and partial) sent from M2M to iMC\000 */
{ 4442198 }, /* unc_m2m_imc_writes.from_tgr\000uncore_m2m\000uncore interconnect\000From TGR - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4442627 }, /* unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000Full Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1801\000\00001\000\000 */
{ 4443071 }, /* unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Full Line - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1804\000\00001\000\000 */
{ 4443823 }, /* unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000Non-Inclusive - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4444094 }, /* unc_m2m_imc_writes.ni_miss\000uncore_m2m\000uncore interconnect\000Non-Inclusive Miss - All Channels. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4444387 }, /* unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000Partial Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1802\000\00001\000\000 */
{ 4444816 }, /* unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000ISOCH Partial - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1808\000\00001\000\000 */
{ 4445274 }, /* unc_m2m_imc_writes.to_ddr_as_cache\000uncore_m2m\000uncore interconnect\000DDR, acting as Cache - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1840\000\00001\000\000 */
{ 4445601 }, /* unc_m2m_imc_writes.to_ddr_as_mem\000uncore_m2m\000uncore interconnect\000DDR - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1820\000\00001\000\000 */
{ 4446041 }, /* unc_m2m_imc_writes.to_pmm\000uncore_m2m\000uncore interconnect\000PMM - All Channels. Unit: uncore_m2m \000event=0x25,umask=0x1880\000\00001\000\000 */
{ 4448579 }, /* unc_m2m_prefcam_cis_drops\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_CIS_DROPS. Unit: uncore_m2m \000event=0x5c\000\00001\000\000 */
{ 4452017 }, /* unc_m2m_prefcam_demand_drops.ch0_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x2\000\00001\000\000 */
{ 4452304 }, /* unc_m2m_prefcam_demand_drops.ch0_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x1\000\00001\000\000 */
{ 4452591 }, /* unc_m2m_prefcam_demand_drops.ch1_upi\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x8\000\00001\000\000 */
{ 4452878 }, /* unc_m2m_prefcam_demand_drops.ch1_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x4\000\00001\000\000 */
{ 4453317 }, /* unc_m2m_prefcam_demand_drops.upi_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2m \000event=0x58,umask=0xa\000\00001\000\000 */
{ 4453799 }, /* unc_m2m_prefcam_demand_drops.xpt_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped. Unit: uncore_m2m \000event=0x58,umask=0x5\000\00001\000\000 */
{ 4454943 }, /* unc_m2m_prefcam_demand_merge.upi_allch\000uncore_m2m\000uncore interconnect\000: UPI - All Channels. Unit: uncore_m2m \000event=0x5d,umask=0xa\000\00001\000\000 */
{ 4455079 }, /* unc_m2m_prefcam_demand_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000: XPT - All Channels. Unit: uncore_m2m \000event=0x5d,umask=0x5\000\00001\000\000 */
{ 4456628 }, /* unc_m2m_prefcam_demand_no_merge.rd_merged\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x40\000\00001\000\000 */
{ 4456788 }, /* unc_m2m_prefcam_demand_no_merge.wr_merged\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x20\000\00001\000\000 */
{ 4456948 }, /* unc_m2m_prefcam_demand_no_merge.wr_squashed\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2m \000event=0x5e,umask=0x10\000\00001\000\000 */
{ 4463058 }, /* unc_m2m_prefcam_inserts.ch0_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2m \000event=0x56,umask=0x2\000\00001\000\000 */
{ 4463342 }, /* unc_m2m_prefcam_inserts.ch0_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2m \000event=0x56,umask=0x1\000\00001\000\000 */
{ 4463626 }, /* unc_m2m_prefcam_inserts.ch1_upi\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2m \000event=0x56,umask=0x8\000\00001\000\000 */
{ 4463910 }, /* unc_m2m_prefcam_inserts.ch1_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2m \000event=0x56,umask=0x4\000\00001\000\000 */
{ 4464480 }, /* unc_m2m_prefcam_inserts.upi_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2m \000event=0x56,umask=0xa\000\00001\000\000 */
{ 4464785 }, /* unc_m2m_prefcam_inserts.xpt_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2m \000event=0x56,umask=0x5\000\00001\000Prefetch CAM Inserts : XPT -All Channels\000 */
{ 4465473 }, /* unc_m2m_prefcam_occupancy.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2m \000event=0x54,umask=0x3\000\00001\000\000 */
{ 4465765 }, /* unc_m2m_prefcam_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2m \000event=0x54,umask=0x1\000\00001\000\000 */
{ 4466047 }, /* unc_m2m_prefcam_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2m \000event=0x54,umask=0x2\000\00001\000\000 */
{ 4466708 }, /* unc_m2m_prefcam_resp_miss.allch\000uncore_m2m\000uncore interconnect\000All Channels. Unit: uncore_m2m \000event=0x5f,umask=0x3\000\00001\000\000 */
{ 4466829 }, /* unc_m2m_prefcam_resp_miss.ch0\000uncore_m2m\000uncore interconnect\000: Channel 0. Unit: uncore_m2m \000event=0x5f,umask=0x1\000\00001\000\000 */
{ 4467065 }, /* unc_m2m_prefcam_resp_miss.ch1\000uncore_m2m\000uncore interconnect\000: Channel 1. Unit: uncore_m2m \000event=0x5f,umask=0x2\000\00001\000\000 */
{ 4467545 }, /* unc_m2m_prefcam_rxc_deallocs.1lm_posted\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2m \000event=0x62,umask=0x2\000\00001\000\000 */
{ 4467857 }, /* unc_m2m_prefcam_rxc_deallocs.cis\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2m \000event=0x62,umask=0x8\000\00001\000\000 */
{ 4468141 }, /* unc_m2m_prefcam_rxc_deallocs.pmm_memmode_accept\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.PMM_MEMMODE_ACCEPT. Unit: uncore_m2m \000event=0x62,umask=0x4\000\00001\000\000 */
{ 4468485 }, /* unc_m2m_prefcam_rxc_deallocs.squashed\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2m \000event=0x62,umask=0x1\000\00001\000\000 */
{ 4468911 }, /* unc_m2m_prefcam_rxc_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy - Prefetches. Unit: uncore_m2m \000event=0x60\000\00001\000\000 */
{ 4480458 }, /* unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x2,umask=0x1\000\00001\000\000 */
{ 4481152 }, /* unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x3\000\00001\000\000 */
{ 4529384 }, /* unc_m2m_tag_hit.nm_rd_hit_clean\000uncore_m2m\000uncore interconnect\000Clean NearMem Read Hit. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000Counts clean full line read hits (reads and RFOs)\000 */
{ 4530123 }, /* unc_m2m_tag_hit.nm_rd_hit_dirty\000uncore_m2m\000uncore interconnect\000Dirty NearMem Read Hit. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000Counts dirty full line read hits (reads and RFOs)\000 */
{ 4531064 }, /* unc_m2m_tag_hit.nm_ufill_hit_clean\000uncore_m2m\000uncore interconnect\000Tag Hit : Clean NearMem Underfill Hit. Unit: uncore_m2m \000event=0x1f,umask=0x4\000\00001\000Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts clean underfill hits due to a partial write\000 */
{ 4531879 }, /* unc_m2m_tag_hit.nm_ufill_hit_dirty\000uncore_m2m\000uncore interconnect\000Tag Hit : Dirty NearMem Underfill Hit. Unit: uncore_m2m \000event=0x1f,umask=0x8\000\00001\000Tag Hit indicates when a request sent to the iMC hit in Near Memory. : Counts dirty underfill read hits due to a partial write\000 */
{ 4532561 }, /* unc_m2m_tag_miss\000uncore_m2m\000uncore interconnect\000UNC_M2M_TAG_MISS. Unit: uncore_m2m \000event=0x4b,umask=0x3\000\00001\000\000 */
{ 4532671 }, /* unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x2e\000\00001\000\000 */
{ 4532901 }, /* unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x2f\000\00001\000\000 */
{ 4534373 }, /* unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x32,umask=0x104\000\00001\000\000 */
{ 4534770 }, /* unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x32,umask=0x204\000\00001\000\000 */
{ 4535838 }, /* unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x33,umask=0x1\000\00001\000\000 */
{ 4536245 }, /* unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x33,umask=0x2\000\00001\000\000 */
{ 4670268 }, /* unc_m2m_wpq_flush.ch0\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 0. Unit: uncore_m2m \000event=0x42,umask=0x1\000\00001\000\000 */
{ 4670508 }, /* unc_m2m_wpq_flush.ch1\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 1. Unit: uncore_m2m \000event=0x42,umask=0x2\000\00001\000\000 */
{ 4670868 }, /* unc_m2m_wpq_no_reg_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x37,umask=0x1\000\00001\000\000 */
{ 4671180 }, /* unc_m2m_wpq_no_reg_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x37,umask=0x2\000\00001\000\000 */
{ 4672116 }, /* unc_m2m_wpq_no_spec_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x38,umask=0x1\000\00001\000\000 */
{ 4672430 }, /* unc_m2m_wpq_no_spec_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x38,umask=0x2\000\00001\000\000 */
{ 4673467 }, /* unc_m2m_wr_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4673749 }, /* unc_m2m_wr_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4674172 }, /* unc_m2m_wr_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x35,umask=0x1\000\00001\000\000 */
{ 4674462 }, /* unc_m2m_wr_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x35,umask=0x2\000\00001\000\000 */
{ 4674897 }, /* unc_m2m_wr_tracker_ne.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Mirror. Unit: uncore_m2m \000event=0x35,umask=0x4\000\00001\000\000 */
{ 4675183 }, /* unc_m2m_wr_tracker_ne.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x35,umask=0x8\000\00001\000\000 */
{ 4675466 }, /* unc_m2m_wr_tracker_ne.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x35,umask=0x10\000\00001\000\000 */
{ 4675744 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4676068 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4676554 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4676886 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4678243 }, /* unc_m2m_wr_tracker_posted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x48,umask=0x1\000\00001\000\000 */
{ 4678553 }, /* unc_m2m_wr_tracker_posted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x48,umask=0x2\000\00001\000\000 */
{ 4679018 }, /* unc_m2m_wr_tracker_posted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4679336 }, /* unc_m2m_wr_tracker_posted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4918269 }, /* unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000CBox AD Credits Empty : Requests : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4918747 }, /* unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000CBox AD Credits Empty : Snoops : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919219 }, /* unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000CBox AD Credits Empty : VNA Messages : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919709 }, /* unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty : Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000CBox AD Credits Empty : Writebacks : No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4920616 }, /* unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000M3UPI Clockticks. Unit: uncore_m3upi \000event=0x1\000\00001\000Number of M2UPI clock cycles while the event is enabled\000 */
{ 4921261 }, /* unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000M3UPI CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000 */
{ 4921510 }, /* unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000D2C Sent : Count cases BL sends direct to core\000 */
{ 4921786 }, /* unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000D2U Sent : Cases where SMI3 sends D2U command\000 */
{ 4924837 }, /* unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m3upi \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925418 }, /* unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m3upi \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4954740 }, /* unc_m3upi_m2_bl_credits_empty.iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000M2 BL Credits Empty : IIO0 and IIO1 share the same ring destination. (1 VN0 credit only) : No vn0 and vna credits available to send to M2\000 */
{ 4955085 }, /* unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000M2 BL Credits Empty : IIO2 : No vn0 and vna credits available to send to M2\000 */
{ 4955497 }, /* unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000M2 BL Credits Empty : IIO3 : No vn0 and vna credits available to send to M2\000 */
{ 4955909 }, /* unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000M2 BL Credits Empty : IIO4 : No vn0 and vna credits available to send to M2\000 */
{ 4956321 }, /* unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000 */
{ 4956735 }, /* unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000M2 BL Credits Empty : All IIO targets for NCS are in single mask. ORs them together : No vn0 and vna credits available to send to M2\000 */
{ 4957310 }, /* unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x80\000\00001\000M2 BL Credits Empty : Selected M2p BL NCS credits : No vn0 and vna credits available to send to M2\000 */
{ 4957791 }, /* unc_m3upi_m2_bl_credits_empty.ubox_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty : IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000M2 BL Credits Empty : IIO5 : No vn0 and vna credits available to send to M2\000 */
{ 4958411 }, /* unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi Slot Flit Received : AD - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4958953 }, /* unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi Slot Flit Received : AD - Slot 1 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959495 }, /* unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi Slot Flit Received : AD - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960037 }, /* unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi Slot Flit Received : AK - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960581 }, /* unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi Slot Flit Received : AK - Slot 2 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961125 }, /* unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received : BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi Slot Flit Received : BL - Slot 0 : Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4969934 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000Lost Arb for VN0 : REQ on AD : VN0 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4970551 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000Lost Arb for VN0 : RSP on AD : VN0 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4971218 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000Lost Arb for VN0 : SNP on AD : VN0 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4971745 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000Lost Arb for VN0 : NCB on BL : VN0 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4972448 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000Lost Arb for VN0 : NCS on BL : VN0 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4972939 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000Lost Arb for VN0 : RSP on BL : VN0 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4973604 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000Lost Arb for VN0 : WB on BL : VN0 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4974386 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000Lost Arb for VN1 : REQ on AD : VN1 message requested but lost arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4975003 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000Lost Arb for VN1 : RSP on AD : VN1 message requested but lost arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4975670 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000Lost Arb for VN1 : SNP on AD : VN1 message requested but lost arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4976197 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000Lost Arb for VN1 : NCB on BL : VN1 message requested but lost arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4976900 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000Lost Arb for VN1 : NCS on BL : VN1 message requested but lost arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4977391 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000Lost Arb for VN1 : RSP on BL : VN1 message requested but lost arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4978056 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000Lost Arb for VN1 : WB on BL : VN1 message requested but lost arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4979060 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN0 : AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4979337 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : AD, BL Parallel Win VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arb Miscellaneous : AD, BL Parallel Win VN1 : AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4979614 }, /* unc_m3upi_rxc_arb_misc.all_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : Max Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x80\000\00001\000Arb Miscellaneous : Max Parallel Win : VN0 and VN1 arbitration sub-pipelines both produced AD and BL winners (maximum possible parallel winners)\000 */
{ 4979916 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN0 : Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000 */
{ 4980523 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000Arb Miscellaneous : No Progress on Pending AD VN1 : Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000 */
{ 4981130 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN0 : Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000 */
{ 4981738 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arb Miscellaneous : No Progress on Pending BL VN1 : Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000 */
{ 4982868 }, /* unc_m3upi_rxc_arb_misc.vn01_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous : VN0, VN1 Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000Arb Miscellaneous : VN0, VN1 Parallel Win : VN0 and VN1 arbitration sub-pipelines had parallel winners (at least one AD or BL on each side)\000 */
{ 4988107 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000No Credits to Arb for VN0 : REQ on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4988493 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000No Credits to Arb for VN0 : RSP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4988904 }, /* unc_m3upi_rxc_arb_nocrd_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000No Credits to Arb for VN0 : SNP on AD : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4989245 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000No Credits to Arb for VN0 : NCB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4989674 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000No Credits to Arb for VN0 : NCS on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4989997 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000No Credits to Arb for VN0 : RSP on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4990407 }, /* unc_m3upi_rxc_arb_nocrd_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000No Credits to Arb for VN0 : WB on BL : VN0 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4990875 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000No Credits to Arb for VN1 : REQ on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4991261 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000No Credits to Arb for VN1 : RSP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4991672 }, /* unc_m3upi_rxc_arb_nocrd_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000No Credits to Arb for VN1 : SNP on AD : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4992013 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000No Credits to Arb for VN1 : NCB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4992442 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000No Credits to Arb for VN1 : NCS on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Non-Coherent Standard (NCS) messages on BL\000 */
{ 4992765 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000No Credits to Arb for VN1 : RSP on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4993175 }, /* unc_m3upi_rxc_arb_nocrd_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000No Credits to Arb for VN1 : WB on BL : VN1 message is blocked from requesting arbitration due to lack of remote UPI credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4998607 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000Can't Arb for VN0 : REQ on AD : VN0 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4998981 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000Can't Arb for VN0 : RSP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4999380 }, /* unc_m3upi_rxc_arb_noreq_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000Can't Arb for VN0 : SNP on AD : VN0 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4999709 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000Can't Arb for VN0 : NCB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5000126 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000Can't Arb for VN0 : NCS on BL : VN0 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5000437 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000Can't Arb for VN0 : RSP on BL : VN0 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5000835 }, /* unc_m3upi_rxc_arb_noreq_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0 : WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000Can't Arb for VN0 : WB on BL : VN0 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5001291 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000Can't Arb for VN1 : REQ on AD : VN1 message was not able to request arbitration while some other message won arbitration : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5001665 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000Can't Arb for VN1 : RSP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5002064 }, /* unc_m3upi_rxc_arb_noreq_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000Can't Arb for VN1 : SNP on AD : VN1 message was not able to request arbitration while some other message won arbitration : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5002393 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000Can't Arb for VN1 : NCB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5002810 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000Can't Arb for VN1 : NCS on BL : VN1 message was not able to request arbitration while some other message won arbitration : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5003121 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000Can't Arb for VN1 : RSP on BL : VN1 message was not able to request arbitration while some other message won arbitration : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5003519 }, /* unc_m3upi_rxc_arb_noreq_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1 : WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000Can't Arb for VN1 : WB on BL : VN1 message was not able to request arbitration while some other message won arbitration : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5003975 }, /* unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on BL Arb : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000 */
{ 5004645 }, /* unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Ingress Queue Bypasses : AD to Slot 0 on Idle : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to slot 0 of independent flit while pipeline is idle\000 */
{ 5005281 }, /* unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 1 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 1 while merging with bl message in same flit\000 */
{ 5005924 }, /* unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses : AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Ingress Queue Bypasses : AD + BL to Slot 2 : Number of times message is bypassed around the Ingress Queue : AD is taking bypass to flit slot 2 while merging with bl message in same flit\000 */
{ 5011447 }, /* unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any In BGF FIFO. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Miscellaneous Credit Events : Any In BGF FIFO : Indication that at least one packet (flit) is in the bgf (fifo only)\000 */
{ 5011954 }, /* unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : Any in BGF Path. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Miscellaneous Credit Events : Any in BGF Path : Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000 */
{ 5012487 }, /* unc_m3upi_rxc_crd_misc.lt1_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 1\000 */
{ 5012692 }, /* unc_m3upi_rxc_crd_misc.lt2_for_d2k\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Miscellaneous Credit Events : d2k credit count is less than 2\000 */
{ 5013152 }, /* unc_m3upi_rxc_crd_misc.vn0_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events : No D2K For Arb. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Miscellaneous Credit Events : No D2K For Arb : VN0 BL RSP message was blocked from arbitration request due to lack of D2K CMP credit\000 */
{ 5013451 }, /* unc_m3upi_rxc_crd_misc.vn1_no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Miscellaneous Credit Events : VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000 */
{ 5013717 }, /* unc_m3upi_rxc_crd_occ.consumed\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Credits Consumed. Unit: uncore_m3upi \000event=0x60,umask=0x80\000\00001\000Credit Occupancy : Credits Consumed : number of remote vna credits consumed per cycle\000 */
{ 5013950 }, /* unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : D2K Credits. Unit: uncore_m3upi \000event=0x60,umask=0x10\000\00001\000Credit Occupancy : D2K Credits : D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5014434 }, /* unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Credit Occupancy : Packets in BGF FIFO : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000 */
{ 5014930 }, /* unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Packets in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000Credit Occupancy : Packets in BGF Path : Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000 */
{ 5015482 }, /* unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x40\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in completion fifo only\000 */
{ 5015897 }, /* unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x60,umask=0x20\000\00001\000Credit Occupancy : count of bl messages in pump-1-pending state, in marker table and in fifo\000 */
{ 5016322 }, /* unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : Transmit Credits. Unit: uncore_m3upi \000event=0x60,umask=0x8\000\00001\000Credit Occupancy : Transmit Credits : Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5016831 }, /* unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy : VNA In Use. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Credit Occupancy : VNA In Use : Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000 */
{ 5017326 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : REQ on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5018636 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5019996 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : SNP on AD : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5021216 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5022612 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : NCS on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5023796 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : RSP on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5025154 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000VN0 Ingress (from CMS) Queue - Cycles Not Empty : WB on BL : Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5035932 }, /* unc_m3upi_rxc_data_flits_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000Data Flit Not Sent : All : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but could not be sent for any reason, e.g. low credits, low tsv, stall injection\000 */
{ 5036278 }, /* unc_m3upi_rxc_data_flits_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000Data Flit Not Sent : No BGF Credits : Data flit is ready for transmission but could not be sent\000 */
{ 5036530 }, /* unc_m3upi_rxc_data_flits_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000Data Flit Not Sent : No TxQ Credits : Data flit is ready for transmission but could not be sent\000 */
{ 5036783 }, /* unc_m3upi_rxc_data_flits_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : TSV High. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000Data Flit Not Sent : TSV High : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while tsv high\000 */
{ 5037093 }, /* unc_m3upi_rxc_data_flits_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000Data Flit Not Sent : Cycle valid for Flit : Data flit is ready for transmission but could not be sent : data flit is ready for transmission but was not sent while cycle is valid for flit transmission\000 */
{ 5037463 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Flit Gen - Header 1 : Accumulate : Events related to Header Flit Generation - Set 1 : Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000 */
{ 5038146 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Ready. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Flit Gen - Header 1 : Accumulate Ready : Events related to Header Flit Generation - Set 1 : header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000 */
{ 5038917 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Accumulate Wasted. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Flit Gen - Header 1 : Accumulate Wasted : Events related to Header Flit Generation - Set 1 : Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000 */
{ 5039667 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Flit Gen - Header 1 : Run-Ahead - Blocked : Events related to Header Flit Generation - Set 1 : Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000 */
{ 5040405 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x80\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: message was slotted only after run-ahead was over; run-ahead mode definitely wasted\000 */
{ 5040723 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg1_during\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1 : Run-Ahead - Message. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Flit Gen - Header 1 : Run-Ahead - Message : Events related to Header Flit Generation - Set 1 : run-ahead mode: one message slotted during run-ahead\000 */
{ 5041039 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_after\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: second message slotted immediately after run-ahead; potential run-ahead success\000 */
{ 5041353 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg2_sent\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Flit Gen - Header 1 : Events related to Header Flit Generation - Set 1 : run-ahead mode: two (or three) message flit sent immediately after run-ahead; complete run-ahead success\000 */
{ 5042811 }, /* unc_m3upi_rxc_flit_gen_hdr2.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Ok. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000Flit Gen - Header 2 : Parallel Ok : Events related to Header Flit Generation - Set 2 : new header flit construction may proceed in parallel with data flit sequence\000 */
{ 5043120 }, /* unc_m3upi_rxc_flit_gen_hdr2.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Flit Finished. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000Flit Gen - Header 2 : Parallel Flit Finished : Events related to Header Flit Generation - Set 2 : header flit finished assembly in parallel with data flit sequence\000 */
{ 5043446 }, /* unc_m3upi_rxc_flit_gen_hdr2.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Parallel Message. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000Flit Gen - Header 2 : Parallel Message : Events related to Header Flit Generation - Set 2 : message is slotted into header flit in parallel with data flit sequence\000 */
{ 5043764 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000Flit Gen - Header 2 : Rate-matching Stall : Events related to Header Flit Generation - Set 2 : Rate-matching stall injected\000 */
{ 5044280 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2 : Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000Flit Gen - Header 2 : Rate-matching Stall - No Message : Events related to Header Flit Generation - Set 2 : Rate matching stall injected, but no additional message slotted during stall cycle\000 */
{ 5047703 }, /* unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 0. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 0 : generating bl data flit sequence; waiting for data pump 0\000 */
{ 5048198 }, /* unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence : Wait on Pump 1. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Generating BL Data Flit Sequence : Wait on Pump 1 : generating bl data flit sequence; waiting for data pump 1\000 */
{ 5048693 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x10\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000 */
{ 5049198 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x8\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is tracking at least one message\000 */
{ 5049637 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x40\000\00001\000Generating BL Data Flit Sequence : pump-1-pending completion fifo is full\000 */
{ 5050058 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x20\000\00001\000Generating BL Data Flit Sequence : pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000 */
{ 5050631 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Generating BL Data Flit Sequence : a bl message finished but is in limbo and moved to pump-1-pending logic\000 */
{ 5051114 }, /* unc_m3upi_rxc_flits_misc.s2req_in_holdoff\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_HOLDOFF. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000: slot 2 request naturally serviced during hold-off period\000 */
{ 5051336 }, /* unc_m3upi_rxc_flits_misc.s2req_in_service\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_IN_SERVICE. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000: slot 2 request forcibly serviced during service window\000 */
{ 5051556 }, /* unc_m3upi_rxc_flits_misc.s2req_received\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_RECEIVED. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000: slot 2 request received from link layer while idle (with no slot 2 request active immediately prior)\000 */
{ 5051818 }, /* unc_m3upi_rxc_flits_misc.s2req_withdrawn\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC.S2REQ_WITHDRAWN. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000: slot 2 request withdrawn during hold-off period or service window\000 */
{ 5053280 }, /* unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : All. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000\000 */
{ 5053589 }, /* unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Needs Data Flit. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Slotting BL Message Into Header Flit : Needs Data Flit : BL message requires data flit sequence\000 */
{ 5054067 }, /* unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 0. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 0 : Waiting for header pump 0\000 */
{ 5054512 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 : Header pump 1 is not required for flit\000 */
{ 5055000 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Bubble : Header pump 1 is not required for flit but flit transmission delayed\000 */
{ 5055597 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000Slotting BL Message Into Header Flit : Don't Need Pump 1 - Not Avail : Header pump 1 is not required for flit and not available\000 */
{ 5056177 }, /* unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit : Wait on Pump 1. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000Slotting BL Message Into Header Flit : Wait on Pump 1 : Waiting for header pump 1\000 */
{ 5056622 }, /* unc_m3upi_rxc_hdr_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent : All. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Header Not Sent : All : header flit is ready for transmission but could not be sent : header flit is ready for transmission but could not be sent for any reason, e.g. no credits, low tsv, stall injection\000 */
{ 5056963 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Header Not Sent : No BGF Credits : header flit is ready for transmission but could not be sent : No BGF credits available\000 */
{ 5057240 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Header Not Sent : No BGF Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No BGF credits available; no additional message slotted into flit\000 */
{ 5057616 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Header Not Sent : No TxQ Credits : header flit is ready for transmission but could not be sent : No TxQ credits available\000 */
{ 5057894 }, /* unc_m3upi_rxc_hdr_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent : No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Header Not Sent : No TxQ Credits + No Extra Message Slotted : header flit is ready for transmission but could not be sent : No TxQ credits available; no additional message slotted into flit\000 */
{ 5058270 }, /* unc_m3upi_rxc_hdr_flit_not_sent.tsv_hi\000uncore_m3upi\000uncore interconnect\000Header Not Sent : TSV High. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Header Not Sent : TSV High : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while tsv high\000 */
{ 5058576 }, /* unc_m3upi_rxc_hdr_flit_not_sent.valid_for_flit\000uncore_m3upi\000uncore interconnect\000Header Not Sent : Cycle valid for Flit. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Header Not Sent : Cycle valid for Flit : header flit is ready for transmission but could not be sent : header flit is ready for transmission but was not sent while cycle is valid for flit transmission\000 */
{ 5058942 }, /* unc_m3upi_rxc_hdr_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Sent Header Flit : One Message : One message in flit; VNA or non-VNA flit\000 */
{ 5059161 }, /* unc_m3upi_rxc_hdr_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Message in non-VNA. Unit: uncore_m3upi \000event=0x54,umask=0x8\000\00001\000Sent Header Flit : One Message in non-VNA : One message in flit; non-VNA flit\000 */
{ 5059399 }, /* unc_m3upi_rxc_hdr_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Messages. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Sent Header Flit : Two Messages : Two messages in flit; VNA flit\000 */
{ 5059611 }, /* unc_m3upi_rxc_hdr_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Three Messages. Unit: uncore_m3upi \000event=0x54,umask=0x4\000\00001\000Sent Header Flit : Three Messages : Three messages in flit; VNA flit\000 */
{ 5059829 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : One Slot Taken. Unit: uncore_m3upi \000event=0x54,umask=0x10\000\00001\000\000 */
{ 5059981 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : Two Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x20\000\00001\000\000 */
{ 5060134 }, /* unc_m3upi_rxc_hdr_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit : All Slots Taken. Unit: uncore_m3upi \000event=0x54,umask=0x40\000\00001\000\000 */
{ 5060287 }, /* unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot AD. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Message Held : Can't Slot AD : some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5060797 }, /* unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held : Can't Slot BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Message Held : Can't Slot BL : some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061556 }, /* unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Attempt. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Message Held : Parallel Attempt : ad and bl messages attempted to slot into the same flit in parallel\000 */
{ 5062268 }, /* unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held : Parallel Success. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Message Held : Parallel Success : ad and bl messages were actually slotted into the same flit in parallel\000 */
{ 5062739 }, /* unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held : VN0. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Message Held : VN0 : vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000 */
{ 5063225 }, /* unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held : VN1. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Message Held : VN1 : vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000 */
{ 5099075 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000VN0 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5099982 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000VN0 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5100939 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000VN0 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5101756 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000VN0 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5102749 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000VN0 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5103530 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000VN0 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5104485 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000VN0 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5105557 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000VN1 message can't slot into flit : REQ on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5106464 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000VN1 message can't slot into flit : RSP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5107421 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000VN1 message can't slot into flit : SNP on AD : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5108238 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000VN1 message can't slot into flit : NCB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5109231 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000VN1 message can't slot into flit : NCS on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Non-Coherent Standard (NCS) messages on BL\000 */
{ 5110012 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000VN1 message can't slot into flit : RSP on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5110967 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit : WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000VN1 message can't slot into flit : WB on BL : Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5112870 }, /* unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Any In Use. Unit: uncore_m3upi \000event=0x5a,umask=0x20\000\00001\000Remote VNA Credits : Any In Use : At least one remote vna credit is in use\000 */
{ 5113275 }, /* unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Corrected. Unit: uncore_m3upi \000event=0x5a,umask=0x1\000\00001\000Remote VNA Credits : Corrected : Number of remote vna credits corrected (local return) per cycle\000 */
{ 5113967 }, /* unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 1. Unit: uncore_m3upi \000event=0x5a,umask=0x2\000\00001\000Remote VNA Credits : Level < 1 : Remote vna credit level is less than 1 (i.e. no vna credits available)\000 */
{ 5113719 }, /* unc_m3upi_rxc_vna_crd.lt10\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 10. Unit: uncore_m3upi \000event=0x5a,umask=0x10\000\00001\000Remote VNA Credits : Level < 10 : remote vna credit level is less than 10; parallel vn0/vn1 arb not possible\000 */
{ 5114413 }, /* unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 4. Unit: uncore_m3upi \000event=0x5a,umask=0x4\000\00001\000Remote VNA Credits : Level < 4 : Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000 */
{ 5114887 }, /* unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits : Level < 5. Unit: uncore_m3upi \000event=0x5a,umask=0x8\000\00001\000Remote VNA Credits : Level < 5 : Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000 */
{ 5115529 }, /* unc_m3upi_rxc_vna_crd_misc.req_adbl_alloc_l5\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_ADBL_ALLOC_L5. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000: remote vna credit count was less than 5 and allocation to ad or bl messages was required\000 */
{ 5115789 }, /* unc_m3upi_rxc_vna_crd_misc.req_vn01_alloc_lt10\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.REQ_VN01_ALLOC_LT10. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000: remote vna credit count was less than 10 and allocation to vn0 or vn1 was required\000 */
{ 5116047 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000: on vn0, remote vna credits were allocated only to ad messages, not to bl\000 */
{ 5116280 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000: on vn0, remote vna credits were allocated only to bl messages, not to ad\000 */
{ 5116513 }, /* unc_m3upi_rxc_vna_crd_misc.vn0_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN0_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000: remote vna credits were allocated only to vn0, not to vn1\000 */
{ 5116724 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_just_ad\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_AD. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000: on vn1, remote vna credits were allocated only to ad messages, not to bl\000 */
{ 5116957 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_just_bl\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_JUST_BL. Unit: uncore_m3upi \000event=0x59,umask=0x80\000\00001\000: on vn1, remote vna credits were allocated only to bl messages, not to ad\000 */
{ 5117190 }, /* unc_m3upi_rxc_vna_crd_misc.vn1_only\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_VNA_CRD_MISC.VN1_ONLY. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000: remote vna credits were allocated only to vn1, not to vn0\000 */
{ 5164612 }, /* unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000Failed ARB for AD : VN0 REQ Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165054 }, /* unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000Failed ARB for AD : VN0 RSP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165496 }, /* unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000Failed ARB for AD : VN0 SNP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5165938 }, /* unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000Failed ARB for AD : VN0 WB Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5166375 }, /* unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000Failed ARB for AD : VN1 REQ Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5166819 }, /* unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000Failed ARB for AD : VN1 RSP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5167263 }, /* unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000Failed ARB for AD : VN1 SNP Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5167707 }, /* unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD : VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000Failed ARB for AD : VN1 WB Messages : AD arb but no win; arb request asserted but not won\000 */
{ 5170442 }, /* unc_m3upi_txc_ad_flq_bypass\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5168146 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5168718 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169290 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169862 }, /* unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000AD FlowQ Bypass : Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170738 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000AD Flow Q Not Empty : VN0 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171192 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000AD Flow Q Not Empty : VN0 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171646 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000AD Flow Q Not Empty : VN0 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172100 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000AD Flow Q Not Empty : VN0 WB Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172549 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000AD Flow Q Not Empty : VN1 REQ Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173005 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000AD Flow Q Not Empty : VN1 RSP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173461 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000AD Flow Q Not Empty : VN1 SNP Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173917 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000AD Flow Q Not Empty : VN1 WB Messages : Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174368 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000AD Flow Q Inserts : VN0 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5175310 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000AD Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5176252 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000AD Flow Q Inserts : VN0 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5177194 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000AD Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5178131 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000AD Flow Q Inserts : VN1 REQ Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5179075 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000AD Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180019 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000AD Flow Q Inserts : VN1 SNP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180963 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 5181278 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 5181593 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 5181908 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 5182219 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 5182536 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 5182853 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 5192146 }, /* unc_m3upi_txc_ak_flq_inserts\000uncore_m3upi\000uncore interconnect\000AK Flow Q Inserts. Unit: uncore_m3upi \000event=0x2f\000\00001\000\000 */
{ 5192263 }, /* unc_m3upi_txc_ak_flq_occupancy\000uncore_m3upi\000uncore interconnect\000AK Flow Q Occupancy. Unit: uncore_m3upi \000event=0x1e\000\00001\000\000 */
{ 5192384 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000Failed ARB for BL : VN0 NCB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5192826 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000Failed ARB for BL : VN0 NCS Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5193268 }, /* unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000Failed ARB for BL : VN0 RSP Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5193710 }, /* unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000Failed ARB for BL : VN0 WB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5194147 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000Failed ARB for BL : VN1 NCS Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5194591 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000Failed ARB for BL : VN1 NCB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195035 }, /* unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000Failed ARB for BL : VN1 RSP Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195479 }, /* unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL : VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000Failed ARB for BL : VN1 WB Messages : BL arb but no win; arb request asserted but not won\000 */
{ 5195918 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000BL Flow Q Not Empty : VN0 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196372 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000BL Flow Q Not Empty : VN0 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196826 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000BL Flow Q Not Empty : VN0 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197280 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000BL Flow Q Not Empty : VN0 WB Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197729 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000BL Flow Q Not Empty : VN1 REQ Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198185 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000BL Flow Q Not Empty : VN1 RSP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198641 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000BL Flow Q Not Empty : VN1 SNP Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199097 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty : VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000BL Flow Q Not Empty : VN1 WB Messages : Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199548 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000BL Flow Q Inserts : VN0 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5200490 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000BL Flow Q Inserts : VN0 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5201429 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000BL Flow Q Inserts : VN0 NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5202371 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000BL Flow Q Inserts : VN0 NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5203311 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000BL Flow Q Inserts : VN1 RSP Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5204255 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000BL Flow Q Inserts : VN1 WB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5205196 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000BL Flow Q Inserts : VN1_NCB Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5206140 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000BL Flow Q Inserts : VN1_NCS Messages : Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5207082 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 5207397 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 5207712 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 5208027 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 5208338 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 5208655 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 5208972 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 5209289 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 5213668 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 5213831 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 5213995 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn0_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x4\000\00001\000\000 */
{ 5214159 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_local\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x10\000\00001\000\000 */
{ 5214323 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_through\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1 WB Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x20\000\00001\000\000 */
{ 5214488 }, /* unc_m3upi_txc_bl_wb_flq_occupancy.vn1_wrpull\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy : VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1f,umask=0x40\000\00001\000\000 */
{ 5296714 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000UPI0 AD Credits Empty : VN0 REQ Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5297188 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000UPI0 AD Credits Empty : VN0 RSP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5297662 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000UPI0 AD Credits Empty : VN0 SNP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5298136 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000UPI0 AD Credits Empty : VN1 REQ Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5298612 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000UPI0 AD Credits Empty : VN1 RSP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5299088 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000UPI0 AD Credits Empty : VN1 SNP Messages : No credits available to send to UPIs on the AD Ring\000 */
{ 5299564 }, /* unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty : VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000UPI0 AD Credits Empty : VNA : No credits available to send to UPIs on the AD Ring\000 */
{ 5299991 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000UPI0 BL Credits Empty : VN0 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5300543 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000UPI0 BL Credits Empty : VN0 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301087 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000UPI0 BL Credits Empty : VN0 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301629 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000UPI0 BL Credits Empty : VN1 RSP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302183 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000UPI0 BL Credits Empty : VN1 REQ Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302729 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000UPI0 BL Credits Empty : VN1 SNP Messages : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303273 }, /* unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty : VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000UPI0 BL Credits Empty : VNA : No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303770 }, /* unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000FlowQ Generated Prefetch. Unit: uncore_m3upi \000event=0x29\000\00001\000FlowQ Generated Prefetch : Count cases where FlowQ causes spawn of Prefetch to iMC/SMI3 target\000 */
{ 5335699 }, /* unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000VN0 Credit Used : WB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5337996 }, /* unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000VN0 Credit Used : NCB on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5340212 }, /* unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000VN0 Credit Used : REQ on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5342342 }, /* unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000VN0 Credit Used : RSP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5344522 }, /* unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000VN0 Credit Used : SNP on AD : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5346562 }, /* unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000VN0 Credit Used : RSP on BL : Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5348738 }, /* unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000VN0 No Credits : WB on BL : Number of Cycles there were no VN0 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5349506 }, /* unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000VN0 No Credits : NCB on BL : Number of Cycles there were no VN0 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5350193 }, /* unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000VN0 No Credits : REQ on AD : Number of Cycles there were no VN0 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5350794 }, /* unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000VN0 No Credits : RSP on AD : Number of Cycles there were no VN0 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5351445 }, /* unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000VN0 No Credits : SNP on AD : Number of Cycles there were no VN0 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5351956 }, /* unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000VN0 No Credits : RSP on BL : Number of Cycles there were no VN0 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5352603 }, /* unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000VN1 Credit Used : WB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5354898 }, /* unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000VN1 Credit Used : NCB on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5357112 }, /* unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000VN1 Credit Used : REQ on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5359240 }, /* unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000VN1 Credit Used : RSP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5361418 }, /* unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000VN1 Credit Used : SNP on AD : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5363456 }, /* unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used : RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000VN1 Credit Used : RSP on BL : Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers. : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5365630 }, /* unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000VN1 No Credits : WB on BL : Number of Cycles there were no VN1 Credits : Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5366398 }, /* unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000VN1 No Credits : NCB on BL : Number of Cycles there were no VN1 Credits : Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5367085 }, /* unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000VN1 No Credits : REQ on AD : Number of Cycles there were no VN1 Credits : Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5367686 }, /* unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000VN1 No Credits : RSP on AD : Number of Cycles there were no VN1 Credits : Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5368337 }, /* unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000VN1 No Credits : SNP on AD : Number of Cycles there were no VN1 Credits : Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5368848 }, /* unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits : RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000VN1 No Credits : RSP on BL : Number of Cycles there were no VN1 Credits : Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5369495 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x82\000\00001\000\000 */
{ 5369690 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xa0\000\00001\000\000 */
{ 5369885 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x81\000\00001\000\000 */
{ 5370080 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x90\000\00001\000\000 */
{ 5370275 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x84\000\00001\000\000 */
{ 5370470 }, /* unc_m3upi_wb_occ_compare.bothnonzero_rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.BOTHNONZERO_RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0xc0\000\00001\000\000 */
{ 5370665 }, /* unc_m3upi_wb_occ_compare.rt_eq_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x2\000\00001\000\000 */
{ 5370835 }, /* unc_m3upi_wb_occ_compare.rt_eq_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_EQ_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x20\000\00001\000\000 */
{ 5371006 }, /* unc_m3upi_wb_occ_compare.rt_gt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x1\000\00001\000\000 */
{ 5371176 }, /* unc_m3upi_wb_occ_compare.rt_gt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_GT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x10\000\00001\000\000 */
{ 5371347 }, /* unc_m3upi_wb_occ_compare.rt_lt_localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7e,umask=0x4\000\00001\000\000 */
{ 5371517 }, /* unc_m3upi_wb_occ_compare.rt_lt_localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_OCC_COMPARE.RT_LT_LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7e,umask=0x40\000\00001\000\000 */
{ 5371688 }, /* unc_m3upi_wb_pending.local_and_rt_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x4\000\00001\000\000 */
{ 5371844 }, /* unc_m3upi_wb_pending.local_and_rt_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCAL_AND_RT_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x40\000\00001\000\000 */
{ 5372001 }, /* unc_m3upi_wb_pending.localdest_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x1\000\00001\000\000 */
{ 5372151 }, /* unc_m3upi_wb_pending.localdest_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.LOCALDEST_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x10\000\00001\000\000 */
{ 5372302 }, /* unc_m3upi_wb_pending.routethru_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x2\000\00001\000\000 */
{ 5372452 }, /* unc_m3upi_wb_pending.routethru_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.ROUTETHRU_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x20\000\00001\000\000 */
{ 5372603 }, /* unc_m3upi_wb_pending.waiting4pull_vn0\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN0. Unit: uncore_m3upi \000event=0x7d,umask=0x8\000\00001\000\000 */
{ 5372759 }, /* unc_m3upi_wb_pending.waiting4pull_vn1\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_WB_PENDING.WAITING4PULL_VN1. Unit: uncore_m3upi \000event=0x7d,umask=0x80\000\00001\000\000 */
{ 5372916 }, /* unc_m3upi_xpt_pftch.arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARB. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000: xpt prefetch message is making arbitration request\000 */
{ 5373096 }, /* unc_m3upi_xpt_pftch.arrived\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.ARRIVED. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000: xpt prefetch message arrived in ingress pipeline\000 */
{ 5373282 }, /* unc_m3upi_xpt_pftch.bypass\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.BYPASS. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000: xpt prefetch message took bypass path\000 */
{ 5373455 }, /* unc_m3upi_xpt_pftch.flitted\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.FLITTED. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000: xpt prefetch message was slotted into flit (non bypass)\000 */
{ 5373649 }, /* unc_m3upi_xpt_pftch.lost_arb\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_ARB. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000: xpt prefetch message lost arbitration\000 */
{ 5373826 }, /* unc_m3upi_xpt_pftch.lost_old\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_OLD. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000: xpt prefetch message was dropped because it became too old\000 */
{ 5374274 }, /* unc_m3upi_xpt_pftch.lost_qfull\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_XPT_PFTCH.LOST_QFULL. Unit: uncore_m3upi \000event=0x61,umask=0x40\000\00001\000: xpt prefetch message was dropped because it was overwritten by new message while prefetch queue was full\000 */
{ 5636917 }, /* unc_mdf_crs_txr_inserts.ad_bnc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AD Bouncable). Unit: uncore_mdf \000event=0x47,umask=0x1\000\00001\000AD Bouncable : Number of allocations into the CRS Egress\000 */
{ 5637185 }, /* unc_mdf_crs_txr_inserts.ad_crd\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AD credited). Unit: uncore_mdf \000event=0x47,umask=0x2\000\00001\000AD credited : Number of allocations into the CRS Egress\000 */
{ 5637451 }, /* unc_mdf_crs_txr_inserts.ak\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AK). Unit: uncore_mdf \000event=0x47,umask=0x10\000\00001\000AK : Number of allocations into the CRS Egress\000 */
{ 5637696 }, /* unc_mdf_crs_txr_inserts.akc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (AKC). Unit: uncore_mdf \000event=0x47,umask=0x40\000\00001\000AKC : Number of allocations into the CRS Egress\000 */
{ 5637944 }, /* unc_mdf_crs_txr_inserts.bl_bnc\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (BL Bouncable). Unit: uncore_mdf \000event=0x47,umask=0x4\000\00001\000BL Bouncable : Number of allocations into the CRS Egress\000 */
{ 5638212 }, /* unc_mdf_crs_txr_inserts.bl_crd\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (BL credited). Unit: uncore_mdf \000event=0x47,umask=0x8\000\00001\000BL credited : Number of allocations into the CRS Egress\000 */
{ 5638478 }, /* unc_mdf_crs_txr_inserts.iv\000uncore_mdf\000uncore interconnect\000Number of allocations into the CRS Egress  used to queue up requests destined to the mesh (IV). Unit: uncore_mdf \000event=0x47,umask=0x20\000\00001\000IV : Number of allocations into the CRS Egress\000 */
{ 5638723 }, /* unc_mdf_crs_txr_v_bounces.ad\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AD). Unit: uncore_mdf \000event=0x4b,umask=0x1\000\00001\000AD : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000 */
{ 5639027 }, /* unc_mdf_crs_txr_v_bounces.ak\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AK). Unit: uncore_mdf \000event=0x4b,umask=0x4\000\00001\000AK : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000 */
{ 5639331 }, /* unc_mdf_crs_txr_v_bounces.akc\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (AKC). Unit: uncore_mdf \000event=0x4b,umask=0x10\000\00001\000AKC : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000 */
{ 5639639 }, /* unc_mdf_crs_txr_v_bounces.bl\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (BL). Unit: uncore_mdf \000event=0x4b,umask=0x2\000\00001\000BL : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000 */
{ 5639943 }, /* unc_mdf_crs_txr_v_bounces.iv\000uncore_mdf\000uncore interconnect\000Number of cycles incoming messages from the vertical ring that are bounced at the SBO\r\nIngress (V-EMIB) (IV). Unit: uncore_mdf \000event=0x4b,umask=0x8\000\00001\000IV : Number of cycles incoming messages from the vertical ring that are bounced at the SBO\000 */
{ 5640247 }, /* unc_mdf_fast_asserted.ad_bnc\000uncore_mdf\000uncore interconnect\000Counts the number of cycles when the distress signals are asserted based on SBO Ingress threshold. Unit: uncore_mdf \000event=0x15,umask=0x1\000\00001\000AD bnc : Counts the number of cycles when the  distress signals are asserted based on SBO Ingress threshold\000 */
{ 5640557 }, /* unc_mdf_fast_asserted.bl_crd\000uncore_mdf\000uncore interconnect\000Counts the number of cycles when the distress signals are asserted based on SBO Ingress threshold. Unit: uncore_mdf \000event=0x15,umask=0x2\000\00001\000BL bnc : Counts the number of cycles when the  distress signals are asserted based on SBO Ingress threshold\000 */
{ 6073690 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : Doorbell. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000\000 */
{ 6074265 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received : Interrupt. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Message Received : Interrupt : Interrupts\000 */
{ 6074870 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Message Received : IPI : Inter Processor Interrupts\000 */
{ 6075510 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Message Received : MSI : Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000 */
{ 6076306 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Message Received : VLW : Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6078260 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 6078414 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 6078568 }, /* unc_u_m2u_misc1.rxc_cycles_ne_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 6078722 }, /* unc_u_m2u_misc1.rxc_cycles_ne_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x8\000\00001\000\000 */
{ 6078876 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x10\000\00001\000\000 */
{ 6079041 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x20\000\00001\000\000 */
{ 6079206 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x40\000\00001\000\000 */
{ 6079371 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_upi_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_UPI_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x80\000\00001\000\000 */
{ 6079536 }, /* unc_u_m2u_misc2.rxc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 6079686 }, /* unc_u_m2u_misc2.rxc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 6079834 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCB. Unit: uncore_ubox \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 6079998 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCS. Unit: uncore_ubox \000event=0x4e,umask=0x8\000\00001\000\000 */
{ 6080162 }, /* unc_u_m2u_misc2.txc_cycles_empty_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AK. Unit: uncore_ubox \000event=0x4e,umask=0x20\000\00001\000\000 */
{ 6080313 }, /* unc_u_m2u_misc2.txc_cycles_empty_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AKC. Unit: uncore_ubox \000event=0x4e,umask=0x40\000\00001\000\000 */
{ 6080466 }, /* unc_u_m2u_misc2.txc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x10\000\00001\000\000 */
{ 6080617 }, /* unc_u_m2u_misc2.txc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x80\000\00001\000\000 */
{ 6080766 }, /* unc_u_m2u_misc3.txc_cycles_full_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AK. Unit: uncore_ubox \000event=0x4f,umask=0x1\000\00001\000\000 */
{ 6080914 }, /* unc_u_m2u_misc3.txc_cycles_full_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AKC. Unit: uncore_ubox \000event=0x4f,umask=0x2\000\00001\000\000 */
{ 6081763 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack : Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000Cycles PHOLD Assert to Ack : Assert to ACK : PHOLD cycles\000 */
{ 6082332 }, /* unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 6082474 }, /* unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 6082598 }, /* unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 6083007 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000RACU Request : Number outstanding register requests within message channel tracker\000 */
{ 6086608 }, /* unc_upi_clockticks\000uncore_upi\000uncore interconnect\000UPI Clockticks. Unit: uncore_upi \000event=0x1\000\00001\000Number of UPI LL clock cycles while the event is enabled\000 */
{ 6087000 }, /* unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2C. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Direct packet attempts : D2C : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 6087538 }, /* unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000Direct packet attempts : D2K. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Direct packet attempts : D2K : Counts the number of DRS packets that we attempted to do direct2core/direct2UPI on.  There are 4 mutually exclusive filters.  Filter [0] can be used to get successful spawns, while [1:3] provide the different failure cases.  Note that this does not count packets that are not candidates for Direct2Core.  The only candidates for Direct2Core are DRS packets destined for Cbos\000 */
{ 6088533 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x1\000\00001\000\000 */
{ 6088681 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x2\000\00001\000\000 */
{ 6088829 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x4\000\00001\000\000 */
{ 6088977 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x10\000\00001\000\000 */
{ 6089126 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x20\000\00001\000\000 */
{ 6089275 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x40\000\00001\000\000 */
{ 6089424 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq3\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ3. Unit: uncore_upi \000event=0x18,umask=0x80\000\00001\000\000 */
{ 6089573 }, /* unc_upi_flowq_no_vna_crd.bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.BL_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x8\000\00001\000\000 */
{ 6090178 }, /* unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L1. Unit: uncore_upi \000event=0x21\000\00001\000Cycles in L1 : Number of UPI qfclk cycles spent in L1 power mode.  L1 is a mode that totally shuts down a UPI link.  Use edge detect to count the number of instances when the UPI link entered L1.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another. Because L1 totally shuts down the link, it takes a good amount of time to exit this mode\000 */
{ 6090695 }, /* unc_upi_m3_byp_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x14,umask=0x8\000\00001\000\000 */
{ 6090833 }, /* unc_upi_m3_byp_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x14,umask=0x1\000\00001\000\000 */
{ 6090989 }, /* unc_upi_m3_byp_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x14,umask=0x4\000\00001\000\000 */
{ 6091145 }, /* unc_upi_m3_byp_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x14,umask=0x2\000\00001\000\000 */
{ 6091301 }, /* unc_upi_m3_byp_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x14,umask=0x10\000\00001\000\000 */
{ 6091442 }, /* unc_upi_m3_crd_return_blocked\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_CRD_RETURN_BLOCKED. Unit: uncore_upi \000event=0x16\000\00001\000\000 */
{ 6091568 }, /* unc_upi_m3_rxq_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x15,umask=0x20\000\00001\000\000 */
{ 6091707 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_btw_2_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_BTW_2_THRESH. Unit: uncore_upi \000event=0x15,umask=0x2\000\00001\000\000 */
{ 6091881 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x15,umask=0x1\000\00001\000\000 */
{ 6092037 }, /* unc_upi_m3_rxq_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x15,umask=0x10\000\00001\000\000 */
{ 6092194 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_btw_0_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_BTW_0_THRESH. Unit: uncore_upi \000event=0x15,umask=0x8\000\00001\000\000 */
{ 6092368 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x15,umask=0x4\000\00001\000\000 */
{ 6092524 }, /* unc_upi_m3_rxq_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x15,umask=0x40\000\00001\000\000 */
{ 6092665 }, /* unc_upi_phy_init_cycles\000uncore_upi\000uncore interconnect\000Cycles where phy is not in L0, L0c, L0p, L1. Unit: uncore_upi \000event=0x20\000\00001\000\000 */
{ 6093557 }, /* unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000L1 Req Nack : Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095094 }, /* unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000L1 Req (same as L1 Ack). : Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095886 }, /* unc_upi_req_slot2_from_m3.ack\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.ACK. Unit: uncore_upi \000event=0x46,umask=0x8\000\00001\000\000 */
{ 6096022 }, /* unc_upi_req_slot2_from_m3.vn0\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN0. Unit: uncore_upi \000event=0x46,umask=0x2\000\00001\000\000 */
{ 6096158 }, /* unc_upi_req_slot2_from_m3.vn1\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN1. Unit: uncore_upi \000event=0x46,umask=0x4\000\00001\000\000 */
{ 6096294 }, /* unc_upi_req_slot2_from_m3.vna\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VNA. Unit: uncore_upi \000event=0x46,umask=0x1\000\00001\000\000 */
{ 6096998 }, /* unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x24\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6097567 }, /* unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x25\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 6098611 }, /* unc_upi_rxl_any_flits.data\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.DATA. Unit: uncore_upi \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 6098741 }, /* unc_upi_rxl_any_flits.llcrd\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.LLCRD. Unit: uncore_upi \000event=0x4b,umask=0x10\000\00001\000\000 */
{ 6098874 }, /* unc_upi_rxl_any_flits.llctrl\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.LLCTRL. Unit: uncore_upi \000event=0x4b,umask=0x40\000\00001\000\000 */
{ 6099009 }, /* unc_upi_rxl_any_flits.null\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.NULL. Unit: uncore_upi \000event=0x4b,umask=0x20\000\00001\000\000 */
{ 6099140 }, /* unc_upi_rxl_any_flits.prothdr\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.PROTHDR. Unit: uncore_upi \000event=0x4b,umask=0x80\000\00001\000\000 */
{ 6099277 }, /* unc_upi_rxl_any_flits.slot0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT0. Unit: uncore_upi \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 6099409 }, /* unc_upi_rxl_any_flits.slot1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT1. Unit: uncore_upi \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 6099541 }, /* unc_upi_rxl_any_flits.slot2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_ANY_FLITS.SLOT2. Unit: uncore_upi \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 6099673 }, /* unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6100571 }, /* unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6101509 }, /* unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6102413 }, /* unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Matches on Receive path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Receive path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6114649 }, /* unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 0. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000RxQ Flit Buffer Bypassed : Slot 0 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6115744 }, /* unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 1. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000RxQ Flit Buffer Bypassed : Slot 1 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6116818 }, /* unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Bypassed : Slot 2. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000RxQ Flit Buffer Bypassed : Slot 2 : Counts the number of times that an incoming flit was able to bypass the flit buffer and pass directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of flits transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6117366 }, /* unc_upi_rxl_crc_errors\000uncore_upi\000uncore interconnect\000CRC Errors Detected. Unit: uncore_upi \000event=0xb\000\00001\000CRC Errors Detected : Number of CRC errors detected in the UPI Agent.  Each UPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the UPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000 */
{ 6118290 }, /* unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000LLR Requests Sent : Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs.\000 */
{ 6119714 }, /* unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000VN0 Credit Consumed : Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6120360 }, /* unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000VN1 Credit Consumed : Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6120694 }, /* unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121690 }, /* unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Data. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Valid Flits Received : All Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6122507 }, /* unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000\000 */
{ 6122914 }, /* unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received : Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Valid Flits Received : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6123628 }, /* unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received : Idle. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Valid Flits Received : Idle : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6124279 }, /* unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Valid Flits Received : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6124938 }, /* unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received : LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Valid Flits Received : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6125767 }, /* unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Received : All Non Data. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Valid Flits Received : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6126166 }, /* unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x3,umask=0x20\000\00001\000Valid Flits Received : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000 */
{ 6126721 }, /* unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received : Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Valid Flits Received : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6127308 }, /* unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Valid Flits Received : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6127838 }, /* unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Valid Flits Received : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6128368 }, /* unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received : Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Valid Flits Received : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6129969 }, /* unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000RxQ Flit Buffer Allocations : Slot 0 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6131141 }, /* unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000RxQ Flit Buffer Allocations : Slot 1 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6132313 }, /* unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations : Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000RxQ Flit Buffer Allocations : Slot 2 : Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6133485 }, /* unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000RxQ Occupancy - All Packets : Slot 0 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6134779 }, /* unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000RxQ Occupancy - All Packets : Slot 1 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6136073 }, /* unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets : Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000RxQ Occupancy - All Packets : Slot 2 : Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6137367 }, /* unc_upi_rxl_slot_bypass.s0_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x1\000\00001\000\000 */
{ 6137507 }, /* unc_upi_rxl_slot_bypass.s0_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x2\000\00001\000\000 */
{ 6137647 }, /* unc_upi_rxl_slot_bypass.s1_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x4\000\00001\000\000 */
{ 6137787 }, /* unc_upi_rxl_slot_bypass.s1_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x8\000\00001\000\000 */
{ 6137927 }, /* unc_upi_rxl_slot_bypass.s2_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x10\000\00001\000\000 */
{ 6138068 }, /* unc_upi_rxl_slot_bypass.s2_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x20\000\00001\000\000 */
{ 6138778 }, /* unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Unit: uncore_upi \000event=0x26\000\00001\000Cycles in L0 : Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6139347 }, /* unc_upi_txl0p_clk_active.cfg_ctl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.CFG_CTL. Unit: uncore_upi \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 6139489 }, /* unc_upi_txl0p_clk_active.dfx\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.DFX. Unit: uncore_upi \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 6139624 }, /* unc_upi_txl0p_clk_active.retry\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RETRY. Unit: uncore_upi \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 6139763 }, /* unc_upi_txl0p_clk_active.rxq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ. Unit: uncore_upi \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 6139897 }, /* unc_upi_txl0p_clk_active.rxq_bypass\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_BYPASS. Unit: uncore_upi \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 6140045 }, /* unc_upi_txl0p_clk_active.rxq_cred\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_CRED. Unit: uncore_upi \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 6140189 }, /* unc_upi_txl0p_clk_active.spare\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.SPARE. Unit: uncore_upi \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 6140328 }, /* unc_upi_txl0p_clk_active.txq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.TXQ. Unit: uncore_upi \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 6140463 }, /* unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0p. Unit: uncore_upi \000event=0x27\000\00001\000Cycles in L0p : Number of UPI qfclk cycles spent in L0p power mode.  L0p is a mode where we disable 1/2 of the UPI lanes, decreasing our bandwidth in order to save power.  It increases snoop and data transfer latencies and decreases overall bandwidth.  This mode can be very useful in NUMA optimized workloads that largely only utilize UPI for snoops and their responses.  Use edge detect to count the number of instances when the UPI link entered L0p.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another\000 */
{ 6141543 }, /* unc_upi_txl0p_power_cycles_ll_enter\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_LL_ENTER. Unit: uncore_upi \000event=0x28\000\00001\000\000 */
{ 6141681 }, /* unc_upi_txl0p_power_cycles_m3_exit\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_M3_EXIT. Unit: uncore_upi \000event=0x29\000\00001\000\000 */
{ 6141817 }, /* unc_upi_txl_any_flits.data\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.DATA. Unit: uncore_upi \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 6141947 }, /* unc_upi_txl_any_flits.llcrd\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.LLCRD. Unit: uncore_upi \000event=0x4a,umask=0x10\000\00001\000\000 */
{ 6142080 }, /* unc_upi_txl_any_flits.llctrl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.LLCTRL. Unit: uncore_upi \000event=0x4a,umask=0x40\000\00001\000\000 */
{ 6142215 }, /* unc_upi_txl_any_flits.null\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.NULL. Unit: uncore_upi \000event=0x4a,umask=0x20\000\00001\000\000 */
{ 6142346 }, /* unc_upi_txl_any_flits.prothdr\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.PROTHDR. Unit: uncore_upi \000event=0x4a,umask=0x80\000\00001\000\000 */
{ 6142483 }, /* unc_upi_txl_any_flits.slot0\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT0. Unit: uncore_upi \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 6142615 }, /* unc_upi_txl_any_flits.slot1\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT1. Unit: uncore_upi \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 6142747 }, /* unc_upi_txl_any_flits.slot2\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL_ANY_FLITS.SLOT2. Unit: uncore_upi \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 6142879 }, /* unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6143781 }, /* unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Bypass, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6144723 }, /* unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6145631 }, /* unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Matches on Transmit path of a UPI Port : Non-Coherent Standard, Match Opcode : Matches on Transmit path of a UPI port.\r\nMatch based on UMask specific bits:\r\nZ: Message Class (3-bit)\r\nY: Message Class Enable\r\nW: Opcode (4-bit)\r\nV: Opcode Enable\r\nU: Local Enable\r\nT: Remote Enable\r\nS: Data Hdr Enable\r\nR: Non-Data Hdr Enable\r\nQ: Dual Slot Hdr Enable\r\nP: Single Slot Hdr Enable\r\nLink Layer control types are excluded (LL CTRL, slot NULL, LLCRD) even under specific opcode match_en cases.\r\nNote: If Message Class is disabled, we expect opcode to also be disabled\000 */
{ 6157916 }, /* unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Bypassed. Unit: uncore_upi \000event=0x41\000\00001\000Tx Flit Buffer Bypassed : Counts the number of times that an incoming flit was able to bypass the Tx flit buffer and pass directly out the UPI Link. Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link\000 */
{ 6158385 }, /* unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Data. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Valid Flits Sent : All Data : Counts number of data flits across this UPI link\000 */
{ 6159112 }, /* unc_upi_txl_flits.all_llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x17\000\00001\000Valid Flits Sent : All Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6159336 }, /* unc_upi_txl_flits.all_llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Valid Flits Sent : All LLCTRL : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6159554 }, /* unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000All Null Flits. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000\000 */
{ 6160211 }, /* unc_upi_txl_flits.all_prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x87\000\00001\000Valid Flits Sent : All ProtDDR : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6160440 }, /* unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Valid Flits Sent : Data : Shows legal flit time (hides impact of L0p and L0c). : Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6161453 }, /* unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Idle. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Valid Flits Sent : Idle : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6161653 }, /* unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Valid Flits Sent : LLCRD Not Empty : Shows legal flit time (hides impact of L0p and L0c). : Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6162300 }, /* unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent : LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Valid Flits Sent : LLCTRL : Shows legal flit time (hides impact of L0p and L0c). : Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6163152 }, /* unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Valid Flits Sent : All Non Data. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Valid Flits Sent : All Non Data : Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6163543 }, /* unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot NULL or LLCRD Empty. Unit: uncore_upi \000event=0x2,umask=0x20\000\00001\000Valid Flits Sent : Slot NULL or LLCRD Empty : Shows legal flit time (hides impact of L0p and L0c). : LLCRD with all zeros is treated as NULL. Slot 1 is not treated as NULL if slot 0 is a dual slot. This can apply to slot 0,1, or 2\000 */
{ 6164090 }, /* unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Valid Flits Sent : Protocol Header : Shows legal flit time (hides impact of L0p and L0c). : Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6164665 }, /* unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Valid Flits Sent : Slot 0 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6165183 }, /* unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Valid Flits Sent : Slot 1 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6165701 }, /* unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent : Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Valid Flits Sent : Slot 2 : Shows legal flit time (hides impact of L0p and L0c). : Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6168722 }, /* unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Tx Flit Buffer Allocations : Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6169764 }, /* unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Tx Flit Buffer Occupancy : Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 6170298 }, /* unc_upi_vna_credit_return_blocked_vn01\000uncore_upi\000uncore interconnect\000UNC_UPI_VNA_CREDIT_RETURN_BLOCKED_VN01. Unit: uncore_upi \000event=0x45\000\00001\000\000 */
{ 6170671 }, /* unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000VNA Credits Pending Return - Occupancy : Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 3924647 }, /* unc_iio_bandwidth_in.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x20\000\00001\000\000 */
{ 3924873 }, /* unc_iio_bandwidth_in.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x21\000\00001\000\000 */
{ 3925099 }, /* unc_iio_bandwidth_in.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x22\000\00001\000\000 */
{ 3925325 }, /* unc_iio_bandwidth_in.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x23\000\00001\000\000 */
{ 3925551 }, /* unc_iio_bandwidth_in.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x24\000\00001\000\000 */
{ 3925777 }, /* unc_iio_bandwidth_in.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x25\000\00001\000\000 */
{ 3926003 }, /* unc_iio_bandwidth_in.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x26\000\00001\000\000 */
{ 3926229 }, /* unc_iio_bandwidth_in.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x27\000\00001\000\000 */
{ 3926455 }, /* unc_iio_bandwidth_out.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x30\000\00001\000\000 */
{ 3926682 }, /* unc_iio_bandwidth_out.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x31\000\00001\000\000 */
{ 3926909 }, /* unc_iio_bandwidth_out.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x32\000\00001\000\000 */
{ 3927136 }, /* unc_iio_bandwidth_out.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x33\000\00001\000\000 */
{ 3927363 }, /* unc_iio_bandwidth_out.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x34\000\00001\000\000 */
{ 3927590 }, /* unc_iio_bandwidth_out.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x35\000\00001\000\000 */
{ 3927817 }, /* unc_iio_bandwidth_out.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x36\000\00001\000\000 */
{ 3928044 }, /* unc_iio_bandwidth_out.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x37\000\00001\000\000 */
{ 3929036 }, /* unc_iio_clockticks\000uncore_iio\000uncore io\000IIO Clockticks. Unit: uncore_iio \000event=0x1,ch_mask=0x0000\000\00001\000Number of IIO clock cycles while the event is enabled\000 */
{ 3929458 }, /* unc_iio_clockticks_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for IIO clocktick. Unit: uncore_iio_free_running \000event=0xff,umask=0x10\000\00001\000\000 */
{ 3930263 }, /* unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-7. Unit: uncore_iio \000event=0xc2,ch_mask=0xff,fc_mask=0x07,umask=0x4\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0-7\000 */
{ 3930527 }, /* unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x0001,fc_mask=0x07,umask=0x7001004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3931456 }, /* unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x0002,fc_mask=0x07,umask=0x7002004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000 */
{ 3932385 }, /* unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x0004,fc_mask=0x07,umask=0x7004004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000 */
{ 3933314 }, /* unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x0008,fc_mask=0x07,umask=0x7008004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000 */
{ 3934243 }, /* unc_iio_comp_buf_inserts.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 4. Unit: uncore_iio \000event=0xc2,ch_mask=0x0010,fc_mask=0x07,umask=0x7010004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000 */
{ 3934981 }, /* unc_iio_comp_buf_inserts.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 5. Unit: uncore_iio \000event=0xc2,ch_mask=0x0020,fc_mask=0x07,umask=0x7020004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000 */
{ 3935719 }, /* unc_iio_comp_buf_inserts.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 6. Unit: uncore_iio \000event=0xc2,ch_mask=0x0040,fc_mask=0x07,umask=0x7040004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000 */
{ 3936457 }, /* unc_iio_comp_buf_inserts.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 7. Unit: uncore_iio \000event=0xc2,ch_mask=0x0080,fc_mask=0x07,umask=0x7080004\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000 */
{ 3938490 }, /* unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000UNC_IIO_COMP_BUF_OCCUPANCY.CMPD.ALL_PARTS. Unit: uncore_iio \000event=0xd5,fc_mask=0x07,umask=0xff\000\00001\000\000 */
{ 3938654 }, /* unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 0. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000001\000\00001\000x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3939450 }, /* unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 1. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000002\000\00001\000x4 card is plugged in to slot 1\000 */
{ 3940178 }, /* unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 2. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000004\000\00001\000x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3940941 }, /* unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 3. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000008\000\00001\000x4 card is plugged in to slot 3\000 */
{ 3941669 }, /* unc_iio_comp_buf_occupancy.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 4. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000010\000\00001\000x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3942283 }, /* unc_iio_comp_buf_occupancy.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 5. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000020\000\00001\000x4 card is plugged in to slot 1\000 */
{ 3942829 }, /* unc_iio_comp_buf_occupancy.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 6. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000040\000\00001\000x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3943410 }, /* unc_iio_comp_buf_occupancy.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy : Part 7. Unit: uncore_iio \000event=0xd5,ch_mask=0x0000,fc_mask=0x07,umask=0x7000080\000\00001\000x4 card is plugged in to slot 3\000 */
{ 3969456 }, /* unc_iio_data_req_by_cpu.mem_read.all_parts\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0-7. Unit: uncore_iio \000event=0xc0,ch_mask=0x00ff,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 3971071 }, /* unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3972707 }, /* unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3974199 }, /* unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3975706 }, /* unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008004\000\00001\000Data requested by the CPU : Core reading from Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3976708 }, /* unc_iio_data_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3977739 }, /* unc_iio_data_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3978627 }, /* unc_iio_data_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3979585 }, /* unc_iio_data_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080004\000\00001\000Data requested by the CPU : Core reading from Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3981067 }, /* unc_iio_data_req_by_cpu.mem_write.all_parts\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0-7 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x00ff,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 3981666 }, /* unc_iio_data_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0100,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3982475 }, /* unc_iio_data_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0200,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3983374 }, /* unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3984965 }, /* unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3986412 }, /* unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3987875 }, /* unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3989366 }, /* unc_iio_data_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3990274 }, /* unc_iio_data_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3991149 }, /* unc_iio_data_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3992024 }, /* unc_iio_data_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Cards MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3994488 }, /* unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3996232 }, /* unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3997832 }, /* unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 3999447 }, /* unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4000547 }, /* unc_iio_data_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4001636 }, /* unc_iio_data_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4002582 }, /* unc_iio_data_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4003598 }, /* unc_iio_data_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080008\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4006627 }, /* unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0001,fc_mask=0x07,umask=0x7001002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4008370 }, /* unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0002,fc_mask=0x07,umask=0x7002002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4009968 }, /* unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0004,fc_mask=0x07,umask=0x7004002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4011581 }, /* unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x0008,fc_mask=0x07,umask=0x7008002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4012681 }, /* unc_iio_data_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0010,fc_mask=0x07,umask=0x7010002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4013764 }, /* unc_iio_data_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0020,fc_mask=0x07,umask=0x7020002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4014704 }, /* unc_iio_data_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0040,fc_mask=0x07,umask=0x7040002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4015714 }, /* unc_iio_data_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x0080,fc_mask=0x07,umask=0x7080002\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4024926 }, /* unc_iio_data_req_of_cpu.cmpd.all_parts\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0xff,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4026325 }, /* unc_iio_data_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4027377 }, /* unc_iio_data_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4028279 }, /* unc_iio_data_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4029251 }, /* unc_iio_data_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4030153 }, /* unc_iio_data_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4031205 }, /* unc_iio_data_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4032107 }, /* unc_iio_data_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4033079 }, /* unc_iio_data_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4033981 }, /* unc_iio_data_req_of_cpu.mem_read.all_parts\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part0-7 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x00ff,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4036551 }, /* unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4038351 }, /* unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4040168 }, /* unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4041939 }, /* unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4042346 }, /* unc_iio_data_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4043305 }, /* unc_iio_data_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4044121 }, /* unc_iio_data_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4045007 }, /* unc_iio_data_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4046375 }, /* unc_iio_data_req_of_cpu.mem_write.all_parts\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part0-7 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x00ff,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4048937 }, /* unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4050733 }, /* unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4052546 }, /* unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4054313 }, /* unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4054719 }, /* unc_iio_data_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4055672 }, /* unc_iio_data_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4056482 }, /* unc_iio_data_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4057362 }, /* unc_iio_data_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4073662 }, /* unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0001,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4075321 }, /* unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0002,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4076836 }, /* unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0004,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4078366 }, /* unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x0008,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4079381 }, /* unc_iio_data_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0010,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4080464 }, /* unc_iio_data_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0020,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4081404 }, /* unc_iio_data_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0040,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4082414 }, /* unc_iio_data_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x0080,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4083974 }, /* unc_iio_inbound_arb_req.data\000uncore_iio\000uncore io\000Incoming arbitration requests : Passing data to be written. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Incoming arbitration requests : Passing data to be written : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4084679 }, /* unc_iio_inbound_arb_req.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing final read or write of line. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests : Issuing final read or write of line : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4085373 }, /* unc_iio_inbound_arb_req.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests : Processing response from IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests : Processing response from IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086043 }, /* unc_iio_inbound_arb_req.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing to IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests : Issuing to IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086657 }, /* unc_iio_inbound_arb_req.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests : Request Ownership. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Incoming arbitration requests : Request Ownership : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4087331 }, /* unc_iio_inbound_arb_req.wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Writing line. Unit: uncore_iio \000event=0x86,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Incoming arbitration requests : Writing line : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4087976 }, /* unc_iio_inbound_arb_won.data\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Passing data to be written. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Incoming arbitration requests granted : Passing data to be written : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4088729 }, /* unc_iio_inbound_arb_won.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing final read or write of line. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Incoming arbitration requests granted : Issuing final read or write of line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4089477 }, /* unc_iio_inbound_arb_won.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Processing response from IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff002\000\00001\000Incoming arbitration requests granted : Processing response from IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4090201 }, /* unc_iio_inbound_arb_won.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing to IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff001\000\00001\000Incoming arbitration requests granted : Issuing to IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4090869 }, /* unc_iio_inbound_arb_won.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Request Ownership. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Incoming arbitration requests granted : Request Ownership : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4091591 }, /* unc_iio_inbound_arb_won.wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Writing line. Unit: uncore_iio \000event=0x87,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Incoming arbitration requests granted : Writing line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4093167 }, /* unc_iio_iommu0.ctxt_cache_hits\000uncore_iio\000uncore io\000: Context cache hits. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x80\000\00001\000: Context cache hits : Counts each time a first look up of the transaction hits the RCC\000 */
{ 4093594 }, /* unc_iio_iommu0.ctxt_cache_lookups\000uncore_iio\000uncore io\000: Context cache lookups. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x40\000\00001\000: Context cache lookups : Counts each time a transaction looks up root context cache\000 */
{ 4094027 }, /* unc_iio_iommu0.first_lookups\000uncore_iio\000uncore io\000: IOTLB lookups first. Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x1\000\00001\000: IOTLB lookups first : Some transactions have to look up IOTLB multiple times.  Counts the first time a request looks up IOTLB\000 */
{ 4094859 }, /* unc_iio_iommu0.misses\000uncore_iio\000uncore io\000IOTLB Fills (same as IOTLB miss). Unit: uncore_iio \000event=0x40,ch_mask=0x0000,umask=0x20\000\00001\000IOTLB Fills (same as IOTLB miss) : When a transaction misses IOTLB, it does a page walk to look up memory and bring in the relevant page translation. Counts when this page translation is written to IOTLB\000 */
{ 4095694 }, /* unc_iio_iommu1.num_mem_accesses\000uncore_iio\000uncore io\000: IOMMU memory access. Unit: uncore_iio \000event=0x41,umask=0xc0\000\00001\000: IOMMU memory access : IOMMU sends out memory fetches when it misses the cache look up which is indicated by this signal.  M2IOSF only uses low priority channel\000 */
{ 4096194 }, /* unc_iio_iommu1.pwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000 */
{ 4096412 }, /* unc_iio_iommu1.pwc_256t_hits\000uncore_iio\000uncore io\000: PWT Hit to a 256T page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWT Hit to a 256T page : Counts each time a transaction's first look up hits the SLPWC at the 512G level\000 */
{ 4096857 }, /* unc_iio_iommu1.pwc_2m_hits\000uncore_iio\000uncore io\000: PWC Hit to a 4K page. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000: PWC Hit to a 4K page : Counts each time a transaction's first look up hits the SLPWC at the 4K level\000 */
{ 4097293 }, /* unc_iio_iommu1.pwc_512g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000 */
{ 4097740 }, /* unc_iio_iommu1.pwc_cache_fills\000uncore_iio\000uncore io\000: PageWalk cache fill. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000: PageWalk cache fill : When a transaction misses SLPWC, it does a page walk to look up memory and bring in the relevant page translation. When this page translation is written to SLPWC, ObsPwcFillValid_nnnH is asserted\000 */
{ 4098079 }, /* unc_iio_iommu1.pwt_cache_lookups\000uncore_iio\000uncore io\000: PageWalk cache lookup. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000: PageWalk cache lookup : Counts each time a transaction looks up second level page walk cache\000 */
{ 4098296 }, /* unc_iio_iommu1.slpwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000 */
{ 4098516 }, /* unc_iio_iommu1.slpwc_256t_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000 */
{ 4098739 }, /* unc_iio_iommu1.slpwc_512g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000 */
{ 4100940 }, /* unc_iio_iommu3.pwt_occupancy_msb\000uncore_iio\000uncore io\000: Global IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,ch_mask=0x0000,umask=0x1\000\00001\000: Global IOTLB invalidation cycles : Indicates that IOMMU is doing global invalidation\000 */
{ 4101506 }, /* unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x1\000\00001\000AND Mask/match for debug bus : Non-PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4102155 }, /* unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x8\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4102884 }, /* unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x4\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4103640 }, /* unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x2\000\00001\000AND Mask/match for debug bus : PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4104269 }, /* unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x10\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4105028 }, /* unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x2,ch_mask=0x0000,umask=0x20\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4105781 }, /* unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x1\000\00001\000OR Mask/match for debug bus : Non-PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4106422 }, /* unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x8\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4107143 }, /* unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x4\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4107891 }, /* unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x2\000\00001\000OR Mask/match for debug bus : PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4108512 }, /* unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x10\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4109263 }, /* unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,ch_mask=0x0000,umask=0x20\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4112824 }, /* unc_iio_num_req_of_cpu.commit.all\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : All. Unit: uncore_iio \000event=0x85,ch_mask=0x0FFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests PCIe makes of the main die : All : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU\000 */
{ 4113556 }, /* unc_iio_num_req_of_cpu_by_tgt.abort\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Abort. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x80\000\00001\000\000 */
{ 4113908 }, /* unc_iio_num_req_of_cpu_by_tgt.confined_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Confined P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x40\000\00001\000\000 */
{ 4114288 }, /* unc_iio_num_req_of_cpu_by_tgt.loc_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Local P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x20\000\00001\000\000 */
{ 4114652 }, /* unc_iio_num_req_of_cpu_by_tgt.mcast\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Multi-cast. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x2\000\00001\000\000 */
{ 4115012 }, /* unc_iio_num_req_of_cpu_by_tgt.mem\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Memory. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000\000 */
{ 4115360 }, /* unc_iio_num_req_of_cpu_by_tgt.msgb\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : MsgB. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4115706 }, /* unc_iio_num_req_of_cpu_by_tgt.rem_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Remote P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x10\000\00001\000\000 */
{ 4116072 }, /* unc_iio_num_req_of_cpu_by_tgt.ubox\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Ubox. Unit: uncore_iio \000event=0x8e,ch_mask=0x00FF,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4116418 }, /* unc_iio_num_tgt_matched_req_of_cpu\000uncore_iio\000uncore io\000ITC address map 1. Unit: uncore_iio \000event=0x8f,ch_mask=0x0000\000\00001\000UNC_IIO_NUM_TGT_MATCHED_REQ_OF_CPU\000 */
{ 4116685 }, /* unc_iio_outbound_cl_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound cacheline requests issued : 64B requests issued to device. Unit: uncore_iio \000event=0xd0,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Outbound cacheline requests issued : 64B requests issued to device : Each outbound cacheline granular request may need to make multiple passes through the pipeline.  Each time a cacheline completes all its passes it advances line\000 */
{ 4117539 }, /* unc_iio_outbound_tlp_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound TLP (transaction layer packet) requests issued : To device. Unit: uncore_iio \000event=0xd1,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000Outbound TLP (transaction layer packet) requests issued : To device : Each time an outbound completes all its passes it advances the pointer\000 */
{ 4137131 }, /* unc_iio_pwt_occupancy\000uncore_iio\000uncore io\000PWT occupancy.  Does not include 9th bit of occupancy (will undercount if PWT is greater than 255 per cycle). Unit: uncore_iio \000event=0x42,ch_mask=0x0000,umask=0xff\000\00001\000PWT occupancy : Indicates how many page walks are outstanding at any point in time\000 */
{ 4138213 }, /* unc_iio_req_from_pcie_cl_cmpl.data\000uncore_iio\000uncore io\000Request Ownership : PCIe Request complete. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000Request Ownership : PCIe Request complete : Only for posted requests : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4139379 }, /* unc_iio_req_from_pcie_cl_cmpl.final_rd_wr\000uncore_iio\000uncore io\000Request Ownership : Writing line. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Request Ownership : Writing line : Only for posted requests : Only for posted requests\000 */
{ 4140237 }, /* unc_iio_req_from_pcie_cl_cmpl.req_own\000uncore_iio\000uncore io\000Request Ownership : Issuing final read or write of line. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Request Ownership : Issuing final read or write of line : Only for posted requests\000 */
{ 4141096 }, /* unc_iio_req_from_pcie_cl_cmpl.wr\000uncore_iio\000uncore io\000Request Ownership : Passing data to be written. Unit: uncore_iio \000event=0x91,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000Request Ownership : Passing data to be written : Only for posted requests : Only for posted requests\000 */
{ 4142502 }, /* unc_iio_req_from_pcie_cmpl.final_rd_wr\000uncore_iio\000uncore io\000Processing response from IOMMU : Passing data to be written. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff008\000\00001\000Processing response from IOMMU : Passing data to be written : Only for posted requests\000 */
{ 4143336 }, /* unc_iio_req_from_pcie_cmpl.iommu_hit\000uncore_iio\000uncore io\000Processing response from IOMMU : Issuing final read or write of line. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff002\000\00001\000\000 */
{ 4144063 }, /* unc_iio_req_from_pcie_cmpl.iommu_req\000uncore_iio\000uncore io\000Processing response from IOMMU : Request Ownership. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff001\000\00001\000Processing response from IOMMU : Request Ownership : Only for posted requests\000 */
{ 4144877 }, /* unc_iio_req_from_pcie_cmpl.req_own\000uncore_iio\000uncore io\000Processing response from IOMMU : Writing line. Unit: uncore_iio \000event=0x92,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000Processing response from IOMMU : Writing line : Only for posted requests\000 */
{ 4145665 }, /* unc_iio_req_from_pcie_pass_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - pass complete : Passing data to be written. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff020\000\00001\000PCIe Request - pass complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4146866 }, /* unc_iio_req_from_pcie_pass_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - pass complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state\000 */
{ 4148056 }, /* unc_iio_req_from_pcie_pass_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - pass complete : Request Ownership. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff004\000\00001\000PCIe Request - pass complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4149226 }, /* unc_iio_req_from_pcie_pass_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Writing line. Unit: uncore_iio \000event=0x90,ch_mask=0x00FF,fc_mask=0x07,umask=0x70ff010\000\00001\000PCIe Request - pass complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4193803 }, /* unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4195445 }, /* unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4196943 }, /* unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4198456 }, /* unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4199998 }, /* unc_iio_txn_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4200910 }, /* unc_iio_txn_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4201789 }, /* unc_iio_txn_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4202668 }, /* unc_iio_txn_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4205024 }, /* unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4206663 }, /* unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4208158 }, /* unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4209668 }, /* unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4211207 }, /* unc_iio_txn_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4212113 }, /* unc_iio_txn_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4212986 }, /* unc_iio_txn_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4213859 }, /* unc_iio_txn_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Cards MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Cards MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4223708 }, /* unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0001,fc_mask=0x07,umask=0x7001002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4225576 }, /* unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0002,fc_mask=0x07,umask=0x7002002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4227183 }, /* unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0004,fc_mask=0x07,umask=0x7004002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4228875 }, /* unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0008,fc_mask=0x07,umask=0x7008002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4230486 }, /* unc_iio_txn_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0010,fc_mask=0x07,umask=0x7010002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4231574 }, /* unc_iio_txn_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0020,fc_mask=0x07,umask=0x7020002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4232512 }, /* unc_iio_txn_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0040,fc_mask=0x07,umask=0x7040002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4233520 }, /* unc_iio_txn_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x0080,fc_mask=0x07,umask=0x7080002\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4243944 }, /* unc_iio_txn_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4245002 }, /* unc_iio_txn_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4245910 }, /* unc_iio_txn_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4246888 }, /* unc_iio_txn_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4247796 }, /* unc_iio_txn_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4248854 }, /* unc_iio_txn_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4249762 }, /* unc_iio_txn_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4250740 }, /* unc_iio_txn_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4252911 }, /* unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4254481 }, /* unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is  made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4255909 }, /* unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4257350 }, /* unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4258339 }, /* unc_iio_txn_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4259296 }, /* unc_iio_txn_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4260110 }, /* unc_iio_txn_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4260994 }, /* unc_iio_txn_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4263668 }, /* unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4265235 }, /* unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4266658 }, /* unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4268096 }, /* unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4269085 }, /* unc_iio_txn_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4270036 }, /* unc_iio_txn_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4270844 }, /* unc_iio_txn_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 1\000 */
{ 4271722 }, /* unc_iio_txn_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4287940 }, /* unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0001,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4289739 }, /* unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0002,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4291276 }, /* unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0004,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4292899 }, /* unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0008,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4294441 }, /* unc_iio_txn_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0010,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4295537 }, /* unc_iio_txn_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0020,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4296483 }, /* unc_iio_txn_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0040,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4297499 }, /* unc_iio_txn_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x0080,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4707041 }, /* unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000M2P Clockticks. Unit: uncore_m2pcie \000event=0x1\000\00001\000Number of M2P clock cycles while the event is enabled\000 */
{ 4707189 }, /* unc_m2p_cms_clockticks\000uncore_m2pcie\000uncore io\000CMS Clockticks. Unit: uncore_m2pcie \000event=0xc0\000\00001\000\000 */
{ 4714289 }, /* unc_m2p_egress_ordering.iv_snoopgo_dn\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2pcie \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4714597 }, /* unc_m2p_egress_ordering.iv_snoopgo_up\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2pcie \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4730880 }, /* unc_m2p_iio_credits_acquired.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x1\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4731581 }, /* unc_m2p_iio_credits_acquired.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x2\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4732282 }, /* unc_m2p_iio_credits_acquired.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x4\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4732983 }, /* unc_m2p_iio_credits_acquired.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x8\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4733684 }, /* unc_m2p_iio_credits_acquired.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x10\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4734386 }, /* unc_m2p_iio_credits_acquired.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x20\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4735088 }, /* unc_m2p_iio_credits_reject.drs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : DRS. Unit: uncore_m2pcie \000event=0x34,umask=0x8\000\00001\000M2PCIe IIO Failed to Acquire a Credit : DRS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the DRS message class\000 */
{ 4735684 }, /* unc_m2p_iio_credits_reject.ncb\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCB. Unit: uncore_m2pcie \000event=0x34,umask=0x10\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCB : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCB message class\000 */
{ 4736281 }, /* unc_m2p_iio_credits_reject.ncs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCS. Unit: uncore_m2pcie \000event=0x34,umask=0x20\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCS message class\000 */
{ 4736878 }, /* unc_m2p_iio_credits_used.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x1\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4737607 }, /* unc_m2p_iio_credits_used.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x2\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4738336 }, /* unc_m2p_iio_credits_used.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x4\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739065 }, /* unc_m2p_iio_credits_used.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x8\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739794 }, /* unc_m2p_iio_credits_used.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x10\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4740524 }, /* unc_m2p_iio_credits_used.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x20\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4742091 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4742262 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4742433 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4742604 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x8\000\00001\000\000 */
{ 4742775 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x10\000\00001\000\000 */
{ 4742947 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x20\000\00001\000\000 */
{ 4743119 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x40\000\00001\000\000 */
{ 4743291 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x80\000\00001\000\000 */
{ 4743463 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4743634 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4743805 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4743976 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x8\000\00001\000\000 */
{ 4744147 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4744322 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4744497 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x4\000\00001\000\000 */
{ 4744672 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x8\000\00001\000\000 */
{ 4744847 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000 */
{ 4745023 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000 */
{ 4745375 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x40\000\00001\000\000 */
{ 4745727 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x80\000\00001\000\000 */
{ 4745903 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x1\000\00001\000\000 */
{ 4746078 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x2\000\00001\000\000 */
{ 4746253 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x4\000\00001\000\000 */
{ 4746428 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x8\000\00001\000\000 */
{ 4746603 }, /* unc_m2p_local_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4746758 }, /* unc_m2p_local_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4746913 }, /* unc_m2p_local_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x17,umask=0x4\000\00001\000\000 */
{ 4747068 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4747241 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4747414 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4747587 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_3\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent3. Unit: uncore_m2pcie \000event=0x44,umask=0x8\000\00001\000\000 */
{ 4747760 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_4\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent4. Unit: uncore_m2pcie \000event=0x44,umask=0x10\000\00001\000\000 */
{ 4747934 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_5\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent5. Unit: uncore_m2pcie \000event=0x44,umask=0x20\000\00001\000\000 */
{ 4748108 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4748277 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4748446 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4748615 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x8\000\00001\000\000 */
{ 4748784 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x10\000\00001\000\000 */
{ 4748954 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x20\000\00001\000\000 */
{ 4749124 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x40\000\00001\000\000 */
{ 4749294 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x80\000\00001\000\000 */
{ 4749464 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x1\000\00001\000\000 */
{ 4749633 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x2\000\00001\000\000 */
{ 4749802 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x4\000\00001\000\000 */
{ 4749971 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x8\000\00001\000\000 */
{ 4750140 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4750313 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4750486 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4750659 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 4750832 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x10\000\00001\000\000 */
{ 4751006 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x20\000\00001\000\000 */
{ 4751180 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x40\000\00001\000\000 */
{ 4751354 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x80\000\00001\000\000 */
{ 4751528 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4751701 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4751874 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4752047 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 4752598 }, /* unc_m2p_p2p_crd_occupancy.all\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : All. Unit: uncore_m2pcie \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4752728 }, /* unc_m2p_p2p_crd_occupancy.local_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4752869 }, /* unc_m2p_p2p_crd_occupancy.local_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4753010 }, /* unc_m2p_p2p_crd_occupancy.remote_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x4\000\00001\000\000 */
{ 4753153 }, /* unc_m2p_p2p_crd_occupancy.remote_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4753296 }, /* unc_m2p_p2p_ded_received.all\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : All. Unit: uncore_m2pcie \000event=0x16,umask=0x10\000\00001\000\000 */
{ 4753431 }, /* unc_m2p_p2p_ded_received.local_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x1\000\00001\000\000 */
{ 4753577 }, /* unc_m2p_p2p_ded_received.local_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x2\000\00001\000\000 */
{ 4753723 }, /* unc_m2p_p2p_ded_received.remote_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x4\000\00001\000\000 */
{ 4753871 }, /* unc_m2p_p2p_ded_received.remote_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x8\000\00001\000\000 */
{ 4754019 }, /* unc_m2p_p2p_shar_received.all\000uncore_m2pcie\000uncore io\000Shared Credits  Received : All. Unit: uncore_m2pcie \000event=0x15,umask=0x10\000\00001\000\000 */
{ 4754153 }, /* unc_m2p_p2p_shar_received.local_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4754298 }, /* unc_m2p_p2p_shar_received.local_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4754443 }, /* unc_m2p_p2p_shar_received.remote_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x4\000\00001\000\000 */
{ 4754590 }, /* unc_m2p_p2p_shar_received.remote_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x8\000\00001\000\000 */
{ 4754737 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x1\000\00001\000\000 */
{ 4754904 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x2\000\00001\000\000 */
{ 4755071 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x4\000\00001\000\000 */
{ 4755238 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x48,umask=0x8\000\00001\000\000 */
{ 4755405 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x48,umask=0x10\000\00001\000\000 */
{ 4755573 }, /* unc_m2p_remote_ded_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x48,umask=0x20\000\00001\000\000 */
{ 4755741 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4755908 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4756075 }, /* unc_m2p_remote_ded_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Dedicated P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x49,umask=0x4\000\00001\000\000 */
{ 4756242 }, /* unc_m2p_remote_p2p_ded_returned.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4756406 }, /* unc_m2p_remote_p2p_ded_returned.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4756570 }, /* unc_m2p_remote_p2p_ded_returned.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x4\000\00001\000\000 */
{ 4756734 }, /* unc_m2p_remote_p2p_ded_returned.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x8\000\00001\000\000 */
{ 4756898 }, /* unc_m2p_remote_p2p_ded_returned.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x1b,umask=0x10\000\00001\000\000 */
{ 4757063 }, /* unc_m2p_remote_p2p_ded_returned.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote P2P Dedicated Credits Returned : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x1b,umask=0x20\000\00001\000\000 */
{ 4757228 }, /* unc_m2p_remote_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4757385 }, /* unc_m2p_remote_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4757542 }, /* unc_m2p_remote_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x18,umask=0x4\000\00001\000\000 */
{ 4757699 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4757874 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4758049 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4758224 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x1\000\00001\000\000 */
{ 4758389 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x2\000\00001\000\000 */
{ 4758554 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x4\000\00001\000\000 */
{ 4758719 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x42,umask=0x8\000\00001\000\000 */
{ 4758884 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x42,umask=0x10\000\00001\000\000 */
{ 4759050 }, /* unc_m2p_remote_shar_p2p_crd_taken_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x42,umask=0x20\000\00001\000\000 */
{ 4759216 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_drs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4759381 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4759546 }, /* unc_m2p_remote_shar_p2p_crd_taken_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Taken - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x43,umask=0x4\000\00001\000\000 */
{ 4759711 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4759880 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4760049 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI0 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 4760218 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - DRS. Unit: uncore_m2pcie \000event=0x4c,umask=0x8\000\00001\000\000 */
{ 4760387 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCB. Unit: uncore_m2pcie \000event=0x4c,umask=0x10\000\00001\000\000 */
{ 4760557 }, /* unc_m2p_remote_shar_p2p_crd_wait_0.upi1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 0 : UPI1 - NCS. Unit: uncore_m2pcie \000event=0x4c,umask=0x20\000\00001\000\000 */
{ 4760727 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_drs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - DRS. Unit: uncore_m2pcie \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4760896 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCB. Unit: uncore_m2pcie \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4761065 }, /* unc_m2p_remote_shar_p2p_crd_wait_1.upi2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Remote Shared P2P Credit - 1 : UPI2 - NCS. Unit: uncore_m2pcie \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4765639 }, /* unc_m2p_rxc_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4765888 }, /* unc_m2p_rxc_cycles_ne.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766140 }, /* unc_m2p_rxc_cycles_ne.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766392 }, /* unc_m2p_rxc_cycles_ne.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766644 }, /* unc_m2p_rxc_cycles_ne.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x20\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766897 }, /* unc_m2p_rxc_cycles_ne.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x40\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767150 }, /* unc_m2p_rxc_cycles_ne.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x8\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767402 }, /* unc_m2p_rxc_cycles_ne.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x10\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767655 }, /* unc_m2p_rxc_inserts.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768017 }, /* unc_m2p_rxc_inserts.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768382 }, /* unc_m2p_rxc_inserts.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x2\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768747 }, /* unc_m2p_rxc_inserts.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769112 }, /* unc_m2p_rxc_inserts.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x20\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769478 }, /* unc_m2p_rxc_inserts.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769844 }, /* unc_m2p_rxc_inserts.upi_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x8\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4770209 }, /* unc_m2p_rxc_inserts.upi_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x10\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4800947 }, /* unc_m2p_txc_credits.pmm\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PMM. Unit: uncore_m2pcie \000event=0x2d,umask=0x2\000\00001\000\000 */
{ 4801067 }, /* unc_m2p_txc_credits.prq\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PRQ. Unit: uncore_m2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 4803008 }, /* unc_m2p_txc_cycles_full.pmm_block_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4803668 }, /* unc_m2p_txc_cycles_full.pmm_block_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x8\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4807503 }, /* unc_m2p_txc_cycles_ne.pmm_distress_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4808621 }, /* unc_m2p_txc_cycles_ne.pmm_distress_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x8\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4300146 }, /* unc_m2hbm_clockticks\000uncore_m2hbm\000uncore memory\000Cycles - at UCLK. Unit: uncore_m2hbm \000event=0x1\000\00001\000\000 */
{ 4300247 }, /* unc_m2hbm_cms_clockticks\000uncore_m2hbm\000uncore memory\000CMS Clockticks. Unit: uncore_m2hbm \000event=0xc0\000\00001\000\000 */
{ 4300668 }, /* unc_m2hbm_direct2core_not_taken_dirstate\000uncore_m2hbm\000uncore memory\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2hbm \000event=0x17,umask=0x7\000\00001\000\000 */
{ 4300351 }, /* unc_m2hbm_direct2core_not_taken_dirstate.non_cisgress\000uncore_m2hbm\000uncore memory\000Cycles when direct to core mode, which bypasses the CHA, was disabled : Non Cisgress. Unit: uncore_m2hbm \000event=0x17,umask=0x2\000\00001\000Counts the number of time non cisgress D2C was not honoured by egress due to directory state constraints\000 */
{ 4300853 }, /* unc_m2hbm_direct2core_not_taken_notforked\000uncore_m2hbm\000uncore memory\000Counts the time when FM didn't do d2c for fill reads (cross tile case). Unit: uncore_m2hbm \000event=0x4a\000\00001\000\000 */
{ 4301226 }, /* unc_m2hbm_direct2core_txn_override\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2hbm \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4301030 }, /* unc_m2hbm_direct2core_txn_override.cisgress\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to core transaction was overridden : Cisgress. Unit: uncore_m2hbm \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4301403 }, /* unc_m2hbm_direct2upi_not_taken_credits\000uncore_m2hbm\000uncore memory\000Number of reads in which direct to Intel UPI transactions were overridden. Unit: uncore_m2hbm \000event=0x1b,umask=0x7\000\00001\000\000 */
{ 4302487 }, /* unc_m2hbm_direct2upi_not_taken_dirstate\000uncore_m2hbm\000uncore memory\000Cycles when direct to Intel UPI was disabled. Unit: uncore_m2hbm \000event=0x1a,umask=0x7\000\00001\000\000 */
{ 4301590 }, /* unc_m2hbm_direct2upi_not_taken_dirstate.cisgress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Cisgress D2U Ignored. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x4\000\00001\000Counts cisgress d2K that was not honored due to directory constraints\000 */
{ 4301879 }, /* unc_m2hbm_direct2upi_not_taken_dirstate.egress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Egress Ignored D2U. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts the number of time D2K was not honoured by egress due to directory state constraints\000 */
{ 4302186 }, /* unc_m2hbm_direct2upi_not_taken_dirstate.non_cisgress\000uncore_m2hbm\000uncore memory\000Cycles when Direct2UPI was Disabled : Non Cisgress D2U Ignored. Unit: uncore_m2hbm \000event=0x1a,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x2\000\00001\000Counts non cisgress d2K that was not honored due to directory constraints\000 */
{ 4302822 }, /* unc_m2hbm_direct2upi_txn_override\000uncore_m2hbm\000uncore memory\000Number of reads that a message sent direct2 Intel UPI was overridden. Unit: uncore_m2hbm \000event=0x1c,umask=0x3\000\00001\000\000 */
{ 4302646 }, /* unc_m2hbm_direct2upi_txn_override.cisgress\000uncore_m2hbm\000uncore memory\000Number of times a direct to UPI transaction was overridden. Unit: uncore_m2hbm \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4302999 }, /* unc_m2hbm_directory_hit.clean_a\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in A State. Unit: uncore_m2hbm \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 4303150 }, /* unc_m2hbm_directory_hit.clean_i\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in I State. Unit: uncore_m2hbm \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 4303301 }, /* unc_m2hbm_directory_hit.clean_p\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in L State. Unit: uncore_m2hbm \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 4303452 }, /* unc_m2hbm_directory_hit.clean_s\000uncore_m2hbm\000uncore memory\000Directory Hit : On NonDirty Line in S State. Unit: uncore_m2hbm \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 4303603 }, /* unc_m2hbm_directory_hit.dirty_a\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in A State. Unit: uncore_m2hbm \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 4303750 }, /* unc_m2hbm_directory_hit.dirty_i\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in I State. Unit: uncore_m2hbm \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4303897 }, /* unc_m2hbm_directory_hit.dirty_p\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in L State. Unit: uncore_m2hbm \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 4304044 }, /* unc_m2hbm_directory_hit.dirty_s\000uncore_m2hbm\000uncore memory\000Directory Hit : On Dirty Line in S State. Unit: uncore_m2hbm \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4304191 }, /* unc_m2hbm_directory_lookup.any\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2hbm \000event=0x20,umask=0x1\000\00001\000Counts the number of hit data returns to egress with any directory to non persistent memory\000 */
{ 4304446 }, /* unc_m2hbm_directory_lookup.state_a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2hbm \000event=0x20,umask=0x8\000\00001\000Counts the number of hit data returns to egress with directory A to non persistent memory\000 */
{ 4304714 }, /* unc_m2hbm_directory_lookup.state_i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2hbm \000event=0x20,umask=0x2\000\00001\000Counts the number of hit data returns to egress with directory I to non persistent memory\000 */
{ 4304981 }, /* unc_m2hbm_directory_lookup.state_s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2hbm \000event=0x20,umask=0x4\000\00001\000Counts the number of hit data returns to egress with directory S to non persistent memory\000 */
{ 4305248 }, /* unc_m2hbm_directory_miss.clean_a\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in A State. Unit: uncore_m2hbm \000event=0x1e,umask=0x80\000\00001\000\000 */
{ 4305401 }, /* unc_m2hbm_directory_miss.clean_i\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in I State. Unit: uncore_m2hbm \000event=0x1e,umask=0x10\000\00001\000\000 */
{ 4305554 }, /* unc_m2hbm_directory_miss.clean_p\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in L State. Unit: uncore_m2hbm \000event=0x1e,umask=0x40\000\00001\000\000 */
{ 4305707 }, /* unc_m2hbm_directory_miss.clean_s\000uncore_m2hbm\000uncore memory\000Directory Miss : On NonDirty Line in S State. Unit: uncore_m2hbm \000event=0x1e,umask=0x20\000\00001\000\000 */
{ 4305860 }, /* unc_m2hbm_directory_miss.dirty_a\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in A State. Unit: uncore_m2hbm \000event=0x1e,umask=0x8\000\00001\000\000 */
{ 4306009 }, /* unc_m2hbm_directory_miss.dirty_i\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in I State. Unit: uncore_m2hbm \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 4306158 }, /* unc_m2hbm_directory_miss.dirty_p\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in L State. Unit: uncore_m2hbm \000event=0x1e,umask=0x4\000\00001\000\000 */
{ 4306307 }, /* unc_m2hbm_directory_miss.dirty_s\000uncore_m2hbm\000uncore memory\000Directory Miss : On Dirty Line in S State. Unit: uncore_m2hbm \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 4306456 }, /* unc_m2hbm_directory_update.a2i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2hbm \000event=0x21,umask=0x320\000\00001\000\000 */
{ 4306615 }, /* unc_m2hbm_directory_update.a2s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2hbm \000event=0x21,umask=0x340\000\00001\000\000 */
{ 4306774 }, /* unc_m2hbm_directory_update.a_to_i_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x120\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to I to non persistent memory\000 */
{ 4307085 }, /* unc_m2hbm_directory_update.a_to_i_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x220\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to I to non persistent memory\000 */
{ 4307391 }, /* unc_m2hbm_directory_update.a_to_s_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x140\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from A to S to non persistent memory\000 */
{ 4307702 }, /* unc_m2hbm_directory_update.a_to_s_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x240\000\00001\000Counts 2lm miss  data returns that would result in directory update from A to S to non persistent memory\000 */
{ 4308008 }, /* unc_m2hbm_directory_update.any\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2hbm \000event=0x21,umask=0x301\000\00001\000\000 */
{ 4308173 }, /* unc_m2hbm_directory_update.hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000Counts any 1lm or 2lm hit data return that would result in directory update to non persistent memory\000 */
{ 4308467 }, /* unc_m2hbm_directory_update.i2a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2hbm \000event=0x21,umask=0x304\000\00001\000\000 */
{ 4308626 }, /* unc_m2hbm_directory_update.i2s\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2hbm \000event=0x21,umask=0x302\000\00001\000\000 */
{ 4308785 }, /* unc_m2hbm_directory_update.i_to_a_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to A to non persistent memory\000 */
{ 4309096 }, /* unc_m2hbm_directory_update.i_to_a_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000Counts 2lm miss  data returns that would result in directory update from I to A to non persistent memory\000 */
{ 4309402 }, /* unc_m2hbm_directory_update.i_to_s_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x102\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from I to S to non persistent memory\000 */
{ 4309713 }, /* unc_m2hbm_directory_update.i_to_s_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x202\000\00001\000Counts  2lm miss  data returns that would result in directory update from I to S to non persistent memory\000 */
{ 4310020 }, /* unc_m2hbm_directory_update.miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000Counts any 2lm miss data return that would result in directory update to non persistent memory\000 */
{ 4310309 }, /* unc_m2hbm_directory_update.s2a\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2hbm \000event=0x21,umask=0x310\000\00001\000\000 */
{ 4310468 }, /* unc_m2hbm_directory_update.s2i\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2hbm \000event=0x21,umask=0x308\000\00001\000\000 */
{ 4310627 }, /* unc_m2hbm_directory_update.s_to_a_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x110\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to A to non persistent memory\000 */
{ 4310938 }, /* unc_m2hbm_directory_update.s_to_a_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x210\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to A to non persistent memory\000 */
{ 4311244 }, /* unc_m2hbm_directory_update.s_to_i_hit_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x108\000\00001\000Counts 1lm or 2lm hit  data returns that would result in directory update from S to I to non persistent memory\000 */
{ 4311555 }, /* unc_m2hbm_directory_update.s_to_i_miss_non_pmm\000uncore_m2hbm\000uncore memory\000Multi-socket cacheline Directory Updates. Unit: uncore_m2hbm \000event=0x21,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x208\000\00001\000Counts 2lm miss  data returns that would result in directory update from S to I to non persistent memory\000 */
{ 4311861 }, /* unc_m2hbm_distress.ad\000uncore_m2hbm\000uncore memory\000Count distress signalled on AkAd cmp message. Unit: uncore_m2hbm \000event=0x67,umask=0x20\000\00001\000\000 */
{ 4312003 }, /* unc_m2hbm_distress.all\000uncore_m2hbm\000uncore memory\000Count distress signalled on any packet type. Unit: uncore_m2hbm \000event=0x67,umask=0x1\000\00001\000\000 */
{ 4312144 }, /* unc_m2hbm_distress.bl_cmp\000uncore_m2hbm\000uncore memory\000Count distress signalled on Bl Cmp message. Unit: uncore_m2hbm \000event=0x67,umask=0x40\000\00001\000\000 */
{ 4312288 }, /* unc_m2hbm_distress.crosstile_nmwr\000uncore_m2hbm\000uncore memory\000Count distress signalled on NM fill write message. Unit: uncore_m2hbm \000event=0x67,umask=0x10\000\00001\000\000 */
{ 4312447 }, /* unc_m2hbm_distress.d2cha\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2Cha message. Unit: uncore_m2hbm \000event=0x67,umask=0x8\000\00001\000\000 */
{ 4312588 }, /* unc_m2hbm_distress.d2core\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2c message. Unit: uncore_m2hbm \000event=0x67,umask=0x2\000\00001\000\000 */
{ 4312728 }, /* unc_m2hbm_distress.d2upi\000uncore_m2hbm\000uncore memory\000Count distress signalled on D2k message. Unit: uncore_m2hbm \000event=0x67,umask=0x4\000\00001\000\000 */
{ 4312867 }, /* unc_m2hbm_egress_ordering.iv_snoopgo_dn\000uncore_m2hbm\000uncore memory\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2hbm \000event=0xba,umask=0x80000004\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4313186 }, /* unc_m2hbm_egress_ordering.iv_snoopgo_up\000uncore_m2hbm\000uncore memory\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2hbm \000event=0xba,umask=0x80000001\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4313501 }, /* unc_m2hbm_igr_starve_winner.mask7\000uncore_m2hbm\000uncore memory\000Count when Starve Glocab counter is at 7. Unit: uncore_m2hbm \000event=0x44,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x80\000\00001\000\000 */
{ 4313689 }, /* unc_m2hbm_imc_reads.all\000uncore_m2hbm\000uncore memory\000Reads to iMC issued. Unit: uncore_m2hbm \000event=0x24,umask=0x304\000\00001\000\000 */
{ 4313809 }, /* unc_m2hbm_imc_reads.ch0.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0.ALL. Unit: uncore_m2hbm \000event=0x24,umask=0x104\000\00001\000\000 */
{ 4313941 }, /* unc_m2hbm_imc_reads.ch0.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x101\000\00001\000\000 */
{ 4314079 }, /* unc_m2hbm_imc_reads.ch0_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_ALL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x104\000\00001\000\000 */
{ 4314249 }, /* unc_m2hbm_imc_reads.ch0_from_tgr\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_FROM_TGR. Unit: uncore_m2hbm \000event=0x24,umask=0x140\000\00001\000\000 */
{ 4314391 }, /* unc_m2hbm_imc_reads.ch0_isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - Ch0. Unit: uncore_m2hbm \000event=0x24,umask=0x102\000\00001\000\000 */
{ 4314521 }, /* unc_m2hbm_imc_reads.ch0_normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH0_NORMAL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000\000 */
{ 4314697 }, /* unc_m2hbm_imc_reads.ch1.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1.ALL. Unit: uncore_m2hbm \000event=0x24,umask=0x204\000\00001\000\000 */
{ 4314829 }, /* unc_m2hbm_imc_reads.ch1.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x201\000\00001\000\000 */
{ 4314967 }, /* unc_m2hbm_imc_reads.ch1_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1_ALL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x204\000\00001\000\000 */
{ 4315137 }, /* unc_m2hbm_imc_reads.ch1_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch1. Unit: uncore_m2hbm \000event=0x24,umask=0x240\000\00001\000\000 */
{ 4315261 }, /* unc_m2hbm_imc_reads.ch1_isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - Ch1. Unit: uncore_m2hbm \000event=0x24,umask=0x202\000\00001\000\000 */
{ 4315391 }, /* unc_m2hbm_imc_reads.ch1_normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.CH1_NORMAL. Unit: uncore_m2hbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000\000 */
{ 4315567 }, /* unc_m2hbm_imc_reads.from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - All Channels. Unit: uncore_m2hbm \000event=0x24,umask=0x340\000\00001\000\000 */
{ 4315696 }, /* unc_m2hbm_imc_reads.isoch\000uncore_m2hbm\000uncore memory\000Critical Priority - All Channels. Unit: uncore_m2hbm \000event=0x24,umask=0x302\000\00001\000\000 */
{ 4315831 }, /* unc_m2hbm_imc_reads.normal\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_READS.NORMAL. Unit: uncore_m2hbm \000event=0x24,umask=0x301\000\00001\000\000 */
{ 4315961 }, /* unc_m2hbm_imc_writes.all\000uncore_m2hbm\000uncore memory\000All Writes - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1810\000\00001\000\000 */
{ 4316089 }, /* unc_m2hbm_imc_writes.ch0.all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.ALL. Unit: uncore_m2hbm \000event=0x25,umask=0x810\000\00001\000\000 */
{ 4316223 }, /* unc_m2hbm_imc_writes.ch0.full\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.FULL. Unit: uncore_m2hbm \000event=0x25,umask=0x801\000\00001\000\000 */
{ 4316359 }, /* unc_m2hbm_imc_writes.ch0.partial\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0.PARTIAL. Unit: uncore_m2hbm \000event=0x25,umask=0x802\000\00001\000\000 */
{ 4316501 }, /* unc_m2hbm_imc_writes.ch0_all\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_ALL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x810\000\00001\000\000 */
{ 4316673 }, /* unc_m2hbm_imc_writes.ch0_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch0. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000 */
{ 4316786 }, /* unc_m2hbm_imc_writes.ch0_full\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_FULL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x801\000\00001\000\000 */
{ 4316960 }, /* unc_m2hbm_imc_writes.ch0_full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - Ch0. Unit: uncore_m2hbm \000event=0x25,umask=0x804\000\00001\000\000 */
{ 4317094 }, /* unc_m2hbm_imc_writes.ch0_ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - Ch0. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4317244 }, /* unc_m2hbm_imc_writes.ch0_ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - Ch0. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4317404 }, /* unc_m2hbm_imc_writes.ch0_partial\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_IMC_WRITES.CH0_PARTIAL. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x802\000\00001\000\000 */
{ 4317584 }, /* unc_m2hbm_imc_writes.ch0_partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - Ch0. Unit: uncore_m2hbm \000event=0x25,umask=0x808\000\00001\000\000 */
{ 4317719 }, /* unc_m2hbm_imc_writes.ch1.all\000uncore_m2hbm\000uncore memory\000All Writes - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1010\000\00001\000\000 */
{ 4317842 }, /* unc_m2hbm_imc_writes.ch1.full\000uncore_m2hbm\000uncore memory\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1001\000\00001\000\000 */
{ 4317975 }, /* unc_m2hbm_imc_writes.ch1.partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1002\000\00001\000\000 */
{ 4318109 }, /* unc_m2hbm_imc_writes.ch1_all\000uncore_m2hbm\000uncore memory\000All Writes - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1010\000\00001\000\000 */
{ 4318270 }, /* unc_m2hbm_imc_writes.ch1_from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - Ch1. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000 */
{ 4318383 }, /* unc_m2hbm_imc_writes.ch1_full\000uncore_m2hbm\000uncore memory\000Full Line Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1001\000\00001\000\000 */
{ 4318554 }, /* unc_m2hbm_imc_writes.ch1_full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1004\000\00001\000\000 */
{ 4318689 }, /* unc_m2hbm_imc_writes.ch1_ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4318839 }, /* unc_m2hbm_imc_writes.ch1_ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4318999 }, /* unc_m2hbm_imc_writes.ch1_partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - Ch1. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1002\000\00001\000\000 */
{ 4319171 }, /* unc_m2hbm_imc_writes.ch1_partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - Ch1. Unit: uncore_m2hbm \000event=0x25,umask=0x1008\000\00001\000\000 */
{ 4319307 }, /* unc_m2hbm_imc_writes.from_tgr\000uncore_m2hbm\000uncore memory\000From TGR - All Channels. Unit: uncore_m2hbm \000event=0x25\000\00001\000\000 */
{ 4319425 }, /* unc_m2hbm_imc_writes.full\000uncore_m2hbm\000uncore memory\000Full Non-ISOCH - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1801\000\00001\000\000 */
{ 4319558 }, /* unc_m2hbm_imc_writes.full_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Full Line - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1804\000\00001\000\000 */
{ 4319698 }, /* unc_m2hbm_imc_writes.ni\000uncore_m2hbm\000uncore memory\000Non-Inclusive - All Channels. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4319853 }, /* unc_m2hbm_imc_writes.ni_miss\000uncore_m2hbm\000uncore memory\000Non-Inclusive Miss - All Channels. Unit: uncore_m2hbm \000event=0x25,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4320018 }, /* unc_m2hbm_imc_writes.partial\000uncore_m2hbm\000uncore memory\000Partial Non-ISOCH - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1802\000\00001\000\000 */
{ 4320157 }, /* unc_m2hbm_imc_writes.partial_isoch\000uncore_m2hbm\000uncore memory\000ISOCH Partial - All Channels. Unit: uncore_m2hbm \000event=0x25,umask=0x1808\000\00001\000\000 */
{ 4320298 }, /* unc_m2hbm_prefcam_cis_drops\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_CIS_DROPS. Unit: uncore_m2hbm \000event=0x5c\000\00001\000\000 */
{ 4320418 }, /* unc_m2hbm_prefcam_demand_drops.ch0_upi\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x2\000\00001\000\000 */
{ 4320555 }, /* unc_m2hbm_prefcam_demand_drops.ch0_xpt\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x1\000\00001\000\000 */
{ 4320692 }, /* unc_m2hbm_prefcam_demand_drops.ch1_upi\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x8\000\00001\000\000 */
{ 4320829 }, /* unc_m2hbm_prefcam_demand_drops.ch1_xpt\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x4\000\00001\000\000 */
{ 4320966 }, /* unc_m2hbm_prefcam_demand_drops.upi_allch\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped : UPI - All Channels. Unit: uncore_m2hbm \000event=0x58,umask=0xa\000\00001\000\000 */
{ 4321126 }, /* unc_m2hbm_prefcam_demand_drops.xpt_allch\000uncore_m2hbm\000uncore memory\000Data Prefetches Dropped. Unit: uncore_m2hbm \000event=0x58,umask=0x5\000\00001\000\000 */
{ 4321265 }, /* unc_m2hbm_prefcam_demand_merge.upi_allch\000uncore_m2hbm\000uncore memory\000: UPI - All Channels. Unit: uncore_m2hbm \000event=0x5d,umask=0xa\000\00001\000\000 */
{ 4321401 }, /* unc_m2hbm_prefcam_demand_merge.xpt_allch\000uncore_m2hbm\000uncore memory\000: XPT - All Channels. Unit: uncore_m2hbm \000event=0x5d,umask=0x5\000\00001\000\000 */
{ 4321537 }, /* unc_m2hbm_prefcam_demand_no_merge.rd_merged\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x40\000\00001\000\000 */
{ 4321697 }, /* unc_m2hbm_prefcam_demand_no_merge.wr_merged\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x20\000\00001\000\000 */
{ 4321857 }, /* unc_m2hbm_prefcam_demand_no_merge.wr_squashed\000uncore_m2hbm\000uncore memory\000Demands Not Merged with CAMed Prefetches. Unit: uncore_m2hbm \000event=0x5e,umask=0x10\000\00001\000\000 */
{ 4322019 }, /* unc_m2hbm_prefcam_inserts.ch0_upi\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - Ch 0. Unit: uncore_m2hbm \000event=0x56,umask=0x2\000\00001\000\000 */
{ 4322161 }, /* unc_m2hbm_prefcam_inserts.ch0_xpt\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2hbm \000event=0x56,umask=0x1\000\00001\000\000 */
{ 4322303 }, /* unc_m2hbm_prefcam_inserts.ch1_upi\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - Ch 1. Unit: uncore_m2hbm \000event=0x56,umask=0x8\000\00001\000\000 */
{ 4322445 }, /* unc_m2hbm_prefcam_inserts.ch1_xpt\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2hbm \000event=0x56,umask=0x4\000\00001\000\000 */
{ 4322587 }, /* unc_m2hbm_prefcam_inserts.upi_allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : UPI - All Channels. Unit: uncore_m2hbm \000event=0x56,umask=0xa\000\00001\000\000 */
{ 4322739 }, /* unc_m2hbm_prefcam_inserts.xpt_allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2hbm \000event=0x56,umask=0x5\000\00001\000Prefetch CAM Inserts : XPT -All Channels\000 */
{ 4322931 }, /* unc_m2hbm_prefcam_occupancy.allch\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2hbm \000event=0x54,umask=0x3\000\00001\000\000 */
{ 4323077 }, /* unc_m2hbm_prefcam_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x54,umask=0x1\000\00001\000\000 */
{ 4323218 }, /* unc_m2hbm_prefcam_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x54,umask=0x2\000\00001\000\000 */
{ 4323359 }, /* unc_m2hbm_prefcam_resp_miss.allch\000uncore_m2hbm\000uncore memory\000All Channels. Unit: uncore_m2hbm \000event=0x5f,umask=0x3\000\00001\000\000 */
{ 4323480 }, /* unc_m2hbm_prefcam_resp_miss.ch0\000uncore_m2hbm\000uncore memory\000: Channel 0. Unit: uncore_m2hbm \000event=0x5f,umask=0x1\000\00001\000\000 */
{ 4323598 }, /* unc_m2hbm_prefcam_resp_miss.ch1\000uncore_m2hbm\000uncore memory\000: Channel 1. Unit: uncore_m2hbm \000event=0x5f,umask=0x2\000\00001\000\000 */
{ 4323716 }, /* unc_m2hbm_prefcam_rxc_deallocs.1lm_posted\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2hbm \000event=0x62,umask=0x2\000\00001\000\000 */
{ 4323874 }, /* unc_m2hbm_prefcam_rxc_deallocs.cis\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2hbm \000event=0x62,umask=0x8\000\00001\000\000 */
{ 4324018 }, /* unc_m2hbm_prefcam_rxc_deallocs.squashed\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2hbm \000event=0x62,umask=0x1\000\00001\000\000 */
{ 4324172 }, /* unc_m2hbm_prefcam_rxc_occupancy\000uncore_m2hbm\000uncore memory\000UNC_M2HBM_PREFCAM_RxC_OCCUPANCY. Unit: uncore_m2hbm \000event=0x60,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000\000 */
{ 4324338 }, /* unc_m2hbm_rxc_ad.inserts\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x2,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000\000 */
{ 4324532 }, /* unc_m2hbm_rxc_ad_inserts\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) : AD Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x2,umask=0x1\000\00001\000\000 */
{ 4324688 }, /* unc_m2hbm_rxc_ad_occupancy\000uncore_m2hbm\000uncore memory\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2hbm \000event=0x3\000\00001\000\000 */
{ 4324810 }, /* unc_m2hbm_rxc_bl.inserts\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) : BL Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x4,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts anytime a BL packet is added to Ingress\000 */
{ 4325050 }, /* unc_m2hbm_rxc_bl_inserts\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) : BL Ingress (from CMS) Allocations. Unit: uncore_m2hbm \000event=0x4,umask=0x1\000\00001\000Counts anytime a BL packet is added to Ingress\000 */
{ 4325252 }, /* unc_m2hbm_rxc_bl_occupancy\000uncore_m2hbm\000uncore memory\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2hbm \000event=0x5\000\00001\000\000 */
{ 4325374 }, /* unc_m2hbm_tgr_ad_credits\000uncore_m2hbm\000uncore memory\000Number AD Ingress Credits. Unit: uncore_m2hbm \000event=0x2e\000\00001\000\000 */
{ 4325489 }, /* unc_m2hbm_tgr_bl_credits\000uncore_m2hbm\000uncore memory\000Number BL Ingress Credits. Unit: uncore_m2hbm \000event=0x2f\000\00001\000\000 */
{ 4325604 }, /* unc_m2hbm_tracker_inserts.ch0\000uncore_m2hbm\000uncore memory\000Tracker Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x32,umask=0x104\000\00001\000\000 */
{ 4325738 }, /* unc_m2hbm_tracker_inserts.ch1\000uncore_m2hbm\000uncore memory\000Tracker Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x32,umask=0x204\000\00001\000\000 */
{ 4325872 }, /* unc_m2hbm_tracker_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Tracker Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x33,umask=0x1\000\00001\000\000 */
{ 4326008 }, /* unc_m2hbm_tracker_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Tracker Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x33,umask=0x2\000\00001\000\000 */
{ 4326144 }, /* unc_m2hbm_txc_ad.inserts\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) : AD Egress (to CMS) Allocations. Unit: uncore_m2hbm \000event=0x6,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x1\000\00001\000Counts anytime a AD packet is added to Egress\000 */
{ 4326377 }, /* unc_m2hbm_txc_ad_inserts\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) : AD Egress (to CMS) Allocations. Unit: uncore_m2hbm \000event=0x6,umask=0x1\000\00001\000Counts anytime a AD packet is added to Egress\000 */
{ 4326572 }, /* unc_m2hbm_txc_ad_occupancy\000uncore_m2hbm\000uncore memory\000AD Egress (to CMS) Occupancy. Unit: uncore_m2hbm \000event=0x7\000\00001\000\000 */
{ 4326691 }, /* unc_m2hbm_txc_bl.inserts_cms0\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) : Inserts - CMS0 - Near Side. Unit: uncore_m2hbm \000event=0xe,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x101\000\00001\000Counts the number of BL transactions to CMS add port 0\000 */
{ 4326936 }, /* unc_m2hbm_txc_bl.inserts_cms1\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) : Inserts - CMS1 - Far Side. Unit: uncore_m2hbm \000event=0xe,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x201\000\00001\000Counts the number of BL transactions to CMS add port 1\000 */
{ 4327180 }, /* unc_m2hbm_txc_bl_occupancy.all\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : All. Unit: uncore_m2hbm \000event=0xf,umask=0x3\000\00001\000\000 */
{ 4327319 }, /* unc_m2hbm_txc_bl_occupancy.cms0\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : Common Mesh Stop - Near Side. Unit: uncore_m2hbm \000event=0xf,umask=0x1\000\00001\000\000 */
{ 4327484 }, /* unc_m2hbm_txc_bl_occupancy.cms1\000uncore_m2hbm\000uncore memory\000BL Egress (to CMS) Occupancy : Common Mesh Stop - Far Side. Unit: uncore_m2hbm \000event=0xf,umask=0x2\000\00001\000\000 */
{ 4327648 }, /* unc_m2hbm_wpq_flush.ch0\000uncore_m2hbm\000uncore memory\000WPQ Flush : Channel 0. Unit: uncore_m2hbm \000event=0x42,umask=0x1\000\00001\000\000 */
{ 4327768 }, /* unc_m2hbm_wpq_flush.ch1\000uncore_m2hbm\000uncore memory\000WPQ Flush : Channel 1. Unit: uncore_m2hbm \000event=0x42,umask=0x2\000\00001\000\000 */
{ 4327888 }, /* unc_m2hbm_wpq_no_reg_crd.chn0\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2hbm \000event=0x37,umask=0x1\000\00001\000\000 */
{ 4328047 }, /* unc_m2hbm_wpq_no_reg_crd.chn1\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2hbm \000event=0x37,umask=0x2\000\00001\000\000 */
{ 4328206 }, /* unc_m2hbm_wpq_no_spec_crd.chn0\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2hbm \000event=0x38,umask=0x1\000\00001\000\000 */
{ 4328366 }, /* unc_m2hbm_wpq_no_spec_crd.chn1\000uncore_m2hbm\000uncore memory\000M2M and iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2hbm \000event=0x38,umask=0x2\000\00001\000\000 */
{ 4328526 }, /* unc_m2hbm_wr_tracker_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4328667 }, /* unc_m2hbm_wr_tracker_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4328808 }, /* unc_m2hbm_wr_tracker_nonposted_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4328970 }, /* unc_m2hbm_wr_tracker_nonposted_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4329132 }, /* unc_m2hbm_wr_tracker_nonposted_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4329298 }, /* unc_m2hbm_wr_tracker_nonposted_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4329464 }, /* unc_m2hbm_wr_tracker_posted_inserts.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2hbm \000event=0x48,umask=0x1\000\00001\000\000 */
{ 4329619 }, /* unc_m2hbm_wr_tracker_posted_inserts.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2hbm \000event=0x48,umask=0x2\000\00001\000\000 */
{ 4329774 }, /* unc_m2hbm_wr_tracker_posted_occupancy.ch0\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2hbm \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4329933 }, /* unc_m2hbm_wr_tracker_posted_occupancy.ch1\000uncore_m2hbm\000uncore memory\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2hbm \000event=0x47,umask=0x2\000\00001\000\000 */
{ 5374523 }, /* unc_m_act_count.all\000uncore_imc\000uncore memory\000Activate due to read, write, underfill, or bypass. Unit: uncore_imc \000event=0x2,umask=0xff\000\00001\000DRAM Activate Count : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5379862 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xff\000\00001\000DRAM RD_CAS and WR_CAS Commands. : All DRAM Read and Write actions : DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5380684 }, /* unc_m_cas_count.pch0\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 0. Unit: uncore_imc \000event=0x5,umask=0x40\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 0 : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5380912 }, /* unc_m_cas_count.pch1\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 1. Unit: uncore_imc \000event=0x5,umask=0x80\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Pseudo Channel 1 : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5381947 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (including underfills). Unit: uncore_imc \000event=0x5,umask=0xcf\000\00001\000DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM Read CAS commands issued on this channel.  This includes underfills\000 */
{ 5383556 }, /* unc_m_cas_count.rd_pre_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xc2\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5383951 }, /* unc_m_cas_count.rd_pre_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xc8\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5385180 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (does not include underfills). Unit: uncore_imc \000event=0x5,umask=0xc1\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/out auto-pre : DRAM RD_CAS and WR_CAS Commands : Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.   We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5388295 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM underfill read CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xc4\000\00001\000DRAM RD_CAS and WR_CAS Commands. : Underfill Read Issued : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5389495 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM write CAS commands issued. Unit: uncore_imc \000event=0x5,umask=0xf0\000\00001\000DRAM RD_CAS and WR_CAS Commands : Counts the total number of DRAM Write CAS commands issued on this channel\000 */
{ 5390685 }, /* unc_m_cas_count.wr_nonpre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre. Unit: uncore_imc \000event=0x5,umask=0xd0\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5391214 }, /* unc_m_cas_count.wr_pre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x5,umask=0xe0\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5393221 }, /* unc_m_cas_issued_req_len.pch0\000uncore_imc\000uncore memory\000Pseudo Channel 0. Unit: uncore_imc \000event=0x6,umask=0x40\000\00001\000\000 */
{ 5393338 }, /* unc_m_cas_issued_req_len.pch1\000uncore_imc\000uncore memory\000Pseudo Channel 1. Unit: uncore_imc \000event=0x6,umask=0x80\000\00001\000\000 */
{ 5393455 }, /* unc_m_cas_issued_req_len.rd_32b\000uncore_imc\000uncore memory\000Read CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xc8\000\00001\000\000 */
{ 5393600 }, /* unc_m_cas_issued_req_len.rd_64b\000uncore_imc\000uncore memory\000Read CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_imc \000event=0x6,umask=0xc1\000\00001\000\000 */
{ 5393760 }, /* unc_m_cas_issued_req_len.rd_ufill_32b\000uncore_imc\000uncore memory\000Underfill Read CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xd0\000\00001\000\000 */
{ 5393921 }, /* unc_m_cas_issued_req_len.rd_ufill_64b\000uncore_imc\000uncore memory\000Underfill Read CAS Command in Regular Mode (64B) in Pseudochannel 1. Unit: uncore_imc \000event=0x6,umask=0xc2\000\00001\000\000 */
{ 5394097 }, /* unc_m_cas_issued_req_len.wr_32b\000uncore_imc\000uncore memory\000Write CAS Command in Interleaved Mode (32B). Unit: uncore_imc \000event=0x6,umask=0xe0\000\00001\000\000 */
{ 5394243 }, /* unc_m_cas_issued_req_len.wr_64b\000uncore_imc\000uncore memory\000Write CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_imc \000event=0x6,umask=0xc4\000\00001\000\000 */
{ 5394646 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000IMC Clockticks at DCLK frequency. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Number of DRAM DCLK clock cycles while the event is enabled\000 */
{ 5397001 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x44,umask=0x3\000\00001\000DRAM Precharge All Commands : Counts the number of times that the precharge all command was sent\000 */
{ 5399276 }, /* unc_m_hclockticks\000uncore_imc\000uncore memory\000IMC Clockticks at HCLK frequency. Unit: uncore_imc \000event=0x1\000\00001\000Number of DRAM HCLK clock cycles while the event is enabled\000 */
{ 5403415 }, /* unc_m_pcls.rd\000uncore_imc\000uncore memory\000UNC_M_PCLS.RD. Unit: uncore_imc \000event=0xa0,umask=0x5\000\00001\000\000 */
{ 5403617 }, /* unc_m_pcls.total\000uncore_imc\000uncore memory\000UNC_M_PCLS.TOTAL. Unit: uncore_imc \000event=0xa0,umask=0xf\000\00001\000\000 */
{ 5403819 }, /* unc_m_pcls.wr\000uncore_imc\000uncore memory\000UNC_M_PCLS.WR. Unit: uncore_imc \000event=0xa0,umask=0xa\000\00001\000\000 */
{ 5410109 }, /* unc_m_pmm_rpq_inserts\000uncore_imc\000uncore memory\000PMM Read Pending Queue inserts. Unit: uncore_imc \000event=0xe3\000\00001\000Counts number of read requests allocated in the PMM Read Pending Queue\000 */
{ 5411136 }, /* unc_m_pmm_rpq_occupancy.all_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue occupancy. Unit: uncore_imc \000event=0xe0,umask=0x1\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5411337 }, /* unc_m_pmm_rpq_occupancy.all_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue occupancy. Unit: uncore_imc \000event=0xe0,umask=0x2\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5411891 }, /* unc_m_pmm_rpq_occupancy.gnt_wait_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x10\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5412133 }, /* unc_m_pmm_rpq_occupancy.gnt_wait_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x20\000\00001\000PMM Read Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5412609 }, /* unc_m_pmm_rpq_occupancy.no_gnt_sch0\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x4\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5412813 }, /* unc_m_pmm_rpq_occupancy.no_gnt_sch1\000uncore_imc\000uncore memory\000PMM Read Pending Queue Occupancy. Unit: uncore_imc \000event=0xe0,umask=0x8\000\00001\000Accumulates the per cycle occupancy of the PMM Read Pending Queue\000 */
{ 5413131 }, /* unc_m_pmm_wpq_cycles_ne\000uncore_imc\000uncore memory\000PMM (for IXP) Write Queue Cycles Not Empty. Unit: uncore_imc \000event=0xe5\000\00001\000\000 */
{ 5413583 }, /* unc_m_pmm_wpq_inserts\000uncore_imc\000uncore memory\000PMM Write Pending Queue inserts. Unit: uncore_imc \000event=0xe7\000\00001\000Counts number of  write requests allocated in the PMM Write Pending Queue\000 */
{ 5414385 }, /* unc_m_pmm_wpq_occupancy.all\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x3\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the PMM DIMM\000 */
{ 5414826 }, /* unc_m_pmm_wpq_occupancy.all_sch0\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x1\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000 */
{ 5415065 }, /* unc_m_pmm_wpq_occupancy.all_sch1\000uncore_imc\000uncore memory\000PMM Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x2\000\00001\000PMM Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the PMM Write Pending Queue\000 */
{ 5415304 }, /* unc_m_pmm_wpq_occupancy.cas\000uncore_imc\000uncore memory\000PMM (for IXP) Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0xc\000\00001\000PMM (for IXP) Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the IXP DIMM\000 */
{ 5415916 }, /* unc_m_pmm_wpq_occupancy.pwr\000uncore_imc\000uncore memory\000PMM (for IXP) Write Pending Queue Occupancy. Unit: uncore_imc \000event=0xe4,umask=0x30\000\00001\000PMM (for IXP) Write Pending Queue Occupancy : Accumulates the per cycle occupancy of the Write Pending Queue to the IXP DIMM\000 */
{ 5416934 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Channel PPD Cycles. Unit: uncore_imc \000event=0x85\000\00001\000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5418958 }, /* unc_m_power_cke_cycles.low_0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x1\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5419790 }, /* unc_m_power_cke_cycles.low_1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x2\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5420622 }, /* unc_m_power_cke_cycles.low_2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x4\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5421454 }, /* unc_m_power_cke_cycles.low_3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x8\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5428666 }, /* unc_m_power_crit_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5429254 }, /* unc_m_power_crit_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5430287 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Clock-Enabled Self-Refresh. Unit: uncore_imc \000event=0x43\000\00001\000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5438028 }, /* unc_m_pre_count.all\000uncore_imc\000uncore memory\000Precharge due to read, write, underfill, or PGT. Unit: uncore_imc \000event=0x3,umask=0xff\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5441203 }, /* unc_m_pre_count.pgt\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x88\000\00001\000DRAM Precharge commands.  Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5441408 }, /* unc_m_pre_count.pgt_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharges from Page Table. Unit: uncore_imc \000event=0x3,umask=0x8\000\00001\000DRAM Precharge commands. : Precharges from Page Table : Counts the number of DRAM Precharge commands sent on this channel. : Equivalent to PAGE_EMPTY\000 */
{ 5441705 }, /* unc_m_pre_count.pgt_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x80\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5442951 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Precharge due to read on page miss. Unit: uncore_imc \000event=0x3,umask=0x11\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5443167 }, /* unc_m_pre_count.rd_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to read. Unit: uncore_imc \000event=0x3,umask=0x1\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000 */
{ 5443463 }, /* unc_m_pre_count.rd_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x10\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5443673 }, /* unc_m_pre_count.ufill\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x44\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5443881 }, /* unc_m_pre_count.ufill_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x4\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5444093 }, /* unc_m_pre_count.ufill_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x40\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5445243 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Precharge due to write on page miss. Unit: uncore_imc \000event=0x3,umask=0x22\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5445460 }, /* unc_m_pre_count.wr_pch0\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to write. Unit: uncore_imc \000event=0x3,umask=0x2\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000 */
{ 5445759 }, /* unc_m_pre_count.wr_pch1\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x3,umask=0x20\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5500998 }, /* unc_m_rdb_full\000uncore_imc\000uncore memory\000Counts the number of cycles where the read buffer has greater than UMASK elements.  This includes reads to both DDR and PMEM.  NOTE: Umask must be set to the maximum number of elements in the queue (24 entries for SPR). Unit: uncore_imc \000event=0x19\000\00001\000\000 */
{ 5501625 }, /* unc_m_rdb_inserts\000uncore_imc\000uncore memory\000Counts the number of inserts into the read buffer destined for DDR.  Does not count reads destined for PMEM. Unit: uncore_imc \000event=0x17,umask=0x3\000\00001\000\000 */
{ 5501389 }, /* unc_m_rdb_inserts.pch0\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17,umask=0x1\000\00001\000\000 */
{ 5501507 }, /* unc_m_rdb_inserts.pch1\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17,umask=0x2\000\00001\000\000 */
{ 5502154 }, /* unc_m_rdb_ne\000uncore_imc\000uncore memory\000Counts the number of cycles where there's at least one element in the read buffer.  This includes reads to both DDR and PMEM. Unit: uncore_imc \000event=0x18,umask=0x3\000\00001\000\000 */
{ 5501924 }, /* unc_m_rdb_ne.pch0\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18,umask=0x1\000\00001\000\000 */
{ 5502039 }, /* unc_m_rdb_ne.pch1\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18,umask=0x2\000\00001\000\000 */
{ 5502362 }, /* unc_m_rdb_not_empty\000uncore_imc\000uncore memory\000Counts the number of cycles where there's at least one element in the read buffer.  This includes reads to both DDR and PMEM. Unit: uncore_imc \000event=0x18,umask=0x3\000\00001\000\000 */
{ 5502684 }, /* unc_m_rdb_occupancy\000uncore_imc\000uncore memory\000Counts the number of elements in the read buffer, including reads to both DDR and PMEM. Unit: uncore_imc \000event=0x1a\000\00001\000\000 */
{ 5507389 }, /* unc_m_rpq_inserts.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5507980 }, /* unc_m_rpq_inserts.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5511146 }, /* unc_m_rpq_occupancy_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5511864 }, /* unc_m_rpq_occupancy_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5512729 }, /* unc_m_sb_accesses.accepts\000uncore_imc\000uncore memory\000Scoreboard accepts. Unit: uncore_imc \000event=0xd2,umask=0x5\000\00001\000\000 */
{ 5512844 }, /* unc_m_sb_accesses.fm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Accepts. Unit: uncore_imc \000event=0xd2,umask=0x40\000\00001\000\000 */
{ 5513115 }, /* unc_m_sb_accesses.fm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : Write Rejects. Unit: uncore_imc \000event=0xd2,umask=0x80\000\00001\000\000 */
{ 5513634 }, /* unc_m_sb_accesses.nm_rd_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM read completions. Unit: uncore_imc \000event=0xd2,umask=0x10\000\00001\000\000 */
{ 5513917 }, /* unc_m_sb_accesses.nm_wr_cmps\000uncore_imc\000uncore memory\000Scoreboard Accesses : FM write completions. Unit: uncore_imc \000event=0xd2,umask=0x20\000\00001\000\000 */
{ 5514450 }, /* unc_m_sb_accesses.rd_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Accepts. Unit: uncore_imc \000event=0xd2,umask=0x1\000\00001\000\000 */
{ 5514717 }, /* unc_m_sb_accesses.rd_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : Read Rejects. Unit: uncore_imc \000event=0xd2,umask=0x2\000\00001\000\000 */
{ 5515131 }, /* unc_m_sb_accesses.rejects\000uncore_imc\000uncore memory\000Scoreboard rejects. Unit: uncore_imc \000event=0xd2,umask=0xa\000\00001\000\000 */
{ 5515246 }, /* unc_m_sb_accesses.wr_accepts\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM read completions. Unit: uncore_imc \000event=0xd2,umask=0x4\000\00001\000\000 */
{ 5515527 }, /* unc_m_sb_accesses.wr_rejects\000uncore_imc\000uncore memory\000Scoreboard Accesses : NM write completions. Unit: uncore_imc \000event=0xd2,umask=0x8\000\00001\000\000 */
{ 5515810 }, /* unc_m_sb_canary.alloc\000uncore_imc\000uncore memory\000: Alloc. Unit: uncore_imc \000event=0xd9,umask=0x1\000\00001\000\000 */
{ 5516008 }, /* unc_m_sb_canary.dealloc\000uncore_imc\000uncore memory\000: Dealloc. Unit: uncore_imc \000event=0xd9,umask=0x2\000\00001\000\000 */
{ 5516214 }, /* unc_m_sb_canary.fm_rd_starved\000uncore_imc\000uncore memory\000: Near Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x20\000\00001\000\000 */
{ 5516340 }, /* unc_m_sb_canary.fm_tgr_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Write Starved. Unit: uncore_imc \000event=0xd9,umask=0x80\000\00001\000\000 */
{ 5516469 }, /* unc_m_sb_canary.fm_wr_starved\000uncore_imc\000uncore memory\000: Far Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x40\000\00001\000\000 */
{ 5517368 }, /* unc_m_sb_canary.nm_rd_starved\000uncore_imc\000uncore memory\000: Valid. Unit: uncore_imc \000event=0xd9,umask=0x8\000\00001\000\000 */
{ 5517476 }, /* unc_m_sb_canary.nm_wr_starved\000uncore_imc\000uncore memory\000: Near Mem Read Starved. Unit: uncore_imc \000event=0xd9,umask=0x10\000\00001\000\000 */
{ 5518292 }, /* unc_m_sb_canary.vld\000uncore_imc\000uncore memory\000: Reject. Unit: uncore_imc \000event=0xd9,umask=0x4\000\00001\000\000 */
{ 5518487 }, /* unc_m_sb_cycles_full\000uncore_imc\000uncore memory\000Scoreboard Cycles Full. Unit: uncore_imc \000event=0xd1\000\00001\000\000 */
{ 5518591 }, /* unc_m_sb_cycles_ne\000uncore_imc\000uncore memory\000Scoreboard Cycles Not-Empty. Unit: uncore_imc \000event=0xd0\000\00001\000\000 */
{ 5518698 }, /* unc_m_sb_inserts.block_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region reads. Unit: uncore_imc \000event=0xd6,umask=0x10\000\00001\000\000 */
{ 5518973 }, /* unc_m_sb_inserts.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Block region writes. Unit: uncore_imc \000event=0xd6,umask=0x20\000\00001\000\000 */
{ 5519535 }, /* unc_m_sb_inserts.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem reads. Unit: uncore_imc \000event=0xd6,umask=0x4\000\00001\000\000 */
{ 5519808 }, /* unc_m_sb_inserts.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Persistent Mem writes. Unit: uncore_imc \000event=0xd6,umask=0x8\000\00001\000\000 */
{ 5520083 }, /* unc_m_sb_inserts.rds\000uncore_imc\000uncore memory\000Scoreboard Inserts : Reads. Unit: uncore_imc \000event=0xd6,umask=0x1\000\00001\000\000 */
{ 5520318 }, /* unc_m_sb_inserts.wrs\000uncore_imc\000uncore memory\000Scoreboard Inserts : Writes. Unit: uncore_imc \000event=0xd6,umask=0x2\000\00001\000\000 */
{ 5520555 }, /* unc_m_sb_occupancy.block_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region reads. Unit: uncore_imc \000event=0xd5,umask=0x20\000\00001\000\000 */
{ 5520838 }, /* unc_m_sb_occupancy.block_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Block region writes. Unit: uncore_imc \000event=0xd5,umask=0x40\000\00001\000\000 */
{ 5521249 }, /* unc_m_sb_occupancy.pmm_rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem reads. Unit: uncore_imc \000event=0xd5,umask=0x4\000\00001\000\000 */
{ 5521530 }, /* unc_m_sb_occupancy.pmm_wrs\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Persistent Mem writes. Unit: uncore_imc \000event=0xd5,umask=0x8\000\00001\000\000 */
{ 5521813 }, /* unc_m_sb_occupancy.rds\000uncore_imc\000uncore memory\000Scoreboard Occupancy : Reads. Unit: uncore_imc \000event=0xd5,umask=0x1\000\00001\000\000 */
{ 5522178 }, /* unc_m_sb_pref_inserts.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : All. Unit: uncore_imc \000event=0xda,umask=0x1\000\00001\000\000 */
{ 5522308 }, /* unc_m_sb_pref_inserts.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : DDR4. Unit: uncore_imc \000event=0xda,umask=0x2\000\00001\000\000 */
{ 5522439 }, /* unc_m_sb_pref_inserts.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Inserts : PMM. Unit: uncore_imc \000event=0xda,umask=0x4\000\00001\000\000 */
{ 5522710 }, /* unc_m_sb_pref_occupancy.all\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : All. Unit: uncore_imc \000event=0xdb,umask=0x1\000\00001\000\000 */
{ 5522844 }, /* unc_m_sb_pref_occupancy.ddr\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : DDR4. Unit: uncore_imc \000event=0xdb,umask=0x2\000\00001\000\000 */
{ 5523151 }, /* unc_m_sb_pref_occupancy.pmm\000uncore_imc\000uncore memory\000Scoreboard Prefetch Occupancy : Persistent Mem. Unit: uncore_imc \000event=0xdb,ch_mask=0x00000000,fc_mask=0x00000000,umask=0x4\000\00001\000\000 */
{ 5523479 }, /* unc_m_sb_reject.canary\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x8\000\00001\000\000 */
{ 5523611 }, /* unc_m_sb_reject.ddr_early_cmp\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected. Unit: uncore_imc \000event=0xd4,umask=0x20\000\00001\000\000 */
{ 5523751 }, /* unc_m_sb_reject.fm_addr_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : FM requests rejected due to full address conflict. Unit: uncore_imc \000event=0xd4,umask=0x2\000\00001\000\000 */
{ 5524132 }, /* unc_m_sb_reject.nm_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : NM requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x1\000\00001\000\000 */
{ 5524493 }, /* unc_m_sb_reject.patrol_set_cnflt\000uncore_imc\000uncore memory\000Number of Scoreboard Requests Rejected : Patrol requests rejected due to set conflict. Unit: uncore_imc \000event=0xd4,umask=0x4\000\00001\000\000 */
{ 5524870 }, /* unc_m_sb_strv_alloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x2\000\00001\000\000 */
{ 5524987 }, /* unc_m_sb_strv_alloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd7,umask=0x10\000\00001\000\000 */
{ 5525109 }, /* unc_m_sb_strv_alloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x8\000\00001\000\000 */
{ 5526208 }, /* unc_m_sb_strv_alloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xd7,umask=0x1\000\00001\000\000 */
{ 5526326 }, /* unc_m_sb_strv_alloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xd7,umask=0x4\000\00001\000\000 */
{ 5527261 }, /* unc_m_sb_strv_dealloc.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x2\000\00001\000\000 */
{ 5527380 }, /* unc_m_sb_strv_dealloc.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xde,umask=0x10\000\00001\000\000 */
{ 5527504 }, /* unc_m_sb_strv_dealloc.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x8\000\00001\000\000 */
{ 5528137 }, /* unc_m_sb_strv_dealloc.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read - Set. Unit: uncore_imc \000event=0xde,umask=0x1\000\00001\000\000 */
{ 5528257 }, /* unc_m_sb_strv_dealloc.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write - Set. Unit: uncore_imc \000event=0xde,umask=0x4\000\00001\000\000 */
{ 5528718 }, /* unc_m_sb_strv_occ.fm_rd\000uncore_imc\000uncore memory\000: Far Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x2\000\00001\000\000 */
{ 5528827 }, /* unc_m_sb_strv_occ.fm_tgr\000uncore_imc\000uncore memory\000: Near Mem Read - Clear. Unit: uncore_imc \000event=0xd8,umask=0x10\000\00001\000\000 */
{ 5528947 }, /* unc_m_sb_strv_occ.fm_wr\000uncore_imc\000uncore memory\000: Far Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x8\000\00001\000\000 */
{ 5529759 }, /* unc_m_sb_strv_occ.nm_rd\000uncore_imc\000uncore memory\000: Near Mem Read. Unit: uncore_imc \000event=0xd8,umask=0x1\000\00001\000\000 */
{ 5529869 }, /* unc_m_sb_strv_occ.nm_wr\000uncore_imc\000uncore memory\000: Near Mem Write. Unit: uncore_imc \000event=0xd8,umask=0x4\000\00001\000\000 */
{ 5530519 }, /* unc_m_sb_tagged.ddr4_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.DDR4_CMP. Unit: uncore_imc \000event=0xdd,umask=0x8\000\00001\000\000 */
{ 5530639 }, /* unc_m_sb_tagged.new\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.NEW. Unit: uncore_imc \000event=0xdd,umask=0x1\000\00001\000\000 */
{ 5530749 }, /* unc_m_sb_tagged.occ\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.OCC. Unit: uncore_imc \000event=0xdd,umask=0x80\000\00001\000\000 */
{ 5530860 }, /* unc_m_sb_tagged.pmm0_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM0_CMP. Unit: uncore_imc \000event=0xdd,umask=0x10\000\00001\000\000 */
{ 5530981 }, /* unc_m_sb_tagged.pmm1_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM1_CMP. Unit: uncore_imc \000event=0xdd,umask=0x20\000\00001\000\000 */
{ 5531102 }, /* unc_m_sb_tagged.pmm2_cmp\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.PMM2_CMP. Unit: uncore_imc \000event=0xdd,umask=0x40\000\00001\000\000 */
{ 5531223 }, /* unc_m_sb_tagged.rd_hit\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_HIT. Unit: uncore_imc \000event=0xdd,umask=0x2\000\00001\000\000 */
{ 5531339 }, /* unc_m_sb_tagged.rd_miss\000uncore_imc\000uncore memory\000UNC_M_SB_TAGGED.RD_MISS. Unit: uncore_imc \000event=0xdd,umask=0x4\000\00001\000\000 */
{ 5531585 }, /* unc_m_tagchk.hit\000uncore_imc\000uncore memory\0002LM Tag check hit in near memory cache (DDR4). Unit: uncore_imc \000event=0xd3,umask=0x1\000\00001\000\000 */
{ 5532007 }, /* unc_m_tagchk.miss_clean\000uncore_imc\000uncore memory\0002LM Tag check miss, no data at this line. Unit: uncore_imc \000event=0xd3,umask=0x2\000\00001\000\000 */
{ 5532475 }, /* unc_m_tagchk.miss_dirty\000uncore_imc\000uncore memory\0002LM Tag check miss, existing data may be evicted to PMM. Unit: uncore_imc \000event=0xd3,umask=0x4\000\00001\000\000 */
{ 5532938 }, /* unc_m_tagchk.nm_rd_hit\000uncore_imc\000uncore memory\0002LM Tag check hit due to memory read. Unit: uncore_imc \000event=0xd3,umask=0x8\000\00001\000\000 */
{ 5533209 }, /* unc_m_tagchk.nm_wr_hit\000uncore_imc\000uncore memory\0002LM Tag check hit due to memory write. Unit: uncore_imc \000event=0xd3,umask=0x10\000\00001\000\000 */
{ 5541626 }, /* unc_m_wpq_inserts.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5542390 }, /* unc_m_wpq_inserts.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5548167 }, /* unc_m_wpq_occupancy_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x82\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5549641 }, /* unc_m_wpq_occupancy_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x83\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5552487 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555177 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5614053 }, /* unc_mchbm_act_count.all\000uncore_mchbm\000uncore memory\000Activate due to read, write, underfill, or bypass. Unit: uncore_mchbm \000event=0x2,umask=0xff\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5614505 }, /* unc_mchbm_act_count.rd\000uncore_mchbm\000uncore memory\000Activate due to read. Unit: uncore_mchbm \000event=0x2,umask=0x11\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5614927 }, /* unc_mchbm_act_count.rd_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Read in PCH0. Unit: uncore_mchbm \000event=0x2,umask=0x1\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5615382 }, /* unc_mchbm_act_count.rd_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Read in PCH1. Unit: uncore_mchbm \000event=0x2,umask=0x10\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5615838 }, /* unc_mchbm_act_count.ufill\000uncore_mchbm\000uncore memory\000HBM Activate Count : Underfill Read transaction on Page Empty or Page Miss. Unit: uncore_mchbm \000event=0x2,umask=0x44\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5616317 }, /* unc_mchbm_act_count.ufill_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count. Unit: uncore_mchbm \000event=0x2,umask=0x4\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5616744 }, /* unc_mchbm_act_count.ufill_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count. Unit: uncore_mchbm \000event=0x2,umask=0x40\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5617172 }, /* unc_mchbm_act_count.wr\000uncore_mchbm\000uncore memory\000Activate due to write. Unit: uncore_mchbm \000event=0x2,umask=0x22\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5617595 }, /* unc_mchbm_act_count.wr_pch0\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Write in PCH0. Unit: uncore_mchbm \000event=0x2,umask=0x2\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5618051 }, /* unc_mchbm_act_count.wr_pch1\000uncore_mchbm\000uncore memory\000HBM Activate Count : Activate due to Write in PCH1. Unit: uncore_mchbm \000event=0x2,umask=0x20\000\00001\000Counts the number of HBM Activate commands sent on this channel.  Activate commands are issued to open up a page on the HBM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5618508 }, /* unc_mchbm_cas_count.all\000uncore_mchbm\000uncore memory\000All CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xff\000\00001\000\000 */
{ 5618630 }, /* unc_mchbm_cas_count.pch0\000uncore_mchbm\000uncore memory\000Pseudo Channel 0. Unit: uncore_mchbm \000event=0x5,umask=0x40\000\00001\000HBM RD_CAS and WR_CAS Commands\000 */
{ 5618776 }, /* unc_mchbm_cas_count.pch1\000uncore_mchbm\000uncore memory\000Pseudo Channel 1. Unit: uncore_mchbm \000event=0x5,umask=0x80\000\00001\000HBM RD_CAS and WR_CAS Commands\000 */
{ 5618922 }, /* unc_mchbm_cas_count.rd\000uncore_mchbm\000uncore memory\000Read CAS commands issued (regular and underfill). Unit: uncore_mchbm \000event=0x5,umask=0xcf\000\00001\000\000 */
{ 5619068 }, /* unc_mchbm_cas_count.rd_pre_reg\000uncore_mchbm\000uncore memory\000Regular read CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xc2\000\00001\000\000 */
{ 5619214 }, /* unc_mchbm_cas_count.rd_pre_underfill\000uncore_mchbm\000uncore memory\000Underfill read CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xc8\000\00001\000\000 */
{ 5619368 }, /* unc_mchbm_cas_count.rd_reg\000uncore_mchbm\000uncore memory\000Regular read CAS commands issued (does not include underfills). Unit: uncore_mchbm \000event=0x5,umask=0xc1\000\00001\000\000 */
{ 5619532 }, /* unc_mchbm_cas_count.rd_underfill\000uncore_mchbm\000uncore memory\000Underfill read CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xc4\000\00001\000\000 */
{ 5619674 }, /* unc_mchbm_cas_count.wr\000uncore_mchbm\000uncore memory\000Write CAS commands issued. Unit: uncore_mchbm \000event=0x5,umask=0xf0\000\00001\000\000 */
{ 5619797 }, /* unc_mchbm_cas_count.wr_nonpre\000uncore_mchbm\000uncore memory\000HBM RD_CAS and WR_CAS Commands. : HBM WR_CAS commands w/o auto-pre. Unit: uncore_mchbm \000event=0x5,umask=0xd0\000\00001\000\000 */
{ 5619968 }, /* unc_mchbm_cas_count.wr_pre\000uncore_mchbm\000uncore memory\000Write CAS commands with precharge. Unit: uncore_mchbm \000event=0x5,umask=0xe0\000\00001\000\000 */
{ 5620103 }, /* unc_mchbm_cas_issued_req_len.pch0\000uncore_mchbm\000uncore memory\000Pseudo Channel 0. Unit: uncore_mchbm \000event=0x6,umask=0x40\000\00001\000\000 */
{ 5620228 }, /* unc_mchbm_cas_issued_req_len.pch1\000uncore_mchbm\000uncore memory\000Pseudo Channel 1. Unit: uncore_mchbm \000event=0x6,umask=0x80\000\00001\000\000 */
{ 5620353 }, /* unc_mchbm_cas_issued_req_len.rd_32b\000uncore_mchbm\000uncore memory\000Read CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xc8\000\00001\000\000 */
{ 5620506 }, /* unc_mchbm_cas_issued_req_len.rd_64b\000uncore_mchbm\000uncore memory\000Read CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_mchbm \000event=0x6,umask=0xc1\000\00001\000\000 */
{ 5620674 }, /* unc_mchbm_cas_issued_req_len.rd_ufill_32b\000uncore_mchbm\000uncore memory\000Underfill Read CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xd0\000\00001\000\000 */
{ 5620843 }, /* unc_mchbm_cas_issued_req_len.rd_ufill_64b\000uncore_mchbm\000uncore memory\000Underfill Read CAS Command in Regular Mode (64B) in Pseudochannel 1. Unit: uncore_mchbm \000event=0x6,umask=0xc2\000\00001\000\000 */
{ 5621027 }, /* unc_mchbm_cas_issued_req_len.wr_32b\000uncore_mchbm\000uncore memory\000Write CAS Command in Interleaved Mode (32B). Unit: uncore_mchbm \000event=0x6,umask=0xe0\000\00001\000\000 */
{ 5621181 }, /* unc_mchbm_cas_issued_req_len.wr_64b\000uncore_mchbm\000uncore memory\000Write CAS Command in Regular Mode (64B) in Pseudochannel 0. Unit: uncore_mchbm \000event=0x6,umask=0xc4\000\00001\000\000 */
{ 5621350 }, /* unc_mchbm_clockticks\000uncore_mchbm\000uncore memory\000IMC Clockticks at DCLK frequency. Unit: uncore_mchbm \000event=0x1,umask=0x1\000\00001\000\000 */
{ 5621477 }, /* unc_mchbm_hbm_pre_all\000uncore_mchbm\000uncore memory\000All Precharge Commands. Unit: uncore_mchbm \000event=0x44,umask=0x3\000\00001\000Precharge All Commands: Counts the number of times that the precharge all command was sent\000 */
{ 5621686 }, /* unc_mchbm_hbm_preall.pch0\000uncore_mchbm\000uncore memory\000HBM Precharge All Commands. Unit: uncore_mchbm \000event=0x44,umask=0x1\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5621879 }, /* unc_mchbm_hbm_preall.pch1\000uncore_mchbm\000uncore memory\000HBM Precharge All Commands. Unit: uncore_mchbm \000event=0x44,umask=0x2\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5622072 }, /* unc_mchbm_hclockticks\000uncore_mchbm\000uncore memory\000IMC Clockticks at HCLK frequency. Unit: uncore_mchbm \000event=0x1\000\00001\000\000 */
{ 5622190 }, /* unc_mchbm_pre_count.all\000uncore_mchbm\000uncore memory\000All precharge events. Unit: uncore_mchbm \000event=0x3,umask=0xff\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5622373 }, /* unc_mchbm_pre_count.pgt\000uncore_mchbm\000uncore memory\000Precharge from MC page table. Unit: uncore_mchbm \000event=0x3,umask=0x88\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5622564 }, /* unc_mchbm_pre_count.pgt_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharges from Page Table. Unit: uncore_mchbm \000event=0x3,umask=0x8\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Equivalent to PAGE_EMPTY\000 */
{ 5622811 }, /* unc_mchbm_pre_count.pgt_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x80\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5623001 }, /* unc_mchbm_pre_count.rd\000uncore_mchbm\000uncore memory\000Precharge due to read on page miss. Unit: uncore_mchbm \000event=0x3,umask=0x11\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5623197 }, /* unc_mchbm_pre_count.rd_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharge due to read. Unit: uncore_mchbm \000event=0x3,umask=0x1\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Precharge from read bank scheduler\000 */
{ 5623448 }, /* unc_mchbm_pre_count.rd_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x10\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5623637 }, /* unc_mchbm_pre_count.ufill\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x44\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5623824 }, /* unc_mchbm_pre_count.ufill_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x4\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5624015 }, /* unc_mchbm_pre_count.ufill_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x40\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5624207 }, /* unc_mchbm_pre_count.wr\000uncore_mchbm\000uncore memory\000Precharge due to write on page miss. Unit: uncore_mchbm \000event=0x3,umask=0x22\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5624404 }, /* unc_mchbm_pre_count.wr_pch0\000uncore_mchbm\000uncore memory\000HBM Precharge commands. : Precharge due to write. Unit: uncore_mchbm \000event=0x3,umask=0x2\000\00001\000Counts the number of HBM Precharge commands sent on this channel. : Precharge from write bank scheduler\000 */
{ 5624657 }, /* unc_mchbm_pre_count.wr_pch1\000uncore_mchbm\000uncore memory\000HBM Precharge commands. Unit: uncore_mchbm \000event=0x3,umask=0x20\000\00001\000Counts the number of HBM Precharge commands sent on this channel\000 */
{ 5624846 }, /* unc_mchbm_rdb_full\000uncore_mchbm\000uncore memory\000Counts the number of cycles where the read buffer has greater than UMASK elements.  NOTE: Umask must be set to the maximum number of elements in the queue (24 entries for SPR). Unit: uncore_mchbm \000event=0x19\000\00001\000\000 */
{ 5625357 }, /* unc_mchbm_rdb_inserts\000uncore_mchbm\000uncore memory\000Counts the number of inserts into the read buffer. Unit: uncore_mchbm \000event=0x17,umask=0x3\000\00001\000\000 */
{ 5625105 }, /* unc_mchbm_rdb_inserts.pch0\000uncore_mchbm\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_mchbm \000event=0x17,umask=0x1\000\00001\000\000 */
{ 5625231 }, /* unc_mchbm_rdb_inserts.pch1\000uncore_mchbm\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_mchbm \000event=0x17,umask=0x2\000\00001\000\000 */
{ 5625503 }, /* unc_mchbm_rdb_occupancy\000uncore_mchbm\000uncore memory\000Counts the number of elements in the read buffer per cycle. Unit: uncore_mchbm \000event=0x1a\000\00001\000\000 */
{ 5625650 }, /* unc_mchbm_rpq_inserts.pch0\000uncore_mchbm\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_mchbm \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations: Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5626248 }, /* unc_mchbm_rpq_inserts.pch1\000uncore_mchbm\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_mchbm \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations: Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5626846 }, /* unc_mchbm_rpq_occupancy_pch0\000uncore_mchbm\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x80\000\00001\000Read Pending Queue Occupancy: Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5627571 }, /* unc_mchbm_rpq_occupancy_pch1\000uncore_mchbm\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x81\000\00001\000Read Pending Queue Occupancy: Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5628296 }, /* unc_mchbm_wpq_inserts.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_mchbm \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations: Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5629059 }, /* unc_mchbm_wpq_inserts.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_mchbm \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations: Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5629822 }, /* unc_mchbm_wpq_occupancy_pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x82\000\00001\000Write Pending Queue Occupancy: Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to memory.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5631297 }, /* unc_mchbm_wpq_occupancy_pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_mchbm \000event=0x83\000\00001\000Write Pending Queue Occupancy: Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to memory.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5634158 }, /* unc_mchbm_wpq_read_hit\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5632772 }, /* unc_mchbm_wpq_read_hit.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,umask=0x1\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5633465 }, /* unc_mchbm_wpq_read_hit.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x23,umask=0x2\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5636231 }, /* unc_mchbm_wpq_write_hit\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,ch_mask=0x00000000,fc_mask=0x00000000\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5634843 }, /* unc_mchbm_wpq_write_hit.pch0\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,umask=0x1\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5635537 }, /* unc_mchbm_wpq_write_hit.pch1\000uncore_mchbm\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_mchbm \000event=0x24,umask=0x2\000\00001\000Write Pending Queue CAM Match: Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5641553 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000PCU PCLK Clockticks. Unit: uncore_pcu \000event=0x1\000\00001\000Number of PCU PCLK Clock cycles while the event is enabled\000 */
{ 5650924 }, /* unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000 */
{ 5656346 }, /* unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000 */
{ 5663972 }, /* unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Phase Shed 0 Cycles : Cycles spent in phase-shedding power state 0\000 */
{ 5664290 }, /* unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Phase Shed 1 Cycles : Cycles spent in phase-shedding power state 1\000 */
{ 5664608 }, /* unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Phase Shed 2 Cycles : Cycles spent in phase-shedding power state 2\000 */
{ 5664926 }, /* unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Phase Shed 3 Cycles : Cycles spent in phase-shedding power state 3\000 */
{ 5667556 }, /* unc_p_freq_clip_avx256\000uncore_pcu\000uncore power\000AVX256 Frequency Clipping. Unit: uncore_pcu \000event=0x49\000\00001\000\000 */
{ 5667664 }, /* unc_p_freq_clip_avx512\000uncore_pcu\000uncore power\000AVX512 Frequency Clipping. Unit: uncore_pcu \000event=0x4a\000\00001\000\000 */
{ 5668479 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Thermal Strongest Upper Limit Cycles : Number of cycles any frequency is reduced due to a thermal limit.  Count only if throttling is occurring\000 */
{ 5669130 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Power Strongest Upper Limit Cycles : Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670854 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000IO P Limit Strongest Lower Limit Cycles : Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673412 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Cycles spent changing Frequency : Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5674248 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Memory Phase Shedding Cycles : Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5676034 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Package C State Residency - C0 : Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677059 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Package C State Residency - C2E : Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678442 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Package C State Residency - C6 : Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679127 }, /* unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000 */
{ 5683099 }, /* unc_p_power_state_occupancy_cores_c0\000uncore_pcu\000uncore power\000Number of cores in C0. Unit: uncore_pcu \000event=0x35\000\00001\000Number of cores in C0 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5683525 }, /* unc_p_power_state_occupancy_cores_c3\000uncore_pcu\000uncore power\000Number of cores in C3. Unit: uncore_pcu \000event=0x36\000\00001\000Number of cores in C3 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5683951 }, /* unc_p_power_state_occupancy_cores_c6\000uncore_pcu\000uncore power\000Number of cores in C6. Unit: uncore_pcu \000event=0x37\000\00001\000Number of cores in C6 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684699 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000External Prochot : Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685335 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Internal Prochot : Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5686051 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Total Core C State Transition Cycles : Number of cycles spent performing core C state transitions across all cores\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 790903 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x12,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 792844 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x12,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 795440 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x12,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 798514 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data load to a 1G page\000event=0x12,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 801756 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x12,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805041 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x12,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 807898 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x12,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 812949 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x13,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815192 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x13,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 817717 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x13,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 820133 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walks completed due to a demand data store to a 1G page\000event=0x13,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 823142 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x13,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 826253 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x13,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 829779 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x13,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1082395 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x11,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085351 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x11,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1086273 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x11,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1090892 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x11,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1093725 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x11,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1097473 }, /* itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x11,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
};

static const struct compact_pmu_event pmu_metrics__sapphirerapids[] = {
{ 3686 }, /* \000C1_Core_Residency\000Power\000cstate_core@c1\\-residency@ / TSC\000\000C1 residency percent per core\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 12911 }, /* \000dtlb_2nd_level_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 13408 }, /* \000dtlb_2nd_level_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 13834 }, /* \000dtlb_2nd_level_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 17218 }, /* \000io_bandwidth_read\000\000UNC_CHA_TOR_INSERTS.IO_PCIRDCUR * 64 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000 */
{ 17954 }, /* \000io_bandwidth_write\000\000(UNC_CHA_TOR_INSERTS.IO_ITOM + UNC_CHA_TOR_INSERTS.IO_ITOMCACHENEAR) * 64 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19058 }, /* \000itlb_2nd_level_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 19568 }, /* \000itlb_2nd_level_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23125 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25514 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25947 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28053 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000UNC_CHA_TOR_INSERTS.IA_MISS_CRD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 32318 }, /* \000llc_data_read_mpi_demand_plus_prefetch\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_LLCPREFDATA + UNC_CHA_TOR_INSERTS.IA_MISS_DRD + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF) / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 33273 }, /* \000llc_demand_data_read_miss_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 33606 }, /* \000llc_demand_data_read_miss_latency_for_local_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_LOCAL) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 34002 }, /* \000llc_demand_data_read_miss_latency_for_remote_requests\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_REMOTE) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 34403 }, /* \000llc_demand_data_read_miss_to_dram_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to DRAM in nano seconds\000\0001ns\000\000\000\00000 */
{ 34774 }, /* \000llc_demand_data_read_miss_to_pmem_latency\000\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / (UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM) * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand data read miss (read memory access) addressed to Intel(R) Optane(TM) Persistent Memory(PMEM) in nano seconds\000\0001ns\000\000\000\00000 */
{ 35184 }, /* \000llc_miss_local_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35388 }, /* \000llc_miss_local_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35595 }, /* \000llc_miss_remote_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 35802 }, /* \000llc_miss_remote_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 36012 }, /* \000loads_per_instr\000\000MEM_INST_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39732 }, /* \000memory_extra_write_bw_due_to_directory_updates\000\000(UNC_CHA_DIR_UPDATE.HA + UNC_CHA_DIR_UPDATE.TOR + UNC_M2M_DIRECTORY_UPDATE.ANY) * 64 / 1e6 / duration_time\000\000Memory write bandwidth (MB/sec) caused by directory updates; includes DDR and Intel(R) Optane(TM) Persistent Memory(PMEM)\000\0001MB/s\000\000\000\00000 */
{ 40404 }, /* \000numa_reads_addressed_to_local_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 41615 }, /* \000numa_reads_addressed_to_remote_dram\000\000(UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE) / (UNC_CHA_TOR_INSERTS.IA_MISS_DRD_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_LOCAL + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_REMOTE + UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PREF_REMOTE)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43154 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43654 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44654 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS + LSD.UOPS)\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 45098 }, /* \000pmem_memory_bandwidth_read\000\000UNC_M_PMM_RPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45264 }, /* \000pmem_memory_bandwidth_total\000\000(UNC_M_PMM_RPQ_INSERTS + UNC_M_PMM_WPQ_INSERTS) * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 45452 }, /* \000pmem_memory_bandwidth_write\000\000UNC_M_PMM_WPQ_INSERTS * 64 / 1e6 / duration_time\000\000Intel(R) Optane(TM) Persistent Memory(PMEM) memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49006 }, /* \000stores_per_instr\000\000MEM_INST_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 50804 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5_11 + UOPS_DISPATCHED.PORT_6) / (5 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 52229 }, /* \000tma_amx_busy\000Compute;HPC;Server;TopdownL5;tma_L5_group;tma_ports_utilized_0_group\000EXE.AMX_BUSY / tma_info_core_core_clks\000tma_amx_busy > 0.5 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles where the Advanced Matrix Extensions (AMX) execution engine was busy with tile (arithmetic) operations\000\000100%\000\000\000\00000 */
{ 56852 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * cpu@ASSISTS.ANY\\,umask\\=0x1B@ / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 57906 }, /* \000tma_avx_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00063 * ASSISTS.SSE_AVX_MIX / tma_info_thread_slots\000tma_avx_assists > 0.1\000This metric estimates fraction of slots the CPU retired uops as a result of handing SSE to AVX* or AVX* to SSE transition Assists\000\000100%\000\000\000\00000 */
{ 58180 }, /* \000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 64724 }, /* \000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 68445 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;Default;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000topdown\\-br\\-mispredict / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: TOPDOWN.BR_MISPREDICT_SLOTS. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 74979 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources. Sample with: FRONTEND_RETIRED.MS_FLOWS\000100%\000\000\000\00000 */
{ 77914 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - tma_branch_mispredicts / tma_bad_speculation) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 96010 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(76 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 75.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 97307 }, /* \000tma_core_bound\000Backend;Compute;Default;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 112298 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00075.5 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD + MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 114774 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116697 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIV_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122373 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks - tma_pmm_bound if #has_pmem > 0 else MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks)\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 125300 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 136052 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - MEMORY_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 139263 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 152564 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00080 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 153696 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 157148 }, /* \000tma_fetch_bandwidth\000Default;FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 162800 }, /* \000tma_fetch_latency\000Default;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000topdown\\-fetch\\-lat / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 166719 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000max(0, tma_heavy_operations - tma_microcode_sequencer)\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 167967 }, /* \000tma_fp_amx\000Compute;Flops;HPC;Pipeline;Server;TopdownL4;tma_L4_group;tma_fp_arith_group\000cpu@AMX_OPS_RETIRED.BF16\\,cmask\\=1@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_amx > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) matrix uops fraction the CPU has retired (aggregated across all supported FP datatypes in AMX engine)\000This metric approximates arithmetic floating-point (FP) matrix uops fraction the CPU has retired (aggregated across all supported FP datatypes in AMX engine). Refer to AMX_Busy and GFLOPs metrics for actual AMX utilization and FP performance, resp\000100%\000\000\000\00000 */
{ 168617 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector + tma_fp_amx\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 170369 }, /* \000tma_fp_assists\000HPC;TopdownL5;tma_L5_group;tma_assists_group\00030 * ASSISTS.FP / tma_info_thread_slots\000tma_fp_assists > 0.1\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Floating Point (FP) Assists. FP Assist may apply when working with very small floating point values (so-called Denormals)\000100%\000\000\000\00000 */
{ 172037 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR) / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 175532 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000(cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ + FP_ARITH_INST_RETIRED2.VECTOR) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 179244 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.128B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 181523 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.256B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183802 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.512B_PACKED_HALF) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 186270 }, /* \000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 189812 }, /* \000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.MACRO_FUSED / (tma_retiring * tma_info_thread_slots)\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000 */
{ 191027 }, /* \000tma_heavy_operations\000Default;Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000topdown\\-heavy\\-ops / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences. Sample with: UOPS_RETIRED.HEAVY\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 195718 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_DATA.STALLS / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197105 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 198371 }, /* \000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198640 }, /* \000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198902 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199501 }, /* \000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 201191 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 202880 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 206415 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_fb_full / (tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 211038 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 213573 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_pmm_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216037 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216577 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 217012 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000 */
{ 217249 }, /* \000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000 */
{ 217937 }, /* \000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 220213 }, /* \000tma_info_core_flopc\000Flops;Ret\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR_HALF + 2 * (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED2.COMPLEX_SCALAR_HALF) + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * (FP_ARITH_INST_RETIRED2.128B_PACKED_HALF + cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@) + 16 * (FP_ARITH_INST_RETIRED2.256B_PACKED_HALF + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) + 32 * FP_ARITH_INST_RETIRED2.512B_PACKED_HALF + 4 * AMX_OPS_RETIRED.BF16\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 220813 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(FP_ARITH_DISPATCHED.PORT_0 + FP_ARITH_DISPATCHED.PORT_1 + FP_ARITH_DISPATCHED.PORT_5) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 226538 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 6 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 227202 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 228005 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_DATA.STALLS / cpu@ICACHE_DATA.STALLS\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 230883 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + FP_ARITH_INST_RETIRED2.SCALAR + (cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ + FP_ARITH_INST_RETIRED2.VECTOR))\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 233239 }, /* \000tma_info_inst_mix_iparith_amx_f16\000Flops;FpVector;InsType;Server\000INST_RETIRED.ANY / AMX_OPS_RETIRED.BF16\000tma_info_inst_mix_iparith_amx_f16 < 10\000Instructions per FP Arithmetic AMX operation (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AMX operation (lower number means higher occurrence rate). Operations factored per matrices' sizes of the AMX instructions\000\000\000\000\00000 */
{ 233632 }, /* \000tma_info_inst_mix_iparith_amx_int8\000InsType;IntVector;Server\000INST_RETIRED.ANY / AMX_OPS_RETIRED.INT8\000tma_info_inst_mix_iparith_amx_int8 < 10\000Instructions per Integer Arithmetic AMX operation (lower number means higher occurrence rate)\000Instructions per Integer Arithmetic AMX operation (lower number means higher occurrence rate). Operations factored per matrices' sizes of the AMX instructions\000\000\000\000\00000 */
{ 234032 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.128B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 234984 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.256B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235924 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE + FP_ARITH_INST_RETIRED2.512B_PACKED_HALF)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240442 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / tma_info_core_flopc\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243000 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 13\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245107 }, /* \000tma_info_memory_core_l2_evictions_nonsilent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.NON_SILENT / tma_info_inst_mix_instructions\000\000Rate of non silent evictions from the L2 cache per Kilo instruction\000\000\000\000\000\00000 */
{ 245315 }, /* \000tma_info_memory_core_l2_evictions_silent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.SILENT / tma_info_inst_mix_instructions\000\000Rate of silent evictions from the L2 cache per Kilo instruction where the evicted lines are dropped (no writeback to L3 or memory)\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249558 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / MEM_LOAD_COMPLETED.L1_MISS_ANY\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251156 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251364 }, /* \000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.L3_MISS_DEMAND_DATA_RD / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 254605 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (4 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 255902 }, /* \000tma_info_pipeline_ipassist\000Pipeline;Ret;Retire\000INST_RETIRED.ANY / cpu@ASSISTS.ANY\\,umask\\=0x1B@\000tma_info_pipeline_ipassist < 100e3\000Instructions per a microcode Assist invocation\000Instructions per a microcode Assist invocation. See Assists tree node for details (lower number means higher occurrence rate)\000\000\000\000\00000 */
{ 256405 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001 */
{ 256601 }, /* \000tma_info_pipeline_strings_cycles\000Pipeline;Ret\000INST_RETIRED.REP_ITERATION / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000tma_info_pipeline_strings_cycles > 0.1\000Estimated fraction of retirement-cycles dealing with repeat instructions\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258309 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 262835 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000tma_info_core_flopc / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264048 }, /* \000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000UNC_CHA_TOR_INSERTS.IO_PCIRDCUR * 64 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 265435 }, /* \000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_DDR / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_DDR) / uncore_cha_0@event\\=0x1@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 267104 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 268467 }, /* \000tma_info_system_mem_pmm_read_latency\000Mem;MemoryLat;Server;SoC\000(1e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD_PMM / UNC_CHA_TOR_INSERTS.IA_MISS_DRD_PMM) / uncore_cha_0@event\\=0x1@ if #has_pmem > 0 else 0)\000\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]\000Average latency of data read request to external 3D X-Point memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 270073 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271515 }, /* \000tma_info_system_pmm_read_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_RPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for reads [GB / sec]\000\000\000\000\000\00000 */
{ 271706 }, /* \000tma_info_system_pmm_write_bw\000Mem;MemoryBW;Server;SoC\000(64 * UNC_M_PMM_WPQ_INSERTS / 1e9 / duration_time if #has_pmem > 0 else 0)\000\000Average 3DXP Memory Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 274904 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275473 }, /* \000tma_info_system_socket_clks\000SoC\000uncore_cha_0@event\\=0x1@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275599 }, /* \000tma_info_system_tiops\000Cor;HPC;IntVector;Server\0008 * AMX_OPS_RETIRED.INT8 / 1e12 / duration_time\000\000Tera Integer (matrix) Operations Per Second\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276053 }, /* \000tma_info_system_upi_data_transmit_bw\000Server;SoC\000UNC_UPI_TxL_FLITS.ALL_DATA * 64 / 9 / 1e6\000\000Cross-socket Ultra Path Interconnect (UPI) data transmit bandwidth for data only [MB / sec]\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277349 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277503 }, /* \000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000 */
{ 277851 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278338 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 9\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 278508 }, /* \000tma_int_amx\000Compute;HPC;IntVector;Pipeline;Server;TopdownL4;tma_L4_group;tma_int_operations_group\000cpu@AMX_OPS_RETIRED.INT8\\,cmask\\=1@ / (tma_retiring * tma_info_thread_slots)\000tma_int_amx > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric approximates arithmetic Integer (Int) matrix uops fraction the CPU has retired (aggregated across all supported Int datatypes in AMX engine)\000This metric approximates arithmetic Integer (Int) matrix uops fraction the CPU has retired (aggregated across all supported Int datatypes in AMX engine). Refer to AMX_Busy and TIOPs metrics for actual AMX utilization and Int performance, resp\000100%\000\000\000\00000 */
{ 279166 }, /* \000tma_int_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_int_vector_128b + tma_int_vector_256b + tma_shuffles + tma_int_amx\000tma_int_operations > 0.1 & tma_light_operations > 0.6\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired)\000This metric represents overall Integer (Int) select operations fraction the CPU has executed (retired). Vector/Matrix Int operations and shuffles are counted. Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain\000100%\000\000\000\00000 */
{ 279722 }, /* \000tma_int_vector_128b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(INT_VEC_RETIRED.ADD_128 + INT_VEC_RETIRED.VNNI_128) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_128b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired\000This metric represents 128-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 280490 }, /* \000tma_int_vector_256b\000Compute;IntVector;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group;tma_issue2P\000(INT_VEC_RETIRED.ADD_256 + INT_VEC_RETIRED.MUL_256 + INT_VEC_RETIRED.VNNI_256) / (tma_retiring * tma_info_thread_slots)\000tma_int_vector_256b > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired\000This metric represents 256-bit vector Integer ADD/SUB/SAD or VNNI (Vector Neural Network Instructions) uops fraction the CPU has retired. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 283903 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_TAG.STALLS / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 286851 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((EXE_ACTIVITY.BOUND_ON_LOADS - MEMORY_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 291059 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L1D_MISS - MEMORY_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 294213 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(MEMORY_ACTIVITY.STALLS_L2_MISS - MEMORY_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 305017 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00033 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 310391 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DECODE.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 313227 }, /* \000tma_light_operations\000Default;Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 318374 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3_10 / (3 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3_10\000100%\000\000\000\00000 */
{ 318802 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 323391 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00071 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000 */
{ 325792 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 328884 }, /* \000tma_machine_clears\000BadSpec;Default;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 332837 }, /* \000tma_mba_stalls\000MemoryBW;Offcore;Server;TopdownL5;tma_L5_group;tma_mem_bandwidth_group\000INT_MISC.MBA_STALLS / tma_info_thread_clks\000tma_mba_stalls > 0.1 & (tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to memory bandwidth Allocation feature (RDT's memory bandwidth throttling)\000\000100%\000\000\000\00000 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 340193 }, /* \000tma_memory_bound\000Backend;Default;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000topdown\\-mem\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2;Default\000TopdownL2\00000 */
{ 348087 }, /* \000tma_memory_fence\000TopdownL6;tma_L6_group;tma_serializing_operation_group\00013 * MISC2_RETIRED.LFENCE / tma_info_thread_clks\000tma_memory_fence > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to LFENCE Instructions\000\000100%\000\000\000\00000 */
{ 349166 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_UOP_RETIRED.ANY / (tma_retiring * tma_info_thread_slots)\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001 */
{ 349787 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.MS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: UOPS_RETIRED.MS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 355452 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000tma_branch_mispredicts / tma_bad_speculation * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 358572 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 6 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 359750 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000160 * ASSISTS.SSE_AVX_MIX / tma_info_thread_clks\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 363235 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * cpu@UOPS_RETIRED.MS\\,cmask\\=1\\,edge@ / (tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY) / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: FRONTEND_RETIRED.MS_FLOWS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 364968 }, /* \000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - INST_RETIRED.MACRO_FUSED) / (tma_retiring * tma_info_thread_slots)\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000 */
{ 366608 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 368462 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_int_operations + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 371149 }, /* \000tma_page_faults\000TopdownL5;tma_L5_group;tma_assists_group\00099 * ASSISTS.PAGE_FAULT / tma_info_thread_slots\000tma_page_faults > 0.05\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults\000This metric roughly estimates fraction of slots the CPU retired uops as a result of handing Page Faults. A Page Fault may apply on first application access to a memory page. Note operating system handling of page faults accounts for the majority of its cost\000100%\000\000\000\00000 */
{ 375470 }, /* \000tma_pmm_bound\000MemoryBound;Server;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(((1 - ((19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS))) / (19 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + 10 * (MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS)) + (25 * (MEM_LOAD_RETIRED.LOCAL_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0) + 33 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) if #has_pmem > 0 else 0))) if #has_pmem > 0 else 0)) * (MEMORY_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks) if 1e6 * (MEM_LOAD_L3_MISS_RETIRED.REMOTE_PMM + MEM_LOAD_RETIRED.LOCAL_PMM) > MEM_LOAD_RETIRED.L1_MISS else 0) if #has_pmem > 0 else 0)\000tma_pmm_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a\000This metric roughly estimates (based on idle latencies) how often the CPU was stalled on accesses to external 3D-Xpoint (Crystal Ridge, a.k.a. IXP) memory by loads, PMM stands for Persistent Memory Module\000100%\000\000\000\00000 */
{ 377276 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 380383 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 387708 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 393765 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * cpu@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@)) / tma_info_thread_clks if ARITH.DIV_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * cpu@EXE_ACTIVITY.2_PORTS_UTIL\\,umask\\=0xc@) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 403081 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - EXE_ACTIVITY.BOUND_ON_LOADS) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 408697 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 415124 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_int_vector_128b, tma_int_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 419352 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 420540 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(135.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 135.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00000 */
{ 428723 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000149 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000 */
{ 432289 }, /* \000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 436702 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 437404 }, /* \000tma_shuffles\000HPC;Pipeline;TopdownL4;tma_L4_group;tma_int_operations_group\000INT_VEC_RETIRED.SHUFFLES / (tma_retiring * tma_info_thread_slots)\000tma_shuffles > 0.1 & (tma_int_operations > 0.1 & tma_light_operations > 0.6)\000This metric represents Shuffle (cross \"vector lane\" data transfers) uops fraction the CPU has retired\000\000100%\000\000\000\00000 */
{ 439299 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000CPU_CLK_UNHALTED.PAUSE / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: CPU_CLK_UNHALTED.PAUSE_INST\000100%\000\000\000\00000 */
{ 440531 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 445630 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(XQ.FULL_CYCLES + L1D_PEND_MISS.L2_STALLS) / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 455060 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(MEM_STORE_RETIRED.L2_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 455967 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 457909 }, /* \000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 460003 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\000INT_MISC.UNKNOWN_BRANCH_CYCLES / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: FRONTEND_RETIRED.UNKNOWN_BRANCH\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
{ 465493 }, /* \000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (source_count(UNC_CHA_CLOCKTICKS) * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
{ 465803 }, /* \000upi_data_transmit_bw\000\000UNC_UPI_TxL_FLITS.ALL_DATA * 7.111111111111111 / 1e6 / duration_time\000\000Intel(R) Ultra Path Interconnect (UPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__sierraforest[] = {
{ 1248632 }, /* longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1252437 }, /* longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1389448 }, /* mem_uops_retired.all_loads\000\000cache\000Counts the number of load ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000\000 */
{ 1392072 }, /* mem_uops_retired.all_stores\000\000cache\000Counts the number of store ops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000\000 */
{ 1397475 }, /* mem_uops_retired.load_latency_gt_1024\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x400\000\00000\000\000 */
{ 1398098 }, /* mem_uops_retired.load_latency_gt_128\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x80\000\00000\000\000 */
{ 1400110 }, /* mem_uops_retired.load_latency_gt_16\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x10\000\00000\000\000 */
{ 1402114 }, /* mem_uops_retired.load_latency_gt_2048\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x800\000\00000\000\000 */
{ 1402737 }, /* mem_uops_retired.load_latency_gt_256\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x100\000\00000\000\000 */
{ 1404753 }, /* mem_uops_retired.load_latency_gt_32\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x20\000\00000\000\000 */
{ 1406757 }, /* mem_uops_retired.load_latency_gt_4\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x4\000\00000\000\000 */
{ 1408749 }, /* mem_uops_retired.load_latency_gt_512\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x200\000\00000\000\000 */
{ 1410765 }, /* mem_uops_retired.load_latency_gt_64\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x40\000\00000\000\000 */
{ 1412769 }, /* mem_uops_retired.load_latency_gt_8\000\000cache\000Counts the number of tagged load uops retired that exceed the latency threshold defined in MEC_CR_PEBS_LD_LAT_THRESHOLD - Only counts with PEBS enabled  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x5,ldlat=0x8\000\00000\000\000 */
{ 1423686 }, /* mem_uops_retired.store_latency\000\000cache\000Counts the number of  stores uops retired same as MEM_UOPS_RETIRED.ALL_STORES  Supports address when precise (Must be precise)\000event=0xd0,period=1000003,umask=0x6\000\00000\000\000 */
{ 982859 }, /* icache.accesses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump\000event=0x80,period=200003,umask=0x3\000\00000\000\000 */
{ 988789 }, /* icache.misses\000\000frontend\000Counts every time the code stream enters into a new cache line by walking sequential from the previous line or being redirected by a jump and the instruction cache registers bytes are not present. -\000event=0x80,period=200003,umask=0x2\000\00000\000\000 */
{ 1559605 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000Counts demand data reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00001\000\00000\000\000 */
{ 1589226 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBFC00002\000\00000\000\000 */
{ 1542604 }, /* ocr.demand_data_rd.any_response\000\000other\000Counts demand data reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1572074 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 497910 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 538105 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 614004 }, /* cpu_clk_unhalted.core\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000 */
{ 615434 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.THREAD_P]\000event=0x3c,period=2000003\000\00000\000\000 */
{ 624035 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000\000 */
{ 634226 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 644590 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000\000 */
{ 646479 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Counts the number of unhalted core clock cycles [This event is alias to CPU_CLK_UNHALTED.CORE_P]\000event=0x3c,period=2000003\000\00000\000\000 */
{ 1044654 }, /* inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1052065 }, /* inst_retired.any_p\000\000pipeline\000Counts the number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 2550658 }, /* topdown_bad_speculation.all\000\000pipeline\000Counts the number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window, including relevant microcode flows, and while uops are not yet available in the instruction queue (IQ) or until an FE_BOUND event occurs besides OTHER and CISC. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2557678 }, /* topdown_be_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to backend stalls\000event=0x74,period=1000003\000\00000\000\000 */
{ 2562399 }, /* topdown_fe_bound.all\000\000pipeline\000Counts the number of retirement slots not consumed due to front end stalls\000event=0x71,period=1000003\000\00000\000\000 */
{ 2570690 }, /* topdown_retiring.all\000\000pipeline\000Counts the number of consumed retirement slots.  Similar to UOPS_RETIRED.ALL (Precise event)\000event=0x72,period=1000003\000\00000\000\000 */
{ 793957 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=1000003,umask=0xe\000\00000\000\000 */
{ 815976 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=1000003,umask=0xe\000\00000\000\000 */
{ 1086987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
};

static const struct compact_pmu_event pmu_events__silvermont[] = {
{ 574632 }, /* core_reject_l2q.all\000\000cache\000Counts the number of request that were not accepted into the L2Q because the L2Q is FULL\000event=0x31,period=200003\000\00000\000Counts the number of (demand and L1 prefetchers) core requests rejected by the L2Q due to a full or nearly full w condition which likely indicates back pressure from L2Q.  It also counts requests that would have gone directly to the XQ, but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link.  The L2Q may also reject transactions  from a core to insure fairness between cores, or to delay a core?s dirty eviction when the address conflicts incoming external snoops.  (Note that L2 prefetcher requests that are dropped are not counted by this event.)\000 */
{ 851639 }, /* fetch_stall.icache_fill_pending_cycles\000\000cache\000Cycles code-fetch stalled due to an outstanding ICache miss\000event=0x86,period=200003,umask=0x4\000\00000\000Counts cycles that fetch is stalled due to an outstanding ICache miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ICache miss.  Note: this event is not the same as the total number of cycles spent retrieving instruction cache lines from the memory hierarchy.\r\nCounts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000 */
{ 1148314 }, /* l2_reject_xq.all\000\000cache\000Counts the number of request from the L2 that were not accepted into the XQ\000event=0x30,period=200003\000\00000\000This event counts the number of demand and prefetch transactions that the L2 XQ rejects due to a full or near full condition which likely indicates back pressure from the IDI link. The XQ may reject transactions from the L2Q (non-cacheable requests), BBS (L2 misses) and WOB (L2 write-back victims)\000 */
{ 1249270 }, /* longest_lat_cache.miss\000\000cache\000L2 cache request misses\000event=0x2e,period=200003,umask=0x41\000\00000\000This event counts the total number of L2 cache references and the number of L2 cache misses respectively\000 */
{ 1252909 }, /* longest_lat_cache.reference\000\000cache\000L2 cache requests from this core\000event=0x2e,period=200003,umask=0x4f\000\00000\000This event counts requests originating from the core that references a cache line in the L2 cache\000 */
{ 1388637 }, /* mem_uops_retired.all_loads\000\000cache\000All Loads\000event=0x4,period=200003,umask=0x40\000\00000\000This event counts the number of load ops retired\000 */
{ 1391239 }, /* mem_uops_retired.all_stores\000\000cache\000All Stores\000event=0x4,period=200003,umask=0x80\000\00000\000This event counts the number of store ops retired\000 */
{ 1395992 }, /* mem_uops_retired.hitm\000\000cache\000Cross core or cross module hitm (Precise event)\000event=0x4,period=200003,umask=0x20\000\00000\000This event counts the number of load ops retired that got data from the other core or from the other module (Precise event)\000 */
{ 1396505 }, /* mem_uops_retired.l1_miss_loads\000\000cache\000Loads missed L1\000event=0x4,period=200003,umask=0x1\000\00000\000This event counts the number of load ops retired that miss in L1 Data cache. Note that prefetch misses will not be counted\000 */
{ 1396906 }, /* mem_uops_retired.l2_hit_loads\000\000cache\000Loads hit L2 (Precise event)\000event=0x4,period=200003,umask=0x2\000\00000\000This event counts the number of load ops retired that hit in the L2 (Precise event)\000 */
{ 1397282 }, /* mem_uops_retired.l2_miss_loads\000\000cache\000Loads missed L2 (Precise event)\000event=0x4,period=100007,umask=0x4\000\00000\000This event counts the number of load ops retired that miss in the L2 (Precise event)\000 */
{ 1425050 }, /* mem_uops_retired.utlb_miss\000\000cache\000Loads missed UTLB\000event=0x4,period=200003,umask=0x10\000\00000\000This event counts the number of load ops retired that had UTLB miss\000 */
{ 2460579 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100007,umask=0x1\000\00000\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000 */
{ 1915090 }, /* offcore_response.any_code_rd.any_response\000\000cache\000Counts any code reads (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010044\000\00000\000\000 */
{ 1918883 }, /* offcore_response.any_code_rd.l2_miss.any\000\000cache\000Counts any code reads (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000044\000\00000\000\000 */
{ 1919051 }, /* offcore_response.any_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any code reads (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000044\000\00000\000\000 */
{ 1919323 }, /* offcore_response.any_code_rd.l2_miss.hitm_other_core\000\000cache\000Counts any code reads (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000044\000\00000\000\000 */
{ 1919577 }, /* offcore_response.any_code_rd.l2_miss.snoop_miss\000\000cache\000Counts any code reads (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000044\000\00000\000\000 */
{ 1926554 }, /* offcore_response.any_data_rd.any_response\000\000cache\000Counts any data read (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000013091\000\00000\000\000 */
{ 1931475 }, /* offcore_response.any_data_rd.l2_miss.any\000\000cache\000Counts any data read (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680003091\000\00000\000\000 */
{ 1931973 }, /* offcore_response.any_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any data read (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400003091\000\00000\000\000 */
{ 1932751 }, /* offcore_response.any_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts any data read (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000003091\000\00000\000\000 */
{ 1933984 }, /* offcore_response.any_data_rd.l2_miss.snoop_miss\000\000cache\000Counts any data read (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200003091\000\00000\000\000 */
{ 1961614 }, /* offcore_response.any_request.any_response\000\000cache\000Counts any request that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000018008\000\00000\000\000 */
{ 1966657 }, /* offcore_response.any_request.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any request that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400008008\000\00000\000\000 */
{ 1967417 }, /* offcore_response.any_request.l2_miss.hitm_other_core\000\000cache\000Counts any request that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000008008\000\00000\000\000 */
{ 1968636 }, /* offcore_response.any_request.l2_miss.snoop_miss\000\000cache\000Counts any request that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200008008\000\00000\000\000 */
{ 1976774 }, /* offcore_response.any_rfo.any_response\000\000cache\000Counts any rfo reads (demand & prefetch) that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010022\000\00000\000\000 */
{ 1981819 }, /* offcore_response.any_rfo.l2_miss.any\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000022\000\00000\000\000 */
{ 1982357 }, /* offcore_response.any_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000022\000\00000\000\000 */
{ 1983175 }, /* offcore_response.any_rfo.l2_miss.hitm_other_core\000\000cache\000Counts any rfo reads (demand & prefetch) that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000022\000\00000\000\000 */
{ 1984492 }, /* offcore_response.any_rfo.l2_miss.snoop_miss\000\000cache\000Counts any rfo reads (demand & prefetch) that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000022\000\00000\000\000 */
{ 2001754 }, /* offcore_response.corewb.l2_miss.any\000\000cache\000Counts writeback (modified to exclusive) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000008\000\00000\000\000 */
{ 2003634 }, /* offcore_response.corewb.l2_miss.no_snoop_needed\000\000cache\000Counts writeback (modified to exclusive) that miss L2 with no details on snoop-related information\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0080000008\000\00000\000\000 */
{ 2025913 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts demand and DCU prefetch instruction cacheline that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010004\000\00000\000\000 */
{ 2031429 }, /* offcore_response.demand_code_rd.l2_miss.any\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000004\000\00000\000\000 */
{ 2032063 }, /* offcore_response.demand_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000004\000\00000\000\000 */
{ 2033583 }, /* offcore_response.demand_code_rd.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch instruction cacheline that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000004\000\00000\000\000 */
{ 2066583 }, /* offcore_response.demand_code_rd.outstanding\000\000cache\000Counts demand and DCU prefetch instruction cacheline that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000004\000\00000\000\000 */
{ 2079663 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand and DCU prefetch data read that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000010001\000\00000\000\000 */
{ 2085019 }, /* offcore_response.demand_data_rd.l2_miss.any\000\000cache\000Counts demand and DCU prefetch data read that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000001\000\00000\000\000 */
{ 2085557 }, /* offcore_response.demand_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch data read that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000001\000\00000\000\000 */
{ 2086375 }, /* offcore_response.demand_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts demand and DCU prefetch data read that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000001\000\00000\000\000 */
{ 2087685 }, /* offcore_response.demand_data_rd.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch data read that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000001\000\00000\000\000 */
{ 2123102 }, /* offcore_response.demand_data_rd.outstanding\000\000cache\000Counts demand and DCU prefetch data read that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000001\000\00000\000\000 */
{ 2143381 }, /* offcore_response.demand_rfo.l2_miss.any\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000002\000\00000\000\000 */
{ 2143984 }, /* offcore_response.demand_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000002\000\00000\000\000 */
{ 2144867 }, /* offcore_response.demand_rfo.l2_miss.hitm_other_core\000\000cache\000Counts demand and DCU prefetch RFOs that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000002\000\00000\000\000 */
{ 2146316 }, /* offcore_response.demand_rfo.l2_miss.snoop_miss\000\000cache\000Counts demand and DCU prefetch RFOs that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000002\000\00000\000\000 */
{ 2181618 }, /* offcore_response.demand_rfo.outstanding\000\000cache\000Counts demand and DCU prefetch RFOs that are are outstanding, per cycle, from the time of the L2 miss to when any response is received\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x4000000002\000\00000\000\000 */
{ 2230942 }, /* offcore_response.partial_reads.l2_miss.any\000\000cache\000Counts demand reads of partial cache lines (including UC and WC) that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000080\000\00000\000\000 */
{ 2239988 }, /* offcore_response.partial_writes.l2_miss.any\000\000cache\000Countsof demand RFO requests to write to partial cache lines that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000100\000\00000\000\000 */
{ 2260524 }, /* offcore_response.pf_l1_data_rd.any_response\000\000cache\000Counts DCU hardware prefetcher data read that have any response type\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0000012000\000\00000\000\000 */
{ 2265415 }, /* offcore_response.pf_l1_data_rd.l2_miss.any\000\000cache\000Counts DCU hardware prefetcher data read that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680002000\000\00000\000\000 */
{ 2265993 }, /* offcore_response.pf_l1_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts DCU hardware prefetcher data read that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400002000\000\00000\000\000 */
{ 2266851 }, /* offcore_response.pf_l1_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts DCU hardware prefetcher data read that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000002000\000\00000\000\000 */
{ 2268242 }, /* offcore_response.pf_l1_data_rd.l2_miss.snoop_miss\000\000cache\000Counts DCU hardware prefetcher data read that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200002000\000\00000\000\000 */
{ 2293041 }, /* offcore_response.pf_l2_code_rd.l2_miss.any\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000040\000\00000\000\000 */
{ 2293215 }, /* offcore_response.pf_l2_code_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000040\000\00000\000\000 */
{ 2293493 }, /* offcore_response.pf_l2_code_rd.l2_miss.snoop_miss\000\000cache\000Counts code reads generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000040\000\00000\000\000 */
{ 2303582 }, /* offcore_response.pf_l2_data_rd.l2_miss.any\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000010\000\00000\000\000 */
{ 2304163 }, /* offcore_response.pf_l2_data_rd.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000010\000\00000\000\000 */
{ 2305024 }, /* offcore_response.pf_l2_data_rd.l2_miss.hitm_other_core\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000010\000\00000\000\000 */
{ 2306406 }, /* offcore_response.pf_l2_data_rd.l2_miss.snoop_miss\000\000cache\000Counts data cacheline reads generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000010\000\00000\000\000 */
{ 2340276 }, /* offcore_response.pf_l2_rfo.l2_miss.any\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680000020\000\00000\000\000 */
{ 2340839 }, /* offcore_response.pf_l2_rfo.l2_miss.hit_other_core_no_fwd\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2 and the snoops to sibling cores hit in either E/S state and the line is not forwarded\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0400000020\000\00000\000\000 */
{ 2341682 }, /* offcore_response.pf_l2_rfo.l2_miss.hitm_other_core\000\000cache\000Counts RFO requests generated by L2 prefetchers that hit in the other module where modified copies were found in other core's L1 cache\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1000000020\000\00000\000\000 */
{ 2343040 }, /* offcore_response.pf_l2_rfo.l2_miss.snoop_miss\000\000cache\000Counts RFO requests generated by L2 prefetchers that miss L2 with a snoop miss response\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x0200000020\000\00000\000\000 */
{ 2448411 }, /* offcore_response.streaming_stores.l2_miss.any\000\000cache\000Counts streaming store that miss L2\000event=0xb7,period=100007,umask=0x1,offcore_rsp=0x1680004800\000\00000\000\000 */
{ 2486130 }, /* rehabq.any_ld\000\000cache\000Any reissued load uops\000event=0x3,period=200003,umask=0x40\000\00000\000This event counts the number of load uops reissued from Rehabq\000 */
{ 2486276 }, /* rehabq.any_st\000\000cache\000Any reissued store uops\000event=0x3,period=200003,umask=0x80\000\00000\000This event counts the number of store uops reissued from Rehabq\000 */
{ 2486424 }, /* rehabq.ld_block_st_forward\000\000cache\000Loads blocked due to store forward restriction (Precise event)\000event=0x3,period=200003,umask=0x1\000\00000\000This event counts the number of retired loads that were prohibited from receiving forwarded data from the store because of address mismatch (Precise event)\000 */
{ 2486715 }, /* rehabq.ld_block_std_notready\000\000cache\000Loads blocked due to store data not ready\000event=0x3,period=200003,umask=0x2\000\00000\000This event counts the cases where a forward was technically possible, but did not occur because the store data was not available at the right time\000 */
{ 2486978 }, /* rehabq.ld_splits\000\000cache\000Load uops that split cache line boundary (Precise event)\000event=0x3,period=200003,umask=0x8\000\00000\000This event counts the number of retire loads that experienced cache line boundary splits (Precise event)\000 */
{ 2487202 }, /* rehabq.lock\000\000cache\000Uops with lock semantics\000event=0x3,period=200003,umask=0x10\000\00000\000This event counts the number of retired memory operations with lock semantics. These are either implicit locked instructions such as the XCHG instruction or instructions with an explicit LOCK prefix (0xF0)\000 */
{ 2487491 }, /* rehabq.st_splits\000\000cache\000Store uops that split cache line boundary\000event=0x3,period=200003,umask=0x4\000\00000\000This event counts the number of retire stores that experienced cache line boundary splits\000 */
{ 2487685 }, /* rehabq.sta_full\000\000cache\000Store address buffer full\000event=0x3,period=200003,umask=0x20\000\00000\000This event counts the number of retired stores that are delayed because there is not a store address buffer available\000 */
{ 1292362 }, /* machine_clears.fp_assist\000\000floating point\000Stalls due to FP assists\000event=0xc3,period=200003,umask=0x4\000\00000\000This event counts the number of times that pipeline stalled due to FP operations needing assists\000 */
{ 474290 }, /* baclears.all\000\000frontend\000Counts the number of baclears\000event=0xe6,period=200003,umask=0x1\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.ANY event counts the number of baclears for any type of branch\000 */
{ 479089 }, /* baclears.cond\000\000frontend\000Counts the number of JCC baclears\000event=0xe6,period=200003,umask=0x10\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.COND event counts the number of JCC (Jump on Conditional Code) baclears\000 */
{ 480084 }, /* baclears.return\000\000frontend\000Counts the number of RETURN baclears\000event=0xe6,period=200003,umask=0x8\000\00000\000The BACLEARS event counts the number of times the front end is resteered, mainly when the Branch Prediction Unit cannot provide a correct prediction and this is corrected by the Branch Address Calculator at the front end.  The BACLEARS.RETURN event counts the number of RETURN baclears\000 */
{ 777599 }, /* decode_restriction.predecode_wrong\000\000frontend\000Counts the number of times a decode restriction reduced the decode throughput due to wrong instruction length prediction\000event=0xe9,period=200003,umask=0x1\000\00000\000Counts the number of times a decode restriction reduced the decode throughput due to wrong instruction length prediction\000 */
{ 983710 }, /* icache.accesses\000\000frontend\000Instruction fetches\000event=0x80,period=200003,umask=0x3\000\00000\000This event counts all instruction fetches, not including most uncacheable\r\nfetches\000 */
{ 986036 }, /* icache.hit\000\000frontend\000Instruction fetches from Icache\000event=0x80,period=200003,umask=0x1\000\00000\000This event counts all instruction fetches from the instruction cache\000 */
{ 989642 }, /* icache.misses\000\000frontend\000Icache miss\000event=0x80,period=200003,umask=0x2\000\00000\000This event counts all instruction fetches that miss the Instruction cache or produce memory requests. This includes uncacheable fetches. An instruction fetch miss is counted only once and not once for every cycle it is outstanding\000 */
{ 1434344 }, /* ms_decoded.ms_entry\000\000frontend\000Counts the number of times entered into a ucode flow in the FEC.  Includes inserted flows due to front-end detected faults or assists.  Speculative count\000event=0xe7,period=200003,umask=0x1\000\00000\000Counts the number of times the MSROM starts a flow of UOPS. It does not count every time a UOP is read from the microcode ROM.  The most common case that this counts is when a micro-coded instruction is encountered by the front end of the machine.  Other cases include when an instruction encounters a fault, trap, or microcode assist of any sort.  The event will count MSROM startups for UOPS that are speculative, and subsequently cleared by branch mispredict or machine clear.  Background: UOPS are produced by two mechanisms.  Either they are generated by hardware that decodes instructions into UOPS, or they are delivered by a ROM (called the MSROM) that holds UOPS associated with a specific instruction.  MSROM UOPS might also be delivered in response to some condition such as a fault or other exceptional condition.  This event is an excellent mechanism for detecting instructions that require the use of MSROM instructions\000 */
{ 1297300 }, /* machine_clears.memory_ordering\000\000memory\000Stalls due to Memory ordering\000event=0xc3,period=200003,umask=0x2\000\00000\000This event counts the number of times that pipeline was cleared due to memory ordering issues\000 */
{ 850101 }, /* fetch_stall.all\000\000other\000Cycles code-fetch stalled due to any reason\000event=0x86,period=200003,umask=0x3f\000\00000\000Counts cycles that fetch is stalled due to any reason. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes.  This will include cycles due to an ITLB miss, ICache miss and other events\000 */
{ 852761 }, /* fetch_stall.itlb_fill_pending_cycles\000\000other\000Cycles code-fetch stalled due to an outstanding ITLB miss\000event=0x86,period=200003,umask=0x2\000\00000\000Counts cycles that fetch is stalled due to an outstanding ITLB miss. That is, the decoder queue is able to accept bytes, but the fetch unit is unable to provide bytes due to an ITLB miss.  Note: this event is not the same as page walk cycles to retrieve an instruction translation\000 */
{ 497168 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the number of branch instructions retired.. (Precise event)\000event=0xc4,period=200003\000\00000\000ALL_BRANCHES counts the number of any branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 500281 }, /* br_inst_retired.all_taken_branches\000\000pipeline\000Counts the number of taken branch instructions retired (Must be precise)\000event=0xc4,period=200003,umask=0x80\000\00000\000ALL_TAKEN_BRANCHES counts the number of all taken branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Must be precise)\000 */
{ 501483 }, /* br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000CALL counts the number of near CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 506754 }, /* br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000FAR counts the number of far branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 509598 }, /* br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000IND_CALL counts the number of near indirect CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 512430 }, /* br_inst_retired.jcc\000\000pipeline\000Counts the number of JCC branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000JCC counts the number of conditional branch (JCC) instructions retired. Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 520409 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000NON_RETURN_IND counts the number of near indirect JMP and near indirect CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 522999 }, /* br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000REL_CALL counts the number of near relative CALL branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 524350 }, /* br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000RETURN counts the number of near RET branch instructions retired.  Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 526291 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of taken JCC branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000TAKEN_JCC counts the number of taken conditional branch (JCC) instructions retired. Branch prediction predicts the branch target and enables the processor to begin executing instructions long before the branch true execution path is known. All branches utilize the branch prediction unit (BPU) for prediction. This unit predicts the target address not only based on the EIP of the branch but also based on the execution path through which execution reached this EIP. The BPU can efficiently predict the following branch types: conditional branches, direct calls and jumps, indirect calls and jumps, returns (Precise event)\000 */
{ 537246 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the number of mispredicted branch instructions retired (Precise event)\000event=0xc5,period=200003\000\00000\000ALL_BRANCHES counts the number of any mispredicted branch instructions retired. This umask is an architecturally defined event. This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 547421 }, /* br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000IND_CALL counts the number of mispredicted near indirect CALL branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 552707 }, /* br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted JCC branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000JCC counts the number of mispredicted conditional branches (JCC) instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 557350 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000NON_RETURN_IND counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 561439 }, /* br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000RETURN counts the number of mispredicted near RET branch instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 563460 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted taken JCC branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000TAKEN_JCC counts the number of mispredicted taken conditional branch (JCC) instructions retired.  This event counts the number of retired branch instructions that were mispredicted by the processor, categorized by type. A branch misprediction occurs when the processor predicts that the branch would be taken, but it is not, or vice-versa.  When the misprediction is discovered, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 612864 }, /* cpu_clk_unhalted.core\000\000pipeline\000Fixed Counter: Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios.  The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. In systems with a constant core frequency, this event can give you a measurement of the elapsed time while the core was not in halt state by dividing the event count by the core frequency. This event is architecturally defined and is a designated fixed counter.  CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.CORE_P use the core frequency which may change from time to time.  CPU_CLK_UNHALTE.REF_TSC and CPU_CLK_UNHALTED.REF are not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  The fixed events are CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.REF_TSC and the programmable events are CPU_CLK_UNHALTED.CORE_P and CPU_CLK_UNHALTED.REF\000 */
{ 615039 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Core cycles when core is not halted\000event=0x3c,period=2000003\000\00000\000This event counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time\000 */
{ 620344 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when core is not halted\000event=0x0,umask=0x03,period=2000003\000\00000\000This event counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. In mobile systems the core frequency may change from time. This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time\000 */
{ 622795 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Fixed Counter: Counts the number of unhalted reference clock cycles\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios.  The core frequency may change from time. This event is not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  Divide this event count by core frequency to determine the elapsed time while the core was not in halt state.  Divide this event count by core frequency to determine the elapsed time while the core was not in halt state.  This event is architecturally defined and is a designated fixed counter.  CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.CORE_P use the core frequency which may change from time to time.  CPU_CLK_UNHALTE.REF_TSC and CPU_CLK_UNHALTED.REF are not affected by core frequency changes but counts as if the core is running at the maximum frequency all the time.  The fixed events are CPU_CLK_UNHALTED.CORE and CPU_CLK_UNHALTED.REF_TSC and the programmable events are CPU_CLK_UNHALTED.CORE_P and CPU_CLK_UNHALTED.REF\000 */
{ 759691 }, /* cycles_div_busy.all\000\000pipeline\000Cycles the divider is busy.  Does not imply a stall waiting for the divider\000event=0xcd,period=2000003,umask=0x1\000\00000\000Cycles the divider is busy.This event counts the cycles when the divide unit is unable to accept a new divide UOP because it is busy processing a previously dispatched UOP. The cycles will be counted irrespective of whether or not another divide UOP is waiting to enter the divide unit (from the RS). This event might count cycles while a divide is in progress even if the RS is empty.  The divide instruction is one of the longest latency instructions in the machine.  Hence, it has a special event associated with it to help determine if divides are delaying the retirement of instructions\000 */
{ 1044785 }, /* inst_retired.any\000\000pipeline\000Fixed Counter: Counts the number of instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire.  For instructions that consist of multiple micro-ops, this event counts exactly once, as the last micro-op of the instruction retires.  The event continues counting while instructions retire, including during interrupt service routines caused by hardware interrupts, faults or traps.  Background: Modern microprocessors employ extensive pipelining and speculative techniques.  Since sometimes an instruction is started but never completed, the notion of \"retirement\" is introduced.  A retired instruction is one that commits its states. Or stated differently, an instruction might be abandoned at some point. No instruction is truly finished until it retires.  This counter measures the number of completed instructions.  The fixed event is INST_RETIRED.ANY and the programmable event is INST_RETIRED.ANY_P\000 */
{ 1053807 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired\000event=0xc0,period=2000003\000\00000\000This event counts the number of instructions that retire execution. For instructions that consist of multiple micro-ops, this event counts the retirement of the last micro-op of the instruction. The counter continues counting during hardware interrupts, traps, and inside interrupt handlers\000 */
{ 1287130 }, /* machine_clears.all\000\000pipeline\000Counts all machine clears\000event=0xc3,period=200003,umask=0x8\000\00000\000Machine clears happen when something happens in the machine that causes the hardware to need to take special care to get the right answer. When such a condition is signaled on an instruction, the front end of the machine is notified that it must restart, so no more instructions will be decoded from the current path.  All instructions \"older\" than this one will be allowed to finish.  This instruction and all \"younger\" instructions must be cleared, since they must not be allowed to complete.  Essentially, the hardware waits until the problematic instruction is the oldest instruction in the machine.  This means all older instructions are retired, and all pending stores (from older instructions) are completed.  Then the new path of instructions from the front end are allowed to start into the machine.  There are many conditions that might cause a machine clear (including the receipt of an interrupt, or a trap or a fault).  All those conditions (including but not limited to MACHINE_CLEARS.MEMORY_ORDERING, MACHINE_CLEARS.SMC, and MACHINE_CLEARS.FP_ASSIST) are captured in the ANY event. In addition, some conditions can be specifically counted (i.e. SMC, MEMORY_ORDERING, FP_ASSIST).  However, the sum of SMC, MEMORY_ORDERING, and FP_ASSIST machine clears will not necessarily equal the number of ANY\000 */
{ 1300858 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=200003,umask=0x1\000\00000\000This event counts the number of times that a program writes to a code section. Self-modifying code causes a severe penalty in all Intel? architecture processors\000 */
{ 1436423 }, /* no_alloc_cycles.all\000\000pipeline\000Counts the number of cycles when no uops are allocated for any reason\000event=0xca,period=200003,umask=0x3f\000\00000\000The NO_ALLOC_CYCLES.ALL event counts the number of cycles when the front-end does not provide any instructions to be allocated for any reason. This event indicates the cycles where an allocation stalls occurs, and no UOPS are allocated in that cycle\000 */
{ 1437331 }, /* no_alloc_cycles.mispredicts\000\000pipeline\000Counts the number of cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted jump to retire.  After the misprediction is detected, the front end will start immediately but the allocate pipe stalls until the mispredicted\000event=0xca,period=200003,umask=0x4\000\00000\000Counts the number of cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted jump to retire.  After the misprediction is detected, the front end will start immediately but the allocate pipe stalls until the mispredicted\000 */
{ 1438299 }, /* no_alloc_cycles.not_delivered\000\000pipeline\000Counts the number of cycles when no uops are allocated, the IQ is empty, and no other condition is blocking allocation\000event=0xca,period=200003,umask=0x50\000\00000\000The NO_ALLOC_CYCLES.NOT_DELIVERED event is used to measure front-end inefficiencies, i.e. when front-end of the machine is not delivering micro-ops to the back-end and the back-end is not stalled. This event can be used to identify if the machine is truly front-end bound.  When this event occurs, it is an indication that the front-end of the machine is operating at less than its theoretical peak performance.  Background: We can think of the processor pipeline as being divided into 2 broader parts: Front-end and Back-end. Front-end is responsible for fetching the instruction, decoding into micro-ops (uops) in machine understandable format and putting them into a micro-op queue to be consumed by back end. The back-end then takes these micro-ops, allocates the required resources.  When all resources are ready, micro-ops are executed. If the back-end is not ready to accept micro-ops from the front-end, then we do not want to count these as front-end bottlenecks.  However, whenever we have bottlenecks in the back-end, we will have allocation unit stalls and eventually forcing the front-end to wait until the back-end is ready to receive more UOPS. This event counts the cycles only when back-end is requesting more uops and front-end is not able to provide them. Some examples of conditions that cause front-end efficiencies are: Icache misses, ITLB misses, and decoder restrictions that limit the front-end bandwidth\000 */
{ 1440134 }, /* no_alloc_cycles.rat_stall\000\000pipeline\000Counts the number of cycles when no uops are allocated and a RATstall is asserted\000event=0xca,period=200003,umask=0x20\000\00000\000\000 */
{ 1440453 }, /* no_alloc_cycles.rob_full\000\000pipeline\000Counts the number of cycles when no uops are allocated and the ROB is full (less than 2 entries available)\000event=0xca,period=200003,umask=0x1\000\00000\000Counts the number of cycles when no uops are allocated and the ROB is full (less than 2 entries available)\000 */
{ 2513399 }, /* rs_full_stall.all\000\000pipeline\000Counts the number of cycles the Alloc pipeline is stalled when any one of the RSs (IEC, FPC and MEC) is full. This event is a superset of all the individual RS stall event counts\000event=0xcb,period=200003,umask=0x1f\000\00000\000\000 */
{ 2514027 }, /* rs_full_stall.mec\000\000pipeline\000Counts the number of cycles and allocation pipeline is stalled and is waiting for a free MEC reservation station entry.  The cycles should be appropriately counted in case of the cracked ops e.g. In case of a cracked load-op, the load portion is sent to M\000event=0xcb,period=200003,umask=0x1\000\00000\000Counts the number of cycles and allocation pipeline is stalled and is waiting for a free MEC reservation station entry.  The cycles should be appropriately counted in case of the cracked ops e.g. In case of a cracked load-op, the load portion is sent to M\000 */
{ 6226852 }, /* uops_retired.all\000\000pipeline\000Micro-ops retired\000event=0xc2,period=2000003,umask=0x10\000\00000\000This event counts the number of micro-ops retired. The processor decodes complex macro instructions into a sequence of simpler micro-ops. Most instructions are composed of one or two micro-ops. Some instructions are decoded into longer sequences such as repeat instructions, floating point transcendental instructions, and assists. In some cases micro-op sequences are fused or whole instructions are fused into one micro-op. See other UOPS_RETIRED events for differentiating retired fused and non-fused micro-ops\000 */
{ 6232301 }, /* uops_retired.ms\000\000pipeline\000MSROM micro-ops retired\000event=0xc2,period=2000003,umask=0x1\000\00000\000This event counts the number of micro-ops retired that were supplied from MSROM\000 */
{ 1395066 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Loads missed DTLB (Precise event)\000event=0x4,period=200003,umask=0x8\000\00000\000This event counts the number of load ops retired that had DTLB miss (Precise event)\000 */
{ 2472738 }, /* page_walks.cycles\000\000virtual memory\000Total cycles for all the page walks. (I-side and D-side)\000event=0x5,period=200003,umask=0x3\000\00000\000This event counts every cycle when a data (D) page walk or instruction (I) page walk is in progress.  Since a pagewalk implies a TLB miss, the approximate cost of a TLB miss can be determined from this event\000 */
{ 2473417 }, /* page_walks.d_side_cycles\000\000virtual memory\000Duration of D-side page-walks in core cycles\000event=0x5,period=200003,umask=0x1\000\00000\000This event counts every cycle when a D-side (walks due to a load) page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks\000 */
{ 2474159 }, /* page_walks.d_side_walks\000\000virtual memory\000D-side page-walks\000event=0x5,edge=1,period=100003,umask=0x1\000\00000\000This event counts when a data (D) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000 */
{ 2475000 }, /* page_walks.i_side_cycles\000\000virtual memory\000Duration of I-side page-walks in core cycles\000event=0x5,period=200003,umask=0x2\000\00000\000This event counts every cycle when a I-side (walks due to an instruction fetch) page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks\000 */
{ 2475686 }, /* page_walks.i_side_walks\000\000virtual memory\000I-side page-walks\000event=0x5,edge=1,period=100003,umask=0x2\000\00000\000This event counts when an instruction (I) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000 */
{ 2476602 }, /* page_walks.walks\000\000virtual memory\000Total page walks that are completed (I-side and D-side)\000event=0x5,edge=1,period=100003,umask=0x3\000\00000\000This event counts when a data (D) page walk or an instruction (I) page walk is completed or started.  Since a page walk implies a TLB miss, the number of TLB misses can be counted by counting the number of pagewalks\000 */
};

static const struct compact_pmu_event pmu_events__skylake[] = {
{ 1101122 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105725 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch\000event=0x48,period=2000003,umask=0x2\000\00000\000Number of times a request needed a FB (Fill Buffer) entry but there was no entry available for it. A request includes cacheable/uncacheable demands that are load, store or SW prefetch instructions\000 */
{ 1109275 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch.Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112533 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1133405 }, /* l2_lines_out.non_silent\000\000cache\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000event=0xf2,period=200003,umask=0x2\000\00000\000\000 */
{ 1136165 }, /* l2_lines_out.silent\000\000cache\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000event=0xf2,period=200003,umask=0x1\000\00000\000\000 */
{ 1138301 }, /* l2_lines_out.useless_hwpf\000\000cache\000Counts the number of lines that have been hardware prefetched but not used and now evicted by L2 cache\000event=0xf2,period=200003,umask=0x4\000\00000\000\000 */
{ 1138806 }, /* l2_lines_out.useless_pref\000\000cache\000This event is deprecated. Refer to new event L2_LINES_OUT.USELESS_HWPF\000event=0xf2,period=200003,umask=0x4\000\00010\000\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159743 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache\000 */
{ 1160496 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache\000 */
{ 1161655 }, /* l2_rqsts.all_pf\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1169217 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that miss L2 cache\000 */
{ 1170900 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000event=0x24,period=200003,umask=0xd8\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000 */
{ 1171454 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000event=0x24,period=200003,umask=0x38\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000 */
{ 1172527 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000All L2 requests\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1246868 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2. It does not include all misses to the L3  Spec update: SKL057\000 */
{ 1250569 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the  L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2.  It does not include all accesses to the L3  Spec update: SKL057\000 */
{ 1310641 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311557 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312305 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315660 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1321255 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1322617 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1323860 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1326191 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1331393 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000\000 */
{ 1332781 }, /* mem_load_retired.fb_hit\000\000cache\000Retired load instructions which data sources were load missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1334379 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335208 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336281 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337713 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338721 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339355 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1745789 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000 */
{ 1748358 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code read requests\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753384 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.Note: Writeback pending FIFO has six entries\000 */
{ 1756367 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1759308 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1761343 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1763371 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)\000 */
{ 1765815 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1770345 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1774107 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.Note: A prefetch promoted to Demand is counted from the promotion point\000 */
{ 1776411 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777863 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 2459789 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000 */
{ 2025436 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 2035294 }, /* offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0004\000\00000\000\000 */
{ 2037883 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0004\000\00000\000\000 */
{ 2038601 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0004\000\00000\000\000 */
{ 2038903 }, /* offcore_response.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0004\000\00000\000\000 */
{ 2039718 }, /* offcore_response.demand_code_rd.l3_hit.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0004\000\00000\000\000 */
{ 2040218 }, /* offcore_response.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0004\000\00000\000\000 */
{ 2040530 }, /* offcore_response.demand_code_rd.l3_hit.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0004\000\00000\000\000 */
{ 2040676 }, /* offcore_response.demand_code_rd.l3_hit_e.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080004\000\00000\000\000 */
{ 2041921 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080004\000\00000\000\000 */
{ 2042079 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080004\000\00000\000\000 */
{ 2042232 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080004\000\00000\000\000 */
{ 2042749 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080004\000\00000\000\000 */
{ 2043106 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080004\000\00000\000\000 */
{ 2043264 }, /* offcore_response.demand_code_rd.l3_hit_e.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080004\000\00000\000\000 */
{ 2044918 }, /* offcore_response.demand_code_rd.l3_hit_m.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040004\000\00000\000\000 */
{ 2046163 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040004\000\00000\000\000 */
{ 2046321 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040004\000\00000\000\000 */
{ 2046474 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040004\000\00000\000\000 */
{ 2046991 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040004\000\00000\000\000 */
{ 2047348 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040004\000\00000\000\000 */
{ 2047506 }, /* offcore_response.demand_code_rd.l3_hit_m.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040004\000\00000\000\000 */
{ 2047654 }, /* offcore_response.demand_code_rd.l3_hit_s.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100004\000\00000\000\000 */
{ 2048899 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100004\000\00000\000\000 */
{ 2049057 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100004\000\00000\000\000 */
{ 2049210 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100004\000\00000\000\000 */
{ 2049727 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100004\000\00000\000\000 */
{ 2050084 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100004\000\00000\000\000 */
{ 2050242 }, /* offcore_response.demand_code_rd.l3_hit_s.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100004\000\00000\000\000 */
{ 2061238 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400004\000\00000\000\000 */
{ 2061397 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400004\000\00000\000\000 */
{ 2061562 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400004\000\00000\000\000 */
{ 2061722 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400004\000\00000\000\000 */
{ 2062046 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400004\000\00000\000\000 */
{ 2062204 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400004\000\00000\000\000 */
{ 2062369 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400004\000\00000\000\000 */
{ 2069196 }, /* offcore_response.demand_code_rd.supplier_none.any_snoop\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020004\000\00000\000\000 */
{ 2070496 }, /* offcore_response.demand_code_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020004\000\00000\000\000 */
{ 2070659 }, /* offcore_response.demand_code_rd.supplier_none.snoop_hitm\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020004\000\00000\000\000 */
{ 2070817 }, /* offcore_response.demand_code_rd.supplier_none.snoop_miss\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020004\000\00000\000\000 */
{ 2071354 }, /* offcore_response.demand_code_rd.supplier_none.snoop_none\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020004\000\00000\000\000 */
{ 2071726 }, /* offcore_response.demand_code_rd.supplier_none.snoop_not_needed\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020004\000\00000\000\000 */
{ 2071889 }, /* offcore_response.demand_code_rd.supplier_none.spl_hit\000\000cache\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020004\000\00000\000\000 */
{ 2080490 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand data reads have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 2089208 }, /* offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0001\000\00000\000\000 */
{ 2091773 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0001\000\00000\000\000 */
{ 2092483 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0001\000\00000\000\000 */
{ 2092777 }, /* offcore_response.demand_data_rd.l3_hit.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0001\000\00000\000\000 */
{ 2093576 }, /* offcore_response.demand_data_rd.l3_hit.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0001\000\00000\000\000 */
{ 2094068 }, /* offcore_response.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0001\000\00000\000\000 */
{ 2094372 }, /* offcore_response.demand_data_rd.l3_hit.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0001\000\00000\000\000 */
{ 2094514 }, /* offcore_response.demand_data_rd.l3_hit_e.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080001\000\00000\000\000 */
{ 2095755 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080001\000\00000\000\000 */
{ 2095909 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080001\000\00000\000\000 */
{ 2096058 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080001\000\00000\000\000 */
{ 2096567 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080001\000\00000\000\000 */
{ 2096920 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080001\000\00000\000\000 */
{ 2097074 }, /* offcore_response.demand_data_rd.l3_hit_e.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080001\000\00000\000\000 */
{ 2098724 }, /* offcore_response.demand_data_rd.l3_hit_m.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040001\000\00000\000\000 */
{ 2099965 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040001\000\00000\000\000 */
{ 2100119 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040001\000\00000\000\000 */
{ 2100268 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040001\000\00000\000\000 */
{ 2100777 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040001\000\00000\000\000 */
{ 2101130 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040001\000\00000\000\000 */
{ 2101284 }, /* offcore_response.demand_data_rd.l3_hit_m.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040001\000\00000\000\000 */
{ 2101428 }, /* offcore_response.demand_data_rd.l3_hit_s.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100001\000\00000\000\000 */
{ 2102669 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100001\000\00000\000\000 */
{ 2102823 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100001\000\00000\000\000 */
{ 2102972 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100001\000\00000\000\000 */
{ 2103481 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100001\000\00000\000\000 */
{ 2103834 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100001\000\00000\000\000 */
{ 2103988 }, /* offcore_response.demand_data_rd.l3_hit_s.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100001\000\00000\000\000 */
{ 2114864 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400001\000\00000\000\000 */
{ 2115019 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400001\000\00000\000\000 */
{ 2115180 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400001\000\00000\000\000 */
{ 2115336 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400001\000\00000\000\000 */
{ 2115652 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400001\000\00000\000\000 */
{ 2115806 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400001\000\00000\000\000 */
{ 2115967 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400001\000\00000\000\000 */
{ 2127074 }, /* offcore_response.demand_data_rd.supplier_none.any_snoop\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020001\000\00000\000\000 */
{ 2128370 }, /* offcore_response.demand_data_rd.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020001\000\00000\000\000 */
{ 2128529 }, /* offcore_response.demand_data_rd.supplier_none.snoop_hitm\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020001\000\00000\000\000 */
{ 2128683 }, /* offcore_response.demand_data_rd.supplier_none.snoop_miss\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020001\000\00000\000\000 */
{ 2129212 }, /* offcore_response.demand_data_rd.supplier_none.snoop_none\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020001\000\00000\000\000 */
{ 2129580 }, /* offcore_response.demand_data_rd.supplier_none.snoop_not_needed\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020001\000\00000\000\000 */
{ 2129739 }, /* offcore_response.demand_data_rd.supplier_none.spl_hit\000\000cache\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020001\000\00000\000\000 */
{ 2137583 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand data writes (RFOs) have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 2147994 }, /* offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C0002\000\00000\000\000 */
{ 2150567 }, /* offcore_response.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C0002\000\00000\000\000 */
{ 2151277 }, /* offcore_response.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C0002\000\00000\000\000 */
{ 2151587 }, /* offcore_response.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C0002\000\00000\000\000 */
{ 2152410 }, /* offcore_response.demand_rfo.l3_hit.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C0002\000\00000\000\000 */
{ 2152910 }, /* offcore_response.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C0002\000\00000\000\000 */
{ 2153230 }, /* offcore_response.demand_rfo.l3_hit.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C0002\000\00000\000\000 */
{ 2153380 }, /* offcore_response.demand_rfo.l3_hit_e.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0080002\000\00000\000\000 */
{ 2154589 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400080002\000\00000\000\000 */
{ 2154751 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000080002\000\00000\000\000 */
{ 2154908 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200080002\000\00000\000\000 */
{ 2155425 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80080002\000\00000\000\000 */
{ 2155778 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100080002\000\00000\000\000 */
{ 2155940 }, /* offcore_response.demand_rfo.l3_hit_e.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40080002\000\00000\000\000 */
{ 2157542 }, /* offcore_response.demand_rfo.l3_hit_m.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0040002\000\00000\000\000 */
{ 2158751 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400040002\000\00000\000\000 */
{ 2158913 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000040002\000\00000\000\000 */
{ 2159070 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200040002\000\00000\000\000 */
{ 2159587 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80040002\000\00000\000\000 */
{ 2159940 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100040002\000\00000\000\000 */
{ 2160102 }, /* offcore_response.demand_rfo.l3_hit_m.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40040002\000\00000\000\000 */
{ 2160254 }, /* offcore_response.demand_rfo.l3_hit_s.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0100002\000\00000\000\000 */
{ 2161463 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400100002\000\00000\000\000 */
{ 2161625 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000100002\000\00000\000\000 */
{ 2161782 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200100002\000\00000\000\000 */
{ 2162299 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80100002\000\00000\000\000 */
{ 2162652 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100100002\000\00000\000\000 */
{ 2162814 }, /* offcore_response.demand_rfo.l3_hit_s.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40100002\000\00000\000\000 */
{ 2173730 }, /* offcore_response.demand_rfo.l4_hit_local_l4.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0400002\000\00000\000\000 */
{ 2173893 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400400002\000\00000\000\000 */
{ 2174062 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000400002\000\00000\000\000 */
{ 2174226 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200400002\000\00000\000\000 */
{ 2174558 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80400002\000\00000\000\000 */
{ 2174720 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100400002\000\00000\000\000 */
{ 2174889 }, /* offcore_response.demand_rfo.l4_hit_local_l4.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40400002\000\00000\000\000 */
{ 2185186 }, /* offcore_response.demand_rfo.supplier_none.any_snoop\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0020002\000\00000\000\000 */
{ 2186450 }, /* offcore_response.demand_rfo.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400020002\000\00000\000\000 */
{ 2186617 }, /* offcore_response.demand_rfo.supplier_none.snoop_hitm\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000020002\000\00000\000\000 */
{ 2186779 }, /* offcore_response.demand_rfo.supplier_none.snoop_miss\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200020002\000\00000\000\000 */
{ 2187316 }, /* offcore_response.demand_rfo.supplier_none.snoop_none\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80020002\000\00000\000\000 */
{ 2187684 }, /* offcore_response.demand_rfo.supplier_none.snoop_not_needed\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100020002\000\00000\000\000 */
{ 2187851 }, /* offcore_response.demand_rfo.supplier_none.spl_hit\000\000cache\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40020002\000\00000\000\000 */
{ 2195738 }, /* offcore_response.other.any_response\000\000cache\000Counts any other requests have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 2196792 }, /* offcore_response.other.l3_hit.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC01C8000\000\00000\000\000 */
{ 2197913 }, /* offcore_response.other.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4001C8000\000\00000\000\000 */
{ 2198402 }, /* offcore_response.other.l3_hit.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001C8000\000\00000\000\000 */
{ 2198680 }, /* offcore_response.other.l3_hit.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001C8000\000\00000\000\000 */
{ 2199429 }, /* offcore_response.other.l3_hit.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801C8000\000\00000\000\000 */
{ 2199887 }, /* offcore_response.other.l3_hit.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001C8000\000\00000\000\000 */
{ 2200175 }, /* offcore_response.other.l3_hit.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401C8000\000\00000\000\000 */
{ 2200309 }, /* offcore_response.other.l3_hit_e.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0088000\000\00000\000\000 */
{ 2201452 }, /* offcore_response.other.l3_hit_e.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400088000\000\00000\000\000 */
{ 2201598 }, /* offcore_response.other.l3_hit_e.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000088000\000\00000\000\000 */
{ 2201739 }, /* offcore_response.other.l3_hit_e.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200088000\000\00000\000\000 */
{ 2202214 }, /* offcore_response.other.l3_hit_e.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80088000\000\00000\000\000 */
{ 2202541 }, /* offcore_response.other.l3_hit_e.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100088000\000\00000\000\000 */
{ 2202687 }, /* offcore_response.other.l3_hit_e.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40088000\000\00000\000\000 */
{ 2204203 }, /* offcore_response.other.l3_hit_m.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0048000\000\00000\000\000 */
{ 2205346 }, /* offcore_response.other.l3_hit_m.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400048000\000\00000\000\000 */
{ 2205492 }, /* offcore_response.other.l3_hit_m.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000048000\000\00000\000\000 */
{ 2205633 }, /* offcore_response.other.l3_hit_m.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200048000\000\00000\000\000 */
{ 2206108 }, /* offcore_response.other.l3_hit_m.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80048000\000\00000\000\000 */
{ 2206435 }, /* offcore_response.other.l3_hit_m.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100048000\000\00000\000\000 */
{ 2206581 }, /* offcore_response.other.l3_hit_m.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40048000\000\00000\000\000 */
{ 2206717 }, /* offcore_response.other.l3_hit_s.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0108000\000\00000\000\000 */
{ 2207860 }, /* offcore_response.other.l3_hit_s.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400108000\000\00000\000\000 */
{ 2208006 }, /* offcore_response.other.l3_hit_s.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000108000\000\00000\000\000 */
{ 2208147 }, /* offcore_response.other.l3_hit_s.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200108000\000\00000\000\000 */
{ 2208622 }, /* offcore_response.other.l3_hit_s.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80108000\000\00000\000\000 */
{ 2208949 }, /* offcore_response.other.l3_hit_s.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100108000\000\00000\000\000 */
{ 2209095 }, /* offcore_response.other.l3_hit_s.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40108000\000\00000\000\000 */
{ 2217675 }, /* offcore_response.other.l4_hit_local_l4.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0408000\000\00000\000\000 */
{ 2217822 }, /* offcore_response.other.l4_hit_local_l4.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400408000\000\00000\000\000 */
{ 2217975 }, /* offcore_response.other.l4_hit_local_l4.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000408000\000\00000\000\000 */
{ 2218123 }, /* offcore_response.other.l4_hit_local_l4.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200408000\000\00000\000\000 */
{ 2218423 }, /* offcore_response.other.l4_hit_local_l4.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80408000\000\00000\000\000 */
{ 2218569 }, /* offcore_response.other.l4_hit_local_l4.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100408000\000\00000\000\000 */
{ 2218722 }, /* offcore_response.other.l4_hit_local_l4.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40408000\000\00000\000\000 */
{ 2223645 }, /* offcore_response.other.supplier_none.any_snoop\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC0028000\000\00000\000\000 */
{ 2224843 }, /* offcore_response.other.supplier_none.snoop_hit_no_fwd\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400028000\000\00000\000\000 */
{ 2224994 }, /* offcore_response.other.supplier_none.snoop_hitm\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000028000\000\00000\000\000 */
{ 2225140 }, /* offcore_response.other.supplier_none.snoop_miss\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200028000\000\00000\000\000 */
{ 2225635 }, /* offcore_response.other.supplier_none.snoop_none\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x80028000\000\00000\000\000 */
{ 2225977 }, /* offcore_response.other.supplier_none.snoop_not_needed\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100028000\000\00000\000\000 */
{ 2226128 }, /* offcore_response.other.supplier_none.spl_hit\000\000cache\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x40028000\000\00000\000\000 */
{ 2531664 }, /* sq_misc.split_lock\000\000cache\000Number of cache line split locks sent to uncore\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the number of cache line split locks sent to the uncore\000 */
{ 2537304 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=2000003,umask=0x1\000\00000\000\000 */
{ 2537950 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=2000003,umask=0x8\000\00000\000\000 */
{ 2538599 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=2000003,umask=0x2\000\00000\000\000 */
{ 2539263 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=2000003,umask=0x4\000\00000\000\000 */
{ 855448 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x4\000\00000\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 858464 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Counts once for most SIMD 128-bit packed computational single precision floating-point instruction retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x8\000\00000\000Counts once for most SIMD 128-bit packed computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 863684 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x10\000\00000\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 867763 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x20\000\00000\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 870832 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 885571 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Counts once for most SIMD scalar computational floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x3\000\00000\000Counts once for most SIMD scalar computational single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891206 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts once for most SIMD scalar computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x1\000\00000\000Counts once for most SIMD scalar computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 894912 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts once for most SIMD scalar computational single precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x2\000\00000\000Counts once for most SIMD scalar computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 901772 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775088 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781493 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000This event counts the number of the Decode Stream Buffer (DSB)-to-MITE switches including all misses because of missing Decode Stream Buffer (DSB) cache and u-arch forced misses.\nNote: Invoking MITE requires two or three cycles delay\000 */
{ 782928 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. MM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.Penalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943451 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000\000 */
{ 944466 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000\000 */
{ 949483 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Must be precise)\000event=0xc6,period=100007,umask=0x1,frontend=0x400106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Must be precise)\000 */
{ 944927 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x408006\000\00000\000\000 */
{ 947148 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x401006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 954352 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400206\000\00000\000\000 */
{ 951387 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x410006\000\00000\000\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 957056 }, /* frontend_retired.latency_ge_2_bubbles_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 2 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x200206\000\00000\000\000 */
{ 957358 }, /* frontend_retired.latency_ge_2_bubbles_ge_3\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 3 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x300206\000\00000\000\000 */
{ 957660 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x402006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 959995 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400406\000\00000\000\000 */
{ 962188 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x420006\000\00000\000\000 */
{ 964409 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x404006\000\00000\000\000 */
{ 966616 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992891 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity\000 */
{ 993527 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000\000 */
{ 994068 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000\000 */
{ 994568 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 996552 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 997882 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.DSB_CYCLES_OK]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_OK]\000 */
{ 998944 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.DSB_CYCLES_ANY]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_ANY]\000 */
{ 1000200 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts the number of cycles 4 uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001450 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002331 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1003527 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000 */
{ 1005201 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000 */
{ 1005996 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1009115 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1011962 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1013663 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1017722 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1022226 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1023696 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025427 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1031951 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when: a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread. b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions).  c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038295 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when less than 1 uop is delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >= 3\000 */
{ 1039505 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles with less than 2 uops delivered by the front-end\000 */
{ 1040076 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with less than 3 uops delivered by the front-end\000 */
{ 751900 }, /* cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 757696 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 970825 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 971725 }, /* hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000\000 */
{ 972195 }, /* hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000 */
{ 972380 }, /* hle_retired.aborted_memtype\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times an HLE execution aborted due to incompatible memory type\000 */
{ 974679 }, /* hle_retired.aborted_timer\000\000memory\000Number of times an HLE execution aborted due to hardware timer expiration\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000 */
{ 975183 }, /* hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000 */
{ 975707 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976185 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region. Does not count nested transactions\000 */
{ 1293986 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts  Spec update: SKL089\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:a. memory disambiguation,b. external snoop, orc. cross SMT-HW-thread snoop (stores) hitting load buffer  Spec update: SKL089\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1752561 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Demand Data Read requests who miss L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000Demand Data Read requests who miss L3 cache\000 */
{ 1768551 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles with at least 1 Demand Data Read requests who miss L3 cache in the superQ\000event=0x60,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1778719 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000Counts number of Offcore outstanding Demand Data Read requests that miss L3 cache in the superQ every cycle\000event=0x60,period=2000003,umask=0x10\000\00000\000\000 */
{ 1780659 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles with at least 6 Demand Data Read requests that miss L3 cache in the superQ\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000\000 */
{ 2039406 }, /* offcore_response.demand_code_rd.l3_hit.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0004\000\00000\000\000 */
{ 2042591 }, /* offcore_response.demand_code_rd.l3_hit_e.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080004\000\00000\000\000 */
{ 2046833 }, /* offcore_response.demand_code_rd.l3_hit_m.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040004\000\00000\000\000 */
{ 2049569 }, /* offcore_response.demand_code_rd.l3_hit_s.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100004\000\00000\000\000 */
{ 2050732 }, /* offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400004\000\00000\000\000 */
{ 2053227 }, /* offcore_response.demand_code_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400004\000\00000\000\000 */
{ 2053385 }, /* offcore_response.demand_code_rd.l3_miss.snoop_hitm\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400004\000\00000\000\000 */
{ 2053690 }, /* offcore_response.demand_code_rd.l3_miss.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400004\000\00000\000\000 */
{ 2054278 }, /* offcore_response.demand_code_rd.l3_miss.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400004\000\00000\000\000 */
{ 2054586 }, /* offcore_response.demand_code_rd.l3_miss.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400004\000\00000\000\000 */
{ 2055100 }, /* offcore_response.demand_code_rd.l3_miss.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400004\000\00000\000\000 */
{ 2055258 }, /* offcore_response.demand_code_rd.l3_miss.spl_hit\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400004\000\00000\000\000 */
{ 2055569 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000004\000\00000\000\000 */
{ 2056930 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000004\000\00000\000\000 */
{ 2057099 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000004\000\00000\000\000 */
{ 2057263 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000004\000\00000\000\000 */
{ 2058133 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000004\000\00000\000\000 */
{ 2058301 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000004\000\00000\000\000 */
{ 2058690 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000004\000\00000\000\000 */
{ 2058859 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.spl_hit\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000004\000\00000\000\000 */
{ 2061881 }, /* offcore_response.demand_code_rd.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400004\000\00000\000\000 */
{ 2071191 }, /* offcore_response.demand_code_rd.supplier_none.snoop_non_dram\000\000memory\000Counts all demand code reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020004\000\00000\000\000 */
{ 2093272 }, /* offcore_response.demand_data_rd.l3_hit.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0001\000\00000\000\000 */
{ 2096413 }, /* offcore_response.demand_data_rd.l3_hit_e.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080001\000\00000\000\000 */
{ 2100623 }, /* offcore_response.demand_data_rd.l3_hit_m.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040001\000\00000\000\000 */
{ 2103327 }, /* offcore_response.demand_data_rd.l3_hit_s.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100001\000\00000\000\000 */
{ 2104466 }, /* offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400001\000\00000\000\000 */
{ 2106941 }, /* offcore_response.demand_data_rd.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400001\000\00000\000\000 */
{ 2107095 }, /* offcore_response.demand_data_rd.l3_miss.snoop_hitm\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400001\000\00000\000\000 */
{ 2107392 }, /* offcore_response.demand_data_rd.l3_miss.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400001\000\00000\000\000 */
{ 2107972 }, /* offcore_response.demand_data_rd.l3_miss.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400001\000\00000\000\000 */
{ 2108272 }, /* offcore_response.demand_data_rd.l3_miss.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400001\000\00000\000\000 */
{ 2108778 }, /* offcore_response.demand_data_rd.l3_miss.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400001\000\00000\000\000 */
{ 2108932 }, /* offcore_response.demand_data_rd.l3_miss.spl_hit\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400001\000\00000\000\000 */
{ 2109235 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.any_snoop\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000001\000\00000\000\000 */
{ 2110592 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000001\000\00000\000\000 */
{ 2110757 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000001\000\00000\000\000 */
{ 2110917 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000001\000\00000\000\000 */
{ 2111779 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000001\000\00000\000\000 */
{ 2111943 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_none\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000001\000\00000\000\000 */
{ 2112328 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000001\000\00000\000\000 */
{ 2112493 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.spl_hit\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000001\000\00000\000\000 */
{ 2115491 }, /* offcore_response.demand_data_rd.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400001\000\00000\000\000 */
{ 2129053 }, /* offcore_response.demand_data_rd.supplier_none.snoop_non_dram\000\000memory\000Counts demand data reads\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020001\000\00000\000\000 */
{ 2152090 }, /* offcore_response.demand_rfo.l3_hit.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C0002\000\00000\000\000 */
{ 2155263 }, /* offcore_response.demand_rfo.l3_hit_e.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000080002\000\00000\000\000 */
{ 2159425 }, /* offcore_response.demand_rfo.l3_hit_m.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000040002\000\00000\000\000 */
{ 2162137 }, /* offcore_response.demand_rfo.l3_hit_s.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000100002\000\00000\000\000 */
{ 2163316 }, /* offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC400002\000\00000\000\000 */
{ 2165775 }, /* offcore_response.demand_rfo.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C400002\000\00000\000\000 */
{ 2165937 }, /* offcore_response.demand_rfo.l3_miss.snoop_hitm\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C400002\000\00000\000\000 */
{ 2166250 }, /* offcore_response.demand_rfo.l3_miss.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C400002\000\00000\000\000 */
{ 2166838 }, /* offcore_response.demand_rfo.l3_miss.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C400002\000\00000\000\000 */
{ 2167154 }, /* offcore_response.demand_rfo.l3_miss.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC400002\000\00000\000\000 */
{ 2167668 }, /* offcore_response.demand_rfo.l3_miss.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C400002\000\00000\000\000 */
{ 2167830 }, /* offcore_response.demand_rfo.l3_miss.spl_hit\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C400002\000\00000\000\000 */
{ 2168149 }, /* offcore_response.demand_rfo.l3_miss_local_dram.any_snoop\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4000002\000\00000\000\000 */
{ 2169474 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404000002\000\00000\000\000 */
{ 2169647 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004000002\000\00000\000\000 */
{ 2169815 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204000002\000\00000\000\000 */
{ 2170677 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004000002\000\00000\000\000 */
{ 2170849 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_none\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84000002\000\00000\000\000 */
{ 2171234 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104000002\000\00000\000\000 */
{ 2171407 }, /* offcore_response.demand_rfo.l3_miss_local_dram.spl_hit\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44000002\000\00000\000\000 */
{ 2174389 }, /* offcore_response.demand_rfo.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000400002\000\00000\000\000 */
{ 2187149 }, /* offcore_response.demand_rfo.supplier_none.snoop_non_dram\000\000memory\000Counts all demand data writes (RFOs)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000020002\000\00000\000\000 */
{ 2199141 }, /* offcore_response.other.l3_hit.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x20001C8000\000\00000\000\000 */
{ 2202068 }, /* offcore_response.other.l3_hit_e.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000088000\000\00000\000\000 */
{ 2205962 }, /* offcore_response.other.l3_hit_m.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000048000\000\00000\000\000 */
{ 2208476 }, /* offcore_response.other.l3_hit_s.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000108000\000\00000\000\000 */
{ 2209231 }, /* offcore_response.other.l3_miss.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FFC408000\000\00000\000\000 */
{ 2210910 }, /* offcore_response.other.l3_miss.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x43C408000\000\00000\000\000 */
{ 2211056 }, /* offcore_response.other.l3_miss.snoop_hitm\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103C408000\000\00000\000\000 */
{ 2211337 }, /* offcore_response.other.l3_miss.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x23C408000\000\00000\000\000 */
{ 2211665 }, /* offcore_response.other.l3_miss.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x203C408000\000\00000\000\000 */
{ 2211949 }, /* offcore_response.other.l3_miss.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0xBC408000\000\00000\000\000 */
{ 2212421 }, /* offcore_response.other.l3_miss.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x13C408000\000\00000\000\000 */
{ 2212567 }, /* offcore_response.other.l3_miss.spl_hit\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x7C408000\000\00000\000\000 */
{ 2212854 }, /* offcore_response.other.l3_miss_local_dram.any_snoop\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FC4008000\000\00000\000\000 */
{ 2214113 }, /* offcore_response.other.l3_miss_local_dram.snoop_hit_no_fwd\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x404008000\000\00000\000\000 */
{ 2214270 }, /* offcore_response.other.l3_miss_local_dram.snoop_hitm\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004008000\000\00000\000\000 */
{ 2214422 }, /* offcore_response.other.l3_miss_local_dram.snoop_miss\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x204008000\000\00000\000\000 */
{ 2215013 }, /* offcore_response.other.l3_miss_local_dram.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2004008000\000\00000\000\000 */
{ 2215169 }, /* offcore_response.other.l3_miss_local_dram.snoop_none\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x84008000\000\00000\000\000 */
{ 2215528 }, /* offcore_response.other.l3_miss_local_dram.snoop_not_needed\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x104008000\000\00000\000\000 */
{ 2215685 }, /* offcore_response.other.l3_miss_local_dram.spl_hit\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x44008000\000\00000\000\000 */
{ 2218270 }, /* offcore_response.other.l4_hit_local_l4.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000408000\000\00000\000\000 */
{ 2225484 }, /* offcore_response.other.supplier_none.snoop_non_dram\000\000memory\000Counts any other requests\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000028000\000\00000\000\000 */
{ 2514787 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered (Precise event)\000 */
{ 2515653 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2516231 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516758 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519252 }, /* rtm_retired.aborted_timer\000\000memory\000Number of times an RTM execution aborted due to uncommon conditions\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000 */
{ 2519638 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520181 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520659 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571935 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573674 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000 */
{ 2574110 }, /* tx_mem.abort_capacity\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional reads or writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000 */
{ 2575819 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576852 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577961 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2579066 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2579929 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2580950 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 978812 }, /* hw_interrupts.received\000\000other\000Number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000Counts the number of hardware interruptions received by the processor\000 */
{ 1427308 }, /* memory_disambiguation.history_reset\000\000other\000MEMORY_DISAMBIGUATION.HISTORY_RESET\000event=0x9,period=2000003,umask=0x1\000\00000\000\000 */
{ 468073 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000event=0x14,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 496249 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009\000\00000\000Counts all (macro) branch instructions retired  Spec update: SKL091\000 */
{ 499329 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000 */
{ 503121 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000 */
{ 504119 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 506277 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000 */
{ 508062 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 514802 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 517512 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 518926 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 522057 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 536275 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path\000 */
{ 541281 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 554675 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted direct and indirect near call instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts both taken and not taken retired mispredicted direct and indirect near calls, including both register and memory indirect (Precise event)\000 */
{ 555365 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 606999 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 607510 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 608492 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 618032 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 627594 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638353 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 639277 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 640312 }, /* cpu_clk_unhalted.ring0_trans\000\000pipeline\000Counts when there is a transition from ring 1, 2 or 3 to ring 0\000event=0x3c,cmask=1,edge=1,period=100007\000\00000\000Counts when the Current Privilege Level (CPL) transitions from ring 1, 2 or 3 to ring 0 (Kernel)\000 */
{ 641300 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 753037 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=2000003,umask=0x10\000\00000\000\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 758894 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=2000003,umask=0x14\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847925 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no outstanding load\000event=0xa6,period=2000003,umask=0x40\000\00000\000\000 */
{ 848693 }, /* exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles where no uops were executed, the Reservation Station was not empty, the Store Buffer was full and there was no outstanding load\000event=0xa6,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 1041006 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1047887 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, Counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. Counting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1055017 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event  Spec update: SKL091, SKL044\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: SKL091, SKL044\000 */
{ 1057846 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions  Spec update: SKL091, SKL044 (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1059777 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1063267 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Number of cycles using always true condition applied to  PEBS instructions retired event  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using an always true condition applied to  PEBS instructions retired event. (inst_ret< 16)  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1066130 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Cycles the issue-stage is waiting for front-end to fetch from resteered path following branch misprediction or machine clear events\000event=0xd,period=2000003,umask=0x80\000\00000\000\000 */
{ 1066904 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1068948 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,period=2000003,umask=0x1\000\00000\000Core cycles the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1071510 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1194460 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1202058 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229766 }, /* load_hit_pre.sw_pf\000\000pipeline\000Demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283301 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_OK]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_OK]\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1284803 }, /* lsd.cycles_ok\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_4_UOPS]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_4_UOPS]\000 */
{ 1286318 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 2461899 }, /* other_assists.any\000\000pipeline\000Number of times a microcode assist is invoked by HW other than FP-assist. Examples include AD (page Access Dirty) and AVX* related assists\000event=0xc1,period=100003,umask=0x3f\000\00000\000\000 */
{ 2478166 }, /* partial_rat_stalls.scoreboard\000\000pipeline\000Cycles where the pipeline is stalled due to serializing operations\000event=0x59,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the microcode scoreboard stalls happen\000 */
{ 2501367 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Counts resource-related stall cycles\000 */
{ 2504559 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2507828 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=2000003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 2508199 }, /* rob_misc_events.pause_inst\000\000pipeline\000Number of retired PAUSE instructions (that do not end up with a VMExit to the VMM; TSX aborted Instructions may be counted). This event is not supported on first SKL and KBL products\000event=0xcc,period=2000003,umask=0x40\000\00000\000\000 */
{ 2510793 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for the thread.; Note: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512239 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate front-end Latency Bound issues\000 */
{ 6184015 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185297 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186603 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 2\000 */
{ 6187901 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189223 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190512 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191493 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192140 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198549 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200712 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201775 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202848 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203792 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6214065 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6219530 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6222270 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=2000003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000 */
{ 6231140 }, /* uops_retired.macro_fused\000\000pipeline\000Number of macro-fused uops retired. (non precise)\000event=0xc2,period=2000003,umask=0x4\000\00000\000Counts the number of macro-fused uops retired. (non precise)\000 */
{ 6235584 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used\000 */
{ 6238702 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240572 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x2\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2784623 }, /* unc_cbo_cache_lookup.any_es\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x86\000\00001\000L3 Lookup any request that access cache and found line in E or S-state\000 */
{ 2785035 }, /* unc_cbo_cache_lookup.any_i\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x88\000\00001\000L3 Lookup any request that access cache and found line in I-state\000 */
{ 2785430 }, /* unc_cbo_cache_lookup.any_m\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x81\000\00001\000L3 Lookup any request that access cache and found line in M-state\000 */
{ 2785825 }, /* unc_cbo_cache_lookup.any_mesi\000uncore_cbox\000uncore cache\000L3 Lookup any request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x8f\000\00001\000L3 Lookup any request that access cache and found line in MESI-state\000 */
{ 2786963 }, /* unc_cbo_cache_lookup.read_es\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x16\000\00001\000L3 Lookup read request that access cache and found line in E or S-state\000 */
{ 2787380 }, /* unc_cbo_cache_lookup.read_i\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in I-state. Unit: uncore_cbox \000event=0x34,umask=0x18\000\00001\000L3 Lookup read request that access cache and found line in I-state\000 */
{ 2788180 }, /* unc_cbo_cache_lookup.read_mesi\000uncore_cbox\000uncore cache\000L3 Lookup read request that access cache and found line in any MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x1f\000\00001\000L3 Lookup read request that access cache and found line in any MESI-state\000 */
{ 2788607 }, /* unc_cbo_cache_lookup.write_es\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in E or S-state. Unit: uncore_cbox \000event=0x34,umask=0x26\000\00001\000L3 Lookup write request that access cache and found line in E or S-state\000 */
{ 2789198 }, /* unc_cbo_cache_lookup.write_m\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in M-state. Unit: uncore_cbox \000event=0x34,umask=0x21\000\00001\000L3 Lookup write request that access cache and found line in M-state\000 */
{ 2789603 }, /* unc_cbo_cache_lookup.write_mesi\000uncore_cbox\000uncore cache\000L3 Lookup write request that access cache and found line in MESI-state. Unit: uncore_cbox \000event=0x34,umask=0x2f\000\00001\000L3 Lookup write request that access cache and found line in MESI-state\000 */
{ 2790402 }, /* unc_cbo_xsnp_response.hit_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a non-modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x44\000\00001\000\000 */
{ 2791012 }, /* unc_cbo_xsnp_response.hitm_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which hits a modified line in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x48\000\00001\000\000 */
{ 2791246 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore cache\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\00001\000\000 */
{ 2791854 }, /* unc_cbo_xsnp_response.miss_xcore\000uncore_cbox\000uncore cache\000A cross-core snoop initiated by this Cbox due to processor core memory request which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x41\000\00001\000\000 */
{ 2582380 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000Number of entries allocated. Account for Any type: e.g. Snoop, Core aperture, etc. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2586839 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Number of all Core entries outstanding for the memory controller. The outstanding interval starts after LLC miss till return of first data chunk. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2587471 }, /* unc_arb_trk_occupancy.cycles_with_any_request\000uncore_arb\000uncore interconnect\000Cycles with at least one request outstanding is waiting for data return from memory controller. Account for coherent and non-coherent requests initiated by IA Cores, Processor Graphics Unit, or LLC. Unit: uncore_arb \000event=0x80,cmask=1,umask=0x1\000\00001\000\000 */
{ 2588129 }, /* unc_arb_trk_occupancy.data_read\000uncore_arb\000uncore interconnect\000Number of Core Data Read entries outstanding for the memory controller. The outstanding interval starts after LLC miss till return of first data chunk. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2590229 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000UNC_ARB_TRK_REQUESTS.ALL. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2590355 }, /* unc_arb_trk_requests.data_read\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read requests sent to memory controller whose data is returned directly to requesting agent. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2590832 }, /* unc_arb_trk_requests.drd_direct\000uncore_arb\000uncore interconnect\000Number of Core coherent Data Read requests sent to memory controller whose data is returned directly to requesting agent. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2591875 }, /* unc_arb_trk_requests.writes\000uncore_arb\000uncore interconnect\000Number of Writes allocated - any write transactions: full/partials writes and evictions. Unit: uncore_arb \000event=0x81,umask=0x20\000\00001\000\000 */
{ 3540382 }, /* unc_clock.socket\000uncore_clock\000uncore other\000This 48-bit fixed counter counts the UCLK cycles. Unit: uncore_clock \000event=0xff\000\00001\000This 48-bit fixed counter counts the UCLK cycles\000 */
{ 788320 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Counts demand data loads that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 791308 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=2000003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793371 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 798170 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data load to a 1G page\000event=0x8,period=2000003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 801032 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data load to a 2M/4M page\000event=0x8,period=2000003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 804341 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data load to a 4K page\000event=0x8,period=2000003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 807135 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 810679 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Counts demand data stores that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 813355 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 814891 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 819786 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 822786 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 825573 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 829022 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 833842 }, /* ept.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a EPT (Extended Page Table) walk for any request type\000event=0x4f,period=2000003,umask=0x10\000\00000\000Counts cycles for each PMH (Page Miss Handler) that is busy with an EPT (Extended Page Table) walk for any request type\000 */
{ 1078252 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080900 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Counts page walks of any page size (4K/2M/4M/1G) caused by a code fetch. This implies it missed in the ITLB and further levels of TLB, but the walk need not have completed\000 */
{ 1082889 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1084967 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1088976 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000Counts completed page walks (1G page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1096669 }, /* itlb_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake\000event=0x85,period=100003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH (Page Miss Handler) that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake michroarchitecture\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__skylake[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51159 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 52640 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * (FP_ASSIST.ANY + OTHER_ASSISTS.ANY) / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62896 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - tma_frontend_bound - (UOPS_ISSUED.ANY + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00000 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 70171 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 79989 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(18.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM + 16.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 99868 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00016.5 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 113664 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122993 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 137218 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(9 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00002 */
{ 142945 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(9 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 146842 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00022 * tma_info_system_average_frequency * OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 154534 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00002 */
{ 160611 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 164336 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 177065 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00001 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 187717 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1\000\00000 */
{ 190426 }, /* \000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * UOPS_RETIRED.MACRO_FUSED / UOPS_RETIRED.RETIRE_SLOTS\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000 */
{ 191743 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000(UOPS_RETIRED.RETIRE_SLOTS + UOPS_RETIRED.MACRO_FUSED - INST_RETIRED.ANY) / tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 193552 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(ICACHE_16B.IFDATA_STALL + 2 * cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@) / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 196454 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 201191 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 203428 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.CONDITIONAL + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 208349 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00001 */
{ 212748 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 214466 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216209 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.NOT_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216379 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000(BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 216744 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00001 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219153 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 221371 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 224783 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 226971 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / DSB2MITE_SWITCHES.COUNT\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227629 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@ + 2\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 231865 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0x3c@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00001 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239525 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00001 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243336 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 253898 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING + EPT.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00002 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 257211 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_ARB_TRK_REQUESTS.ALL + UNC_ARB_COH_TRK_REQUESTS.ALL) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 261268 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00001 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 266789 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_TRK_OCCUPANCY.DATA_READ / UNC_ARB_TRK_OCCUPANCY.DATA_READ@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 267776 }, /* \000tma_info_system_mem_parallel_requests\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_OCCUPANCY.CYCLES_WITH_ANY_REQUEST\000\000Average number of parallel requests to external memory\000Average number of parallel requests to external memory. Accounts for all requests\000\000\000\000\00000 */
{ 269667 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_ARB_TRK_OCCUPANCY.DATA_READ / UNC_ARB_TRK_REQUESTS.DATA_READ) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271339 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000UNC_ARB_TRK_OCCUPANCY.ALL / UNC_ARB_TRK_REQUESTS.ALL\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275116 }, /* \000tma_info_system_socket_clks\000SoC\000UNC_CLOCK.SOCKET\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 292417 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 308465 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\0006.5 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 315911 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 319201 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00002 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 324936 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(12 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (9 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00000 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 343499 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 348484 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00000 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 356236 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 365594 }, /* \000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - UOPS_RETIRED.MACRO_FUSED) / UOPS_RETIRED.RETIRE_SLOTS\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000 */
{ 367158 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / UOPS_RETIRED.RETIRE_SLOTS\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369645 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00000 */
{ 379171 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382050 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 386530 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 389567 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 391440 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((EXE_ACTIVITY.EXE_BOUND_0_PORTS + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 400041 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_NONE / 2 if #SMT_on else CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_core_core_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 403843 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_1 - UOPS_EXECUTED.CORE_CYCLES_GE_2) / 2 if #SMT_on else EXE_ACTIVITY.1_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 409809 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_2 - UOPS_EXECUTED.CORE_CYCLES_GE_3) / 2 if #SMT_on else EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 417118 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_GE_3 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_3) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 435994 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000PARTIAL_RAT_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: PARTIAL_RAT_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 441609 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00002 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444174 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 453264 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 9 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00002 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 459384 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\0009 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__skylakex[] = {
{ 1101122 }, /* l1d.replacement\000\000cache\000L1D data line replacements\000event=0x51,period=2000003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105725 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of times a request needed a FB entry but there was no entry available for it. That is the FB unavailability was dominant reason for blocking the request. A request includes cacheable/uncacheable demands that is load, store or SW prefetch\000event=0x48,period=2000003,umask=0x2\000\00000\000Number of times a request needed a FB (Fill Buffer) entry but there was no entry available for it. A request includes cacheable/uncacheable demands that are load, store or SW prefetch instructions\000 */
{ 1109275 }, /* l1d_pend_miss.pending\000\000cache\000L1D miss outstandings duration in cycles\000event=0x48,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding, that is each cycle number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch.Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112533 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=2000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1113456 }, /* l1d_pend_miss.pending_cycles_any\000\000cache\000Cycles with L1D load Misses outstanding from any thread on physical core\000event=0x48,any=1,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1133641 }, /* l2_lines_out.non_silent\000\000cache\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines can be either in modified state or clean state. Modified lines may either be written back to L3 or directly written to memory and not allocated in L3.  Clean lines may either be allocated in L3 or dropped\000 */
{ 1136410 }, /* l2_lines_out.silent\000\000cache\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared state. A non-threaded event\000event=0xf2,period=200003,umask=0x1\000\00000\000\000 */
{ 1138301 }, /* l2_lines_out.useless_hwpf\000\000cache\000Counts the number of lines that have been hardware prefetched but not used and now evicted by L2 cache\000event=0xf2,period=200003,umask=0x4\000\00000\000\000 */
{ 1138806 }, /* l2_lines_out.useless_pref\000\000cache\000This event is deprecated. Refer to new event L2_LINES_OUT.USELESS_HWPF\000event=0xf2,period=200003,umask=0x4\000\00010\000\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1158516 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read requests\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts the number of demand Data Read requests (including requests from L1D hardware prefetchers). These loads may hit or miss L2 cache. Only non rejected loads are counted\000 */
{ 1159743 }, /* l2_rqsts.all_demand_miss\000\000cache\000Demand requests that miss L2 cache\000event=0x24,period=200003,umask=0x27\000\00000\000Demand requests that miss L2 cache\000 */
{ 1160496 }, /* l2_rqsts.all_demand_references\000\000cache\000Demand requests to L2 cache\000event=0x24,period=200003,umask=0xe7\000\00000\000Demand requests to L2 cache\000 */
{ 1161655 }, /* l2_rqsts.all_pf\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches\000event=0x24,period=200003,umask=0xf8\000\00000\000Counts the total number of requests from the L2 hardware prefetchers\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165616 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests, initiated by load instructions, that hit L2 cache\000 */
{ 1166558 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2, no rejects\000event=0x24,period=200003,umask=0x21\000\00000\000Counts the number of demand Data Read requests that miss L2 cache. Only not rejected loads are counted\000 */
{ 1169217 }, /* l2_rqsts.miss\000\000cache\000All requests that miss L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000All requests that miss L2 cache\000 */
{ 1170900 }, /* l2_rqsts.pf_hit\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000event=0x24,period=200003,umask=0xd8\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that hit L2 cache\000 */
{ 1171454 }, /* l2_rqsts.pf_miss\000\000cache\000Requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000event=0x24,period=200003,umask=0x38\000\00000\000Counts requests from the L1/L2/L3 hardware prefetchers or Load software prefetches that miss L2 cache\000 */
{ 1172527 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200003,umask=0xff\000\00000\000All L2 requests\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1246868 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable demand requests missed L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2. It does not include all misses to the L3  Spec update: SKL057\000 */
{ 1250569 }, /* longest_lat_cache.reference\000\000cache\000Core-originated cacheable demand requests that refer to L3  Spec update: SKL057\000event=0x2e,period=100003,umask=0x4f\000\00000\000Counts core-originated cacheable requests to the  L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches from L1 and L2.  It does not include all accesses to the L3  Spec update: SKL057\000 */
{ 1310641 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311557 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312305 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=2000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315660 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1321255 }, /* mem_load_l3_hit_retired.xsnp_hit\000\000cache\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Retired load instructions which data sources were L3 and cross-core snoop hits in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1322617 }, /* mem_load_l3_hit_retired.xsnp_hitm\000\000cache\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Retired load instructions which data sources were HitM responses from shared L3  Supports address when precise (Precise event)\000 */
{ 1323860 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions which data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000\000 */
{ 1326191 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Retired load instructions which data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1327262 }, /* mem_load_l3_miss_retired.local_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from local dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x1\000\00000\000Retired load instructions which data sources missed L3 but serviced from local DRAM  Supports address when precise (Precise event)\000 */
{ 1328144 }, /* mem_load_l3_miss_retired.remote_dram\000\000cache\000Retired load instructions which data sources missed L3 but serviced from remote dram  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x2\000\00000\000\000 */
{ 1328360 }, /* mem_load_l3_miss_retired.remote_fwd\000\000cache\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x8\000\00000\000Retired load instructions whose data sources was forwarded from a remote cache  Supports address when precise (Precise event)\000 */
{ 1329165 }, /* mem_load_l3_miss_retired.remote_hitm\000\000cache\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000event=0xd3,period=100007,umask=0x4\000\00000\000Retired load instructions whose data sources was remote HITM  Supports address when precise (Precise event)\000 */
{ 1331393 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000\000 */
{ 1332781 }, /* mem_load_retired.fb_hit\000\000cache\000Retired load instructions which data sources were load missed L1 but hit FB due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1334379 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=2000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335208 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336281 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100003,umask=0x2\000\00000\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337713 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x10\000\00000\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338721 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339355 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1745789 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000 */
{ 1748358 }, /* offcore_requests.demand_code_rd\000\000cache\000Cacheable and non-cacheable code read requests\000event=0xb0,period=100003,umask=0x2\000\00000\000Counts both cacheable and non-cacheable code read requests\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1753384 }, /* offcore_requests_buffer.sq_full\000\000cache\000Offcore requests buffer cannot take more entries for this thread core\000event=0xb2,period=2000003,umask=0x1\000\00000\000Counts the number of cases when the offcore requests buffer cannot take more entries for the core. This can happen when the superqueue does not contain eligible entries, or when L1D writeback pending FIFO requests is full.Note: Writeback pending FIFO has six entries\000 */
{ 1756367 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=2000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1759308 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1761343 }, /* offcore_requests_outstanding.cycles_with_demand_code_rd\000\000cache\000Cycles with offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1763371 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)\000 */
{ 1765815 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1770345 }, /* offcore_requests_outstanding.demand_code_rd\000\000cache\000Offcore outstanding Code Reads transactions in the SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x2\000\00000\000Counts the number of offcore outstanding Code Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1774107 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,period=2000003,umask=0x1\000\00000\000Counts the number of offcore outstanding Demand Data Read transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor. See the corresponding Umask under OFFCORE_REQUESTS.Note: A prefetch promoted to Demand is counted from the promotion point\000 */
{ 1776411 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1777863 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore, every cycle\000event=0x60,period=2000003,umask=0x4\000\00000\000Counts the number of offcore outstanding RFO (store) transactions in the super queue (SQ) every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 2459789 }, /* offcore_response\000\000cache\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000event=0xb7,period=100003,umask=0x1\000\00000\000Offcore response can be programmed only with a specific pair of event select and counter MSR, and with specific event codes and predefine mask bit value in a dedicated MSR to specify attributes of the offcore transaction\000 */
{ 1784520 }, /* offcore_response.all_data_rd.any_response\000\000cache\000Counts all demand & prefetch data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10491\000\00000\000\000 */
{ 1785032 }, /* offcore_response.all_data_rd.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0491\000\00000\000\000 */
{ 1786045 }, /* offcore_response.all_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0491\000\00000\000\000 */
{ 1786816 }, /* offcore_response.all_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0491\000\00000\000\000 */
{ 1787300 }, /* offcore_response.all_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand & prefetch data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0491\000\00000\000\000 */
{ 1787980 }, /* offcore_response.all_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0491\000\00000\000\000 */
{ 1818809 }, /* offcore_response.all_pf_data_rd.any_response\000\000cache\000Counts all prefetch data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10490\000\00000\000\000 */
{ 1819169 }, /* offcore_response.all_pf_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0490\000\00000\000\000 */
{ 1819913 }, /* offcore_response.all_pf_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0490\000\00000\000\000 */
{ 1820413 }, /* offcore_response.all_pf_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0490\000\00000\000\000 */
{ 1820897 }, /* offcore_response.all_pf_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0490\000\00000\000\000 */
{ 1821571 }, /* offcore_response.all_pf_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_PF_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0490\000\00000\000\000 */
{ 1843508 }, /* offcore_response.all_pf_rfo.any_response\000\000cache\000Counts prefetch RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10120\000\00000\000\000 */
{ 1843846 }, /* offcore_response.all_pf_rfo.l3_hit.any_snoop\000\000cache\000Counts prefetch RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0120\000\00000\000\000 */
{ 1844546 }, /* offcore_response.all_pf_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0120\000\00000\000\000 */
{ 1845024 }, /* offcore_response.all_pf_rfo.l3_hit.hitm_other_core\000\000cache\000Counts prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0120\000\00000\000\000 */
{ 1845486 }, /* offcore_response.all_pf_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0120\000\00000\000\000 */
{ 1846124 }, /* offcore_response.all_pf_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_PF_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0120\000\00000\000\000 */
{ 1889628 }, /* offcore_response.all_rfo.any_response\000\000cache\000Counts all demand & prefetch RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10122\000\00000\000\000 */
{ 1890273 }, /* offcore_response.all_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0122\000\00000\000\000 */
{ 1891240 }, /* offcore_response.all_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0122\000\00000\000\000 */
{ 1891983 }, /* offcore_response.all_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0122\000\00000\000\000 */
{ 1892449 }, /* offcore_response.all_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand & prefetch RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0122\000\00000\000\000 */
{ 1893101 }, /* offcore_response.all_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.ALL_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0122\000\00000\000\000 */
{ 2025600 }, /* offcore_response.demand_code_rd.any_response\000\000cache\000Counts all demand code reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 2034975 }, /* offcore_response.demand_code_rd.l3_hit.any_snoop\000\000cache\000Counts all demand code reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0004\000\00000\000\000 */
{ 2036126 }, /* offcore_response.demand_code_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand code reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 2036887 }, /* offcore_response.demand_code_rd.l3_hit.hitm_other_core\000\000cache\000Counts all demand code reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 2037369 }, /* offcore_response.demand_code_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all demand code reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 2038195 }, /* offcore_response.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_CODE_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000 */
{ 2080650 }, /* offcore_response.demand_data_rd.any_response\000\000cache\000Counts demand data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 2088897 }, /* offcore_response.demand_data_rd.l3_hit.any_snoop\000\000cache\000Counts demand data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0001\000\00000\000\000 */
{ 2090032 }, /* offcore_response.demand_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts demand data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 2090785 }, /* offcore_response.demand_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts demand data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 2091263 }, /* offcore_response.demand_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts demand data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 2092077 }, /* offcore_response.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 2137751 }, /* offcore_response.demand_rfo.any_response\000\000cache\000Counts all demand data writes (RFOs) that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 2147667 }, /* offcore_response.demand_rfo.l3_hit.any_snoop\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0002\000\00000\000\000 */
{ 2148818 }, /* offcore_response.demand_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 2149579 }, /* offcore_response.demand_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 2150057 }, /* offcore_response.demand_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all demand data writes (RFOs) that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 2150887 }, /* offcore_response.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000 */
{ 2270792 }, /* offcore_response.pf_l1d_and_sw.any_response\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 2271197 }, /* offcore_response.pf_l1d_and_sw.l3_hit.any_snoop\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0400\000\00000\000\000 */
{ 2271832 }, /* offcore_response.pf_l1d_and_sw.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0400\000\00000\000\000 */
{ 2272377 }, /* offcore_response.pf_l1d_and_sw.l3_hit.hitm_other_core\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000 */
{ 2272906 }, /* offcore_response.pf_l1d_and_sw.l3_hit.no_snoop_needed\000\000cache\000Counts L1 data cache hardware prefetch requests and software prefetch requests that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0400\000\00000\000\000 */
{ 2273467 }, /* offcore_response.pf_l1d_and_sw.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L1D_AND_SW.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0400\000\00000\000\000 */
{ 2302435 }, /* offcore_response.pf_l2_data_rd.any_response\000\000cache\000Counts prefetch (that bring data to L2) data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 2307878 }, /* offcore_response.pf_l2_data_rd.l3_hit.any_snoop\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0010\000\00000\000\000 */
{ 2308656 }, /* offcore_response.pf_l2_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 2309173 }, /* offcore_response.pf_l2_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 2309674 }, /* offcore_response.pf_l2_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts prefetch (that bring data to L2) data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 2310384 }, /* offcore_response.pf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L2_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000 */
{ 2335411 }, /* offcore_response.pf_l2_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 2344482 }, /* offcore_response.pf_l2_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0020\000\00000\000\000 */
{ 2345232 }, /* offcore_response.pf_l2_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 2345735 }, /* offcore_response.pf_l2_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 2346222 }, /* offcore_response.pf_l2_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to L2) RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 2346912 }, /* offcore_response.pf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L2_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000 */
{ 2375752 }, /* offcore_response.pf_l3_data_rd.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10080\000\00000\000\000 */
{ 2376337 }, /* offcore_response.pf_l3_data_rd.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0080\000\00000\000\000 */
{ 2377135 }, /* offcore_response.pf_l3_data_rd.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0080\000\00000\000\000 */
{ 2377662 }, /* offcore_response.pf_l3_data_rd.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0080\000\00000\000\000 */
{ 2378173 }, /* offcore_response.pf_l3_data_rd.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) data reads that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0080\000\00000\000\000 */
{ 2378903 }, /* offcore_response.pf_l3_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L3_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0080\000\00000\000\000 */
{ 2399951 }, /* offcore_response.pf_l3_rfo.any_response\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that have any response type\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10100\000\00000\000\000 */
{ 2400508 }, /* offcore_response.pf_l3_rfo.l3_hit.any_snoop\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3F803C0100\000\00000\000\000 */
{ 2401270 }, /* offcore_response.pf_l3_rfo.l3_hit.hit_other_core_no_fwd\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0100\000\00000\000\000 */
{ 2401779 }, /* offcore_response.pf_l3_rfo.l3_hit.hitm_other_core\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and the snoop to one of the sibling cores hits the line in M state and the line is forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0100\000\00000\000\000 */
{ 2402272 }, /* offcore_response.pf_l3_rfo.l3_hit.no_snoop_needed\000\000cache\000Counts all prefetch (that bring data to LLC only) RFOs that hit in the L3 and sibling core snoops are not needed as either the core-valid bit is not set or the shared line is present in multiple cores\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0100\000\00000\000\000 */
{ 2402974 }, /* offcore_response.pf_l3_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000OFFCORE_RESPONSE.PF_L3_RFO.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0100\000\00000\000\000 */
{ 2531664 }, /* sq_misc.split_lock\000\000cache\000Number of cache line split locks sent to uncore\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the number of cache line split locks sent to the uncore\000 */
{ 2537304 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=2000003,umask=0x1\000\00000\000\000 */
{ 2537950 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=2000003,umask=0x8\000\00000\000\000 */
{ 2538599 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=2000003,umask=0x2\000\00000\000\000 */
{ 2539263 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=2000003,umask=0x4\000\00000\000\000 */
{ 855448 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x4\000\00000\000Counts once for most SIMD 128-bit packed computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 858464 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Counts once for most SIMD 128-bit packed computational single precision floating-point instruction retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x8\000\00000\000Counts once for most SIMD 128-bit packed computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 863684 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x10\000\00000\000Counts once for most SIMD 256-bit packed double computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 867763 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x20\000\00000\000Counts once for most SIMD 256-bit packed single computational precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 870832 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 876819 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 880047 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=2000003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 882208 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=1000003,umask=0x18\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 885571 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Counts once for most SIMD scalar computational floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x3\000\00000\000Counts once for most SIMD scalar computational single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 891206 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts once for most SIMD scalar computational double precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x1\000\00000\000Counts once for most SIMD scalar computational double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 894912 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts once for most SIMD scalar computational single precision floating-point instructions retired. Counts twice for DPP and FM(N)ADD/SUB instructions retired\000event=0xc7,period=2000003,umask=0x2\000\00000\000Counts once for most SIMD scalar computational single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SIMD scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898587 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=2000003,umask=0xfc\000\00000\000\000 */
{ 901772 }, /* fp_assist.any\000\000floating point\000Cycles with any input/output SSE or FP assist\000event=0xca,cmask=1,period=100003,umask=0x1e\000\00000\000Counts cycles with any input and output SSE or x87 FP assist. If an input and output assist are detected on the same cycle the event increments by 1\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775088 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781493 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switches\000event=0xab,period=2000003,umask=0x1\000\00000\000This event counts the number of the Decode Stream Buffer (DSB)-to-MITE switches including all misses because of missing Decode Stream Buffer (DSB) cache and u-arch forced misses.\nNote: Invoking MITE requires two or three cycles delay\000 */
{ 782928 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles\000event=0xab,period=2000003,umask=0x2\000\00000\000Counts Decode Stream Buffer (DSB)-to-MITE switch true penalty cycles. These cycles do not include uops routed through because of the switch itself, for example, when Instruction Decode Queue (IDQ) pre-allocation is unavailable, or Instruction Decode Queue (IDQ) is full. SBD-to-MITE switch true penalty cycles happen after the merge mux (MM) receives Decode Stream Buffer (DSB) Sync-indication until receiving the first MITE uop. MM is placed before Instruction Decode Queue (IDQ) to merge uops being fed from the MITE and Decode Stream Buffer (DSB) paths. Decode Stream Buffer (DSB) inserts the Sync-indication whenever a Decode Stream Buffer (DSB)-to-MITE switch occurs.Penalty: A Decode Stream Buffer (DSB) hit followed by a Decode Stream Buffer (DSB) miss can cost up to six cycles in which no uops are delivered to the IDQ. Most often, such switches from the Decode Stream Buffer (DSB) to the legacy pipeline cost 02 cycles\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943451 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000\000 */
{ 944466 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000\000 */
{ 949483 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Must be precise)\000event=0xc6,period=100007,umask=0x1,frontend=0x400106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Must be precise)\000 */
{ 944927 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x408006\000\00000\000\000 */
{ 947148 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x401006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 954352 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400206\000\00000\000\000 */
{ 951387 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x410006\000\00000\000\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 957056 }, /* frontend_retired.latency_ge_2_bubbles_ge_2\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 2 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x200206\000\00000\000\000 */
{ 957358 }, /* frontend_retired.latency_ge_2_bubbles_ge_3\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 3 bubble-slots for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x300206\000\00000\000\000 */
{ 957660 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x402006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 959995 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400406\000\00000\000\000 */
{ 962188 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x420006\000\00000\000\000 */
{ 964409 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x404006\000\00000\000\000 */
{ 966616 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x400806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992891 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss\000event=0x80,period=2000003,umask=0x4\000\00000\000Cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity\000 */
{ 993527 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000\000 */
{ 994068 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000\000 */
{ 994568 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 996552 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000\000 */
{ 997882 }, /* idq.all_dsb_cycles_4_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.DSB_CYCLES_OK]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_OK]\000 */
{ 998944 }, /* idq.all_dsb_cycles_any_uops\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.DSB_CYCLES_ANY]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.DSB_CYCLES_ANY]\000 */
{ 1000200 }, /* idq.all_mite_cycles_4_uops\000\000frontend\000Cycles MITE is delivering 4 Uops\000event=0x79,cmask=4,period=2000003,umask=0x24\000\00000\000Counts the number of cycles 4 uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1001450 }, /* idq.all_mite_cycles_any_uops\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x24\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. Counting includes uops that may 'bypass' the IDQ. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1002331 }, /* idq.dsb_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from Decode Stream Buffer (DSB) path\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1003527 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000event=0x79,cmask=1,period=2000003,umask=0x18\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_ANY_UOPS]\000 */
{ 1005201 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering 4 Uops [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000event=0x79,cmask=4,period=2000003,umask=0x18\000\00000\000Counts the number of cycles 4 uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Count includes uops that may 'bypass' the IDQ. [This event is alias to IDQ.ALL_DSB_CYCLES_4_UOPS]\000 */
{ 1005996 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1009115 }, /* idq.mite_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1011962 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. Counting includes uops that may 'bypass' the IDQ. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1013663 }, /* idq.ms_cycles\000\000frontend\000Cycles when uops are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1017722 }, /* idq.ms_dsb_cycles\000\000frontend\000Cycles when uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,cmask=1,period=2000003,umask=0x10\000\00000\000Counts cycles during which uops initiated by Decode Stream Buffer (DSB) are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1022226 }, /* idq.ms_mite_uops\000\000frontend\000Uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x20\000\00000\000Counts the number of uops initiated by MITE and delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Counting includes uops that may 'bypass' the IDQ\000 */
{ 1023696 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000event=0x79,cmask=1,edge=1,period=2000003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025427 }, /* idq.ms_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) while Microcode Sequencer (MS) is busy\000event=0x79,period=2000003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1031951 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered to Resource Allocation Table (RAT) per thread when backend of the machine is not stalled\000event=0x9c,period=2000003,umask=0x1\000\00000\000Counts the number of uops not delivered to Resource Allocation Table (RAT) per thread adding 4  x when Resource Allocation Table (RAT) is not stalled and Instruction Decode Queue (IDQ) delivers x uops to Resource Allocation Table (RAT) (where x belongs to {0,1,2,3}). Counting does not cover cases when: a. IDQ-Resource Allocation Table (RAT) pipe serves the other thread. b. Resource Allocation Table (RAT) is stalled for the thread (including uop drops and clear BE conditions).  c. Instruction Decode Queue (IDQ) delivers four uops\000 */
{ 1034288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles per thread when 4 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=4,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when no uops are delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core =4\000 */
{ 1036763 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Counts cycles FE delivered 4 uops or Resource Allocation Table (RAT) was stalling FE\000event=0x9c,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1038295 }, /* idq_uops_not_delivered.cycles_le_1_uop_deliv.core\000\000frontend\000Cycles per thread when 3 or more uops are not delivered to Resource Allocation Table (RAT) when backend of the machine is not stalled\000event=0x9c,cmask=3,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles when less than 1 uop is delivered to Resource Allocation Table (RAT). IDQ_Uops_Not_Delivered.core >= 3\000 */
{ 1039505 }, /* idq_uops_not_delivered.cycles_le_2_uop_deliv.core\000\000frontend\000Cycles with less than 2 uops delivered by the front end\000event=0x9c,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles with less than 2 uops delivered by the front-end\000 */
{ 1040076 }, /* idq_uops_not_delivered.cycles_le_3_uop_deliv.core\000\000frontend\000Cycles with less than 3 uops delivered by the front end\000event=0x9c,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles with less than 3 uops delivered by the front-end\000 */
{ 751900 }, /* cycle_activity.cycles_l3_miss\000\000memory\000Cycles while L3 cache miss demand load is outstanding\000event=0xa3,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 757696 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=2000003,umask=0x6\000\00000\000\000 */
{ 970825 }, /* hle_retired.aborted\000\000memory\000Number of times an HLE execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc8,period=2000003,umask=0x4\000\00000\000Number of times HLE abort was triggered (Precise event)\000 */
{ 971725 }, /* hle_retired.aborted_events\000\000memory\000Number of times an HLE execution aborted due to unfriendly events (such as interrupts)\000event=0xc8,period=2000003,umask=0x80\000\00000\000\000 */
{ 972195 }, /* hle_retired.aborted_mem\000\000memory\000Number of times an HLE execution aborted due to various memory events (e.g., read/write capacity and conflicts)\000event=0xc8,period=2000003,umask=0x8\000\00000\000\000 */
{ 972380 }, /* hle_retired.aborted_memtype\000\000memory\000Number of times an HLE execution aborted due to incompatible memory type\000event=0xc8,period=2000003,umask=0x40\000\00000\000Number of times an HLE execution aborted due to incompatible memory type\000 */
{ 974679 }, /* hle_retired.aborted_timer\000\000memory\000Number of times an HLE execution aborted due to hardware timer expiration\000event=0xc8,period=2000003,umask=0x10\000\00000\000\000 */
{ 975183 }, /* hle_retired.aborted_unfriendly\000\000memory\000Number of times an HLE execution aborted due to HLE-unfriendly instructions and certain unfriendly events (such as AD assists etc.)\000event=0xc8,period=2000003,umask=0x20\000\00000\000\000 */
{ 975707 }, /* hle_retired.commit\000\000memory\000Number of times an HLE execution successfully committed\000event=0xc8,period=2000003,umask=0x2\000\00000\000Number of times HLE commit succeeded\000 */
{ 976185 }, /* hle_retired.start\000\000memory\000Number of times an HLE execution started\000event=0xc8,period=2000003,umask=0x1\000\00000\000Number of times we entered an HLE region. Does not count nested transactions\000 */
{ 1293986 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory order conflicts  Spec update: SKL089\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of memory ordering Machine Clears detected. Memory Ordering Machine Clears can result from one of the following:a. memory disambiguation,b. external snoop, orc. cross SMT-HW-thread snoop (stores) hitting load buffer  Spec update: SKL089\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1752561 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Demand Data Read requests who miss L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000Demand Data Read requests who miss L3 cache\000 */
{ 1768551 }, /* offcore_requests_outstanding.cycles_with_l3_miss_demand_data_rd\000\000memory\000Cycles with at least 1 Demand Data Read requests who miss L3 cache in the superQ\000event=0x60,cmask=1,period=2000003,umask=0x10\000\00000\000\000 */
{ 1778719 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd\000\000memory\000Counts number of Offcore outstanding Demand Data Read requests that miss L3 cache in the superQ every cycle\000event=0x60,period=2000003,umask=0x10\000\00000\000\000 */
{ 1780659 }, /* offcore_requests_outstanding.l3_miss_demand_data_rd_ge_6\000\000memory\000Cycles with at least 6 Demand Data Read requests that miss L3 cache in the superQ\000event=0x60,cmask=6,period=2000003,umask=0x10\000\00000\000\000 */
{ 1795603 }, /* offcore_response.all_data_rd.l3_miss.any_snoop\000\000memory\000Counts all demand & prefetch data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000491\000\00000\000\000 */
{ 1797054 }, /* offcore_response.all_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00491\000\00000\000\000 */
{ 1797513 }, /* offcore_response.all_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00491\000\00000\000\000 */
{ 1798476 }, /* offcore_response.all_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00491\000\00000\000\000 */
{ 1801319 }, /* offcore_response.all_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000491\000\00000\000\000 */
{ 1802544 }, /* offcore_response.all_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800491\000\00000\000\000 */
{ 1829178 }, /* offcore_response.all_pf_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000490\000\00000\000\000 */
{ 1830440 }, /* offcore_response.all_pf_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00490\000\00000\000\000 */
{ 1830899 }, /* offcore_response.all_pf_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00490\000\00000\000\000 */
{ 1831856 }, /* offcore_response.all_pf_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00490\000\00000\000\000 */
{ 1834699 }, /* offcore_response.all_pf_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000490\000\00000\000\000 */
{ 1835912 }, /* offcore_response.all_pf_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800490\000\00000\000\000 */
{ 1853405 }, /* offcore_response.all_pf_rfo.l3_miss.any_snoop\000\000memory\000Counts prefetch RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000120\000\00000\000\000 */
{ 1854613 }, /* offcore_response.all_pf_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00120\000\00000\000\000 */
{ 1855050 }, /* offcore_response.all_pf_rfo.l3_miss.remote_hitm\000\000memory\000Counts prefetch RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00120\000\00000\000\000 */
{ 1855949 }, /* offcore_response.all_pf_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00120\000\00000\000\000 */
{ 1858638 }, /* offcore_response.all_pf_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000120\000\00000\000\000 */
{ 1859779 }, /* offcore_response.all_pf_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800120\000\00000\000\000 */
{ 1900408 }, /* offcore_response.all_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand & prefetch RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000122\000\00000\000\000 */
{ 1901799 }, /* offcore_response.all_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00122\000\00000\000\000 */
{ 1902240 }, /* offcore_response.all_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00122\000\00000\000\000 */
{ 1903157 }, /* offcore_response.all_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00122\000\00000\000\000 */
{ 1905874 }, /* offcore_response.all_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000122\000\00000\000\000 */
{ 1907043 }, /* offcore_response.all_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand & prefetch RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800122\000\00000\000\000 */
{ 2050560 }, /* offcore_response.demand_code_rd.l3_miss.any_snoop\000\000memory\000Counts all demand code reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000004\000\00000\000\000 */
{ 2052177 }, /* offcore_response.demand_code_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all demand code reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00004\000\00000\000\000 */
{ 2052634 }, /* offcore_response.demand_code_rd.l3_miss.remote_hitm\000\000memory\000Counts all demand code reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00004\000\00000\000\000 */
{ 2054048 }, /* offcore_response.demand_code_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00004\000\00000\000\000 */
{ 2057654 }, /* offcore_response.demand_code_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000004\000\00000\000\000 */
{ 2059018 }, /* offcore_response.demand_code_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand code reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800004\000\00000\000\000 */
{ 2104298 }, /* offcore_response.demand_data_rd.l3_miss.any_snoop\000\000memory\000Counts demand data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000001\000\00000\000\000 */
{ 2105903 }, /* offcore_response.demand_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts demand data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00001\000\00000\000\000 */
{ 2106356 }, /* offcore_response.demand_data_rd.l3_miss.remote_hitm\000\000memory\000Counts demand data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00001\000\00000\000\000 */
{ 2107746 }, /* offcore_response.demand_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00001\000\00000\000\000 */
{ 2111304 }, /* offcore_response.demand_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000001\000\00000\000\000 */
{ 2112648 }, /* offcore_response.demand_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts demand data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800001\000\00000\000\000 */
{ 2163140 }, /* offcore_response.demand_rfo.l3_miss.any_snoop\000\000memory\000Counts all demand data writes (RFOs) that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000002\000\00000\000\000 */
{ 2164729 }, /* offcore_response.demand_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00002\000\00000\000\000 */
{ 2165182 }, /* offcore_response.demand_rfo.l3_miss.remote_hitm\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00002\000\00000\000\000 */
{ 2166604 }, /* offcore_response.demand_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00002\000\00000\000\000 */
{ 2170202 }, /* offcore_response.demand_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000002\000\00000\000\000 */
{ 2171570 }, /* offcore_response.demand_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all demand data writes (RFOs) that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800002\000\00000\000\000 */
{ 2280238 }, /* offcore_response.pf_l1d_and_sw.l3_miss.any_snoop\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000400\000\00000\000\000 */
{ 2281537 }, /* offcore_response.pf_l1d_and_sw.l3_miss.remote_hit_forward\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00400\000\00000\000\000 */
{ 2282041 }, /* offcore_response.pf_l1d_and_sw.l3_miss.remote_hitm\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00400\000\00000\000\000 */
{ 2282727 }, /* offcore_response.pf_l1d_and_sw.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00400\000\00000\000\000 */
{ 2284623 }, /* offcore_response.pf_l1d_and_sw.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000400\000\00000\000\000 */
{ 2285374 }, /* offcore_response.pf_l1d_and_sw.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts L1 data cache hardware prefetch requests and software prefetch requests that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800400\000\00000\000\000 */
{ 2318213 }, /* offcore_response.pf_l2_data_rd.l3_miss.any_snoop\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000010\000\00000\000\000 */
{ 2319484 }, /* offcore_response.pf_l2_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00010\000\00000\000\000 */
{ 2319960 }, /* offcore_response.pf_l2_data_rd.l3_miss.remote_hitm\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00010\000\00000\000\000 */
{ 2320970 }, /* offcore_response.pf_l2_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00010\000\00000\000\000 */
{ 2323932 }, /* offcore_response.pf_l2_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000010\000\00000\000\000 */
{ 2325217 }, /* offcore_response.pf_l2_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts prefetch (that bring data to L2) data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800010\000\00000\000\000 */
{ 2354449 }, /* offcore_response.pf_l2_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000020\000\00000\000\000 */
{ 2355674 }, /* offcore_response.pf_l2_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00020\000\00000\000\000 */
{ 2356136 }, /* offcore_response.pf_l2_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00020\000\00000\000\000 */
{ 2357112 }, /* offcore_response.pf_l2_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00020\000\00000\000\000 */
{ 2359976 }, /* offcore_response.pf_l2_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000020\000\00000\000\000 */
{ 2361221 }, /* offcore_response.pf_l2_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to L2) RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800020\000\00000\000\000 */
{ 2386792 }, /* offcore_response.pf_l3_data_rd.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000080\000\00000\000\000 */
{ 2388073 }, /* offcore_response.pf_l3_data_rd.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00080\000\00000\000\000 */
{ 2388559 }, /* offcore_response.pf_l3_data_rd.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00080\000\00000\000\000 */
{ 2389599 }, /* offcore_response.pf_l3_data_rd.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00080\000\00000\000\000 */
{ 2392631 }, /* offcore_response.pf_l3_data_rd.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000080\000\00000\000\000 */
{ 2393956 }, /* offcore_response.pf_l3_data_rd.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) data reads that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800080\000\00000\000\000 */
{ 2410547 }, /* offcore_response.pf_l3_rfo.l3_miss.any_snoop\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss in the L3\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3FBC000100\000\00000\000\000 */
{ 2411778 }, /* offcore_response.pf_l3_rfo.l3_miss.remote_hit_forward\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and clean or shared data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x83FC00100\000\00000\000\000 */
{ 2412246 }, /* offcore_response.pf_l3_rfo.l3_miss.remote_hitm\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the modified data is transferred from remote cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x103FC00100\000\00000\000\000 */
{ 2413240 }, /* offcore_response.pf_l3_rfo.l3_miss.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from local or remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63FC00100\000\00000\000\000 */
{ 2416146 }, /* offcore_response.pf_l3_rfo.l3_miss_local_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from local dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x604000100\000\00000\000\000 */
{ 2417415 }, /* offcore_response.pf_l3_rfo.l3_miss_remote_dram.snoop_miss_or_no_fwd\000\000memory\000Counts all prefetch (that bring data to LLC only) RFOs that miss the L3 and the data is returned from remote dram\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x63B800100\000\00000\000\000 */
{ 2514787 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted due to any reasons (multiple categories may count as one) (Precise event)\000event=0xc9,period=2000003,umask=0x4\000\00000\000Number of times RTM abort was triggered (Precise event)\000 */
{ 2515653 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=2000003,umask=0x80\000\00000\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2516231 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=2000003,umask=0x8\000\00000\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516758 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=2000003,umask=0x40\000\00000\000Number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519252 }, /* rtm_retired.aborted_timer\000\000memory\000Number of times an RTM execution aborted due to uncommon conditions\000event=0xc9,period=2000003,umask=0x10\000\00000\000\000 */
{ 2519638 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=2000003,umask=0x20\000\00000\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520181 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=2000003,umask=0x2\000\00000\000Number of times RTM commit succeeded\000 */
{ 2520659 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=2000003,umask=0x1\000\00000\000Number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2571414 }, /* tx_exec.misc1\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed. Since this is the count of execution, it may not always cause a transactional abort\000event=0x5d,period=2000003,umask=0x1\000\00000\000\000 */
{ 2571935 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions (e.g., vzeroupper) that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=2000003,umask=0x2\000\00000\000Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2572677 }, /* tx_exec.misc3\000\000memory\000Counts the number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=2000003,umask=0x4\000\00000\000Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2573326 }, /* tx_exec.misc4\000\000memory\000Counts the number of times a XBEGIN instruction was executed inside an HLE transactional region\000event=0x5d,period=2000003,umask=0x8\000\00000\000RTM region detected inside HLE\000 */
{ 2573674 }, /* tx_exec.misc5\000\000memory\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000event=0x5d,period=2000003,umask=0x10\000\00000\000Counts the number of times an HLE XACQUIRE instruction was executed inside an RTM transactional region\000 */
{ 2574110 }, /* tx_mem.abort_capacity\000\000memory\000Number of times a transactional abort was signaled due to a data capacity limitation for transactional reads or writes\000event=0x54,period=2000003,umask=0x2\000\00000\000\000 */
{ 2575819 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=2000003,umask=0x1\000\00000\000Number of times a TSX line had a cache conflict\000 */
{ 2576852 }, /* tx_mem.abort_hle_elision_buffer_mismatch\000\000memory\000Number of times an HLE transactional execution aborted due to XRELEASE lock not satisfying the address and value requirements in the elision buffer\000event=0x54,period=2000003,umask=0x10\000\00000\000Number of times a TSX Abort was triggered due to release/commit but data and address mismatch\000 */
{ 2577961 }, /* tx_mem.abort_hle_elision_buffer_not_empty\000\000memory\000Number of times an HLE transactional execution aborted due to NoAllocatedElisionBuffer being non-zero\000event=0x54,period=2000003,umask=0x8\000\00000\000Number of times a TSX Abort was triggered due to commit but Lock Buffer not empty\000 */
{ 2579066 }, /* tx_mem.abort_hle_elision_buffer_unsupported_alignment\000\000memory\000Number of times an HLE transactional execution aborted due to an unsupported read alignment from the elision buffer\000event=0x54,period=2000003,umask=0x20\000\00000\000Number of times a TSX Abort was triggered due to attempting an unsupported alignment from Lock Buffer\000 */
{ 2579929 }, /* tx_mem.abort_hle_store_to_elided_lock\000\000memory\000Number of times a HLE transactional region aborted due to a non XRELEASE prefixed instruction writing to an elided lock in the elision buffer\000event=0x54,period=2000003,umask=0x4\000\00000\000Number of times a TSX Abort was triggered due to a non-release/commit store to lock\000 */
{ 2580950 }, /* tx_mem.hle_elision_buffer_full\000\000memory\000Number of times HLE lock could not be elided due to ElisionBufferAvailable being zero\000event=0x54,period=2000003,umask=0x40\000\00000\000Number of times we could not allocate Lock Buffer\000 */
{ 571949 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 572666 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573399 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server michroarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 574130 }, /* core_power.throttle\000\000other\000Core cycles the core was throttled due to a pending power level request\000event=0x28,period=200003,umask=0x40\000\00000\000Core cycles the out-of-order engine was throttled due to a pending power level request\000 */
{ 578999 }, /* core_snoop_response.rsp_ifwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDFE\000event=0xef,period=2000003,umask=0x20\000\00000\000\000 */
{ 579110 }, /* core_snoop_response.rsp_ifwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_IFWDM\000event=0xef,period=2000003,umask=0x10\000\00000\000\000 */
{ 579219 }, /* core_snoop_response.rsp_ihitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITFSE\000event=0xef,period=2000003,umask=0x2\000\00000\000\000 */
{ 579331 }, /* core_snoop_response.rsp_ihiti\000\000other\000CORE_SNOOP_RESPONSE.RSP_IHITI\000event=0xef,period=2000003,umask=0x1\000\00000\000\000 */
{ 579439 }, /* core_snoop_response.rsp_sfwdfe\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDFE\000event=0xef,period=2000003,umask=0x40\000\00000\000\000 */
{ 579550 }, /* core_snoop_response.rsp_sfwdm\000\000other\000CORE_SNOOP_RESPONSE.RSP_SFWDM\000event=0xef,period=2000003,umask=0x8\000\00000\000\000 */
{ 579658 }, /* core_snoop_response.rsp_shitfse\000\000other\000CORE_SNOOP_RESPONSE.RSP_SHITFSE\000event=0xef,period=2000003,umask=0x4\000\00000\000\000 */
{ 978812 }, /* hw_interrupts.received\000\000other\000Number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000Counts the number of hardware interruptions received by the processor\000 */
{ 997212 }, /* idi_misc.wb_downgrade\000\000other\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000event=0xfe,period=100003,umask=0x4\000\00000\000Counts number of cache lines that are dropped and not written back to L3 as they are deemed to be less likely to be reused shortly\000 */
{ 997542 }, /* idi_misc.wb_upgrade\000\000other\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000event=0xfe,period=100003,umask=0x2\000\00000\000Counts number of cache lines that are allocated and written back to L3 with the intention that they are more likely to be reused shortly\000 */
{ 1427308 }, /* memory_disambiguation.history_reset\000\000other\000MEMORY_DISAMBIGUATION.HISTORY_RESET\000event=0x9,period=2000003,umask=0x1\000\00000\000\000 */
{ 468073 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000event=0x14,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 496249 }, /* br_inst_retired.all_branches\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009\000\00000\000Counts all (macro) branch instructions retired  Spec update: SKL091\000 */
{ 499329 }, /* br_inst_retired.all_branches_pebs\000\000pipeline\000All (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000event=0xc4,period=400009,umask=0x4\000\00000\000This is a precise version of BR_INST_RETIRED.ALL_BRANCHES that counts all (macro) branch instructions retired  Spec update: SKL091 (Must be precise)\000 */
{ 503121 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.CONDITIONAL]  Spec update: SKL091\000 */
{ 504119 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 506277 }, /* br_inst_retired.conditional\000\000pipeline\000Conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000This event counts conditional branch instructions retired. [This event is alias to BR_INST_RETIRED.COND]  Spec update: SKL091 (Precise event)\000 */
{ 508062 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000This event counts far branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 514802 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000This event counts both direct and indirect near call instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 517512 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000This event counts return instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 518926 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired  Spec update: SKL091 (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000This event counts taken branch instructions retired  Spec update: SKL091 (Precise event)\000 */
{ 522057 }, /* br_inst_retired.not_taken\000\000pipeline\000Not taken branch instructions retired  Spec update: SKL091\000event=0xc4,period=400009,umask=0x10\000\00000\000This event counts not taken branch instructions retired  Spec update: SKL091\000 */
{ 528885 }, /* br_misp_exec.all_branches\000\000pipeline\000Speculative and retired mispredicted macro conditional branches\000event=0x89,period=200003,umask=0xff\000\00000\000This event counts both taken and not taken speculative and retired mispredicted branch instructions\000 */
{ 531080 }, /* br_misp_exec.indirect\000\000pipeline\000Speculative mispredicted indirect branches\000event=0x89,period=200003,umask=0xe4\000\00000\000Counts speculatively miss-predicted indirect branches at execution time. Counts for indirect near CALL or JMP instructions (RET excluded)\000 */
{ 536275 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted macro branch instructions retired\000event=0xc5,period=400009\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path\000 */
{ 541281 }, /* br_misp_retired.all_branches_pebs\000\000pipeline\000Mispredicted macro branch instructions retired (Must be precise)\000event=0xc5,period=400009,umask=0x4\000\00000\000This is a precise version of BR_MISP_RETIRED.ALL_BRANCHES that counts all mispredicted macro branch instructions retired (Must be precise)\000 */
{ 546575 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x1\000\00000\000This event counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 554675 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted direct and indirect near call instructions retired (Precise event)\000event=0xc5,period=400009,umask=0x2\000\00000\000Counts both taken and not taken retired mispredicted direct and indirect near calls, including both register and memory indirect (Precise event)\000 */
{ 555365 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=400009,umask=0x20\000\00000\000\000 */
{ 560165 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=100007,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 606999 }, /* cpu_clk_thread_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 607510 }, /* cpu_clk_thread_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 608492 }, /* cpu_clk_thread_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 618032 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000\000 */
{ 627594 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638353 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000\000 */
{ 639277 }, /* cpu_clk_unhalted.ref_xclk_any\000\000pipeline\000Core crystal clock cycles when at least one thread on the physical core is unhalted\000event=0x3c,any=1,period=25003,umask=0x1\000\00000\000\000 */
{ 640312 }, /* cpu_clk_unhalted.ring0_trans\000\000pipeline\000Counts when there is a transition from ring 1, 2 or 3 to ring 0\000event=0x3c,cmask=1,edge=1,period=100007\000\00000\000Counts when the Current Privilege Level (CPL) transitions from ring 1, 2 or 3 to ring 0 (Kernel)\000 */
{ 641300 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events\000 */
{ 646325 }, /* cpu_clk_unhalted.thread_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 649647 }, /* cpu_clk_unhalted.thread_p_any\000\000pipeline\000Core cycles when at least one thread on the physical core is not in halt state\000event=0x3c,any=1,period=2000003\000\00000\000\000 */
{ 748876 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=2000003,umask=0x8\000\00000\000\000 */
{ 750304 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 753037 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=2000003,umask=0x10\000\00000\000\000 */
{ 754625 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=2000003,umask=0xc\000\00000\000\000 */
{ 755963 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=2000003,umask=0x5\000\00000\000\000 */
{ 758894 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=2000003,umask=0x14\000\00000\000\000 */
{ 759312 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=2000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847925 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no outstanding load\000event=0xa6,period=2000003,umask=0x40\000\00000\000\000 */
{ 848693 }, /* exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles where no uops were executed, the Reservation Station was not empty, the Store Buffer was full and there was no outstanding load\000event=0xa6,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 1041006 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=2000003,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1047887 }, /* inst_retired.any\000\000pipeline\000Instructions retired from execution\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions retired from execution. For instructions that consist of multiple micro-ops, Counts the retirement of the last micro-op of the instruction. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter, leaving the four (eight when Hyperthreading is disabled) programmable counters available for other events. INST_RETIRED.ANY_P is counted by a programmable counter and it is an architectural performance event. Counting: Faulting executions of GETSEC/VM entry/VM Exit/MWait will not count as retired instructions\000 */
{ 1055017 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event  Spec update: SKL091, SKL044\000event=0xc0,period=2000003\000\00000\000Counts the number of instructions (EOMs) retired. Counting covers macro-fused instructions individually (that is, increments by two)  Spec update: SKL091, SKL044\000 */
{ 1057846 }, /* inst_retired.nop\000\000pipeline\000Number of all retired NOP instructions  Spec update: SKL091, SKL044 (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000\000 */
{ 1059777 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with HW to reduce effect of PEBS shadow in IP distribution  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1063267 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Number of cycles using always true condition applied to  PEBS instructions retired event  Spec update: SKL091, SKL044 (Must be precise)\000event=0xc0,cmask=10,inv=1,period=2000003,umask=0x1\000\00000\000Number of cycles using an always true condition applied to  PEBS instructions retired event. (inst_ret< 16)  Spec update: SKL091, SKL044 (Must be precise)\000 */
{ 1066130 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Cycles the issue-stage is waiting for front-end to fetch from resteered path following branch misprediction or machine clear events\000event=0xd,period=2000003,umask=0x80\000\00000\000\000 */
{ 1066904 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=2000003,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1068948 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread (e.g. misprediction or memory nuke)\000event=0xd,period=2000003,umask=0x1\000\00000\000Core cycles the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1071510 }, /* int_misc.recovery_cycles_any\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for any thread running on the physical core (e.g. misprediction or memory nuke)\000event=0xd,any=1,period=2000003,umask=0x1\000\00000\000\000 */
{ 1194460 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1202058 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts false dependencies in MOB when the partial comparison upon loose net check and dependency was resolved by the Enhanced Loose net mechanism. This may not result in high performance penalties. Loose net checks can fail when loads and stores are 4k aliased\000 */
{ 1229766 }, /* load_hit_pre.sw_pf\000\000pipeline\000Demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283301 }, /* lsd.cycles_4_uops\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_OK]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_OK]\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1284803 }, /* lsd.cycles_ok\000\000pipeline\000Cycles 4 Uops delivered by the LSD, but didn't come from the decoder. [This event is alias to LSD.CYCLES_4_UOPS]\000event=0xa8,cmask=4,period=2000003,umask=0x1\000\00000\000Counts the cycles when 4 uops are delivered by the LSD (Loop-stream detector). [This event is alias to LSD.CYCLES_4_UOPS]\000 */
{ 1286318 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1289012 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 2461899 }, /* other_assists.any\000\000pipeline\000Number of times a microcode assist is invoked by HW other than FP-assist. Examples include AD (page Access Dirty) and AVX* related assists\000event=0xc1,period=100003,umask=0x3f\000\00000\000\000 */
{ 2478166 }, /* partial_rat_stalls.scoreboard\000\000pipeline\000Cycles where the pipeline is stalled due to serializing operations\000event=0x59,period=2000003,umask=0x1\000\00000\000This event counts cycles during which the microcode scoreboard stalls happen\000 */
{ 2501367 }, /* resource_stalls.any\000\000pipeline\000Resource-related stall cycles\000event=0xa2,period=2000003,umask=0x1\000\00000\000Counts resource-related stall cycles\000 */
{ 2504559 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=2000003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2507828 }, /* rob_misc_events.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=2000003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 2508199 }, /* rob_misc_events.pause_inst\000\000pipeline\000Number of retired PAUSE instructions (that do not end up with a VMExit to the VMM; TSX aborted Instructions may be counted). This event is not supported on first SKL and KBL products\000event=0xcc,period=2000003,umask=0x40\000\00000\000\000 */
{ 2510793 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=2000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for the thread.; Note: In ST-mode, not active thread should drive 0. This is usually caused by severely costly branch mispredictions, or allocator/FE issues\000 */
{ 2512239 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate Frontend Latency Bound issues\000event=0x5e,cmask=1,edge=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to precisely locate front-end Latency Bound issues\000 */
{ 6184015 }, /* uops_dispatched_port.port_0\000\000pipeline\000Cycles per thread when uops are executed in port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6185297 }, /* uops_dispatched_port.port_1\000\000pipeline\000Cycles per thread when uops are executed in port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6186603 }, /* uops_dispatched_port.port_2\000\000pipeline\000Cycles per thread when uops are executed in port 2\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 2\000 */
{ 6187901 }, /* uops_dispatched_port.port_3\000\000pipeline\000Cycles per thread when uops are executed in port 3\000event=0xa1,period=2000003,umask=0x8\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 3\000 */
{ 6189223 }, /* uops_dispatched_port.port_4\000\000pipeline\000Cycles per thread when uops are executed in port 4\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 4\000 */
{ 6190512 }, /* uops_dispatched_port.port_5\000\000pipeline\000Cycles per thread when uops are executed in port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6191493 }, /* uops_dispatched_port.port_6\000\000pipeline\000Cycles per thread when uops are executed in port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6192140 }, /* uops_dispatched_port.port_7\000\000pipeline\000Cycles per thread when uops are executed in port 7\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 7\000 */
{ 6193333 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Number of uops executed from any thread\000 */
{ 6194626 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6195727 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000\000 */
{ 6196830 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000\000 */
{ 6197933 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000\000 */
{ 6198549 }, /* uops_executed.core_cycles_none\000\000pipeline\000Cycles with no micro-ops executed from any thread on physical core\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000\000 */
{ 6200712 }, /* uops_executed.cycles_ge_1_uop_exec\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201775 }, /* uops_executed.cycles_ge_2_uops_exec\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202848 }, /* uops_executed.cycles_ge_3_uops_exec\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203792 }, /* uops_executed.cycles_ge_4_uops_exec\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207194 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000Number of uops to be executed per-thread each cycle\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6214065 }, /* uops_issued.any\000\000pipeline\000Uops that Resource Allocation Table (RAT) issues to Reservation Station (RS)\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6218875 }, /* uops_issued.slow_lea\000\000pipeline\000Number of slow LEA uops being allocated. A uop is generally considered SlowLea if it has 3 sources (e.g. 2 sources + immediate) regardless if as a result of LEA instruction or not\000event=0xe,period=2000003,umask=0x20\000\00000\000\000 */
{ 6219530 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when Resource Allocation Table (RAT) does not issue Uops to Reservation Station (RS) for the thread\000event=0xe,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6222270 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=2000003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000 */
{ 6231140 }, /* uops_retired.macro_fused\000\000pipeline\000Number of macro-fused uops retired. (non precise)\000event=0xc2,period=2000003,umask=0x4\000\00000\000Counts the number of macro-fused uops retired. (non precise)\000 */
{ 6235584 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used\000 */
{ 6238702 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=2000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6240572 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=16,inv=1,period=2000003,umask=0x2\000\00000\000Number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2592253 }, /* unc_c_clockticks\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CLOCKTICKS. Unit: uncore_cha \000event=0\000\00011\000\000 */
{ 2593126 }, /* unc_c_fast_asserted\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_FAST_ASSERTED.HORZ. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00011\000\000 */
{ 2595531 }, /* unc_c_llc_lookup.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.ANY. Unit: uncore_cha \000event=0x34,umask=0x11\000\00011\000\000 */
{ 2597499 }, /* unc_c_llc_lookup.data_read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x3\000\00011\000\000 */
{ 2597669 }, /* unc_c_llc_lookup.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.LOCAL. Unit: uncore_cha \000event=0x34,umask=0x31\000\00011\000\000 */
{ 2600597 }, /* unc_c_llc_lookup.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE. Unit: uncore_cha \000event=0x34,umask=0x91\000\00011\000\000 */
{ 2602721 }, /* unc_c_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.REMOTE_SNOOP. Unit: uncore_cha \000event=0x34,umask=0x9\000\00011\000\000 */
{ 2604859 }, /* unc_c_llc_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.WRITE. Unit: uncore_cha \000event=0x34,umask=0x5\000\00011\000\000 */
{ 2605267 }, /* unc_c_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000 */
{ 2605663 }, /* unc_c_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000 */
{ 2606077 }, /* unc_c_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.LOCAL_ALL. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00011\000\000 */
{ 2606759 }, /* unc_c_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000 */
{ 2608101 }, /* unc_c_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000 */
{ 2608746 }, /* unc_c_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000 */
{ 2702473 }, /* unc_c_ring_src_thrtl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SRC_THRTL. Unit: uncore_cha \000event=0xa4\000\00011\000\000 */
{ 2729483 }, /* unc_c_tor_inserts.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.EVICT. Unit: uncore_cha \000event=0x35,umask=0x2\000\00011\000\000 */
{ 2731157 }, /* unc_c_tor_inserts.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.HIT. Unit: uncore_cha \000event=0x35,umask=0x10\000\00011\000\000 */
{ 2731318 }, /* unc_c_tor_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00011\000\000 */
{ 2731696 }, /* unc_c_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000 */
{ 2732036 }, /* unc_c_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000 */
{ 2732158 }, /* unc_c_tor_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000 */
{ 2732536 }, /* unc_c_tor_inserts.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_HIT. Unit: uncore_cha \000event=0x35,umask=0x11\000\00011\000\000 */
{ 2732923 }, /* unc_c_tor_inserts.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA_MISS. Unit: uncore_cha \000event=0x35,umask=0x21\000\00011\000\000 */
{ 2733318 }, /* unc_c_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000 */
{ 2733439 }, /* unc_c_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00011\000\000 */
{ 2733602 }, /* unc_c_tor_inserts.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00011\000\000 */
{ 2735882 }, /* unc_c_tor_inserts.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.MISS. Unit: uncore_cha \000event=0x35,umask=0x20\000\00011\000\000 */
{ 2749852 }, /* unc_c_tor_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00011\000\000 */
{ 2750230 }, /* unc_c_tor_inserts.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_HIT. Unit: uncore_cha \000event=0x35,umask=0x14\000\00011\000\000 */
{ 2750617 }, /* unc_c_tor_inserts.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.IO_MISS. Unit: uncore_cha \000event=0x35,umask=0x24\000\00011\000\000 */
{ 2750787 }, /* unc_c_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000 */
{ 2752328 }, /* unc_c_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000 */
{ 2752449 }, /* unc_c_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000 */
{ 2753879 }, /* unc_c_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000 */
{ 2754000 }, /* unc_c_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000 */
{ 2755950 }, /* unc_c_tor_occupancy.evict\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.EVICT. Unit: uncore_cha \000event=0x36,umask=0x2\000\00011\000\000 */
{ 2757672 }, /* unc_c_tor_occupancy.hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.HIT. Unit: uncore_cha \000event=0x36,umask=0x10\000\00011\000\000 */
{ 2757837 }, /* unc_c_tor_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00011\000\000 */
{ 2758001 }, /* unc_c_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000 */
{ 2758124 }, /* unc_c_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000 */
{ 2758248 }, /* unc_c_tor_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000 */
{ 2758412 }, /* unc_c_tor_occupancy.irq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_HIT. Unit: uncore_cha \000event=0x36,umask=0x11\000\00011\000\000 */
{ 2758584 }, /* unc_c_tor_occupancy.irq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA_MISS. Unit: uncore_cha \000event=0x36,umask=0x21\000\00011\000\000 */
{ 2759590 }, /* unc_c_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000 */
{ 2759713 }, /* unc_c_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00011\000\000 */
{ 2759880 }, /* unc_c_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00011\000\000 */
{ 2761386 }, /* unc_c_tor_occupancy.miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.MISS. Unit: uncore_cha \000event=0x36,umask=0x20\000\00011\000\000 */
{ 2775624 }, /* unc_c_tor_occupancy.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00011\000\000 */
{ 2775788 }, /* unc_c_tor_occupancy.prq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_HIT. Unit: uncore_cha \000event=0x36,umask=0x14\000\00011\000\000 */
{ 2775960 }, /* unc_c_tor_occupancy.prq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.IO_MISS. Unit: uncore_cha \000event=0x36,umask=0x24\000\00011\000\000 */
{ 2793572 }, /* unc_cha_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2793797 }, /* unc_cha_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794022 }, /* unc_cha_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794247 }, /* unc_cha_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794472 }, /* unc_cha_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2794698 }, /* unc_cha_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2798000 }, /* unc_cha_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798225 }, /* unc_cha_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798450 }, /* unc_cha_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798675 }, /* unc_cha_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2798900 }, /* unc_cha_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799126 }, /* unc_cha_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2802439 }, /* unc_cha_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2802664 }, /* unc_cha_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2802889 }, /* unc_cha_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803114 }, /* unc_cha_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803339 }, /* unc_cha_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2803565 }, /* unc_cha_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806867 }, /* unc_cha_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807092 }, /* unc_cha_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807317 }, /* unc_cha_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807542 }, /* unc_cha_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807767 }, /* unc_cha_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2807993 }, /* unc_cha_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2811306 }, /* unc_cha_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811531 }, /* unc_cha_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811756 }, /* unc_cha_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2811981 }, /* unc_cha_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812206 }, /* unc_cha_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812432 }, /* unc_cha_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815734 }, /* unc_cha_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2815959 }, /* unc_cha_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816184 }, /* unc_cha_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816409 }, /* unc_cha_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816634 }, /* unc_cha_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2816860 }, /* unc_cha_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2823249 }, /* unc_cha_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823474 }, /* unc_cha_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823699 }, /* unc_cha_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2823924 }, /* unc_cha_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824149 }, /* unc_cha_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824375 }, /* unc_cha_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827688 }, /* unc_cha_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2827917 }, /* unc_cha_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828146 }, /* unc_cha_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828375 }, /* unc_cha_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828604 }, /* unc_cha_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2828834 }, /* unc_cha_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2829596 }, /* unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the intermediate bypass\000 */
{ 2830692 }, /* unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000 */
{ 2831749 }, /* unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass; Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not.; Filter for transactions that succeeded in taking the full bypass\000 */
{ 2832341 }, /* unc_cha_clockticks\000uncore_cha\000uncore cache\000Clockticks of the uncore caching & home agent (CHA). Unit: uncore_cha \000event=0\000\00001\000Counts clockticks of the clock controlling the uncore caching and home agent (CHA)\000 */
{ 2832961 }, /* unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 2833058 }, /* unc_cha_core_pma.c1_state\000uncore_cha\000uncore cache\000Core PMA Events; C1  State. Unit: uncore_cha \000event=0x17,umask=0x1\000\00001\000\000 */
{ 2833180 }, /* unc_cha_core_pma.c1_transition\000uncore_cha\000uncore cache\000Core PMA Events; C1 Transition. Unit: uncore_cha \000event=0x17,umask=0x2\000\00001\000\000 */
{ 2833311 }, /* unc_cha_core_pma.c6_state\000uncore_cha\000uncore cache\000Core PMA Events; C6 State. Unit: uncore_cha \000event=0x17,umask=0x4\000\00001\000\000 */
{ 2833432 }, /* unc_cha_core_pma.c6_transition\000uncore_cha\000uncore cache\000Core PMA Events; C6 Transition. Unit: uncore_cha \000event=0x17,umask=0x8\000\00001\000\000 */
{ 2833563 }, /* unc_cha_core_pma.gv\000uncore_cha\000uncore cache\000Core PMA Events; GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00001\000\000 */
{ 2834469 }, /* unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2835970 }, /* unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2836689 }, /* unc_cha_core_snp.any_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Any Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2838200 }, /* unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2839703 }, /* unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2840427 }, /* unc_cha_core_snp.core_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Core Request to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x44\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2841933 }, /* unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2843423 }, /* unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2844143 }, /* unc_cha_core_snp.evict_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Eviction to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x84\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2845658 }, /* unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2847165 }, /* unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2847890 }, /* unc_cha_core_snp.ext_remote\000uncore_cha\000uncore cache\000Core Cross Snoops Issued; External Snoop to Remote Node. Unit: uncore_cha \000event=0x33,umask=0x24\000\00001\000Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2850751 }, /* unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2851249 }, /* unc_cha_dir_lookup.no_snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Not Needed. Unit: uncore_cha \000event=0x53,umask=0x2\000\00001\000Counts transactions that looked into the multi-socket cacheline Directory state, and therefore did not send a snoop because the Directory indicated it was not needed\000 */
{ 2852041 }, /* unc_cha_dir_lookup.snp\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state lookups; Snoop Needed. Unit: uncore_cha \000event=0x53,umask=0x1\000\00001\000Counts  transactions that looked into the multi-socket cacheline Directory state, and sent one or more snoops, because the Directory indicated it was needed\000 */
{ 2852809 }, /* unc_cha_dir_update.ha\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from the HA pipe. Unit: uncore_cha \000event=0x54,umask=0x1\000\00001\000Counts only multi-socket cacheline Directory state updates memory writes issued from the HA pipe. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2853605 }, /* unc_cha_dir_update.tor\000uncore_cha\000uncore cache\000Multi-socket cacheline Directory state updates; Directory Updated memory write from TOR pipe. Unit: uncore_cha \000event=0x54,umask=0x2\000\00001\000Counts only multi-socket cacheline Directory state updates due to memory writes issued from the TOR pipe which are the result of remote transaction hitting the SF/LLC and returning data Core2Core. This does not include memory write requests which are for I (Invalid) or E (Exclusive) cachelines\000 */
{ 2858937 }, /* unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_cha \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859488 }, /* unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_cha \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859736 }, /* unc_cha_fast_asserted.horz\000uncore_cha\000uncore cache\000FaST wire asserted; Horizontal. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 2859996 }, /* unc_cha_fast_asserted.vert\000uncore_cha\000uncore cache\000FaST wire asserted; Vertical. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 2860254 }, /* unc_cha_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000Read request from a remote socket which hit in the HitMe Cache to a line In the E state. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00001\000Counts read requests from a remote socket which hit in the HitME cache (used to cache the multi-socket Directory state) to a line in the E(Exclusive) state.  This includes the following read opcodes (RdCode, RdData, RdDataMigratory, RdCur, RdInv*, Inv*)\000 */
{ 2861212 }, /* unc_cha_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; Shared hit and op is RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00001\000\000 */
{ 2861703 }, /* unc_cha_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00001\000\000 */
{ 2862342 }, /* unc_cha_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000Counts Number of Hits in HitMe Cache; op is WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00001\000\000 */
{ 2863055 }, /* unc_cha_hitme_lookup.read\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is RdCode, RdData, RdDataMigratory, RdCur, RdInvOwn, RdInv, Inv*. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00001\000\000 */
{ 2863804 }, /* unc_cha_hitme_lookup.write\000uncore_cha\000uncore cache\000Counts Number of times HitMe Cache is accessed; op is WbMtoE, WbMtoI, WbPushMtoI, WbFlush, or WbMtoS. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00001\000\000 */
{ 2864533 }, /* unc_cha_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; No SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x40\000\00001\000\000 */
{ 2865243 }, /* unc_cha_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; op is RdCode, RdData, RdDataMigratory, RdCur, RdInv, Inv*. Unit: uncore_cha \000event=0x60,umask=0x80\000\00001\000\000 */
{ 2865936 }, /* unc_cha_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000Counts Number of Misses in HitMe Cache; SF/LLC HitS/F and op is RdInvOwn. Unit: uncore_cha \000event=0x60,umask=0x20\000\00001\000\000 */
{ 2866314 }, /* unc_cha_hitme_update.deallocate\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Deallocate HitME$ on Reads without RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x10\000\00001\000\000 */
{ 2866901 }, /* unc_cha_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a local request. Unit: uncore_cha \000event=0x61,umask=0x1\000\00001\000Received RspFwdI* for a local request, but converted HitME$ to SF entry\000 */
{ 2867390 }, /* unc_cha_hitme_update.rdinvown\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache on RdInvOwn even if not RspFwdI*. Unit: uncore_cha \000event=0x61,umask=0x8\000\00001\000\000 */
{ 2867974 }, /* unc_cha_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; op is RspIFwd or RspIFwdWb for a remote request. Unit: uncore_cha \000event=0x61,umask=0x2\000\00001\000Updated HitME$ on RspFwdI* or local HitM/E received for a remote request\000 */
{ 2868429 }, /* unc_cha_hitme_update.shared\000uncore_cha\000uncore cache\000Counts the number of Allocate/Update to HitMe Cache; Update HitMe Cache to SHARed. Unit: uncore_cha \000event=0x61,umask=0x4\000\00001\000\000 */
{ 2869528 }, /* unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2871320 }, /* unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2873116 }, /* unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2874913 }, /* unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2876706 }, /* unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2878494 }, /* unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2880286 }, /* unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2882079 }, /* unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2887579 }, /* unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2889369 }, /* unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2891163 }, /* unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2892958 }, /* unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2894425 }, /* unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Left. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2895578 }, /* unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use; Right. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2896137 }, /* unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000 */
{ 2896705 }, /* unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued; ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 2897239 }, /* unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued; Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to the any of the memory controller channels\000 */
{ 2897516 }, /* unc_cha_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Full Line MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2898147 }, /* unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2898782 }, /* unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2899110 }, /* unc_cha_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; Partial MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH.; Filter for memory controller 5 only\000 */
{ 2899779 }, /* unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000Writes Issued to the iMC by the HA; ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000Counts the total number of writes issued from the HA into the memory controller.  This counts for all four channels.  It can be filtered by full/partial and ISOCH/non-ISOCH\000 */
{ 2900112 }, /* unc_cha_iodc_alloc.invitom\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations. Unit: uncore_cha \000event=0x62,umask=0x1\000\00001\000\000 */
{ 2900294 }, /* unc_cha_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IODC allocations dropped due to IODC Full. Unit: uncore_cha \000event=0x62,umask=0x2\000\00001\000\000 */
{ 2900502 }, /* unc_cha_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000Counts Number of times IODC entry allocation is attempted; Number of IDOC allocation dropped due to OSB gate. Unit: uncore_cha \000event=0x62,umask=0x4\000\00001\000\000 */
{ 2900708 }, /* unc_cha_iodc_dealloc.all\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to any reason. Unit: uncore_cha \000event=0x63,umask=0x10\000\00001\000\000 */
{ 2900875 }, /* unc_cha_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to conflicting transaction. Unit: uncore_cha \000event=0x63,umask=0x8\000\00001\000\000 */
{ 2901057 }, /* unc_cha_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00001\000\000 */
{ 2901222 }, /* unc_cha_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbMtoI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00001\000\000 */
{ 2901387 }, /* unc_cha_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000Counts number of IODC deallocations; IODC deallocated due to WbPushMtoI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00001\000Moved to Cbo section\000 */
{ 2903523 }, /* unc_cha_llc_lookup.any\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x11\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2913171 }, /* unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x3\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Read transactions\000 */
{ 2928303 }, /* unc_cha_llc_lookup.local\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Local. Unit: uncore_cha \000event=0x34,umask=0x31\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000 */
{ 2950278 }, /* unc_cha_llc_lookup.remote\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Remote. Unit: uncore_cha \000event=0x34,umask=0x91\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state\000 */
{ 2955522 }, /* unc_cha_llc_lookup.remote_snoop\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; External Snoop Request. Unit: uncore_cha \000event=0x34,umask=0x9\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for only snoop requests coming from the remote socket(s) through the IPQ\000 */
{ 2968298 }, /* unc_cha_llc_lookup.write\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Write Requests. Unit: uncore_cha \000event=0x34,umask=0x5\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2972000 }, /* unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_E. Unit: uncore_cha \000event=0x37,umask=0x2\000\00011\000\000 */
{ 2972170 }, /* unc_cha_llc_victims.f_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_F. Unit: uncore_cha \000event=0x37,umask=0x8\000\00011\000\000 */
{ 2974017 }, /* unc_cha_llc_victims.local\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x37,umask=0x20\000\00011\000\000 */
{ 2974682 }, /* unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized; Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x2f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975486 }, /* unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x22\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975741 }, /* unc_cha_llc_victims.local_f\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x28\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976550 }, /* unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x21\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977625 }, /* unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized; Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x24\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2978165 }, /* unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_M. Unit: uncore_cha \000event=0x37,umask=0x1\000\00011\000\000 */
{ 2978335 }, /* unc_cha_llc_victims.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.REMOTE_ALL. Unit: uncore_cha \000event=0x37,umask=0x80\000\00011\000\000 */
{ 2979057 }, /* unc_cha_llc_victims.remote_all\000uncore_cha\000uncore cache\000Lines Victimized; Remote - All Lines. Unit: uncore_cha \000event=0x37,umask=0x8f\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2979867 }, /* unc_cha_llc_victims.remote_e\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x82\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980124 }, /* unc_cha_llc_victims.remote_f\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x88\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2980939 }, /* unc_cha_llc_victims.remote_m\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x81\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982023 }, /* unc_cha_llc_victims.remote_s\000uncore_cha\000uncore cache\000Lines Victimized; Remote - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x84\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982565 }, /* unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_VICTIMS.TOTAL_S. Unit: uncore_cha \000event=0x37,umask=0x4\000\00011\000\000 */
{ 2983001 }, /* unc_cha_llc_victims.total_e\000uncore_cha\000uncore cache\000Lines Victimized; Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2983247 }, /* unc_cha_llc_victims.total_f\000uncore_cha\000uncore cache\000Lines Victimized; Lines in F State. Unit: uncore_cha \000event=0x37,umask=0x8\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2983759 }, /* unc_cha_llc_victims.total_m\000uncore_cha\000uncore cache\000Lines Victimized; Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984271 }, /* unc_cha_llc_victims.total_s\000uncore_cha\000uncore cache\000Lines Victimized; Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984705 }, /* unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2985052 }, /* unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc; CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Miscellaneous events in the Cbo\000 */
{ 2985209 }, /* unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000 */
{ 2985815 }, /* unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc; Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2986519 }, /* unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc; Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Miscellaneous events in the Cbo.; Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2989072 }, /* unc_cha_osb\000uncore_cha\000uncore cache\000OSB Snoop Broadcast. Unit: uncore_cha \000event=0x55\000\00001\000Count of OSB snoop broadcasts. Counts by 1 per request causing OSB snoops to be broadcast. Does not count all the snoops generated by OSB\000 */
{ 3000928 }, /* unc_cha_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 2 only\000 */
{ 3001337 }, /* unc_cha_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 3 only\000 */
{ 3001746 }, /* unc_cha_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 4 only\000 */
{ 3002156 }, /* unc_cha_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 5 only\000 */
{ 3003005 }, /* unc_cha_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 0 only\000 */
{ 3005583 }, /* unc_cha_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue.; Filter for memory controller 1 only\000 */
{ 3010612 }, /* unc_cha_requests.invitoe_local\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line  without receiving data. Unit: uncore_cha \000event=0x50,umask=0x10\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3010945 }, /* unc_cha_requests.invitoe_remote\000uncore_cha\000uncore cache\000Local requests for exclusive ownership of a cache line without receiving data. Unit: uncore_cha \000event=0x50,umask=0x20\000\00001\000Counts the total number of requests coming from a remote socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3012545 }, /* unc_cha_requests.reads\000uncore_cha\000uncore cache\000Read requests. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000 */
{ 3013130 }, /* unc_cha_requests.reads_local\000uncore_cha\000uncore cache\000Read requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x1\000\00001\000Counts read requests coming from a unit on this socket made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3013437 }, /* unc_cha_requests.reads_remote\000uncore_cha\000uncore cache\000Read requests from a remote socket. Unit: uncore_cha \000event=0x50,umask=0x2\000\00001\000Counts read requests coming from a remote socket made into the CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write)\000 */
{ 3014622 }, /* unc_cha_requests.writes\000uncore_cha\000uncore cache\000Write requests. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015208 }, /* unc_cha_requests.writes_local\000uncore_cha\000uncore cache\000Write Requests from a unit on this socket. Unit: uncore_cha \000event=0x50,umask=0x4\000\00001\000Counts  write requests coming from a unit on this socket made into this CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3015517 }, /* unc_cha_requests.writes_remote\000uncore_cha\000uncore cache\000Read and Write Requests; Writes Remote. Unit: uncore_cha \000event=0x50,umask=0x8\000\00001\000Counts the total number of read requests made into the Home Agent. Reads include all read opcodes (including RFO).  Writes include all writes (streaming, evictions, HitM, etc)\000 */
{ 3016450 }, /* unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3016982 }, /* unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017514 }, /* unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018046 }, /* unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018572 }, /* unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019138 }, /* unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020000 }, /* unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020593 }, /* unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020996 }, /* unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 3021281 }, /* unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 3021596 }, /* unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 3021911 }, /* unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 3022196 }, /* unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 3022479 }, /* unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 3022782 }, /* unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 3023243 }, /* unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 3023569 }, /* unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 3023734 }, /* unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xa4\000\00001\000\000 */
{ 3024170 }, /* unc_cha_rxc_inserts.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024610 }, /* unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025072 }, /* unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025526 }, /* unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025972 }, /* unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026418 }, /* unc_cha_rxc_inserts.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3026860 }, /* unc_cha_rxc_inserts.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations; WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00001\000Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3027322 }, /* unc_cha_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00001\000\000 */
{ 3027731 }, /* unc_cha_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00001\000\000 */
{ 3028137 }, /* unc_cha_rxc_ipq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x22,umask=0x40\000\00001\000\000 */
{ 3028535 }, /* unc_cha_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00001\000\000 */
{ 3028928 }, /* unc_cha_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00001\000\000 */
{ 3029338 }, /* unc_cha_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00001\000\000 */
{ 3029745 }, /* unc_cha_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00001\000\000 */
{ 3030149 }, /* unc_cha_rxc_ipq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x22,umask=0x80\000\00001\000\000 */
{ 3030461 }, /* unc_cha_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x23,umask=0x40\000\00001\000\000 */
{ 3030858 }, /* unc_cha_rxc_ipq1_reject.any0\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00001\000\000 */
{ 3031132 }, /* unc_cha_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00001\000\000 */
{ 3031540 }, /* unc_cha_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x23,umask=0x20\000\00001\000\000 */
{ 3031893 }, /* unc_cha_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x23,umask=0x4\000\00001\000\000 */
{ 3032315 }, /* unc_cha_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x23,umask=0x80\000\00001\000\000 */
{ 3032717 }, /* unc_cha_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x23,umask=0x8\000\00001\000\000 */
{ 3033010 }, /* unc_cha_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000Ingress Probe Queue Rejects; Victim. Unit: uncore_cha \000event=0x23,umask=0x10\000\00001\000\000 */
{ 3033408 }, /* unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000\000 */
{ 3033830 }, /* unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000\000 */
{ 3034249 }, /* unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000\000 */
{ 3034660 }, /* unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000\000 */
{ 3035066 }, /* unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000\000 */
{ 3035489 }, /* unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000\000 */
{ 3035909 }, /* unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000\000 */
{ 3036326 }, /* unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000\000 */
{ 3036651 }, /* unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3037061 }, /* unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000\000 */
{ 3037348 }, /* unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000 */
{ 3037769 }, /* unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000\000 */
{ 3038135 }, /* unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000 */
{ 3038292 }, /* unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3038707 }, /* unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000\000 */
{ 3039013 }, /* unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000 */
{ 3039644 }, /* unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3040514 }, /* unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3041381 }, /* unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3042240 }, /* unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3043094 }, /* unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3043965 }, /* unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3044833 }, /* unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3045698 }, /* unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3046572 }, /* unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3047440 }, /* unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3048305 }, /* unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3049162 }, /* unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3050014 }, /* unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3050883 }, /* unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3051749 }, /* unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3052612 }, /* unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3053478 }, /* unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects; ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3054257 }, /* unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects; HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3055098 }, /* unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries; ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3055875 }, /* unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries; HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3056479 }, /* unc_cha_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3056913 }, /* unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057348 }, /* unc_cha_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057784 }, /* unc_cha_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy; WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00001\000Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3058333 }, /* unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3058941 }, /* unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3059546 }, /* unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3060143 }, /* unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3060735 }, /* unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3061344 }, /* unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3061950 }, /* unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3062553 }, /* unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063118 }, /* unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries; Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063716 }, /* unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries; ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064234 }, /* unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries; HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064841 }, /* unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3065446 }, /* unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries; LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3066067 }, /* unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3066668 }, /* unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries; SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067209 }, /* unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries; Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067456 }, /* unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3067877 }, /* unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3068299 }, /* unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000\000 */
{ 3068724 }, /* unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000\000 */
{ 3069130 }, /* unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000\000 */
{ 3069536 }, /* unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3069958 }, /* unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000\000 */
{ 3070376 }, /* unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000\000 */
{ 3070801 }, /* unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3071118 }, /* unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000\000 */
{ 3071515 }, /* unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000 */
{ 3071798 }, /* unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000\000 */
{ 3072242 }, /* unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000 */
{ 3072557 }, /* unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000\000 */
{ 3072994 }, /* unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000\000 */
{ 3073405 }, /* unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000 */
{ 3074021 }, /* unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3074551 }, /* unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3075078 }, /* unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3075597 }, /* unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3076111 }, /* unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3076642 }, /* unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3077170 }, /* unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries; BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3077695 }, /* unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries; Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078182 }, /* unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries; Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078700 }, /* unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries; ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079140 }, /* unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries; HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079669 }, /* unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080196 }, /* unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries; LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080739 }, /* unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries; PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081262 }, /* unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries; SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3081725 }, /* unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries; Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3082242 }, /* unc_cha_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3082777 }, /* unc_cha_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3083309 }, /* unc_cha_rxc_rrq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x26,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3083833 }, /* unc_cha_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3084352 }, /* unc_cha_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3084888 }, /* unc_cha_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3085421 }, /* unc_cha_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000RRQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3085951 }, /* unc_cha_rxc_rrq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000RRQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x26,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086442 }, /* unc_cha_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000RRQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x27,umask=0x40\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3086965 }, /* unc_cha_rxc_rrq1_reject.any0\000uncore_cha\000uncore cache\000RRQ Rejects; ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087409 }, /* unc_cha_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000RRQ Rejects; HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3087943 }, /* unc_cha_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000RRQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x27,umask=0x20\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3088474 }, /* unc_cha_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000RRQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x27,umask=0x4\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3089022 }, /* unc_cha_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000RRQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x27,umask=0x80\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3089550 }, /* unc_cha_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000RRQ Rejects; SF Victim. Unit: uncore_cha \000event=0x27,umask=0x8\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090017 }, /* unc_cha_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000RRQ Rejects; Victim. Unit: uncore_cha \000event=0x27,umask=0x10\000\00001\000Number of times a transaction flowing through the RRQ (Remote Response Queue) had to retry\000 */
{ 3090535 }, /* unc_cha_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD REQ on VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3091058 }, /* unc_cha_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; AD RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3091578 }, /* unc_cha_rxc_wbq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI AK Request. Unit: uncore_cha \000event=0x28,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3092090 }, /* unc_cha_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCB on VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3092597 }, /* unc_cha_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL NCS on VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3093121 }, /* unc_cha_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL RSP on VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3093642 }, /* unc_cha_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000WBQ Rejects; BL WB on VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094160 }, /* unc_cha_rxc_wbq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000WBQ Rejects; Non UPI IV Request. Unit: uncore_cha \000event=0x28,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3094639 }, /* unc_cha_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000WBQ Rejects; Allow Snoop. Unit: uncore_cha \000event=0x29,umask=0x40\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095150 }, /* unc_cha_rxc_wbq1_reject.any0\000uncore_cha\000uncore cache\000WBQ Rejects; ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3095582 }, /* unc_cha_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000WBQ Rejects; HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096104 }, /* unc_cha_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000WBQ Rejects; Merging these two together to make room for ANY_REJECT_*0. Unit: uncore_cha \000event=0x29,umask=0x20\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3096623 }, /* unc_cha_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000WBQ Rejects; LLC Victim. Unit: uncore_cha \000event=0x29,umask=0x4\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3097159 }, /* unc_cha_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000WBQ Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x29,umask=0x80\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3097675 }, /* unc_cha_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000WBQ Rejects; SF Victim. Unit: uncore_cha \000event=0x29,umask=0x8\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3098130 }, /* unc_cha_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000WBQ Rejects; Victim. Unit: uncore_cha \000event=0x29,umask=0x10\000\00001\000Number of times a transaction flowing through the WBQ (Writeback Queue) had to retry\000 */
{ 3098794 }, /* unc_cha_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3099616 }, /* unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100903 }, /* unc_cha_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3101725 }, /* unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102799 }, /* unc_cha_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3103201 }, /* unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3103807 }, /* unc_cha_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3104464 }, /* unc_cha_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3104866 }, /* unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3105472 }, /* unc_cha_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 3106120 }, /* unc_cha_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3106964 }, /* unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AD - Credit. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3108236 }, /* unc_cha_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3109102 }, /* unc_cha_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3109946 }, /* unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation; BL - Credit. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3111244 }, /* unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112060 }, /* unc_cha_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3113177 }, /* unc_cha_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3113724 }, /* unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114550 }, /* unc_cha_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115427 }, /* unc_cha_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115974 }, /* unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116800 }, /* unc_cha_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117374 }, /* unc_cha_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117935 }, /* unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118781 }, /* unc_cha_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119678 }, /* unc_cha_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120239 }, /* unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121085 }, /* unc_cha_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121340 }, /* unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3122286 }, /* unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3123230 }, /* unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores cache. Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry. Does not count clean evictions such as when a cores cache replaces a tracked cacheline with a new cacheline\000 */
{ 3124170 }, /* unc_cha_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000Rsp*Fwd*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00001\000Counts when a transaction with the opcode type Rsp*Fwd*WB Snoop Response was received which indicates the data was written back to its home socket, and the cacheline was forwarded to the requestor socket.  This snoop response is only used in >= 4 socket systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to its home socket to be written back to memory\000 */
{ 3124752 }, /* unc_cha_snoop_resp.rsp_wbwb\000uncore_cha\000uncore cache\000Rsp*WB Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00001\000Counts when a transaction with the opcode type Rsp*WB Snoop Response was received which indicates which indicates the data was written back to its home.  This is returned when a non-RFO request hits a cacheline in the Modified state. The Cache can either downgrade the cacheline to a S (Shared) or I (Invalid) state depending on how the system has been configured.  This response will also be sent when a cache requests E (Exclusive) ownership of a cache line without receiving data, because the cache must acquire ownership\000 */
{ 3126267 }, /* unc_cha_snoop_resp.rspcnflcts\000uncore_cha\000uncore cache\000RspCnflct* Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00001\000Counts when a a transaction with the opcode type RspCnflct* Snoop Response was received. This is returned when a snoop finds an existing outstanding transaction in a remote caching agent. This triggers conflict resolution hardware. This covers both the opcode RspCnflct and RspCnflctWbI\000 */
{ 3127517 }, /* unc_cha_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received; RspFwd. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00001\000Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1.; Filters for a snoop response of RspFwd to a CA request.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3129170 }, /* unc_cha_snoop_resp.rspi\000uncore_cha\000uncore cache\000RspI Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00001\000Counts when a transaction with the opcode type RspI Snoop Response was received which indicates the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO: the Read for Ownership issued before a write hits non-modified data)\000 */
{ 3129964 }, /* unc_cha_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000RspIFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00001\000Counts when a a transaction with the opcode type RspIFwd Snoop Response was received which indicates a remote caching agent forwarded the data and the requesting agent is able to acquire the data in E (Exclusive) or M (modified) states.  This is commonly returned with RFO (the Read for Ownership issued before a write) transactions.  The snoop could have either been to a cacheline in the M,E,F (Modified, Exclusive or Forward)  states\000 */
{ 3131886 }, /* unc_cha_snoop_resp.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received : RspS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00001\000Snoop Responses Received : RspS : Counts the total number of RspI snoop responses received.  Whenever a snoops are issued, one or more snoop responses will be returned depending on the topology of the system.   In systems larger than 2s, when multiple snoops are returned this will count all the snoops that are received.  For example, if 3 snoops were issued and returned RspI, RspS, and RspSFwd; then each of these sub-events would increment by 1. : Filters for snoop responses of RspS.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3132693 }, /* unc_cha_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000RspSFwd Snoop Responses Received. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00001\000Counts when a a transaction with the opcode type RspSFwd Snoop Response was received which indicates a remote caching agent forwarded the data but held on to its current copy.  This is common for data and code reads that hit in a remote socket in E (Exclusive) or F (Forward) state\000 */
{ 3134392 }, /* unc_cha_snoop_resp_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3134888 }, /* unc_cha_snoop_resp_local.rsp_wb\000uncore_cha\000uncore cache\000Snoop Responses Received Local; Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3135939 }, /* unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3136921 }, /* unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3138358 }, /* unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Number of snoop responses received for a Local  request; Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3139285 }, /* unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3140247 }, /* unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Number of snoop responses received for a Local  request; Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3141659 }, /* unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local; RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Number of snoop responses received for a Local  request; Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its current copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3143797 }, /* unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent; All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Counts the number of snoops issued by the HA\000 */
{ 3144650 }, /* unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoop for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3145670 }, /* unc_cha_snoops_sent.bcst_remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x20\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast snoops issued by the HA.This filter includes only requests coming from remote sockets\000 */
{ 3146684 }, /* unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from local sockets\000 */
{ 3147704 }, /* unc_cha_snoops_sent.direct_remote\000uncore_cha\000uncore cache\000Snoops Sent; Directed snoops for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x80\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of directed snoops issued by the HA. This filter includes only requests coming from remote sockets\000 */
{ 3148772 }, /* unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the local socket\000 */
{ 3149883 }, /* unc_cha_snoops_sent.remote\000uncore_cha\000uncore cache\000Snoops Sent; Broadcast or directed Snoops sent for Remote Requests. Unit: uncore_cha \000event=0x51,umask=0x8\000\00001\000Counts the number of snoops issued by the HA.; Counts the number of broadcast or directed snoops issued by the HA per request. This filter includes only requests coming from the remote socket\000 */
{ 3165727 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166014 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166301 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166588 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3166875 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167163 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167451 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3167738 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168025 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168312 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168599 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3168887 }, /* unc_cha_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169175 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169462 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3169749 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170036 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170323 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170611 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3170899 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171186 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171473 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3171760 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172047 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172335 }, /* unc_cha_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3173425 }, /* unc_cha_tor_inserts.all_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local. Unit: uncore_cha \000event=0x35,umask=0x15\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3173667 }, /* unc_cha_tor_inserts.all_io_ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0x35\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests\000 */
{ 3173953 }, /* unc_cha_tor_inserts.all_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local. Unit: uncore_cha \000event=0x35,umask=0x25\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3175701 }, /* unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts; SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3176586 }, /* unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts; Hit (Not a Miss). Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000 */
{ 3177630 }, /* unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts; All from Local iA. Unit: uncore_cha \000event=0x35,umask=0x31\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally initiated requests from iA Cores\000 */
{ 3183533 }, /* unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local iA. Unit: uncore_cha \000event=0x35,umask=0x11\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3183777 }, /* unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3185823 }, /* unc_cha_tor_inserts.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3190857 }, /* unc_cha_tor_inserts.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b233\000\00001\000\000 */
{ 3191894 }, /* unc_cha_tor_inserts.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b433\000\00001\000\000 */
{ 3192056 }, /* unc_cha_tor_inserts.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3193170 }, /* unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0x11,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3198531 }, /* unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3199737 }, /* unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40233\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3205429 }, /* unc_cha_tor_inserts.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Inserts : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40433\000\00001\000TOR Inserts : DRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3227466 }, /* unc_cha_tor_inserts.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b233\000\00001\000\000 */
{ 3228752 }, /* unc_cha_tor_inserts.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_INSERTS.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b433\000\00001\000\000 */
{ 3228916 }, /* unc_cha_tor_inserts.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x4b033\000\00001\000TOR Inserts : LLCPrefRFO issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3239874 }, /* unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0x21,config1=0x40033\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3259197 }, /* unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts; All from Local IO. Unit: uncore_cha \000event=0x35,umask=0x34\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; All locally generated IO traffic\000 */
{ 3260917 }, /* unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts; Hits from Local IO. Unit: uncore_cha \000event=0x35,umask=0x14\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3267820 }, /* unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts; Misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3268808 }, /* unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts; ItoM misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x49033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM request is used by IIO to request a data write without first reading the data for ownership\000 */
{ 3270884 }, /* unc_cha_tor_inserts.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Inserts; RdCur misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x43C33\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RdCur requests and miss the LLC. A RdCur request is used by IIO to read data without changing state\000 */
{ 3271655 }, /* unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts; RFO misses from Local IO. Unit: uncore_cha \000event=0x35,umask=0x24,config1=0x40033\000\00001\000Counts the number of entries successfully inserted into the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests a cache line to be cached in E state with the intent to modify\000 */
{ 3275022 }, /* unc_cha_tor_inserts.ipq\000uncore_cha\000uncore cache\000TOR Inserts; IPQ. Unit: uncore_cha \000event=0x35,umask=0x8\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3275247 }, /* unc_cha_tor_inserts.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x18\000\00011\000\000 */
{ 3275370 }, /* unc_cha_tor_inserts.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x28\000\00011\000\000 */
{ 3275494 }, /* unc_cha_tor_inserts.irq\000uncore_cha\000uncore cache\000TOR Inserts; IRQ. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3278263 }, /* unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x37\000\00011\000\000 */
{ 3281786 }, /* unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts; Miss. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000 */
{ 3286529 }, /* unc_cha_tor_inserts.prq\000uncore_cha\000uncore cache\000TOR Inserts; PRQ. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent\000 */
{ 3288384 }, /* unc_cha_tor_inserts.rem_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x30\000\00011\000\000 */
{ 3290043 }, /* unc_cha_tor_inserts.rrq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x50\000\00011\000\000 */
{ 3290166 }, /* unc_cha_tor_inserts.rrq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x60\000\00011\000\000 */
{ 3291169 }, /* unc_cha_tor_inserts.wbq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0x90\000\00011\000\000 */
{ 3291292 }, /* unc_cha_tor_inserts.wbq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x35,umask=0xa0\000\00011\000\000 */
{ 3292033 }, /* unc_cha_tor_occupancy.all_from_loc\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local. Unit: uncore_cha \000event=0x36,umask=0x37\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   There are a number of subevent 'filters' but only a subset of the subevent combinations are valid.  Subevents that require an opcode or NID match require the Cn_MSR_PMON_BOX_FILTER.{opc, nid} field to be set.  If, for example, one wanted to count DRD Local Misses, one should select MISS_OPC_MATCH and set Cn_MSR_PMON_BOX_FILTER.opc to DRD (0x182); All remotely generated requests\000 */
{ 3292681 }, /* unc_cha_tor_occupancy.all_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local. Unit: uncore_cha \000event=0x36,umask=0x17\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3292946 }, /* unc_cha_tor_occupancy.all_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local. Unit: uncore_cha \000event=0x36,umask=0x27\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3294652 }, /* unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy; SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3295606 }, /* unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hit (Not a Miss). Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; HITs (hit is defined to be not a miss [see below], as a result for any request allocated into the TOR, one of either HIT or MISS must be true)\000 */
{ 3296402 }, /* unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local iA. Unit: uncore_cha \000event=0x36,umask=0x31\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally initiated requests from iA Cores\000 */
{ 3302556 }, /* unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local iA. Unit: uncore_cha \000event=0x36,umask=0x11\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3303225 }, /* unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3305373 }, /* unc_cha_tor_occupancy.ia_hit_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3310595 }, /* unc_cha_tor_occupancy.ia_hit_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b233\000\00001\000\000 */
{ 3311466 }, /* unc_cha_tor_occupancy.ia_hit_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_HIT_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b433\000\00001\000\000 */
{ 3311632 }, /* unc_cha_tor_occupancy.ia_hit_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3312796 }, /* unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0x11,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3318170 }, /* unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local iA. Unit: uncore_cha \000event=0x36,umask=0x21\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3318440 }, /* unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40233\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3322797 }, /* unc_cha_tor_occupancy.ia_miss_drd\000uncore_cha\000uncore cache\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40433\000\00001\000TOR Occupancy : DRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3340534 }, /* unc_cha_tor_occupancy.ia_miss_llcprefcrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefCRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b233\000\00001\000\000 */
{ 3341876 }, /* unc_cha_tor_occupancy.ia_miss_llcprefdrd\000uncore_cha\000uncore cache\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_LlcPrefDRD. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b433\000\00001\000\000 */
{ 3342044 }, /* unc_cha_tor_occupancy.ia_miss_llcprefrfo\000uncore_cha\000uncore cache\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x4b033\000\00001\000TOR Occupancy : LLCPrefRFO issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3349467 }, /* unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0x21,config1=0x40033\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3362576 }, /* unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy; All from Local IO. Unit: uncore_cha \000event=0x36,umask=0x34\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; All locally generated IO traffic\000 */
{ 3364092 }, /* unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy; Hits from Local IO. Unit: uncore_cha \000event=0x36,umask=0x14\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3370079 }, /* unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy; Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3371199 }, /* unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy;  ITOM Misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x49033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO ItoM requests that miss the LLC. An ItoM is used by IIO to request a data write without first reading the data for ownership\000 */
{ 3373437 }, /* unc_cha_tor_occupancy.io_miss_rdcur\000uncore_cha\000uncore cache\000TOR Occupancy;  RDCUR misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x43C33\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RdCur requests that miss the LLC. A RdCur request is used by IIO to read data without changing state\000 */
{ 3374250 }, /* unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy;  RFO misses from Local IO. Unit: uncore_cha \000event=0x36,umask=0x24,config1=0x40033\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that are generated from local IO RFO requests that miss the LLC. A read for ownership (RFO) requests data to be cached in E state with the intent to modify\000 */
{ 3377659 }, /* unc_cha_tor_occupancy.ipq\000uncore_cha\000uncore cache\000TOR Occupancy; IPQ. Unit: uncore_cha \000event=0x36,umask=0x8\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3377907 }, /* unc_cha_tor_occupancy.ipq_hit\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x18\000\00011\000\000 */
{ 3378032 }, /* unc_cha_tor_occupancy.ipq_miss\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x36,umask=0x28\000\00011\000\000 */
{ 3378158 }, /* unc_cha_tor_occupancy.irq\000uncore_cha\000uncore cache\000TOR Occupancy; IRQ. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3381136 }, /* unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_OCCUPANCY.ALL_FROM_LOC. Unit: uncore_cha \000event=0x36,umask=0x37\000\00011\000\000 */
{ 3384949 }, /* unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy; Miss. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T; Misses.  (a miss is defined to be any transaction from the IRQ, PRQ, RRQ, IPQ or (in the victim case) the ISMQ, that required the CHA to spawn a new UPI/SMI3 request on the UPI fabric (including UPI snoops and/or any RD/WR to a local memory controller, in the event that the CHA is the home node)).  Basically, if the LLC/SF/MLC complex were not able to service the request without involving another agent...it is a miss.  If only IDI snoops were required, it is not a miss (that means the SF/MLC com\000 */
{ 3390697 }, /* unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy; PRQ. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.   T\000 */
{ 3394228 }, /* unc_cha_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3394746 }, /* unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395270 }, /* unc_cha_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395810 }, /* unc_cha_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396328 }, /* unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3397152 }, /* unc_cha_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3397659 }, /* unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398423 }, /* unc_cha_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399239 }, /* unc_cha_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399746 }, /* unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400510 }, /* unc_cha_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3401136 }, /* unc_cha_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3401821 }, /* unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402860 }, /* unc_cha_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403951 }, /* unc_cha_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3404636 }, /* unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405675 }, /* unc_cha_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3406395 }, /* unc_cha_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407101 }, /* unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_cha \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408174 }, /* unc_cha_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3409299 }, /* unc_cha_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_cha \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410005 }, /* unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_cha \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411078 }, /* unc_cha_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_cha \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411773 }, /* unc_cha_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3412431 }, /* unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_cha \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413423 }, /* unc_cha_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3414467 }, /* unc_cha_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_cha \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415125 }, /* unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_cha \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416117 }, /* unc_cha_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_cha \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416695 }, /* unc_cha_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417153 }, /* unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_cha \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417844 }, /* unc_cha_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418586 }, /* unc_cha_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_cha \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419044 }, /* unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_cha \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419735 }, /* unc_cha_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_cha \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3420315 }, /* unc_cha_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3420969 }, /* unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421956 }, /* unc_cha_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422995 }, /* unc_cha_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3423649 }, /* unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424636 }, /* unc_cha_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3425345 }, /* unc_cha_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426422 }, /* unc_cha_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3427551 }, /* unc_cha_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428628 }, /* unc_cha_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3429224 }, /* unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429731 }, /* unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429965 }, /* unc_cha_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430198 }, /* unc_cha_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430705 }, /* unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431212 }, /* unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431709 }, /* unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432196 }, /* unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432683 }, /* unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433170 }, /* unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433657 }, /* unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434144 }, /* unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434368 }, /* unc_cha_txr_vert_bypass.iv\000uncore_cha\000uncore cache\000CMS Vertical ADS Used; IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3435376 }, /* unc_cha_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3435814 }, /* unc_cha_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3436221 }, /* unc_cha_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3436641 }, /* unc_cha_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3437002 }, /* unc_cha_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3437438 }, /* unc_cha_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3437868 }, /* unc_cha_txr_vert_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3442575 }, /* unc_cha_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3443017 }, /* unc_cha_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3443428 }, /* unc_cha_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3443852 }, /* unc_cha_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3444217 }, /* unc_cha_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3444657 }, /* unc_cha_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3445091 }, /* unc_cha_txr_vert_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3449883 }, /* unc_cha_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3450301 }, /* unc_cha_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3450688 }, /* unc_cha_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3451088 }, /* unc_cha_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3451429 }, /* unc_cha_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3451845 }, /* unc_cha_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3452255 }, /* unc_cha_txr_vert_inserts.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations; IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3456645 }, /* unc_cha_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3456846 }, /* unc_cha_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457048 }, /* unc_cha_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457249 }, /* unc_cha_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457451 }, /* unc_cha_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457652 }, /* unc_cha_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3457854 }, /* unc_cha_txr_vert_nack.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs; IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3460244 }, /* unc_cha_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3460669 }, /* unc_cha_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3461063 }, /* unc_cha_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3461470 }, /* unc_cha_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3461818 }, /* unc_cha_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3462241 }, /* unc_cha_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3462658 }, /* unc_cha_txr_vert_occupancy.iv\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy; IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3467100 }, /* unc_cha_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3467409 }, /* unc_cha_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3467719 }, /* unc_cha_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468028 }, /* unc_cha_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468338 }, /* unc_cha_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468647 }, /* unc_cha_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3468957 }, /* unc_cha_txr_vert_starved.iv\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472930 }, /* unc_cha_upi_credit_occupancy.vn0_ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD REQ VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x4\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3473763 }, /* unc_cha_upi_credit_occupancy.vn0_ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x8\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3474596 }, /* unc_cha_upi_credit_occupancy.vn0_bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCB VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x40\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3475430 }, /* unc_cha_upi_credit_occupancy.vn0_bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL NCS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x80\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3476264 }, /* unc_cha_upi_credit_occupancy.vn0_bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL RSP VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x10\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3477098 }, /* unc_cha_upi_credit_occupancy.vn0_bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL DRS VN0 Credits. Unit: uncore_cha \000event=0x3b,umask=0x20\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3477931 }, /* unc_cha_upi_credit_occupancy.vna_ad\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; AD VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x1\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3478756 }, /* unc_cha_upi_credit_occupancy.vna_bl\000uncore_cha\000uncore cache\000UPI Ingress Credits In Use Cycles; BL VNA Credits. Unit: uncore_cha \000event=0x3b,umask=0x2\000\00001\000Accumulates the number of UPI credits available in each cycle for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This stat increments by the number of credits that are available each cycle.  This can be used in conjunction with the Credit Acquired event in order to calculate average credit lifetime.  This event supports filtering for the different types of credits that are available.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3479581 }, /* unc_cha_upi_credits_acquired.ad_req\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD REQ Credits. Unit: uncore_cha \000event=0x38,umask=0x4\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3480300 }, /* unc_cha_upi_credits_acquired.ad_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; AD RSP VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x8\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3481023 }, /* unc_cha_upi_credits_acquired.bl_ncb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCB Credits. Unit: uncore_cha \000event=0x38,umask=0x40\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3481743 }, /* unc_cha_upi_credits_acquired.bl_ncs\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL NCS Credits. Unit: uncore_cha \000event=0x38,umask=0x80\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3482463 }, /* unc_cha_upi_credits_acquired.bl_rsp\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL RSP Credits. Unit: uncore_cha \000event=0x38,umask=0x10\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3483183 }, /* unc_cha_upi_credits_acquired.bl_wb\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; BL DRS Credits. Unit: uncore_cha \000event=0x38,umask=0x20\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3483902 }, /* unc_cha_upi_credits_acquired.vn0\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VN0 Credits. Unit: uncore_cha \000event=0x38,umask=0x2\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3484615 }, /* unc_cha_upi_credits_acquired.vna\000uncore_cha\000uncore cache\000UPI Ingress Credit Allocations; VNA Credits. Unit: uncore_cha \000event=0x38,umask=0x1\000\00001\000Counts the number of UPI credits acquired for either the AD or BL ring.  In order to send snoops, snoop responses, requests, data, etc to the UPI agent on the ring, it is necessary to first acquire a credit for the UPI ingress buffer.  This can be used with the Credit Occupancy event in order to calculate average credit lifetime.  This event supports filtering to cover the VNA/VN0 credits and the different message classes.  Note that you must select the link that you would like to monitor using the link select register, and you can only monitor 1 link at a time\000 */
{ 3486241 }, /* unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3488021 }, /* unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3489798 }, /* unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3491572 }, /* unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3493351 }, /* unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Even. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3495131 }, /* unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3496908 }, /* unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Even. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3498682 }, /* unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3504129 }, /* unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Even. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3505905 }, /* unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3507678 }, /* unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Even. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3509448 }, /* unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3510897 }, /* unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Down. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3512029 }, /* unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use; Up. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3516538 }, /* unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was able to push WbPushMToI to LLC\000 */
{ 3517120 }, /* unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI; Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000Counts the number of times when the CHA was received WbPushMtoI; Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000 */
{ 3517409 }, /* unc_cha_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 2 only\000 */
{ 3517822 }, /* unc_cha_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 3 only\000 */
{ 3518235 }, /* unc_cha_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 4 only\000 */
{ 3518649 }, /* unc_cha_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 5 only\000 */
{ 3519507 }, /* unc_cha_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 0 only\000 */
{ 3522114 }, /* unc_cha_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty; MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue.; Filter for memory controller 1 only\000 */
{ 3527470 }, /* unc_cha_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response any to Hit F/S/E\000 */
{ 3528109 }, /* unc_cha_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd F/E\000 */
{ 3528744 }, /* unc_cha_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response I to Fwd M\000 */
{ 3529361 }, /* unc_cha_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd F/E\000 */
{ 3529996 }, /* unc_cha_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Any RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Any Request - Response S to Fwd M\000 */
{ 3530627 }, /* unc_cha_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response any to Hit F/S/E\000 */
{ 3531269 }, /* unc_cha_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd F/E\000 */
{ 3531907 }, /* unc_cha_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response I to Fwd M\000 */
{ 3532541 }, /* unc_cha_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd F/E\000 */
{ 3533179 }, /* unc_cha_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Core RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Core Request - Response S to Fwd M\000 */
{ 3533813 }, /* unc_cha_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response any to Hit F/S/E\000 */
{ 3534461 }, /* unc_cha_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd F/E\000 */
{ 3535105 }, /* unc_cha_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response I to Fwd M\000 */
{ 3535745 }, /* unc_cha_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd F/E\000 */
{ 3536389 }, /* unc_cha_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; Evict RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; Eviction Request - Response S to Fwd M\000 */
{ 3537029 }, /* unc_cha_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspHitFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response any to Hit F/S/E\000 */
{ 3537678 }, /* unc_cha_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd F/E\000 */
{ 3538323 }, /* unc_cha_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspIFwdM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response I to Fwd M\000 */
{ 3538964 }, /* unc_cha_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd F/E\000 */
{ 3539609 }, /* unc_cha_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000Core Cross Snoop Responses; External RspSFwdM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00001\000Counts the number of core cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type. This event can be filtered based on who triggered the initial snoop(s):  from Evictions, Core  or External (i.e. from a remote node) Requests.  And the event can be filtered based on the responses:  RspX_Fwd/HitY where Y is the state prior to the snoop response and X is the state following.; External Request - Response S to Fwd M\000 */
{ 3551478 }, /* unc_h_ag0_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00011\000\000 */
{ 3551804 }, /* unc_h_ag0_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00011\000\000 */
{ 3552130 }, /* unc_h_ag0_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00011\000\000 */
{ 3552456 }, /* unc_h_ag0_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00011\000\000 */
{ 3552783 }, /* unc_h_ag0_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00011\000\000 */
{ 3553111 }, /* unc_h_ag0_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00011\000\000 */
{ 3554061 }, /* unc_h_ag0_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00011\000\000 */
{ 3554391 }, /* unc_h_ag0_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00011\000\000 */
{ 3554721 }, /* unc_h_ag0_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00011\000\000 */
{ 3555051 }, /* unc_h_ag0_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00011\000\000 */
{ 3555382 }, /* unc_h_ag0_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00011\000\000 */
{ 3555714 }, /* unc_h_ag0_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00011\000\000 */
{ 3556672 }, /* unc_h_ag0_bl_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00011\000\000 */
{ 3556998 }, /* unc_h_ag0_bl_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00011\000\000 */
{ 3557324 }, /* unc_h_ag0_bl_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00011\000\000 */
{ 3557650 }, /* unc_h_ag0_bl_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00011\000\000 */
{ 3557977 }, /* unc_h_ag0_bl_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00011\000\000 */
{ 3558305 }, /* unc_h_ag0_bl_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00011\000\000 */
{ 3559255 }, /* unc_h_ag0_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00011\000\000 */
{ 3559585 }, /* unc_h_ag0_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00011\000\000 */
{ 3559915 }, /* unc_h_ag0_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00011\000\000 */
{ 3560245 }, /* unc_h_ag0_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00011\000\000 */
{ 3560576 }, /* unc_h_ag0_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00011\000\000 */
{ 3560908 }, /* unc_h_ag0_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG0_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00011\000\000 */
{ 3565188 }, /* unc_h_ag1_ad_crd_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00011\000\000 */
{ 3565514 }, /* unc_h_ag1_ad_crd_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00011\000\000 */
{ 3565840 }, /* unc_h_ag1_ad_crd_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00011\000\000 */
{ 3566166 }, /* unc_h_ag1_ad_crd_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00011\000\000 */
{ 3566493 }, /* unc_h_ag1_ad_crd_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00011\000\000 */
{ 3566821 }, /* unc_h_ag1_ad_crd_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00011\000\000 */
{ 3567771 }, /* unc_h_ag1_ad_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00011\000\000 */
{ 3568101 }, /* unc_h_ag1_ad_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00011\000\000 */
{ 3568431 }, /* unc_h_ag1_ad_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00011\000\000 */
{ 3568761 }, /* unc_h_ag1_ad_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00011\000\000 */
{ 3569092 }, /* unc_h_ag1_ad_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00011\000\000 */
{ 3569424 }, /* unc_h_ag1_ad_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_AD_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00011\000\000 */
{ 3571895 }, /* unc_h_ag1_bl_crd_occupancy.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00011\000\000 */
{ 3572225 }, /* unc_h_ag1_bl_crd_occupancy.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00011\000\000 */
{ 3572555 }, /* unc_h_ag1_bl_crd_occupancy.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00011\000\000 */
{ 3572885 }, /* unc_h_ag1_bl_crd_occupancy.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00011\000\000 */
{ 3573216 }, /* unc_h_ag1_bl_crd_occupancy.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00011\000\000 */
{ 3573548 }, /* unc_h_ag1_bl_crd_occupancy.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CRD_OCCUPANCY.TGR5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00011\000\000 */
{ 3574358 }, /* unc_h_ag1_bl_credits_acquired.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00011\000\000 */
{ 3574544 }, /* unc_h_ag1_bl_credits_acquired.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00011\000\000 */
{ 3574730 }, /* unc_h_ag1_bl_credits_acquired.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00011\000\000 */
{ 3574916 }, /* unc_h_ag1_bl_credits_acquired.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00011\000\000 */
{ 3575102 }, /* unc_h_ag1_bl_credits_acquired.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00011\000\000 */
{ 3575289 }, /* unc_h_ag1_bl_credits_acquired.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_AG1_BL_CREDITS_ACQUIRED.TGR5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00011\000\000 */
{ 3583813 }, /* unc_h_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.INTERMEDIATE. Unit: uncore_cha \000event=0x57,umask=0x2\000\00011\000\000 */
{ 3583997 }, /* unc_h_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.NOT_TAKEN. Unit: uncore_cha \000event=0x57,umask=0x4\000\00011\000\000 */
{ 3584175 }, /* unc_h_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_BYPASS_CHA_IMC.TAKEN. Unit: uncore_cha \000event=0x57,umask=0x1\000\00011\000\000 */
{ 3587190 }, /* unc_h_clock\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CMS_CLOCKTICKS. Unit: uncore_cha \000event=0xc0\000\00011\000\000 */
{ 3588958 }, /* unc_h_core_pma.c1_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_STATE. Unit: uncore_cha \000event=0x17,umask=0x1\000\00011\000\000 */
{ 3589122 }, /* unc_h_core_pma.c1_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C1_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x2\000\00011\000\000 */
{ 3589296 }, /* unc_h_core_pma.c6_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_STATE. Unit: uncore_cha \000event=0x17,umask=0x4\000\00011\000\000 */
{ 3589460 }, /* unc_h_core_pma.c6_transition\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.C6_TRANSITION. Unit: uncore_cha \000event=0x17,umask=0x8\000\00011\000\000 */
{ 3589634 }, /* unc_h_core_pma.gv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_PMA.GV. Unit: uncore_cha \000event=0x17,umask=0x10\000\00011\000\000 */
{ 3589787 }, /* unc_h_core_snp.any_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_GTONE. Unit: uncore_cha \000event=0x33,umask=0xe2\000\00011\000\000 */
{ 3589954 }, /* unc_h_core_snp.any_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_ONE. Unit: uncore_cha \000event=0x33,umask=0xe1\000\00011\000\000 */
{ 3590117 }, /* unc_h_core_snp.any_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.ANY_REMOTE. Unit: uncore_cha \000event=0x33,umask=0xe4\000\00011\000\000 */
{ 3590286 }, /* unc_h_core_snp.core_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_GTONE. Unit: uncore_cha \000event=0x33,umask=0x42\000\00011\000\000 */
{ 3590455 }, /* unc_h_core_snp.core_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_ONE. Unit: uncore_cha \000event=0x33,umask=0x41\000\00011\000\000 */
{ 3590620 }, /* unc_h_core_snp.core_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.CORE_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x44\000\00011\000\000 */
{ 3590791 }, /* unc_h_core_snp.evict_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x82\000\00011\000\000 */
{ 3590962 }, /* unc_h_core_snp.evict_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_ONE. Unit: uncore_cha \000event=0x33,umask=0x81\000\00011\000\000 */
{ 3591129 }, /* unc_h_core_snp.evict_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EVICT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x84\000\00011\000\000 */
{ 3591302 }, /* unc_h_core_snp.ext_gtone\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_GTONE. Unit: uncore_cha \000event=0x33,umask=0x22\000\00011\000\000 */
{ 3591469 }, /* unc_h_core_snp.ext_one\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_ONE. Unit: uncore_cha \000event=0x33,umask=0x21\000\00011\000\000 */
{ 3591632 }, /* unc_h_core_snp.ext_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_CORE_SNP.EXT_REMOTE. Unit: uncore_cha \000event=0x33,umask=0x24\000\00011\000\000 */
{ 3591801 }, /* unc_h_counter0_occupancy\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_COUNTER0_OCCUPANCY. Unit: uncore_cha \000event=0x1f\000\00011\000\000 */
{ 3591957 }, /* unc_h_dir_lookup.no_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.NO_SNP. Unit: uncore_cha \000event=0x53,umask=0x2\000\00011\000\000 */
{ 3592121 }, /* unc_h_dir_lookup.snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_LOOKUP.SNP. Unit: uncore_cha \000event=0x53,umask=0x1\000\00011\000\000 */
{ 3592279 }, /* unc_h_dir_update.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.HA. Unit: uncore_cha \000event=0x54,umask=0x1\000\00011\000\000 */
{ 3592435 }, /* unc_h_dir_update.tor\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_DIR_UPDATE.TOR. Unit: uncore_cha \000event=0x54,umask=0x2\000\00011\000\000 */
{ 3603946 }, /* unc_h_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_DN. Unit: uncore_cha \000event=0xae,umask=0x4\000\00011\000\000 */
{ 3604134 }, /* unc_h_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_EGRESS_ORDERING.IV_SNOOPGO_UP. Unit: uncore_cha \000event=0xae,umask=0x1\000\00011\000\000 */
{ 3613554 }, /* unc_h_hitme_hit.ex_rds\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.EX_RDS. Unit: uncore_cha \000event=0x5f,umask=0x1\000\00011\000\000 */
{ 3614908 }, /* unc_h_hitme_hit.shared_ownreq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.SHARED_OWNREQ. Unit: uncore_cha \000event=0x5f,umask=0x4\000\00011\000\000 */
{ 3615084 }, /* unc_h_hitme_hit.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOE. Unit: uncore_cha \000event=0x5f,umask=0x8\000\00011\000\000 */
{ 3615543 }, /* unc_h_hitme_hit.wbmtoi_or_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_HIT.WBMTOI_OR_S. Unit: uncore_cha \000event=0x5f,umask=0x10\000\00011\000\000 */
{ 3618419 }, /* unc_h_hitme_lookup.read\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.READ. Unit: uncore_cha \000event=0x5e,umask=0x1\000\00011\000\000 */
{ 3619882 }, /* unc_h_hitme_lookup.write\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_LOOKUP.WRITE. Unit: uncore_cha \000event=0x5e,umask=0x2\000\00011\000\000 */
{ 3620048 }, /* unc_h_hitme_miss.notshared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.NOTSHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x40\000\00011\000\000 */
{ 3620237 }, /* unc_h_hitme_miss.read_or_inv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.READ_OR_INV. Unit: uncore_cha \000event=0x60,umask=0x80\000\00011\000\000 */
{ 3620412 }, /* unc_h_hitme_miss.shared_rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_MISS.SHARED_RDINVOWN. Unit: uncore_cha \000event=0x60,umask=0x20\000\00011\000\000 */
{ 3620595 }, /* unc_h_hitme_update.deallocate\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE. Unit: uncore_cha \000event=0x61,umask=0x10\000\00011\000\000 */
{ 3620772 }, /* unc_h_hitme_update.deallocate_rspfwdi_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.DEALLOCATE_RSPFWDI_LOC. Unit: uncore_cha \000event=0x61,umask=0x1\000\00011\000\000 */
{ 3620972 }, /* unc_h_hitme_update.rdinvown\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RDINVOWN. Unit: uncore_cha \000event=0x61,umask=0x8\000\00011\000\000 */
{ 3621144 }, /* unc_h_hitme_update.rspfwdi_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.RSPFWDI_REM. Unit: uncore_cha \000event=0x61,umask=0x2\000\00011\000\000 */
{ 3621322 }, /* unc_h_hitme_update.shared\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HITME_UPDATE.SHARED. Unit: uncore_cha \000event=0x61,umask=0x4\000\00011\000\000 */
{ 3621699 }, /* unc_h_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00011\000\000 */
{ 3622094 }, /* unc_h_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00011\000\000 */
{ 3622491 }, /* unc_h_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00011\000\000 */
{ 3622890 }, /* unc_h_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AD_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00011\000\000 */
{ 3623287 }, /* unc_h_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x1\000\00011\000\000 */
{ 3623682 }, /* unc_h_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x2\000\00011\000\000 */
{ 3624079 }, /* unc_h_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xa9,umask=0x4\000\00011\000\000 */
{ 3624478 }, /* unc_h_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_AK_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xa9,umask=0x8\000\00011\000\000 */
{ 3624875 }, /* unc_h_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x1\000\00011\000\000 */
{ 3625270 }, /* unc_h_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.LEFT_ODD. Unit: uncore_cha \000event=0xab,umask=0x2\000\00011\000\000 */
{ 3625667 }, /* unc_h_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_EVEN. Unit: uncore_cha \000event=0xab,umask=0x4\000\00011\000\000 */
{ 3626066 }, /* unc_h_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_BL_IN_USE.RIGHT_ODD. Unit: uncore_cha \000event=0xab,umask=0x8\000\00011\000\000 */
{ 3626449 }, /* unc_h_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.LEFT. Unit: uncore_cha \000event=0xad,umask=0x1\000\00011\000\000 */
{ 3626824 }, /* unc_h_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_HORZ_RING_IV_IN_USE.RIGHT. Unit: uncore_cha \000event=0xad,umask=0x4\000\00011\000\000 */
{ 3630030 }, /* unc_h_imc_reads_count.normal\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.NORMAL. Unit: uncore_cha \000event=0x59,umask=0x1\000\00011\000\000 */
{ 3630204 }, /* unc_h_imc_reads_count.priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_READS_COUNT.PRIORITY. Unit: uncore_cha \000event=0x59,umask=0x2\000\00011\000\000 */
{ 3632094 }, /* unc_h_imc_writes_count.full\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00011\000\000 */
{ 3632266 }, /* unc_h_imc_writes_count.full_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x10\000\00011\000\000 */
{ 3632447 }, /* unc_h_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.FULL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00011\000\000 */
{ 3632637 }, /* unc_h_imc_writes_count.partial\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00011\000\000 */
{ 3632815 }, /* unc_h_imc_writes_count.partial_mig\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_MIG. Unit: uncore_cha \000event=0x5b,umask=0x20\000\00011\000\000 */
{ 3633002 }, /* unc_h_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IMC_WRITES_COUNT.PARTIAL_PRIORITY. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00011\000\000 */
{ 3647627 }, /* unc_h_iodc_alloc.invitom\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.INVITOM. Unit: uncore_cha \000event=0x62,umask=0x1\000\00011\000\000 */
{ 3647793 }, /* unc_h_iodc_alloc.iodcfull\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.IODCFULL. Unit: uncore_cha \000event=0x62,umask=0x2\000\00011\000\000 */
{ 3647961 }, /* unc_h_iodc_alloc.osbgated\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_ALLOC.OSBGATED. Unit: uncore_cha \000event=0x62,umask=0x4\000\00011\000\000 */
{ 3648682 }, /* unc_h_iodc_dealloc.all\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.ALL. Unit: uncore_cha \000event=0x63,umask=0x10\000\00011\000\000 */
{ 3648845 }, /* unc_h_iodc_dealloc.snpout\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.SNPOUT. Unit: uncore_cha \000event=0x63,umask=0x8\000\00011\000\000 */
{ 3649013 }, /* unc_h_iodc_dealloc.wbmtoe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOE. Unit: uncore_cha \000event=0x63,umask=0x1\000\00011\000\000 */
{ 3649181 }, /* unc_h_iodc_dealloc.wbmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBMTOI. Unit: uncore_cha \000event=0x63,umask=0x2\000\00011\000\000 */
{ 3649349 }, /* unc_h_iodc_dealloc.wbpushmtoi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_IODC_DEALLOC.WBPUSHMTOI. Unit: uncore_cha \000event=0x63,umask=0x4\000\00011\000\000 */
{ 3651067 }, /* unc_h_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_MISS. Unit: uncore_cha \000event=0x39,umask=0x20\000\00011\000\000 */
{ 3651381 }, /* unc_h_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.CV0_PREF_VIC. Unit: uncore_cha \000event=0x39,umask=0x10\000\00011\000\000 */
{ 3651678 }, /* unc_h_misc.rfo_hit_s\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RFO_HIT_S. Unit: uncore_cha \000event=0x39,umask=0x8\000\00011\000\000 */
{ 3651984 }, /* unc_h_misc.rspi_was_fse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.RSPI_WAS_FSE. Unit: uncore_cha \000event=0x39,umask=0x1\000\00011\000\000 */
{ 3652298 }, /* unc_h_misc.wc_aliasing\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_MISC.WC_ALIASING. Unit: uncore_cha \000event=0x39,umask=0x2\000\00011\000\000 */
{ 3654323 }, /* unc_h_osb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_OSB. Unit: uncore_cha \000event=0x55\000\00011\000\000 */
{ 3655777 }, /* unc_h_read_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00011\000\000 */
{ 3655957 }, /* unc_h_read_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00011\000\000 */
{ 3656137 }, /* unc_h_read_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00011\000\000 */
{ 3656318 }, /* unc_h_read_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00011\000\000 */
{ 3656499 }, /* unc_h_read_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00011\000\000 */
{ 3656677 }, /* unc_h_read_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_READ_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00011\000\000 */
{ 3656855 }, /* unc_h_requests.invitoe_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_LOCAL. Unit: uncore_cha \000event=0x50,umask=0x10\000\00011\000\000 */
{ 3657407 }, /* unc_h_requests.invitoe_remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_REQUESTS.INVITOE_REMOTE. Unit: uncore_cha \000event=0x50,umask=0x20\000\00011\000\000 */
{ 3657961 }, /* unc_h_requests.reads\000uncore_cha\000uncore cache\000read requests from home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00011\000\000 */
{ 3658751 }, /* unc_h_requests.reads_local\000uncore_cha\000uncore cache\000read requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x1\000\00011\000\000 */
{ 3659341 }, /* unc_h_requests.reads_remote\000uncore_cha\000uncore cache\000read requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x2\000\00011\000\000 */
{ 3659937 }, /* unc_h_requests.writes\000uncore_cha\000uncore cache\000write requests from home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00011\000\000 */
{ 3660675 }, /* unc_h_requests.writes_local\000uncore_cha\000uncore cache\000write requests from local home agent. Unit: uncore_cha \000event=0x50,umask=0x4\000\00011\000\000 */
{ 3661180 }, /* unc_h_requests.writes_remote\000uncore_cha\000uncore cache\000write requests from remote home agent. Unit: uncore_cha \000event=0x50,umask=0x8\000\00011\000\000 */
{ 3686494 }, /* unc_h_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AD. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00011\000\000 */
{ 3686872 }, /* unc_h_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00011\000\000 */
{ 3687248 }, /* unc_h_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.BL. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00011\000\000 */
{ 3687629 }, /* unc_h_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_HORZ.IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00011\000\000 */
{ 3687978 }, /* unc_h_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AD. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00011\000\000 */
{ 3688354 }, /* unc_h_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00011\000\000 */
{ 3688728 }, /* unc_h_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.BL. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00011\000\000 */
{ 3689107 }, /* unc_h_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_BOUNCES_VERT.IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00011\000\000 */
{ 3689426 }, /* unc_h_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AD. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00011\000\000 */
{ 3689755 }, /* unc_h_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00011\000\000 */
{ 3689935 }, /* unc_h_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.AK_AG1. Unit: uncore_cha \000event=0xa3,umask=0x20\000\00011\000\000 */
{ 3690273 }, /* unc_h_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.BL. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00011\000\000 */
{ 3690602 }, /* unc_h_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_HORZ.IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00011\000\000 */
{ 3690782 }, /* unc_h_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AD. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00011\000\000 */
{ 3691109 }, /* unc_h_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00011\000\000 */
{ 3691436 }, /* unc_h_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.BL. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00011\000\000 */
{ 3691763 }, /* unc_h_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RING_SINK_STARVED_VERT.IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00011\000\000 */
{ 3706145 }, /* unc_h_rxc_inserts.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IPQ. Unit: uncore_cha \000event=0x13,umask=0x4\000\00011\000\000 */
{ 3706305 }, /* unc_h_rxc_inserts.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00011\000\000 */
{ 3706465 }, /* unc_h_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.IRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x2\000\00011\000\000 */
{ 3706633 }, /* unc_h_rxc_inserts.prq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00011\000\000 */
{ 3706794 }, /* unc_h_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.PRQ_REJ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00011\000\000 */
{ 3706963 }, /* unc_h_rxc_inserts.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.RRQ. Unit: uncore_cha \000event=0x13,umask=0x40\000\00011\000\000 */
{ 3707124 }, /* unc_h_rxc_inserts.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_INSERTS.WBQ. Unit: uncore_cha \000event=0x13,umask=0x80\000\00011\000\000 */
{ 3707285 }, /* unc_h_rxc_ipq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x22,umask=0x1\000\00011\000\000 */
{ 3707467 }, /* unc_h_rxc_ipq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x2\000\00011\000\000 */
{ 3707649 }, /* unc_h_rxc_ipq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x22,umask=0x10\000\00011\000\000 */
{ 3707832 }, /* unc_h_rxc_ipq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x22,umask=0x20\000\00011\000\000 */
{ 3708015 }, /* unc_h_rxc_ipq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x22,umask=0x4\000\00011\000\000 */
{ 3708197 }, /* unc_h_rxc_ipq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x22,umask=0x8\000\00011\000\000 */
{ 3708377 }, /* unc_h_rxc_ipq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x23,umask=0x40\000\00011\000\000 */
{ 3708558 }, /* unc_h_rxc_ipq1_reject.any_ipq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x23,umask=0x1\000\00011\000\000 */
{ 3708732 }, /* unc_h_rxc_ipq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.HA. Unit: uncore_cha \000event=0x23,umask=0x2\000\00011\000\000 */
{ 3708898 }, /* unc_h_rxc_ipq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x23,umask=0x20\000\00011\000\000 */
{ 3709087 }, /* unc_h_rxc_ipq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x4\000\00011\000\000 */
{ 3709269 }, /* unc_h_rxc_ipq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x23,umask=0x80\000\00011\000\000 */
{ 3709448 }, /* unc_h_rxc_ipq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x23,umask=0x8\000\00011\000\000 */
{ 3709628 }, /* unc_h_rxc_ipq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IPQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x23,umask=0x10\000\00011\000\000 */
{ 3709803 }, /* unc_h_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00011\000\000 */
{ 3709985 }, /* unc_h_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00011\000\000 */
{ 3710167 }, /* unc_h_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00011\000\000 */
{ 3710350 }, /* unc_h_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00011\000\000 */
{ 3710533 }, /* unc_h_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00011\000\000 */
{ 3710715 }, /* unc_h_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00011\000\000 */
{ 3710895 }, /* unc_h_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x19,umask=0x40\000\00011\000\000 */
{ 3711076 }, /* unc_h_rxc_irq1_reject.any_reject_irq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00011\000\000 */
{ 3711257 }, /* unc_h_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00011\000\000 */
{ 3711423 }, /* unc_h_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x19,umask=0x20\000\00011\000\000 */
{ 3711612 }, /* unc_h_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x4\000\00011\000\000 */
{ 3711794 }, /* unc_h_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x19,umask=0x80\000\00011\000\000 */
{ 3711973 }, /* unc_h_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x19,umask=0x8\000\00011\000\000 */
{ 3712153 }, /* unc_h_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_IRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x19,umask=0x10\000\00011\000\000 */
{ 3712328 }, /* unc_h_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00011\000\000 */
{ 3712512 }, /* unc_h_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00011\000\000 */
{ 3712696 }, /* unc_h_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00011\000\000 */
{ 3712881 }, /* unc_h_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00011\000\000 */
{ 3713066 }, /* unc_h_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00011\000\000 */
{ 3713250 }, /* unc_h_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00011\000\000 */
{ 3713432 }, /* unc_h_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00011\000\000 */
{ 3713614 }, /* unc_h_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00011\000\000 */
{ 3713796 }, /* unc_h_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00011\000\000 */
{ 3713979 }, /* unc_h_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00011\000\000 */
{ 3714162 }, /* unc_h_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00011\000\000 */
{ 3714344 }, /* unc_h_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00011\000\000 */
{ 3714524 }, /* unc_h_rxc_ismq1_reject.any_ismq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00011\000\000 */
{ 3714701 }, /* unc_h_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_REJECT.HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00011\000\000 */
{ 3714869 }, /* unc_h_rxc_ismq1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00011\000\000 */
{ 3715038 }, /* unc_h_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_ISMQ1_RETRY.HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00011\000\000 */
{ 3715204 }, /* unc_h_rxc_occupancy.ipq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IPQ. Unit: uncore_cha \000event=0x11,umask=0x4\000\00011\000\000 */
{ 3715368 }, /* unc_h_rxc_occupancy.irq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00011\000\000 */
{ 3715532 }, /* unc_h_rxc_occupancy.rrq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.RRQ. Unit: uncore_cha \000event=0x11,umask=0x40\000\00011\000\000 */
{ 3715697 }, /* unc_h_rxc_occupancy.wbq\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OCCUPANCY.WBQ. Unit: uncore_cha \000event=0x11,umask=0x80\000\00011\000\000 */
{ 3715862 }, /* unc_h_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00011\000\000 */
{ 3716046 }, /* unc_h_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00011\000\000 */
{ 3716230 }, /* unc_h_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00011\000\000 */
{ 3716415 }, /* unc_h_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00011\000\000 */
{ 3716600 }, /* unc_h_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00011\000\000 */
{ 3716784 }, /* unc_h_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00011\000\000 */
{ 3716966 }, /* unc_h_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00011\000\000 */
{ 3717149 }, /* unc_h_rxc_other1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00011\000\000 */
{ 3717320 }, /* unc_h_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00011\000\000 */
{ 3717488 }, /* unc_h_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00011\000\000 */
{ 3717679 }, /* unc_h_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00011\000\000 */
{ 3717863 }, /* unc_h_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00011\000\000 */
{ 3718044 }, /* unc_h_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00011\000\000 */
{ 3718226 }, /* unc_h_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_OTHER1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00011\000\000 */
{ 3718403 }, /* unc_h_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00011\000\000 */
{ 3718585 }, /* unc_h_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00011\000\000 */
{ 3718767 }, /* unc_h_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00011\000\000 */
{ 3718950 }, /* unc_h_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00011\000\000 */
{ 3719133 }, /* unc_h_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00011\000\000 */
{ 3719315 }, /* unc_h_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00011\000\000 */
{ 3719495 }, /* unc_h_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x21,umask=0x40\000\00011\000\000 */
{ 3719676 }, /* unc_h_rxc_prq1_reject.any_prq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00011\000\000 */
{ 3719850 }, /* unc_h_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00011\000\000 */
{ 3720016 }, /* unc_h_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x21,umask=0x20\000\00011\000\000 */
{ 3720205 }, /* unc_h_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x4\000\00011\000\000 */
{ 3720387 }, /* unc_h_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x21,umask=0x80\000\00011\000\000 */
{ 3720566 }, /* unc_h_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x21,umask=0x8\000\00011\000\000 */
{ 3720746 }, /* unc_h_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_PRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x21,umask=0x10\000\00011\000\000 */
{ 3720921 }, /* unc_h_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_REQ_VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00011\000\000 */
{ 3721105 }, /* unc_h_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.AD_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00011\000\000 */
{ 3721289 }, /* unc_h_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00011\000\000 */
{ 3721474 }, /* unc_h_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_NCS_VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00011\000\000 */
{ 3721659 }, /* unc_h_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_RSP_VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00011\000\000 */
{ 3721843 }, /* unc_h_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q0_RETRY.BL_WB_VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00011\000\000 */
{ 3722025 }, /* unc_h_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ALLOW_SNP. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00011\000\000 */
{ 3722208 }, /* unc_h_rxc_req_q1_retry.any\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00011\000\000 */
{ 3722379 }, /* unc_h_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00011\000\000 */
{ 3722547 }, /* unc_h_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00011\000\000 */
{ 3722738 }, /* unc_h_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.LLC_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00011\000\000 */
{ 3722922 }, /* unc_h_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.PA_MATCH. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00011\000\000 */
{ 3723103 }, /* unc_h_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.SF_VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00011\000\000 */
{ 3723285 }, /* unc_h_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_REQ_Q1_RETRY.VICTIM. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00011\000\000 */
{ 3723462 }, /* unc_h_rxc_rrq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x26,umask=0x1\000\00011\000\000 */
{ 3723644 }, /* unc_h_rxc_rrq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x2\000\00011\000\000 */
{ 3723826 }, /* unc_h_rxc_rrq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x26,umask=0x10\000\00011\000\000 */
{ 3724009 }, /* unc_h_rxc_rrq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x26,umask=0x20\000\00011\000\000 */
{ 3724192 }, /* unc_h_rxc_rrq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x26,umask=0x4\000\00011\000\000 */
{ 3724374 }, /* unc_h_rxc_rrq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x26,umask=0x8\000\00011\000\000 */
{ 3724554 }, /* unc_h_rxc_rrq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x27,umask=0x40\000\00011\000\000 */
{ 3724735 }, /* unc_h_rxc_rrq1_reject.any_rrq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x27,umask=0x1\000\00011\000\000 */
{ 3724909 }, /* unc_h_rxc_rrq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.HA. Unit: uncore_cha \000event=0x27,umask=0x2\000\00011\000\000 */
{ 3725075 }, /* unc_h_rxc_rrq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x27,umask=0x20\000\00011\000\000 */
{ 3725264 }, /* unc_h_rxc_rrq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x4\000\00011\000\000 */
{ 3725446 }, /* unc_h_rxc_rrq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x27,umask=0x80\000\00011\000\000 */
{ 3725625 }, /* unc_h_rxc_rrq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x27,umask=0x8\000\00011\000\000 */
{ 3725805 }, /* unc_h_rxc_rrq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_RRQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x27,umask=0x10\000\00011\000\000 */
{ 3725980 }, /* unc_h_rxc_wbq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_REQ_VN0. Unit: uncore_cha \000event=0x28,umask=0x1\000\00011\000\000 */
{ 3726162 }, /* unc_h_rxc_wbq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.AD_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x2\000\00011\000\000 */
{ 3726344 }, /* unc_h_rxc_wbq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCB_VN0. Unit: uncore_cha \000event=0x28,umask=0x10\000\00011\000\000 */
{ 3726527 }, /* unc_h_rxc_wbq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_NCS_VN0. Unit: uncore_cha \000event=0x28,umask=0x20\000\00011\000\000 */
{ 3726710 }, /* unc_h_rxc_wbq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_RSP_VN0. Unit: uncore_cha \000event=0x28,umask=0x4\000\00011\000\000 */
{ 3726892 }, /* unc_h_rxc_wbq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ0_REJECT.BL_WB_VN0. Unit: uncore_cha \000event=0x28,umask=0x8\000\00011\000\000 */
{ 3727072 }, /* unc_h_rxc_wbq1_reject.allow_snp\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ALLOW_SNP. Unit: uncore_cha \000event=0x29,umask=0x40\000\00011\000\000 */
{ 3727253 }, /* unc_h_rxc_wbq1_reject.any_wbq0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.ANY0. Unit: uncore_cha \000event=0x29,umask=0x1\000\00011\000\000 */
{ 3727427 }, /* unc_h_rxc_wbq1_reject.ha\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.HA. Unit: uncore_cha \000event=0x29,umask=0x2\000\00011\000\000 */
{ 3727593 }, /* unc_h_rxc_wbq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_OR_SF_WAY. Unit: uncore_cha \000event=0x29,umask=0x20\000\00011\000\000 */
{ 3727782 }, /* unc_h_rxc_wbq1_reject.llc_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.LLC_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x4\000\00011\000\000 */
{ 3727964 }, /* unc_h_rxc_wbq1_reject.pa_match\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.PA_MATCH. Unit: uncore_cha \000event=0x29,umask=0x80\000\00011\000\000 */
{ 3728143 }, /* unc_h_rxc_wbq1_reject.sf_victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.SF_VICTIM. Unit: uncore_cha \000event=0x29,umask=0x8\000\00011\000\000 */
{ 3728323 }, /* unc_h_rxc_wbq1_reject.victim\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxC_WBQ1_REJECT.VICTIM. Unit: uncore_cha \000event=0x29,umask=0x10\000\00011\000\000 */
{ 3728498 }, /* unc_h_rxr_busy_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00011\000\000 */
{ 3728674 }, /* unc_h_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb4,umask=0x10\000\00011\000\000 */
{ 3728851 }, /* unc_h_rxr_busy_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00011\000\000 */
{ 3729027 }, /* unc_h_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BUSY_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb4,umask=0x40\000\00011\000\000 */
{ 3729204 }, /* unc_h_rxr_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_BNC. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00011\000\000 */
{ 3729368 }, /* unc_h_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AD_CRD. Unit: uncore_cha \000event=0xb2,umask=0x10\000\00011\000\000 */
{ 3729533 }, /* unc_h_rxr_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.AK_BNC. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00011\000\000 */
{ 3729697 }, /* unc_h_rxr_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_BNC. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00011\000\000 */
{ 3729861 }, /* unc_h_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.BL_CRD. Unit: uncore_cha \000event=0xb2,umask=0x40\000\00011\000\000 */
{ 3730026 }, /* unc_h_rxr_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_BYPASS.IV_BNC. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00011\000\000 */
{ 3730190 }, /* unc_h_rxr_crd_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_BNC. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00011\000\000 */
{ 3730364 }, /* unc_h_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AD_CRD. Unit: uncore_cha \000event=0xb3,umask=0x10\000\00011\000\000 */
{ 3730539 }, /* unc_h_rxr_crd_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.AK_BNC. Unit: uncore_cha \000event=0xb3,umask=0x2\000\00011\000\000 */
{ 3730713 }, /* unc_h_rxr_crd_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_BNC. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00011\000\000 */
{ 3730887 }, /* unc_h_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.BL_CRD. Unit: uncore_cha \000event=0xb3,umask=0x40\000\00011\000\000 */
{ 3731062 }, /* unc_h_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IFV. Unit: uncore_cha \000event=0xb3,umask=0x80\000\00011\000\000 */
{ 3731231 }, /* unc_h_rxr_crd_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_CRD_STARVED.IV_BNC. Unit: uncore_cha \000event=0xb3,umask=0x8\000\00011\000\000 */
{ 3731405 }, /* unc_h_rxr_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_BNC. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00011\000\000 */
{ 3731571 }, /* unc_h_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AD_CRD. Unit: uncore_cha \000event=0xb1,umask=0x10\000\00011\000\000 */
{ 3731738 }, /* unc_h_rxr_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.AK_BNC. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00011\000\000 */
{ 3731904 }, /* unc_h_rxr_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_BNC. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00011\000\000 */
{ 3732070 }, /* unc_h_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.BL_CRD. Unit: uncore_cha \000event=0xb1,umask=0x40\000\00011\000\000 */
{ 3732237 }, /* unc_h_rxr_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_INSERTS.IV_BNC. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00011\000\000 */
{ 3732403 }, /* unc_h_rxr_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00011\000\000 */
{ 3732573 }, /* unc_h_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0xb0,umask=0x10\000\00011\000\000 */
{ 3732744 }, /* unc_h_rxr_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00011\000\000 */
{ 3732914 }, /* unc_h_rxr_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00011\000\000 */
{ 3733084 }, /* unc_h_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0xb0,umask=0x40\000\00011\000\000 */
{ 3733255 }, /* unc_h_rxr_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_RxR_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00011\000\000 */
{ 3734957 }, /* unc_h_sf_eviction.e_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.E_STATE. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00011\000\000 */
{ 3735125 }, /* unc_h_sf_eviction.m_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.M_STATE. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00011\000\000 */
{ 3735293 }, /* unc_h_sf_eviction.s_state\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SF_EVICTION.S_STATE. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00011\000\000 */
{ 3738503 }, /* unc_h_snoop_resp.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_FWD_WB. Unit: uncore_cha \000event=0x5c,umask=0x20\000\00011\000\000 */
{ 3740350 }, /* unc_h_snoop_resp.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSP_WBWB. Unit: uncore_cha \000event=0x5c,umask=0x10\000\00011\000\000 */
{ 3741353 }, /* unc_h_snoop_resp.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPCNFLCTS. Unit: uncore_cha \000event=0x5c,umask=0x40\000\00011\000\000 */
{ 3742340 }, /* unc_h_snoop_resp.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPFWD. Unit: uncore_cha \000event=0x5c,umask=0x80\000\00011\000\000 */
{ 3742505 }, /* unc_h_snoop_resp.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPI. Unit: uncore_cha \000event=0x5c,umask=0x1\000\00011\000\000 */
{ 3743394 }, /* unc_h_snoop_resp.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPIFWD. Unit: uncore_cha \000event=0x5c,umask=0x4\000\00011\000\000 */
{ 3745194 }, /* unc_h_snoop_resp.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPS. Unit: uncore_cha \000event=0x5c,umask=0x2\000\00011\000\000 */
{ 3746903 }, /* unc_h_snoop_resp.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP.RSPSFWD. Unit: uncore_cha \000event=0x5c,umask=0x8\000\00011\000\000 */
{ 3750737 }, /* unc_h_snoops_sent.\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.ALL. Unit: uncore_cha \000event=0x51,umask=0x1\000\00011\000\000 */
{ 3750894 }, /* unc_h_snoops_sent.bcst_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x10\000\00011\000\000 */
{ 3751067 }, /* unc_h_snoops_sent.bcst_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.BCST_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x20\000\00011\000\000 */
{ 3751241 }, /* unc_h_snoops_sent.direct_loc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_LOCAL. Unit: uncore_cha \000event=0x51,umask=0x40\000\00011\000\000 */
{ 3751418 }, /* unc_h_snoops_sent.direct_rem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.DIRECT_REMOTE. Unit: uncore_cha \000event=0x51,umask=0x80\000\00011\000\000 */
{ 3751596 }, /* unc_h_snoops_sent.local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.LOCAL. Unit: uncore_cha \000event=0x51,umask=0x4\000\00011\000\000 */
{ 3751760 }, /* unc_h_snoops_sent.remote\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOPS_SENT.REMOTE. Unit: uncore_cha \000event=0x51,umask=0x8\000\00011\000\000 */
{ 3755686 }, /* unc_h_snp_rsp_rcv_local.rsp_fwd_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_FWD_WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00011\000\000 */
{ 3755872 }, /* unc_h_snp_rsp_rcv_local.rsp_wb\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSP_WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00011\000\000 */
{ 3756050 }, /* unc_h_snp_rsp_rcv_local.rspcnflct\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPCNFLCT. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00011\000\000 */
{ 3756234 }, /* unc_h_snp_rsp_rcv_local.rspfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPFWD. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00011\000\000 */
{ 3756412 }, /* unc_h_snp_rsp_rcv_local.rspi\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00011\000\000 */
{ 3756585 }, /* unc_h_snp_rsp_rcv_local.rspifwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPIFWD. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00011\000\000 */
{ 3756764 }, /* unc_h_snp_rsp_rcv_local.rsps\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00011\000\000 */
{ 3756937 }, /* unc_h_snp_rsp_rcv_local.rspsfwd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_SNOOP_RESP_LOCAL.RSPSFWD. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00011\000\000 */
{ 3758092 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00011\000\000 */
{ 3758288 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00011\000\000 */
{ 3758484 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00011\000\000 */
{ 3758680 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00011\000\000 */
{ 3758876 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00011\000\000 */
{ 3759073 }, /* unc_h_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG0.TGR5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00011\000\000 */
{ 3759270 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00011\000\000 */
{ 3759466 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00011\000\000 */
{ 3759662 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00011\000\000 */
{ 3759858 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00011\000\000 */
{ 3760054 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00011\000\000 */
{ 3760251 }, /* unc_h_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_AD_AG1.TGR5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00011\000\000 */
{ 3760448 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00011\000\000 */
{ 3760644 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00011\000\000 */
{ 3760840 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00011\000\000 */
{ 3761036 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00011\000\000 */
{ 3761232 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00011\000\000 */
{ 3761429 }, /* unc_h_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG0.TGR5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00011\000\000 */
{ 3761626 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00011\000\000 */
{ 3761822 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00011\000\000 */
{ 3762018 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00011\000\000 */
{ 3762214 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00011\000\000 */
{ 3762410 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00011\000\000 */
{ 3762607 }, /* unc_h_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_STALL_NO_TxR_HORZ_CRD_BL_AG1.TGR5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00011\000\000 */
{ 3818505 }, /* unc_h_txr_horz_ads_used.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_BNC. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00011\000\000 */
{ 3818683 }, /* unc_h_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AD_CRD. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00011\000\000 */
{ 3818862 }, /* unc_h_txr_horz_ads_used.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.AK_BNC. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00011\000\000 */
{ 3819040 }, /* unc_h_txr_horz_ads_used.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_BNC. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00011\000\000 */
{ 3819218 }, /* unc_h_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_ADS_USED.BL_CRD. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00011\000\000 */
{ 3819397 }, /* unc_h_txr_horz_bypass.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_BNC. Unit: uncore_cha \000event=0x9f,umask=0x1\000\00011\000\000 */
{ 3819571 }, /* unc_h_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AD_CRD. Unit: uncore_cha \000event=0x9f,umask=0x10\000\00011\000\000 */
{ 3819746 }, /* unc_h_txr_horz_bypass.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.AK_BNC. Unit: uncore_cha \000event=0x9f,umask=0x2\000\00011\000\000 */
{ 3819920 }, /* unc_h_txr_horz_bypass.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_BNC. Unit: uncore_cha \000event=0x9f,umask=0x4\000\00011\000\000 */
{ 3820094 }, /* unc_h_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.BL_CRD. Unit: uncore_cha \000event=0x9f,umask=0x40\000\00011\000\000 */
{ 3820269 }, /* unc_h_txr_horz_bypass.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_BYPASS.IV_BNC. Unit: uncore_cha \000event=0x9f,umask=0x8\000\00011\000\000 */
{ 3820443 }, /* unc_h_txr_horz_cycles_full.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_BNC. Unit: uncore_cha \000event=0x96,umask=0x1\000\00011\000\000 */
{ 3820627 }, /* unc_h_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AD_CRD. Unit: uncore_cha \000event=0x96,umask=0x10\000\00011\000\000 */
{ 3820812 }, /* unc_h_txr_horz_cycles_full.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.AK_BNC. Unit: uncore_cha \000event=0x96,umask=0x2\000\00011\000\000 */
{ 3820996 }, /* unc_h_txr_horz_cycles_full.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_BNC. Unit: uncore_cha \000event=0x96,umask=0x4\000\00011\000\000 */
{ 3821180 }, /* unc_h_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.BL_CRD. Unit: uncore_cha \000event=0x96,umask=0x40\000\00011\000\000 */
{ 3821365 }, /* unc_h_txr_horz_cycles_full.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_FULL.IV_BNC. Unit: uncore_cha \000event=0x96,umask=0x8\000\00011\000\000 */
{ 3821549 }, /* unc_h_txr_horz_cycles_ne.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_BNC. Unit: uncore_cha \000event=0x97,umask=0x1\000\00011\000\000 */
{ 3821729 }, /* unc_h_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AD_CRD. Unit: uncore_cha \000event=0x97,umask=0x10\000\00011\000\000 */
{ 3821910 }, /* unc_h_txr_horz_cycles_ne.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.AK_BNC. Unit: uncore_cha \000event=0x97,umask=0x2\000\00011\000\000 */
{ 3822090 }, /* unc_h_txr_horz_cycles_ne.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_BNC. Unit: uncore_cha \000event=0x97,umask=0x4\000\00011\000\000 */
{ 3822270 }, /* unc_h_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.BL_CRD. Unit: uncore_cha \000event=0x97,umask=0x40\000\00011\000\000 */
{ 3822451 }, /* unc_h_txr_horz_cycles_ne.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_CYCLES_NE.IV_BNC. Unit: uncore_cha \000event=0x97,umask=0x8\000\00011\000\000 */
{ 3822631 }, /* unc_h_txr_horz_inserts.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_BNC. Unit: uncore_cha \000event=0x95,umask=0x1\000\00011\000\000 */
{ 3822807 }, /* unc_h_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AD_CRD. Unit: uncore_cha \000event=0x95,umask=0x10\000\00011\000\000 */
{ 3822984 }, /* unc_h_txr_horz_inserts.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.AK_BNC. Unit: uncore_cha \000event=0x95,umask=0x2\000\00011\000\000 */
{ 3823160 }, /* unc_h_txr_horz_inserts.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_BNC. Unit: uncore_cha \000event=0x95,umask=0x4\000\00011\000\000 */
{ 3823336 }, /* unc_h_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.BL_CRD. Unit: uncore_cha \000event=0x95,umask=0x40\000\00011\000\000 */
{ 3823513 }, /* unc_h_txr_horz_inserts.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_INSERTS.IV_BNC. Unit: uncore_cha \000event=0x95,umask=0x8\000\00011\000\000 */
{ 3823689 }, /* unc_h_txr_horz_nack.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_BNC. Unit: uncore_cha \000event=0x99,umask=0x1\000\00011\000\000 */
{ 3823859 }, /* unc_h_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AD_CRD. Unit: uncore_cha \000event=0x99,umask=0x20\000\00011\000\000 */
{ 3824030 }, /* unc_h_txr_horz_nack.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.AK_BNC. Unit: uncore_cha \000event=0x99,umask=0x2\000\00011\000\000 */
{ 3824200 }, /* unc_h_txr_horz_nack.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_BNC. Unit: uncore_cha \000event=0x99,umask=0x4\000\00011\000\000 */
{ 3824370 }, /* unc_h_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.BL_CRD. Unit: uncore_cha \000event=0x99,umask=0x40\000\00011\000\000 */
{ 3824541 }, /* unc_h_txr_horz_nack.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_NACK.IV_BNC. Unit: uncore_cha \000event=0x99,umask=0x8\000\00011\000\000 */
{ 3824711 }, /* unc_h_txr_horz_occupancy.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_BNC. Unit: uncore_cha \000event=0x94,umask=0x1\000\00011\000\000 */
{ 3824891 }, /* unc_h_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AD_CRD. Unit: uncore_cha \000event=0x94,umask=0x10\000\00011\000\000 */
{ 3825072 }, /* unc_h_txr_horz_occupancy.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.AK_BNC. Unit: uncore_cha \000event=0x94,umask=0x2\000\00011\000\000 */
{ 3825252 }, /* unc_h_txr_horz_occupancy.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_BNC. Unit: uncore_cha \000event=0x94,umask=0x4\000\00011\000\000 */
{ 3825432 }, /* unc_h_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.BL_CRD. Unit: uncore_cha \000event=0x94,umask=0x40\000\00011\000\000 */
{ 3825613 }, /* unc_h_txr_horz_occupancy.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_OCCUPANCY.IV_BNC. Unit: uncore_cha \000event=0x94,umask=0x8\000\00011\000\000 */
{ 3825793 }, /* unc_h_txr_horz_starved.ad_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AD_BNC. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00011\000\000 */
{ 3825969 }, /* unc_h_txr_horz_starved.ak_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.AK_BNC. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00011\000\000 */
{ 3826145 }, /* unc_h_txr_horz_starved.bl_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.BL_BNC. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00011\000\000 */
{ 3826321 }, /* unc_h_txr_horz_starved.iv_bnc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_HORZ_STARVED.IV_BNC. Unit: uncore_cha \000event=0x9b,umask=0x8\000\00011\000\000 */
{ 3827021 }, /* unc_h_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00011\000\000 */
{ 3827199 }, /* unc_h_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AD_AG1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00011\000\000 */
{ 3827378 }, /* unc_h_txr_vert_ads_used.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG0. Unit: uncore_cha \000event=0x9c,umask=0x2\000\00011\000\000 */
{ 3827556 }, /* unc_h_txr_vert_ads_used.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.AK_AG1. Unit: uncore_cha \000event=0x9c,umask=0x20\000\00011\000\000 */
{ 3827735 }, /* unc_h_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00011\000\000 */
{ 3827913 }, /* unc_h_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_ADS_USED.BL_AG1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00011\000\000 */
{ 3828092 }, /* unc_h_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00011\000\000 */
{ 3828266 }, /* unc_h_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AD_AG1. Unit: uncore_cha \000event=0x9e,umask=0x10\000\00011\000\000 */
{ 3828441 }, /* unc_h_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG0. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00011\000\000 */
{ 3828615 }, /* unc_h_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.AK_AG1. Unit: uncore_cha \000event=0x9e,umask=0x20\000\00011\000\000 */
{ 3828790 }, /* unc_h_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG0. Unit: uncore_cha \000event=0x9e,umask=0x4\000\00011\000\000 */
{ 3828964 }, /* unc_h_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.BL_AG1. Unit: uncore_cha \000event=0x9e,umask=0x40\000\00011\000\000 */
{ 3829139 }, /* unc_h_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_BYPASS.IV. Unit: uncore_cha \000event=0x9e,umask=0x8\000\00011\000\000 */
{ 3829309 }, /* unc_h_txr_vert_cycles_full.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00011\000\000 */
{ 3829493 }, /* unc_h_txr_vert_cycles_full.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AD_AG1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00011\000\000 */
{ 3829678 }, /* unc_h_txr_vert_cycles_full.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00011\000\000 */
{ 3829862 }, /* unc_h_txr_vert_cycles_full.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.AK_AG1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00011\000\000 */
{ 3830047 }, /* unc_h_txr_vert_cycles_full.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00011\000\000 */
{ 3830231 }, /* unc_h_txr_vert_cycles_full.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.BL_AG1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00011\000\000 */
{ 3830416 }, /* unc_h_txr_vert_cycles_full.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_FULL.IV. Unit: uncore_cha \000event=0x92,umask=0x8\000\00011\000\000 */
{ 3830596 }, /* unc_h_txr_vert_cycles_ne.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00011\000\000 */
{ 3830776 }, /* unc_h_txr_vert_cycles_ne.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AD_AG1. Unit: uncore_cha \000event=0x93,umask=0x10\000\00011\000\000 */
{ 3830957 }, /* unc_h_txr_vert_cycles_ne.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG0. Unit: uncore_cha \000event=0x93,umask=0x2\000\00011\000\000 */
{ 3831137 }, /* unc_h_txr_vert_cycles_ne.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.AK_AG1. Unit: uncore_cha \000event=0x93,umask=0x20\000\00011\000\000 */
{ 3831318 }, /* unc_h_txr_vert_cycles_ne.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG0. Unit: uncore_cha \000event=0x93,umask=0x4\000\00011\000\000 */
{ 3831498 }, /* unc_h_txr_vert_cycles_ne.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.BL_AG1. Unit: uncore_cha \000event=0x93,umask=0x40\000\00011\000\000 */
{ 3831679 }, /* unc_h_txr_vert_cycles_ne.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_CYCLES_NE.IV. Unit: uncore_cha \000event=0x93,umask=0x8\000\00011\000\000 */
{ 3831855 }, /* unc_h_txr_vert_inserts.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00011\000\000 */
{ 3832031 }, /* unc_h_txr_vert_inserts.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AD_AG1. Unit: uncore_cha \000event=0x91,umask=0x10\000\00011\000\000 */
{ 3832208 }, /* unc_h_txr_vert_inserts.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG0. Unit: uncore_cha \000event=0x91,umask=0x2\000\00011\000\000 */
{ 3832384 }, /* unc_h_txr_vert_inserts.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.AK_AG1. Unit: uncore_cha \000event=0x91,umask=0x20\000\00011\000\000 */
{ 3832561 }, /* unc_h_txr_vert_inserts.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG0. Unit: uncore_cha \000event=0x91,umask=0x4\000\00011\000\000 */
{ 3832737 }, /* unc_h_txr_vert_inserts.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.BL_AG1. Unit: uncore_cha \000event=0x91,umask=0x40\000\00011\000\000 */
{ 3832914 }, /* unc_h_txr_vert_inserts.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_INSERTS.IV. Unit: uncore_cha \000event=0x91,umask=0x8\000\00011\000\000 */
{ 3833086 }, /* unc_h_txr_vert_nack.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00011\000\000 */
{ 3833256 }, /* unc_h_txr_vert_nack.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AD_AG1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00011\000\000 */
{ 3833427 }, /* unc_h_txr_vert_nack.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00011\000\000 */
{ 3833597 }, /* unc_h_txr_vert_nack.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.AK_AG1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00011\000\000 */
{ 3833768 }, /* unc_h_txr_vert_nack.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00011\000\000 */
{ 3833938 }, /* unc_h_txr_vert_nack.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.BL_AG1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00011\000\000 */
{ 3834109 }, /* unc_h_txr_vert_nack.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_NACK.IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00011\000\000 */
{ 3834271 }, /* unc_h_txr_vert_occupancy.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00011\000\000 */
{ 3834451 }, /* unc_h_txr_vert_occupancy.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AD_AG1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00011\000\000 */
{ 3834632 }, /* unc_h_txr_vert_occupancy.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00011\000\000 */
{ 3834812 }, /* unc_h_txr_vert_occupancy.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.AK_AG1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00011\000\000 */
{ 3834993 }, /* unc_h_txr_vert_occupancy.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00011\000\000 */
{ 3835173 }, /* unc_h_txr_vert_occupancy.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.BL_AG1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00011\000\000 */
{ 3835354 }, /* unc_h_txr_vert_occupancy.iv_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_OCCUPANCY.IV. Unit: uncore_cha \000event=0x90,umask=0x8\000\00011\000\000 */
{ 3835530 }, /* unc_h_txr_vert_starved.ad_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00011\000\000 */
{ 3835706 }, /* unc_h_txr_vert_starved.ad_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AD_AG1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00011\000\000 */
{ 3835883 }, /* unc_h_txr_vert_starved.ak_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00011\000\000 */
{ 3836059 }, /* unc_h_txr_vert_starved.ak_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.AK_AG1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00011\000\000 */
{ 3836236 }, /* unc_h_txr_vert_starved.bl_ag0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00011\000\000 */
{ 3836412 }, /* unc_h_txr_vert_starved.bl_ag1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.BL_AG1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00011\000\000 */
{ 3836589 }, /* unc_h_txr_vert_starved.iv\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TxR_VERT_STARVED.IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00011\000\000 */
{ 3837051 }, /* unc_h_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00011\000\000 */
{ 3837438 }, /* unc_h_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa6,umask=0x8\000\00011\000\000 */
{ 3837823 }, /* unc_h_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00011\000\000 */
{ 3838208 }, /* unc_h_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AD_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa6,umask=0x2\000\00011\000\000 */
{ 3838595 }, /* unc_h_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x4\000\00011\000\000 */
{ 3838982 }, /* unc_h_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xa8,umask=0x8\000\00011\000\000 */
{ 3839367 }, /* unc_h_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xa8,umask=0x1\000\00011\000\000 */
{ 3839752 }, /* unc_h_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_AK_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xa8,umask=0x2\000\00011\000\000 */
{ 3840139 }, /* unc_h_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00011\000\000 */
{ 3840526 }, /* unc_h_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.DN_ODD. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00011\000\000 */
{ 3840911 }, /* unc_h_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_EVEN. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00011\000\000 */
{ 3841296 }, /* unc_h_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_BL_IN_USE.UP_ODD. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00011\000\000 */
{ 3841669 }, /* unc_h_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.DN. Unit: uncore_cha \000event=0xac,umask=0x4\000\00011\000\000 */
{ 3842032 }, /* unc_h_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_VERT_RING_IV_IN_USE.UP. Unit: uncore_cha \000event=0xac,umask=0x1\000\00011\000\000 */
{ 3842206 }, /* unc_h_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00011\000\000 */
{ 3842368 }, /* unc_h_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WB_PUSH_MTOI.MEM. Unit: uncore_cha \000event=0x56,umask=0x2\000\00011\000\000 */
{ 3856682 }, /* unc_h_write_no_credits.edc0_smi2\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC0_SMI2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00011\000\000 */
{ 3856864 }, /* unc_h_write_no_credits.edc1_smi3\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC1_SMI3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00011\000\000 */
{ 3857046 }, /* unc_h_write_no_credits.edc2_smi4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC2_SMI4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00011\000\000 */
{ 3857229 }, /* unc_h_write_no_credits.edc3_smi5\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.EDC3_SMI5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00011\000\000 */
{ 3857412 }, /* unc_h_write_no_credits.mc0_smi0\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC0_SMI0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00011\000\000 */
{ 3857592 }, /* unc_h_write_no_credits.mc1_smi1\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_WRITE_NO_CREDITS.MC1_SMI1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00011\000\000 */
{ 3857772 }, /* unc_h_xsnp_resp.any_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0xe1\000\00011\000\000 */
{ 3857951 }, /* unc_h_xsnp_resp.any_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe4\000\00011\000\000 */
{ 3858130 }, /* unc_h_xsnp_resp.any_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0xf0\000\00011\000\000 */
{ 3858307 }, /* unc_h_xsnp_resp.any_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0xe2\000\00011\000\000 */
{ 3858486 }, /* unc_h_xsnp_resp.any_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.ANY_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0xe8\000\00011\000\000 */
{ 3858663 }, /* unc_h_xsnp_resp.core_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x41\000\00011\000\000 */
{ 3858844 }, /* unc_h_xsnp_resp.core_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x44\000\00011\000\000 */
{ 3859025 }, /* unc_h_xsnp_resp.core_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x50\000\00011\000\000 */
{ 3859204 }, /* unc_h_xsnp_resp.core_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x42\000\00011\000\000 */
{ 3859385 }, /* unc_h_xsnp_resp.core_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.CORE_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x48\000\00011\000\000 */
{ 3859564 }, /* unc_h_xsnp_resp.evict_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x81\000\00011\000\000 */
{ 3859747 }, /* unc_h_xsnp_resp.evict_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x84\000\00011\000\000 */
{ 3859930 }, /* unc_h_xsnp_resp.evict_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x90\000\00011\000\000 */
{ 3860111 }, /* unc_h_xsnp_resp.evict_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x82\000\00011\000\000 */
{ 3860294 }, /* unc_h_xsnp_resp.evict_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EVICT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x88\000\00011\000\000 */
{ 3860475 }, /* unc_h_xsnp_resp.ext_rsp_hitfse\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSP_HITFSE. Unit: uncore_cha \000event=0x32,umask=0x21\000\00011\000\000 */
{ 3860654 }, /* unc_h_xsnp_resp.ext_rspi_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x24\000\00011\000\000 */
{ 3860833 }, /* unc_h_xsnp_resp.ext_rspi_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPI_FWDM. Unit: uncore_cha \000event=0x32,umask=0x30\000\00011\000\000 */
{ 3861010 }, /* unc_h_xsnp_resp.ext_rsps_fwdfe\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDFE. Unit: uncore_cha \000event=0x32,umask=0x22\000\00011\000\000 */
{ 3861189 }, /* unc_h_xsnp_resp.ext_rsps_fwdm\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_XSNP_RESP.EXT_RSPS_FWDM. Unit: uncore_cha \000event=0x32,umask=0x28\000\00011\000\000 */
{ 3872082 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events.; Tracks all requests from any source port\000 */
{ 3872796 }, /* unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy; Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3873432 }, /* unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests.  This is effectively the sum of read occupancy and write occupancy\000 */
{ 3877003 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000IRP Clocks. Unit: uncore_irp \000event=0x1\000\00001\000\000 */
{ 3877466 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops; CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3877854 }, /* unc_i_coherent_ops.crd\000uncore_irp\000uncore interconnect\000Coherent Ops; CRd. Unit: uncore_irp \000event=0x10,umask=0x2\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878224 }, /* unc_i_coherent_ops.drd\000uncore_irp\000uncore interconnect\000Coherent Ops; DRd. Unit: uncore_irp \000event=0x10,umask=0x4\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878594 }, /* unc_i_coherent_ops.pcidcahint\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIDCAHin5t. Unit: uncore_irp \000event=0x10,umask=0x20\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3878996 }, /* unc_i_coherent_ops.pcirdcur\000uncore_irp\000uncore interconnect\000Coherent Ops; PCIRdCur. Unit: uncore_irp \000event=0x10,umask=0x1\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3879579 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline. Unit: uncore_irp \000event=0x10,umask=0x10\000\00001\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline to coherent memory, without a RFO.  PCIITOM is a speculative Invalidate to Modified command that requests ownership of the cacheline and does not move data from the mesh to IRP cache\000 */
{ 3880245 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline. Unit: uncore_irp \000event=0x10,umask=0x8\000\00001\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline to coherent memory.  RFO is a Read For Ownership command that requests ownership of the cacheline and moves data from the mesh to IRP cache\000 */
{ 3880894 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops; WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Counts the number of coherency related operations servied by the IRP\000 */
{ 3881278 }, /* unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000 */
{ 3881484 }, /* unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000Inbound read requests received by the IRP and inserted into the FAF queue. Unit: uncore_irp \000event=0x18\000\00001\000Inbound read requests to coherent memory, received by the IRP and inserted into the Fire and Forget queue (FAF), a queue used for processing inbound reads in the IRP\000 */
{ 3881907 }, /* unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000Occupancy of the IRP FAF queue. Unit: uncore_irp \000event=0x19\000\00001\000Occupancy of the IRP Fire and Forget (FAF) queue, a queue used for processing inbound reads in the IRP\000 */
{ 3882126 }, /* unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000 */
{ 3882529 }, /* unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 3882821 }, /* unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 3883402 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 3884000 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 3884594 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 3885083 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Rejects. Unit: uncore_irp \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 3885538 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Requests. Unit: uncore_irp \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 3886079 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 3886653 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Misc Events - Set 0; Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 3887255 }, /* unc_i_misc0.unknown\000uncore_irp\000uncore interconnect\000Misc Events - Set 0. Unit: uncore_irp \000event=0x1c,umask=0x80\000\00001\000\000 */
{ 3887973 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Lost Forward. Unit: uncore_irp \000event=0x1d,umask=0x10\000\00001\000Snoop pulled away ownership before a write was committed\000 */
{ 3888625 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Invalid. Unit: uncore_irp \000event=0x1d,umask=0x20\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3889282 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Received Valid. Unit: uncore_irp \000event=0x1d,umask=0x40\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889944 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of E Line. Unit: uncore_irp \000event=0x1d,umask=0x4\000\00001\000Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890612 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of I Line. Unit: uncore_irp \000event=0x1d,umask=0x1\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891282 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of M Line. Unit: uncore_irp \000event=0x1d,umask=0x8\000\00001\000Snoop took cacheline ownership before write from data was committed\000 */
{ 3891956 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1; Slow Transfer of S Line. Unit: uncore_irp \000event=0x1d,umask=0x2\000\00001\000Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3892302 }, /* unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P requests from the ITC\000 */
{ 3892424 }, /* unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P B & S Queue Occupancy\000 */
{ 3892829 }, /* unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000 */
{ 3893110 }, /* unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000 */
{ 3893423 }, /* unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000 */
{ 3893727 }, /* unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000 */
{ 3893991 }, /* unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000 */
{ 3894265 }, /* unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions; Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000 */
{ 3894580 }, /* unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions; match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000 */
{ 3894883 }, /* unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions; P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000 */
{ 3900346 }, /* unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000 */
{ 3900612 }, /* unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000 */
{ 3900881 }, /* unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000 */
{ 3901139 }, /* unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000 */
{ 3901397 }, /* unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000 */
{ 3901765 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000 */
{ 3902172 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000 */
{ 3902562 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses; Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000 */
{ 3902950 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses; Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000 */
{ 3903340 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000 */
{ 3903747 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000 */
{ 3904152 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses; SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000 */
{ 3906606 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of atomic transactions\000 */
{ 3908131 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of 'other' kinds of transactions\000 */
{ 3910065 }, /* unc_i_transactions.rd_pref\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Read Prefetches. Unit: uncore_irp \000event=0x11,umask=0x4\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks the number of read prefetches\000 */
{ 3911565 }, /* unc_i_transactions.reads\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Reads. Unit: uncore_irp \000event=0x11,umask=0x1\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Tracks only read requests (not including read prefetches)\000 */
{ 3914035 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000 */
{ 3915045 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count; Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID.; Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3918099 }, /* unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000 */
{ 3918207 }, /* unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000 */
{ 3918327 }, /* unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000 */
{ 3918439 }, /* unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000 */
{ 3918555 }, /* unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000 */
{ 3918675 }, /* unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000 */
{ 3918787 }, /* unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000 */
{ 3918903 }, /* unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000 */
{ 3919023 }, /* unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000 */
{ 3919135 }, /* unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000 */
{ 3920506 }, /* unc_i_txr2_ad_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD Egress Credit Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000Counts the number times when it is not possible to issue a request to the R2PCIe because there are no AD Egress Credits available\000 */
{ 3920762 }, /* unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3922871 }, /* unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923270 }, /* unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923669 }, /* unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 4330092 }, /* unc_m2m_ag0_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330324 }, /* unc_m2m_ag0_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330556 }, /* unc_m2m_ag0_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4330788 }, /* unc_m2m_ag0_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331020 }, /* unc_m2m_ag0_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331253 }, /* unc_m2m_ag0_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334639 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4334871 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335103 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335335 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335567 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4335800 }, /* unc_m2m_ag0_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4339197 }, /* unc_m2m_ag0_bl_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339429 }, /* unc_m2m_ag0_bl_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339661 }, /* unc_m2m_ag0_bl_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4339893 }, /* unc_m2m_ag0_bl_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340125 }, /* unc_m2m_ag0_bl_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340358 }, /* unc_m2m_ag0_bl_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343744 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4343976 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344208 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344440 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344672 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4344905 }, /* unc_m2m_ag0_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4348302 }, /* unc_m2m_ag1_ad_crd_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348534 }, /* unc_m2m_ag1_ad_crd_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348766 }, /* unc_m2m_ag1_ad_crd_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4348998 }, /* unc_m2m_ag1_ad_crd_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349230 }, /* unc_m2m_ag1_ad_crd_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349463 }, /* unc_m2m_ag1_ad_crd_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352849 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353081 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353313 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353545 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4353777 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354010 }, /* unc_m2m_ag1_ad_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4360560 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4360792 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361024 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361256 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361488 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4361721 }, /* unc_m2m_ag1_bl_crd_occupancy.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4365118 }, /* unc_m2m_ag1_bl_credits_acquired.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365354 }, /* unc_m2m_ag1_bl_credits_acquired.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365590 }, /* unc_m2m_ag1_bl_credits_acquired.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4365826 }, /* unc_m2m_ag1_bl_credits_acquired.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366062 }, /* unc_m2m_ag1_bl_credits_acquired.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366299 }, /* unc_m2m_ag1_bl_credits_acquired.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4366678 }, /* unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000Traffic in which the M2M to iMC Bypass was not taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000Counts traffic in which the M2M (Mesh to Memory) to iMC (Memory Controller) bypass was not taken\000 */
{ 4367073 }, /* unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000 */
{ 4367349 }, /* unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000 */
{ 4367626 }, /* unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass; Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000 */
{ 4367881 }, /* unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Cycles - at UCLK. Unit: uncore_m2m \000event=0\000\00001\000\000 */
{ 4368117 }, /* unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000 */
{ 4368810 }, /* unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode (which bypasses the CHA) was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000Counts cycles when direct to core mode (which bypasses the CHA) was disabled\000 */
{ 4369559 }, /* unc_m2m_direct2core_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to core (bypassing the CHA). Unit: uncore_m2m \000event=0x23\000\00001\000Counts when messages were sent direct to core (bypassing the CHA)\000 */
{ 4370499 }, /* unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction were overridden. Unit: uncore_m2m \000event=0x25\000\00001\000Counts reads in which direct to core transactions (which would have bypassed the CHA) were overridden\000 */
{ 4371131 }, /* unc_m2m_direct2upi_not_taken_credits\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to Intel(R) UPI transactions were overridden. Unit: uncore_m2m \000event=0x28\000\00001\000Counts reads in which direct to Intel(R) Ultra Path Interconnect (UPI) transactions (which would have bypassed the CHA) were overridden\000 */
{ 4372713 }, /* unc_m2m_direct2upi_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to Intel(R) UPI was disabled. Unit: uncore_m2m \000event=0x27\000\00001\000Counts cycles when the ability to send messages direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was disabled\000 */
{ 4373188 }, /* unc_m2m_direct2upi_taken\000uncore_m2m\000uncore interconnect\000Messages sent direct to the Intel(R) UPI. Unit: uncore_m2m \000event=0x26\000\00001\000Counts when messages were sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA)\000 */
{ 4373972 }, /* unc_m2m_direct2upi_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads that a message sent direct2 Intel(R) UPI was overridden. Unit: uncore_m2m \000event=0x29\000\00001\000Counts when a read message that was sent direct to the Intel(R) Ultra Path Interconnect (bypassing the CHA) was overridden\000 */
{ 4374892 }, /* unc_m2m_directory_hit.clean_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 4375344 }, /* unc_m2m_directory_hit.clean_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 4375796 }, /* unc_m2m_directory_hit.clean_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 4376248 }, /* unc_m2m_directory_hit.clean_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 4376692 }, /* unc_m2m_directory_hit.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 4377132 }, /* unc_m2m_directory_hit.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 4377572 }, /* unc_m2m_directory_hit.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 4378012 }, /* unc_m2m_directory_hit.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Hit; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 4378580 }, /* unc_m2m_directory_lookup.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (any state found). Unit: uncore_m2m \000event=0x2d,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in Any State (A, I, S or unused)\000 */
{ 4379336 }, /* unc_m2m_directory_lookup.state_a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookups (cacheline found in A state). Unit: uncore_m2m \000event=0x2d,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state, and found the cacheline marked in the A (SnoopAll) state, indicating the cacheline is stored in another socket in any state, and we must snoop the other sockets to make sure we get the latest data.  The data may be stored in any state in the local socket\000 */
{ 4380297 }, /* unc_m2m_directory_lookup.state_i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in I state). Unit: uncore_m2m \000event=0x2d,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the I (Invalid) state indicating the cacheline is not stored in another socket, and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000 */
{ 4381246 }, /* unc_m2m_directory_lookup.state_s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory lookup (cacheline found in S state). Unit: uncore_m2m \000event=0x2d,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) looks into the multi-socket cacheline Directory state , and found the cacheline marked in the S (Shared) state indicating the cacheline is either stored in another socket in the S(hared) state , and so there is no need to snoop the other sockets for the latest data.  The data may be stored in any state in the local socket\000 */
{ 4382090 }, /* unc_m2m_directory_miss.clean_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x80\000\00001\000\000 */
{ 4382548 }, /* unc_m2m_directory_miss.clean_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x10\000\00001\000\000 */
{ 4383006 }, /* unc_m2m_directory_miss.clean_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x40\000\00001\000\000 */
{ 4383464 }, /* unc_m2m_directory_miss.clean_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On NonDirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x20\000\00001\000\000 */
{ 4383914 }, /* unc_m2m_directory_miss.dirty_a\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in A State. Unit: uncore_m2m \000event=0x2b,umask=0x8\000\00001\000\000 */
{ 4384360 }, /* unc_m2m_directory_miss.dirty_i\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in I State. Unit: uncore_m2m \000event=0x2b,umask=0x1\000\00001\000\000 */
{ 4384806 }, /* unc_m2m_directory_miss.dirty_p\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in L State. Unit: uncore_m2m \000event=0x2b,umask=0x4\000\00001\000\000 */
{ 4385252 }, /* unc_m2m_directory_miss.dirty_s\000uncore_m2m\000uncore interconnect\000Directory Miss; On Dirty Line in S State. Unit: uncore_m2m \000event=0x2b,umask=0x2\000\00001\000\000 */
{ 4385559 }, /* unc_m2m_directory_update.a2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to I. Unit: uncore_m2m \000event=0x2e,umask=0x20\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to I (Invalid)\000 */
{ 4385996 }, /* unc_m2m_directory_update.a2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from A to S. Unit: uncore_m2m \000event=0x2e,umask=0x40\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from A (SnoopAll) to S (Shared)\000 */
{ 4387788 }, /* unc_m2m_directory_update.any\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from/to Any state. Unit: uncore_m2m \000event=0x2e,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory to a new state\000 */
{ 4388476 }, /* unc_m2m_directory_update.i2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to A. Unit: uncore_m2m \000event=0x2e,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to A (SnoopAll)\000 */
{ 4388912 }, /* unc_m2m_directory_update.i2s\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from I to S. Unit: uncore_m2m \000event=0x2e,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from I (Invalid) to S (Shared)\000 */
{ 4390750 }, /* unc_m2m_directory_update.s2a\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to A. Unit: uncore_m2m \000event=0x2e,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to A (SnoopAll)\000 */
{ 4391186 }, /* unc_m2m_directory_update.s2i\000uncore_m2m\000uncore interconnect\000Multi-socket cacheline Directory update from S to I. Unit: uncore_m2m \000event=0x2e,umask=0x8\000\00001\000Counts when the M2M (Mesh to Memory) updates the multi-socket cacheline Directory state from S (Shared) to I (Invalid)\000 */
{ 4396322 }, /* unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m2m \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397202 }, /* unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m2m \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397457 }, /* unc_m2m_fast_asserted.horz\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4397724 }, /* unc_m2m_fast_asserted.vert\000uncore_m2m\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4398916 }, /* unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4400722 }, /* unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4402532 }, /* unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4404343 }, /* unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4406150 }, /* unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m2m \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4407952 }, /* unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4409758 }, /* unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m2m \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4411565 }, /* unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m2m \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4417107 }, /* unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4418911 }, /* unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4420719 }, /* unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4422528 }, /* unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4424009 }, /* unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4425176 }, /* unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4426182 }, /* unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000Reads to iMC issued. Unit: uncore_m2m \000event=0x37,umask=0x4\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller)\000 */
{ 4431955 }, /* unc_m2m_imc_reads.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x37,umask=0x10\000\00001\000\000 */
{ 4432280 }, /* unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC; Critical Priority. Unit: uncore_m2m \000event=0x37,umask=0x2\000\00001\000\000 */
{ 4432709 }, /* unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000Reads to iMC issued at Normal Priority (Non-Isochronous). Unit: uncore_m2m \000event=0x37,umask=0x1\000\00001\000Counts when the M2M (Mesh to Memory) issues reads to the iMC (Memory Controller).  It only counts  normal priority non-isochronous reads\000 */
{ 4434813 }, /* unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000Writes to iMC issued. Unit: uncore_m2m \000event=0x38,umask=0x10\000\00001\000Counts when the M2M (Mesh to Memory) issues writes to the iMC (Memory Controller)\000 */
{ 4442461 }, /* unc_m2m_imc_writes.from_transgress\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x40\000\00001\000\000 */
{ 4442925 }, /* unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; Full Line Non-ISOCH. Unit: uncore_m2m \000event=0x38,umask=0x1\000\00001\000\000 */
{ 4443378 }, /* unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Full Line. Unit: uncore_m2m \000event=0x38,umask=0x4\000\00001\000\000 */
{ 4443670 }, /* unc_m2m_imc_writes.ni\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; All, regardless of priority. Unit: uncore_m2m \000event=0x38,umask=0x80\000\00001\000\000 */
{ 4444526 }, /* unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000Partial Non-Isochronous writes to the iMC. Unit: uncore_m2m \000event=0x38,umask=0x2\000\00001\000Counts when the M2M (Mesh to Memory) issues partial writes to the iMC (Memory Controller).  It only counts normal priority non-isochronous writes\000 */
{ 4445125 }, /* unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC; ISOCH Partial. Unit: uncore_m2m \000event=0x38,umask=0x8\000\00001\000\000 */
{ 4447160 }, /* unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4447437 }, /* unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches; Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4449400 }, /* unc_m2m_prefcam_cycles_full\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full. Unit: uncore_m2m \000event=0x53\000\00001\000\000 */
{ 4450116 }, /* unc_m2m_prefcam_cycles_ne\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty. Unit: uncore_m2m \000event=0x54\000\00001\000\000 */
{ 4457481 }, /* unc_m2m_prefcam_demand_promotions\000uncore_m2m\000uncore interconnect\000Prefetch requests that got turn into a demand request. Unit: uncore_m2m \000event=0x56\000\00001\000Counts when the M2M (Mesh to Memory) promotes a outstanding request in the prefetch queue due to a subsequent demand read request that entered the M2M with the same address.  Explanatory Side Note: The Prefetch queue is made of CAM (Content Addressable Memory)\000 */
{ 4465130 }, /* unc_m2m_prefcam_inserts\000uncore_m2m\000uncore interconnect\000Inserts into the Memory Controller Prefetch Queue. Unit: uncore_m2m \000event=0x57\000\00001\000Counts when the M2M (Mesh to Memory) receives a prefetch request and inserts it into its outstanding prefetch queue.  Explanatory Side Note: the prefect queue is made from CAM: Content Addressable Memory\000 */
{ 4466470 }, /* unc_m2m_prefcam_occupancy\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy. Unit: uncore_m2m \000event=0x55\000\00001\000\000 */
{ 4469478 }, /* unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470024 }, /* unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470570 }, /* unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471116 }, /* unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471656 }, /* unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472236 }, /* unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473119 }, /* unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473726 }, /* unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4474143 }, /* unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 4474442 }, /* unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 4474771 }, /* unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 4475100 }, /* unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 4475399 }, /* unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 4475696 }, /* unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 4476013 }, /* unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 4476495 }, /* unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 4476835 }, /* unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 4477007 }, /* unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xa4\000\00001\000\000 */
{ 4477217 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00011\000\000 */
{ 4477415 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00011\000\000 */
{ 4477613 }, /* unc_m2m_rpq_cycles_no_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_RPQ_CYCLES_SPEC_CREDITS.CHN2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00011\000\000 */
{ 4477811 }, /* unc_m2m_rpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4477976 }, /* unc_m2m_rpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4478141 }, /* unc_m2m_rpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x43,umask=0x4\000\00001\000\000 */
{ 4478306 }, /* unc_m2m_rpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4478472 }, /* unc_m2m_rpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4478638 }, /* unc_m2m_rpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4480217 }, /* unc_m2m_rxc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x4\000\00001\000\000 */
{ 4480336 }, /* unc_m2m_rxc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x3\000\00001\000\000 */
{ 4480736 }, /* unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Queue Inserts. Unit: uncore_m2m \000event=0x1\000\00001\000Counts when the a new entry is Received(RxC) and then added to the AD (Address Ring) Ingress Queue from the CMS (Common Mesh Stop).  This is generally used for reads, and\000 */
{ 4481030 }, /* unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x2\000\00001\000\000 */
{ 4481534 }, /* unc_m2m_rxc_bl_cycles_full\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x8\000\00001\000\000 */
{ 4481653 }, /* unc_m2m_rxc_bl_cycles_ne\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x7\000\00001\000\000 */
{ 4481775 }, /* unc_m2m_rxc_bl_inserts\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x5\000\00001\000\000 */
{ 4481897 }, /* unc_m2m_rxc_bl_occupancy\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x6\000\00001\000\000 */
{ 4482485 }, /* unc_m2m_rxr_busy_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4483321 }, /* unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4484629 }, /* unc_m2m_rxr_busy_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4485465 }, /* unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4486560 }, /* unc_m2m_rxr_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4486976 }, /* unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4487603 }, /* unc_m2m_rxr_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4488281 }, /* unc_m2m_rxr_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4488697 }, /* unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m2m \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4489324 }, /* unc_m2m_rxr_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 4489986 }, /* unc_m2m_rxr_crd_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4490844 }, /* unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4492137 }, /* unc_m2m_rxr_crd_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4493017 }, /* unc_m2m_rxr_crd_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4493875 }, /* unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4495194 }, /* unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m2m \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496024 }, /* unc_m2m_rxr_crd_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4497162 }, /* unc_m2m_rxr_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4497723 }, /* unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498570 }, /* unc_m2m_rxr_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4499468 }, /* unc_m2m_rxr_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500029 }, /* unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m2m \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500876 }, /* unc_m2m_rxr_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4501464 }, /* unc_m2m_rxr_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502039 }, /* unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502906 }, /* unc_m2m_rxr_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503824 }, /* unc_m2m_rxr_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504399 }, /* unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4505266 }, /* unc_m2m_rxr_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4522320 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4522614 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4522908 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523202 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523496 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4523791 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524086 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524380 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524674 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4524968 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525262 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525557 }, /* unc_m2m_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4525852 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526146 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526440 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4526734 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527028 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527323 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527618 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4527912 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528206 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528500 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4528794 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4529089 }, /* unc_m2m_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4532786 }, /* unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x41\000\00001\000\000 */
{ 4533016 }, /* unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x42\000\00001\000\000 */
{ 4533131 }, /* unc_m2m_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4533270 }, /* unc_m2m_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4533409 }, /* unc_m2m_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4533548 }, /* unc_m2m_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4533690 }, /* unc_m2m_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4533832 }, /* unc_m2m_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4534639 }, /* unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4535036 }, /* unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4535299 }, /* unc_m2m_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x49,umask=0x4\000\00001\000\000 */
{ 4536110 }, /* unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4536517 }, /* unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4536788 }, /* unc_m2m_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4536923 }, /* unc_m2m_tracker_pending_occupancy\000uncore_m2m\000uncore interconnect\000Data Pending Occupancy. Unit: uncore_m2m \000event=0x48\000\00001\000\000 */
{ 4537046 }, /* unc_m2m_txc_ad_credit_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credits Occupancy. Unit: uncore_m2m \000event=0xe\000\00001\000\000 */
{ 4537180 }, /* unc_m2m_txc_ad_credits_acquired\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credit Acquired. Unit: uncore_m2m \000event=0xd\000\00001\000\000 */
{ 4537312 }, /* unc_m2m_txc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Full. Unit: uncore_m2m \000event=0xc\000\00001\000\000 */
{ 4537428 }, /* unc_m2m_txc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0xb\000\00001\000\000 */
{ 4537547 }, /* unc_m2m_txc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x9\000\00001\000\000 */
{ 4537666 }, /* unc_m2m_txc_ad_no_credit_cycles\000uncore_m2m\000uncore interconnect\000Cycles with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0xf\000\00001\000\000 */
{ 4537805 }, /* unc_m2m_txc_ad_no_credit_stalled\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0x10\000\00001\000\000 */
{ 4537954 }, /* unc_m2m_txc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0xa\000\00001\000\000 */
{ 4538231 }, /* unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000 */
{ 4538535 }, /* unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK; NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000 */
{ 4538681 }, /* unc_m2m_txc_ak_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 4538861 }, /* unc_m2m_txc_ak_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 4539219 }, /* unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4539575 }, /* unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4539889 }, /* unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000 */
{ 4540188 }, /* unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4540512 }, /* unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4540807 }, /* unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4541097 }, /* unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Read Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000 */
{ 4541388 }, /* unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000 */
{ 4541681 }, /* unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Compare Request. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000 */
{ 4541974 }, /* unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4542266 }, /* unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full; Write Credit Request. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000 */
{ 4542563 }, /* unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000 */
{ 4542868 }, /* unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000 */
{ 4543198 }, /* unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000 */
{ 4543498 }, /* unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Read Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000 */
{ 4543792 }, /* unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Compare Request. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000 */
{ 4544089 }, /* unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty; Write Credit Request. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000 */
{ 4544388 }, /* unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000 */
{ 4544693 }, /* unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000 */
{ 4545023 }, /* unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000 */
{ 4545334 }, /* unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Prefetch Read Cam Hit. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000 */
{ 4545640 }, /* unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Read Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000 */
{ 4545934 }, /* unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Compare Request. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000 */
{ 4546231 }, /* unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations; Write Credit Request. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000 */
{ 4546576 }, /* unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 4546946 }, /* unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 4547325 }, /* unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000 */
{ 4547713 }, /* unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000 */
{ 4548046 }, /* unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000 */
{ 4548351 }, /* unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000 */
{ 4548681 }, /* unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000 */
{ 4548981 }, /* unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Read Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000 */
{ 4549275 }, /* unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Compare Request. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000 */
{ 4549572 }, /* unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy; Write Credit Request. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000 */
{ 4549731 }, /* unc_m2m_txc_ak_sideband.rd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 4549862 }, /* unc_m2m_txc_ak_sideband.wr\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Sideband. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 4550252 }, /* unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4550563 }, /* unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4550870 }, /* unc_m2m_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache; Data to QPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4551022 }, /* unc_m2m_txc_bl_credit_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1a,umask=0x1\000\00001\000\000 */
{ 4551202 }, /* unc_m2m_txc_bl_credit_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credits Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1a,umask=0x2\000\00001\000\000 */
{ 4551560 }, /* unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4551916 }, /* unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4552230 }, /* unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4552529 }, /* unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4552853 }, /* unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4553154 }, /* unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000 */
{ 4553459 }, /* unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4553789 }, /* unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4554093 }, /* unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000 */
{ 4554398 }, /* unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4554728 }, /* unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4555078 }, /* unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4555448 }, /* unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4555827 }, /* unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 4556215 }, /* unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4556408 }, /* unc_m2m_txc_bl_occupancy.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; All. Unit: uncore_m2m \000event=0x16,umask=0x3\000\00001\000\000 */
{ 4556547 }, /* unc_m2m_txc_bl_occupancy.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x16,umask=0x1\000\00001\000\000 */
{ 4556712 }, /* unc_m2m_txc_bl_occupancy.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Occupancy; Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x16,umask=0x2\000\00001\000\000 */
{ 4557187 }, /* unc_m2m_txr_horz_ads_used.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4557719 }, /* unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558257 }, /* unc_m2m_txr_horz_ads_used.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558811 }, /* unc_m2m_txr_horz_ads_used.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559343 }, /* unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4560188 }, /* unc_m2m_txr_horz_bypass.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4560709 }, /* unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561494 }, /* unc_m2m_txr_horz_bypass.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562331 }, /* unc_m2m_txr_horz_bypass.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562852 }, /* unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m2m \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563637 }, /* unc_m2m_txr_horz_bypass.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m2m \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4564277 }, /* unc_m2m_txr_horz_cycles_full.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4564976 }, /* unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566036 }, /* unc_m2m_txr_horz_cycles_full.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4567148 }, /* unc_m2m_txr_horz_cycles_full.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4567847 }, /* unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568907 }, /* unc_m2m_txr_horz_cycles_full.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4569641 }, /* unc_m2m_txr_horz_cycles_ne.ad_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4570361 }, /* unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m2m \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571455 }, /* unc_m2m_txr_horz_cycles_ne.ak_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4572601 }, /* unc_m2m_txr_horz_cycles_ne.bl_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4573321 }, /* unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m2m \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574415 }, /* unc_m2m_txr_horz_cycles_ne.iv_bnc\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m2m \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4575124 }, /* unc_m2m_txr_horz_inserts.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4575796 }, /* unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m2m \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576809 }, /* unc_m2m_txr_horz_inserts.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577874 }, /* unc_m2m_txr_horz_inserts.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4578546 }, /* unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m2m \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579559 }, /* unc_m2m_txr_horz_inserts.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m2m \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4580151 }, /* unc_m2m_txr_horz_nack.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4580623 }, /* unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m2m \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581335 }, /* unc_m2m_txr_horz_nack.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582098 }, /* unc_m2m_txr_horz_nack.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582570 }, /* unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m2m \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583282 }, /* unc_m2m_txr_horz_nack.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m2m \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583876 }, /* unc_m2m_txr_horz_occupancy.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4584544 }, /* unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585552 }, /* unc_m2m_txr_horz_occupancy.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4586612 }, /* unc_m2m_txr_horz_occupancy.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587280 }, /* unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4588288 }, /* unc_m2m_txr_horz_occupancy.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4589011 }, /* unc_m2m_txr_horz_starved.ad_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590109 }, /* unc_m2m_txr_horz_starved.ak_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4591259 }, /* unc_m2m_txr_horz_starved.bl_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592357 }, /* unc_m2m_txr_horz_starved.iv_bnc\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m2m \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592967 }, /* unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593488 }, /* unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593729 }, /* unc_m2m_txr_vert_ads_used.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593969 }, /* unc_m2m_txr_vert_ads_used.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594490 }, /* unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595011 }, /* unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595522 }, /* unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596023 }, /* unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596524 }, /* unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597025 }, /* unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597526 }, /* unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598027 }, /* unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598258 }, /* unc_m2m_txr_vert_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m2m \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4599294 }, /* unc_m2m_txr_vert_cycles_full.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4599739 }, /* unc_m2m_txr_vert_cycles_full.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4600153 }, /* unc_m2m_txr_vert_cycles_full.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4600580 }, /* unc_m2m_txr_vert_cycles_full.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4600948 }, /* unc_m2m_txr_vert_cycles_full.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4601391 }, /* unc_m2m_txr_vert_cycles_full.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4601828 }, /* unc_m2m_txr_vert_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4606605 }, /* unc_m2m_txr_vert_cycles_ne.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4607054 }, /* unc_m2m_txr_vert_cycles_ne.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4607472 }, /* unc_m2m_txr_vert_cycles_ne.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4607903 }, /* unc_m2m_txr_vert_cycles_ne.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4608275 }, /* unc_m2m_txr_vert_cycles_ne.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4608722 }, /* unc_m2m_txr_vert_cycles_ne.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4609163 }, /* unc_m2m_txr_vert_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m2m \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4614025 }, /* unc_m2m_txr_vert_inserts.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4614450 }, /* unc_m2m_txr_vert_inserts.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4614844 }, /* unc_m2m_txr_vert_inserts.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4615251 }, /* unc_m2m_txr_vert_inserts.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4615599 }, /* unc_m2m_txr_vert_inserts.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4616022 }, /* unc_m2m_txr_vert_inserts.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4616439 }, /* unc_m2m_txr_vert_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m2m \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4620899 }, /* unc_m2m_txr_vert_nack.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621107 }, /* unc_m2m_txr_vert_nack.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621316 }, /* unc_m2m_txr_vert_nack.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621524 }, /* unc_m2m_txr_vert_nack.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621733 }, /* unc_m2m_txr_vert_nack.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4621941 }, /* unc_m2m_txr_vert_nack.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622150 }, /* unc_m2m_txr_vert_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624610 }, /* unc_m2m_txr_vert_occupancy.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4625042 }, /* unc_m2m_txr_vert_occupancy.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4625443 }, /* unc_m2m_txr_vert_occupancy.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4625857 }, /* unc_m2m_txr_vert_occupancy.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4626212 }, /* unc_m2m_txr_vert_occupancy.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4626642 }, /* unc_m2m_txr_vert_occupancy.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4627066 }, /* unc_m2m_txr_vert_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4631578 }, /* unc_m2m_txr_vert_starved.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4631894 }, /* unc_m2m_txr_vert_starved.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632211 }, /* unc_m2m_txr_vert_starved.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632527 }, /* unc_m2m_txr_vert_starved.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4632844 }, /* unc_m2m_txr_vert_starved.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4633160 }, /* unc_m2m_txr_vert_starved.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4633477 }, /* unc_m2m_txr_vert_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4638447 }, /* unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4640241 }, /* unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4642032 }, /* unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4643820 }, /* unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4645613 }, /* unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m2m \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4647407 }, /* unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4649198 }, /* unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m2m \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4650986 }, /* unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m2m \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4656475 }, /* unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4658265 }, /* unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4660052 }, /* unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4661836 }, /* unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4663299 }, /* unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4664445 }, /* unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4668699 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00011\000\000 */
{ 4668895 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00011\000\000 */
{ 4669091 }, /* unc_m2m_wpq_cycles_no_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_WPQ_CYCLES_REG_CREDITS.CHN2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00011\000\000 */
{ 4669287 }, /* unc_m2m_wpq_cycles_reg_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4669450 }, /* unc_m2m_wpq_cycles_reg_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4669613 }, /* unc_m2m_wpq_cycles_reg_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular; Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4669776 }, /* unc_m2m_wpq_cycles_spec_credits.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 4669940 }, /* unc_m2m_wpq_cycles_spec_credits.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 4670104 }, /* unc_m2m_wpq_cycles_spec_credits.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special; Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 4679813 }, /* unc_m2m_write_tracker_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4679964 }, /* unc_m2m_write_tracker_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4680115 }, /* unc_m2m_write_tracker_cycles_full.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full; Channel 2. Unit: uncore_m2m \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4680266 }, /* unc_m2m_write_tracker_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4680420 }, /* unc_m2m_write_tracker_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4680574 }, /* unc_m2m_write_tracker_cycles_ne.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty; Channel 2. Unit: uncore_m2m \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4680728 }, /* unc_m2m_write_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 0. Unit: uncore_m2m \000event=0x61,umask=0x1\000\00001\000\000 */
{ 4680871 }, /* unc_m2m_write_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 1. Unit: uncore_m2m \000event=0x61,umask=0x2\000\00001\000\000 */
{ 4681014 }, /* unc_m2m_write_tracker_inserts.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts; Channel 2. Unit: uncore_m2m \000event=0x61,umask=0x4\000\00001\000\000 */
{ 4681157 }, /* unc_m2m_write_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 0. Unit: uncore_m2m \000event=0x60,umask=0x1\000\00001\000\000 */
{ 4681304 }, /* unc_m2m_write_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 1. Unit: uncore_m2m \000event=0x60,umask=0x2\000\00001\000\000 */
{ 4681451 }, /* unc_m2m_write_tracker_occupancy.ch2\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy; Channel 2. Unit: uncore_m2m \000event=0x60,umask=0x4\000\00001\000\000 */
{ 4881009 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x80,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881247 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x80,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881485 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x80,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881723 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x80,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4881961 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x80,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4882200 }, /* unc_m3upi_ag0_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x80,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4885658 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x82,umask=0x1\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4885896 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x82,umask=0x2\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886134 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x82,umask=0x4\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886372 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x82,umask=0x8\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886610 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x82,umask=0x10\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4886849 }, /* unc_m3upi_ag0_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x82,umask=0x20\000\00001\000Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4890318 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x88,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4890556 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x88,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4890794 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x88,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891032 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x88,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891270 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x88,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4891509 }, /* unc_m3upi_ag0_bl_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x88,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4894967 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8a,umask=0x1\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895205 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8a,umask=0x2\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895443 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8a,umask=0x4\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895681 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8a,umask=0x8\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4895919 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8a,umask=0x10\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4896158 }, /* unc_m3upi_ag0_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent0 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8a,umask=0x20\000\00001\000Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4899627 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x84,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4899865 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x84,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900103 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x84,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900341 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x84,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900579 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x84,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4900818 }, /* unc_m3upi_ag1_ad_crd_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x84,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4904276 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x86,umask=0x1\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904514 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x86,umask=0x2\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904752 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x86,umask=0x4\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4904990 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x86,umask=0x8\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4905228 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x86,umask=0x10\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4905467 }, /* unc_m3upi_ag1_ad_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 AD Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x86,umask=0x20\000\00001\000Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4912155 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 0. Unit: uncore_m3upi \000event=0x8e,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912393 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 1. Unit: uncore_m3upi \000event=0x8e,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912631 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 2. Unit: uncore_m3upi \000event=0x8e,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4912869 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 3. Unit: uncore_m3upi \000event=0x8e,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4913107 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 4. Unit: uncore_m3upi \000event=0x8e,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4913346 }, /* unc_m3upi_ag1_bl_crd_occupancy.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Occupancy; For Transgress 5. Unit: uncore_m3upi \000event=0x8e,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4916815 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr0\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 0. Unit: uncore_m3upi \000event=0x8c,umask=0x1\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917057 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr1\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 1. Unit: uncore_m3upi \000event=0x8c,umask=0x2\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917299 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr2\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 2. Unit: uncore_m3upi \000event=0x8c,umask=0x4\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917541 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr3\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 3. Unit: uncore_m3upi \000event=0x8c,umask=0x8\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4917783 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr4\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 4. Unit: uncore_m3upi \000event=0x8c,umask=0x10\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4918026 }, /* unc_m3upi_ag1_bl_credits_acquired.tgr5\000uncore_m3upi\000uncore interconnect\000CMS Agent1 BL Credits Acquired; For Transgress 5. Unit: uncore_m3upi \000event=0x8c,umask=0x20\000\00001\000Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4918526 }, /* unc_m3upi_cha_ad_credits_empty.req\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Requests. Unit: uncore_m3upi \000event=0x22,umask=0x4\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919000 }, /* unc_m3upi_cha_ad_credits_empty.snp\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Snoops. Unit: uncore_m3upi \000event=0x22,umask=0x8\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919484 }, /* unc_m3upi_cha_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; VNA Messages. Unit: uncore_m3upi \000event=0x22,umask=0x1\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4919969 }, /* unc_m3upi_cha_ad_credits_empty.wb\000uncore_m3upi\000uncore interconnect\000CBox AD Credits Empty; Writebacks. Unit: uncore_m3upi \000event=0x22,umask=0x2\000\00001\000No credits available to send to Cbox on the AD Ring (covers higher CBoxes)\000 */
{ 4920778 }, /* unc_m3upi_clockticks\000uncore_m3upi\000uncore interconnect\000Number of uclks in domain. Unit: uncore_m3upi \000event=0x1\000\00001\000Counts the number of uclks in the M3 uclk domain.  This could be slightly different than the count in the Ubox because of enable/freeze delays.  However, because the M3 is close to the Ubox, they generally should not diverge by more than a handful of cycles\000 */
{ 4921151 }, /* unc_m3upi_cms_clockticks\000uncore_m3upi\000uncore interconnect\000CMS Clockticks. Unit: uncore_m3upi \000event=0xc0\000\00001\000\000 */
{ 4921377 }, /* unc_m3upi_d2c_sent\000uncore_m3upi\000uncore interconnect\000D2C Sent. Unit: uncore_m3upi \000event=0x2b\000\00001\000Count cases BL sends direct to core\000 */
{ 4921654 }, /* unc_m3upi_d2u_sent\000uncore_m3upi\000uncore interconnect\000D2U Sent. Unit: uncore_m3upi \000event=0x2a\000\00001\000Cases where SMI3 sends D2U command\000 */
{ 4925155 }, /* unc_m3upi_egress_ordering.iv_snoopgo_dn\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Down. Unit: uncore_m3upi \000event=0xae,umask=0x4\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925732 }, /* unc_m3upi_egress_ordering.iv_snoopgo_up\000uncore_m3upi\000uncore interconnect\000Egress Blocking due to Ordering requirements; Up. Unit: uncore_m3upi \000event=0xae,umask=0x1\000\00001\000Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4925993 }, /* unc_m3upi_fast_asserted.horz\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Horizontal. Unit: uncore_m3upi \000event=0xa5,umask=0x2\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4926266 }, /* unc_m3upi_fast_asserted.vert\000uncore_m3upi\000uncore interconnect\000FaST wire asserted; Vertical. Unit: uncore_m3upi \000event=0xa5,umask=0x1\000\00001\000Counts the number of cycles either the local or incoming distress signals are asserted.  Incoming distress includes up, dn and across\000 */
{ 4927470 }, /* unc_m3upi_horz_ring_ad_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4929288 }, /* unc_m3upi_horz_ring_ad_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4931110 }, /* unc_m3upi_horz_ring_ad_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa7,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4932933 }, /* unc_m3upi_horz_ring_ad_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AD Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa7,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4934752 }, /* unc_m3upi_horz_ring_ak_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4936566 }, /* unc_m3upi_horz_ring_ak_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Left and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4938384 }, /* unc_m3upi_horz_ring_ak_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Even. Unit: uncore_m3upi \000event=0xa9,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4940203 }, /* unc_m3upi_horz_ring_ak_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal AK Ring In Use; Right and Odd. Unit: uncore_m3upi \000event=0xa9,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4945781 }, /* unc_m3upi_horz_ring_bl_in_use.left_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Even. Unit: uncore_m3upi \000event=0xab,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4947597 }, /* unc_m3upi_horz_ring_bl_in_use.left_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Left and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x2\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4949417 }, /* unc_m3upi_horz_ring_bl_in_use.right_even\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Even. Unit: uncore_m3upi \000event=0xab,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4951238 }, /* unc_m3upi_horz_ring_bl_in_use.right_odd\000uncore_m3upi\000uncore interconnect\000Horizontal BL Ring in Use; Right and Odd. Unit: uncore_m3upi \000event=0xab,umask=0x8\000\00001\000Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4952731 }, /* unc_m3upi_horz_ring_iv_in_use.left\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Left. Unit: uncore_m3upi \000event=0xad,umask=0x1\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4953910 }, /* unc_m3upi_horz_ring_iv_in_use.right\000uncore_m3upi\000uncore interconnect\000Horizontal IV Ring in Use; Right. Unit: uncore_m3upi \000event=0xad,umask=0x4\000\00001\000Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4954482 }, /* unc_m3upi_m2_bl_credits_empty.iio0_iio1_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO0 and IIO1 share the same ring destination. (1 VN0 credit only). Unit: uncore_m3upi \000event=0x23,umask=0x1\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4955306 }, /* unc_m3upi_m2_bl_credits_empty.iio2_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO2. Unit: uncore_m3upi \000event=0x23,umask=0x2\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4955718 }, /* unc_m3upi_m2_bl_credits_empty.iio3_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO3. Unit: uncore_m3upi \000event=0x23,umask=0x4\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4956130 }, /* unc_m3upi_m2_bl_credits_empty.iio4_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO4. Unit: uncore_m3upi \000event=0x23,umask=0x8\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4956543 }, /* unc_m3upi_m2_bl_credits_empty.iio5_ncb\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; IIO5. Unit: uncore_m3upi \000event=0x23,umask=0x10\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4957066 }, /* unc_m3upi_m2_bl_credits_empty.ncs\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; All IIO targets for NCS are in single mask. ORs them together. Unit: uncore_m3upi \000event=0x23,umask=0x20\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4957577 }, /* unc_m3upi_m2_bl_credits_empty.ncs_sel\000uncore_m3upi\000uncore interconnect\000M2 BL Credits Empty; Selected M2p BL NCS credits. Unit: uncore_m3upi \000event=0x23,umask=0x40\000\00001\000No vn0 and vna credits available to send to M2\000 */
{ 4958703 }, /* unc_m3upi_multi_slot_rcvd.ad_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x1\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959245 }, /* unc_m3upi_multi_slot_rcvd.ad_slot1\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 1. Unit: uncore_m3upi \000event=0x3e,umask=0x2\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4959787 }, /* unc_m3upi_multi_slot_rcvd.ad_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AD - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x4\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960330 }, /* unc_m3upi_multi_slot_rcvd.ak_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x10\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4960874 }, /* unc_m3upi_multi_slot_rcvd.ak_slot2\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; AK - Slot 2. Unit: uncore_m3upi \000event=0x3e,umask=0x20\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961417 }, /* unc_m3upi_multi_slot_rcvd.bl_slot0\000uncore_m3upi\000uncore interconnect\000Multi Slot Flit Received; BL - Slot 0. Unit: uncore_m3upi \000event=0x3e,umask=0x8\000\00001\000Multi slot flit received - S0, S1 and/or S2 populated (can use AK S0/S1 masks for AK allocations)\000 */
{ 4961973 }, /* unc_m3upi_ring_bounces_horz.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AD. Unit: uncore_m3upi \000event=0xa1,umask=0x1\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4962531 }, /* unc_m3upi_ring_bounces_horz.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; AK. Unit: uncore_m3upi \000event=0xa1,umask=0x2\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963089 }, /* unc_m3upi_ring_bounces_horz.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; BL. Unit: uncore_m3upi \000event=0xa1,umask=0x4\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4963647 }, /* unc_m3upi_ring_bounces_horz.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Horizontal Ring.; IV. Unit: uncore_m3upi \000event=0xa1,umask=0x8\000\00001\000Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4964199 }, /* unc_m3upi_ring_bounces_vert.ad\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; AD. Unit: uncore_m3upi \000event=0xa0,umask=0x1\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4964791 }, /* unc_m3upi_ring_bounces_vert.ak\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa0,umask=0x2\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4965692 }, /* unc_m3upi_ring_bounces_vert.bl\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Data Responses to core. Unit: uncore_m3upi \000event=0xa0,umask=0x4\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4966311 }, /* unc_m3upi_ring_bounces_vert.iv\000uncore_m3upi\000uncore interconnect\000Messages that bounced on the Vertical Ring.; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa0,umask=0x8\000\00001\000Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4966740 }, /* unc_m3upi_ring_sink_starved_horz.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AD. Unit: uncore_m3upi \000event=0xa3,umask=0x1\000\00001\000\000 */
{ 4967051 }, /* unc_m3upi_ring_sink_starved_horz.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; AK. Unit: uncore_m3upi \000event=0xa3,umask=0x2\000\00001\000\000 */
{ 4967392 }, /* unc_m3upi_ring_sink_starved_horz.ak_ag1\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; Acknowledgements to Agent 1. Unit: uncore_m3upi \000event=0xa3,umask=0x20\000\00001\000\000 */
{ 4967733 }, /* unc_m3upi_ring_sink_starved_horz.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; BL. Unit: uncore_m3upi \000event=0xa3,umask=0x4\000\00001\000\000 */
{ 4968044 }, /* unc_m3upi_ring_sink_starved_horz.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Horizontal Ring; IV. Unit: uncore_m3upi \000event=0xa3,umask=0x8\000\00001\000\000 */
{ 4968353 }, /* unc_m3upi_ring_sink_starved_vert.ad\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; AD. Unit: uncore_m3upi \000event=0xa2,umask=0x1\000\00001\000\000 */
{ 4968682 }, /* unc_m3upi_ring_sink_starved_vert.ak\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Acknowledgements to core. Unit: uncore_m3upi \000event=0xa2,umask=0x2\000\00001\000\000 */
{ 4969182 }, /* unc_m3upi_ring_sink_starved_vert.bl\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Data Responses to core. Unit: uncore_m3upi \000event=0xa2,umask=0x4\000\00001\000\000 */
{ 4969534 }, /* unc_m3upi_ring_sink_starved_vert.iv\000uncore_m3upi\000uncore interconnect\000Sink Starvation on Vertical Ring; Snoops of processor's cache. Unit: uncore_m3upi \000event=0xa2,umask=0x8\000\00001\000\000 */
{ 4969712 }, /* unc_m3upi_ring_src_thrtl\000uncore_m3upi\000uncore interconnect\000Source Throttle. Unit: uncore_m3upi \000event=0xa4\000\00001\000\000 */
{ 4970259 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x1\000\00001\000VN0 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4970901 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x4\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4971498 }, /* unc_m3upi_rxc_arb_lost_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x4b,umask=0x2\000\00001\000VN0 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4972113 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x20\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4972710 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x40\000\00001\000VN0 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4973288 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x8\000\00001\000VN0 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4974011 }, /* unc_m3upi_rxc_arb_lost_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x4b,umask=0x10\000\00001\000VN0 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4974711 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x1\000\00001\000VN1 message requested but lost arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4975353 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x4\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4975950 }, /* unc_m3upi_rxc_arb_lost_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4c,umask=0x2\000\00001\000VN1 message requested but lost arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4976565 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x20\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4977162 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x40\000\00001\000VN1 message requested but lost arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4977740 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x8\000\00001\000VN1 message requested but lost arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4978463 }, /* unc_m3upi_rxc_arb_lost_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Lost Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4c,umask=0x10\000\00001\000VN1 message requested but lost arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4978838 }, /* unc_m3upi_rxc_arb_misc.adbl_parallel_win\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; AD, BL Parallel Win. Unit: uncore_m3upi \000event=0x4d,umask=0x40\000\00001\000AD and BL messages won arbitration concurrently / in parallel\000 */
{ 4980246 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x4\000\00001\000Arbitration stage made no progress on pending ad vn0 messages because slotting stage cannot accept new message\000 */
{ 4980853 }, /* unc_m3upi_rxc_arb_misc.no_prog_ad_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending AD VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x8\000\00001\000Arbitration stage made no progress on pending ad vn1 messages because slotting stage cannot accept new message\000 */
{ 4981460 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x10\000\00001\000Arbitration stage made no progress on pending bl vn0 messages because slotting stage cannot accept new message\000 */
{ 4982068 }, /* unc_m3upi_rxc_arb_misc.no_prog_bl_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; No Progress on Pending BL VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x20\000\00001\000Arbitration stage made no progress on pending bl vn1 messages because slotting stage cannot accept new message\000 */
{ 4982346 }, /* unc_m3upi_rxc_arb_misc.par_bias_vn0\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN0. Unit: uncore_m3upi \000event=0x4d,umask=0x1\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn0, delaying vn1 win, because vn0 offered parallel ad/bl\000 */
{ 4982607 }, /* unc_m3upi_rxc_arb_misc.par_bias_vn1\000uncore_m3upi\000uncore interconnect\000Arb Miscellaneous; Parallel Bias to VN1. Unit: uncore_m3upi \000event=0x4d,umask=0x2\000\00001\000VN0/VN1 arbiter gave second, consecutive win to vn1, delaying vn0 win, because vn1 offered parallel ad/bl\000 */
{ 4983171 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x49,umask=0x1\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4983514 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x4\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4983882 }, /* unc_m3upi_rxc_arb_noad_req_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x49,umask=0x2\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4984180 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x20\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4984566 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x49,umask=0x40\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4984846 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x49,umask=0x8\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4985213 }, /* unc_m3upi_rxc_arb_noad_req_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x49,umask=0x10\000\00001\000VN0 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4985639 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x1\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4985982 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x4\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4986350 }, /* unc_m3upi_rxc_arb_noad_req_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x4a,umask=0x2\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4986648 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x20\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4987034 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x40\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4987314 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x8\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4987681 }, /* unc_m3upi_rxc_arb_noad_req_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000Can't Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x4a,umask=0x10\000\00001\000VN1 message was not able to request arbitration while some other message won arbitration; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4993643 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; REQ on AD. Unit: uncore_m3upi \000event=0x47,umask=0x1\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4993988 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x4\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4994358 }, /* unc_m3upi_rxc_arb_nocred_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; SNP on AD. Unit: uncore_m3upi \000event=0x47,umask=0x2\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4994658 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x20\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4995046 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; NCS on BL. Unit: uncore_m3upi \000event=0x47,umask=0x40\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4995328 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; RSP on BL. Unit: uncore_m3upi \000event=0x47,umask=0x8\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4995697 }, /* unc_m3upi_rxc_arb_nocred_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN0; WB on BL. Unit: uncore_m3upi \000event=0x47,umask=0x10\000\00001\000VN0 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 4996125 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; REQ on AD. Unit: uncore_m3upi \000event=0x48,umask=0x1\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 4996470 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x4\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4996840 }, /* unc_m3upi_rxc_arb_nocred_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; SNP on AD. Unit: uncore_m3upi \000event=0x48,umask=0x2\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 4997140 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x20\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 4997528 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; NCS on BL. Unit: uncore_m3upi \000event=0x48,umask=0x40\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Non-Coherent Standard (NCS) messages on BL\000 */
{ 4997810 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; RSP on BL. Unit: uncore_m3upi \000event=0x48,umask=0x8\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 4998179 }, /* unc_m3upi_rxc_arb_nocred_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000No Credits to Arb for VN1; WB on BL. Unit: uncore_m3upi \000event=0x48,umask=0x10\000\00001\000VN1 message is blocked from requesting arbitration due to lack of remote UPI credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5004336 }, /* unc_m3upi_rxc_bypassed.ad_s0_bl_arb\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on BL Arb. Unit: uncore_m3upi \000event=0x40,umask=0x2\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while bl message is in arbitration\000 */
{ 5004988 }, /* unc_m3upi_rxc_bypassed.ad_s0_idle\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD to Slot 0 on Idle. Unit: uncore_m3upi \000event=0x40,umask=0x1\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to slot 0 of independent flit while pipeline is idle\000 */
{ 5005626 }, /* unc_m3upi_rxc_bypassed.ad_s1_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 1. Unit: uncore_m3upi \000event=0x40,umask=0x4\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 1 while merging with bl message in same flit\000 */
{ 5006269 }, /* unc_m3upi_rxc_bypassed.ad_s2_bl_slot\000uncore_m3upi\000uncore interconnect\000Ingress Queue Bypasses; AD + BL to Slot 2. Unit: uncore_m3upi \000event=0x40,umask=0x8\000\00001\000Number of times message is bypassed around the Ingress Queue; AD is taking bypass to flit slot 2 while merging with bl message in same flit\000 */
{ 5006567 }, /* unc_m3upi_rxc_collision_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x50,umask=0x1\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5006906 }, /* unc_m3upi_rxc_collision_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x4\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5007270 }, /* unc_m3upi_rxc_collision_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x50,umask=0x2\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5007564 }, /* unc_m3upi_rxc_collision_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x20\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5007946 }, /* unc_m3upi_rxc_collision_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x50,umask=0x40\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5008222 }, /* unc_m3upi_rxc_collision_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x50,umask=0x8\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5008585 }, /* unc_m3upi_rxc_collision_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x50,umask=0x10\000\00001\000Count cases where Ingress VN0 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5009007 }, /* unc_m3upi_rxc_collision_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; REQ on AD. Unit: uncore_m3upi \000event=0x51,umask=0x1\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5009346 }, /* unc_m3upi_rxc_collision_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x4\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5009710 }, /* unc_m3upi_rxc_collision_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; SNP on AD. Unit: uncore_m3upi \000event=0x51,umask=0x2\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5010004 }, /* unc_m3upi_rxc_collision_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x20\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5010386 }, /* unc_m3upi_rxc_collision_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; NCS on BL. Unit: uncore_m3upi \000event=0x51,umask=0x40\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5010662 }, /* unc_m3upi_rxc_collision_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; RSP on BL. Unit: uncore_m3upi \000event=0x51,umask=0x8\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5011025 }, /* unc_m3upi_rxc_collision_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message lost contest for flit; WB on BL. Unit: uncore_m3upi \000event=0x51,umask=0x10\000\00001\000Count cases where Ingress VN1 packets lost the contest for Flit Slot 0.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5011725 }, /* unc_m3upi_rxc_crd_misc.any_bgf_fifo\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any In BGF FIFO. Unit: uncore_m3upi \000event=0x60,umask=0x1\000\00001\000Indication that at least one packet (flit) is in the bgf (fifo only)\000 */
{ 5012245 }, /* unc_m3upi_rxc_crd_misc.any_bgf_path\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; Any in BGF Path. Unit: uncore_m3upi \000event=0x60,umask=0x2\000\00001\000Indication that at least one packet (flit) is in the bgf path (i.e. pipe to fifo)\000 */
{ 5012897 }, /* unc_m3upi_rxc_crd_misc.no_d2k_for_arb\000uncore_m3upi\000uncore interconnect\000Miscellaneous Credit Events; No D2K For Arb. Unit: uncore_m3upi \000event=0x60,umask=0x4\000\00001\000VN0 or VN1 BL RSP message was blocked from arbitration request due to lack of D2K CMP credits\000 */
{ 5014209 }, /* unc_m3upi_rxc_crd_occ.d2k_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; D2K Credits. Unit: uncore_m3upi \000event=0x61,umask=0x10\000\00001\000D2K completion fifo credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5014703 }, /* unc_m3upi_rxc_crd_occ.flits_in_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF FIFO. Unit: uncore_m3upi \000event=0x61,umask=0x2\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in fifo\000 */
{ 5015227 }, /* unc_m3upi_rxc_crd_occ.flits_in_path\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Packets in BGF Path. Unit: uncore_m3upi \000event=0x61,umask=0x4\000\00001\000Occupancy of m3upi ingress -> upi link layer bgf; packets (flits) in path (i.e. pipe to fifo or fifo)\000 */
{ 5015699 }, /* unc_m3upi_rxc_crd_occ.p1p_fifo\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x40\000\00001\000count of bl messages in pump-1-pending state, in completion fifo only\000 */
{ 5016119 }, /* unc_m3upi_rxc_crd_occ.p1p_total\000uncore_m3upi\000uncore interconnect\000Credit Occupancy. Unit: uncore_m3upi \000event=0x61,umask=0x20\000\00001\000count of bl messages in pump-1-pending state, in marker table and in fifo\000 */
{ 5016596 }, /* unc_m3upi_rxc_crd_occ.txq_crd\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; Transmit Credits. Unit: uncore_m3upi \000event=0x61,umask=0x8\000\00001\000Link layer transmit queue credit occupancy (credits in use), accumulated across all cycles\000 */
{ 5017095 }, /* unc_m3upi_rxc_crd_occ.vna_in_use\000uncore_m3upi\000uncore interconnect\000Credit Occupancy; VNA In Use. Unit: uncore_m3upi \000event=0x61,umask=0x1\000\00001\000Remote UPI VNA credit occupancy (number of credits in use), accumulated across all cycles\000 */
{ 5018013 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x43,umask=0x1\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5019348 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x4\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5020638 }, /* unc_m3upi_rxc_cycles_ne_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x43,umask=0x2\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5021946 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x20\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5023236 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x43,umask=0x40\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5024507 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x43,umask=0x8\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5025923 }, /* unc_m3upi_rxc_cycles_ne_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x43,umask=0x10\000\00001\000Counts the number of cycles when the UPI Ingress is not empty.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5027316 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; REQ on AD. Unit: uncore_m3upi \000event=0x44,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5028651 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5029941 }, /* unc_m3upi_rxc_cycles_ne_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; SNP on AD. Unit: uncore_m3upi \000event=0x44,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5031249 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5032539 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; NCS on BL. Unit: uncore_m3upi \000event=0x44,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5033810 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; RSP on BL. Unit: uncore_m3upi \000event=0x44,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5035226 }, /* unc_m3upi_rxc_cycles_ne_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Cycles Not Empty; WB on BL. Unit: uncore_m3upi \000event=0x44,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5037823 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate. Unit: uncore_m3upi \000event=0x53,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting control state machine is in any accumulate state; multi-message flit may be assembled over multiple cycles\000 */
{ 5038553 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_read\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Ready. Unit: uncore_m3upi \000event=0x53,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 1; header flit slotting control state machine is in accum_ready state; flit is ready to send but transmission is blocked; more messages may be slotted into flit\000 */
{ 5039314 }, /* unc_m3upi_rxc_flit_gen_hdr1.accum_wasted\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Accumulate Wasted. Unit: uncore_m3upi \000event=0x53,umask=0x4\000\00001\000Events related to Header Flit Generation - Set 1; Flit is being assembled over multiple cycles, but no additional message is being slotted into flit in current cycle; accumulate cycle is wasted\000 */
{ 5040059 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_blocked\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Blocked. Unit: uncore_m3upi \000event=0x53,umask=0x8\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting entered run-ahead state; new header flit is started while transmission of prior, fully assembled flit is blocked\000 */
{ 5041675 }, /* unc_m3upi_rxc_flit_gen_hdr1.ahead_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Run-Ahead - Message. Unit: uncore_m3upi \000event=0x53,umask=0x10\000\00001\000Events related to Header Flit Generation - Set 1; Header flit slotting is in run-ahead to start new flit, and message is actually slotted into new flit\000 */
{ 5041986 }, /* unc_m3upi_rxc_flit_gen_hdr1.par\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Ok. Unit: uncore_m3upi \000event=0x53,umask=0x20\000\00001\000Events related to Header Flit Generation - Set 1; New header flit construction may proceed in parallel with data flit sequence\000 */
{ 5042258 }, /* unc_m3upi_rxc_flit_gen_hdr1.par_flit\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Flit Finished. Unit: uncore_m3upi \000event=0x53,umask=0x80\000\00001\000Events related to Header Flit Generation - Set 1; Header flit finished assembly in parallel with data flit sequence\000 */
{ 5042535 }, /* unc_m3upi_rxc_flit_gen_hdr1.par_msg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 1; Parallel Message. Unit: uncore_m3upi \000event=0x53,umask=0x40\000\00001\000Events related to Header Flit Generation - Set 1; Message is slotted into header flit in parallel with data flit sequence\000 */
{ 5044045 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall. Unit: uncore_m3upi \000event=0x54,umask=0x1\000\00001\000Events related to Header Flit Generation - Set 2; Rate-matching stall injected\000 */
{ 5044647 }, /* unc_m3upi_rxc_flit_gen_hdr2.rmstall_nomsg\000uncore_m3upi\000uncore interconnect\000Flit Gen - Header 2; Rate-matching Stall - No Message. Unit: uncore_m3upi \000event=0x54,umask=0x2\000\00001\000Events related to Header Flit Generation - Set 2; Rate matching stall injected, but no additional message slotted during stall cycle\000 */
{ 5044955 }, /* unc_m3upi_rxc_flit_not_sent.all\000uncore_m3upi\000uncore interconnect\000Header Not Sent; All. Unit: uncore_m3upi \000event=0x55,umask=0x1\000\00001\000header flit is ready for transmission but could not be sent\000 */
{ 5045147 }, /* unc_m3upi_rxc_flit_not_sent.no_bgf_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x55,umask=0x2\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available\000 */
{ 5045383 }, /* unc_m3upi_rxc_flit_not_sent.no_bgf_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No BGF Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x8\000\00001\000header flit is ready for transmission but could not be sent; No BGF credits available; no additional message slotted into flit\000 */
{ 5045690 }, /* unc_m3upi_rxc_flit_not_sent.no_txq_crd\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x55,umask=0x4\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available\000 */
{ 5045926 }, /* unc_m3upi_rxc_flit_not_sent.no_txq_no_msg\000uncore_m3upi\000uncore interconnect\000Header Not Sent; No TxQ Credits + No Extra Message Slotted. Unit: uncore_m3upi \000event=0x55,umask=0x10\000\00001\000header flit is ready for transmission but could not be sent; No TxQ credits available; no additional message slotted into flit\000 */
{ 5046234 }, /* unc_m3upi_rxc_flit_not_sent.one_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - One Slot Taken. Unit: uncore_m3upi \000event=0x55,umask=0x20\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only one slot taken (two slots free)\000 */
{ 5046514 }, /* unc_m3upi_rxc_flit_not_sent.three_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Three Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x80\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with three slots taken (no slots free)\000 */
{ 5046796 }, /* unc_m3upi_rxc_flit_not_sent.two_taken\000uncore_m3upi\000uncore interconnect\000Header Not Sent; Sent - Two Slots Taken. Unit: uncore_m3upi \000event=0x55,umask=0x40\000\00001\000header flit is ready for transmission but could not be sent; sending header flit with only two slots taken (one slots free)\000 */
{ 5047078 }, /* unc_m3upi_rxc_flits_data_not_sent.all\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; All. Unit: uncore_m3upi \000event=0x57,umask=0x1\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047277 }, /* unc_m3upi_rxc_flits_data_not_sent.no_bgf\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No BGF Credits. Unit: uncore_m3upi \000event=0x57,umask=0x2\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047490 }, /* unc_m3upi_rxc_flits_data_not_sent.no_txq\000uncore_m3upi\000uncore interconnect\000Data Flit Not Sent; No TxQ Credits. Unit: uncore_m3upi \000event=0x57,umask=0x4\000\00001\000Data flit is ready for transmission but could not be sent\000 */
{ 5047977 }, /* unc_m3upi_rxc_flits_gen_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 0. Unit: uncore_m3upi \000event=0x59,umask=0x1\000\00001\000generating bl data flit sequence; waiting for data pump 0\000 */
{ 5048472 }, /* unc_m3upi_rxc_flits_gen_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence; Wait on Pump 1. Unit: uncore_m3upi \000event=0x59,umask=0x2\000\00001\000generating bl data flit sequence; waiting for data pump 1\000 */
{ 5048963 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_at_limit\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x10\000\00001\000pump-1-pending logic is at capacity (pending table plus completion fifo at limit)\000 */
{ 5049435 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_busy\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x8\000\00001\000pump-1-pending logic is tracking at least one message\000 */
{ 5049865 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_fifo_full\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x40\000\00001\000pump-1-pending completion fifo is full\000 */
{ 5050362 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_hold_p0\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x20\000\00001\000pump-1-pending logic is at or near capacity, such that pump-0-only bl messages are getting stalled in slotting stage\000 */
{ 5050890 }, /* unc_m3upi_rxc_flits_gen_bl.p1p_to_limbo\000uncore_m3upi\000uncore interconnect\000Generating BL Data Flit Sequence. Unit: uncore_m3upi \000event=0x59,umask=0x4\000\00001\000a bl message finished but is in limbo and moved to pump-1-pending logic\000 */
{ 5052047 }, /* unc_m3upi_rxc_flits_misc\000uncore_m3upi\000uncore interconnect\000UNC_M3UPI_RxC_FLITS_MISC. Unit: uncore_m3upi \000event=0x5a\000\00001\000\000 */
{ 5052167 }, /* unc_m3upi_rxc_flits_sent.1_msg\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message. Unit: uncore_m3upi \000event=0x56,umask=0x1\000\00001\000One message in flit; VNA or non-VNA flit\000 */
{ 5052348 }, /* unc_m3upi_rxc_flits_sent.1_msg_vnx\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; One Message in non-VNA. Unit: uncore_m3upi \000event=0x56,umask=0x8\000\00001\000One message in flit; non-VNA flit\000 */
{ 5052537 }, /* unc_m3upi_rxc_flits_sent.2_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Two Messages. Unit: uncore_m3upi \000event=0x56,umask=0x2\000\00001\000Two messages in flit; VNA flit\000 */
{ 5052710 }, /* unc_m3upi_rxc_flits_sent.3_msgs\000uncore_m3upi\000uncore interconnect\000Sent Header Flit; Three Messages. Unit: uncore_m3upi \000event=0x56,umask=0x4\000\00001\000Three messages in flit; VNA flit\000 */
{ 5052887 }, /* unc_m3upi_rxc_flits_sent.slots_1\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x10\000\00001\000\000 */
{ 5053018 }, /* unc_m3upi_rxc_flits_sent.slots_2\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x20\000\00001\000\000 */
{ 5053149 }, /* unc_m3upi_rxc_flits_sent.slots_3\000uncore_m3upi\000uncore interconnect\000Sent Header Flit. Unit: uncore_m3upi \000event=0x56,umask=0x40\000\00001\000\000 */
{ 5053435 }, /* unc_m3upi_rxc_flits_slot_bl.all\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; All. Unit: uncore_m3upi \000event=0x58,umask=0x1\000\00001\000\000 */
{ 5053857 }, /* unc_m3upi_rxc_flits_slot_bl.need_data\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Needs Data Flit. Unit: uncore_m3upi \000event=0x58,umask=0x2\000\00001\000BL message requires data flit sequence\000 */
{ 5054318 }, /* unc_m3upi_rxc_flits_slot_bl.p0_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 0. Unit: uncore_m3upi \000event=0x58,umask=0x4\000\00001\000Waiting for header pump 0\000 */
{ 5054786 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x10\000\00001\000Header pump 1 is not required for flit\000 */
{ 5055333 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_but_bubble\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Bubble. Unit: uncore_m3upi \000event=0x58,umask=0x20\000\00001\000Header pump 1 is not required for flit but flit transmission delayed\000 */
{ 5055923 }, /* unc_m3upi_rxc_flits_slot_bl.p1_not_req_not_avail\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Don't Need Pump 1 - Not Avail. Unit: uncore_m3upi \000event=0x58,umask=0x40\000\00001\000Header pump 1 is not required for flit and not available\000 */
{ 5056428 }, /* unc_m3upi_rxc_flits_slot_bl.p1_wait\000uncore_m3upi\000uncore interconnect\000Slotting BL Message Into Header Flit; Wait on Pump 1. Unit: uncore_m3upi \000event=0x58,umask=0x8\000\00001\000Waiting for header pump 1\000 */
{ 5060558 }, /* unc_m3upi_rxc_held.cant_slot_ad\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot AD. Unit: uncore_m3upi \000event=0x52,umask=0x40\000\00001\000some AD message could not be slotted (logical OR of all AD events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061068 }, /* unc_m3upi_rxc_held.cant_slot_bl\000uncore_m3upi\000uncore interconnect\000Message Held; Can't Slot BL. Unit: uncore_m3upi \000event=0x52,umask=0x80\000\00001\000some BL message could not be slotted (logical OR of all BL events under INGR_SLOT_CANT_MC_VN{0,1})\000 */
{ 5061307 }, /* unc_m3upi_rxc_held.parallel_ad_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel AD Lost. Unit: uncore_m3upi \000event=0x52,umask=0x10\000\00001\000some AD message lost contest for slot 0 (logical OR of all AD events under INGR_SLOT_LOST_MC_VN{0,1})\000 */
{ 5061805 }, /* unc_m3upi_rxc_held.parallel_attempt\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Attempt. Unit: uncore_m3upi \000event=0x52,umask=0x4\000\00001\000ad and bl messages attempted to slot into the same flit in parallel\000 */
{ 5062019 }, /* unc_m3upi_rxc_held.parallel_bl_lost\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel BL Lost. Unit: uncore_m3upi \000event=0x52,umask=0x20\000\00001\000some BL message lost contest for slot 0 (logical OR of all BL events under INGR_SLOT_LOST_MC_VN{0,1})\000 */
{ 5062521 }, /* unc_m3upi_rxc_held.parallel_success\000uncore_m3upi\000uncore interconnect\000Message Held; Parallel Success. Unit: uncore_m3upi \000event=0x52,umask=0x8\000\00001\000ad and bl messages were actually slotted into the same flit in parallel\000 */
{ 5062993 }, /* unc_m3upi_rxc_held.vn0\000uncore_m3upi\000uncore interconnect\000Message Held; VN0. Unit: uncore_m3upi \000event=0x52,umask=0x1\000\00001\000vn0 message(s) that couldn't be slotted into last vn0 flit are held in slotting stage while processing vn1 flit\000 */
{ 5063479 }, /* unc_m3upi_rxc_held.vn1\000uncore_m3upi\000uncore interconnect\000Message Held; VN1. Unit: uncore_m3upi \000event=0x52,umask=0x2\000\00001\000vn1 message(s) that couldn't be slotted into last vn1 flit are held in slotting stage while processing vn0 flit\000 */
{ 5064368 }, /* unc_m3upi_rxc_inserts_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x41,umask=0x1\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5065652 }, /* unc_m3upi_rxc_inserts_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x4\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5066891 }, /* unc_m3upi_rxc_inserts_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x41,umask=0x2\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5068148 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x20\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5069387 }, /* unc_m3upi_rxc_inserts_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x41,umask=0x40\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5070607 }, /* unc_m3upi_rxc_inserts_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x41,umask=0x8\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5071972 }, /* unc_m3upi_rxc_inserts_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x41,umask=0x10\000\00001\000Counts the number of allocations into the UPI Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5073324 }, /* unc_m3upi_rxc_inserts_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; REQ on AD. Unit: uncore_m3upi \000event=0x42,umask=0x1\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5074628 }, /* unc_m3upi_rxc_inserts_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x4\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5075887 }, /* unc_m3upi_rxc_inserts_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; SNP on AD. Unit: uncore_m3upi \000event=0x42,umask=0x2\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5077164 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x20\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5078423 }, /* unc_m3upi_rxc_inserts_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; NCS on BL. Unit: uncore_m3upi \000event=0x42,umask=0x40\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5079663 }, /* unc_m3upi_rxc_inserts_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; RSP on BL. Unit: uncore_m3upi \000event=0x42,umask=0x8\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5081048 }, /* unc_m3upi_rxc_inserts_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Inserts; WB on BL. Unit: uncore_m3upi \000event=0x42,umask=0x10\000\00001\000Counts the number of allocations into the UPI VN1  Ingress.  This tracks one of the three rings that are used by the UPI agent.  This can be used in conjunction with the UPI VN1  Ingress Occupancy Accumulator event in order to calculate average queue latency.  Multiple ingress buffers can be tracked at a given time using multiple counters.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5082381 }, /* unc_m3upi_rxc_occupancy_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x45,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5083625 }, /* unc_m3upi_rxc_occupancy_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5084824 }, /* unc_m3upi_rxc_occupancy_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x45,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5086041 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5087240 }, /* unc_m3upi_rxc_occupancy_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x45,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5088420 }, /* unc_m3upi_rxc_occupancy_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x45,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5089745 }, /* unc_m3upi_rxc_occupancy_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x45,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5091047 }, /* unc_m3upi_rxc_occupancy_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; REQ on AD. Unit: uncore_m3upi \000event=0x46,umask=0x1\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5092291 }, /* unc_m3upi_rxc_occupancy_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x4\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5093490 }, /* unc_m3upi_rxc_occupancy_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; SNP on AD. Unit: uncore_m3upi \000event=0x46,umask=0x2\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5094707 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x20\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5095906 }, /* unc_m3upi_rxc_occupancy_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; NCS on BL. Unit: uncore_m3upi \000event=0x46,umask=0x40\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5097086 }, /* unc_m3upi_rxc_occupancy_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; RSP on BL. Unit: uncore_m3upi \000event=0x46,umask=0x8\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5098411 }, /* unc_m3upi_rxc_occupancy_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 Ingress (from CMS) Queue - Occupancy; WB on BL. Unit: uncore_m3upi \000event=0x46,umask=0x10\000\00001\000Accumulates the occupancy of a given UPI VN1  Ingress queue in each cycle.  This tracks one of the three ring Ingress buffers.  This can be used with the UPI VN1  Ingress Not Empty event to calculate average occupancy or the UPI VN1  Ingress Allocations event in order to calculate average queuing latency.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5099553 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_req\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5100485 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5101372 }, /* unc_m3upi_rxc_packing_miss_vn0.ad_snp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4e,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5102277 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5103164 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5104032 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5105045 }, /* unc_m3upi_rxc_packing_miss_vn0.bl_wb\000uncore_m3upi\000uncore interconnect\000VN0 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4e,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5106035 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_req\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; REQ on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x1\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5106967 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x4\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5107854 }, /* unc_m3upi_rxc_packing_miss_vn1.ad_snp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; SNP on AD. Unit: uncore_m3upi \000event=0x4f,umask=0x2\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5108759 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x20\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5109646 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_ncs\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; NCS on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x40\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Non-Coherent Standard (NCS) messages on BL\000 */
{ 5110514 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_rsp\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; RSP on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x8\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5111527 }, /* unc_m3upi_rxc_packing_miss_vn1.bl_wb\000uncore_m3upi\000uncore interconnect\000VN1 message can't slot into flit; WB on BL. Unit: uncore_m3upi \000event=0x4f,umask=0x10\000\00001\000Count cases where Ingress has packets to send but did not have time to pack into flit before sending to Agent so slot was left NULL which could have been used.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5112039 }, /* unc_m3upi_rxc_smi3_pftch.arb_lost\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Lost Arbitration. Unit: uncore_m3upi \000event=0x62,umask=0x2\000\00001\000\000 */
{ 5112194 }, /* unc_m3upi_rxc_smi3_pftch.arrived\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Arrived. Unit: uncore_m3upi \000event=0x62,umask=0x1\000\00001\000\000 */
{ 5112339 }, /* unc_m3upi_rxc_smi3_pftch.drop_old\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Old. Unit: uncore_m3upi \000event=0x62,umask=0x8\000\00001\000\000 */
{ 5112491 }, /* unc_m3upi_rxc_smi3_pftch.drop_wrap\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Dropped - Wrap. Unit: uncore_m3upi \000event=0x62,umask=0x10\000\00001\000Dropped because it was overwritten by new message while prefetch queue was full\000 */
{ 5112725 }, /* unc_m3upi_rxc_smi3_pftch.slotted\000uncore_m3upi\000uncore interconnect\000SMI3 Prefetch Messages; Slotted. Unit: uncore_m3upi \000event=0x62,umask=0x4\000\00001\000\000 */
{ 5113090 }, /* unc_m3upi_rxc_vna_crd.any_in_use\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Any In Use. Unit: uncore_m3upi \000event=0x5b,umask=0x20\000\00001\000At least one remote vna credit is in use\000 */
{ 5113514 }, /* unc_m3upi_rxc_vna_crd.corrected\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Corrected. Unit: uncore_m3upi \000event=0x5b,umask=0x2\000\00001\000Number of remote vna credits corrected (local return) per cycle\000 */
{ 5114207 }, /* unc_m3upi_rxc_vna_crd.lt1\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 1. Unit: uncore_m3upi \000event=0x5b,umask=0x4\000\00001\000Remote vna credit level is less than 1 (i.e. no vna credits available)\000 */
{ 5114667 }, /* unc_m3upi_rxc_vna_crd.lt4\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 4. Unit: uncore_m3upi \000event=0x5b,umask=0x8\000\00001\000Remote vna credit level is less than 4; bl (or ad requiring 4 vna) cannot arb on vna\000 */
{ 5115135 }, /* unc_m3upi_rxc_vna_crd.lt5\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Level < 5. Unit: uncore_m3upi \000event=0x5b,umask=0x10\000\00001\000Remote vna credit level is less than 5; parallel ad/bl arb on vna not possible\000 */
{ 5115350 }, /* unc_m3upi_rxc_vna_crd.used\000uncore_m3upi\000uncore interconnect\000Remote VNA Credits; Used. Unit: uncore_m3upi \000event=0x5b,umask=0x1\000\00001\000Number of remote vna credits consumed per cycle\000 */
{ 5117873 }, /* unc_m3upi_rxr_busy_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5118721 }, /* unc_m3upi_rxr_busy_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5120047 }, /* unc_m3upi_rxr_busy_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb4,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5120895 }, /* unc_m3upi_rxr_busy_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb4,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 5122008 }, /* unc_m3upi_rxr_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x1\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5122436 }, /* unc_m3upi_rxr_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AD - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x10\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5123081 }, /* unc_m3upi_rxr_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; AK - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x2\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5123777 }, /* unc_m3upi_rxr_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x4\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5124205 }, /* unc_m3upi_rxr_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; BL - Credit. Unit: uncore_m3upi \000event=0xb2,umask=0x40\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5124850 }, /* unc_m3upi_rxr_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Bypass; IV - Bounce. Unit: uncore_m3upi \000event=0xb2,umask=0x8\000\00001\000Number of packets bypassing the CMS Ingress\000 */
{ 5125524 }, /* unc_m3upi_rxr_crd_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x1\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5126394 }, /* unc_m3upi_rxr_crd_starved.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AD - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x10\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5127705 }, /* unc_m3upi_rxr_crd_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x2\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5128597 }, /* unc_m3upi_rxr_crd_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x4\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5129467 }, /* unc_m3upi_rxr_crd_starved.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; BL - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x40\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5130804 }, /* unc_m3upi_rxr_crd_starved.ifv\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IFV - Credit. Unit: uncore_m3upi \000event=0xb3,umask=0x80\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5131646 }, /* unc_m3upi_rxr_crd_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0xb3,umask=0x8\000\00001\000Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 5132802 }, /* unc_m3upi_rxr_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x1\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5133375 }, /* unc_m3upi_rxr_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AD - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x10\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5134240 }, /* unc_m3upi_rxr_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; AK - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x2\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5135156 }, /* unc_m3upi_rxr_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x4\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5135729 }, /* unc_m3upi_rxr_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; BL - Credit. Unit: uncore_m3upi \000event=0xb1,umask=0x40\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5136594 }, /* unc_m3upi_rxr_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Allocations; IV - Bounce. Unit: uncore_m3upi \000event=0xb1,umask=0x8\000\00001\000Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 5137194 }, /* unc_m3upi_rxr_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x1\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5137781 }, /* unc_m3upi_rxr_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x10\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5138666 }, /* unc_m3upi_rxr_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x2\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5139602 }, /* unc_m3upi_rxr_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x4\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5140189 }, /* unc_m3upi_rxr_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0xb0,umask=0x40\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5141074 }, /* unc_m3upi_rxr_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000Transgress Ingress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0xb0,umask=0x8\000\00001\000Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 5157404 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd0,umask=0x1\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5157704 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd0,umask=0x2\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158004 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd0,umask=0x4\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158304 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd0,umask=0x8\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158604 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd0,umask=0x10\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5158905 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd0,umask=0x20\000\00001\000Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159206 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd2,umask=0x1\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159506 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd2,umask=0x2\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5159806 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd2,umask=0x4\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160106 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd2,umask=0x8\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160406 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd2,umask=0x10\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5160707 }, /* unc_m3upi_stall_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd2,umask=0x20\000\00001\000Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161008 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd4,umask=0x1\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161308 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd4,umask=0x2\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161608 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd4,umask=0x4\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5161908 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd4,umask=0x8\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162208 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd4,umask=0x10\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162509 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd4,umask=0x20\000\00001\000Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5162810 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 0. Unit: uncore_m3upi \000event=0xd6,umask=0x1\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163110 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 1. Unit: uncore_m3upi \000event=0xd6,umask=0x2\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163410 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 2. Unit: uncore_m3upi \000event=0xd6,umask=0x4\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5163710 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 3. Unit: uncore_m3upi \000event=0xd6,umask=0x8\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164010 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 4. Unit: uncore_m3upi \000event=0xd6,umask=0x10\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164311 }, /* unc_m3upi_stall_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m3upi\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits; For Transgress 5. Unit: uncore_m3upi \000event=0xd6,umask=0x20\000\00001\000Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 5164853 }, /* unc_m3upi_txc_ad_arb_fail.vn0_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x1\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5165295 }, /* unc_m3upi_txc_ad_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x4\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5165737 }, /* unc_m3upi_txc_ad_arb_fail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x2\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5166176 }, /* unc_m3upi_txc_ad_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN0 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x8\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5166617 }, /* unc_m3upi_txc_ad_arb_fail.vn1_req\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x30,umask=0x10\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167061 }, /* unc_m3upi_txc_ad_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x40\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167505 }, /* unc_m3upi_txc_ad_arb_fail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x30,umask=0x20\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5167946 }, /* unc_m3upi_txc_ad_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for AD; VN1 WB Messages. Unit: uncore_m3upi \000event=0x30,umask=0x80\000\00001\000AD arb but no win; arb request asserted but not won\000 */
{ 5168441 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot0\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x1\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169013 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot1\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x2\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5169585 }, /* unc_m3upi_txc_ad_flq_bypass.ad_slot2\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x4\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170161 }, /* unc_m3upi_txc_ad_flq_bypass.bl_early_rsp\000uncore_m3upi\000uncore interconnect\000AD FlowQ Bypass. Unit: uncore_m3upi \000event=0x2c,umask=0x8\000\00001\000Counts cases when the AD flowQ is bypassed (S0, S1 and S2 indicate which slot was bypassed with S0 having the highest priority and S2 the least)\000 */
{ 5170986 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x1\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171440 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x4\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5171894 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x2\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172345 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x8\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5172798 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x27,umask=0x10\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173254 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x40\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5173710 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x27,umask=0x20\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174163 }, /* unc_m3upi_txc_ad_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x27,umask=0x80\000\00001\000Number of cycles the AD Egress queue is Not Empty\000 */
{ 5174859 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5175801 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5176743 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5177682 }, /* unc_m3upi_txc_ad_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5178623 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5179567 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5180511 }, /* unc_m3upi_txc_ad_flq_inserts.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Inserts; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x2d,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5181121 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 5181436 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x4\000\00001\000\000 */
{ 5181751 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 5182064 }, /* unc_m3upi_txc_ad_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x8\000\00001\000\000 */
{ 5182378 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_req\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x10\000\00001\000\000 */
{ 5182695 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x40\000\00001\000\000 */
{ 5183012 }, /* unc_m3upi_txc_ad_flq_occupancy.vn1_snp\000uncore_m3upi\000uncore interconnect\000AD Flow Q Occupancy; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x1c,umask=0x20\000\00001\000\000 */
{ 5183170 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x4\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to CHA\000 */
{ 5183450 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x40\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn0 Snpf\000 */
{ 5183768 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x1\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI0\000 */
{ 5184066 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn0_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN0. Unit: uncore_m3upi \000event=0x3c,umask=0x2\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN0 Snpf to peer UPI1\000 */
{ 5184364 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_cha\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; CHA on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x20\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to CHA\000 */
{ 5184645 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_non_idle\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Non Idle cycles on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x80\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of non-idle cycles in issuing Vn1 Snpf\000 */
{ 5184963 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi0\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI0 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x8\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI0\000 */
{ 5185261 }, /* unc_m3upi_txc_ad_snpf_grp1_vn1.vn1_peer_upi1\000uncore_m3upi\000uncore interconnect\000Number of Snoop Targets; Peer UPI1 on VN1. Unit: uncore_m3upi \000event=0x3c,umask=0x10\000\00001\000Number of snpfanout targets and non-idle cycles can be used to calculate average snpfanout latency; Number of VN1 Snpf to peer UPI1\000 */
{ 5185560 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x1\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn0\000 */
{ 5185795 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn0_snpfp_vn2snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x4\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn0 SnpF issued when SnpF pending on Vn1\000 */
{ 5186040 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_nonsnp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ Won. Unit: uncore_m3upi \000event=0x3d,umask=0x2\000\00001\000Outcome of SnpF pending arbitration; FlowQ txn issued when SnpF pending on Vn1\000 */
{ 5186275 }, /* unc_m3upi_txc_ad_snpf_grp2_vn1.vn1_snpfp_vn0snp\000uncore_m3upi\000uncore interconnect\000Snoop Arbitration; FlowQ SnpF Won. Unit: uncore_m3upi \000event=0x3d,umask=0x8\000\00001\000Outcome of SnpF pending arbitration; FlowQ Vn1 SnpF issued when SnpF pending on Vn0\000 */
{ 5186520 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x1\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5186788 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x2\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187056 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN0 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x8\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187322 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x34,umask=0x10\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187591 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x34,umask=0x20\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5187860 }, /* unc_m3upi_txc_ad_spec_arb_crd_avail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  -  Credit Available; VN1 WB Messages. Unit: uncore_m3upi \000event=0x34,umask=0x80\000\00001\000AD speculative arb request with prior cycle credit check complete and credit avail\000 */
{ 5188127 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x1\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188389 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x2\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188651 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x8\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5188911 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x33,umask=0x10\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189174 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x33,umask=0x20\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189437 }, /* unc_m3upi_txc_ad_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x33,umask=0x80\000\00001\000AD speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5189698 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x1\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190004 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x4\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190310 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x2\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190616 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x8\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5190920 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_req\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x32,umask=0x10\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191227 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x40\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191534 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_snp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x32,umask=0x20\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5191841 }, /* unc_m3upi_txc_ad_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD  - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x32,umask=0x80\000\00001\000AD speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5192146 }, /* unc_m3upi_txc_ak_flq_inserts\000uncore_m3upi\000uncore interconnect\000AK Flow Q Inserts. Unit: uncore_m3upi \000event=0x2f\000\00001\000\000 */
{ 5192263 }, /* unc_m3upi_txc_ak_flq_occupancy\000uncore_m3upi\000uncore interconnect\000AK Flow Q Occupancy. Unit: uncore_m3upi \000event=0x1e\000\00001\000\000 */
{ 5192625 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x4\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193067 }, /* unc_m3upi_txc_bl_arb_fail.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x8\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193509 }, /* unc_m3upi_txc_bl_arb_fail.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x1\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5193948 }, /* unc_m3upi_txc_bl_arb_fail.vn0_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN0 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x2\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5194389 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x35,umask=0x40\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5194833 }, /* unc_m3upi_txc_bl_arb_fail.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x80\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5195277 }, /* unc_m3upi_txc_bl_arb_fail.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x35,umask=0x10\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5195718 }, /* unc_m3upi_txc_bl_arb_fail.vn1_wb\000uncore_m3upi\000uncore interconnect\000Failed ARB for BL; VN1 WB Messages. Unit: uncore_m3upi \000event=0x35,umask=0x20\000\00001\000BL arb but no win; arb request asserted but not won\000 */
{ 5196166 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x1\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5196620 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x4\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197074 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x2\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197525 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN0 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x8\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5197978 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_req\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x28,umask=0x10\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198434 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x40\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5198890 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_snp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x28,umask=0x20\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5199343 }, /* unc_m3upi_txc_bl_flq_cycles_ne.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Not Empty; VN1 WB Messages. Unit: uncore_m3upi \000event=0x28,umask=0x80\000\00001\000Number of cycles the BL Egress queue is Not Empty\000 */
{ 5200039 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x1\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5200979 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x2\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5201920 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x8\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5202861 }, /* unc_m3upi_txc_bl_flq_inserts.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x4\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5203803 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x10\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5204745 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1 WB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x20\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5205688 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x80\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5206631 }, /* unc_m3upi_txc_bl_flq_inserts.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Inserts; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x2e,umask=0x40\000\00001\000Counts the number of allocations into the QPI FlowQ. This can be used in conjunction with the QPI FlowQ Occupancy Accumulator event in order to calculate average queue latency.  Only a single FlowQ queue can be tracked at any given time.  It is not possible to filter based on direction or polarity\000 */
{ 5207240 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x4\000\00001\000\000 */
{ 5207555 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x8\000\00001\000\000 */
{ 5207870 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 5208183 }, /* unc_m3upi_txc_bl_flq_occupancy.vn0_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN0 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 5208497 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCS Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x40\000\00001\000\000 */
{ 5208814 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_ncs\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1_NCB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x80\000\00001\000\000 */
{ 5209131 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_rsp\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x10\000\00001\000\000 */
{ 5209446 }, /* unc_m3upi_txc_bl_flq_occupancy.vn1_wb\000uncore_m3upi\000uncore interconnect\000BL Flow Q Occupancy; VN1 WB Messages. Unit: uncore_m3upi \000event=0x1d,umask=0x20\000\00001\000\000 */
{ 5209602 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x2\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5209863 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x38,umask=0x8\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210125 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN0 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x1\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210385 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 WB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x20\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210647 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x38,umask=0x80\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5210910 }, /* unc_m3upi_txc_bl_spec_arb_new_msg.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for BL  - New Message; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x38,umask=0x10\000\00001\000BL speculative arb request due to new message arriving on a specific channel (MC/VN)\000 */
{ 5211172 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x4\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5211484 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x8\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5211796 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x1\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212108 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn0_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN0 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x2\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212418 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCS Messages. Unit: uncore_m3upi \000event=0x37,umask=0x40\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5212731 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_ncs\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 NCB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x80\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5213044 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_rsp\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x37,umask=0x10\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5213357 }, /* unc_m3upi_txc_bl_spec_arb_no_other_pend.vn1_wb\000uncore_m3upi\000uncore interconnect\000Speculative ARB for AD Failed - No Credit; VN1 WB Messages. Unit: uncore_m3upi \000event=0x37,umask=0x20\000\00001\000BL speculative arb request asserted due to no other channel being active (have a valid entry but don't have credits to send)\000 */
{ 5214970 }, /* unc_m3upi_txr_horz_ads_used.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x1\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5215514 }, /* unc_m3upi_txr_horz_ads_used.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AD - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x10\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5216064 }, /* unc_m3upi_txr_horz_ads_used.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x2\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5216630 }, /* unc_m3upi_txr_horz_ads_used.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9d,umask=0x4\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5217174 }, /* unc_m3upi_txr_horz_ads_used.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal ADS Used; BL - Credit. Unit: uncore_m3upi \000event=0x9d,umask=0x40\000\00001\000Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5218037 }, /* unc_m3upi_txr_horz_bypass.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x1\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5218570 }, /* unc_m3upi_txr_horz_bypass.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AD - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x10\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5219373 }, /* unc_m3upi_txr_horz_bypass.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; AK - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x2\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5220228 }, /* unc_m3upi_txr_horz_bypass.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x4\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5220761 }, /* unc_m3upi_txr_horz_bypass.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; BL - Credit. Unit: uncore_m3upi \000event=0x9f,umask=0x40\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5221564 }, /* unc_m3upi_txr_horz_bypass.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Bypass Used; IV - Bounce. Unit: uncore_m3upi \000event=0x9f,umask=0x8\000\00001\000Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 5222216 }, /* unc_m3upi_txr_horz_cycles_full.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5222927 }, /* unc_m3upi_txr_horz_cycles_full.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AD - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5224005 }, /* unc_m3upi_txr_horz_cycles_full.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; AK - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5225135 }, /* unc_m3upi_txr_horz_cycles_full.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5225846 }, /* unc_m3upi_txr_horz_cycles_full.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; BL - Credit. Unit: uncore_m3upi \000event=0x96,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5226924 }, /* unc_m3upi_txr_horz_cycles_full.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full; IV - Bounce. Unit: uncore_m3upi \000event=0x96,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5227670 }, /* unc_m3upi_txr_horz_cycles_ne.ad_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x1\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5228402 }, /* unc_m3upi_txr_horz_cycles_ne.ad_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AD - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x10\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5229514 }, /* unc_m3upi_txr_horz_cycles_ne.ak_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; AK - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x2\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5230678 }, /* unc_m3upi_txr_horz_cycles_ne.bl_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x4\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5231410 }, /* unc_m3upi_txr_horz_cycles_ne.bl_crd\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; BL - Credit. Unit: uncore_m3upi \000event=0x97,umask=0x40\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5232522 }, /* unc_m3upi_txr_horz_cycles_ne.iv_bnc\000uncore_m3upi\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty; IV - Bounce. Unit: uncore_m3upi \000event=0x97,umask=0x8\000\00001\000Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5233243 }, /* unc_m3upi_txr_horz_inserts.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x1\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5233927 }, /* unc_m3upi_txr_horz_inserts.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AD - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x10\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5234958 }, /* unc_m3upi_txr_horz_inserts.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; AK - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x2\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5236041 }, /* unc_m3upi_txr_horz_inserts.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x4\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5236725 }, /* unc_m3upi_txr_horz_inserts.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; BL - Credit. Unit: uncore_m3upi \000event=0x95,umask=0x40\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5237756 }, /* unc_m3upi_txr_horz_inserts.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Inserts; IV - Bounce. Unit: uncore_m3upi \000event=0x95,umask=0x8\000\00001\000Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5238360 }, /* unc_m3upi_txr_horz_nack.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5238844 }, /* unc_m3upi_txr_horz_nack.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AD - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5239574 }, /* unc_m3upi_txr_horz_nack.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; AK - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5240355 }, /* unc_m3upi_txr_horz_nack.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5240839 }, /* unc_m3upi_txr_horz_nack.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; BL - Credit. Unit: uncore_m3upi \000event=0x99,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5241569 }, /* unc_m3upi_txr_horz_nack.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress NACKs; IV - Bounce. Unit: uncore_m3upi \000event=0x99,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 5242175 }, /* unc_m3upi_txr_horz_occupancy.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x1\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5242855 }, /* unc_m3upi_txr_horz_occupancy.ad_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AD - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x10\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5243881 }, /* unc_m3upi_txr_horz_occupancy.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; AK - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x2\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5244959 }, /* unc_m3upi_txr_horz_occupancy.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x4\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5245639 }, /* unc_m3upi_txr_horz_occupancy.bl_crd\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; BL - Credit. Unit: uncore_m3upi \000event=0x94,umask=0x40\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5246665 }, /* unc_m3upi_txr_horz_occupancy.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Occupancy; IV - Bounce. Unit: uncore_m3upi \000event=0x94,umask=0x8\000\00001\000Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 5247400 }, /* unc_m3upi_txr_horz_starved.ad_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AD - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5248516 }, /* unc_m3upi_txr_horz_starved.ak_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; AK - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5249684 }, /* unc_m3upi_txr_horz_starved.bl_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; BL - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5250800 }, /* unc_m3upi_txr_horz_starved.iv_bnc\000uncore_m3upi\000uncore interconnect\000CMS Horizontal Egress Injection Starvation; IV - Bounce. Unit: uncore_m3upi \000event=0x9b,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 5251422 }, /* unc_m3upi_txr_vert_ads_used.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x1\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5251955 }, /* unc_m3upi_txr_vert_ads_used.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x10\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252202 }, /* unc_m3upi_txr_vert_ads_used.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x2\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252448 }, /* unc_m3upi_txr_vert_ads_used.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x20\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5252981 }, /* unc_m3upi_txr_vert_ads_used.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9c,umask=0x4\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5253514 }, /* unc_m3upi_txr_vert_ads_used.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9c,umask=0x40\000\00001\000Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 5254037 }, /* unc_m3upi_txr_vert_bypass.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x1\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5254550 }, /* unc_m3upi_txr_vert_bypass.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AD - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x10\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255063 }, /* unc_m3upi_txr_vert_bypass.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x2\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5255576 }, /* unc_m3upi_txr_vert_bypass.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; AK - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x20\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256089 }, /* unc_m3upi_txr_vert_bypass.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 0. Unit: uncore_m3upi \000event=0x9e,umask=0x4\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256602 }, /* unc_m3upi_txr_vert_bypass.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; BL - Agent 1. Unit: uncore_m3upi \000event=0x9e,umask=0x40\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5256839 }, /* unc_m3upi_txr_vert_bypass.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical ADS Used; IV. Unit: uncore_m3upi \000event=0x9e,umask=0x8\000\00001\000Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 5257899 }, /* unc_m3upi_txr_vert_cycles_full.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5258350 }, /* unc_m3upi_txr_vert_cycles_full.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AD - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5258770 }, /* unc_m3upi_txr_vert_cycles_full.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5259203 }, /* unc_m3upi_txr_vert_cycles_full.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; AK - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5259577 }, /* unc_m3upi_txr_vert_cycles_full.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 0. Unit: uncore_m3upi \000event=0x92,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5260026 }, /* unc_m3upi_txr_vert_cycles_full.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; BL - Agent 1. Unit: uncore_m3upi \000event=0x92,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5260469 }, /* unc_m3upi_txr_vert_cycles_full.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full; IV. Unit: uncore_m3upi \000event=0x92,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5265306 }, /* unc_m3upi_txr_vert_cycles_ne.ad_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x1\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5265761 }, /* unc_m3upi_txr_vert_cycles_ne.ad_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AD - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x10\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5266185 }, /* unc_m3upi_txr_vert_cycles_ne.ak_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x2\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5266622 }, /* unc_m3upi_txr_vert_cycles_ne.ak_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; AK - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x20\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5267000 }, /* unc_m3upi_txr_vert_cycles_ne.bl_ag0\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 0. Unit: uncore_m3upi \000event=0x93,umask=0x4\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5267453 }, /* unc_m3upi_txr_vert_cycles_ne.bl_ag1\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; BL - Agent 1. Unit: uncore_m3upi \000event=0x93,umask=0x40\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5267900 }, /* unc_m3upi_txr_vert_cycles_ne.iv\000uncore_m3upi\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty; IV. Unit: uncore_m3upi \000event=0x93,umask=0x8\000\00001\000Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5272822 }, /* unc_m3upi_txr_vert_inserts.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x1\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5273253 }, /* unc_m3upi_txr_vert_inserts.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AD - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x10\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5273653 }, /* unc_m3upi_txr_vert_inserts.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x2\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5274066 }, /* unc_m3upi_txr_vert_inserts.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; AK - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x20\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5274420 }, /* unc_m3upi_txr_vert_inserts.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 0. Unit: uncore_m3upi \000event=0x91,umask=0x4\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5274849 }, /* unc_m3upi_txr_vert_inserts.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; BL - Agent 1. Unit: uncore_m3upi \000event=0x91,umask=0x40\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5275272 }, /* unc_m3upi_txr_vert_inserts.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Allocations; IV. Unit: uncore_m3upi \000event=0x91,umask=0x8\000\00001\000Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5279792 }, /* unc_m3upi_txr_vert_nack.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x1\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280006 }, /* unc_m3upi_txr_vert_nack.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AD - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x10\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280221 }, /* unc_m3upi_txr_vert_nack.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x2\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280435 }, /* unc_m3upi_txr_vert_nack.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; AK - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x20\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280650 }, /* unc_m3upi_txr_vert_nack.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 0. Unit: uncore_m3upi \000event=0x98,umask=0x4\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5280864 }, /* unc_m3upi_txr_vert_nack.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; BL - Agent 1. Unit: uncore_m3upi \000event=0x98,umask=0x40\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5281079 }, /* unc_m3upi_txr_vert_nack.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress NACKs; IV. Unit: uncore_m3upi \000event=0x98,umask=0x8\000\00001\000Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 5283599 }, /* unc_m3upi_txr_vert_occupancy.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x1\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 5284037 }, /* unc_m3upi_txr_vert_occupancy.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AD - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x10\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 5284444 }, /* unc_m3upi_txr_vert_occupancy.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x2\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 5284864 }, /* unc_m3upi_txr_vert_occupancy.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; AK - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x20\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the AK ring\000 */
{ 5285225 }, /* unc_m3upi_txr_vert_occupancy.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 0. Unit: uncore_m3upi \000event=0x90,umask=0x4\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 5285661 }, /* unc_m3upi_txr_vert_occupancy.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; BL - Agent 1. Unit: uncore_m3upi \000event=0x90,umask=0x40\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 5286091 }, /* unc_m3upi_txr_vert_occupancy.iv\000uncore_m3upi\000uncore interconnect\000CMS Vert Egress Occupancy; IV. Unit: uncore_m3upi \000event=0x90,umask=0x8\000\00001\000Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh.; Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 5290663 }, /* unc_m3upi_txr_vert_starved.ad_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x1\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5290985 }, /* unc_m3upi_txr_vert_starved.ad_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AD - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x10\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291308 }, /* unc_m3upi_txr_vert_starved.ak_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x2\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291630 }, /* unc_m3upi_txr_vert_starved.ak_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; AK - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x20\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5291953 }, /* unc_m3upi_txr_vert_starved.bl_ag0\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 0. Unit: uncore_m3upi \000event=0x9a,umask=0x4\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5292275 }, /* unc_m3upi_txr_vert_starved.bl_ag1\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; BL - Agent 1. Unit: uncore_m3upi \000event=0x9a,umask=0x40\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5292598 }, /* unc_m3upi_txr_vert_starved.iv\000uncore_m3upi\000uncore interconnect\000CMS Vertical Egress Injection Starvation; IV. Unit: uncore_m3upi \000event=0x9a,umask=0x8\000\00001\000Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 5296973 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x2\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5297447 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x8\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5297921 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn0_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x4\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5298396 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_req\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x20,umask=0x10\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5298872 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x40\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5299348 }, /* unc_m3upi_upi_peer_ad_credits_empty.vn1_snp\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x20,umask=0x20\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5299793 }, /* unc_m3upi_upi_peer_ad_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 AD Credits Empty; VNA. Unit: uncore_m3upi \000event=0x20,umask=0x1\000\00001\000No credits available to send to UPIs on the AD Ring\000 */
{ 5300289 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x4\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5300837 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x2\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301380 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn0_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN0 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x8\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5301928 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_ncs_ncb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 RSP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x20\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5302478 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_rsp\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 REQ Messages. Unit: uncore_m3upi \000event=0x21,umask=0x10\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303023 }, /* unc_m3upi_upi_peer_bl_credits_empty.vn1_wb\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VN1 SNP Messages. Unit: uncore_m3upi \000event=0x21,umask=0x40\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303537 }, /* unc_m3upi_upi_peer_bl_credits_empty.vna\000uncore_m3upi\000uncore interconnect\000UPI0 BL Credits Empty; VNA. Unit: uncore_m3upi \000event=0x21,umask=0x1\000\00001\000No credits available to send to UPI on the BL Ring (diff between non-SMI and SMI mode)\000 */
{ 5303988 }, /* unc_m3upi_upi_prefetch_spawn\000uncore_m3upi\000uncore interconnect\000Prefetches generated by the flow control queue of the M3UPI unit. Unit: uncore_m3upi \000event=0x29\000\00001\000Count cases where flow control queue that sits between the Intel(R) Ultra Path Interconnect (UPI) and the mesh spawns a prefetch to the iMC (Memory Controller)\000 */
{ 5305237 }, /* unc_m3upi_vert_ring_ad_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5307043 }, /* unc_m3upi_vert_ring_ad_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5308846 }, /* unc_m3upi_vert_ring_ad_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa6,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5310646 }, /* unc_m3upi_vert_ring_ad_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AD Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa6,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5312451 }, /* unc_m3upi_vert_ring_ak_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x4\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5314257 }, /* unc_m3upi_vert_ring_ak_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Down and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x8\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5316060 }, /* unc_m3upi_vert_ring_ak_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Even. Unit: uncore_m3upi \000event=0xa8,umask=0x1\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5317860 }, /* unc_m3upi_vert_ring_ak_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical AK Ring In Use; Up and Odd. Unit: uncore_m3upi \000event=0xa8,umask=0x2\000\00001\000Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5323385 }, /* unc_m3upi_vert_ring_bl_in_use.dn_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x4\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5325187 }, /* unc_m3upi_vert_ring_bl_in_use.dn_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Down and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x8\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5326986 }, /* unc_m3upi_vert_ring_bl_in_use.up_even\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Even. Unit: uncore_m3upi \000event=0xaa,umask=0x1\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5328782 }, /* unc_m3upi_vert_ring_bl_in_use.up_odd\000uncore_m3upi\000uncore interconnect\000Vertical BL Ring in Use; Up and Odd. Unit: uncore_m3upi \000event=0xaa,umask=0x2\000\00001\000Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 5330257 }, /* unc_m3upi_vert_ring_iv_in_use.dn\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Down. Unit: uncore_m3upi \000event=0xac,umask=0x4\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5331415 }, /* unc_m3upi_vert_ring_iv_in_use.up\000uncore_m3upi\000uncore interconnect\000Vertical IV Ring in Use; Up. Unit: uncore_m3upi \000event=0xac,umask=0x1\000\00001\000Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 5336863 }, /* unc_m3upi_vn0_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x10\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5339120 }, /* unc_m3upi_vn0_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x20\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5341293 }, /* unc_m3upi_vn0_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x1\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5343448 }, /* unc_m3upi_vn0_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x4\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5345558 }, /* unc_m3upi_vn0_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5c,umask=0x2\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5347666 }, /* unc_m3upi_vn0_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN0 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5c,umask=0x8\000\00001\000Number of times a VN0 credit was used on the DRS message channel.  In order for a request to be transferred across UPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN0.  VNA is a shared pool used to achieve high performance.  The VN0 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN0 if they fail.  This counts the number of times a VN0 credit was used.  Note that a single VN0 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN0 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5349137 }, /* unc_m3upi_vn0_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x10\000\00001\000Number of Cycles there were no VN0 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5349865 }, /* unc_m3upi_vn0_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x20\000\00001\000Number of Cycles there were no VN0 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5350509 }, /* unc_m3upi_vn0_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x1\000\00001\000Number of Cycles there were no VN0 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5351135 }, /* unc_m3upi_vn0_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x4\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5351716 }, /* unc_m3upi_vn0_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5e,umask=0x2\000\00001\000Number of Cycles there were no VN0 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5352295 }, /* unc_m3upi_vn0_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN0 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5e,umask=0x8\000\00001\000Number of Cycles there were no VN0 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5353766 }, /* unc_m3upi_vn1_credits_used.ncb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; WB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x10\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5356021 }, /* unc_m3upi_vn1_credits_used.ncs\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; NCB on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x20\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5358192 }, /* unc_m3upi_vn1_credits_used.req\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; REQ on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x1\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5360345 }, /* unc_m3upi_vn1_credits_used.rsp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x4\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5362453 }, /* unc_m3upi_vn1_credits_used.snp\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; SNP on AD. Unit: uncore_m3upi \000event=0x5d,umask=0x2\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5364559 }, /* unc_m3upi_vn1_credits_used.wb\000uncore_m3upi\000uncore interconnect\000VN1 Credit Used; RSP on BL. Unit: uncore_m3upi \000event=0x5d,umask=0x8\000\00001\000Number of times a VN1 credit was used on the WB message channel.  In order for a request to be transferred across QPI, it must be guaranteed to have a flit buffer on the remote socket to sink into.  There are two credit pools, VNA and VN1.  VNA is a shared pool used to achieve high performance.  The VN1 pool has reserved entries for each message class and is used to prevent deadlock.  Requests first attempt to acquire a VNA credit, and then fall back to VN1 if they fail.  This counts the number of times a VN1 credit was used.  Note that a single VN1 credit holds access to potentially multiple flit buffers.  For example, a transfer that uses VNA could use 9 flit buffers and in that case uses 9 credits.  A transfer on VN1 will only count a single credit even though it may use multiple buffers.; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5366029 }, /* unc_m3upi_vn1_no_credits.ncb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; WB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x10\000\00001\000Number of Cycles there were no VN1 Credits; Data Response (WB) messages on BL.  WB is generally used to transmit data with coherency.  For example, remote reads and writes, or cache to cache transfers will transmit their data using WB\000 */
{ 5366757 }, /* unc_m3upi_vn1_no_credits.ncs\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; NCB on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x20\000\00001\000Number of Cycles there were no VN1 Credits; Non-Coherent Broadcast (NCB) messages on BL.  NCB is generally used to transmit data without coherency.  For example, non-coherent read data returns\000 */
{ 5367401 }, /* unc_m3upi_vn1_no_credits.req\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; REQ on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x1\000\00001\000Number of Cycles there were no VN1 Credits; Home (REQ) messages on AD.  REQ is generally used to send requests, request responses, and snoop responses\000 */
{ 5368027 }, /* unc_m3upi_vn1_no_credits.rsp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x4\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on AD.  RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5368608 }, /* unc_m3upi_vn1_no_credits.snp\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; SNP on AD. Unit: uncore_m3upi \000event=0x5f,umask=0x2\000\00001\000Number of Cycles there were no VN1 Credits; Snoops (SNP) messages on AD.  SNP is used for outgoing snoops\000 */
{ 5369187 }, /* unc_m3upi_vn1_no_credits.wb\000uncore_m3upi\000uncore interconnect\000VN1 No Credits; RSP on BL. Unit: uncore_m3upi \000event=0x5f,umask=0x8\000\00001\000Number of Cycles there were no VN1 Credits; Response (RSP) messages on BL. RSP packets are used to transmit a variety of protocol flits including grants and completions (CMP)\000 */
{ 5640867 }, /* unc_nounit_txc_bl.drs_upi\000uncore_m2m\000uncore interconnect\000This event is deprecated. Refer to new event UNC_M2M_TxC_BL.DRS_UPI. Unit: uncore_m2m \000event=0x40,umask=0x4\000\00011\000\000 */
{ 6073363 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000 */
{ 6073826 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6074439 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6075047 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Inter Processor Interrupts\000 */
{ 6075765 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore.; Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000 */
{ 6076520 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received; VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6078090 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6082167 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack; Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000PHOLD cycles\000 */
{ 6082332 }, /* unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 6082474 }, /* unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 6082598 }, /* unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 6082839 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000Number outstanding register requests within message channel tracker\000 */
{ 6085887 }, /* unc_upi_clockticks\000uncore_upi\000uncore interconnect\000Clocks of the Intel(R) Ultra Path Interconnect (UPI). Unit: uncore_upi \000event=0x1\000\00001\000Counts clockticks of the fixed frequency clock controlling the Intel(R) Ultra Path Interconnect (UPI).  This clock runs at1/8th the 'GT/s' speed of the UPI link.  For example, a  9.6GT/s  link will have a fixed Frequency of 1.2 Ghz\000 */
{ 6086763 }, /* unc_upi_direct_attempts.d2c\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to core. Unit: uncore_upi \000event=0x12,umask=0x1\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to core bypassing the CHA\000 */
{ 6088076 }, /* unc_upi_direct_attempts.d2k\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_DIRECT_ATTEMPTS.D2U. Unit: uncore_upi \000event=0x12,umask=0x2\000\00011\000\000 */
{ 6088253 }, /* unc_upi_direct_attempts.d2u\000uncore_upi\000uncore interconnect\000Data Response packets that go direct to Intel(R) UPI. Unit: uncore_upi \000event=0x12,umask=0x2\000\00001\000Counts Data Response (DRS) packets that attempted to go direct to Intel(R) Ultra Path Interconnect (UPI) bypassing the CHA \000 */
{ 6088533 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x1\000\00001\000\000 */
{ 6088681 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x2\000\00001\000\000 */
{ 6088829 }, /* unc_upi_flowq_no_vna_crd.ad_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AD_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x4\000\00001\000\000 */
{ 6088977 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x10\000\00001\000\000 */
{ 6089126 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq1\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ1. Unit: uncore_upi \000event=0x18,umask=0x20\000\00001\000\000 */
{ 6089275 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq2\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ2. Unit: uncore_upi \000event=0x18,umask=0x40\000\00001\000\000 */
{ 6089424 }, /* unc_upi_flowq_no_vna_crd.ak_vna_eq3\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.AK_VNA_EQ3. Unit: uncore_upi \000event=0x18,umask=0x80\000\00001\000\000 */
{ 6089573 }, /* unc_upi_flowq_no_vna_crd.bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_FLOWQ_NO_VNA_CRD.BL_VNA_EQ0. Unit: uncore_upi \000event=0x18,umask=0x8\000\00001\000\000 */
{ 6089721 }, /* unc_upi_l1_power_cycles\000uncore_upi\000uncore interconnect\000Cycles Intel(R) UPI is in L1 power mode (shutdown). Unit: uncore_upi \000event=0x21\000\00001\000Counts cycles when the Intel(R) Ultra Path Interconnect (UPI) is in L1 power mode.  L1 is a mode that totally shuts down the UPI link.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another, this event only coutns when both links are shutdown\000 */
{ 6090695 }, /* unc_upi_m3_byp_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x14,umask=0x8\000\00001\000\000 */
{ 6090833 }, /* unc_upi_m3_byp_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x14,umask=0x1\000\00001\000\000 */
{ 6090989 }, /* unc_upi_m3_byp_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x14,umask=0x4\000\00001\000\000 */
{ 6091145 }, /* unc_upi_m3_byp_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x14,umask=0x2\000\00001\000\000 */
{ 6091301 }, /* unc_upi_m3_byp_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_BYP_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x14,umask=0x10\000\00001\000\000 */
{ 6091442 }, /* unc_upi_m3_crd_return_blocked\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_CRD_RETURN_BLOCKED. Unit: uncore_upi \000event=0x16\000\00001\000\000 */
{ 6091568 }, /* unc_upi_m3_rxq_blocked.bgf_crd\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.BGF_CRD. Unit: uncore_upi \000event=0x15,umask=0x20\000\00001\000\000 */
{ 6091707 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_btw_2_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_BTW_2_THRESH. Unit: uncore_upi \000event=0x15,umask=0x2\000\00001\000\000 */
{ 6091881 }, /* unc_upi_m3_rxq_blocked.flowq_ad_vna_le2\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AD_VNA_LE2. Unit: uncore_upi \000event=0x15,umask=0x1\000\00001\000\000 */
{ 6092037 }, /* unc_upi_m3_rxq_blocked.flowq_ak_vna_le3\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_AK_VNA_LE3. Unit: uncore_upi \000event=0x15,umask=0x10\000\00001\000\000 */
{ 6092194 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_btw_0_thresh\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_BTW_0_THRESH. Unit: uncore_upi \000event=0x15,umask=0x8\000\00001\000\000 */
{ 6092368 }, /* unc_upi_m3_rxq_blocked.flowq_bl_vna_eq0\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.FLOWQ_BL_VNA_EQ0. Unit: uncore_upi \000event=0x15,umask=0x4\000\00001\000\000 */
{ 6092524 }, /* unc_upi_m3_rxq_blocked.gv_block\000uncore_upi\000uncore interconnect\000UNC_UPI_M3_RXQ_BLOCKED.GV_BLOCK. Unit: uncore_upi \000event=0x15,umask=0x40\000\00001\000\000 */
{ 6092665 }, /* unc_upi_phy_init_cycles\000uncore_upi\000uncore interconnect\000Cycles where phy is not in L0, L0c, L0p, L1. Unit: uncore_upi \000event=0x20\000\00001\000\000 */
{ 6092799 }, /* unc_upi_power_l1_nack\000uncore_upi\000uncore interconnect\000L1 Req Nack. Unit: uncore_upi \000event=0x23\000\00001\000Counts the number of times a link sends/receives a LinkReqNAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqNAck refers to receiving an NAck (meaning this agent's Tx originally requested the power change).  A Tx LinkReqNAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6094329 }, /* unc_upi_power_l1_req\000uncore_upi\000uncore interconnect\000L1 Req (same as L1 Ack). Unit: uncore_upi \000event=0x22\000\00001\000Counts the number of times a link sends/receives a LinkReqAck.  When the UPI links would like to change power state, the Tx side initiates a request to the Rx side requesting to change states.  This requests can either be accepted or denied.  If the Rx side replies with an Ack, the power mode will change.  If it replies with NAck, no change will take place.  This can be filtered based on Rx and Tx.  An Rx LinkReqAck refers to receiving an Ack (meaning this agent's Tx originally requested the power change).  A Tx LinkReqAck refers to sending this command (meaning the peer agent's Tx originally requested the power change and this agent accepted it)\000 */
{ 6095886 }, /* unc_upi_req_slot2_from_m3.ack\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.ACK. Unit: uncore_upi \000event=0x46,umask=0x8\000\00001\000\000 */
{ 6096022 }, /* unc_upi_req_slot2_from_m3.vn0\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN0. Unit: uncore_upi \000event=0x46,umask=0x2\000\00001\000\000 */
{ 6096158 }, /* unc_upi_req_slot2_from_m3.vn1\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VN1. Unit: uncore_upi \000event=0x46,umask=0x4\000\00001\000\000 */
{ 6096294 }, /* unc_upi_req_slot2_from_m3.vna\000uncore_upi\000uncore interconnect\000UNC_UPI_REQ_SLOT2_FROM_M3.VNA. Unit: uncore_upi \000event=0x46,umask=0x1\000\00001\000\000 */
{ 6096430 }, /* unc_upi_rxl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Receive side. Unit: uncore_upi \000event=0x24\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6098255 }, /* unc_upi_rxl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles the Rx of the Intel(R) UPI is in L0p power mode. Unit: uncore_upi \000event=0x25\000\00001\000Counts cycles when the receive side (Rx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000 */
{ 6100380 }, /* unc_upi_rxl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0xe\000\00001\000Match Message Class - NCB\000 */
{ 6101312 }, /* unc_upi_rxl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x5,umask=0x10e\000\00001\000Match Message Class - NCB\000 */
{ 6102220 }, /* unc_upi_rxl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0xf\000\00001\000Match Message Class - NCS\000 */
{ 6103158 }, /* unc_upi_rxl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x5,umask=0x10f\000\00001\000Match Message Class - NCS\000 */
{ 6104040 }, /* unc_upi_rxl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request. Unit: uncore_upi \000event=0x5,umask=0x8\000\00001\000REQ Message Class\000 */
{ 6104928 }, /* unc_upi_rxl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x5,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000 */
{ 6105842 }, /* unc_upi_rxl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0xc\000\00001\000Match Message Class -WB\000 */
{ 6106770 }, /* unc_upi_rxl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x5,umask=0x10c\000\00001\000Match Message Class -WB\000 */
{ 6107678 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0xa\000\00001\000Match Message Class - RSP\000 */
{ 6108621 }, /* unc_upi_rxl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x5,umask=0x10a\000\00001\000Match Message Class - RSP\000 */
{ 6109538 }, /* unc_upi_rxl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x5,umask=0x1aa\000\00001\000\000 */
{ 6110419 }, /* unc_upi_rxl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x5,umask=0x12a\000\00001\000\000 */
{ 6111266 }, /* unc_upi_rxl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x5,umask=0x9\000\00001\000SNP Message Class\000 */
{ 6112148 }, /* unc_upi_rxl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x5,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000 */
{ 6113042 }, /* unc_upi_rxl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0xd\000\00001\000Match Message Class -WB\000 */
{ 6113940 }, /* unc_upi_rxl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Receive path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x5,umask=0x10d\000\00001\000Match Message Class -WB\000 */
{ 6114124 }, /* unc_upi_rxl_bypassed.slot0\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x1\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot0 RxQ buffer (Receive Queue) and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6115197 }, /* unc_upi_rxl_bypassed.slot1\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x2\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot1 RxQ buffer  (Receive Queue) and passed directly across the BGF and into the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6116292 }, /* unc_upi_rxl_bypassed.slot2\000uncore_upi\000uncore interconnect\000FLITs received which bypassed the Slot0 Receive Buffer. Unit: uncore_upi \000event=0x31,umask=0x4\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the slot2 RxQ buffer (Receive Queue)  and passed directly to the Egress.  This is a latency optimization, and should generally be the common case.  If this value is less than the number of FLITs transferred, it implies that there was queueing getting onto the ring, and thus the transactions saw higher latency\000 */
{ 6117839 }, /* unc_upi_rxl_crc_errors\000uncore_upi\000uncore interconnect\000CRC Errors Detected. Unit: uncore_upi \000event=0xb\000\00001\000Number of CRC errors detected in the UPI Agent.  Each UPI flit incorporates 8 bits of CRC for error detection.  This counts the number of flits where the CRC was able to detect an error.  After an error has been detected, the UPI agent will send a request to the transmitting socket to resend the flit (as well as any flits that came after it)\000 */
{ 6119045 }, /* unc_upi_rxl_crc_llr_req_transmit\000uncore_upi\000uncore interconnect\000LLR Requests Sent. Unit: uncore_upi \000event=0x8\000\00001\000Number of LLR Requests were transmitted.  This should generally be <= the number of CRC errors detected.  If multiple errors are detected before the Rx side receives a LLC_REQ_ACK from the Tx side, there is no need to send more LLR_REQ_NACKs\000 */
{ 6119402 }, /* unc_upi_rxl_credits_consumed_vn0\000uncore_upi\000uncore interconnect\000VN0 Credit Consumed. Unit: uncore_upi \000event=0x39\000\00001\000Counts the number of times that an RxQ VN0 credit was consumed (i.e. message uses a VN0 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6120048 }, /* unc_upi_rxl_credits_consumed_vn1\000uncore_upi\000uncore interconnect\000VN1 Credit Consumed. Unit: uncore_upi \000event=0x3a\000\00001\000Counts the number of times that an RxQ VN1 credit was consumed (i.e. message uses a VN1 credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121044 }, /* unc_upi_rxl_credits_consumed_vna\000uncore_upi\000uncore interconnect\000VNA Credit Consumed. Unit: uncore_upi \000event=0x38\000\00001\000Counts the number of times that an RxQ VNA credit was consumed (i.e. message uses a VNA credit for the Rx Buffer).  This includes packets that went through the RxQ and those that were bypasssed\000 */
{ 6121909 }, /* unc_upi_rxl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0xf\000\00001\000Counts valid data FLITs  (80 bit FLow control unITs: 64bits of data) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000 */
{ 6122222 }, /* unc_upi_rxl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) received from any of the 3 Intel(R) Ultra Path Interconnect (UPI) Receive Queue slots on this UPI unit\000 */
{ 6123287 }, /* unc_upi_rxl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Received; Data. Unit: uncore_upi \000event=0x3,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6124102 }, /* unc_upi_rxl_flits.idle\000uncore_upi\000uncore interconnect\000Valid Flits Received; Idle. Unit: uncore_upi \000event=0x3,umask=0x47\000\00001\000Shows legal flit time (hides impact of L0p and L0c)\000 */
{ 6124630 }, /* unc_upi_rxl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCRD Not Empty. Unit: uncore_upi \000event=0x3,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6125229 }, /* unc_upi_rxl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Received; LLCTRL. Unit: uncore_upi \000event=0x3,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6125486 }, /* unc_upi_rxl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs received from any slot. Unit: uncore_upi \000event=0x3,umask=0x97\000\00001\000Counts protocol header and credit FLITs  (80 bit FLow control unITs) received from any of the 3 UPI slots on this UPI unit\000 */
{ 6125995 }, /* unc_upi_rxl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x3,umask=0x20\000\00011\000\000 */
{ 6126547 }, /* unc_upi_rxl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x3,umask=0x80\000\00011\000\000 */
{ 6127036 }, /* unc_upi_rxl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Received; Protocol Header. Unit: uncore_upi \000event=0x3,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6127590 }, /* unc_upi_rxl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 0. Unit: uncore_upi \000event=0x3,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6128120 }, /* unc_upi_rxl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 1. Unit: uncore_upi \000event=0x3,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6128650 }, /* unc_upi_rxl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Received; Slot 2. Unit: uncore_upi \000event=0x3,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6128898 }, /* unc_upi_rxl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x5,umask=0xc\000\00011\000\000 */
{ 6129076 }, /* unc_upi_rxl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x5,umask=0xd\000\00011\000\000 */
{ 6129254 }, /* unc_upi_rxl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x5,umask=0x8\000\00011\000\000 */
{ 6129432 }, /* unc_upi_rxl_hdr_match.rsp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x5,umask=0xa\000\00011\000\000 */
{ 6129615 }, /* unc_upi_rxl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x5,umask=0x9\000\00011\000\000 */
{ 6129793 }, /* unc_upi_rxl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_RxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x5,umask=0xb\000\00011\000\000 */
{ 6130575 }, /* unc_upi_rxl_inserts.slot0\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 0. Unit: uncore_upi \000event=0x30,umask=0x1\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6131747 }, /* unc_upi_rxl_inserts.slot1\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 1. Unit: uncore_upi \000event=0x30,umask=0x2\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6132919 }, /* unc_upi_rxl_inserts.slot2\000uncore_upi\000uncore interconnect\000RxQ Flit Buffer Allocations; Slot 2. Unit: uncore_upi \000event=0x30,umask=0x4\000\00001\000Number of allocations into the UPI Rx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6134152 }, /* unc_upi_rxl_occupancy.slot0\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 0. Unit: uncore_upi \000event=0x32,umask=0x1\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6135446 }, /* unc_upi_rxl_occupancy.slot1\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 1. Unit: uncore_upi \000event=0x32,umask=0x2\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6136740 }, /* unc_upi_rxl_occupancy.slot2\000uncore_upi\000uncore interconnect\000RxQ Occupancy - All Packets; Slot 2. Unit: uncore_upi \000event=0x32,umask=0x4\000\00001\000Accumulates the number of elements in the UPI RxQ in each cycle.  Generally, when data is transmitted across UPI, it will bypass the RxQ and pass directly to the ring interface.  If things back up getting transmitted onto the ring, however, it may need to allocate into this buffer, thus increasing the latency.  This event can be used in conjunction with the Flit Buffer Not Empty event to calculate average occupancy, or with the Flit Buffer Allocations event to track average lifetime\000 */
{ 6137367 }, /* unc_upi_rxl_slot_bypass.s0_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x1\000\00001\000\000 */
{ 6137507 }, /* unc_upi_rxl_slot_bypass.s0_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S0_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x2\000\00001\000\000 */
{ 6137647 }, /* unc_upi_rxl_slot_bypass.s1_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x4\000\00001\000\000 */
{ 6137787 }, /* unc_upi_rxl_slot_bypass.s1_rxq2\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S1_RXQ2. Unit: uncore_upi \000event=0x33,umask=0x8\000\00001\000\000 */
{ 6137927 }, /* unc_upi_rxl_slot_bypass.s2_rxq0\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ0. Unit: uncore_upi \000event=0x33,umask=0x10\000\00001\000\000 */
{ 6138068 }, /* unc_upi_rxl_slot_bypass.s2_rxq1\000uncore_upi\000uncore interconnect\000UNC_UPI_RxL_SLOT_BYPASS.S2_RXQ1. Unit: uncore_upi \000event=0x33,umask=0x20\000\00001\000\000 */
{ 6138209 }, /* unc_upi_txl0_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in L0. Transmit side. Unit: uncore_upi \000event=0x26\000\00001\000Number of UPI qfclk cycles spent in L0 power mode in the Link Layer.  L0 is the default mode which provides the highest performance with the most power.  Use edge detect to count the number of instances that the link entered L0.  Link power states are per link and per direction, so for example the Tx direction could be in one state while Rx was in another.  The phy layer  sometimes leaves L0 for training, which will not be captured by this event\000 */
{ 6139347 }, /* unc_upi_txl0p_clk_active.cfg_ctl\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.CFG_CTL. Unit: uncore_upi \000event=0x2a,umask=0x1\000\00001\000\000 */
{ 6139489 }, /* unc_upi_txl0p_clk_active.dfx\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.DFX. Unit: uncore_upi \000event=0x2a,umask=0x40\000\00001\000\000 */
{ 6139624 }, /* unc_upi_txl0p_clk_active.retry\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RETRY. Unit: uncore_upi \000event=0x2a,umask=0x20\000\00001\000\000 */
{ 6139763 }, /* unc_upi_txl0p_clk_active.rxq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ. Unit: uncore_upi \000event=0x2a,umask=0x2\000\00001\000\000 */
{ 6139897 }, /* unc_upi_txl0p_clk_active.rxq_bypass\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_BYPASS. Unit: uncore_upi \000event=0x2a,umask=0x4\000\00001\000\000 */
{ 6140045 }, /* unc_upi_txl0p_clk_active.rxq_cred\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.RXQ_CRED. Unit: uncore_upi \000event=0x2a,umask=0x8\000\00001\000\000 */
{ 6140189 }, /* unc_upi_txl0p_clk_active.spare\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.SPARE. Unit: uncore_upi \000event=0x2a,umask=0x80\000\00001\000\000 */
{ 6140328 }, /* unc_upi_txl0p_clk_active.txq\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_CLK_ACTIVE.TXQ. Unit: uncore_upi \000event=0x2a,umask=0x10\000\00001\000\000 */
{ 6141151 }, /* unc_upi_txl0p_power_cycles\000uncore_upi\000uncore interconnect\000Cycles in which the Tx of the Intel(R) Ultra Path Interconnect (UPI) is in L0p power mode. Unit: uncore_upi \000event=0x27\000\00001\000Counts cycles when the transmit side (Tx) of the Intel(R) Ultra Path Interconnect(UPI) is in L0p power mode. L0p is a mode where we disable 60% of the UPI lanes, decreasing our bandwidth in order to save power\000 */
{ 6141543 }, /* unc_upi_txl0p_power_cycles_ll_enter\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_LL_ENTER. Unit: uncore_upi \000event=0x28\000\00001\000\000 */
{ 6141681 }, /* unc_upi_txl0p_power_cycles_m3_exit\000uncore_upi\000uncore interconnect\000UNC_UPI_TxL0P_POWER_CYCLES_M3_EXIT. Unit: uncore_upi \000event=0x29\000\00001\000\000 */
{ 6143589 }, /* unc_upi_txl_basic_hdr_match.ncb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0xe\000\00001\000Match Message Class - NCB\000 */
{ 6144525 }, /* unc_upi_txl_basic_hdr_match.ncb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Bypass. Unit: uncore_upi \000event=0x4,umask=0x10e\000\00001\000Match Message Class - NCB\000 */
{ 6145437 }, /* unc_upi_txl_basic_hdr_match.ncs\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0xf\000\00001\000Match Message Class - NCS\000 */
{ 6146379 }, /* unc_upi_txl_basic_hdr_match.ncs_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Non-Coherent Standard. Unit: uncore_upi \000event=0x4,umask=0x10f\000\00001\000Match Message Class - NCS\000 */
{ 6147265 }, /* unc_upi_txl_basic_hdr_match.req\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request. Unit: uncore_upi \000event=0x4,umask=0x8\000\00001\000REQ Message Class\000 */
{ 6148157 }, /* unc_upi_txl_basic_hdr_match.req_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Request Opcode. Unit: uncore_upi \000event=0x4,umask=0x108\000\00001\000Match REQ Opcodes - Specified in Umask[7:4]\000 */
{ 6149075 }, /* unc_upi_txl_basic_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0xc\000\00001\000Match Message Class -WB\000 */
{ 6150007 }, /* unc_upi_txl_basic_hdr_match.rsp_data_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Data. Unit: uncore_upi \000event=0x4,umask=0x10c\000\00001\000Match Message Class -WB\000 */
{ 6150919 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0xa\000\00001\000Match Message Class - RSP\000 */
{ 6151866 }, /* unc_upi_txl_basic_hdr_match.rsp_nodata_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - No Data. Unit: uncore_upi \000event=0x4,umask=0x10a\000\00001\000Match Message Class - RSP\000 */
{ 6152787 }, /* unc_upi_txl_basic_hdr_match.rspcnflt\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Conflict. Unit: uncore_upi \000event=0x4,umask=0x1aa\000\00001\000\000 */
{ 6153672 }, /* unc_upi_txl_basic_hdr_match.rspi\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Response - Invalid. Unit: uncore_upi \000event=0x4,umask=0x12a\000\00001\000\000 */
{ 6154523 }, /* unc_upi_txl_basic_hdr_match.snp\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop. Unit: uncore_upi \000event=0x4,umask=0x9\000\00001\000SNP Message Class\000 */
{ 6155409 }, /* unc_upi_txl_basic_hdr_match.snp_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Snoop Opcode. Unit: uncore_upi \000event=0x4,umask=0x109\000\00001\000Match SNP Opcodes - Specified in Umask[7:4]\000 */
{ 6156307 }, /* unc_upi_txl_basic_hdr_match.wb\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0xd\000\00001\000Match Message Class -WB\000 */
{ 6157209 }, /* unc_upi_txl_basic_hdr_match.wb_opc\000uncore_upi\000uncore interconnect\000Matches on Transmit path of a UPI Port; Writeback. Unit: uncore_upi \000event=0x4,umask=0x10d\000\00001\000Match Message Class -WB\000 */
{ 6157394 }, /* unc_upi_txl_bypassed\000uncore_upi\000uncore interconnect\000FLITs that bypassed the TxL Buffer. Unit: uncore_upi \000event=0x41\000\00001\000Counts incoming FLITs (FLow control unITs) which bypassed the TxL(transmit) FLIT buffer and pass directly out the UPI Link. Generally, when data is transmitted across the Intel(R) Ultra Path Interconnect (UPI), it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used in L0p (Low Power) mode and (Link Layer Retry) LLR  mode, increasing latency to transfer out to the link\000 */
{ 6158804 }, /* unc_upi_txl_flits.all_data\000uncore_upi\000uncore interconnect\000Valid data FLITs transmitted via any slot. Unit: uncore_upi \000event=0x2,umask=0xf\000\00001\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 6159672 }, /* unc_upi_txl_flits.all_null\000uncore_upi\000uncore interconnect\000Null FLITs transmitted from any slot. Unit: uncore_upi \000event=0x2,umask=0x27\000\00001\000Counts null FLITs (80 bit FLow control unITs) transmitted via any of the 3 Intel(R) Ulra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 6160805 }, /* unc_upi_txl_flits.data\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Data. Unit: uncore_upi \000event=0x2,umask=0x8\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Data Flits (which consume all slots), but how much to count is based on Slot0-2 mask, so count can be 0-3 depending on which slots are enabled for counting.\000 */
{ 6161142 }, /* unc_upi_txl_flits.idle\000uncore_upi\000uncore interconnect\000Idle FLITs transmitted. Unit: uncore_upi \000event=0x2,umask=0x47\000\00001\000Counts when the Intel Ultra Path Interconnect(UPI) transmits an idle FLIT(80 bit FLow control unITs).  Every UPI cycle must be sending either data FLITs, protocol/credit FLITs or idle FLITs\000 */
{ 6161996 }, /* unc_upi_txl_flits.llcrd\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCRD Not Empty. Unit: uncore_upi \000event=0x2,umask=0x10\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables counting of LLCRD (with non-zero payload). This only applies to slot 2 since LLCRD is only allowed in slot 2\000 */
{ 6162583 }, /* unc_upi_txl_flits.llctrl\000uncore_upi\000uncore interconnect\000Valid Flits Sent; LLCTRL. Unit: uncore_upi \000event=0x2,umask=0x40\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Equivalent to an idle packet.  Enables counting of slot 0 LLCTRL messages\000 */
{ 6162836 }, /* unc_upi_txl_flits.non_data\000uncore_upi\000uncore interconnect\000Protocol header and credit FLITs transmitted across any slot. Unit: uncore_upi \000event=0x2,umask=0x97\000\00001\000Counts protocol header and credit FLITs (80 bit FLow control unITs) transmitted across any of the 3 UPI (Ultra Path Interconnect) slots on this UPI unit\000 */
{ 6163372 }, /* unc_upi_txl_flits.null\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.ALL_NULL. Unit: uncore_upi \000event=0x2,umask=0x20\000\00011\000\000 */
{ 6163916 }, /* unc_upi_txl_flits.prot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_FLITS.PROTHDR. Unit: uncore_upi \000event=0x2,umask=0x80\000\00011\000\000 */
{ 6164397 }, /* unc_upi_txl_flits.prothdr\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Protocol Header. Unit: uncore_upi \000event=0x2,umask=0x80\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Enables count of protocol headers in slot 0,1,2 (depending on slot uMask bits)\000 */
{ 6164939 }, /* unc_upi_txl_flits.slot0\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 0. Unit: uncore_upi \000event=0x2,umask=0x1\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 0 - Other mask bits determine types of headers to count\000 */
{ 6165457 }, /* unc_upi_txl_flits.slot1\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 1. Unit: uncore_upi \000event=0x2,umask=0x2\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 1 - Other mask bits determine types of headers to count\000 */
{ 6165975 }, /* unc_upi_txl_flits.slot2\000uncore_upi\000uncore interconnect\000Valid Flits Sent; Slot 2. Unit: uncore_upi \000event=0x2,umask=0x4\000\00001\000Shows legal flit time (hides impact of L0p and L0c).; Count Slot 2 - Other mask bits determine types of headers to count\000 */
{ 6166219 }, /* unc_upi_txl_hdr_match.data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166340 }, /* unc_upi_txl_hdr_match.dual_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166466 }, /* unc_upi_txl_hdr_match.loc\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6166582 }, /* unc_upi_txl_hdr_match.ncb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCB. Unit: uncore_upi \000event=0x4,umask=0xe\000\00011\000\000 */
{ 6166760 }, /* unc_upi_txl_hdr_match.ncs\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.NCS. Unit: uncore_upi \000event=0x4,umask=0xf\000\00011\000\000 */
{ 6166938 }, /* unc_upi_txl_hdr_match.non_data_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167063 }, /* unc_upi_txl_hdr_match.rem\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167179 }, /* unc_upi_txl_hdr_match.req\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.REQ. Unit: uncore_upi \000event=0x4,umask=0x8\000\00011\000\000 */
{ 6167357 }, /* unc_upi_txl_hdr_match.rsp_data\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_DATA. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000 */
{ 6167545 }, /* unc_upi_txl_hdr_match.rsp_nodata\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.RSP_NODATA. Unit: uncore_upi \000event=0x4,umask=0xa\000\00011\000\000 */
{ 6167737 }, /* unc_upi_txl_hdr_match.sgl_slot_hdr\000uncore_upi\000uncore interconnect\000This event is deprecated. Unit: uncore_upi \000event=0x4\000\00011\000\000 */
{ 6167862 }, /* unc_upi_txl_hdr_match.snp\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.SNP. Unit: uncore_upi \000event=0x4,umask=0x9\000\00011\000\000 */
{ 6168040 }, /* unc_upi_txl_hdr_match.wb\000uncore_upi\000uncore interconnect\000This event is deprecated. Refer to new event UNC_UPI_TxL_BASIC_HDR_MATCH.WB. Unit: uncore_upi \000event=0x4,umask=0xc\000\00011\000\000 */
{ 6168216 }, /* unc_upi_txl_inserts\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Allocations. Unit: uncore_upi \000event=0x40\000\00001\000Number of allocations into the UPI Tx Flit Buffer.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link.  This event can be used in conjunction with the Flit Buffer Occupancy event in order to calculate the average flit buffer lifetime\000 */
{ 6169257 }, /* unc_upi_txl_occupancy\000uncore_upi\000uncore interconnect\000Tx Flit Buffer Occupancy. Unit: uncore_upi \000event=0x42\000\00001\000Accumulates the number of flits in the TxQ.  Generally, when data is transmitted across UPI, it will bypass the TxQ and pass directly to the link.  However, the TxQ will be used with L0p and when LLR occurs, increasing latency to transfer out to the link. This can be used with the cycles not empty event to track average occupancy, or the allocations event to track average lifetime in the TxQ\000 */
{ 6170298 }, /* unc_upi_vna_credit_return_blocked_vn01\000uncore_upi\000uncore interconnect\000UNC_UPI_VNA_CREDIT_RETURN_BLOCKED_VN01. Unit: uncore_upi \000event=0x45\000\00001\000\000 */
{ 6170442 }, /* unc_upi_vna_credit_return_occupancy\000uncore_upi\000uncore interconnect\000VNA Credits Pending Return - Occupancy. Unit: uncore_upi \000event=0x44\000\00001\000Number of VNA credits in the Rx side that are waitng to be returned back across the link\000 */
{ 6241797 }, /* upi_data_bandwidth_tx\000uncore_upi\000uncore interconnect\000UPI interconnect send bandwidth for payload. Derived from unc_upi_txl_flits.all_data. Unit: uncore_upi \000event=0x2,umask=0xf\000\000017.11E-06Bytes\000Counts valid data FLITs (80 bit FLow control unITs: 64bits of data) transmitted (TxL) via any of the 3 Intel(R) Ultra Path Interconnect (UPI) slots on this UPI unit\000 */
{ 1216662 }, /* llc_misses.pcie_read\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4,ch_mask=0x1f\000\000014Bytes\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 1218626 }, /* llc_misses.pcie_write\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1,ch_mask=0x1f\000\000014Bytes\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3928456 }, /* unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the IIO Traffic Controller. Unit: uncore_iio \000event=0x1\000\00001\000Counts clockticks of the 1GHz trafiic controller clock in the IIO unit\000 */
{ 3929802 }, /* unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-3. Unit: uncore_iio \000event=0xc2,ch_mask=0x0f,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3931265 }, /* unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3932194 }, /* unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3933123 }, /* unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3934052 }, /* unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x4,umask=0x3\000\00001\000\000 */
{ 3937195 }, /* unc_iio_comp_buf_inserts.port0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937356 }, /* unc_iio_comp_buf_inserts.port1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937517 }, /* unc_iio_comp_buf_inserts.port2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3937678 }, /* unc_iio_comp_buf_inserts.port3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts; Port 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x7,umask=0x4\000\00001\000\000 */
{ 3938301 }, /* unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0-3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xf\000\00001\000\000 */
{ 3939267 }, /* unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000\000 */
{ 3939995 }, /* unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000\000 */
{ 3940758 }, /* unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000\000 */
{ 3941486 }, /* unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer occupancy of completions with data: Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000\000 */
{ 3945285 }, /* unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3946101 }, /* unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3946884 }, /* unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3947667 }, /* unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3949809 }, /* unc_iio_data_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3950109 }, /* unc_iio_data_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3951729 }, /* unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3952541 }, /* unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3953320 }, /* unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3954099 }, /* unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3956228 }, /* unc_iio_data_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3956527 }, /* unc_iio_data_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3958128 }, /* unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3958930 }, /* unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3959699 }, /* unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3960468 }, /* unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3962569 }, /* unc_iio_data_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3962864 }, /* unc_iio_data_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3964452 }, /* unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3965250 }, /* unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 1\000 */
{ 3966015 }, /* unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3966780 }, /* unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; x4 card is plugged in to slot 3\000 */
{ 3968868 }, /* unc_iio_data_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3969162 }, /* unc_iio_data_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3971560 }, /* unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3973128 }, /* unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3974655 }, /* unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3976127 }, /* unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for 4 bytes made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 3980473 }, /* unc_iio_data_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3980770 }, /* unc_iio_data_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3983856 }, /* unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3985379 }, /* unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3986861 }, /* unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3988289 }, /* unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of 4 bytes made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by  a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 3992444 }, /* unc_iio_data_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 3992740 }, /* unc_iio_data_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 3995027 }, /* unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 3996703 }, /* unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 3998338 }, /* unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 3999918 }, /* unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts ever peer to peer read request for 4 bytes of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4004544 }, /* unc_iio_data_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 4004864 }, /* unc_iio_data_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 4007165 }, /* unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit.  In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4008840 }, /* unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4010473 }, /* unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4012051 }, /* unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4016654 }, /* unc_iio_data_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 0\000 */
{ 4016973 }, /* unc_iio_data_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests initiated by the main die to the attached device.; VTd - Type 1\000 */
{ 4018591 }, /* unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4019380 }, /* unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4020136 }, /* unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4020892 }, /* unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4022977 }, /* unc_iio_data_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4023260 }, /* unc_iio_data_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4023543 }, /* unc_iio_data_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4023931 }, /* unc_iio_data_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4024251 }, /* unc_iio_data_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4024606 }, /* unc_iio_data_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4035451 }, /* unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4037437 }, /* unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4039204 }, /* unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4041021 }, /* unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4045823 }, /* unc_iio_data_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4046099 }, /* unc_iio_data_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4047837 }, /* unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4049819 }, /* unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4051582 }, /* unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4053395 }, /* unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of 4 bytes of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4058172 }, /* unc_iio_data_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4058447 }, /* unc_iio_data_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4059880 }, /* unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4060597 }, /* unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 1\000 */
{ 4061281 }, /* unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4061965 }, /* unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; x4 card is plugged in to slot 3\000 */
{ 4063837 }, /* unc_iio_data_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4064095 }, /* unc_iio_data_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4065814 }, /* unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4066946 }, /* unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4068002 }, /* unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4069038 }, /* unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for 4 bytes made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4071588 }, /* unc_iio_data_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4071899 }, /* unc_iio_data_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4074191 }, /* unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4075782 }, /* unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4077332 }, /* unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4078827 }, /* unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of 4 bytes made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of 4 bytes of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4083354 }, /* unc_iio_data_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 0\000 */
{ 4083664 }, /* unc_iio_data_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Data requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number of double word (4 bytes) requests the attached device made of the main die.; VTd - Type 1\000 */
{ 4101175 }, /* unc_iio_link_num_corr_err\000uncore_iio\000uncore io\000Num Link  Correctable Errors. Unit: uncore_iio \000event=0xf\000\00001\000\000 */
{ 4101285 }, /* unc_iio_link_num_retries\000uncore_iio\000uncore io\000Num Link Retries. Unit: uncore_iio \000event=0xe\000\00001\000\000 */
{ 4101382 }, /* unc_iio_mask_match\000uncore_iio\000uncore io\000Number packets that passed the Mask/Match Filter. Unit: uncore_iio \000event=0x21\000\00001\000\000 */
{ 4101975 }, /* unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4102686 }, /* unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4103435 }, /* unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4104093 }, /* unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4104822 }, /* unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4105601 }, /* unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus. Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000Asserted if all bits specified by mask match\000 */
{ 4106244 }, /* unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4106947 }, /* unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4107688 }, /* unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4108338 }, /* unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4109059 }, /* unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4109830 }, /* unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus; !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000Asserted if any bits specified by mask match\000 */
{ 4110041 }, /* unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0\000\00001\000\000 */
{ 4118219 }, /* unc_iio_payload_bytes_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118430 }, /* unc_iio_payload_bytes_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118641 }, /* unc_iio_payload_bytes_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4118852 }, /* unc_iio_payload_bytes_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119063 }, /* unc_iio_payload_bytes_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119273 }, /* unc_iio_payload_bytes_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMIC.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4119483 }, /* unc_iio_payload_bytes_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4119700 }, /* unc_iio_payload_bytes_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4119917 }, /* unc_iio_payload_bytes_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4120134 }, /* unc_iio_payload_bytes_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.ATOMICCMP.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4120351 }, /* unc_iio_payload_bytes_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120565 }, /* unc_iio_payload_bytes_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120779 }, /* unc_iio_payload_bytes_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4120993 }, /* unc_iio_payload_bytes_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121207 }, /* unc_iio_payload_bytes_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121420 }, /* unc_iio_payload_bytes_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4121633 }, /* unc_iio_payload_bytes_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4121849 }, /* unc_iio_payload_bytes_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122065 }, /* unc_iio_payload_bytes_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122281 }, /* unc_iio_payload_bytes_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122497 }, /* unc_iio_payload_bytes_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122712 }, /* unc_iio_payload_bytes_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4122927 }, /* unc_iio_payload_bytes_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123132 }, /* unc_iio_payload_bytes_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123337 }, /* unc_iio_payload_bytes_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123542 }, /* unc_iio_payload_bytes_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123747 }, /* unc_iio_payload_bytes_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4123951 }, /* unc_iio_payload_bytes_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.MSG.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4124155 }, /* unc_iio_payload_bytes_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124371 }, /* unc_iio_payload_bytes_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124587 }, /* unc_iio_payload_bytes_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4124803 }, /* unc_iio_payload_bytes_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125019 }, /* unc_iio_payload_bytes_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125234 }, /* unc_iio_payload_bytes_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4125449 }, /* unc_iio_payload_bytes_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0x83,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4125667 }, /* unc_iio_payload_bytes_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0x83,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4125885 }, /* unc_iio_payload_bytes_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0x83,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126103 }, /* unc_iio_payload_bytes_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0x83,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126321 }, /* unc_iio_payload_bytes_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126538 }, /* unc_iio_payload_bytes_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_OF_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4126755 }, /* unc_iio_payload_bytes_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4126971 }, /* unc_iio_payload_bytes_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127187 }, /* unc_iio_payload_bytes_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127403 }, /* unc_iio_payload_bytes_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127619 }, /* unc_iio_payload_bytes_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4127834 }, /* unc_iio_payload_bytes_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4128049 }, /* unc_iio_payload_bytes_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128267 }, /* unc_iio_payload_bytes_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128485 }, /* unc_iio_payload_bytes_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128703 }, /* unc_iio_payload_bytes_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4128921 }, /* unc_iio_payload_bytes_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4129138 }, /* unc_iio_payload_bytes_out.cfg_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.CFG_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4129355 }, /* unc_iio_payload_bytes_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129569 }, /* unc_iio_payload_bytes_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129783 }, /* unc_iio_payload_bytes_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4129997 }, /* unc_iio_payload_bytes_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130211 }, /* unc_iio_payload_bytes_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130424 }, /* unc_iio_payload_bytes_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4130637 }, /* unc_iio_payload_bytes_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4130853 }, /* unc_iio_payload_bytes_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131069 }, /* unc_iio_payload_bytes_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131285 }, /* unc_iio_payload_bytes_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131501 }, /* unc_iio_payload_bytes_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131716 }, /* unc_iio_payload_bytes_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4131931 }, /* unc_iio_payload_bytes_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132146 }, /* unc_iio_payload_bytes_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132361 }, /* unc_iio_payload_bytes_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132576 }, /* unc_iio_payload_bytes_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4132791 }, /* unc_iio_payload_bytes_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4133005 }, /* unc_iio_payload_bytes_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4133219 }, /* unc_iio_payload_bytes_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133436 }, /* unc_iio_payload_bytes_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133653 }, /* unc_iio_payload_bytes_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4133870 }, /* unc_iio_payload_bytes_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134087 }, /* unc_iio_payload_bytes_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134303 }, /* unc_iio_payload_bytes_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4134519 }, /* unc_iio_payload_bytes_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4134736 }, /* unc_iio_payload_bytes_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4134953 }, /* unc_iio_payload_bytes_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135170 }, /* unc_iio_payload_bytes_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135387 }, /* unc_iio_payload_bytes_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135603 }, /* unc_iio_payload_bytes_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4135819 }, /* unc_iio_payload_bytes_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc0,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136038 }, /* unc_iio_payload_bytes_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc0,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136257 }, /* unc_iio_payload_bytes_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc0,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136476 }, /* unc_iio_payload_bytes_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc0,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136695 }, /* unc_iio_payload_bytes_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4136913 }, /* unc_iio_payload_bytes_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_DATA_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4150367 }, /* unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000 */
{ 4150780 }, /* unc_iio_txn_in.atomic.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4150924 }, /* unc_iio_txn_in.atomic.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151068 }, /* unc_iio_txn_in.atomic.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151212 }, /* unc_iio_txn_in.atomic.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151356 }, /* unc_iio_txn_in.atomic.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151500 }, /* unc_iio_txn_in.atomic.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4151644 }, /* unc_iio_txn_in.atomiccmp.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4151791 }, /* unc_iio_txn_in.atomiccmp.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4151938 }, /* unc_iio_txn_in.atomiccmp.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4152085 }, /* unc_iio_txn_in.atomiccmp.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4152232 }, /* unc_iio_txn_in.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152377 }, /* unc_iio_txn_in.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152522 }, /* unc_iio_txn_in.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152667 }, /* unc_iio_txn_in.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152812 }, /* unc_iio_txn_in.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4152957 }, /* unc_iio_txn_in.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4153102 }, /* unc_iio_txn_in.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153307 }, /* unc_iio_txn_in.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153512 }, /* unc_iio_txn_in.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153717 }, /* unc_iio_txn_in.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4153922 }, /* unc_iio_txn_in.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4154126 }, /* unc_iio_txn_in.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_OF_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4154330 }, /* unc_iio_txn_in.msg.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154471 }, /* unc_iio_txn_in.msg.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154612 }, /* unc_iio_txn_in.msg.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154753 }, /* unc_iio_txn_in.msg.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4154894 }, /* unc_iio_txn_in.msg.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4155035 }, /* unc_iio_txn_in.msg.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4155176 }, /* unc_iio_txn_in.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155322 }, /* unc_iio_txn_in.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155468 }, /* unc_iio_txn_in.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155614 }, /* unc_iio_txn_in.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155760 }, /* unc_iio_txn_in.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4155906 }, /* unc_iio_txn_in.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4156052 }, /* unc_iio_txn_in.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156199 }, /* unc_iio_txn_in.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156346 }, /* unc_iio_txn_in.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156493 }, /* unc_iio_txn_in.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156640 }, /* unc_iio_txn_in.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156787 }, /* unc_iio_txn_in.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4156934 }, /* unc_iio_txn_out.cfg_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157139 }, /* unc_iio_txn_out.cfg_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157344 }, /* unc_iio_txn_out.cfg_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157549 }, /* unc_iio_txn_out.cfg_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157754 }, /* unc_iio_txn_out.cfg_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4157958 }, /* unc_iio_txn_out.cfg_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x40\000\00011\000\000 */
{ 4158162 }, /* unc_iio_txn_out.cfg_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158369 }, /* unc_iio_txn_out.cfg_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158576 }, /* unc_iio_txn_out.cfg_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158783 }, /* unc_iio_txn_out.cfg_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4158990 }, /* unc_iio_txn_out.cfg_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.CFG_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x10\000\00011\000\000 */
{ 4159196 }, /* unc_iio_txn_out.io_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159399 }, /* unc_iio_txn_out.io_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159602 }, /* unc_iio_txn_out.io_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4159805 }, /* unc_iio_txn_out.io_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160008 }, /* unc_iio_txn_out.io_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160210 }, /* unc_iio_txn_out.io_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x80\000\00011\000\000 */
{ 4160412 }, /* unc_iio_txn_out.io_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4160617 }, /* unc_iio_txn_out.io_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4160822 }, /* unc_iio_txn_out.io_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161027 }, /* unc_iio_txn_out.io_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161232 }, /* unc_iio_txn_out.io_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161436 }, /* unc_iio_txn_out.io_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.IO_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x20\000\00011\000\000 */
{ 4161640 }, /* unc_iio_txn_out.mem_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4161844 }, /* unc_iio_txn_out.mem_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162048 }, /* unc_iio_txn_out.mem_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162252 }, /* unc_iio_txn_out.mem_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162456 }, /* unc_iio_txn_out.mem_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162659 }, /* unc_iio_txn_out.mem_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x4\000\00011\000\000 */
{ 4162862 }, /* unc_iio_txn_out.mem_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163068 }, /* unc_iio_txn_out.mem_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163274 }, /* unc_iio_txn_out.mem_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163480 }, /* unc_iio_txn_out.mem_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163686 }, /* unc_iio_txn_out.mem_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4163891 }, /* unc_iio_txn_out.mem_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.MEM_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x1\000\00011\000\000 */
{ 4164096 }, /* unc_iio_txn_out.peer_read.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164302 }, /* unc_iio_txn_out.peer_read.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164508 }, /* unc_iio_txn_out.peer_read.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164714 }, /* unc_iio_txn_out.peer_read.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4164920 }, /* unc_iio_txn_out.peer_read.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4165125 }, /* unc_iio_txn_out.peer_read.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_READ.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x8\000\00011\000\000 */
{ 4165330 }, /* unc_iio_txn_out.peer_write.part0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART0. Unit: uncore_iio \000event=0xc1,ch_mask=0x1,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165538 }, /* unc_iio_txn_out.peer_write.part1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART1. Unit: uncore_iio \000event=0xc1,ch_mask=0x2,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165746 }, /* unc_iio_txn_out.peer_write.part2\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART2. Unit: uncore_iio \000event=0xc1,ch_mask=0x4,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4165954 }, /* unc_iio_txn_out.peer_write.part3\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.PART3. Unit: uncore_iio \000event=0xc1,ch_mask=0x8,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4166162 }, /* unc_iio_txn_out.peer_write.vtd0\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD0. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4166369 }, /* unc_iio_txn_out.peer_write.vtd1\000uncore_iio\000uncore io\000This event is deprecated. Refer to new event UNC_IIO_TXN_REQ_BY_CPU.PEER_WRITE.VTD1. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x7,umask=0x2\000\00011\000\000 */
{ 4167902 }, /* unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4168736 }, /* unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4169537 }, /* unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4170338 }, /* unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4172495 }, /* unc_iio_txn_req_by_cpu.cfg_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4172814 }, /* unc_iio_txn_req_by_cpu.cfg_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4174450 }, /* unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4175280 }, /* unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4176077 }, /* unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4176874 }, /* unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4179018 }, /* unc_iio_txn_req_by_cpu.cfg_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4179336 }, /* unc_iio_txn_req_by_cpu.cfg_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4180953 }, /* unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4181773 }, /* unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4182560 }, /* unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4183347 }, /* unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4185463 }, /* unc_iio_txn_req_by_cpu.io_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4185777 }, /* unc_iio_txn_req_by_cpu.io_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4187381 }, /* unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4188197 }, /* unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 1\000 */
{ 4188980 }, /* unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4189763 }, /* unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; x4 card is plugged in to slot 3\000 */
{ 4191866 }, /* unc_iio_txn_req_by_cpu.io_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4192179 }, /* unc_iio_txn_req_by_cpu.io_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4194293 }, /* unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part0. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4195867 }, /* unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part1. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4197400 }, /* unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part2. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4198878 }, /* unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by the CPU to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by a unit on the main die (generally a core) or by another IIO unit to the MMIO space of a card on IIO Part3. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4203090 }, /* unc_iio_txn_req_by_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4203406 }, /* unc_iio_txn_req_by_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4205513 }, /* unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part0 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4207084 }, /* unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part1 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4208614 }, /* unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part2 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4210089 }, /* unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made to IIO Part3 by the CPU. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a unit on the main die (generally a core) or by another IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4214278 }, /* unc_iio_txn_req_by_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4214593 }, /* unc_iio_txn_req_by_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4216357 }, /* unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part0. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part0. Does not include requests made by the same IIO unit. In the general case, part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4217604 }, /* unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part1. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part1. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4218775 }, /* unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part2. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part2. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4219926 }, /* unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request for up to a 64 byte transaction is made by a different IIO unit to IIO Part3. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request for up to a 64 byte transaction of data made by a different IIO unit to the MMIO space of a card on IIO Part3. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4222580 }, /* unc_iio_txn_req_by_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4222919 }, /* unc_iio_txn_req_by_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4224796 }, /* unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part0 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part0 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4226514 }, /* unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part1 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part1 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4228191 }, /* unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part2 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part2 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4229813 }, /* unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made to IIO Part3 by a different IIO unit. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made to the MMIO space of a card on IIO Part3 by a different IIO unit. Does not include requests made by the same IIO unit. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4234458 }, /* unc_iio_txn_req_by_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 0\000 */
{ 4234796 }, /* unc_iio_txn_req_by_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU; Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Outbound.  Number of requests, to the attached device, initiated by the main die.; VTd - Type 1\000 */
{ 4236442 }, /* unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4237261 }, /* unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4238047 }, /* unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4238833 }, /* unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4240957 }, /* unc_iio_txn_req_of_cpu.atomic.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4241267 }, /* unc_iio_txn_req_of_cpu.atomic.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4241577 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4241992 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4242339 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4242721 }, /* unc_iio_txn_req_of_cpu.atomiccmp.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Completion of atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4253397 }, /* unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4254900 }, /* unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is  made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4256362 }, /* unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4257768 }, /* unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Read request for up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Counts every read request for up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4261808 }, /* unc_iio_txn_req_of_cpu.mem_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4262111 }, /* unc_iio_txn_req_of_cpu.mem_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4264153 }, /* unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part0 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4265652 }, /* unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part1 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part1 to a unit on the main die (generally memory). In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4267110 }, /* unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part2 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part2 to a unit on the main die (generally memory). In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4268513 }, /* unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Write request of up to a 64 byte transaction is made by IIO Part3 to Memory. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Counts every write request of up to a 64 byte transaction of data made by IIO Part3 to a unit on the main die (generally memory). In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4272530 }, /* unc_iio_txn_req_of_cpu.mem_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4272832 }, /* unc_iio_txn_req_of_cpu.mem_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4274301 }, /* unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x16 card plugged in to stack, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4275048 }, /* unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 1\000 */
{ 4275762 }, /* unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4276476 }, /* unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; x4 card is plugged in to slot 3\000 */
{ 4278387 }, /* unc_iio_txn_req_of_cpu.msg.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4278672 }, /* unc_iio_txn_req_of_cpu.msg.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4280427 }, /* unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4281594 }, /* unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part1 to the MMIO space of an IIO target. In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4282685 }, /* unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4283756 }, /* unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Peer to peer read request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Counts every peer to peer read request of up to a 64 byte transaction made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4286350 }, /* unc_iio_txn_req_of_cpu.peer_read.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4286688 }, /* unc_iio_txn_req_of_cpu.peer_read.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4289036 }, /* unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part0 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part0 to the MMIO space of an IIO target. In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\000 */
{ 4290685 }, /* unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part1 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part1 to the MMIO space of an IIO target.In the general case, Part1 refers to a x4 PCIe card plugged into the second slot of a PCIe riser card, but it could refer to any x4 device attached to the IIO unit using lanes starting at lane 4 of the 16 lanes supported by the bus\000 */
{ 4292292 }, /* unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part2 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part2 to the MMIO space of an IIO target. In the general case, Part2 refers to a x4 or x8 PCIe card plugged into the third slot of a PCIe riser card, but it could refer to any x4 or x8 device attached to the IIO unit and using lanes starting at lane 8 of the 16 lanes supported by the bus\000 */
{ 4293845 }, /* unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Peer to peer write request of up to a 64 byte transaction is made by IIO Part3 to an IIO target. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Counts every peer to peer write request of up to a 64 byte transaction of data made by IIO Part3 to the MMIO space of an IIO target. In the general case, Part3 refers to a x4 PCIe card plugged into the fourth slot of a PCIe riser card, but it could brefer to  any device attached to the IIO unit using the lanes starting at lane 12 of the 16 lanes supported by the bus\000 */
{ 4298445 }, /* unc_iio_txn_req_of_cpu.peer_write.vtd0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 0\000 */
{ 4298782 }, /* unc_iio_txn_req_of_cpu.peer_write.vtd1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU; Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Also known as Inbound.  Number of 64 byte cache line requests initiated by the attached device.; VTd - Type 1\000 */
{ 4299119 }, /* unc_iio_vtd_access.ctxt_miss\000uncore_iio\000uncore io\000VTd Access; context cache miss. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000\000 */
{ 4299245 }, /* unc_iio_vtd_access.l1_miss\000uncore_iio\000uncore io\000VTd Access; L1 miss. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000\000 */
{ 4299358 }, /* unc_iio_vtd_access.l2_miss\000uncore_iio\000uncore io\000VTd Access; L2 miss. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000\000 */
{ 4299471 }, /* unc_iio_vtd_access.l3_miss\000uncore_iio\000uncore io\000VTd Access; L3 miss. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000\000 */
{ 4299585 }, /* unc_iio_vtd_access.l4_page_hit\000uncore_iio\000uncore io\000VTd Access; Vtd hit. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000\000 */
{ 4299702 }, /* unc_iio_vtd_access.tlb1_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000\000 */
{ 4299819 }, /* unc_iio_vtd_access.tlb_full\000uncore_iio\000uncore io\000VTd Access; TLB is full. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000\000 */
{ 4299938 }, /* unc_iio_vtd_access.tlb_miss\000uncore_iio\000uncore io\000VTd Access; TLB miss. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000\000 */
{ 4300054 }, /* unc_iio_vtd_occupancy\000uncore_iio\000uncore io\000VTd Occupancy. Unit: uncore_iio \000event=0x40\000\00001\000\000 */
{ 1209942 }, /* llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0x3\000\0000164Bytes\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 1211341 }, /* llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0xc\000\0000164Bytes\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5375947 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5376824 }, /* unc_m_act_count.rd\000uncore_imc\000uncore memory\000DRAM Activate Count; Activate due to Read. Unit: uncore_imc \000event=0x1,umask=0x1\000\00001\000Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5377697 }, /* unc_m_act_count.wr\000uncore_imc\000uncore memory\000DRAM Page Activate commands sent due to a write request. Unit: uncore_imc \000event=0x1,umask=0x2\000\00001\000Counts DRAM Page Activate commands sent on this channel due to a write request to the iMC (Memory Controller).  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS (Column Access Select) command\000 */
{ 5378853 }, /* unc_m_byp_cmds.act\000uncore_imc\000uncore memory\000ACT command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x1\000\00001\000\000 */
{ 5378979 }, /* unc_m_byp_cmds.cas\000uncore_imc\000uncore memory\000CAS command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x2\000\00001\000\000 */
{ 5379105 }, /* unc_m_byp_cmds.pre\000uncore_imc\000uncore memory\000PRE command issued by 2 cycle bypass. Unit: uncore_imc \000event=0xa1,umask=0x4\000\00001\000\000 */
{ 5379231 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, so this event increments for every read and write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5381140 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0x3\000\00001\000Counts all CAS (Column Access Select) read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every read.  This event includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 5382780 }, /* unc_m_cas_count.rd_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Read ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x40\000\00001\000\000 */
{ 5384152 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM Read CAS Commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts CAS (Column Access Select) regular read commands issued to DRAM on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every regular read.  This event only counts regular reads and does not includes underfill reads due to partial write requests.  This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write)  is enabled or not\000 */
{ 5386414 }, /* unc_m_cas_count.rd_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in RMM. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000\000 */
{ 5387373 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM Underfill Read CAS Commands issued. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000Counts CAS (Column Access Select) underfill read commands issued to DRAM due to a partial write, on a per channel basis.  CAS commands are issued to specify the address to read or write on DRAM, and this command counts underfill reads.  Partial writes must be completed by first reading in the underfill from DRAM and then merging in the partial write data before writing the full line back to DRAM. This event will generally count about the same as the number of partial writes, but may be slightly less because of partials hitting in the WPQ (due to a previous write request)\000 */
{ 5388524 }, /* unc_m_cas_count.rd_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in WMM. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000\000 */
{ 5388834 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM Write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0xc\000\00001\000Counts all CAS (Column Address Select) commands issued to DRAM per memory channel.  CAS commands are issued to specify the address to read or write on DRAM, and this event increments for every write. This event counts whether AutoPrecharge (which closes the DRAM Page automatically after a read/write) is enabled or not\000 */
{ 5390243 }, /* unc_m_cas_count.wr_isoch\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; Read CAS issued in Write ISOCH Mode. Unit: uncore_imc \000event=0x4,umask=0x80\000\00001\000\000 */
{ 5391405 }, /* unc_m_cas_count.wr_rmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Read Major Mode. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000Counts the total number of Opportunistic DRAM Write CAS commands issued on this channel while in Read-Major-Mode\000 */
{ 5392215 }, /* unc_m_cas_count.wr_wmm\000uncore_imc\000uncore memory\000DRAM CAS (Column Address Strobe) Commands.; DRAM WR_CAS (w/ and w/out auto-pre) in Write Major Mode. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total number or DRAM Write CAS commands issued on this channel while in Write-Major-Mode\000 */
{ 5394980 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Memory controller clock ticks. Unit: uncore_imc \000event=0\000\00001\000Counts clockticks of the fixed frequency clock of the memory controller using one of the programmable counters\000 */
{ 5395395 }, /* unc_m_clockticks_f\000uncore_imc\000uncore memory\000Clockticks in the Memory Controller using a dedicated 48-bit Fixed Counter. Unit: uncore_imc \000event=0xff\000\00001\000\000 */
{ 5397417 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x6\000\00001\000Counts the number of times that the precharge all command was sent\000 */
{ 5397786 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x4\000\00001\000Counts the number of refreshes issued\000 */
{ 5398352 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x5,umask=0x2\000\00001\000Counts the number of refreshes issued\000 */
{ 5398727 }, /* unc_m_ecc_correctable_errors\000uncore_imc\000uncore memory\000ECC Correctable Errors. Unit: uncore_imc \000event=0x9\000\00001\000Counts the number of ECC errors detected and corrected by the iMC on this channel.  This counter is only useful with ECC DRAM devices.  This count will increment one time for each correction regardless of the number of bits corrected.  The iMC can correct up to 4 bit errors in independent channel mode and 8 bit errors in lockstep mode\000 */
{ 5399951 }, /* unc_m_major_modes.isoch\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Isoch Major Mode. Unit: uncore_imc \000event=0x7,umask=0x8\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; We group these two modes together so that we can use four counters to track each of the major modes at one time.  These major modes are used whenever there is an ISOCH txn in the memory controller.  In these mode, only ISOCH transactions are processed\000 */
{ 5400821 }, /* unc_m_major_modes.partial\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Partial Major Mode. Unit: uncore_imc \000event=0x7,umask=0x4\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This major mode is used to drain starved underfill reads.  Regular reads and writes are blocked and only underfill reads will be processed\000 */
{ 5401586 }, /* unc_m_major_modes.read\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Read Major Mode. Unit: uncore_imc \000event=0x7,umask=0x1\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; Read Major Mode is the default mode for the iMC, as reads are generally more critical to forward progress than writes\000 */
{ 5402318 }, /* unc_m_major_modes.write\000uncore_imc\000uncore memory\000Cycles in a Major Mode; Write Major Mode. Unit: uncore_imc \000event=0x7,umask=0x2\000\00001\000Counts the total number of cycles spent in a major mode (selected by a filter) on the given channel.   Major modea are channel-wide, and not a per-rank (or dimm or bank) mode.; This mode is triggered when the WPQ hits high occupancy and causes writes to be higher priority than reads.  This can cause blips in the available read bandwidth in the system and temporarily increase read latencies in order to achieve better bus utilizations and higher bandwidth\000 */
{ 5416745 }, /* unc_m_power_channel_dlloff\000uncore_imc\000uncore memory\000Channel DLLOFF Cycles. Unit: uncore_imc \000event=0x84\000\00001\000Number of cycles when all the ranks in the channel are in CKE Slow (DLLOFF) mode\000 */
{ 5418508 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000event=0x85\000\00001\000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000 */
{ 5422286 }, /* unc_m_power_cke_cycles.rank0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x1\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423083 }, /* unc_m_power_cke_cycles.rank1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x2\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5423880 }, /* unc_m_power_cke_cycles.rank2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x4\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5424677 }, /* unc_m_power_cke_cycles.rank3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x8\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5425474 }, /* unc_m_power_cke_cycles.rank4\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x10\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5426272 }, /* unc_m_power_cke_cycles.rank5\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x20\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427070 }, /* unc_m_power_cke_cycles.rank6\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x40\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5427868 }, /* unc_m_power_cke_cycles.rank7\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank; DIMM ID. Unit: uncore_imc \000event=0x83,umask=0x80\000\00001\000Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5429729 }, /* unc_m_power_critical_throttle_cycles\000uncore_imc\000uncore memory\000Critical Throttle Cycles. Unit: uncore_imc \000event=0x86\000\00001\000Counts the number of cycles when the iMC is in critical thermal throttling.  When this happens, all traffic is blocked.  This should be rare unless something bad is going on in the platform.  There is no filtering by rank for this event\000 */
{ 5430087 }, /* unc_m_power_pcu_throttling\000uncore_imc\000uncore memory\000UNC_M_POWER_PCU_THROTTLING. Unit: uncore_imc \000event=0x42\000\00001\000\000 */
{ 5431979 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000event=0x43\000\00001\000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5432603 }, /* unc_m_power_throttle_cycles.rank0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x1\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1.; Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5433615 }, /* unc_m_power_throttle_cycles.rank1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x2\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434065 }, /* unc_m_power_throttle_cycles.rank2\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x4\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434515 }, /* unc_m_power_throttle_cycles.rank3\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x8\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5434965 }, /* unc_m_power_throttle_cycles.rank4\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x10\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435416 }, /* unc_m_power_throttle_cycles.rank5\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x20\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5435867 }, /* unc_m_power_throttle_cycles.rank6\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x40\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5436318 }, /* unc_m_power_throttle_cycles.rank7\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0; DIMM ID. Unit: uncore_imc \000event=0x41,umask=0x80\000\00001\000Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5438258 }, /* unc_m_pre_count.byp\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to bypass. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5438463 }, /* unc_m_pre_count.page_close\000uncore_imc\000uncore memory\000DRAM Precharge commands.; Precharge due to timer expiration. Unit: uncore_imc \000event=0x2,umask=0x2\000\00001\000Counts the number of DRAM Precharge commands sent on this channel.; Counts the number of DRAM Precharge commands sent on this channel as a result of the page close counter expiring.  This does not include implicit precharge commands sent in auto-precharge mode\000 */
{ 5440157 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000Pre-charges due to page misses. Unit: uncore_imc \000event=0x2,umask=0x1\000\00001\000Counts the number of explicit DRAM Precharge commands sent on this channel as a result of a DRAM page miss. This does not include the implicit precharge commands sent with CAS commands in Auto-Precharge mode. This does not include Precharge commands sent as a result of a page close counter expiration\000 */
{ 5442408 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Pre-charge for reads. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000Counts the number of explicit DRAM Precharge commands issued on a per channel basis due to a read, so as to close the previous DRAM page, before opening the requested page\000 */
{ 5444802 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Pre-charge for writes. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5446251 }, /* unc_m_preemption.rd_preempt_rd\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Read Preemption. Unit: uncore_imc \000event=0x8,umask=0x1\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts another read\000 */
{ 5447478 }, /* unc_m_preemption.rd_preempt_wr\000uncore_imc\000uncore memory\000Read Preemption Count; Read over Write Preemption. Unit: uncore_imc \000event=0x8,umask=0x2\000\00001\000Counts the number of times a read in the iMC preempts another read or write.  Generally reads to an open page are issued ahead of requests to closed pages.  This improves the page hit rate of the system.  However, high priority requests can cause pages of active requests to be closed in order to get them out.  This will reduce the latency of the high-priority request at the expense of lower bandwidth and increased overall average latency.; Filter for when a read preempts a write\000 */
{ 5448818 }, /* unc_m_rd_cas_prio.high\000uncore_imc\000uncore memory\000Read CAS issued with HIGH priority. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5448946 }, /* unc_m_rd_cas_prio.low\000uncore_imc\000uncore memory\000Read CAS issued with LOW priority. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5449072 }, /* unc_m_rd_cas_prio.med\000uncore_imc\000uncore memory\000Read CAS issued with MEDIUM priority. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5449201 }, /* unc_m_rd_cas_prio.panic\000uncore_imc\000uncore memory\000Read CAS issued with PANIC NON ISOCH priority (starved). Unit: uncore_imc \000event=0xa0,umask=0x8\000\00001\000\000 */
{ 5449520 }, /* unc_m_rd_cas_rank0.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb0,umask=0x10\000\00001\000\000 */
{ 5449930 }, /* unc_m_rd_cas_rank0.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb0\000\00001\000\000 */
{ 5451952 }, /* unc_m_rd_cas_rank0.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb0,umask=0x1\000\00001\000\000 */
{ 5450209 }, /* unc_m_rd_cas_rank0.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb0,umask=0xa\000\00001\000\000 */
{ 5450500 }, /* unc_m_rd_cas_rank0.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb0,umask=0xb\000\00001\000\000 */
{ 5450791 }, /* unc_m_rd_cas_rank0.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb0,umask=0xc\000\00001\000\000 */
{ 5451082 }, /* unc_m_rd_cas_rank0.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb0,umask=0xd\000\00001\000\000 */
{ 5451373 }, /* unc_m_rd_cas_rank0.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb0,umask=0xe\000\00001\000\000 */
{ 5451664 }, /* unc_m_rd_cas_rank0.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb0,umask=0xf\000\00001\000\000 */
{ 5452365 }, /* unc_m_rd_cas_rank0.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb0,umask=0x2\000\00001\000\000 */
{ 5452778 }, /* unc_m_rd_cas_rank0.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb0,umask=0x3\000\00001\000\000 */
{ 5453319 }, /* unc_m_rd_cas_rank0.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb0,umask=0x4\000\00001\000\000 */
{ 5453733 }, /* unc_m_rd_cas_rank0.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb0,umask=0x5\000\00001\000\000 */
{ 5454147 }, /* unc_m_rd_cas_rank0.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb0,umask=0x6\000\00001\000\000 */
{ 5454433 }, /* unc_m_rd_cas_rank0.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb0,umask=0x7\000\00001\000\000 */
{ 5454847 }, /* unc_m_rd_cas_rank0.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb0,umask=0x8\000\00001\000\000 */
{ 5455133 }, /* unc_m_rd_cas_rank0.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb0,umask=0x9\000\00001\000\000 */
{ 5455457 }, /* unc_m_rd_cas_rank0.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb0,umask=0x11\000\00001\000\000 */
{ 5455801 }, /* unc_m_rd_cas_rank0.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb0,umask=0x12\000\00001\000\000 */
{ 5456147 }, /* unc_m_rd_cas_rank0.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb0,umask=0x13\000\00001\000\000 */
{ 5456496 }, /* unc_m_rd_cas_rank0.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb0,umask=0x14\000\00001\000\000 */
{ 5456814 }, /* unc_m_rd_cas_rank1.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb1,umask=0x10\000\00001\000\000 */
{ 5457224 }, /* unc_m_rd_cas_rank1.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb1\000\00001\000\000 */
{ 5459246 }, /* unc_m_rd_cas_rank1.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb1,umask=0x1\000\00001\000\000 */
{ 5457503 }, /* unc_m_rd_cas_rank1.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb1,umask=0xa\000\00001\000\000 */
{ 5457794 }, /* unc_m_rd_cas_rank1.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb1,umask=0xb\000\00001\000\000 */
{ 5458085 }, /* unc_m_rd_cas_rank1.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb1,umask=0xc\000\00001\000\000 */
{ 5458376 }, /* unc_m_rd_cas_rank1.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb1,umask=0xd\000\00001\000\000 */
{ 5458667 }, /* unc_m_rd_cas_rank1.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb1,umask=0xe\000\00001\000\000 */
{ 5458958 }, /* unc_m_rd_cas_rank1.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb1,umask=0xf\000\00001\000\000 */
{ 5459659 }, /* unc_m_rd_cas_rank1.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb1,umask=0x2\000\00001\000\000 */
{ 5460072 }, /* unc_m_rd_cas_rank1.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb1,umask=0x3\000\00001\000\000 */
{ 5460613 }, /* unc_m_rd_cas_rank1.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb1,umask=0x4\000\00001\000\000 */
{ 5461027 }, /* unc_m_rd_cas_rank1.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb1,umask=0x5\000\00001\000\000 */
{ 5461441 }, /* unc_m_rd_cas_rank1.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb1,umask=0x6\000\00001\000\000 */
{ 5461727 }, /* unc_m_rd_cas_rank1.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb1,umask=0x7\000\00001\000\000 */
{ 5462141 }, /* unc_m_rd_cas_rank1.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb1,umask=0x8\000\00001\000\000 */
{ 5462427 }, /* unc_m_rd_cas_rank1.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb1,umask=0x9\000\00001\000\000 */
{ 5462751 }, /* unc_m_rd_cas_rank1.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb1,umask=0x11\000\00001\000\000 */
{ 5463095 }, /* unc_m_rd_cas_rank1.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb1,umask=0x12\000\00001\000\000 */
{ 5463441 }, /* unc_m_rd_cas_rank1.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb1,umask=0x13\000\00001\000\000 */
{ 5463790 }, /* unc_m_rd_cas_rank1.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb1,umask=0x14\000\00001\000\000 */
{ 5463939 }, /* unc_m_rd_cas_rank2.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xb2,umask=0x10\000\00001\000\000 */
{ 5464349 }, /* unc_m_rd_cas_rank2.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xb2\000\00001\000\000 */
{ 5465240 }, /* unc_m_rd_cas_rank2.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xb2,umask=0x1\000\00001\000\000 */
{ 5464466 }, /* unc_m_rd_cas_rank2.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xb2,umask=0xa\000\00001\000\000 */
{ 5464595 }, /* unc_m_rd_cas_rank2.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xb2,umask=0xb\000\00001\000\000 */
{ 5464724 }, /* unc_m_rd_cas_rank2.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xb2,umask=0xc\000\00001\000\000 */
{ 5464853 }, /* unc_m_rd_cas_rank2.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xb2,umask=0xd\000\00001\000\000 */
{ 5464982 }, /* unc_m_rd_cas_rank2.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xb2,umask=0xe\000\00001\000\000 */
{ 5465111 }, /* unc_m_rd_cas_rank2.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xb2,umask=0xf\000\00001\000\000 */
{ 5465494 }, /* unc_m_rd_cas_rank2.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xb2,umask=0x2\000\00001\000\000 */
{ 5465748 }, /* unc_m_rd_cas_rank2.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xb2,umask=0x3\000\00001\000\000 */
{ 5466130 }, /* unc_m_rd_cas_rank2.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xb2,umask=0x4\000\00001\000\000 */
{ 5466385 }, /* unc_m_rd_cas_rank2.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xb2,umask=0x5\000\00001\000\000 */
{ 5466640 }, /* unc_m_rd_cas_rank2.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xb2,umask=0x6\000\00001\000\000 */
{ 5466767 }, /* unc_m_rd_cas_rank2.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xb2,umask=0x7\000\00001\000\000 */
{ 5467022 }, /* unc_m_rd_cas_rank2.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xb2,umask=0x8\000\00001\000\000 */
{ 5467149 }, /* unc_m_rd_cas_rank2.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xb2,umask=0x9\000\00001\000\000 */
{ 5467276 }, /* unc_m_rd_cas_rank2.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb2,umask=0x11\000\00001\000\000 */
{ 5467423 }, /* unc_m_rd_cas_rank2.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb2,umask=0x12\000\00001\000\000 */
{ 5467570 }, /* unc_m_rd_cas_rank2.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb2,umask=0x13\000\00001\000\000 */
{ 5467718 }, /* unc_m_rd_cas_rank2.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb2,umask=0x14\000\00001\000\000 */
{ 5467867 }, /* unc_m_rd_cas_rank3.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xb3,umask=0x10\000\00001\000\000 */
{ 5468128 }, /* unc_m_rd_cas_rank3.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xb3\000\00001\000\000 */
{ 5469019 }, /* unc_m_rd_cas_rank3.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xb3,umask=0x1\000\00001\000\000 */
{ 5468245 }, /* unc_m_rd_cas_rank3.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xb3,umask=0xa\000\00001\000\000 */
{ 5468374 }, /* unc_m_rd_cas_rank3.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xb3,umask=0xb\000\00001\000\000 */
{ 5468503 }, /* unc_m_rd_cas_rank3.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xb3,umask=0xc\000\00001\000\000 */
{ 5468632 }, /* unc_m_rd_cas_rank3.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xb3,umask=0xd\000\00001\000\000 */
{ 5468761 }, /* unc_m_rd_cas_rank3.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xb3,umask=0xe\000\00001\000\000 */
{ 5468890 }, /* unc_m_rd_cas_rank3.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xb3,umask=0xf\000\00001\000\000 */
{ 5469273 }, /* unc_m_rd_cas_rank3.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xb3,umask=0x2\000\00001\000\000 */
{ 5469527 }, /* unc_m_rd_cas_rank3.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xb3,umask=0x3\000\00001\000\000 */
{ 5469909 }, /* unc_m_rd_cas_rank3.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xb3,umask=0x4\000\00001\000\000 */
{ 5470164 }, /* unc_m_rd_cas_rank3.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xb3,umask=0x5\000\00001\000\000 */
{ 5470419 }, /* unc_m_rd_cas_rank3.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xb3,umask=0x6\000\00001\000\000 */
{ 5470546 }, /* unc_m_rd_cas_rank3.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xb3,umask=0x7\000\00001\000\000 */
{ 5470801 }, /* unc_m_rd_cas_rank3.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xb3,umask=0x8\000\00001\000\000 */
{ 5470928 }, /* unc_m_rd_cas_rank3.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xb3,umask=0x9\000\00001\000\000 */
{ 5471055 }, /* unc_m_rd_cas_rank3.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb3,umask=0x11\000\00001\000\000 */
{ 5471202 }, /* unc_m_rd_cas_rank3.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb3,umask=0x12\000\00001\000\000 */
{ 5471349 }, /* unc_m_rd_cas_rank3.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb3,umask=0x13\000\00001\000\000 */
{ 5471497 }, /* unc_m_rd_cas_rank3.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb3,umask=0x14\000\00001\000\000 */
{ 5471815 }, /* unc_m_rd_cas_rank4.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xb4,umask=0x10\000\00001\000\000 */
{ 5472225 }, /* unc_m_rd_cas_rank4.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xb4\000\00001\000\000 */
{ 5474247 }, /* unc_m_rd_cas_rank4.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xb4,umask=0x1\000\00001\000\000 */
{ 5472504 }, /* unc_m_rd_cas_rank4.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xb4,umask=0xa\000\00001\000\000 */
{ 5472795 }, /* unc_m_rd_cas_rank4.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xb4,umask=0xb\000\00001\000\000 */
{ 5473086 }, /* unc_m_rd_cas_rank4.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xb4,umask=0xc\000\00001\000\000 */
{ 5473377 }, /* unc_m_rd_cas_rank4.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xb4,umask=0xd\000\00001\000\000 */
{ 5473668 }, /* unc_m_rd_cas_rank4.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xb4,umask=0xe\000\00001\000\000 */
{ 5473959 }, /* unc_m_rd_cas_rank4.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xb4,umask=0xf\000\00001\000\000 */
{ 5474660 }, /* unc_m_rd_cas_rank4.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xb4,umask=0x2\000\00001\000\000 */
{ 5475073 }, /* unc_m_rd_cas_rank4.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xb4,umask=0x3\000\00001\000\000 */
{ 5475614 }, /* unc_m_rd_cas_rank4.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xb4,umask=0x4\000\00001\000\000 */
{ 5476028 }, /* unc_m_rd_cas_rank4.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xb4,umask=0x5\000\00001\000\000 */
{ 5476442 }, /* unc_m_rd_cas_rank4.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xb4,umask=0x6\000\00001\000\000 */
{ 5476728 }, /* unc_m_rd_cas_rank4.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xb4,umask=0x7\000\00001\000\000 */
{ 5477142 }, /* unc_m_rd_cas_rank4.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xb4,umask=0x8\000\00001\000\000 */
{ 5477428 }, /* unc_m_rd_cas_rank4.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xb4,umask=0x9\000\00001\000\000 */
{ 5477752 }, /* unc_m_rd_cas_rank4.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb4,umask=0x11\000\00001\000\000 */
{ 5478096 }, /* unc_m_rd_cas_rank4.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb4,umask=0x12\000\00001\000\000 */
{ 5478442 }, /* unc_m_rd_cas_rank4.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb4,umask=0x13\000\00001\000\000 */
{ 5478791 }, /* unc_m_rd_cas_rank4.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb4,umask=0x14\000\00001\000\000 */
{ 5479109 }, /* unc_m_rd_cas_rank5.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xb5,umask=0x10\000\00001\000\000 */
{ 5479519 }, /* unc_m_rd_cas_rank5.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xb5\000\00001\000\000 */
{ 5481541 }, /* unc_m_rd_cas_rank5.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xb5,umask=0x1\000\00001\000\000 */
{ 5479798 }, /* unc_m_rd_cas_rank5.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xb5,umask=0xa\000\00001\000\000 */
{ 5480089 }, /* unc_m_rd_cas_rank5.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xb5,umask=0xb\000\00001\000\000 */
{ 5480380 }, /* unc_m_rd_cas_rank5.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xb5,umask=0xc\000\00001\000\000 */
{ 5480671 }, /* unc_m_rd_cas_rank5.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xb5,umask=0xd\000\00001\000\000 */
{ 5480962 }, /* unc_m_rd_cas_rank5.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xb5,umask=0xe\000\00001\000\000 */
{ 5481253 }, /* unc_m_rd_cas_rank5.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xb5,umask=0xf\000\00001\000\000 */
{ 5481954 }, /* unc_m_rd_cas_rank5.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xb5,umask=0x2\000\00001\000\000 */
{ 5482367 }, /* unc_m_rd_cas_rank5.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xb5,umask=0x3\000\00001\000\000 */
{ 5482908 }, /* unc_m_rd_cas_rank5.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xb5,umask=0x4\000\00001\000\000 */
{ 5483322 }, /* unc_m_rd_cas_rank5.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xb5,umask=0x5\000\00001\000\000 */
{ 5483736 }, /* unc_m_rd_cas_rank5.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xb5,umask=0x6\000\00001\000\000 */
{ 5484022 }, /* unc_m_rd_cas_rank5.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xb5,umask=0x7\000\00001\000\000 */
{ 5484436 }, /* unc_m_rd_cas_rank5.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xb5,umask=0x8\000\00001\000\000 */
{ 5484722 }, /* unc_m_rd_cas_rank5.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xb5,umask=0x9\000\00001\000\000 */
{ 5485046 }, /* unc_m_rd_cas_rank5.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb5,umask=0x11\000\00001\000\000 */
{ 5485390 }, /* unc_m_rd_cas_rank5.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb5,umask=0x12\000\00001\000\000 */
{ 5485736 }, /* unc_m_rd_cas_rank5.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb5,umask=0x13\000\00001\000\000 */
{ 5486085 }, /* unc_m_rd_cas_rank5.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb5,umask=0x14\000\00001\000\000 */
{ 5486403 }, /* unc_m_rd_cas_rank6.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xb6,umask=0x10\000\00001\000\000 */
{ 5486813 }, /* unc_m_rd_cas_rank6.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xb6\000\00001\000\000 */
{ 5488835 }, /* unc_m_rd_cas_rank6.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xb6,umask=0x1\000\00001\000\000 */
{ 5487092 }, /* unc_m_rd_cas_rank6.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xb6,umask=0xa\000\00001\000\000 */
{ 5487383 }, /* unc_m_rd_cas_rank6.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xb6,umask=0xb\000\00001\000\000 */
{ 5487674 }, /* unc_m_rd_cas_rank6.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xb6,umask=0xc\000\00001\000\000 */
{ 5487965 }, /* unc_m_rd_cas_rank6.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xb6,umask=0xd\000\00001\000\000 */
{ 5488256 }, /* unc_m_rd_cas_rank6.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xb6,umask=0xe\000\00001\000\000 */
{ 5488547 }, /* unc_m_rd_cas_rank6.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xb6,umask=0xf\000\00001\000\000 */
{ 5489248 }, /* unc_m_rd_cas_rank6.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xb6,umask=0x2\000\00001\000\000 */
{ 5489661 }, /* unc_m_rd_cas_rank6.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xb6,umask=0x3\000\00001\000\000 */
{ 5490202 }, /* unc_m_rd_cas_rank6.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xb6,umask=0x4\000\00001\000\000 */
{ 5490616 }, /* unc_m_rd_cas_rank6.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xb6,umask=0x5\000\00001\000\000 */
{ 5491030 }, /* unc_m_rd_cas_rank6.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xb6,umask=0x6\000\00001\000\000 */
{ 5491316 }, /* unc_m_rd_cas_rank6.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xb6,umask=0x7\000\00001\000\000 */
{ 5491730 }, /* unc_m_rd_cas_rank6.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xb6,umask=0x8\000\00001\000\000 */
{ 5492016 }, /* unc_m_rd_cas_rank6.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xb6,umask=0x9\000\00001\000\000 */
{ 5492340 }, /* unc_m_rd_cas_rank6.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb6,umask=0x11\000\00001\000\000 */
{ 5492684 }, /* unc_m_rd_cas_rank6.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb6,umask=0x12\000\00001\000\000 */
{ 5493030 }, /* unc_m_rd_cas_rank6.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb6,umask=0x13\000\00001\000\000 */
{ 5493379 }, /* unc_m_rd_cas_rank6.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb6,umask=0x14\000\00001\000\000 */
{ 5493697 }, /* unc_m_rd_cas_rank7.allbanks\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xb7,umask=0x10\000\00001\000\000 */
{ 5494107 }, /* unc_m_rd_cas_rank7.bank0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xb7\000\00001\000\000 */
{ 5496129 }, /* unc_m_rd_cas_rank7.bank1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xb7,umask=0x1\000\00001\000\000 */
{ 5494386 }, /* unc_m_rd_cas_rank7.bank10\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xb7,umask=0xa\000\00001\000\000 */
{ 5494677 }, /* unc_m_rd_cas_rank7.bank11\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xb7,umask=0xb\000\00001\000\000 */
{ 5494968 }, /* unc_m_rd_cas_rank7.bank12\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xb7,umask=0xc\000\00001\000\000 */
{ 5495259 }, /* unc_m_rd_cas_rank7.bank13\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xb7,umask=0xd\000\00001\000\000 */
{ 5495550 }, /* unc_m_rd_cas_rank7.bank14\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xb7,umask=0xe\000\00001\000\000 */
{ 5495841 }, /* unc_m_rd_cas_rank7.bank15\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xb7,umask=0xf\000\00001\000\000 */
{ 5496542 }, /* unc_m_rd_cas_rank7.bank2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xb7,umask=0x2\000\00001\000\000 */
{ 5496955 }, /* unc_m_rd_cas_rank7.bank3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xb7,umask=0x3\000\00001\000\000 */
{ 5497496 }, /* unc_m_rd_cas_rank7.bank4\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xb7,umask=0x4\000\00001\000\000 */
{ 5497910 }, /* unc_m_rd_cas_rank7.bank5\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xb7,umask=0x5\000\00001\000\000 */
{ 5498324 }, /* unc_m_rd_cas_rank7.bank6\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xb7,umask=0x6\000\00001\000\000 */
{ 5498610 }, /* unc_m_rd_cas_rank7.bank7\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xb7,umask=0x7\000\00001\000\000 */
{ 5499024 }, /* unc_m_rd_cas_rank7.bank8\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xb7,umask=0x8\000\00001\000\000 */
{ 5499310 }, /* unc_m_rd_cas_rank7.bank9\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xb7,umask=0x9\000\00001\000\000 */
{ 5499634 }, /* unc_m_rd_cas_rank7.bankg0\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb7,umask=0x11\000\00001\000\000 */
{ 5499978 }, /* unc_m_rd_cas_rank7.bankg1\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb7,umask=0x12\000\00001\000\000 */
{ 5500324 }, /* unc_m_rd_cas_rank7.bankg2\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb7,umask=0x13\000\00001\000\000 */
{ 5500673 }, /* unc_m_rd_cas_rank7.bankg3\000uncore_imc\000uncore memory\000RD_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb7,umask=0x14\000\00001\000\000 */
{ 5502958 }, /* unc_m_rpq_cycles_full\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5506599 }, /* unc_m_rpq_cycles_ne\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11\000\00001\000Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5509114 }, /* unc_m_rpq_inserts\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10\000\00001\000Counts the number of read requests allocated into the Read Pending Queue (RPQ).  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  The requests deallocate after the read CAS command has been issued to DRAM.  This event counts both Isochronous and non-Isochronous requests which were issued to the RPQ\000 */
{ 5510414 }, /* unc_m_rpq_occupancy\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Counts the number of entries in the Read Pending Queue (RPQ) at each cycle.  This can then be used to calculate both the average occupancy of the queue (in conjunction with the number of cycles not empty) and the average latency in the queue (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC. They deallocate from the RPQ after the CAS command has been issued to memory\000 */
{ 5534494 }, /* unc_m_wmm_to_rmm.low_thresh\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold; Transition from WMM to RMM because of starve counter. Unit: uncore_imc \000event=0xc0,umask=0x1\000\00001\000\000 */
{ 5534698 }, /* unc_m_wmm_to_rmm.starve\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x2\000\00001\000\000 */
{ 5534844 }, /* unc_m_wmm_to_rmm.vmse_retry\000uncore_imc\000uncore memory\000Transition from WMM to RMM because of low threshold. Unit: uncore_imc \000event=0xc0,umask=0x4\000\00001\000\000 */
{ 5535448 }, /* unc_m_wpq_cycles_full\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5538845 }, /* unc_m_wpq_cycles_ne\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21\000\00001\000Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5544584 }, /* unc_m_wpq_inserts\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20\000\00001\000Counts the number of writes requests allocated into the Write Pending Queue (WPQ).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (Memory Controller).  The write requests deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC\000 */
{ 5546690 }, /* unc_m_wpq_occupancy\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Counts the number of entries in the Write Pending Queue (WPQ) at each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule writes out to the memory controller and to track the requests.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC (memory controller).  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have 'posted' to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the 'not posted' filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The 'posted' filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5553164 }, /* unc_m_wpq_read_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5555855 }, /* unc_m_wpq_write_hit\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24\000\00001\000Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5556664 }, /* unc_m_wr_cas_rank0.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; All Banks. Unit: uncore_imc \000event=0xb8,umask=0x10\000\00001\000\000 */
{ 5557074 }, /* unc_m_wr_cas_rank0.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 0. Unit: uncore_imc \000event=0xb8\000\00001\000\000 */
{ 5559096 }, /* unc_m_wr_cas_rank0.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 1. Unit: uncore_imc \000event=0xb8,umask=0x1\000\00001\000\000 */
{ 5557353 }, /* unc_m_wr_cas_rank0.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 10. Unit: uncore_imc \000event=0xb8,umask=0xa\000\00001\000\000 */
{ 5557644 }, /* unc_m_wr_cas_rank0.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 11. Unit: uncore_imc \000event=0xb8,umask=0xb\000\00001\000\000 */
{ 5557935 }, /* unc_m_wr_cas_rank0.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 12. Unit: uncore_imc \000event=0xb8,umask=0xc\000\00001\000\000 */
{ 5558226 }, /* unc_m_wr_cas_rank0.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 13. Unit: uncore_imc \000event=0xb8,umask=0xd\000\00001\000\000 */
{ 5558517 }, /* unc_m_wr_cas_rank0.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 14. Unit: uncore_imc \000event=0xb8,umask=0xe\000\00001\000\000 */
{ 5558808 }, /* unc_m_wr_cas_rank0.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 15. Unit: uncore_imc \000event=0xb8,umask=0xf\000\00001\000\000 */
{ 5559509 }, /* unc_m_wr_cas_rank0.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 2. Unit: uncore_imc \000event=0xb8,umask=0x2\000\00001\000\000 */
{ 5559922 }, /* unc_m_wr_cas_rank0.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 3. Unit: uncore_imc \000event=0xb8,umask=0x3\000\00001\000\000 */
{ 5560463 }, /* unc_m_wr_cas_rank0.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 4. Unit: uncore_imc \000event=0xb8,umask=0x4\000\00001\000\000 */
{ 5560877 }, /* unc_m_wr_cas_rank0.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 5. Unit: uncore_imc \000event=0xb8,umask=0x5\000\00001\000\000 */
{ 5561291 }, /* unc_m_wr_cas_rank0.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 6. Unit: uncore_imc \000event=0xb8,umask=0x6\000\00001\000\000 */
{ 5561577 }, /* unc_m_wr_cas_rank0.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 7. Unit: uncore_imc \000event=0xb8,umask=0x7\000\00001\000\000 */
{ 5561991 }, /* unc_m_wr_cas_rank0.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 8. Unit: uncore_imc \000event=0xb8,umask=0x8\000\00001\000\000 */
{ 5562277 }, /* unc_m_wr_cas_rank0.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank 9. Unit: uncore_imc \000event=0xb8,umask=0x9\000\00001\000\000 */
{ 5562601 }, /* unc_m_wr_cas_rank0.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb8,umask=0x11\000\00001\000\000 */
{ 5562945 }, /* unc_m_wr_cas_rank0.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb8,umask=0x12\000\00001\000\000 */
{ 5563291 }, /* unc_m_wr_cas_rank0.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb8,umask=0x13\000\00001\000\000 */
{ 5563640 }, /* unc_m_wr_cas_rank0.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 0; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb8,umask=0x14\000\00001\000\000 */
{ 5563958 }, /* unc_m_wr_cas_rank1.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; All Banks. Unit: uncore_imc \000event=0xb9,umask=0x10\000\00001\000\000 */
{ 5564368 }, /* unc_m_wr_cas_rank1.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 0. Unit: uncore_imc \000event=0xb9\000\00001\000\000 */
{ 5566390 }, /* unc_m_wr_cas_rank1.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 1. Unit: uncore_imc \000event=0xb9,umask=0x1\000\00001\000\000 */
{ 5564647 }, /* unc_m_wr_cas_rank1.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 10. Unit: uncore_imc \000event=0xb9,umask=0xa\000\00001\000\000 */
{ 5564938 }, /* unc_m_wr_cas_rank1.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 11. Unit: uncore_imc \000event=0xb9,umask=0xb\000\00001\000\000 */
{ 5565229 }, /* unc_m_wr_cas_rank1.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 12. Unit: uncore_imc \000event=0xb9,umask=0xc\000\00001\000\000 */
{ 5565520 }, /* unc_m_wr_cas_rank1.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 13. Unit: uncore_imc \000event=0xb9,umask=0xd\000\00001\000\000 */
{ 5565811 }, /* unc_m_wr_cas_rank1.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 14. Unit: uncore_imc \000event=0xb9,umask=0xe\000\00001\000\000 */
{ 5566102 }, /* unc_m_wr_cas_rank1.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 15. Unit: uncore_imc \000event=0xb9,umask=0xf\000\00001\000\000 */
{ 5566803 }, /* unc_m_wr_cas_rank1.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 2. Unit: uncore_imc \000event=0xb9,umask=0x2\000\00001\000\000 */
{ 5567216 }, /* unc_m_wr_cas_rank1.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 3. Unit: uncore_imc \000event=0xb9,umask=0x3\000\00001\000\000 */
{ 5567757 }, /* unc_m_wr_cas_rank1.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 4. Unit: uncore_imc \000event=0xb9,umask=0x4\000\00001\000\000 */
{ 5568171 }, /* unc_m_wr_cas_rank1.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 5. Unit: uncore_imc \000event=0xb9,umask=0x5\000\00001\000\000 */
{ 5568585 }, /* unc_m_wr_cas_rank1.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 6. Unit: uncore_imc \000event=0xb9,umask=0x6\000\00001\000\000 */
{ 5568871 }, /* unc_m_wr_cas_rank1.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 7. Unit: uncore_imc \000event=0xb9,umask=0x7\000\00001\000\000 */
{ 5569285 }, /* unc_m_wr_cas_rank1.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 8. Unit: uncore_imc \000event=0xb9,umask=0x8\000\00001\000\000 */
{ 5569571 }, /* unc_m_wr_cas_rank1.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank 9. Unit: uncore_imc \000event=0xb9,umask=0x9\000\00001\000\000 */
{ 5569895 }, /* unc_m_wr_cas_rank1.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xb9,umask=0x11\000\00001\000\000 */
{ 5570239 }, /* unc_m_wr_cas_rank1.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xb9,umask=0x12\000\00001\000\000 */
{ 5570585 }, /* unc_m_wr_cas_rank1.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xb9,umask=0x13\000\00001\000\000 */
{ 5570934 }, /* unc_m_wr_cas_rank1.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 1; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xb9,umask=0x14\000\00001\000\000 */
{ 5571083 }, /* unc_m_wr_cas_rank2.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; All Banks. Unit: uncore_imc \000event=0xba,umask=0x10\000\00001\000\000 */
{ 5571344 }, /* unc_m_wr_cas_rank2.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 0. Unit: uncore_imc \000event=0xba\000\00001\000\000 */
{ 5572235 }, /* unc_m_wr_cas_rank2.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 1. Unit: uncore_imc \000event=0xba,umask=0x1\000\00001\000\000 */
{ 5571461 }, /* unc_m_wr_cas_rank2.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 10. Unit: uncore_imc \000event=0xba,umask=0xa\000\00001\000\000 */
{ 5571590 }, /* unc_m_wr_cas_rank2.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 11. Unit: uncore_imc \000event=0xba,umask=0xb\000\00001\000\000 */
{ 5571719 }, /* unc_m_wr_cas_rank2.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 12. Unit: uncore_imc \000event=0xba,umask=0xc\000\00001\000\000 */
{ 5571848 }, /* unc_m_wr_cas_rank2.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 13. Unit: uncore_imc \000event=0xba,umask=0xd\000\00001\000\000 */
{ 5571977 }, /* unc_m_wr_cas_rank2.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 14. Unit: uncore_imc \000event=0xba,umask=0xe\000\00001\000\000 */
{ 5572106 }, /* unc_m_wr_cas_rank2.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 15. Unit: uncore_imc \000event=0xba,umask=0xf\000\00001\000\000 */
{ 5572489 }, /* unc_m_wr_cas_rank2.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 2. Unit: uncore_imc \000event=0xba,umask=0x2\000\00001\000\000 */
{ 5572743 }, /* unc_m_wr_cas_rank2.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 3. Unit: uncore_imc \000event=0xba,umask=0x3\000\00001\000\000 */
{ 5573125 }, /* unc_m_wr_cas_rank2.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 4. Unit: uncore_imc \000event=0xba,umask=0x4\000\00001\000\000 */
{ 5573380 }, /* unc_m_wr_cas_rank2.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 5. Unit: uncore_imc \000event=0xba,umask=0x5\000\00001\000\000 */
{ 5573635 }, /* unc_m_wr_cas_rank2.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 6. Unit: uncore_imc \000event=0xba,umask=0x6\000\00001\000\000 */
{ 5573762 }, /* unc_m_wr_cas_rank2.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 7. Unit: uncore_imc \000event=0xba,umask=0x7\000\00001\000\000 */
{ 5574017 }, /* unc_m_wr_cas_rank2.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 8. Unit: uncore_imc \000event=0xba,umask=0x8\000\00001\000\000 */
{ 5574144 }, /* unc_m_wr_cas_rank2.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank 9. Unit: uncore_imc \000event=0xba,umask=0x9\000\00001\000\000 */
{ 5574271 }, /* unc_m_wr_cas_rank2.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xba,umask=0x11\000\00001\000\000 */
{ 5574418 }, /* unc_m_wr_cas_rank2.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xba,umask=0x12\000\00001\000\000 */
{ 5574565 }, /* unc_m_wr_cas_rank2.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xba,umask=0x13\000\00001\000\000 */
{ 5574713 }, /* unc_m_wr_cas_rank2.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 2; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xba,umask=0x14\000\00001\000\000 */
{ 5574862 }, /* unc_m_wr_cas_rank3.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; All Banks. Unit: uncore_imc \000event=0xbb,umask=0x10\000\00001\000\000 */
{ 5575123 }, /* unc_m_wr_cas_rank3.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 0. Unit: uncore_imc \000event=0xbb\000\00001\000\000 */
{ 5576014 }, /* unc_m_wr_cas_rank3.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 1. Unit: uncore_imc \000event=0xbb,umask=0x1\000\00001\000\000 */
{ 5575240 }, /* unc_m_wr_cas_rank3.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 10. Unit: uncore_imc \000event=0xbb,umask=0xa\000\00001\000\000 */
{ 5575369 }, /* unc_m_wr_cas_rank3.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 11. Unit: uncore_imc \000event=0xbb,umask=0xb\000\00001\000\000 */
{ 5575498 }, /* unc_m_wr_cas_rank3.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 12. Unit: uncore_imc \000event=0xbb,umask=0xc\000\00001\000\000 */
{ 5575627 }, /* unc_m_wr_cas_rank3.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 13. Unit: uncore_imc \000event=0xbb,umask=0xd\000\00001\000\000 */
{ 5575756 }, /* unc_m_wr_cas_rank3.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 14. Unit: uncore_imc \000event=0xbb,umask=0xe\000\00001\000\000 */
{ 5575885 }, /* unc_m_wr_cas_rank3.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 15. Unit: uncore_imc \000event=0xbb,umask=0xf\000\00001\000\000 */
{ 5576268 }, /* unc_m_wr_cas_rank3.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 2. Unit: uncore_imc \000event=0xbb,umask=0x2\000\00001\000\000 */
{ 5576522 }, /* unc_m_wr_cas_rank3.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 3. Unit: uncore_imc \000event=0xbb,umask=0x3\000\00001\000\000 */
{ 5576904 }, /* unc_m_wr_cas_rank3.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 4. Unit: uncore_imc \000event=0xbb,umask=0x4\000\00001\000\000 */
{ 5577159 }, /* unc_m_wr_cas_rank3.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 5. Unit: uncore_imc \000event=0xbb,umask=0x5\000\00001\000\000 */
{ 5577414 }, /* unc_m_wr_cas_rank3.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 6. Unit: uncore_imc \000event=0xbb,umask=0x6\000\00001\000\000 */
{ 5577541 }, /* unc_m_wr_cas_rank3.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 7. Unit: uncore_imc \000event=0xbb,umask=0x7\000\00001\000\000 */
{ 5577796 }, /* unc_m_wr_cas_rank3.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 8. Unit: uncore_imc \000event=0xbb,umask=0x8\000\00001\000\000 */
{ 5577923 }, /* unc_m_wr_cas_rank3.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank 9. Unit: uncore_imc \000event=0xbb,umask=0x9\000\00001\000\000 */
{ 5578050 }, /* unc_m_wr_cas_rank3.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbb,umask=0x11\000\00001\000\000 */
{ 5578197 }, /* unc_m_wr_cas_rank3.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbb,umask=0x12\000\00001\000\000 */
{ 5578344 }, /* unc_m_wr_cas_rank3.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbb,umask=0x13\000\00001\000\000 */
{ 5578492 }, /* unc_m_wr_cas_rank3.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 3; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbb,umask=0x14\000\00001\000\000 */
{ 5578810 }, /* unc_m_wr_cas_rank4.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; All Banks. Unit: uncore_imc \000event=0xbc,umask=0x10\000\00001\000\000 */
{ 5579220 }, /* unc_m_wr_cas_rank4.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 0. Unit: uncore_imc \000event=0xbc\000\00001\000\000 */
{ 5581242 }, /* unc_m_wr_cas_rank4.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 1. Unit: uncore_imc \000event=0xbc,umask=0x1\000\00001\000\000 */
{ 5579499 }, /* unc_m_wr_cas_rank4.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 10. Unit: uncore_imc \000event=0xbc,umask=0xa\000\00001\000\000 */
{ 5579790 }, /* unc_m_wr_cas_rank4.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 11. Unit: uncore_imc \000event=0xbc,umask=0xb\000\00001\000\000 */
{ 5580081 }, /* unc_m_wr_cas_rank4.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 12. Unit: uncore_imc \000event=0xbc,umask=0xc\000\00001\000\000 */
{ 5580372 }, /* unc_m_wr_cas_rank4.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 13. Unit: uncore_imc \000event=0xbc,umask=0xd\000\00001\000\000 */
{ 5580663 }, /* unc_m_wr_cas_rank4.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 14. Unit: uncore_imc \000event=0xbc,umask=0xe\000\00001\000\000 */
{ 5580954 }, /* unc_m_wr_cas_rank4.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 15. Unit: uncore_imc \000event=0xbc,umask=0xf\000\00001\000\000 */
{ 5581655 }, /* unc_m_wr_cas_rank4.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 2. Unit: uncore_imc \000event=0xbc,umask=0x2\000\00001\000\000 */
{ 5582068 }, /* unc_m_wr_cas_rank4.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 3. Unit: uncore_imc \000event=0xbc,umask=0x3\000\00001\000\000 */
{ 5582609 }, /* unc_m_wr_cas_rank4.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 4. Unit: uncore_imc \000event=0xbc,umask=0x4\000\00001\000\000 */
{ 5583023 }, /* unc_m_wr_cas_rank4.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 5. Unit: uncore_imc \000event=0xbc,umask=0x5\000\00001\000\000 */
{ 5583437 }, /* unc_m_wr_cas_rank4.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 6. Unit: uncore_imc \000event=0xbc,umask=0x6\000\00001\000\000 */
{ 5583723 }, /* unc_m_wr_cas_rank4.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 7. Unit: uncore_imc \000event=0xbc,umask=0x7\000\00001\000\000 */
{ 5584137 }, /* unc_m_wr_cas_rank4.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 8. Unit: uncore_imc \000event=0xbc,umask=0x8\000\00001\000\000 */
{ 5584423 }, /* unc_m_wr_cas_rank4.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank 9. Unit: uncore_imc \000event=0xbc,umask=0x9\000\00001\000\000 */
{ 5584747 }, /* unc_m_wr_cas_rank4.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbc,umask=0x11\000\00001\000\000 */
{ 5585091 }, /* unc_m_wr_cas_rank4.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbc,umask=0x12\000\00001\000\000 */
{ 5585437 }, /* unc_m_wr_cas_rank4.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbc,umask=0x13\000\00001\000\000 */
{ 5585786 }, /* unc_m_wr_cas_rank4.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 4; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbc,umask=0x14\000\00001\000\000 */
{ 5586104 }, /* unc_m_wr_cas_rank5.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; All Banks. Unit: uncore_imc \000event=0xbd,umask=0x10\000\00001\000\000 */
{ 5586514 }, /* unc_m_wr_cas_rank5.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 0. Unit: uncore_imc \000event=0xbd\000\00001\000\000 */
{ 5588536 }, /* unc_m_wr_cas_rank5.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 1. Unit: uncore_imc \000event=0xbd,umask=0x1\000\00001\000\000 */
{ 5586793 }, /* unc_m_wr_cas_rank5.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 10. Unit: uncore_imc \000event=0xbd,umask=0xa\000\00001\000\000 */
{ 5587084 }, /* unc_m_wr_cas_rank5.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 11. Unit: uncore_imc \000event=0xbd,umask=0xb\000\00001\000\000 */
{ 5587375 }, /* unc_m_wr_cas_rank5.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 12. Unit: uncore_imc \000event=0xbd,umask=0xc\000\00001\000\000 */
{ 5587666 }, /* unc_m_wr_cas_rank5.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 13. Unit: uncore_imc \000event=0xbd,umask=0xd\000\00001\000\000 */
{ 5587957 }, /* unc_m_wr_cas_rank5.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 14. Unit: uncore_imc \000event=0xbd,umask=0xe\000\00001\000\000 */
{ 5588248 }, /* unc_m_wr_cas_rank5.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 15. Unit: uncore_imc \000event=0xbd,umask=0xf\000\00001\000\000 */
{ 5588949 }, /* unc_m_wr_cas_rank5.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 2. Unit: uncore_imc \000event=0xbd,umask=0x2\000\00001\000\000 */
{ 5589362 }, /* unc_m_wr_cas_rank5.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 3. Unit: uncore_imc \000event=0xbd,umask=0x3\000\00001\000\000 */
{ 5589903 }, /* unc_m_wr_cas_rank5.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 4. Unit: uncore_imc \000event=0xbd,umask=0x4\000\00001\000\000 */
{ 5590317 }, /* unc_m_wr_cas_rank5.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 5. Unit: uncore_imc \000event=0xbd,umask=0x5\000\00001\000\000 */
{ 5590731 }, /* unc_m_wr_cas_rank5.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 6. Unit: uncore_imc \000event=0xbd,umask=0x6\000\00001\000\000 */
{ 5591017 }, /* unc_m_wr_cas_rank5.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 7. Unit: uncore_imc \000event=0xbd,umask=0x7\000\00001\000\000 */
{ 5591431 }, /* unc_m_wr_cas_rank5.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 8. Unit: uncore_imc \000event=0xbd,umask=0x8\000\00001\000\000 */
{ 5591717 }, /* unc_m_wr_cas_rank5.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank 9. Unit: uncore_imc \000event=0xbd,umask=0x9\000\00001\000\000 */
{ 5592041 }, /* unc_m_wr_cas_rank5.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbd,umask=0x11\000\00001\000\000 */
{ 5592385 }, /* unc_m_wr_cas_rank5.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbd,umask=0x12\000\00001\000\000 */
{ 5592731 }, /* unc_m_wr_cas_rank5.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbd,umask=0x13\000\00001\000\000 */
{ 5593080 }, /* unc_m_wr_cas_rank5.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 5; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbd,umask=0x14\000\00001\000\000 */
{ 5593398 }, /* unc_m_wr_cas_rank6.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; All Banks. Unit: uncore_imc \000event=0xbe,umask=0x10\000\00001\000\000 */
{ 5593808 }, /* unc_m_wr_cas_rank6.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 0. Unit: uncore_imc \000event=0xbe\000\00001\000\000 */
{ 5595830 }, /* unc_m_wr_cas_rank6.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 1. Unit: uncore_imc \000event=0xbe,umask=0x1\000\00001\000\000 */
{ 5594087 }, /* unc_m_wr_cas_rank6.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 10. Unit: uncore_imc \000event=0xbe,umask=0xa\000\00001\000\000 */
{ 5594378 }, /* unc_m_wr_cas_rank6.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 11. Unit: uncore_imc \000event=0xbe,umask=0xb\000\00001\000\000 */
{ 5594669 }, /* unc_m_wr_cas_rank6.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 12. Unit: uncore_imc \000event=0xbe,umask=0xc\000\00001\000\000 */
{ 5594960 }, /* unc_m_wr_cas_rank6.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 13. Unit: uncore_imc \000event=0xbe,umask=0xd\000\00001\000\000 */
{ 5595251 }, /* unc_m_wr_cas_rank6.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 14. Unit: uncore_imc \000event=0xbe,umask=0xe\000\00001\000\000 */
{ 5595542 }, /* unc_m_wr_cas_rank6.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 15. Unit: uncore_imc \000event=0xbe,umask=0xf\000\00001\000\000 */
{ 5596243 }, /* unc_m_wr_cas_rank6.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 2. Unit: uncore_imc \000event=0xbe,umask=0x2\000\00001\000\000 */
{ 5596656 }, /* unc_m_wr_cas_rank6.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 3. Unit: uncore_imc \000event=0xbe,umask=0x3\000\00001\000\000 */
{ 5597197 }, /* unc_m_wr_cas_rank6.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 4. Unit: uncore_imc \000event=0xbe,umask=0x4\000\00001\000\000 */
{ 5597611 }, /* unc_m_wr_cas_rank6.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 5. Unit: uncore_imc \000event=0xbe,umask=0x5\000\00001\000\000 */
{ 5598025 }, /* unc_m_wr_cas_rank6.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 6. Unit: uncore_imc \000event=0xbe,umask=0x6\000\00001\000\000 */
{ 5598311 }, /* unc_m_wr_cas_rank6.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 7. Unit: uncore_imc \000event=0xbe,umask=0x7\000\00001\000\000 */
{ 5598725 }, /* unc_m_wr_cas_rank6.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 8. Unit: uncore_imc \000event=0xbe,umask=0x8\000\00001\000\000 */
{ 5599011 }, /* unc_m_wr_cas_rank6.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank 9. Unit: uncore_imc \000event=0xbe,umask=0x9\000\00001\000\000 */
{ 5599335 }, /* unc_m_wr_cas_rank6.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbe,umask=0x11\000\00001\000\000 */
{ 5599679 }, /* unc_m_wr_cas_rank6.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbe,umask=0x12\000\00001\000\000 */
{ 5600025 }, /* unc_m_wr_cas_rank6.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbe,umask=0x13\000\00001\000\000 */
{ 5600374 }, /* unc_m_wr_cas_rank6.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 6; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbe,umask=0x14\000\00001\000\000 */
{ 5600692 }, /* unc_m_wr_cas_rank7.allbanks\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; All Banks. Unit: uncore_imc \000event=0xbf,umask=0x10\000\00001\000\000 */
{ 5601102 }, /* unc_m_wr_cas_rank7.bank0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 0. Unit: uncore_imc \000event=0xbf\000\00001\000\000 */
{ 5603124 }, /* unc_m_wr_cas_rank7.bank1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 1. Unit: uncore_imc \000event=0xbf,umask=0x1\000\00001\000\000 */
{ 5601381 }, /* unc_m_wr_cas_rank7.bank10\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 10. Unit: uncore_imc \000event=0xbf,umask=0xa\000\00001\000\000 */
{ 5601672 }, /* unc_m_wr_cas_rank7.bank11\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 11. Unit: uncore_imc \000event=0xbf,umask=0xb\000\00001\000\000 */
{ 5601963 }, /* unc_m_wr_cas_rank7.bank12\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 12. Unit: uncore_imc \000event=0xbf,umask=0xc\000\00001\000\000 */
{ 5602254 }, /* unc_m_wr_cas_rank7.bank13\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 13. Unit: uncore_imc \000event=0xbf,umask=0xd\000\00001\000\000 */
{ 5602545 }, /* unc_m_wr_cas_rank7.bank14\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 14. Unit: uncore_imc \000event=0xbf,umask=0xe\000\00001\000\000 */
{ 5602836 }, /* unc_m_wr_cas_rank7.bank15\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 15. Unit: uncore_imc \000event=0xbf,umask=0xf\000\00001\000\000 */
{ 5603537 }, /* unc_m_wr_cas_rank7.bank2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 2. Unit: uncore_imc \000event=0xbf,umask=0x2\000\00001\000\000 */
{ 5603950 }, /* unc_m_wr_cas_rank7.bank3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 3. Unit: uncore_imc \000event=0xbf,umask=0x3\000\00001\000\000 */
{ 5604491 }, /* unc_m_wr_cas_rank7.bank4\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 4. Unit: uncore_imc \000event=0xbf,umask=0x4\000\00001\000\000 */
{ 5604905 }, /* unc_m_wr_cas_rank7.bank5\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 5. Unit: uncore_imc \000event=0xbf,umask=0x5\000\00001\000\000 */
{ 5605319 }, /* unc_m_wr_cas_rank7.bank6\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 6. Unit: uncore_imc \000event=0xbf,umask=0x6\000\00001\000\000 */
{ 5605605 }, /* unc_m_wr_cas_rank7.bank7\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 7. Unit: uncore_imc \000event=0xbf,umask=0x7\000\00001\000\000 */
{ 5606019 }, /* unc_m_wr_cas_rank7.bank8\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 8. Unit: uncore_imc \000event=0xbf,umask=0x8\000\00001\000\000 */
{ 5606305 }, /* unc_m_wr_cas_rank7.bank9\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank 9. Unit: uncore_imc \000event=0xbf,umask=0x9\000\00001\000\000 */
{ 5606629 }, /* unc_m_wr_cas_rank7.bankg0\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 0 (Banks 0-3). Unit: uncore_imc \000event=0xbf,umask=0x11\000\00001\000\000 */
{ 5606973 }, /* unc_m_wr_cas_rank7.bankg1\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 1 (Banks 4-7). Unit: uncore_imc \000event=0xbf,umask=0x12\000\00001\000\000 */
{ 5607319 }, /* unc_m_wr_cas_rank7.bankg2\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 2 (Banks 8-11). Unit: uncore_imc \000event=0xbf,umask=0x13\000\00001\000\000 */
{ 5607668 }, /* unc_m_wr_cas_rank7.bankg3\000uncore_imc\000uncore memory\000WR_CAS Access to Rank 7; Bank Group 3 (Banks 12-15). Unit: uncore_imc \000event=0xbf,umask=0x14\000\00001\000\000 */
{ 5607992 }, /* unc_m_wrong_mm\000uncore_imc\000uncore memory\000Not getting the requested Major Mode. Unit: uncore_imc \000event=0xc1\000\00001\000\000 */
{ 5641706 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000pclk Cycles. Unit: uncore_pcu \000event=0\000\00001\000The PCU runs off a fixed 1 GHz clock.  This event counts the number of pclk cycles measured while the counter was enabled.  The pclk, like the Memory Controller's dclk, counts at a constant rate making it a good measure of actual wall time\000 */
{ 5650924 }, /* unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000 */
{ 5656346 }, /* unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000 */
{ 5663824 }, /* unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Cycles spent in phase-shedding power state 0\000 */
{ 5664142 }, /* unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Cycles spent in phase-shedding power state 1\000 */
{ 5664460 }, /* unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Cycles spent in phase-shedding power state 2\000 */
{ 5664778 }, /* unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Cycles spent in phase-shedding power state 3\000 */
{ 5667969 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Counts the number of cycles when thermal conditions are the upper limit on frequency.  This is related to the THERMAL_THROTTLE CYCLES_ABOVE_TEMP event, which always counts cycles when we are above the thermal temperature.  This event (STRONGEST_UPPER_LIMIT) is sampled at the output of the algorithm that determines the actual frequency, while THERMAL_THROTTLE looks at the input\000 */
{ 5668939 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670355 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673025 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5673833 }, /* unc_p_mcp_prochot_cycles\000uncore_pcu\000uncore power\000UNC_P_MCP_PROCHOT_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000 */
{ 5673941 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5675706 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5676727 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677425 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678114 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679241 }, /* unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x7\000\00001\000\000 */
{ 5679815 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State; C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681056 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State; C3. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5682304 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State; C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684377 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685040 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5685850 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Number of cycles spent performing core C state transitions across all cores\000 */
{ 5688334 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000\000 */
{ 788320 }, /* dtlb_load_misses.miss_causes_a_walk\000\000virtual memory\000Load misses in all DTLB levels that cause page walks\000event=0x8,period=100003,umask=0x1\000\00000\000Counts demand data loads that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 791308 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=2000003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793371 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 798170 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data load to a 1G page\000event=0x8,period=2000003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 801032 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data load to a 2M/4M page\000event=0x8,period=2000003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 804341 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data load to a 4K page\000event=0x8,period=2000003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 807135 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake\000event=0x8,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a load. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 810679 }, /* dtlb_store_misses.miss_causes_a_walk\000\000virtual memory\000Store misses in all DTLB levels that cause page walks\000event=0x49,period=100003,umask=0x1\000\00000\000Counts demand data stores that caused a page walk of any page size (4K/2M/4M/1G). This implies it missed in all TLB levels, but the walk need not have completed\000 */
{ 813355 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 814891 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 819786 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Page walk completed due to a demand data store to a 1G page\000event=0x49,period=100003,umask=0x8\000\00000\000Counts completed page walks  (1G sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 822786 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walk completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 825573 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walk completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data stores. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 829022 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake\000event=0x49,period=2000003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH that is busy with a page walk for a store. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 833842 }, /* ept.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a EPT (Extended Page Table) walk for any request type\000event=0x4f,period=2000003,umask=0x10\000\00000\000Counts cycles for each PMH (Page Miss Handler) that is busy with an EPT (Extended Page Table) walk for any request type\000 */
{ 1078252 }, /* itlb.itlb_flush\000\000virtual memory\000Flushing of the Instruction TLB (ITLB) pages, includes 4k/2M/4M pages\000event=0xae,period=100007,umask=0x1\000\00000\000Counts the number of flushes of the big or small ITLB pages. Counting include both TLB Flush (covering all sets) and TLB Set Clear (set-specific)\000 */
{ 1080900 }, /* itlb_misses.miss_causes_a_walk\000\000virtual memory\000Misses at all ITLB levels that cause page walks\000event=0x85,period=100003,umask=0x1\000\00000\000Counts page walks of any page size (4K/2M/4M/1G) caused by a code fetch. This implies it missed in the ITLB and further levels of TLB, but the walk need not have completed\000 */
{ 1082889 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000\000 */
{ 1084967 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request. EPT page walk duration are excluded in Skylake microarchitecture\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1088976 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (1G)\000event=0x85,period=100003,umask=0x8\000\00000\000Counts completed page walks (1G page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1096669 }, /* itlb_misses.walk_pending\000\000virtual memory\000Counts 1 per cycle for each PMH that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake\000event=0x85,period=100003,umask=0x10\000\00000\000Counts 1 per cycle for each PMH (Page Miss Handler) that is busy with a page walk for an instruction fetch request. EPT page walk duration are excluded in Skylake michroarchitecture\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__skylakex[] = {
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3887 }, /* \000C3_Core_Residency\000Power\000cstate_core@c3\\-residency@ / TSC\000\000C3 residency percent per core\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 6571 }, /* \000UNCORE_FREQ\000SoC\000tma_info_system_socket_clks / #num_dies / duration_time / 1e9\000\000Uncore frequency per die [GHZ]\000\000\000\000\000\00000 */
{ 9605 }, /* \000cpi\000\000CPU_CLK_UNHALTED.THREAD / INST_RETIRED.ANY\000\000Cycles per instruction retired; indicating how much time each executed instruction took; in units of cycles\000\0001per_instr\000\000\000\00000 */
{ 9780 }, /* \000cpu_operating_frequency\000\000CPU_CLK_UNHALTED.THREAD / CPU_CLK_UNHALTED.REF_TSC * #SYSTEM_TSC_FREQ / 1e9\000\000CPU operating frequency (in GHz)\000\0001GHz\000\000\000\00000 */
{ 9927 }, /* \000cpu_utilization\000\000tma_info_system_cpu_utilization\000\000Percentage of time spent in the active CPU power state C0\000\000100%\000\000\000\00000 */
{ 12424 }, /* \000dtlb_2mb_large_page_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the Data Translation Lookaside Buffer (DTLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14264 }, /* \000dtlb_load_mpi\000\000DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data loads to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 14680 }, /* \000dtlb_store_mpi\000\000DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by demand data stores to the total number of completed instructions. This implies it missed in the DTLB and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 16888 }, /* \000io_bandwidth_read\000\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO reads that are initiated by end device controllers that are requesting memory from the CPU\000\0001MB/s\000\000\000\00000 */
{ 18187 }, /* \000io_bandwidth_write\000\000(UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART0 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART1 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART2 + UNC_IIO_PAYLOAD_BYTES_IN.MEM_WRITE.PART3) * 4 / 1e6 / duration_time\000\000Bandwidth of IO writes that are initiated by end device controllers that are writing memory to the CPU\000\0001MB/s\000\000\000\00000 */
{ 19992 }, /* \000itlb_large_page_mpi\000\000ITLB_MISSES.WALK_COMPLETED_2M_4M / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for 2 megabyte and 4 megabyte page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the Instruction Translation Lookaside Buffer (ITLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 20492 }, /* \000itlb_mpi\000\000ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions\000Ratio of number of completed page walks (for all page sizes) caused by a code fetch to the total number of completed instructions. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB\0001per_instr\000\000\000\00000 */
{ 22484 }, /* \000l1_i_code_read_misses_with_prefetches_per_instr\000\000L2_RQSTS.ALL_CODE_RD / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing in L1 instruction cache (includes prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23125 }, /* \000l1d_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L1_HIT / INST_RETIRED.ANY\000\000Ratio of number of demand load requests hitting in L1 data cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 23550 }, /* \000l1d_mpi\000\000L1D.REPLACEMENT / INST_RETIRED.ANY\000\000Ratio of number of requests missing L1 data cache (includes data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25334 }, /* \000l2_demand_code_mpi\000\000L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000Ratio of number of code read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25514 }, /* \000l2_demand_data_read_hits_per_instr\000\000MEM_LOAD_RETIRED.L2_HIT / INST_RETIRED.ANY\000\000Ratio of number of completed demand load requests hitting in L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 25947 }, /* \000l2_demand_data_read_mpi\000\000MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000Ratio of number of completed data read request missing L2 cache to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 26556 }, /* \000l2_mpi\000\000L2_LINES_IN.ALL / INST_RETIRED.ANY\000\000Ratio of number of requests missing L2 cache (includes code+data+rfo w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28309 }, /* \000llc_code_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12CC0233@ / INST_RETIRED.ANY\000\000Ratio of number of code read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 28970 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40433@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40433@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) in nano seconds\000\0001ns\000\000\000\00000 */
{ 30170 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_local_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40432@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to local memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 31464 }, /* \000llc_data_read_demand_plus_prefetch_miss_latency_for_remote_requests\000\0001e9 * (cha@UNC_CHA_TOR_OCCUPANCY.IA_MISS\\,config1\\=0x40431@ / cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@) / (UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages)) * duration_time\000\000Average latency of a last level cache (LLC) demand and prefetch data read miss (read memory access) addressed to remote memory in nano seconds\000\0001ns\000\000\000\00000 */
{ 32995 }, /* \000llc_data_read_mpi_demand_plus_prefetch\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x12D40433@ / INST_RETIRED.ANY\000\000Ratio of number of data read requests missing last level core cache (includes demand w/ prefetches) to the total number of completed instructions\000\0001per_instr\000\000\000\00000 */
{ 35184 }, /* \000llc_miss_local_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35388 }, /* \000llc_miss_local_memory_bandwidth_write\000\000UNC_CHA_REQUESTS.WRITES_LOCAL * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of write requests that miss the last level cache (LLC) and go to local memory\000\0001MB/s\000\000\000\00000 */
{ 35595 }, /* \000llc_miss_remote_memory_bandwidth_read\000\000UNC_CHA_REQUESTS.READS_REMOTE * 64 / 1e6 / duration_time\000\000Bandwidth (MB/sec) of read requests that miss the last level cache (LLC) and go to remote memory\000\0001MB/s\000\000\000\00000 */
{ 36012 }, /* \000loads_per_instr\000\000MEM_INST_RETIRED.ALL_LOADS / INST_RETIRED.ANY\000\000The ratio of number of completed memory load instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 39357 }, /* \000memory_bandwidth_read\000\000UNC_M_CAS_COUNT.RD * 64 / 1e6 / duration_time\000\000DDR memory read bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39475 }, /* \000memory_bandwidth_total\000\000(UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) * 64 / 1e6 / duration_time\000\000DDR memory bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 39612 }, /* \000memory_bandwidth_write\000\000UNC_M_CAS_COUNT.WR * 64 / 1e6 / duration_time\000\000DDR memory write bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 41255 }, /* \000numa_reads_addressed_to_local_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory read that miss the last level cache (LLC) addressed to local DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 42475 }, /* \000numa_reads_addressed_to_remote_dram\000\000cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@ / (cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40432@ + cha@UNC_CHA_TOR_INSERTS.IA_MISS\\,config1\\=0x40431@)\000\000Memory reads that miss the last level cache (LLC) addressed to remote DRAM as a percentage of total memory read accesses, does not include LLC prefetches\000\000100%\000\000\000\00000 */
{ 43424 }, /* \000percent_uops_delivered_from_decoded_icache\000\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from decoded instruction cache (decoded stream buffer or DSB) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 43946 }, /* \000percent_uops_delivered_from_legacy_decode_pipeline\000\000IDQ.MITE_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from legacy decode pipeline (Micro-instruction Translation Engine or MITE) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 44896 }, /* \000percent_uops_delivered_from_microcode_sequencer\000\000IDQ.MS_UOPS / UOPS_ISSUED.ANY\000\000Uops delivered from microcode sequencer (MS) as a percent of total uops delivered to Instruction Decode Queue\000\000100%\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49006 }, /* \000stores_per_instr\000\000MEM_INST_RETIRED.ALL_STORES / INST_RETIRED.ANY\000\000The ratio of number of completed memory store instructions to the total number completed instructions\000\0001per_instr\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 51159 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_0 + UOPS_DISPATCHED_PORT.PORT_1 + UOPS_DISPATCHED_PORT.PORT_5 + UOPS_DISPATCHED_PORT.PORT_6) / tma_info_thread_slots\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 52640 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * (FP_ASSIST.ANY + OTHER_ASSISTS.ANY) / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: OTHER_ASSISTS.ANY\000100%\000\000\000\00000 */
{ 62896 }, /* \000tma_backend_bound\000TmaL1;TopdownL1;tma_L1_group\0001 - tma_frontend_bound - (UOPS_ISSUED.ANY + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound\000100%\000\000TopdownL1\000\00000 */
{ 66401 }, /* \000tma_bad_speculation\000TmaL1;TopdownL1;tma_L1_group\000(UOPS_ISSUED.ANY - UOPS_RETIRED.RETIRE_SLOTS + 4 * (INT_MISC.RECOVERY_CYCLES_ANY / 2 if #SMT_on else INT_MISC.RECOVERY_CYCLES)) / tma_info_thread_slots\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1\000\00000 */
{ 70171 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00001 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 84957 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(44 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 44 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS_PS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98830 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000tma_backend_bound - tma_memory_bound\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00001 */
{ 109985 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00044 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT + MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM * (1 - OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE / (OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HIT_PS. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 113664 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122993 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124017 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_DSB_CYCLES_ANY_UOPS - IDQ.ALL_DSB_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 137218 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(9 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00002 */
{ 142945 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(9 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 144891 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\000(110 * tma_info_system_average_frequency * (OFFCORE_RESPONSE.DEMAND_RFO.L3_MISS.REMOTE_HITM + OFFCORE_RESPONSE.PF_L2_RFO.L3_MISS.REMOTE_HITM) + 47.5 * tma_info_system_average_frequency * (OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.HITM_OTHER_CORE + OFFCORE_RESPONSE.PF_L2_RFO.L3_HIT.HITM_OTHER_CORE)) / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_HITM_PS;OFFCORE_RESPONSE.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 154534 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@ / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00002 */
{ 160611 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000tma_frontend_bound - tma_fetch_latency\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 164336 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\0004 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 173429 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 178522 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00001 */
{ 180800 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 183079 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 185358 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / UOPS_RETIRED.RETIRE_SLOTS\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 187717 }, /* \000tma_frontend_bound\000PGO;TmaL1;TopdownL1;tma_L1_group\000IDQ_UOPS_NOT_DELIVERED.CORE / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1\000\00000 */
{ 190426 }, /* \000tma_fused_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * UOPS_RETIRED.MACRO_FUSED / UOPS_RETIRED.RETIRE_SLOTS\000tma_fused_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions\000This metric represents fraction of slots where the CPU was retiring fused instructions -- where one uop can represent multiple contiguous instructions. The instruction pairs of CMP+JCC or DEC+JCC are commonly used examples\000100%\000\000\000\00000 */
{ 191743 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000(UOPS_RETIRED.RETIRE_SLOTS + UOPS_RETIRED.MACRO_FUSED - INST_RETIRED.ANY) / tma_info_thread_slots\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 193552 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000(ICACHE_16B.IFDATA_STALL + 2 * cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@) / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 196454 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00000 */
{ 199161 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000tma_info_inst_mix_instructions / (UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * cpu@BR_MISP_EXEC.ALL_BRANCHES\\,umask\\=0xE4@)\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199999 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000tma_info_core_ipmispredict\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 201191 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 203428 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.CONDITIONAL + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 208349 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00001 */
{ 212748 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 214466 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216209 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.NOT_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216379 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000(BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 216744 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - (BR_INST_RETIRED.CONDITIONAL - BR_INST_RETIRED.NOT_TAKEN) - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00001 */
{ 217628 }, /* \000tma_info_core_core_clks\000SMT\000(CPU_CLK_UNHALTED.THREAD / 2 * (1 + CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_XCLK) if #core_wide < 1 else (CPU_CLK_UNHALTED.THREAD_ANY / 2 if #SMT_on else tma_info_thread_clks))\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 218334 }, /* \000tma_info_core_flopc\000Flops;Ret\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 221959 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00000 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 224428 }, /* \000tma_info_core_ipmispredict\000Bad;BadSpec;BrMispredicts;TopdownL1;tma_L1_group\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000\000Number of Instructions per non-speculative Branch Misprediction (JEClear)\000\000\000\000TopdownL1\000\00000 */
{ 224783 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / (IDQ.DSB_UOPS + IDQ.MITE_UOPS + IDQ.MS_UOPS)\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 4 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 226971 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / DSB2MITE_SWITCHES.COUNT\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227629 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@ + 2\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232781 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00001 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238534 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00001 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 243336 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 9\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245107 }, /* \000tma_info_memory_core_l2_evictions_nonsilent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.NON_SILENT / tma_info_inst_mix_instructions\000\000Rate of non silent evictions from the L2 cache per Kilo instruction\000\000\000\000\000\00000 */
{ 245315 }, /* \000tma_info_memory_core_l2_evictions_silent_pki\000L2Evicts;Mem;Server\0001e3 * L2_LINES_OUT.SILENT / tma_info_inst_mix_instructions\000\000Rate of silent evictions from the L2 cache per Kilo instruction where the evicted lines are dropped (no writeback to L3 or memory)\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 250951 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_DATA_RD\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 253898 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING + EPT.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00002 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256213 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000UOPS_RETIRED.RETIRE_SLOTS / cpu@UOPS_RETIRED.RETIRE_SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00000 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 258309 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (UNC_M_CAS_COUNT.RD + UNC_M_CAS_COUNT.WR) / 1e9 / duration_time\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 260111 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(FP_ARITH_INST_RETIRED.SCALAR_SINGLE + FP_ARITH_INST_RETIRED.SCALAR_DOUBLE + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * (FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE) + 8 * (FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE + FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE) + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00001 */
{ 263422 }, /* \000tma_info_system_io_read_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Reads [GB / sec]\000\000\000\000\000\00000 */
{ 263736 }, /* \000tma_info_system_io_write_bw\000IoBW;Mem;Server;SoC\000(UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3) * 4 / 1e9 / duration_time\000\000Average IO (network or disk) Bandwidth Use for Writes [GB / sec]\000\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 265831 }, /* \000tma_info_system_mem_dram_read_latency\000Mem;MemoryLat;Server;SoC\0001e9 * (UNC_M_RPQ_OCCUPANCY / UNC_M_RPQ_INSERTS) / imc_0@event\\=0x0@\000\000Average latency of data read request to external DRAM memory [in nanoseconds]\000Average latency of data read request to external DRAM memory [in nanoseconds]. Accounts for demand loads and L1/L2 data-read prefetches\000\000\000\000\00000 */
{ 267104 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD@thresh\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 270073 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\0001e9 * (UNC_CHA_TOR_OCCUPANCY.IA_MISS_DRD / UNC_CHA_TOR_INSERTS.IA_MISS_DRD) / (tma_info_system_socket_clks / duration_time)\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271899 }, /* \000tma_info_system_power_license0_utilization\000Power\000(CORE_POWER.LVL0_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks)\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 272769 }, /* \000tma_info_system_power_license1_utilization\000Power\000(CORE_POWER.LVL1_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 273737 }, /* \000tma_info_system_power_license2_utilization\000Power\000(CORE_POWER.LVL2_TURBO_LICENSE / 2 / tma_info_core_core_clks if #SMT_on else CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks)\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274689 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / (CPU_CLK_UNHALTED.REF_XCLK_ANY / 2) if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275354 }, /* \000tma_info_system_socket_clks\000SoC\000cha_0@event\\=0x0@\000\000Socket actual clocks when any core is active on that socket\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277181 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\0004 * tma_info_core_core_clks\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277706 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000UOPS_RETIRED.RETIRE_SLOTS / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278007 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000UOPS_RETIRED.RETIRE_SLOTS / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 6\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 292417 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + cpu@L1D_PEND_MISS.FB_FULL\\,cmask\\=1@) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 298837 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00017 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 315030 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_retiring - tma_heavy_operations\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 315911 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED_PORT.PORT_2 + UOPS_DISPATCHED_PORT.PORT_3 + UOPS_DISPATCHED_PORT.PORT_7 - UOPS_DISPATCHED_PORT.PORT_4) / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 319201 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00002 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 322701 }, /* \000tma_local_dram\000Server;TopdownL5;tma_L5_group;tma_mem_latency_group\00059.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_local_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from local memory. Caching will improve the latency and increase performance. Sample with: MEM_LOAD_L3_MISS_RETIRED.LOCAL_DRAM_PS\000100%\000\000\000\00000 */
{ 324079 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(12 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (11 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00000 */
{ 330723 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000tma_bad_speculation - tma_branch_mispredicts\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00001 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 343499 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00001 */
{ 348484 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00000 */
{ 350591 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000UOPS_RETIRED.RETIRE_SLOTS / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 356236 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.ALL_MITE_CYCLES_ANY_UOPS - IDQ.ALL_MITE_CYCLES_4_UOPS) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 4 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 360777 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0002 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 365594 }, /* \000tma_non_fused_branches\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * (BR_INST_RETIRED.ALL_BRANCHES - UOPS_RETIRED.MACRO_FUSED) / UOPS_RETIRED.RETIRE_SLOTS\000tma_non_fused_branches > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused\000This metric represents fraction of slots where the CPU was retiring branch instructions that were not fused. Non-conditional branches like direct JMP or CALL would count here. Can be used to examine fusible conditional jumps that were not fused\000100%\000\000\000\00000 */
{ 367158 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / UOPS_RETIRED.RETIRE_SLOTS\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369645 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_fused_instructions + tma_non_fused_branches + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00000 */
{ 379171 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED_PORT.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 382050 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 383110 }, /* \000tma_port_2\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_2 / tma_info_core_core_clks\000tma_port_2 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 2 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_2\000100%\000\000\000\00000 */
{ 383844 }, /* \000tma_port_3\000TopdownL6;tma_L6_group;tma_load_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_3 / tma_info_core_core_clks\000tma_port_3 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 3 ([SNB+]Loads and Store-address; [ICL+] Loads). Sample with: UOPS_DISPATCHED_PORT.PORT_3\000100%\000\000\000\00000 */
{ 384945 }, /* \000tma_port_4\000TopdownL6;tma_L6_group;tma_issueSpSt;tma_store_op_utilization_group\000tma_store_op_utilization\000tma_port_4 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 4 (Store-data). Sample with: UOPS_DISPATCHED_PORT.PORT_4. Related metrics: tma_split_stores\000100%\000\000\000\00000 */
{ 386530 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 389567 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED_PORT.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED_PORT.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 390755 }, /* \000tma_port_7\000TopdownL6;tma_L6_group;tma_store_op_utilization_group\000UOPS_DISPATCHED_PORT.PORT_7 / tma_info_core_core_clks\000tma_port_7 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 7 ([HSW+]simple Store-address). Sample with: UOPS_DISPATCHED_PORT.PORT_7\000100%\000\000\000\00000 */
{ 391440 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((EXE_ACTIVITY.EXE_BOUND_0_PORTS + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 400041 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_NONE / 2 if #SMT_on else CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_core_core_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 403843 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_1 - UOPS_EXECUTED.CORE_CYCLES_GE_2) / 2 if #SMT_on else EXE_ACTIVITY.1_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 409809 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000((UOPS_EXECUTED.CORE_CYCLES_GE_2 - UOPS_EXECUTED.CORE_CYCLES_GE_3) / 2 if #SMT_on else EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_core_core_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 417118 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000(UOPS_EXECUTED.CORE_CYCLES_GE_3 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_3) / tma_info_core_core_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000\000100%\000\000\000\00000 */
{ 425139 }, /* \000tma_remote_cache\000Offcore;Server;Snoop;TopdownL5;tma_L5_group;tma_issueSyncxn;tma_mem_latency_group\000(89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM + 89.5 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_cache > 0.05 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote cache in other sockets including synchronizations issues. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_HITM_PS;MEM_LOAD_L3_MISS_RETIRED.REMOTE_FWD_PS. Related metrics: tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_machine_clears\000100%\000\000\000\00002 */
{ 428000 }, /* \000tma_remote_dram\000Server;Snoop;TopdownL5;tma_L5_group;tma_mem_latency_group\000127 * tma_info_system_average_frequency * MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_remote_dram > 0.1 & (tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory\000This metric estimates fraction of cycles while the memory subsystem was handling loads from remote memory. This is caused often due to non-optimal NUMA allocations. #link to NUMA article. Sample with: MEM_LOAD_L3_MISS_RETIRED.REMOTE_DRAM_PS\000100%\000\000\000\00000 */
{ 433528 }, /* \000tma_retiring\000TmaL1;TopdownL1;tma_L1_group\000UOPS_RETIRED.RETIRE_SLOTS / tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.RETIRE_SLOTS\000100%\000\000TopdownL1\000\00000 */
{ 435994 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000PARTIAL_RAT_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: PARTIAL_RAT_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 441609 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00002 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 444174 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000(OFFCORE_REQUESTS_BUFFER.SQ_FULL / 2 if #SMT_on else OFFCORE_REQUESTS_BUFFER.SQ_FULL) / tma_info_core_core_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 452365 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 11 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00002 */
{ 456845 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED_PORT.PORT_4 / tma_info_core_core_clks\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 459384 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\0009 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
{ 465340 }, /* \000uncore_frequency\000\000UNC_CHA_CLOCKTICKS / (#num_cores / #num_packages * #num_packages) / 1e9 / duration_time\000\000Uncore operating frequency in GHz\000\0001GHz\000\000\000\00000 */
{ 465803 }, /* \000upi_data_transmit_bw\000\000UNC_UPI_TxL_FLITS.ALL_DATA * 7.111111111111111 / 1e6 / duration_time\000\000Intel(R) Ultra Path Interconnect (UPI) data transmit bandwidth (MB/sec)\000\0001MB/s\000\000\000\00000 */
{ 6171185 }, /* uncore_iio\000LLC_MISSES.PCIE_READ\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3\000\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000Counts every read request for 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000 */
{ 6172569 }, /* uncore_iio\000LLC_MISSES.PCIE_WRITE\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3\000\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000Counts every write request of 4 bytes of data made by IIO Part0 to a unit on the main die (generally memory). In the general case, Part0 refers to a standard PCIe card of any size (x16,x8,x4) that is plugged directly into one of the PCIe slots. Part0 could also refer to any device plugged into the first slot of a PCIe riser card or to a device attached to the IIO unit which starts its use of the bus using lane 0 of the 16 lanes supported by the bus\0004Bytes\000\000\000\00000 */
{ 6175437 }, /* uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000Counts cycles when all the ranks in the channel are in PPD (PreCharge Power Down) mode. If IBT (Input Buffer Terminators)=off is enabled, then this event counts the cycles in PPD mode. If IBT=off is not enabled, then this event counts the number of cycles when being in PPD mode could have been taken advantage of\000\000\000\000\00000 */
{ 6176517 }, /* uncore_imc\000power_self_refresh\000\000UNC_M_POWER_SELF_REFRESH / UNC_M_CLOCKTICKS * 100\000\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000Counts the number of cycles when the iMC (memory controller) is in self-refresh and has a clock. This happens in some ACPI CPU package C-states for the sleep levels. For example, the PCU (Power Control Unit) may ask the iMC to enter self-refresh even though some of the cores are still processing. One use of this is for Intel? Dynamic Power Technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__snowridgex[] = {
{ 576549 }, /* core_reject_l2q.any\000\000cache\000Counts the number of core requests (demand and L1 prefetchers) rejected by the L2 queue (L2Q) due to a full condition\000event=0x31,period=200003\000\00000\000Counts the number of (demand and L1 prefetchers) core requests rejected by the L2 queue (L2Q) due to a full or nearly full condition, which likely indicates back pressure from L2Q.  It also counts requests that would have gone directly to the External Queue (XQ), but are rejected due to a full or nearly full condition, indicating back pressure from the IDI link.  The L2Q may also reject transactions  from a core to ensure fairness between cores, or to delay a cores dirty eviction when the address conflicts incoming external snoops.  (Note that L2 prefetcher requests that are dropped are not counted by this event).  Counts on a per core basis\000 */
{ 778889 }, /* dl1.dirty_eviction\000\000cache\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches\000event=0x51,period=200003,umask=0x1\000\00000\000Counts the number of L1D cacheline (dirty) evictions caused by load misses, stores, and prefetches.  Does not count evictions or dirty writebacks caused by snoops.  Does not count a replacement unless a (dirty) line was written back\000 */
{ 1149126 }, /* l2_reject_xq.any\000\000cache\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition\000event=0x30,period=200003\000\00000\000Counts the number of demand and prefetch transactions that the External Queue (XQ) rejects due to a full or near full condition which likely indicates back pressure from the IDI link.  The XQ may reject transactions from the L2Q (non-cacheable requests), BBL (L2 misses) and WOB (L2 write-back victims)\000 */
{ 1149916 }, /* l2_request.all\000\000cache\000Counts the total number of L2 Cache accesses. Counts on a per core basis\000event=0x24,period=200003\000\00000\000Counts the total number of L2 Cache Accesses, includes hits, misses, rejects  front door requests for CRd/DRd/RFO/ItoM/L2 Prefetches only.  Counts on a per core basis\000 */
{ 1150538 }, /* l2_request.hit\000\000cache\000Counts the number of L2 Cache accesses that resulted in a hit. Counts on a per core basis\000event=0x24,period=200003,umask=0x2\000\00000\000Counts the number of L2 Cache accesses that resulted in a hit from a front door request only (does not include rejects or recycles), Counts on a per core basis\000 */
{ 1151083 }, /* l2_request.miss\000\000cache\000Counts the number of L2 Cache accesses that resulted in a miss. Counts on a per core basis\000event=0x24,period=200003,umask=0x1\000\00000\000Counts the number of L2 Cache accesses that resulted in a miss from a front door request only (does not include rejects or recycles). Counts on a per core basis\000 */
{ 1152400 }, /* l2_request.rejects\000\000cache\000Counts the number of L2 Cache accesses that miss the L2 and get rejected. Counts on a per core basis\000event=0x24,period=200003,umask=0x4\000\00000\000Counts the number of L2 Cache accesses that miss the L2 and get BBL reject  short and long rejects (includes those counted in L2_reject_XQ.any). Counts on a per core basis\000 */
{ 1248632 }, /* longest_lat_cache.miss\000\000cache\000Counts the number of cacheable memory requests that miss in the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x41\000\00000\000Counts the number of cacheable memory requests that miss in the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1252437 }, /* longest_lat_cache.reference\000\000cache\000Counts the number of cacheable memory requests that access the LLC. Counts on a per core basis\000event=0x2e,period=200003,umask=0x4f\000\00000\000Counts the number of cacheable memory requests that access the Last Level Cache (LLC). Requests include demand loads, reads for ownership (RFO), instruction fetches and L1 HW prefetches. If the platform has an L3 cache, the LLC is the L3 cache, otherwise it is the L2 cache. Counts on a per core basis\000 */
{ 1303294 }, /* mem_bound_stalls.ifetch\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x38\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000 */
{ 1304075 }, /* mem_bound_stalls.ifetch_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x20\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or translation lookaside buffer (TLB) miss which hit in DRAM or MMIO (non-DRAM)\000 */
{ 1304822 }, /* mem_bound_stalls.ifetch_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the L2 cache\000event=0x34,period=200003,umask=0x8\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the L2 cache\000 */
{ 1305519 }, /* mem_bound_stalls.ifetch_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to an instruction cache or TLB miss which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x10\000\00000\000Counts the number of cycles the core is stalled due to an instruction cache or Translation Lookaside Buffer (TLB) miss which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1306350 }, /* mem_bound_stalls.load\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in the L2, LLC, DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x7\000\00000\000\000 */
{ 1306761 }, /* mem_bound_stalls.load_dram_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load miss which hit in DRAM or MMIO (Non-DRAM)\000event=0x34,period=200003,umask=0x4\000\00000\000\000 */
{ 1307164 }, /* mem_bound_stalls.load_l2_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the L2 cache\000event=0x34,period=200003,umask=0x1\000\00000\000\000 */
{ 1307531 }, /* mem_bound_stalls.load_llc_hit\000\000cache\000Counts the number of cycles the core is stalled due to a demand load which hit in the LLC or other core with HITE/F/M\000event=0x34,period=200003,umask=0x2\000\00000\000Counts the number of cycles the core is stalled due to a demand load which hit in the Last Level Cache (LLC) or other core with HITE/F/M\000 */
{ 1308218 }, /* mem_bound_stalls.store_buffer_full\000\000cache\000Counts the number of cycles the core is stalled due to a store buffer being full\000event=0x34,period=200003,umask=0x40\000\00000\000\000 */
{ 1352752 }, /* mem_load_uops_retired.dram_hit\000\000cache\000Counts the number of load uops retired that hit in DRAM  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x80\000\00000\000\000 */
{ 1355113 }, /* mem_load_uops_retired.hitm\000\000cache\000Counts the number of load uops retired that hit in the L3 cache, in which a snoop was required and modified data was forwarded from another core or module  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x20\000\00000\000\000 */
{ 1356362 }, /* mem_load_uops_retired.l1_hit\000\000cache\000Counts the number of load uops retired that hit in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x1\000\00000\000\000 */
{ 1358158 }, /* mem_load_uops_retired.l1_miss\000\000cache\000Counts the number of load uops retired that miss in the L1 data cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000\000 */
{ 1359677 }, /* mem_load_uops_retired.l2_hit\000\000cache\000Counts the number of load uops retired that hit in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000\000 */
{ 1361415 }, /* mem_load_uops_retired.l2_miss\000\000cache\000Counts the number of load uops retired that miss in the L2 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x10\000\00000\000\000 */
{ 1362932 }, /* mem_load_uops_retired.l3_hit\000\000cache\000Counts the number of load uops retired that hit in the L3 cache  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x4\000\00000\000\000 */
{ 1387995 }, /* mem_uops_retired.all\000\000cache\000Counts the number of memory uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x83\000\00000\000Counts the number of memory uops retired.  A single uop that performs both a load AND a store will be counted as 1, not 2 (e.g. ADD [mem], CONST)  Supports address when precise (Precise event)\000 */
{ 1389608 }, /* mem_uops_retired.all_loads\000\000cache\000Counts the number of load uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x81\000\00000\000Counts the total number of load uops retired  Supports address when precise (Precise event)\000 */
{ 1392234 }, /* mem_uops_retired.all_stores\000\000cache\000Counts the number of store uops retired  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x82\000\00000\000Counts the total number of store uops retired  Supports address when precise (Precise event)\000 */
{ 1414761 }, /* mem_uops_retired.lock_loads\000\000cache\000Counts the number of load uops retired that performed one or more locks  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x21\000\00000\000\000 */
{ 1416633 }, /* mem_uops_retired.split\000\000cache\000Counts the number of memory uops retired that were splits  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x43\000\00000\000\000 */
{ 1417334 }, /* mem_uops_retired.split_loads\000\000cache\000Counts the number of retired split load uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x41\000\00000\000\000 */
{ 1419426 }, /* mem_uops_retired.split_stores\000\000cache\000Counts the number of retired split store uops  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x42\000\00000\000\000 */
{ 1442166 }, /* ocr.all_code_rd.l3_hit\000\000cache\000Counts all code reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0044\000\00000\000\000 */
{ 1441031 }, /* ocr.all_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0044\000\00000\000\000 */
{ 1441264 }, /* ocr.all_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0044\000\00000\000\000 */
{ 1441509 }, /* ocr.all_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0044\000\00000\000\000 */
{ 1441743 }, /* ocr.all_code_rd.l3_hit.snoop_miss\000\000cache\000Counts all code reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0044\000\00000\000\000 */
{ 1441949 }, /* ocr.all_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts all code reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0044\000\00000\000\000 */
{ 1514370 }, /* ocr.corewb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache and L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3001F803C0000\000\00000\000\000 */
{ 1522191 }, /* ocr.demand_code_rd.l3_hit\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0004\000\00000\000\000 */
{ 1518194 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0004\000\00000\000\000 */
{ 1518623 }, /* ocr.demand_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0004\000\00000\000\000 */
{ 1519772 }, /* ocr.demand_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0004\000\00000\000\000 */
{ 1520495 }, /* ocr.demand_code_rd.l3_hit.snoop_miss\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0004\000\00000\000\000 */
{ 1521192 }, /* ocr.demand_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0004\000\00000\000\000 */
{ 1540920 }, /* ocr.demand_data_and_l1pf_rd.l3_hit\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00000\000\000 */
{ 1539270 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00000\000\000 */
{ 1539606 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1539954 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_hitm\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1540291 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_miss\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00000\000\000 */
{ 1540600 }, /* ocr.demand_data_and_l1pf_rd.l3_hit.snoop_not_needed\000\000cache\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00000\000\000 */
{ 1552258 }, /* ocr.demand_data_rd.l3_hit\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0001\000\00010\000\000 */
{ 1546321 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_NO_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0001\000\00010\000\000 */
{ 1547857 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00010\000\000 */
{ 1549584 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_HITM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00010\000\000 */
{ 1550703 }, /* ocr.demand_data_rd.l3_hit.snoop_miss\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0001\000\00010\000\000 */
{ 1551293 }, /* ocr.demand_data_rd.l3_hit.snoop_not_needed\000\000cache\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_HIT.SNOOP_NOT_NEEDED\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0001\000\00010\000\000 */
{ 1580657 }, /* ocr.demand_rfo.l3_hit\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0002\000\00000\000\000 */
{ 1575817 }, /* ocr.demand_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0002\000\00000\000\000 */
{ 1576593 }, /* ocr.demand_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0002\000\00000\000\000 */
{ 1576915 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1579038 }, /* ocr.demand_rfo.l3_hit.snoop_miss\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0002\000\00000\000\000 */
{ 1579793 }, /* ocr.demand_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0002\000\00000\000\000 */
{ 1602111 }, /* ocr.full_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify a full 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x801F803C0000\000\00000\000\000 */
{ 1604026 }, /* ocr.hwpf_l1d_and_swpf.l3_hit.snoop_hitm\000\000cache\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0400\000\00000\000\000 */
{ 1608691 }, /* ocr.hwpf_l2_code_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0040\000\00000\000\000 */
{ 1607266 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0040\000\00000\000\000 */
{ 1607557 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0040\000\00000\000\000 */
{ 1607860 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0040\000\00000\000\000 */
{ 1608152 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0040\000\00000\000\000 */
{ 1608416 }, /* ocr.hwpf_l2_code_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0040\000\00000\000\000 */
{ 1613603 }, /* ocr.hwpf_l2_data_rd.l3_hit\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0010\000\00000\000\000 */
{ 1610862 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0010\000\00000\000\000 */
{ 1611428 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0010\000\00000\000\000 */
{ 1611731 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0010\000\00000\000\000 */
{ 1612321 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0010\000\00000\000\000 */
{ 1612842 }, /* ocr.hwpf_l2_data_rd.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0010\000\00000\000\000 */
{ 1618449 }, /* ocr.hwpf_l2_rfo.l3_hit\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0020\000\00000\000\000 */
{ 1615813 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0020\000\00000\000\000 */
{ 1616358 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0020\000\00000\000\000 */
{ 1616651 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_hitm\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0020\000\00000\000\000 */
{ 1617220 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_miss\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0020\000\00000\000\000 */
{ 1617720 }, /* ocr.hwpf_l2_rfo.l3_hit.snoop_not_needed\000\000cache\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0020\000\00000\000\000 */
{ 1622882 }, /* ocr.l1wb_m.l3_hit\000\000cache\000Counts modified writebacks from L1 cache that miss the L2 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001F803C0000\000\00000\000\000 */
{ 1623670 }, /* ocr.l2wb_m.l3_hit\000\000cache\000Counts modified writeBacks from L2 cache that miss the L3 cache that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2001F803C0000\000\00000\000\000 */
{ 1639727 }, /* ocr.partial_streaming_wr.l3_hit\000\000cache\000Counts streaming stores which modify only part of a 64 byte cacheline that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x401F803C0000\000\00000\000\000 */
{ 1724431 }, /* ocr.reads_to_core.l3_hit\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0477\000\00000\000\000 */
{ 1720874 }, /* ocr.reads_to_core.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x4003C0477\000\00000\000\000 */
{ 1721903 }, /* ocr.reads_to_core.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0477\000\00000\000\000 */
{ 1722894 }, /* ocr.reads_to_core.l3_hit.snoop_hitm\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0477\000\00000\000\000 */
{ 1723220 }, /* ocr.reads_to_core.l3_hit.snoop_miss\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2003C0477\000\00000\000\000 */
{ 1723518 }, /* ocr.reads_to_core.l3_hit.snoop_not_needed\000\000cache\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1003C0477\000\00000\000\000 */
{ 1739801 }, /* ocr.streaming_wr.l3_hit\000\000cache\000Counts streaming stores that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1F803C0800\000\00000\000\000 */
{ 1742854 }, /* ocr.uc_rd.l3_hit\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x101F803C0000\000\00000\000\000 */
{ 1741700 }, /* ocr.uc_rd.l3_hit.snoop_hit_no_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, but no data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1004003C0000\000\00000\000\000 */
{ 1741937 }, /* ocr.uc_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and non-modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1008003C0000\000\00000\000\000 */
{ 1742186 }, /* ocr.uc_rd.l3_hit.snoop_hitm\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent, the snoop hit, and modified data was forwarded\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1010003C0000\000\00000\000\000 */
{ 1742423 }, /* ocr.uc_rd.l3_hit.snoop_miss\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where a snoop was sent but the snoop missed\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002003C0000\000\00000\000\000 */
{ 1742633 }, /* ocr.uc_rd.l3_hit.snoop_not_needed\000\000cache\000Counts uncached memory reads that were supplied by the L3 cache where no snoop was needed to satisfy the request\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1001003C0000\000\00000\000\000 */
{ 1743893 }, /* ocr.uc_wr.l3_hit\000\000cache\000Counts uncached memory writes that were supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x201F803C0000\000\00000\000\000 */
{ 2567930 }, /* topdown_fe_bound.icache\000\000cache\000Counts the number of issue slots every cycle that were not delivered by the frontend due to instruction cache misses\000event=0x71,period=1000003,umask=0x20\000\00000\000\000 */
{ 761126 }, /* cycles_div_busy.fpdiv\000\000floating point\000Counts the number of cycles the floating point divider is busy\000event=0xcd,period=200003,umask=0x2\000\00000\000Counts the number of cycles the floating point divider is busy.  Does not imply a stall waiting for the divider\000 */
{ 1291322 }, /* machine_clears.fp_assist\000\000floating point\000Counts the number of floating point operations retired that required microcode assist\000event=0xc3,period=20003,umask=0x4\000\00000\000Counts the number of floating point operations retired that required microcode assist, which is not a reflection of the number of FP operations, instructions or uops\000 */
{ 6228633 }, /* uops_retired.fpdiv\000\000floating point\000Counts the number of floating point divide uops retired (x87 and SSE, including x87 sqrt) (Precise event)\000event=0xc2,period=2000003,umask=0x8\000\00000\000\000 */
{ 475810 }, /* baclears.any\000\000frontend\000Counts the total number of BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000event=0xe6,period=200003,umask=0x1\000\00000\000Counts the total number of BACLEARS, which occur when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend.  Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 478968 }, /* baclears.cond\000\000frontend\000Counts the number of BACLEARS due to a conditional jump\000event=0xe6,period=200003,umask=0x10\000\00000\000\000 */
{ 479701 }, /* baclears.indirect\000\000frontend\000Counts the number of BACLEARS due to an indirect branch\000event=0xe6,period=200003,umask=0x2\000\00000\000\000 */
{ 479965 }, /* baclears.return\000\000frontend\000Counts the number of BACLEARS due to a return branch\000event=0xe6,period=200003,umask=0x8\000\00000\000\000 */
{ 480671 }, /* baclears.uncond\000\000frontend\000Counts the number of BACLEARS due to a direct, unconditional jump\000event=0xe6,period=200003,umask=0x4\000\00000\000\000 */
{ 777925 }, /* decode_restriction.predecode_wrong\000\000frontend\000Counts the number of times a decode restriction reduces the decode throughput due to wrong instruction length prediction\000event=0xe9,period=200003,umask=0x1\000\00000\000\000 */
{ 983063 }, /* icache.accesses\000\000frontend\000Counts the number of requests to the instruction cache for one or more bytes of a cache line\000event=0x80,period=200003,umask=0x3\000\00000\000Counts the total number of requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line or byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 985453 }, /* icache.hit\000\000frontend\000Counts the number of instruction cache hits\000event=0x80,period=200003,umask=0x1\000\00000\000Counts the number of requests that hit in the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 989052 }, /* icache.misses\000\000frontend\000Counts the number of instruction cache misses\000event=0x80,period=200003,umask=0x2\000\00000\000Counts the number of missed requests to the instruction cache.  The event only counts new cache line accesses, so that multiple back to back fetches to the exact same cache line and byte chunk count as one.  Specifically, the event counts when accesses from sequential code crosses the cache line boundary, or when a branch target is moved to a new line or to a non-sequential byte chunk of the same line\000 */
{ 1295858 }, /* machine_clears.memory_ordering\000\000memory\000Counts the number of machine clears due to memory ordering caused by a snoop from an external agent. Does not count internally generated machine clears such as those due to memory disambiguation\000event=0xc3,period=20003,umask=0x2\000\00000\000\000 */
{ 1427819 }, /* misalign_mem_ref.load_page_split\000\000memory\000Counts the number of misaligned load uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x2\000\00000\000\000 */
{ 1429789 }, /* misalign_mem_ref.store_page_split\000\000memory\000Counts the number of misaligned store uops that are 4K page splits (Precise event)\000event=0x13,period=200003,umask=0x4\000\00000\000\000 */
{ 1442318 }, /* ocr.all_code_rd.l3_miss\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000 */
{ 1442476 }, /* ocr.all_code_rd.l3_miss_local\000\000memory\000Counts all code reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000044\000\00000\000\000 */
{ 1514554 }, /* ocr.corewb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000 */
{ 1514744 }, /* ocr.corewb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache and L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3002184000000\000\00000\000\000 */
{ 1529409 }, /* ocr.demand_code_rd.l3_miss\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000 */
{ 1530090 }, /* ocr.demand_code_rd.l3_miss_local\000\000memory\000Counts demand instruction fetches and L1 instruction cache prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000004\000\00000\000\000 */
{ 1541175 }, /* ocr.demand_data_and_l1pf_rd.l3_miss\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000 */
{ 1541436 }, /* ocr.demand_data_and_l1pf_rd.l3_miss_local\000\000memory\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00000\000\000 */
{ 1560151 }, /* ocr.demand_data_rd.l3_miss\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000 */
{ 1561112 }, /* ocr.demand_data_rd.l3_miss_local\000\000memory\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.L3_MISS_LOCAL\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000001\000\00010\000\000 */
{ 1588756 }, /* ocr.demand_rfo.l3_miss\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000 */
{ 1590774 }, /* ocr.demand_rfo.l3_miss_local\000\000memory\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000002\000\00000\000\000 */
{ 1602311 }, /* ocr.full_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000 */
{ 1602517 }, /* ocr.full_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify a full 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x802184000000\000\00000\000\000 */
{ 1608901 }, /* ocr.hwpf_l2_code_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000 */
{ 1609117 }, /* ocr.hwpf_l2_code_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000040\000\00000\000\000 */
{ 1613813 }, /* ocr.hwpf_l2_data_rd.l3_miss\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000 */
{ 1614230 }, /* ocr.hwpf_l2_data_rd.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000010\000\00000\000\000 */
{ 1618649 }, /* ocr.hwpf_l2_rfo.l3_miss\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000 */
{ 1619045 }, /* ocr.hwpf_l2_rfo.l3_miss_local\000\000memory\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000020\000\00000\000\000 */
{ 1623074 }, /* ocr.l1wb_m.l3_miss\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000 */
{ 1623272 }, /* ocr.l1wb_m.l3_miss_local\000\000memory\000Counts modified writebacks from L1 cache that miss the L2 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1002184000000\000\00000\000\000 */
{ 1623862 }, /* ocr.l2wb_m.l3_miss\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000 */
{ 1624060 }, /* ocr.l2wb_m.l3_miss_local\000\000memory\000Counts modified writeBacks from L2 cache that miss the L3 cache that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2002184000000\000\00000\000\000 */
{ 1633637 }, /* ocr.other.l3_miss\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000 */
{ 1634244 }, /* ocr.other.l3_miss_local\000\000memory\000Counts miscellaneous requests, such as I/O accesses, that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184008000\000\00000\000\000 */
{ 1639938 }, /* ocr.partial_streaming_wr.l3_miss\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000 */
{ 1640155 }, /* ocr.partial_streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores which modify only part of a 64 byte cacheline that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x402184000000\000\00000\000\000 */
{ 1718314 }, /* ocr.prefetches.l3_miss\000\000memory\000Counts all hardware and software prefetches that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000470\000\00000\000\000 */
{ 1725253 }, /* ocr.reads_to_core.l3_miss\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000 */
{ 1726166 }, /* ocr.reads_to_core.l3_miss_local\000\000memory\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000477\000\00000\000\000 */
{ 1740462 }, /* ocr.streaming_wr.l3_miss\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000 */
{ 1740623 }, /* ocr.streaming_wr.l3_miss_local\000\000memory\000Counts streaming stores that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2184000800\000\00000\000\000 */
{ 1743009 }, /* ocr.uc_rd.l3_miss\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000 */
{ 1743170 }, /* ocr.uc_rd.l3_miss_local\000\000memory\000Counts uncached memory reads that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x102184000000\000\00000\000\000 */
{ 1744049 }, /* ocr.uc_wr.l3_miss\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000 */
{ 1744211 }, /* ocr.uc_wr.l3_miss_local\000\000memory\000Counts uncached memory writes that were not supplied by the L3 cache\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x202184000000\000\00000\000\000 */
{ 566747 }, /* bus_lock.all\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.SELF_LOCKS\000event=0x63,edge=1,period=200003\000\00010\000\000 */
{ 566869 }, /* bus_lock.block_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores\000event=0x63,period=200003,umask=0x2\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock issued by other cores. Counts on a per core basis\000 */
{ 567167 }, /* bus_lock.cycles_other_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.BLOCK_CYCLES\000event=0x63,period=200003,umask=0x2\000\00010\000\000 */
{ 567309 }, /* bus_lock.cycles_self_block\000\000other\000This event is deprecated. Refer to new event BUS_LOCK.LOCK_CYCLES\000event=0x63,period=200003,umask=0x1\000\00010\000\000 */
{ 567449 }, /* bus_lock.lock_cycles\000\000other\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued\000event=0x63,period=200003,umask=0x1\000\00000\000Counts the number of unhalted cycles a core is blocked due to an accepted lock it issued. Counts on a per core basis\000 */
{ 567722 }, /* bus_lock.self_locks\000\000other\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks\000event=0x63,edge=1,period=200003\000\00000\000Counts the number of bus locks a core issued its self (e.g. lock to UC or Split Lock) and does not include cache locks. Counts on a per core basis\000 */
{ 570986 }, /* c0_stalls.load_dram_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_DRAM_HIT\000event=0x34,period=200003,umask=0x4\000\00010\000\000 */
{ 571133 }, /* c0_stalls.load_l2_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_L2_HIT\000event=0x34,period=200003,umask=0x1\000\00010\000\000 */
{ 571276 }, /* c0_stalls.load_llc_hit\000\000other\000This event is deprecated. Refer to new event MEM_BOUND_STALLS.LOAD_LLC_HIT\000event=0x34,period=200003,umask=0x2\000\00010\000\000 */
{ 976774 }, /* hw_interrupts.masked\000\000other\000Counts the number of core cycles during which interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x2\000\00000\000Counts the number of core cycles during which interrupts are masked (disabled). Increments by 1 each core cycle that EFLAGS.IF is 0, regardless of whether interrupts are pending or not\000 */
{ 977395 }, /* hw_interrupts.pending_and_masked\000\000other\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled)\000event=0xcb,period=200003,umask=0x4\000\00000\000Counts the number of core cycles during which there are pending interrupts while interrupts are masked (disabled). Increments by 1 each core cycle that both EFLAGS.IF is 0 and an INTR is pending (which means the APIC is telling the ROB to cause an INTR). This event does not increment if EFLAGS.IF is 0 but all interrupt in the APICs Interrupt Request Register (IRR) are inhibited by the PPR (thus either by ISRV or TPR)  because in these cases the interrupts would be held up in the APIC and would not be pended to the ROB. This event does count when an interrupt is only inhibited by MOV/POP SS state machines or the STI state machine. These extra inhibits only last for a single instructions and would not be important\000 */
{ 978530 }, /* hw_interrupts.received\000\000other\000Counts the number of hardware interrupts received by the processor\000event=0xcb,period=203,umask=0x1\000\00000\000\000 */
{ 1440741 }, /* ocr.all_code_rd.any_response\000\000other\000Counts all code reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10044\000\00000\000\000 */
{ 1440890 }, /* ocr.all_code_rd.dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000 */
{ 1442640 }, /* ocr.all_code_rd.local_dram\000\000other\000Counts all code reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000044\000\00000\000\000 */
{ 1442787 }, /* ocr.all_code_rd.outstanding\000\000other\000Counts all code reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000044\000\00000\000\000 */
{ 1513981 }, /* ocr.corewb_m.any_response\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x3000000010000\000\00000\000\000 */
{ 1514940 }, /* ocr.corewb_m.outstanding\000\000other\000Counts modified writebacks from L1 cache and L2 cache that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003000000000000\000\00000\000\000 */
{ 1515566 }, /* ocr.demand_code_rd.any_response\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10004\000\00000\000\000 */
{ 1516154 }, /* ocr.demand_code_rd.dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1534712 }, /* ocr.demand_code_rd.local_dram\000\000other\000Counts demand instruction fetches and L1 instruction cache prefetches that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000004\000\00000\000\000 */
{ 1538774 }, /* ocr.demand_data_and_l1pf_rd.any_response\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00000\000\000 */
{ 1539026 }, /* ocr.demand_data_and_l1pf_rd.dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1541703 }, /* ocr.demand_data_and_l1pf_rd.local_dram\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00000\000\000 */
{ 1541953 }, /* ocr.demand_data_and_l1pf_rd.outstanding\000\000other\000Counts cacheable demand data reads, L1 data cache hardware prefetches and software prefetches (except PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00000\000\000 */
{ 1542759 }, /* ocr.demand_data_rd.any_response\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.ANY_RESPONSE\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10001\000\00010\000\000 */
{ 1543749 }, /* ocr.demand_data_rd.dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000 */
{ 1565431 }, /* ocr.demand_data_rd.local_dram\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.LOCAL_DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000001\000\00010\000\000 */
{ 1565919 }, /* ocr.demand_data_rd.outstanding\000\000other\000This event is deprecated. Refer to new event OCR.DEMAND_DATA_AND_L1PF_RD.OUTSTANDING\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000001\000\00010\000\000 */
{ 1572074 }, /* ocr.demand_rfo.any_response\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10002\000\00000\000\000 */
{ 1573525 }, /* ocr.demand_rfo.dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1595079 }, /* ocr.demand_rfo.local_dram\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000002\000\00000\000\000 */
{ 1596695 }, /* ocr.demand_rfo.outstanding\000\000other\000Counts demand reads for ownership (RFO) and software prefetches for exclusive ownership (PREFETCHW) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000002\000\00000\000\000 */
{ 1601909 }, /* ocr.full_streaming_wr.any_response\000\000other\000Counts streaming stores which modify a full 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x800000010000\000\00000\000\000 */
{ 1602918 }, /* ocr.hwpf_l1d_and_swpf.any_response\000\000other\000Counts L1 data cache hardware prefetches and software prefetches (except PREFETCHW and PFRFO) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10400\000\00000\000\000 */
{ 1606860 }, /* ocr.hwpf_l2_code_rd.any_response\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10040\000\00000\000\000 */
{ 1607067 }, /* ocr.hwpf_l2_code_rd.dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000 */
{ 1609339 }, /* ocr.hwpf_l2_code_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000040\000\00000\000\000 */
{ 1609544 }, /* ocr.hwpf_l2_code_rd.outstanding\000\000other\000Counts L2 cache hardware prefetch code reads (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000040\000\00000\000\000 */
{ 1609848 }, /* ocr.hwpf_l2_data_rd.any_response\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10010\000\00000\000\000 */
{ 1610248 }, /* ocr.hwpf_l2_data_rd.dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614452 }, /* ocr.hwpf_l2_data_rd.local_dram\000\000other\000Counts L2 cache hardware prefetch data reads (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000010\000\00000\000\000 */
{ 1614852 }, /* ocr.hwpf_l2_rfo.any_response\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10020\000\00000\000\000 */
{ 1615231 }, /* ocr.hwpf_l2_rfo.dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619257 }, /* ocr.hwpf_l2_rfo.local_dram\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000020\000\00000\000\000 */
{ 1619636 }, /* ocr.hwpf_l2_rfo.outstanding\000\000other\000Counts L2 cache hardware prefetch RFOs (written to the L2 cache only) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000020\000\00000\000\000 */
{ 1622688 }, /* ocr.l1wb_m.any_response\000\000other\000Counts modified writebacks from L1 cache that miss the L2 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x1000000010000\000\00000\000\000 */
{ 1623476 }, /* ocr.l2wb_m.any_response\000\000other\000Counts modified writeBacks from L2 cache that miss the L3 cache that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x2000000010000\000\00000\000\000 */
{ 1624595 }, /* ocr.other.any_response\000\000other\000Counts miscellaneous requests, such as I/O accesses, that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x18000\000\00000\000\000 */
{ 1639514 }, /* ocr.partial_streaming_wr.any_response\000\000other\000Counts streaming stores which modify only part of a 64 byte cacheline that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x400000010000\000\00000\000\000 */
{ 1717909 }, /* ocr.prefetches.any_response\000\000other\000Counts all hardware and software prefetches that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10470\000\00000\000\000 */
{ 1719272 }, /* ocr.reads_to_core.any_response\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10477\000\00000\000\000 */
{ 1720003 }, /* ocr.reads_to_core.dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000 */
{ 1728233 }, /* ocr.reads_to_core.local_dram\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x184000477\000\00000\000\000 */
{ 1730543 }, /* ocr.reads_to_core.outstanding\000\000other\000Counts all data read, code read and RFO requests including demands and prefetches to the core caches (L1 or L2) that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000000000000477\000\00000\000\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 1741398 }, /* ocr.uc_rd.any_response\000\000other\000Counts uncached memory reads that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100000010000\000\00000\000\000 */
{ 1741555 }, /* ocr.uc_rd.dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000 */
{ 1743337 }, /* ocr.uc_rd.local_dram\000\000other\000Counts uncached memory reads that were supplied by DRAM\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x100184000000\000\00000\000\000 */
{ 1743488 }, /* ocr.uc_rd.outstanding\000\000other\000Counts uncached memory reads that have an outstanding request. Returns the number of cycles until the response is received (i.e. XQ to XQ latency)\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8000100000000000\000\00000\000\000 */
{ 1743735 }, /* ocr.uc_wr.any_response\000\000other\000Counts uncached memory writes that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x200000010000\000\00000\000\000 */
{ 497910 }, /* br_inst_retired.all_branches\000\000pipeline\000Counts the total number of branch instructions retired for all branch types (Precise event)\000event=0xc4,period=200003\000\00000\000Counts the total number of instructions in which the instruction pointer (IP) of the processor is resteered due to a branch instruction and the branch instruction successfully retires.  All branch type instructions are accounted for (Precise event)\000 */
{ 502234 }, /* br_inst_retired.call\000\000pipeline\000Counts the number of near CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf9\000\00000\000\000 */
{ 507645 }, /* br_inst_retired.far_branch\000\000pipeline\000Counts the number of far branch instructions retired, includes far jump, far call and return, and interrupt call and return (Precise event)\000event=0xc4,period=200003,umask=0xbf\000\00000\000\000 */
{ 510375 }, /* br_inst_retired.ind_call\000\000pipeline\000Counts the number of near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfb\000\00000\000\000 */
{ 513344 }, /* br_inst_retired.jcc\000\000pipeline\000Counts the number of retired JCC (Jump on Conditional Code) branch instructions retired, includes both taken and not taken branches (Precise event)\000event=0xc4,period=200003,umask=0x7e\000\00000\000\000 */
{ 521242 }, /* br_inst_retired.non_return_ind\000\000pipeline\000Counts the number of near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xeb\000\00000\000\000 */
{ 523776 }, /* br_inst_retired.rel_call\000\000pipeline\000Counts the number of near relative CALL branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfd\000\00000\000\000 */
{ 525103 }, /* br_inst_retired.return\000\000pipeline\000Counts the number of near RET branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xf7\000\00000\000\000 */
{ 526112 }, /* br_inst_retired.taken_jcc\000\000pipeline\000Counts the number of taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc4,period=200003,umask=0xfe\000\00000\000\000 */
{ 538105 }, /* br_misp_retired.all_branches\000\000pipeline\000Counts the total number of mispredicted branch instructions retired for all branch types (Precise event)\000event=0xc5,period=200003\000\00000\000Counts the total number of mispredicted branch instructions retired.  All branch type instructions are accounted for.  Prediction of the branch target address enables the processor to begin executing instructions before the non-speculative execution path is known. The branch prediction unit (BPU) predicts the target address based on the instruction pointer (IP) of the branch and on the execution path through which execution reached this IP.    A branch misprediction occurs when the prediction is wrong, and results in discarding all instructions executed in the speculative path and re-fetching from the correct path (Precise event)\000 */
{ 548123 }, /* br_misp_retired.ind_call\000\000pipeline\000Counts the number of mispredicted near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfb\000\00000\000\000 */
{ 552527 }, /* br_misp_retired.jcc\000\000pipeline\000Counts the number of mispredicted JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0x7e\000\00000\000\000 */
{ 558108 }, /* br_misp_retired.non_return_ind\000\000pipeline\000Counts the number of mispredicted near indirect JMP and near indirect CALL branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xeb\000\00000\000\000 */
{ 562117 }, /* br_misp_retired.return\000\000pipeline\000Counts the number of mispredicted near RET branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xf7\000\00000\000\000 */
{ 563268 }, /* br_misp_retired.taken_jcc\000\000pipeline\000Counts the number of mispredicted taken JCC (Jump on Conditional Code) branch instructions retired (Precise event)\000event=0xc5,period=200003,umask=0xfe\000\00000\000\000 */
{ 565564 }, /* btclear.any\000\000pipeline\000Counts the total number of BTCLEARS\000event=0xe8,period=200003\000\00000\000Counts the total number of BTCLEARS which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 612440 }, /* cpu_clk_unhalted.core\000\000pipeline\000Counts the number of unhalted core clock cycles. (Fixed event)\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses fixed counter 1\000 */
{ 615598 }, /* cpu_clk_unhalted.core_p\000\000pipeline\000Counts the number of unhalted core clock cycles\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. The core frequency may change from time to time. For this reason this event may have a changing ratio with regards to time. This event uses a programmable general purpose performance counter\000 */
{ 619311 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x0,umask=0x03,period=2000003\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 622318 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency. (Fixed event)\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses fixed counter 2\000 */
{ 634226 }, /* cpu_clk_unhalted.ref_tsc_p\000\000pipeline\000Counts the number of unhalted reference clock cycles at TSC frequency\000event=0x3c,period=2000003,umask=0x1\000\00000\000Counts the number of reference cycles that the core is not in a halt state. The core enters the halt state when it is running the HLT instruction. This event is not affected by core frequency changes and increments at a fixed frequency that is also used for the Time Stamp Counter (TSC). This event uses a programmable general purpose performance counter\000 */
{ 761040 }, /* cycles_div_busy.any\000\000pipeline\000This event is deprecated\000event=0xcd,period=2000003\000\00010\000\000 */
{ 761547 }, /* cycles_div_busy.idiv\000\000pipeline\000Counts the number of cycles the integer divider is busy\000event=0xcd,period=200003,umask=0x1\000\00000\000Counts the number of cycles the integer divider is busy.  Does not imply a stall waiting for the divider\000 */
{ 1044203 }, /* inst_retired.any\000\000pipeline\000Counts the total number of instructions retired. (Fixed event) (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses fixed counter 0 (Precise event)\000 */
{ 1052183 }, /* inst_retired.any_p\000\000pipeline\000Counts the total number of instructions retired (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the total number of instructions that retired. For instructions that consist of multiple uops, this event counts the retirement of the last uop of the instruction. This event continues counting during hardware interrupts, traps, and inside interrupt handlers. This event uses a programmable general purpose performance counter (Precise event)\000 */
{ 1189894 }, /* ld_blocks.4k_alias\000\000pipeline\000Counts the number of retired loads that are blocked because it initially appears to be store forward blocked, but subsequently is shown not to be blocked based on 4K alias check (Precise event)\000event=0x3,period=1000003,umask=0x4\000\00000\000\000 */
{ 1191843 }, /* ld_blocks.all\000\000pipeline\000Counts the number of retired loads that are blocked for any of the following reasons:  DTLB miss, address alias, store forward or data unknown (includes memory disambiguation blocks and ESP consuming load blocks) (Precise event)\000event=0x3,period=1000003,umask=0x10\000\00000\000\000 */
{ 1192607 }, /* ld_blocks.data_unknown\000\000pipeline\000Counts the number of retired loads that are blocked because its address exactly matches an older store whose data is not ready (Precise event)\000event=0x3,period=1000003,umask=0x1\000\00000\000\000 */
{ 1198416 }, /* ld_blocks.store_forward\000\000pipeline\000Counts the number of retired loads that are blocked because its address partially overlapped with an older store (Precise event)\000event=0x3,period=1000003,umask=0x2\000\00000\000\000 */
{ 1288621 }, /* machine_clears.any\000\000pipeline\000Counts the total number of machine clears for any reason including, but not limited to, memory ordering, memory disambiguation, SMC, and FP assist\000event=0xc3,period=20003\000\00000\000\000 */
{ 1289828 }, /* machine_clears.disambiguation\000\000pipeline\000Counts the number of machine clears due to memory ordering in which an internal load passes an older store within the same CPU\000event=0xc3,period=20003,umask=0x8\000\00000\000\000 */
{ 1298456 }, /* machine_clears.page_fault\000\000pipeline\000Counts the number of machine clears due to a page fault.  Counts both I-Side and D-Side (Loads/Stores) page faults.  A page fault occurs when either the page is not present, or an access violation occurs\000event=0xc3,period=20003,umask=0x20\000\00000\000\000 */
{ 1299922 }, /* machine_clears.smc\000\000pipeline\000Counts the number of machine clears due to program modifying data (self modifying code) within 1K of a recently fetched code page\000event=0xc3,period=20003,umask=0x1\000\00000\000\000 */
{ 2551516 }, /* topdown_bad_speculation.all\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear\000event=0x73,period=1000003,umask=0x6\000\00000\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a mispredicted jump or a machine clear. Only issue slots wasted due to fast nukes such as memory ordering nukes are counted. Other nukes are not accounted for. Counts all issue slots blocked during this recovery window including relevant microcode flows and while uops are not yet available in the instruction queue (IQ) even if an FE_bound event occurs during this period. Also includes the issue slots that were consumed by the backend but were thrown away because they were younger than the mispredict or machine clear\000 */
{ 2555005 }, /* topdown_bad_speculation.fastnuke\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to fast nukes such as memory ordering and memory disambiguation machine clears\000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2555794 }, /* topdown_bad_speculation.machine_clears\000\000pipeline\000Counts the total number of issue slots that were not consumed by the backend because allocation is stalled due to a machine clear (nuke) of any kind including memory ordering and memory disambiguation\000event=0x73,period=1000003,umask=0x2\000\00000\000\000 */
{ 2556692 }, /* topdown_bad_speculation.mispredict\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to branch mispredicts\000event=0x73,period=1000003,umask=0x4\000\00000\000\000 */
{ 2557107 }, /* topdown_bad_speculation.monuke\000\000pipeline\000This event is deprecated. Refer to new event TOPDOWN_BAD_SPECULATION.FASTNUKE\000event=0x73,period=1000003,umask=0x2\000\00010\000\000 */
{ 2557813 }, /* topdown_be_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to backend stalls\000event=0x74,period=1000003\000\00000\000\000 */
{ 2558344 }, /* topdown_be_bound.alloc_restrictions\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to certain allocation restrictions\000event=0x74,period=1000003,umask=0x1\000\00000\000\000 */
{ 2559028 }, /* topdown_be_bound.mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to memory reservation stalls in which a scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x2\000\00000\000\000 */
{ 2559545 }, /* topdown_be_bound.non_mem_scheduler\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to IEC or FPC RAT stalls, which can be due to FIQ or IEC reservation stalls in which the integer, floating point or SIMD scheduler is not able to accept uops\000event=0x74,period=1000003,umask=0x8\000\00000\000\000 */
{ 2560232 }, /* topdown_be_bound.register\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the physical register file unable to accept an entry (marble stalls)\000event=0x74,period=1000003,umask=0x20\000\00000\000\000 */
{ 2561036 }, /* topdown_be_bound.reorder_buffer\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to the reorder buffer being full (ROB stalls)\000event=0x74,period=1000003,umask=0x40\000\00000\000\000 */
{ 2561495 }, /* topdown_be_bound.serialization\000\000pipeline\000Counts the number of issue slots every cycle that were not consumed by the backend due to scoreboards from the instruction queue (IQ), jump execution unit (JEU), or microcode sequencer (MS)\000event=0x74,period=1000003,umask=0x10\000\00000\000\000 */
{ 2562293 }, /* topdown_be_bound.store_buffer\000\000pipeline\000This event is deprecated\000event=0x74,period=1000003,umask=0x4\000\00010\000\000 */
{ 2562536 }, /* topdown_fe_bound.all\000\000pipeline\000Counts the total number of issue slots every cycle that were not consumed by the backend due to frontend stalls\000event=0x71,period=1000003\000\00000\000\000 */
{ 2563071 }, /* topdown_fe_bound.branch_detect\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS\000event=0x71,period=1000003,umask=0x2\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BACLEARS, which occurs when the Branch Target Buffer (BTB) prediction or lack thereof, was corrected by a later branch predictor in the frontend. Includes BACLEARS due to all branch types including conditional and unconditional jumps, returns, and indirect branches\000 */
{ 2564383 }, /* topdown_fe_bound.branch_resteer\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS\000event=0x71,period=1000003,umask=0x40\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to BTCLEARS, which occurs when the Branch Target Buffer (BTB) predicts a taken branch\000 */
{ 2565335 }, /* topdown_fe_bound.cisc\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to the microcode sequencer (MS)\000event=0x71,period=1000003,umask=0x1\000\00000\000\000 */
{ 2565941 }, /* topdown_fe_bound.decode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to decode stalls\000event=0x71,period=1000003,umask=0x8\000\00000\000\000 */
{ 2568540 }, /* topdown_fe_bound.itlb\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to ITLB misses\000event=0x71,period=1000003,umask=0x10\000\00000\000Counts the number of issue slots every cycle that were not delivered by the frontend due to Instruction Table Lookaside Buffer (ITLB) misses\000 */
{ 2569631 }, /* topdown_fe_bound.other\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to other common frontend stalls not categorized\000event=0x71,period=1000003,umask=0x80\000\00000\000\000 */
{ 2570080 }, /* topdown_fe_bound.predecode\000\000pipeline\000Counts the number of issue slots every cycle that were not delivered by the frontend due to wrong predecodes\000event=0x71,period=1000003,umask=0x4\000\00000\000\000 */
{ 2570845 }, /* topdown_retiring.all\000\000pipeline\000Counts the total number of consumed retirement slots (Precise event)\000event=0xc2,period=1000003\000\00000\000\000 */
{ 6212632 }, /* uops_issued.any\000\000pipeline\000Counts the number of uops issued by the front end every cycle\000event=0xe,period=200003\000\00000\000Counts the number of uops issued by the front end every cycle. When 4-uops are requested and only 2-uops are delivered, the event counts 2.  Uops_issued correlates to the number of ROB entries.  If uop takes 2 ROB slots it counts as 2 uops_issued\000 */
{ 6226738 }, /* uops_retired.all\000\000pipeline\000Counts the total number of uops retired (Precise event)\000event=0xc2,period=2000003\000\00000\000\000 */
{ 6230315 }, /* uops_retired.idiv\000\000pipeline\000Counts the number of integer divide uops retired (Precise event)\000event=0xc2,period=2000003,umask=0x10\000\00000\000\000 */
{ 6231578 }, /* uops_retired.ms\000\000pipeline\000Counts the number of uops that are from complex flows issued by the micro-sequencer (MS) (Precise event)\000event=0xc2,period=2000003,umask=0x1\000\00000\000Counts the number of uops that are from complex flows issued by the Microcode Sequencer (MS). This includes uops from flows due to complex instructions, faults, assists, and inserted flows (Precise event)\000 */
{ 6241237 }, /* uops_retired.x87\000\000pipeline\000Counts the number of x87 uops retired, includes those in MS flows (Precise event)\000event=0xc2,period=2000003,umask=0x2\000\00000\000\000 */
{ 1213222 }, /* llc_misses.mmio_read\000uncore_cha\000uncore cache\000MMIO reads. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40040e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1214767 }, /* llc_misses.mmio_write\000uncore_cha\000uncore cache\000MMIO writes. Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40041e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1221722 }, /* llc_misses.uncacheable\000uncore_cha\000uncore cache\000LLC misses - Uncacheable reads (from cpu) . Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x40e33\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1226464 }, /* llc_references.streaming_full\000uncore_cha\000uncore cache\000Streaming stores (full cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x41833\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 1228142 }, /* llc_references.streaming_partial\000uncore_cha\000uncore cache\000Streaming stores (partial cache line). Derived from unc_cha_tor_inserts.ia_miss. Unit: uncore_cha \000event=0x35,umask=0xc001fe01,config1=0x41a33\000\0000164Bytes\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 2794924 }, /* unc_cha_ag0_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795203 }, /* unc_cha_ag0_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795482 }, /* unc_cha_ag0_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2795761 }, /* unc_cha_ag0_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796040 }, /* unc_cha_ag0_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796320 }, /* unc_cha_ag0_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796600 }, /* unc_cha_ag0_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2796880 }, /* unc_cha_ag0_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797160 }, /* unc_cha_ag0_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797442 }, /* unc_cha_ag0_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2797721 }, /* unc_cha_ag0_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 2799352 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799632 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2799912 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800192 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800472 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2800753 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801034 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801315 }, /* unc_cha_ag0_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801596 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2801879 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2802159 }, /* unc_cha_ag0_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 2803791 }, /* unc_cha_ag0_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804070 }, /* unc_cha_ag0_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804349 }, /* unc_cha_ag0_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804628 }, /* unc_cha_ag0_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2804907 }, /* unc_cha_ag0_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805187 }, /* unc_cha_ag0_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805467 }, /* unc_cha_ag0_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2805747 }, /* unc_cha_ag0_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806027 }, /* unc_cha_ag0_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806309 }, /* unc_cha_ag0_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2806588 }, /* unc_cha_ag0_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 2808219 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2808499 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2808779 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809059 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809339 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809620 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2809901 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810182 }, /* unc_cha_ag0_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810463 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2810746 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2811026 }, /* unc_cha_ag0_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 2812658 }, /* unc_cha_ag1_ad_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2812937 }, /* unc_cha_ag1_ad_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813216 }, /* unc_cha_ag1_ad_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813495 }, /* unc_cha_ag1_ad_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2813774 }, /* unc_cha_ag1_ad_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814054 }, /* unc_cha_ag1_ad_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814334 }, /* unc_cha_ag1_ad_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_cha \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814614 }, /* unc_cha_ag1_ad_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_cha \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2814894 }, /* unc_cha_ag1_ad_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815176 }, /* unc_cha_ag1_ad_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2815455 }, /* unc_cha_ag1_ad_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 2817086 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817366 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817646 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2817926 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818206 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818487 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2818768 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819049 }, /* unc_cha_ag1_ad_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819330 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819613 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2819893 }, /* unc_cha_ag1_ad_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 2820173 }, /* unc_cha_ag1_bl_crd_acquired0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_cha \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2820452 }, /* unc_cha_ag1_bl_crd_acquired0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_cha \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2820731 }, /* unc_cha_ag1_bl_crd_acquired0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_cha \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821010 }, /* unc_cha_ag1_bl_crd_acquired0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_cha \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821289 }, /* unc_cha_ag1_bl_crd_acquired0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821569 }, /* unc_cha_ag1_bl_crd_acquired0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2821849 }, /* unc_cha_ag1_bl_crd_acquired0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_cha \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822129 }, /* unc_cha_ag1_bl_crd_acquired0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_cha \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822409 }, /* unc_cha_ag1_bl_crd_acquired1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_cha \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822691 }, /* unc_cha_ag1_bl_crd_acquired1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_cha \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2822970 }, /* unc_cha_ag1_bl_crd_acquired1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_cha \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 2824601 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr0\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_cha \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2824881 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr1\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_cha \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825161 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr2\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_cha \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825441 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr3\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_cha \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2825721 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr4\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_cha \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826002 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr5\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_cha \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826283 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr6\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_cha \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826564 }, /* unc_cha_ag1_bl_crd_occupancy0.tgr7\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_cha \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2826845 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr10\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_cha \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827128 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr8\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_cha \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2827408 }, /* unc_cha_ag1_bl_crd_occupancy1.tgr9\000uncore_cha\000uncore cache\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_cha \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 2829064 }, /* unc_cha_bypass_cha_imc.intermediate\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Intermediate bypass Taken. Unit: uncore_cha \000event=0x57,umask=0x2\000\00001\000CHA to iMC Bypass : Intermediate bypass Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the intermediate bypass\000 */
{ 2830078 }, /* unc_cha_bypass_cha_imc.not_taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Not Taken. Unit: uncore_cha \000event=0x57,umask=0x4\000\00001\000CHA to iMC Bypass : Not Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that could not take the bypass, and issues a read to memory. Note that transactions that did not take the bypass but did not issue read to memory will not be counted\000 */
{ 2831272 }, /* unc_cha_bypass_cha_imc.taken\000uncore_cha\000uncore cache\000CHA to iMC Bypass : Taken. Unit: uncore_cha \000event=0x57,umask=0x1\000\00001\000CHA to iMC Bypass : Taken : Counts the number of times when the CHA was able to bypass HA pipe on the way to iMC.  This is a latency optimization for situations when there is light loadings on the memory subsystem.  This can be filtered by when the bypass was taken and when it was not. : Filter for transactions that succeeded in taking the full bypass\000 */
{ 2832861 }, /* unc_cha_clockticks\000uncore_cha\000uncore cache\000Uncore cache clock ticks. Unit: uncore_cha \000event=0\000\00001\000\000 */
{ 2832961 }, /* unc_cha_cms_clockticks\000uncore_cha\000uncore cache\000CMS Clockticks. Unit: uncore_cha \000event=0xc0\000\00001\000\000 */
{ 2833673 }, /* unc_cha_core_snp.any_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops. Unit: uncore_cha \000event=0x33,umask=0xf2\000\00001\000Core Cross Snoops Issued : Any Cycle with Multiple Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2835204 }, /* unc_cha_core_snp.any_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Any Single Snoop. Unit: uncore_cha \000event=0x33,umask=0xf1\000\00001\000Core Cross Snoops Issued : Any Single Snoop : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2837419 }, /* unc_cha_core_snp.core_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Core Requests. Unit: uncore_cha \000event=0x33,umask=0x42\000\00001\000Core Cross Snoops Issued : Multiple Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2838928 }, /* unc_cha_core_snp.core_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Core Requests. Unit: uncore_cha \000event=0x33,umask=0x41\000\00001\000Core Cross Snoops Issued : Single Core Requests : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2841161 }, /* unc_cha_core_snp.evict_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple Eviction. Unit: uncore_cha \000event=0x33,umask=0x82\000\00001\000Core Cross Snoops Issued : Multiple Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2842657 }, /* unc_cha_core_snp.evict_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single Eviction. Unit: uncore_cha \000event=0x33,umask=0x81\000\00001\000Core Cross Snoops Issued : Single Eviction : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2844874 }, /* unc_cha_core_snp.ext_gtone\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Multiple External Snoops. Unit: uncore_cha \000event=0x33,umask=0x22\000\00001\000Core Cross Snoops Issued : Multiple External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2846387 }, /* unc_cha_core_snp.ext_one\000uncore_cha\000uncore cache\000Core Cross Snoops Issued : Single External Snoops. Unit: uncore_cha \000event=0x33,umask=0x21\000\00001\000Core Cross Snoops Issued : Single External Snoops : Counts the number of transactions that trigger a configurable number of cross snoops.  Cores are snooped if the transaction looks up the cache and determines that it is necessary based on the operation type and what CoreValid bits are set.  For example, if 2 CV bits are set on a data read, the cores must have the data in S state so it is not necessary to snoop them.  However, if only 1 CV bit is set the core my have modified the data.  If the transaction was an RFO, it would need to invalidate the lines.  This event can be filtered based on who triggered the initial snoop(s)\000 */
{ 2850231 }, /* unc_cha_counter0_occupancy\000uncore_cha\000uncore cache\000Counter 0 Occupancy. Unit: uncore_cha \000event=0x1f\000\00001\000Counter 0 Occupancy : Since occupancy counts can only be captured in the Cbo's 0 counter, this event allows a user to capture occupancy related information by filtering the Cb0 occupancy count captured in Counter 0.   The filtering available is found in the control register - threshold, invert and edge detect.   E.g. setting threshold to 1 can effectively monitor how many cycles the monitored queue has an entry\000 */
{ 2854609 }, /* unc_cha_direct_go.ha_suppress_drd\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x4\000\00001\000\000 */
{ 2854722 }, /* unc_cha_direct_go.ha_suppress_no_d2c\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x2\000\00001\000\000 */
{ 2854838 }, /* unc_cha_direct_go.ha_tor_dealloc\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6e,umask=0x1\000\00001\000\000 */
{ 2854950 }, /* unc_cha_direct_go_opc.extcmp\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x1\000\00001\000\000 */
{ 2855058 }, /* unc_cha_direct_go_opc.fast_go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x10\000\00001\000\000 */
{ 2855168 }, /* unc_cha_direct_go_opc.fast_go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x20\000\00001\000\000 */
{ 2855283 }, /* unc_cha_direct_go_opc.go\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x4\000\00001\000\000 */
{ 2855387 }, /* unc_cha_direct_go_opc.go_pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x8\000\00001\000\000 */
{ 2855496 }, /* unc_cha_direct_go_opc.idle_due_suppress\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x80\000\00001\000\000 */
{ 2855616 }, /* unc_cha_direct_go_opc.nop\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x40\000\00001\000\000 */
{ 2855722 }, /* unc_cha_direct_go_opc.pull\000uncore_cha\000uncore cache\000Direct GO. Unit: uncore_cha \000event=0x6d,umask=0x2\000\00001\000\000 */
{ 2855828 }, /* unc_cha_distress_asserted.dpt_local\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Local. Unit: uncore_cha \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 2856147 }, /* unc_cha_distress_asserted.dpt_nonlocal\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Remote. Unit: uncore_cha \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 2856470 }, /* unc_cha_distress_asserted.dpt_stall_iv\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_cha \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 2856830 }, /* unc_cha_distress_asserted.dpt_stall_nocrd\000uncore_cha\000uncore cache\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_cha \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 2857203 }, /* unc_cha_distress_asserted.horz\000uncore_cha\000uncore cache\000Distress signal asserted : Horizontal. Unit: uncore_cha \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 2858291 }, /* unc_cha_distress_asserted.vert\000uncore_cha\000uncore cache\000Distress signal asserted : Vertical. Unit: uncore_cha \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 2858632 }, /* unc_cha_egress_ordering.iv_snoopgo_dn\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_cha \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2859187 }, /* unc_cha_egress_ordering.iv_snoopgo_up\000uncore_cha\000uncore cache\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_cha \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 2868608 }, /* unc_cha_horz_ring_ad_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2870403 }, /* unc_cha_horz_ring_ad_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2872193 }, /* unc_cha_horz_ring_ad_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2873993 }, /* unc_cha_horz_ring_ad_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2875788 }, /* unc_cha_horz_ring_ak_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2877579 }, /* unc_cha_horz_ring_ak_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2879365 }, /* unc_cha_horz_ring_ak_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2881161 }, /* unc_cha_horz_ring_ak_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2882952 }, /* unc_cha_horz_ring_akc_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_cha \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2883879 }, /* unc_cha_horz_ring_akc_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_cha \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2884803 }, /* unc_cha_horz_ring_akc_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_cha \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2885733 }, /* unc_cha_horz_ring_akc_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_cha \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2886660 }, /* unc_cha_horz_ring_bl_in_use.left_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_cha \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2888453 }, /* unc_cha_horz_ring_bl_in_use.left_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_cha \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2890241 }, /* unc_cha_horz_ring_bl_in_use.right_even\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_cha \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2892039 }, /* unc_cha_horz_ring_bl_in_use.right_odd\000uncore_cha\000uncore cache\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_cha \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 2893832 }, /* unc_cha_horz_ring_iv_in_use.left\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Left. Unit: uncore_cha \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2894982 }, /* unc_cha_horz_ring_iv_in_use.right\000uncore_cha\000uncore cache\000Horizontal IV Ring in Use : Right. Unit: uncore_cha \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 2896137 }, /* unc_cha_imc_reads_count.normal\000uncore_cha\000uncore cache\000Normal priority reads issued to the memory controller from the CHA. Unit: uncore_cha \000event=0x59,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) read is issued to any of the memory controller channels from the CHA\000 */
{ 2896411 }, /* unc_cha_imc_reads_count.priority\000uncore_cha\000uncore cache\000HA to iMC Reads Issued : ISOCH. Unit: uncore_cha \000event=0x59,umask=0x2\000\00001\000HA to iMC Reads Issued : ISOCH : Count of the number of reads issued to any of the memory controller channels.  This can be filtered by the priority of the reads\000 */
{ 2896965 }, /* unc_cha_imc_writes_count.full\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Full Line Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x1\000\00001\000Counts when a normal (Non-Isochronous) full line write is issued from the CHA to any of the memory controller channels\000 */
{ 2897842 }, /* unc_cha_imc_writes_count.full_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Full Line. Unit: uncore_cha \000event=0x5b,umask=0x4\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Full Line : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2898479 }, /* unc_cha_imc_writes_count.partial\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH. Unit: uncore_cha \000event=0x5b,umask=0x2\000\00001\000CHA to iMC Full Line Writes Issued : Partial Non-ISOCH : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2899475 }, /* unc_cha_imc_writes_count.partial_priority\000uncore_cha\000uncore cache\000CHA to iMC Full Line Writes Issued : ISOCH Partial. Unit: uncore_cha \000event=0x5b,umask=0x8\000\00001\000CHA to iMC Full Line Writes Issued : ISOCH Partial : Counts the total number of full line writes issued from the HA into the memory controller\000 */
{ 2901580 }, /* unc_cha_llc_lookup.all\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Any Request. Unit: uncore_cha \000event=0x34,umask=0x1fffff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state.; Filters for any transaction originating from the IPQ or IRQ.  This does not include lookups originating from the ISMQ\000 */
{ 2904238 }, /* unc_cha_llc_lookup.any_f\000uncore_cha\000uncore cache\000Cache Lookups : All Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : All Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local or remote transaction to the LLC, including prefetch\000 */
{ 2906108 }, /* unc_cha_llc_lookup.code\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.CODE_READ. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00011\000\000 */
{ 2906464 }, /* unc_cha_llc_lookup.code_read\000uncore_cha\000uncore cache\000Cache Lookups : Code Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd0ff\000\00001\000Cache Lookups : Code Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2907025 }, /* unc_cha_llc_lookup.code_read_f\000uncore_cha\000uncore cache\000Cache Lookups : CRd Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : CRd Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote CRd transactions to the LLC.  This includes CRd prefetch\000 */
{ 2908989 }, /* unc_cha_llc_lookup.code_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Code Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd001\000\00001\000Cache Lookups : Code Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2911085 }, /* unc_cha_llc_lookup.corepref_or_dmnd_local_f\000uncore_cha\000uncore cache\000Cache Lookups : Local request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Local request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Any local transaction to the LLC, including prefetches from the Core\000 */
{ 2912366 }, /* unc_cha_llc_lookup.data_rd\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00011\000\000 */
{ 2912541 }, /* unc_cha_llc_lookup.data_read\000uncore_cha\000uncore cache\000Cache and Snoop Filter Lookups; Data Read Request. Unit: uncore_cha \000event=0x34,umask=0x1bc1ff\000\00001\000Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing.   CHAFilter0[24:21,17] bits correspond to [FMESI] state. Read transactions\000 */
{ 2914543 }, /* unc_cha_llc_lookup.data_read_all\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x34,umask=0x1fc1ff\000\00011\000\000 */
{ 2914675 }, /* unc_cha_llc_lookup.data_read_f\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Data Read Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Read transactions\000 */
{ 2917171 }, /* unc_cha_llc_lookup.data_read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Data Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc101\000\00001\000Cache Lookups : Data Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2918996 }, /* unc_cha_llc_lookup.dmnd_read_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.DATA_READ_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x841ff\000\00011\000\000 */
{ 2919184 }, /* unc_cha_llc_lookup.e\000uncore_cha\000uncore cache\000Cache Lookups : E State. Unit: uncore_cha \000event=0x34,umask=0x20\000\00001\000Cache Lookups : E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Exclusive State\000 */
{ 2920315 }, /* unc_cha_llc_lookup.f\000uncore_cha\000uncore cache\000Cache Lookups : F State. Unit: uncore_cha \000event=0x34,umask=0x80\000\00001\000Cache Lookups : F State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Forward State\000 */
{ 2921442 }, /* unc_cha_llc_lookup.flush_inv\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Requests. Unit: uncore_cha \000event=0x34,umask=0x1a44ff\000\00001\000Cache Lookups : Flush : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing\000 */
{ 2923256 }, /* unc_cha_llc_lookup.flush_or_inv_f\000uncore_cha\000uncore cache\000Cache Lookups : Flush or Invalidate Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Flush or Invalidate Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2924379 }, /* unc_cha_llc_lookup.i\000uncore_cha\000uncore cache\000Cache Lookups : I State. Unit: uncore_cha \000event=0x34,umask=0x1\000\00001\000Cache Lookups : I State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Miss\000 */
{ 2932368 }, /* unc_cha_llc_lookup.local_f\000uncore_cha\000uncore cache\000Cache Lookups : Transactions homed locally Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Transactions homed locally Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Transaction whose address resides in the local MC\000 */
{ 2939264 }, /* unc_cha_llc_lookup.m\000uncore_cha\000uncore cache\000Cache Lookups : M State. Unit: uncore_cha \000event=0x34,umask=0x40\000\00001\000Cache Lookups : M State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Modified State\000 */
{ 2940393 }, /* unc_cha_llc_lookup.miss_all\000uncore_cha\000uncore cache\000Cache Lookups : All Misses. Unit: uncore_cha \000event=0x34,umask=0x1fe001\000\00001\000Cache Lookups : All Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2941484 }, /* unc_cha_llc_lookup.other_req_f\000uncore_cha\000uncore cache\000Cache Lookups : Write Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : Write Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Writeback transactions to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2944101 }, /* unc_cha_llc_lookup.read\000uncore_cha\000uncore cache\000Cache Lookups : Reads. Unit: uncore_cha \000event=0x34,umask=0x1bd9ff\000\00001\000Cache Lookups : Reads : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2944647 }, /* unc_cha_llc_lookup.read_local_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0x9d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2945288 }, /* unc_cha_llc_lookup.read_local_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally Requested Reads that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x11d9ff\000\00001\000Cache Lookups : Locally Requested Reads that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2945932 }, /* unc_cha_llc_lookup.read_miss\000uncore_cha\000uncore cache\000Cache Lookups : Read Misses. Unit: uncore_cha \000event=0x34,umask=0x1bd901\000\00001\000Cache Lookups : Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2946495 }, /* unc_cha_llc_lookup.read_miss_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Locally HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0xbd901\000\00001\000Cache Lookups : Locally HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2947093 }, /* unc_cha_llc_lookup.read_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely HOMed Read Misses. Unit: uncore_cha \000event=0x34,umask=0x13d901\000\00001\000Cache Lookups : Remotely HOMed Read Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2947694 }, /* unc_cha_llc_lookup.read_or_snoop_remote_miss_rem_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed. Unit: uncore_cha \000event=0x34,umask=0x161901\000\00001\000Cache Lookups : Remotely requested Read or Snoop Misses that are Remotely HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2948385 }, /* unc_cha_llc_lookup.read_remote_loc_hom\000uncore_cha\000uncore cache\000Cache Lookups : Remotely Requested Reads that are Locally HOMed. Unit: uncore_cha \000event=0x34,umask=0xa19ff\000\00001\000Cache Lookups : Remotely Requested Reads that are Locally HOMed : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2949029 }, /* unc_cha_llc_lookup.read_sf_hit\000uncore_cha\000uncore cache\000Cache Lookups : Reads that Hit the Snoop Filter. Unit: uncore_cha \000event=0x34,umask=0x1bd90e\000\00001\000Cache Lookups : Reads that Hit the Snoop Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2959064 }, /* unc_cha_llc_lookup.rfo\000uncore_cha\000uncore cache\000Cache Lookups : RFO Requests. Unit: uncore_cha \000event=0x34,umask=0x1bc8ff\000\00001\000Cache Lookups : RFO Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2959698 }, /* unc_cha_llc_lookup.rfo_f\000uncore_cha\000uncore cache\000Cache Lookups : RFO Request Filter. Unit: uncore_cha \000event=0x34\000\00001\000Cache Lookups : RFO Request Filter : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Local or remote RFO transactions to the LLC.  This includes RFO prefetch\000 */
{ 2962183 }, /* unc_cha_llc_lookup.rfo_miss\000uncore_cha\000uncore cache\000Cache Lookups : RFO Misses. Unit: uncore_cha \000event=0x34,umask=0x1bc801\000\00001\000Cache Lookups : RFO Misses : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing\000 */
{ 2962743 }, /* unc_cha_llc_lookup.rfo_pref_local\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_LLC_LOOKUP.RFO_LOCAL. Unit: uncore_cha \000event=0x34,umask=0x888ff\000\00011\000\000 */
{ 2963596 }, /* unc_cha_llc_lookup.s\000uncore_cha\000uncore cache\000Cache Lookups : S State. Unit: uncore_cha \000event=0x34,umask=0x10\000\00001\000Cache Lookups : S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : Hit Shared State\000 */
{ 2964721 }, /* unc_cha_llc_lookup.sf_e\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - E State. Unit: uncore_cha \000event=0x34,umask=0x4\000\00001\000Cache Lookups : SnoopFilter - E State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Exclusive State\000 */
{ 2965918 }, /* unc_cha_llc_lookup.sf_h\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - H State. Unit: uncore_cha \000event=0x34,umask=0x8\000\00001\000Cache Lookups : SnoopFilter - H State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit HitMe State\000 */
{ 2967107 }, /* unc_cha_llc_lookup.sf_s\000uncore_cha\000uncore cache\000Cache Lookups : SnoopFilter - S State. Unit: uncore_cha \000event=0x34,umask=0x2\000\00001\000Cache Lookups : SnoopFilter - S State : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS select a state or states (in the umask field) to match.  Otherwise, the event will count nothing. : SF Hit Shared State\000 */
{ 2969846 }, /* unc_cha_llc_lookup.write_local\000uncore_cha\000uncore cache\000This event is deprecated. Unit: uncore_cha \000event=0x34,umask=0x842ff\000\00011\000\000 */
{ 2970700 }, /* unc_cha_llc_lookup.writes_and_other\000uncore_cha\000uncore cache\000Cache Lookups : Filters Requests for those that write info into the cache. Unit: uncore_cha \000event=0x34,umask=0x1a42ff\000\00001\000Cache Lookups : Write Requests : Counts the number of times the LLC was accessed - this includes code, data, prefetches and hints coming from L2.  This has numerous filters available.  Note the non-standard filtering equation.  This event will count requests that lookup the cache multiple times with multiple increments.  One must ALWAYS set umask bit 0 and select a state or states to match.  Otherwise, the event will count nothing. : Writeback transactions from L2 to the LLC  This includes all write transactions -- both Cacheable and UC\000 */
{ 2971426 }, /* unc_cha_llc_victims.all\000uncore_cha\000uncore cache\000Lines Victimized : All Lines Victimized. Unit: uncore_cha \000event=0x37,umask=0xf\000\00001\000Lines Victimized : All Lines Victimized : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2971715 }, /* unc_cha_llc_victims.e_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in E state. Unit: uncore_cha \000event=0x37,umask=0x2\000\00001\000Lines Victimized : Lines in E state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2974138 }, /* unc_cha_llc_victims.local_all\000uncore_cha\000uncore cache\000Lines Victimized : Local - All Lines. Unit: uncore_cha \000event=0x37,umask=0x200f\000\00001\000Lines Victimized : Local - All Lines : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2974932 }, /* unc_cha_llc_victims.local_e\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in E State. Unit: uncore_cha \000event=0x37,umask=0x2002\000\00001\000Lines Victimized : Local - Lines in E State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2975996 }, /* unc_cha_llc_victims.local_m\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in M State. Unit: uncore_cha \000event=0x37,umask=0x2001\000\00001\000Lines Victimized : Local - Lines in M State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2976805 }, /* unc_cha_llc_victims.local_only\000uncore_cha\000uncore cache\000Lines Victimized : Local Only. Unit: uncore_cha \000event=0x37\000\00001\000Lines Victimized : Local Only : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977071 }, /* unc_cha_llc_victims.local_s\000uncore_cha\000uncore cache\000Lines Victimized : Local - Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x2004\000\00001\000Lines Victimized : Local - Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2977880 }, /* unc_cha_llc_victims.m_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in M state. Unit: uncore_cha \000event=0x37,umask=0x1\000\00001\000Lines Victimized : Lines in M state : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2982280 }, /* unc_cha_llc_victims.s_state\000uncore_cha\000uncore cache\000Lines Victimized : Lines in S State. Unit: uncore_cha \000event=0x37,umask=0x4\000\00001\000Lines Victimized : Lines in S State : Counts the number of lines that were victimized on a fill.  This can be filtered by the state that the line was in\000 */
{ 2984517 }, /* unc_cha_misc.cv0_pref_miss\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Miss. Unit: uncore_cha \000event=0x39,umask=0x20\000\00001\000Cbo Misc : CV0 Prefetch Miss : Miscellaneous events in the Cbo\000 */
{ 2984861 }, /* unc_cha_misc.cv0_pref_vic\000uncore_cha\000uncore cache\000Cbo Misc : CV0 Prefetch Victim. Unit: uncore_cha \000event=0x39,umask=0x10\000\00001\000Cbo Misc : CV0 Prefetch Victim : Miscellaneous events in the Cbo\000 */
{ 2985209 }, /* unc_cha_misc.rfo_hit_s\000uncore_cha\000uncore cache\000Number of times that an RFO hit in S state. Unit: uncore_cha \000event=0x39,umask=0x8\000\00001\000Counts when a RFO (the Read for Ownership issued before a  write) request hit a cacheline in the S (Shared) state\000 */
{ 2985457 }, /* unc_cha_misc.rspi_was_fse\000uncore_cha\000uncore cache\000Cbo Misc : Silent Snoop Eviction. Unit: uncore_cha \000event=0x39,umask=0x1\000\00001\000Cbo Misc : Silent Snoop Eviction : Miscellaneous events in the Cbo. : Counts the number of times when a Snoop hit in FSE states and triggered a silent eviction.  This is useful because this information is lost in the PRE encodings\000 */
{ 2986136 }, /* unc_cha_misc.wc_aliasing\000uncore_cha\000uncore cache\000Cbo Misc : Write Combining Aliasing. Unit: uncore_cha \000event=0x39,umask=0x2\000\00001\000Cbo Misc : Write Combining Aliasing : Miscellaneous events in the Cbo. : Counts the number of times that a USWC write (WCIL(F)) transaction hit in the LLC in M state, triggering a WBMtoI followed by the USWC write.  This occurs when there is WC aliasing\000 */
{ 2986862 }, /* unc_cha_misc_external.mbe_inst0\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_cha \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 2987048 }, /* unc_cha_misc_external.mbe_inst1\000uncore_cha\000uncore cache\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_cha \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 2989300 }, /* unc_cha_pipe_reject.adegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989455 }, /* unc_cha_pipe_reject.akegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989610 }, /* unc_cha_pipe_reject.allrsfways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989768 }, /* unc_cha_pipe_reject.blegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2989923 }, /* unc_cha_pipe_reject.fsf_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990075 }, /* unc_cha_pipe_reject.gotrack_allowsnp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x4\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990245 }, /* unc_cha_pipe_reject.gotrack_allwayrsv\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x10\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990417 }, /* unc_cha_pipe_reject.gotrack_pamatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x2\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990586 }, /* unc_cha_pipe_reject.gotrack_waymatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x8\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990756 }, /* unc_cha_pipe_reject.hacredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2990908 }, /* unc_cha_pipe_reject.idx_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991062 }, /* unc_cha_pipe_reject.ipq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991385 }, /* unc_cha_pipe_reject.irq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991546 }, /* unc_cha_pipe_reject.ismq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991708 }, /* unc_cha_pipe_reject.ivegrcredit\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2991863 }, /* unc_cha_pipe_reject.llc_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992019 }, /* unc_cha_pipe_reject.notallowsnoop\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992176 }, /* unc_cha_pipe_reject.one_fsf_vic\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992331 }, /* unc_cha_pipe_reject.one_rsp_con\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2992983 }, /* unc_cha_pipe_reject.ptl_inpipe\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x80\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993148 }, /* unc_cha_pipe_reject.rmw_setmatch\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42,umask=0x1\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993314 }, /* unc_cha_pipe_reject.rrq_setmatch_vicp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993475 }, /* unc_cha_pipe_reject.setmatchentrywsct\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993636 }, /* unc_cha_pipe_reject.sf_ways_res\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993791 }, /* unc_cha_pipe_reject.topa_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2993945 }, /* unc_cha_pipe_reject.torid_match_go_p\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994105 }, /* unc_cha_pipe_reject.vn_ad_req\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994258 }, /* unc_cha_pipe_reject.vn_ad_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994411 }, /* unc_cha_pipe_reject.vn_bl_ncb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994564 }, /* unc_cha_pipe_reject.vn_bl_ncs\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994717 }, /* unc_cha_pipe_reject.vn_bl_rsp\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2994870 }, /* unc_cha_pipe_reject.vn_bl_wb\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 2995022 }, /* unc_cha_pipe_reject.way_match\000uncore_cha\000uncore cache\000Pipe Rejects. Unit: uncore_cha \000event=0x42\000\00001\000Pipe Rejects : More Miscellaneous events in the Cbo\000 */
{ 3002566 }, /* unc_cha_read_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC0. Unit: uncore_cha \000event=0x58,umask=0x1\000\00001\000CHA iMC CHNx READ Credits Empty : MC0 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 0 only\000 */
{ 3005144 }, /* unc_cha_read_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC1. Unit: uncore_cha \000event=0x58,umask=0x2\000\00001\000CHA iMC CHNx READ Credits Empty : MC1 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 1 only\000 */
{ 3003412 }, /* unc_cha_read_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC10. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC10 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 10 only\000 */
{ 3003845 }, /* unc_cha_read_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC11. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC11 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 11 only\000 */
{ 3004278 }, /* unc_cha_read_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC12. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC12 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 12 only\000 */
{ 3004711 }, /* unc_cha_read_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC13. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC13 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 13 only\000 */
{ 3005990 }, /* unc_cha_read_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC2. Unit: uncore_cha \000event=0x58,umask=0x4\000\00001\000CHA iMC CHNx READ Credits Empty : MC2 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 2 only\000 */
{ 3006429 }, /* unc_cha_read_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC3. Unit: uncore_cha \000event=0x58,umask=0x8\000\00001\000CHA iMC CHNx READ Credits Empty : MC3 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 3 only\000 */
{ 3006868 }, /* unc_cha_read_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC4. Unit: uncore_cha \000event=0x58,umask=0x10\000\00001\000CHA iMC CHNx READ Credits Empty : MC4 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 4 only\000 */
{ 3007308 }, /* unc_cha_read_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC5. Unit: uncore_cha \000event=0x58,umask=0x20\000\00001\000CHA iMC CHNx READ Credits Empty : MC5 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 5 only\000 */
{ 3007748 }, /* unc_cha_read_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC6. Unit: uncore_cha \000event=0x58,umask=0x40\000\00001\000CHA iMC CHNx READ Credits Empty : MC6 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 6 only\000 */
{ 3008188 }, /* unc_cha_read_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC7. Unit: uncore_cha \000event=0x58,umask=0x80\000\00001\000CHA iMC CHNx READ Credits Empty : MC7 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 7 only\000 */
{ 3008628 }, /* unc_cha_read_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC8. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC8 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 8 only\000 */
{ 3009057 }, /* unc_cha_read_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx READ Credits Empty : MC9. Unit: uncore_cha \000event=0x58\000\00001\000CHA iMC CHNx READ Credits Empty : MC9 : Counts the number of times when there are no credits available for sending reads from the CHA into the iMC.  In order to send reads into the memory controller, the HA must first acquire a credit for the iMC's AD Ingress queue. : Filter for memory controller 9 only\000 */
{ 3009486 }, /* unc_cha_requests.invitoe\000uncore_cha\000uncore cache\000Local INVITOE requests (exclusive ownership of a cache line without receiving data) that miss the SF/LLC and remote INVITOE requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x30\000\00001\000Counts the total number of requests coming from a unit on this socket for exclusive ownership of a cache line without receiving data (INVITOE) to the CHA\000 */
{ 3011964 }, /* unc_cha_requests.reads\000uncore_cha\000uncore cache\000Local read requests that miss the SF/LLC and remote read requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0x3\000\00001\000Counts read requests made into this CHA. Reads include all read opcodes (including RFO: the Read for Ownership issued before a  write) \000 */
{ 3014042 }, /* unc_cha_requests.writes\000uncore_cha\000uncore cache\000Local write requests that miss the SF/LLC and remote write requests sent to the CHA's home agent. Unit: uncore_cha \000event=0x50,umask=0xc\000\00001\000Counts write requests made into the CHA, including streaming, evictions, HitM (Reads from another core to a Modified cacheline), etc\000 */
{ 3016157 }, /* unc_cha_ring_bounces_horz.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_cha \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3016689 }, /* unc_cha_ring_bounces_horz.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_cha \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017221 }, /* unc_cha_ring_bounces_horz.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_cha \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3017753 }, /* unc_cha_ring_bounces_horz.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_cha \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 3018285 }, /* unc_cha_ring_bounces_vert.ad\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_cha \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3018807 }, /* unc_cha_ring_bounces_vert.ak\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_cha \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019395 }, /* unc_cha_ring_bounces_vert.akc\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. Unit: uncore_cha \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3019673 }, /* unc_cha_ring_bounces_vert.bl\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_cha \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020255 }, /* unc_cha_ring_bounces_vert.iv\000uncore_cha\000uncore cache\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_cha \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 3020853 }, /* unc_cha_ring_sink_starved_horz.ad\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_cha \000event=0xad,umask=0x1\000\00001\000\000 */
{ 3021138 }, /* unc_cha_ring_sink_starved_horz.ak\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_cha \000event=0xad,umask=0x2\000\00001\000\000 */
{ 3021423 }, /* unc_cha_ring_sink_starved_horz.ak_ag1\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_cha \000event=0xad,umask=0x20\000\00001\000\000 */
{ 3021768 }, /* unc_cha_ring_sink_starved_horz.bl\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_cha \000event=0xad,umask=0x4\000\00001\000\000 */
{ 3022053 }, /* unc_cha_ring_sink_starved_horz.iv\000uncore_cha\000uncore cache\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_cha \000event=0xad,umask=0x8\000\00001\000\000 */
{ 3022338 }, /* unc_cha_ring_sink_starved_vert.ad\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : AD. Unit: uncore_cha \000event=0xab,umask=0x1\000\00001\000\000 */
{ 3022619 }, /* unc_cha_ring_sink_starved_vert.ak\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_cha \000event=0xab,umask=0x2\000\00001\000\000 */
{ 3022944 }, /* unc_cha_ring_sink_starved_vert.akc\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring. Unit: uncore_cha \000event=0xab,umask=0x10\000\00001\000\000 */
{ 3023082 }, /* unc_cha_ring_sink_starved_vert.bl\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_cha \000event=0xab,umask=0x4\000\00001\000\000 */
{ 3023403 }, /* unc_cha_ring_sink_starved_vert.iv\000uncore_cha\000uncore cache\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_cha \000event=0xab,umask=0x8\000\00001\000\000 */
{ 3023832 }, /* unc_cha_ring_src_thrtl\000uncore_cha\000uncore cache\000Source Throttle. Unit: uncore_cha \000event=0xae\000\00001\000\000 */
{ 3024370 }, /* unc_cha_rxc_inserts.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ. Unit: uncore_cha \000event=0x13,umask=0x1\000\00001\000Ingress (from CMS) Allocations : IRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3024810 }, /* unc_cha_rxc_inserts.irq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : IRQ Rejected. Unit: uncore_cha \000event=0x13,umask=0x2\000\00001\000Ingress (from CMS) Allocations : IRQ Rejected : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025285 }, /* unc_cha_rxc_inserts.prq\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x10\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3025727 }, /* unc_cha_rxc_inserts.prq_rej\000uncore_cha\000uncore cache\000Ingress (from CMS) Allocations : PRQ. Unit: uncore_cha \000event=0x13,umask=0x20\000\00001\000Ingress (from CMS) Allocations : PRQ : Counts number of allocations per cycle into the specified Ingress queue\000 */
{ 3033147 }, /* unc_cha_rxc_irq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x18,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3033568 }, /* unc_cha_rxc_irq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x2\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3033990 }, /* unc_cha_rxc_irq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x18,umask=0x40\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3034415 }, /* unc_cha_rxc_irq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x18,umask=0x10\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3034821 }, /* unc_cha_rxc_irq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x18,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3035227 }, /* unc_cha_rxc_irq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x18,umask=0x4\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3035649 }, /* unc_cha_rxc_irq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x18,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3036067 }, /* unc_cha_rxc_irq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x18,umask=0x80\000\00001\000IRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3036492 }, /* unc_cha_rxc_irq1_reject.allow_snp\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x19,umask=0x40\000\00001\000\000 */
{ 3036809 }, /* unc_cha_rxc_irq1_reject.any0\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x19,umask=0x1\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the IRQ0 Reject counter was true\000 */
{ 3037206 }, /* unc_cha_rxc_irq1_reject.ha\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x19,umask=0x2\000\00001\000\000 */
{ 3037489 }, /* unc_cha_rxc_irq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way. Unit: uncore_cha \000event=0x19,umask=0x20\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : LLC or SF Way : Way conflict with another request that caused the reject\000 */
{ 3037977 }, /* unc_cha_rxc_irq1_reject.llc_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x19,umask=0x4\000\00001\000\000 */
{ 3038292 }, /* unc_cha_rxc_irq1_reject.pa_match\000uncore_cha\000uncore cache\000Ingress (from CMS) Request Queue Rejects; PhyAddr Match. Unit: uncore_cha \000event=0x19,umask=0x80\000\00001\000\000 */
{ 3038451 }, /* unc_cha_rxc_irq1_reject.sf_victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x19,umask=0x8\000\00001\000IRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3038862 }, /* unc_cha_rxc_irq1_reject.victim\000uncore_cha\000uncore cache\000IRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x19,umask=0x10\000\00001\000\000 */
{ 3039163 }, /* unc_cha_rxc_ismq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x24,umask=0x1\000\00001\000ISMQ Rejects - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3040032 }, /* unc_cha_rxc_ismq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x2\000\00001\000ISMQ Rejects - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3040902 }, /* unc_cha_rxc_ismq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x24,umask=0x40\000\00001\000ISMQ Rejects - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3041775 }, /* unc_cha_rxc_ismq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x24,umask=0x10\000\00001\000ISMQ Rejects - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3042629 }, /* unc_cha_rxc_ismq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x24,umask=0x20\000\00001\000ISMQ Rejects - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3043483 }, /* unc_cha_rxc_ismq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x24,umask=0x4\000\00001\000ISMQ Rejects - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3044353 }, /* unc_cha_rxc_ismq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x24,umask=0x8\000\00001\000ISMQ Rejects - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3045219 }, /* unc_cha_rxc_ismq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x24,umask=0x80\000\00001\000ISMQ Rejects - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3046092 }, /* unc_cha_rxc_ismq0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2c,umask=0x1\000\00001\000ISMQ Retries - Set 0 : AD REQ on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a request\000 */
{ 3046959 }, /* unc_cha_rxc_ismq0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x2\000\00001\000ISMQ Retries - Set 0 : AD RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No AD VN0 credit for generating a response\000 */
{ 3047827 }, /* unc_cha_rxc_ismq0_retry.ak_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2c,umask=0x40\000\00001\000ISMQ Retries - Set 0 : Non UPI AK Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject AK ring message\000 */
{ 3048698 }, /* unc_cha_rxc_ismq0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x10\000\00001\000ISMQ Retries - Set 0 : BL NCB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCB\000 */
{ 3049550 }, /* unc_cha_rxc_ismq0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2c,umask=0x20\000\00001\000ISMQ Retries - Set 0 : BL NCS on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for NCS\000 */
{ 3050402 }, /* unc_cha_rxc_ismq0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2c,umask=0x4\000\00001\000ISMQ Retries - Set 0 : BL RSP on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a response\000 */
{ 3051270 }, /* unc_cha_rxc_ismq0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2c,umask=0x8\000\00001\000ISMQ Retries - Set 0 : BL WB on VN0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : No BL VN0 credit for generating a writeback\000 */
{ 3052134 }, /* unc_cha_rxc_ismq0_retry.iv_non_upi\000uncore_cha\000uncore cache\000ISMQ Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2c,umask=0x80\000\00001\000ISMQ Retries - Set 0 : Non UPI IV Request : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Can't inject IV ring message\000 */
{ 3053005 }, /* unc_cha_rxc_ismq1_reject.any0\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : ANY0. Unit: uncore_cha \000event=0x25,umask=0x1\000\00001\000ISMQ Rejects - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3053851 }, /* unc_cha_rxc_ismq1_reject.ha\000uncore_cha\000uncore cache\000ISMQ Rejects - Set 1 : HA. Unit: uncore_cha \000event=0x25,umask=0x2\000\00001\000ISMQ Rejects - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3054626 }, /* unc_cha_rxc_ismq1_retry.any0\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2d,umask=0x1\000\00001\000ISMQ Retries - Set 1 : ANY0 : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores. : Any condition listed in the ISMQ0 Reject counter was true\000 */
{ 3055470 }, /* unc_cha_rxc_ismq1_retry.ha\000uncore_cha\000uncore cache\000ISMQ Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2d,umask=0x2\000\00001\000ISMQ Retries - Set 1 : HA : Number of times a transaction flowing through the ISMQ had to retry.  Transaction pass through the ISMQ as responses for requests that already exist in the Cbo.  Some examples include: when data is returned or when snoop responses come back from the cores\000 */
{ 3056677 }, /* unc_cha_rxc_occupancy.irq\000uncore_cha\000uncore cache\000Ingress (from CMS) Occupancy : IRQ. Unit: uncore_cha \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Occupancy : IRQ : Counts number of entries in the specified Ingress queue in each cycle\000 */
{ 3057983 }, /* unc_cha_rxc_other0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2e,umask=0x1\000\00001\000Other Retries - Set 0 : AD REQ on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a request\000 */
{ 3058590 }, /* unc_cha_rxc_other0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x2\000\00001\000Other Retries - Set 0 : AD RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No AD VN0 credit for generating a response\000 */
{ 3059198 }, /* unc_cha_rxc_other0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2e,umask=0x40\000\00001\000Other Retries - Set 0 : Non UPI AK Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject AK ring message\000 */
{ 3059809 }, /* unc_cha_rxc_other0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x10\000\00001\000Other Retries - Set 0 : BL NCB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCB\000 */
{ 3060401 }, /* unc_cha_rxc_other0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2e,umask=0x20\000\00001\000Other Retries - Set 0 : BL NCS on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for NCS\000 */
{ 3060993 }, /* unc_cha_rxc_other0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2e,umask=0x4\000\00001\000Other Retries - Set 0 : BL RSP on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a response\000 */
{ 3061601 }, /* unc_cha_rxc_other0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Other Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2e,umask=0x8\000\00001\000Other Retries - Set 0 : BL WB on VN0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : No BL VN0 credit for generating a writeback\000 */
{ 3062205 }, /* unc_cha_rxc_other0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Other Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2e,umask=0x80\000\00001\000Other Retries - Set 0 : Non UPI IV Request : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Can't inject IV ring message\000 */
{ 3062816 }, /* unc_cha_rxc_other1_retry.allow_snp\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2f,umask=0x40\000\00001\000Other Retries - Set 1 : Allow Snoop : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3063373 }, /* unc_cha_rxc_other1_retry.any0\000uncore_cha\000uncore cache\000Other Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2f,umask=0x1\000\00001\000Other Retries - Set 1 : ANY0 : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Any condition listed in the Other0 Reject counter was true\000 */
{ 3063958 }, /* unc_cha_rxc_other1_retry.ha\000uncore_cha\000uncore cache\000Other Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2f,umask=0x2\000\00001\000Other Retries - Set 1 : HA : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3064472 }, /* unc_cha_rxc_other1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2f,umask=0x20\000\00001\000Other Retries - Set 1 : LLC OR SF Way : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Way conflict with another request that caused the reject\000 */
{ 3065146 }, /* unc_cha_rxc_other1_retry.llc_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2f,umask=0x4\000\00001\000Other Retries - Set 1 : LLC Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3065700 }, /* unc_cha_rxc_other1_retry.pa_match\000uncore_cha\000uncore cache\000Other Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2f,umask=0x80\000\00001\000Other Retries - Set 1 : PhyAddr Match : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Address match with an outstanding request that was rejected\000 */
{ 3066323 }, /* unc_cha_rxc_other1_retry.sf_victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2f,umask=0x8\000\00001\000Other Retries - Set 1 : SF Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject) : Requests did not generate Snoop filter victim\000 */
{ 3066920 }, /* unc_cha_rxc_other1_retry.victim\000uncore_cha\000uncore cache\000Other Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2f,umask=0x10\000\00001\000Other Retries - Set 1 : Victim : Retry Queue Inserts of Transactions that were already in another Retry Q (sub-events encode the reason for the next reject)\000 */
{ 3067616 }, /* unc_cha_rxc_prq0_reject.ad_req_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x20,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD REQ on VN0 : No AD VN0 credit for generating a request\000 */
{ 3068037 }, /* unc_cha_rxc_prq0_reject.ad_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x2\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : AD RSP on VN0 : No AD VN0 credit for generating a response\000 */
{ 3068465 }, /* unc_cha_rxc_prq0_reject.ak_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x20,umask=0x40\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI AK Request : Can't inject AK ring message\000 */
{ 3068885 }, /* unc_cha_rxc_prq0_reject.bl_ncb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x20,umask=0x10\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCB on VN0 : No BL VN0 credit for NCB\000 */
{ 3069291 }, /* unc_cha_rxc_prq0_reject.bl_ncs_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x20,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL NCS on VN0 : No BL VN0 credit for NCS\000 */
{ 3069696 }, /* unc_cha_rxc_prq0_reject.bl_rsp_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x20,umask=0x4\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL RSP on VN0 : No BL VN0 credit for generating a response\000 */
{ 3070116 }, /* unc_cha_rxc_prq0_reject.bl_wb_vn0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x20,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : BL WB on VN0 : No BL VN0 credit for generating a writeback\000 */
{ 3070542 }, /* unc_cha_rxc_prq0_reject.iv_non_upi\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x20,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 0 : Non UPI IV Request : Can't inject IV ring message\000 */
{ 3070959 }, /* unc_cha_rxc_prq1_reject.allow_snp\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x21,umask=0x40\000\00001\000\000 */
{ 3071263 }, /* unc_cha_rxc_prq1_reject.any0\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0. Unit: uncore_cha \000event=0x21,umask=0x1\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : ANY0 : Any condition listed in the PRQ0 Reject counter was true\000 */
{ 3071656 }, /* unc_cha_rxc_prq1_reject.ha\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : HA. Unit: uncore_cha \000event=0x21,umask=0x2\000\00001\000\000 */
{ 3071962 }, /* unc_cha_rxc_prq1_reject.llc_or_sf_way\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x21,umask=0x20\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : LLC OR SF Way : Way conflict with another request that caused the reject\000 */
{ 3072399 }, /* unc_cha_rxc_prq1_reject.llc_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x21,umask=0x4\000\00001\000\000 */
{ 3072716 }, /* unc_cha_rxc_prq1_reject.pa_match\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x21,umask=0x80\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : PhyAddr Match : Address match with an outstanding request that was rejected\000 */
{ 3073149 }, /* unc_cha_rxc_prq1_reject.sf_victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim. Unit: uncore_cha \000event=0x21,umask=0x8\000\00001\000PRQ Requests (from CMS) Rejected - Set 1 : SF Victim : Requests did not generate Snoop filter victim\000 */
{ 3073555 }, /* unc_cha_rxc_prq1_reject.victim\000uncore_cha\000uncore cache\000PRQ Requests (from CMS) Rejected - Set 1 : Victim. Unit: uncore_cha \000event=0x21,umask=0x10\000\00001\000\000 */
{ 3073706 }, /* unc_cha_rxc_req_q0_retry.ad_req_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD REQ on VN0. Unit: uncore_cha \000event=0x2a,umask=0x1\000\00001\000Request Queue Retries - Set 0 : AD REQ on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a request\000 */
{ 3074235 }, /* unc_cha_rxc_req_q0_retry.ad_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : AD RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x2\000\00001\000Request Queue Retries - Set 0 : AD RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No AD VN0 credit for generating a response\000 */
{ 3074765 }, /* unc_cha_rxc_req_q0_retry.ak_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI AK Request. Unit: uncore_cha \000event=0x2a,umask=0x40\000\00001\000Request Queue Retries - Set 0 : Non UPI AK Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject AK ring message\000 */
{ 3075298 }, /* unc_cha_rxc_req_q0_retry.bl_ncb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x10\000\00001\000Request Queue Retries - Set 0 : BL NCB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCB\000 */
{ 3075812 }, /* unc_cha_rxc_req_q0_retry.bl_ncs_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL NCS on VN0. Unit: uncore_cha \000event=0x2a,umask=0x20\000\00001\000Request Queue Retries - Set 0 : BL NCS on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for NCS\000 */
{ 3076326 }, /* unc_cha_rxc_req_q0_retry.bl_rsp_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL RSP on VN0. Unit: uncore_cha \000event=0x2a,umask=0x4\000\00001\000Request Queue Retries - Set 0 : BL RSP on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a response\000 */
{ 3076856 }, /* unc_cha_rxc_req_q0_retry.bl_wb_vn0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : BL WB on VN0. Unit: uncore_cha \000event=0x2a,umask=0x8\000\00001\000Request Queue Retries - Set 0 : BL WB on VN0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : No BL VN0 credit for generating a writeback\000 */
{ 3077382 }, /* unc_cha_rxc_req_q0_retry.iv_non_upi\000uncore_cha\000uncore cache\000Request Queue Retries - Set 0 : Non UPI IV Request. Unit: uncore_cha \000event=0x2a,umask=0x80\000\00001\000Request Queue Retries - Set 0 : Non UPI IV Request : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Can't inject IV ring message\000 */
{ 3077915 }, /* unc_cha_rxc_req_q1_retry.allow_snp\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Allow Snoop. Unit: uncore_cha \000event=0x2b,umask=0x40\000\00001\000Request Queue Retries - Set 1 : Allow Snoop : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3078394 }, /* unc_cha_rxc_req_q1_retry.any0\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : ANY0. Unit: uncore_cha \000event=0x2b,umask=0x1\000\00001\000Request Queue Retries - Set 1 : ANY0 : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Any condition listed in the WBQ0 Reject counter was true\000 */
{ 3078899 }, /* unc_cha_rxc_req_q1_retry.ha\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : HA. Unit: uncore_cha \000event=0x2b,umask=0x2\000\00001\000Request Queue Retries - Set 1 : HA : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3079335 }, /* unc_cha_rxc_req_q1_retry.llc_or_sf_way\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC OR SF Way. Unit: uncore_cha \000event=0x2b,umask=0x20\000\00001\000Request Queue Retries - Set 1 : LLC OR SF Way : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Way conflict with another request that caused the reject\000 */
{ 3079931 }, /* unc_cha_rxc_req_q1_retry.llc_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : LLC Victim. Unit: uncore_cha \000event=0x2b,umask=0x4\000\00001\000Request Queue Retries - Set 1 : LLC Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3080407 }, /* unc_cha_rxc_req_q1_retry.pa_match\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : PhyAddr Match. Unit: uncore_cha \000event=0x2b,umask=0x80\000\00001\000Request Queue Retries - Set 1 : PhyAddr Match : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Address match with an outstanding request that was rejected\000 */
{ 3080952 }, /* unc_cha_rxc_req_q1_retry.sf_victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : SF Victim. Unit: uncore_cha \000event=0x2b,umask=0x8\000\00001\000Request Queue Retries - Set 1 : SF Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ) : Requests did not generate Snoop filter victim\000 */
{ 3081471 }, /* unc_cha_rxc_req_q1_retry.victim\000uncore_cha\000uncore cache\000Request Queue Retries - Set 1 : Victim. Unit: uncore_cha \000event=0x2b,umask=0x10\000\00001\000Request Queue Retries - Set 1 : Victim : REQUESTQ includes:  IRQ, PRQ, IPQ, RRQ, WBQ (everything except for ISMQ)\000 */
{ 3098335 }, /* unc_cha_rxr_busy_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 3099178 }, /* unc_cha_rxr_busy_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100001 }, /* unc_cha_rxr_busy_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3100444 }, /* unc_cha_rxr_busy_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 3101287 }, /* unc_cha_rxr_busy_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102110 }, /* unc_cha_rxr_busy_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 3102553 }, /* unc_cha_rxr_bypass.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - All. Unit: uncore_cha \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 3102976 }, /* unc_cha_rxr_bypass.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_cha \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 3103379 }, /* unc_cha_rxr_bypass.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3103609 }, /* unc_cha_rxr_bypass.ak\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AK. Unit: uncore_cha \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 3103984 }, /* unc_cha_rxr_bypass.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3104218 }, /* unc_cha_rxr_bypass.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - All. Unit: uncore_cha \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 3104641 }, /* unc_cha_rxr_bypass.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_cha \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 3105044 }, /* unc_cha_rxr_bypass.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_cha \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 3105274 }, /* unc_cha_rxr_bypass.iv\000uncore_cha\000uncore cache\000Transgress Ingress Bypass : IV. Unit: uncore_cha \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 3105649 }, /* unc_cha_rxr_crd_starved.ad_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 3106515 }, /* unc_cha_rxr_crd_starved.ad_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Credited. Unit: uncore_cha \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3107360 }, /* unc_cha_rxr_crd_starved.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3107814 }, /* unc_cha_rxr_crd_starved.ak\000uncore_cha\000uncore cache\000Transgress Injection Starvation : AK. Unit: uncore_cha \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3108631 }, /* unc_cha_rxr_crd_starved.bl_all\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 3109497 }, /* unc_cha_rxr_crd_starved.bl_crd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Credited. Unit: uncore_cha \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3110342 }, /* unc_cha_rxr_crd_starved.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3110796 }, /* unc_cha_rxr_crd_starved.ifv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_cha \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3111638 }, /* unc_cha_rxr_crd_starved.iv\000uncore_cha\000uncore cache\000Transgress Injection Starvation : IV. Unit: uncore_cha \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112455 }, /* unc_cha_rxr_crd_starved_1\000uncore_cha\000uncore cache\000Transgress Injection Starvation. Unit: uncore_cha \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 3112856 }, /* unc_cha_rxr_inserts.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - All. Unit: uncore_cha \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3113424 }, /* unc_cha_rxr_inserts.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_cha \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3113972 }, /* unc_cha_rxr_inserts.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114277 }, /* unc_cha_rxr_inserts.ak\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AK. Unit: uncore_cha \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3114797 }, /* unc_cha_rxr_inserts.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3115106 }, /* unc_cha_rxr_inserts.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - All. Unit: uncore_cha \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3115674 }, /* unc_cha_rxr_inserts.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_cha \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116222 }, /* unc_cha_rxr_inserts.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_cha \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3116527 }, /* unc_cha_rxr_inserts.iv\000uncore_cha\000uncore cache\000Transgress Ingress Allocations : IV. Unit: uncore_cha \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 3117047 }, /* unc_cha_rxr_occupancy.ad_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - All. Unit: uncore_cha \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3117629 }, /* unc_cha_rxr_occupancy.ad_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118191 }, /* unc_cha_rxr_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3118502 }, /* unc_cha_rxr_occupancy.ak\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AK. Unit: uncore_cha \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119036 }, /* unc_cha_rxr_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3119351 }, /* unc_cha_rxr_occupancy.bl_all\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - All. Unit: uncore_cha \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 3119933 }, /* unc_cha_rxr_occupancy.bl_crd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120495 }, /* unc_cha_rxr_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3120806 }, /* unc_cha_rxr_occupancy.iv\000uncore_cha\000uncore cache\000Transgress Ingress Occupancy : IV. Unit: uncore_cha \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 3121811 }, /* unc_cha_sf_eviction.e_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for E-state entries. Unit: uncore_cha \000event=0x3d,umask=0x2\000\00001\000Counts snoop filter capacity evictions for entries tracking exclusive lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3122756 }, /* unc_cha_sf_eviction.m_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for M-state entries. Unit: uncore_cha \000event=0x3d,umask=0x1\000\00001\000Counts snoop filter capacity evictions for entries tracking modified lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3123698 }, /* unc_cha_sf_eviction.s_state\000uncore_cha\000uncore cache\000Snoop filter capacity evictions for S-state entries. Unit: uncore_cha \000event=0x3d,umask=0x4\000\00001\000Counts snoop filter capacity evictions for entries tracking shared lines in the cores? cache.? Snoop filter capacity evictions occur when the snoop filter is full and evicts an existing entry to track a new entry.? Does not count clean evictions such as when a core?s cache replaces a tracked cacheline with a new cacheline\000 */
{ 3135401 }, /* unc_cha_snoop_resp_local.rspcnflct\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspCnflct. Unit: uncore_cha \000event=0x5d,umask=0x40\000\00001\000Snoop Responses Received Local : RspCnflct : Number of snoop responses received for a Local  request : Filters for snoops responses of RspConflict to local CA requests.  This is returned when a snoop finds an existing outstanding transaction in a remote caching agent when it CAMs that caching agent.  This triggers conflict resolution hardware.  This covers both RspCnflct and RspCnflctWbI\000 */
{ 3136430 }, /* unc_cha_snoop_resp_local.rspfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspFwd. Unit: uncore_cha \000event=0x5d,umask=0x80\000\00001\000Snoop Responses Received Local : RspFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspFwd to local CA requests.  This snoop response is only possible for RdCur when a snoop HITM/E in a remote caching agent and it directly forwards data to a requestor without changing the requestor's cache line state\000 */
{ 3137368 }, /* unc_cha_snoop_resp_local.rspfwdwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*FWD*WB. Unit: uncore_cha \000event=0x5d,umask=0x20\000\00001\000Snoop Responses Received Local : Rsp*FWD*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of Rsp*Fwd*WB to local CA requests.  This snoop response is only used in 4s systems.  It is used when a snoop HITM's in a remote caching agent and it directly forwards data to a requestor, and simultaneously returns data to the home to be written back to memory\000 */
{ 3137910 }, /* unc_cha_snoop_resp_local.rspi\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspI. Unit: uncore_cha \000event=0x5d,umask=0x1\000\00001\000Snoop Responses Received Local : RspI : Number of snoop responses received for a Local  request : Filters for snoops responses of RspI to local CA requests.  RspI is returned when the remote cache does not have the data, or when the remote cache silently evicts data (such as when an RFO hits non-modified data)\000 */
{ 3138764 }, /* unc_cha_snoop_resp_local.rspifwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspIFwd. Unit: uncore_cha \000event=0x5d,umask=0x4\000\00001\000Snoop Responses Received Local : RspIFwd : Number of snoop responses received for a Local  request : Filters for snoop responses of RspIFwd to local CA requests.  This is returned when a remote caching agent forwards data and the requesting agent is able to acquire the data in E or M states.  This is commonly returned with RFO transactions.  It can be either a HitM or a HitFE\000 */
{ 3139761 }, /* unc_cha_snoop_resp_local.rsps\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspS. Unit: uncore_cha \000event=0x5d,umask=0x2\000\00001\000Snoop Responses Received Local : RspS : Number of snoop responses received for a Local  request : Filters for snoop responses of RspS to local CA requests.  RspS is returned when a remote cache has data but is not forwarding it.  It is a way to let the requesting socket know that it cannot allocate the data in E state.  No data is sent with S RspS\000 */
{ 3141174 }, /* unc_cha_snoop_resp_local.rspsfwd\000uncore_cha\000uncore cache\000Snoop Responses Received Local : RspSFwd. Unit: uncore_cha \000event=0x5d,umask=0x8\000\00001\000Snoop Responses Received Local : RspSFwd : Number of snoop responses received for a Local  request : Filters for a snoop response of RspSFwd to local CA requests.  This is returned when a remote caching agent forwards data but holds on to its currently copy.  This is common for data and code reads that hit in a remote socket in E or F state\000 */
{ 3142097 }, /* unc_cha_snoop_resp_local.rspwb\000uncore_cha\000uncore cache\000Snoop Responses Received Local : Rsp*WB. Unit: uncore_cha \000event=0x5d,umask=0x10\000\00001\000Snoop Responses Received Local : Rsp*WB : Number of snoop responses received for a Local  request : Filters for a snoop response of RspIWB or RspSWB to local CA requests.  This is returned when a non-RFO request hits in M state.  Data and Code Reads can return either RspIWB or RspSWB depending on how the system has been configured.  InvItoE transactions will also return RspIWB because they must acquire ownership\000 */
{ 3142653 }, /* unc_cha_snoop_rsp_misc.mtoi_rspdatam\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIDataM. Unit: uncore_cha \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 3142806 }, /* unc_cha_snoop_rsp_misc.mtoi_rspifwdm\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : MtoI RspIFwdM. Unit: uncore_cha \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 3142958 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x20\000\00001\000\000 */
{ 3143130 }, /* unc_cha_snoop_rsp_misc.pulldataptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : Pull Data Partial - Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x10\000\00001\000\000 */
{ 3143300 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitllc\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit LLC. Unit: uncore_cha \000event=0x6b,umask=0x8\000\00001\000\000 */
{ 3143462 }, /* unc_cha_snoop_rsp_misc.rspifwdmptl_hitsf\000uncore_cha\000uncore cache\000Misc Snoop Responses Received : RspIFwdPtl Hit SF. Unit: uncore_cha \000event=0x6b,umask=0x4\000\00001\000\000 */
{ 3143622 }, /* unc_cha_snoops_sent.all\000uncore_cha\000uncore cache\000Snoops Sent : All. Unit: uncore_cha \000event=0x51,umask=0x1\000\00001\000Snoops Sent : All : Counts the number of snoops issued by the HA\000 */
{ 3144316 }, /* unc_cha_snoops_sent.bcst_local\000uncore_cha\000uncore cache\000Snoops Sent : Broadcast snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x10\000\00001\000Snoops Sent : Broadcast snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast snoops issued by the HA responding to local requests\000 */
{ 3145985 }, /* unc_cha_snoops_sent.direct_local\000uncore_cha\000uncore cache\000Snoops Sent : Directed snoops for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x40\000\00001\000Snoops Sent : Directed snoops for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of directed snoops issued by the HA responding to local requests\000 */
{ 3148442 }, /* unc_cha_snoops_sent.local\000uncore_cha\000uncore cache\000Snoops Sent : Snoops sent for Local Requests. Unit: uncore_cha \000event=0x51,umask=0x4\000\00001\000Snoops Sent : Snoops sent for Local Requests : Counts the number of snoops issued by the HA. : Counts the number of broadcast or directed snoops issued by the HA responding to local requests\000 */
{ 3150237 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3150588 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3150939 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151290 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151641 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3151993 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3152345 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3152697 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153049 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153400 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3153751 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154102 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154453 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3154805 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155157 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155509 }, /* unc_cha_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3155861 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156212 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156563 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3156914 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157265 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157617 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3157969 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3158321 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3158673 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_cha \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159024 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_cha \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159375 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_cha \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3159726 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_cha \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160077 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_cha \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160429 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_cha \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3160781 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_cha \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161133 }, /* unc_cha_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_cha \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161485 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3161839 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162190 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162541 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3162897 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163250 }, /* unc_cha_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163603 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3163959 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3164312 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3164665 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_cha \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3165021 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_cha \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3165374 }, /* unc_cha_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_cha\000uncore cache\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_cha \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 3172623 }, /* unc_cha_tor_inserts.all\000uncore_cha\000uncore cache\000TOR Inserts : All. Unit: uncore_cha \000event=0x35,umask=0xc001ffff\000\00001\000TOR Inserts : All : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3174601 }, /* unc_cha_tor_inserts.ddr\000uncore_cha\000uncore cache\000TOR Inserts : DDR4 Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : DDR4 Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3174198 }, /* unc_cha_tor_inserts.ddr4\000uncore_cha\000uncore cache\000This event is deprecated. Refer to new event UNC_CHA_TOR_INSERTS.DDR. Unit: uncore_cha \000event=0x35\000\00011\000\000 */
{ 3174923 }, /* unc_cha_tor_inserts.evict\000uncore_cha\000uncore cache\000TOR Inserts : SF/LLC Evictions. Unit: uncore_cha \000event=0x35,umask=0x2\000\00001\000TOR Inserts : SF/LLC Evictions : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3176020 }, /* unc_cha_tor_inserts.hit\000uncore_cha\000uncore cache\000TOR Inserts : Just Hits. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Hits : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3176970 }, /* unc_cha_tor_inserts.ia\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc001ff01\000\00001\000TOR Inserts : All requests from iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3177916 }, /* unc_cha_tor_inserts.ia_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8c7ff01\000\00001\000TOR Inserts : CLFlushes issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3178602 }, /* unc_cha_tor_inserts.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8d7ff01\000\00001\000TOR Inserts : CLFlushOpts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3179304 }, /* unc_cha_tor_inserts.ia_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc80fff01\000\00001\000TOR Inserts : CRDs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3179872 }, /* unc_cha_tor_inserts.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts; CRd Pref from local IA. Unit: uncore_cha \000event=0x35,umask=0xc88fff01\000\00001\000TOR Inserts; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3180661 }, /* unc_cha_tor_inserts.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc827ff01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3181253 }, /* unc_cha_tor_inserts.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc8a7ff01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3182481 }, /* unc_cha_tor_inserts.ia_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc837ff01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3182877 }, /* unc_cha_tor_inserts.ia_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd01\000\00001\000TOR Inserts : All requests from iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3184191 }, /* unc_cha_tor_inserts.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffd01\000\00001\000TOR Inserts : CRds issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3184804 }, /* unc_cha_tor_inserts.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffd01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3186850 }, /* unc_cha_tor_inserts.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fd01\000\00001\000TOR Inserts : DRd_Opts issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3187487 }, /* unc_cha_tor_inserts.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fd01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3188805 }, /* unc_cha_tor_inserts.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fd01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to page walks that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3193584 }, /* unc_cha_tor_inserts.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fd01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3194206 }, /* unc_cha_tor_inserts.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fd01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3198938 }, /* unc_cha_tor_inserts.ia_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe01\000\00001\000TOR Inserts : All requests from iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3200158 }, /* unc_cha_tor_inserts.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Inserts : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc80ffe01\000\00001\000TOR Inserts : CRds issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3201633 }, /* unc_cha_tor_inserts.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc88ffe01\000\00001\000TOR Inserts : CRd_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3210197 }, /* unc_cha_tor_inserts.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc827fe01\000\00001\000TOR Inserts : DRd_Opt issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3211036 }, /* unc_cha_tor_inserts.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8a7fe01\000\00001\000TOR Inserts : DRd_Opt_Prefs issued by iA Cores that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3223021 }, /* unc_cha_tor_inserts.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Inserts : DRd PTEs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc837fe01\000\00001\000TOR Inserts : DRd PTEs issued by iA Cores due to a page walk that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3223462 }, /* unc_cha_tor_inserts.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiLF misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3233995 }, /* unc_cha_tor_inserts.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Inserts; WCiL misses from local IA. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts; Data read from local IA that misses in the snoop filter\000 */
{ 3240295 }, /* unc_cha_tor_inserts.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc807fe01\000\00001\000TOR Inserts : RFOs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3242000 }, /* unc_cha_tor_inserts.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc887fe01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3246221 }, /* unc_cha_tor_inserts.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc877de01\000\00001\000TOR Inserts : UCRdFs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3246983 }, /* unc_cha_tor_inserts.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc86ffe01\000\00001\000TOR Inserts : WCiLs issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3249385 }, /* unc_cha_tor_inserts.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc867fe01\000\00001\000TOR Inserts : WCiLF issued by iA Cores that Missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3251791 }, /* unc_cha_tor_inserts.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Inserts : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x35,umask=0xc87fde01\000\00001\000TOR Inserts : WiLs issued by iA Cores that Missed LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3252194 }, /* unc_cha_tor_inserts.ia_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc807ff01\000\00001\000TOR Inserts : RFOs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3252771 }, /* unc_cha_tor_inserts.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Inserts : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc887ff01\000\00001\000TOR Inserts : RFO_Prefs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3254072 }, /* unc_cha_tor_inserts.ia_wbeftoe\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc3fff01\000\00001\000WbEFtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3254916 }, /* unc_cha_tor_inserts.ia_wbeftoi\000uncore_cha\000uncore cache\000TOR Inserts : WBEFtoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc37ff01\000\00001\000WbEFtoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3255759 }, /* unc_cha_tor_inserts.ia_wbmtoe\000uncore_cha\000uncore cache\000TOR Inserts : WBMtoEs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc2fff01\000\00001\000WbMtoEs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3256178 }, /* unc_cha_tor_inserts.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by an iA Cores. Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc27ff01\000\00001\000WbMtoIs issued by iA Cores .  (Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3257010 }, /* unc_cha_tor_inserts.ia_wbstoi\000uncore_cha\000uncore cache\000TOR Inserts : WBStoIs issued by an IA Core.  Non Modified Write Backs. Unit: uncore_cha \000event=0x35,umask=0xcc67ff01\000\00001\000WbStoIs issued by iA Cores .  (Non Modified Write Backs)  :Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.  Does not include addressless requests such as locks and interrupts\000 */
{ 3257757 }, /* unc_cha_tor_inserts.ia_wcil\000uncore_cha\000uncore cache\000TOR Inserts : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc86fff01\000\00001\000TOR Inserts : WCiLs issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3258455 }, /* unc_cha_tor_inserts.ia_wcilf\000uncore_cha\000uncore cache\000TOR Inserts : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x35,umask=0xc867ff01\000\00001\000TOR Inserts : WCiLF issued by iA Cores : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3258825 }, /* unc_cha_tor_inserts.io\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc001ff04\000\00001\000TOR Inserts : All requests from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3260123 }, /* unc_cha_tor_inserts.io_clflush\000uncore_cha\000uncore cache\000TOR Inserts : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8c3ff04\000\00001\000TOR Inserts : CLFlushes issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3260507 }, /* unc_cha_tor_inserts.io_hit\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fd04\000\00001\000TOR Inserts : All requests from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3261481 }, /* unc_cha_tor_inserts.io_hit_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fd04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that Hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3262222 }, /* unc_cha_tor_inserts.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fd04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3262724 }, /* unc_cha_tor_inserts.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fd04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3263558 }, /* unc_cha_tor_inserts.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fd04\000\00001\000TOR Inserts : RFOs issued by IO Devices that hit the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3264294 }, /* unc_cha_tor_inserts.io_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc43ff04\000\00001\000TOR Inserts : ItoMs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3265669 }, /* unc_cha_tor_inserts.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcd43ff04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3267403 }, /* unc_cha_tor_inserts.io_miss\000uncore_cha\000uncore cache\000TOR Inserts : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc001fe04\000\00001\000TOR Inserts : All requests from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3268390 }, /* unc_cha_tor_inserts.io_miss_itom\000uncore_cha\000uncore cache\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcc43fe04\000\00001\000TOR Inserts : ItoMs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3269528 }, /* unc_cha_tor_inserts.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xcd43fe04\000\00001\000TOR Inserts : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3270037 }, /* unc_cha_tor_inserts.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc8f3fe04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3271240 }, /* unc_cha_tor_inserts.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x35,umask=0xc803fe04\000\00001\000TOR Inserts : RFOs issued by IO Devices that missed the LLC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3272431 }, /* unc_cha_tor_inserts.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Inserts : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc8f3ff04\000\00001\000TOR Inserts : PCIRdCurs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3273016 }, /* unc_cha_tor_inserts.io_rfo\000uncore_cha\000uncore cache\000TOR Inserts : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xc803ff04\000\00001\000TOR Inserts : RFOs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3274081 }, /* unc_cha_tor_inserts.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Inserts : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x35,umask=0xcc23ff04\000\00001\000TOR Inserts : WbMtoIs issued by IO Devices : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3275719 }, /* unc_cha_tor_inserts.irq_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - iA. Unit: uncore_cha \000event=0x35,umask=0x1\000\00001\000TOR Inserts : IRQ - iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From an iA Core\000 */
{ 3276345 }, /* unc_cha_tor_inserts.irq_non_ia\000uncore_cha\000uncore cache\000TOR Inserts : IRQ - Non iA. Unit: uncore_cha \000event=0x35,umask=0x10\000\00001\000TOR Inserts : IRQ - Non iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3276959 }, /* unc_cha_tor_inserts.isoc\000uncore_cha\000uncore cache\000TOR Inserts : Just ISOC. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just ISOC : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3277527 }, /* unc_cha_tor_inserts.loc_all\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA and IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff05\000\00001\000TOR Inserts : All from Local iA and IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000 */
{ 3278386 }, /* unc_cha_tor_inserts.loc_ia\000uncore_cha\000uncore cache\000TOR Inserts : All from Local iA. Unit: uncore_cha \000event=0x35,umask=0xc000ff01\000\00001\000TOR Inserts : All from Local iA : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000 */
{ 3279120 }, /* unc_cha_tor_inserts.loc_io\000uncore_cha\000uncore cache\000TOR Inserts : All from Local IO. Unit: uncore_cha \000event=0x35,umask=0xc000ff04\000\00001\000TOR Inserts : All from Local IO : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000 */
{ 3279830 }, /* unc_cha_tor_inserts.local_tgt\000uncore_cha\000uncore cache\000TOR Inserts : Just Local Targets. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Local Targets : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3280444 }, /* unc_cha_tor_inserts.match_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3281210 }, /* unc_cha_tor_inserts.miss\000uncore_cha\000uncore cache\000TOR Inserts : Just Misses. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just Misses : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3282517 }, /* unc_cha_tor_inserts.mmcfg\000uncore_cha\000uncore cache\000TOR Inserts : MMCFG Access. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : MMCFG Access : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3283352 }, /* unc_cha_tor_inserts.nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3283938 }, /* unc_cha_tor_inserts.noncoh\000uncore_cha\000uncore cache\000TOR Inserts : Just NonCoherent. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NonCoherent : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3284538 }, /* unc_cha_tor_inserts.not_nearmem\000uncore_cha\000uncore cache\000TOR Inserts : Just NotNearMem. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Just NotNearMem : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3285713 }, /* unc_cha_tor_inserts.premorph_opc\000uncore_cha\000uncore cache\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x35\000\00001\000TOR Inserts : Match the PreMorphed Opcode in b[29:19] of the extended umask field : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3286754 }, /* unc_cha_tor_inserts.prq_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - IOSF. Unit: uncore_cha \000event=0x35,umask=0x4\000\00001\000TOR Inserts : PRQ - IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000 */
{ 3287398 }, /* unc_cha_tor_inserts.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Inserts : PRQ - Non IOSF. Unit: uncore_cha \000event=0x35,umask=0x20\000\00001\000TOR Inserts : PRQ - Non IOSF : Counts the number of entries successfully inserted into the TOR that match qualifications specified by the subevent.   Does not include addressless requests such as locks and interrupts\000 */
{ 3293484 }, /* unc_cha_tor_occupancy.ddr\000uncore_cha\000uncore cache\000TOR Occupancy : DDR4 Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : DDR4 Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3293828 }, /* unc_cha_tor_occupancy.evict\000uncore_cha\000uncore cache\000TOR Occupancy : SF/LLC Evictions. Unit: uncore_cha \000event=0x36,umask=0x2\000\00001\000TOR Occupancy : SF/LLC Evictions : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : TOR allocation occurred as a result of SF/LLC evictions (came from the ISMQ)\000 */
{ 3294993 }, /* unc_cha_tor_occupancy.hit\000uncore_cha\000uncore cache\000TOR Occupancy : Just Hits. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Hits : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3296012 }, /* unc_cha_tor_occupancy.ia\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc001ff01\000\00001\000TOR Occupancy : All requests from iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297090 }, /* unc_cha_tor_occupancy.ia_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8c7ff01\000\00001\000TOR Occupancy : CLFlushes issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297492 }, /* unc_cha_tor_occupancy.ia_clflushopt\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushOpts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8d7ff01\000\00001\000TOR Occupancy : CLFlushOpts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3297901 }, /* unc_cha_tor_occupancy.ia_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRDs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc80fff01\000\00001\000TOR Occupancy : CRDs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3298497 }, /* unc_cha_tor_occupancy.ia_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy; CRd Pref from local IA. Unit: uncore_cha \000event=0x36,umask=0xc88fff01\000\00001\000TOR Occupancy; Code read prefetch from local IA that misses in the snoop filter\000 */
{ 3299320 }, /* unc_cha_tor_occupancy.ia_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc827ff01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3299940 }, /* unc_cha_tor_occupancy.ia_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc8a7ff01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3301695 }, /* unc_cha_tor_occupancy.ia_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk. Unit: uncore_cha \000event=0x36,umask=0xc837ff01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3302128 }, /* unc_cha_tor_occupancy.ia_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd01\000\00001\000TOR Occupancy : All requests from iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3303661 }, /* unc_cha_tor_occupancy.ia_hit_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffd01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3304302 }, /* unc_cha_tor_occupancy.ia_hit_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffd01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3306450 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fd01\000\00001\000TOR Occupancy : DRd_Opts issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3307115 }, /* unc_cha_tor_occupancy.ia_hit_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fd01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3308998 }, /* unc_cha_tor_occupancy.ia_hit_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fd01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3313232 }, /* unc_cha_tor_occupancy.ia_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fd01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3313882 }, /* unc_cha_tor_occupancy.ia_hit_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fd01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3317327 }, /* unc_cha_tor_occupancy.ia_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe01\000\00001\000TOR Occupancy : All requests from iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3318883 }, /* unc_cha_tor_occupancy.ia_miss_crd\000uncore_cha\000uncore cache\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc80ffe01\000\00001\000TOR Occupancy : CRds issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3320005 }, /* unc_cha_tor_occupancy.ia_miss_crd_pref\000uncore_cha\000uncore cache\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc88ffe01\000\00001\000TOR Occupancy : CRd_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3327026 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc827fe01\000\00001\000TOR Occupancy : DRd_Opt issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3327897 }, /* unc_cha_tor_occupancy.ia_miss_drd_opt_pref\000uncore_cha\000uncore cache\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8a7fe01\000\00001\000TOR Occupancy : DRd_Opt_Prefs issued by iA Cores that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3336945 }, /* unc_cha_tor_occupancy.ia_miss_drdpte\000uncore_cha\000uncore cache\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc837fe01\000\00001\000TOR Occupancy : DRdPte issued by iA Cores due to a page walk that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3337423 }, /* unc_cha_tor_occupancy.ia_miss_full_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiLF misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3345709 }, /* unc_cha_tor_occupancy.ia_miss_partial_streaming_wr\000uncore_cha\000uncore cache\000TOR Occupancy; WCiL misses from local IA. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy; Data read from local IA that misses in the snoop filter\000 */
{ 3349910 }, /* unc_cha_tor_occupancy.ia_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc807fe01\000\00001\000TOR Occupancy : RFOs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3351696 }, /* unc_cha_tor_occupancy.ia_miss_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc887fe01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3355744 }, /* unc_cha_tor_occupancy.ia_miss_ucrdf\000uncore_cha\000uncore cache\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc877de01\000\00001\000TOR Occupancy : UCRdFs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3356175 }, /* unc_cha_tor_occupancy.ia_miss_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc86ffe01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3357547 }, /* unc_cha_tor_occupancy.ia_miss_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc867fe01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores that Missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3358926 }, /* unc_cha_tor_occupancy.ia_miss_wil\000uncore_cha\000uncore cache\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC. Unit: uncore_cha \000event=0x36,umask=0xc87fde01\000\00001\000TOR Occupancy : WiLs issued by iA Cores that Missed LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3359351 }, /* unc_cha_tor_occupancy.ia_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc807ff01\000\00001\000TOR Occupancy : RFOs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3359956 }, /* unc_cha_tor_occupancy.ia_rfo_pref\000uncore_cha\000uncore cache\000TOR Occupancy : RFO_Prefs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc887ff01\000\00001\000TOR Occupancy : RFO_Prefs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361002 }, /* unc_cha_tor_occupancy.ia_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xcc27ff01\000\00001\000TOR Occupancy : WbMtoIs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361399 }, /* unc_cha_tor_occupancy.ia_wcil\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLs issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc86fff01\000\00001\000TOR Occupancy : WCiLs issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3361790 }, /* unc_cha_tor_occupancy.ia_wcilf\000uncore_cha\000uncore cache\000TOR Occupancy : WCiLF issued by iA Cores. Unit: uncore_cha \000event=0x36,umask=0xc867ff01\000\00001\000TOR Occupancy : WCiLF issued by iA Cores : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3362182 }, /* unc_cha_tor_occupancy.io\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc001ff04\000\00001\000TOR Occupancy : All requests from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3363254 }, /* unc_cha_tor_occupancy.io_clflush\000uncore_cha\000uncore cache\000TOR Occupancy : CLFlushes issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8c3ff04\000\00001\000TOR Occupancy : CLFlushes issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3363660 }, /* unc_cha_tor_occupancy.io_hit\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fd04\000\00001\000TOR Occupancy : All requests from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3364763 }, /* unc_cha_tor_occupancy.io_hit_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fd04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that Hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3365608 }, /* unc_cha_tor_occupancy.io_hit_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fd04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3366132 }, /* unc_cha_tor_occupancy.io_hit_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fd04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3367010 }, /* unc_cha_tor_occupancy.io_hit_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fd04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that hit the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3367849 }, /* unc_cha_tor_occupancy.io_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc43ff04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3369154 }, /* unc_cha_tor_occupancy.io_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcd43ff04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3369640 }, /* unc_cha_tor_occupancy.io_miss\000uncore_cha\000uncore cache\000TOR Occupancy : All requests from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc001fe04\000\00001\000TOR Occupancy : All requests from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3370759 }, /* unc_cha_tor_occupancy.io_miss_itom\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcc43fe04\000\00001\000TOR Occupancy : ItoMs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372015 }, /* unc_cha_tor_occupancy.io_miss_itomcachenear\000uncore_cha\000uncore cache\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xcd43fe04\000\00001\000TOR Occupancy : ItoMCacheNears, indicating a partial write request, from IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3372546 }, /* unc_cha_tor_occupancy.io_miss_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc8f3fe04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3373813 }, /* unc_cha_tor_occupancy.io_miss_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC. Unit: uncore_cha \000event=0x36,umask=0xc803fe04\000\00001\000TOR Occupancy : RFOs issued by IO Devices that missed the LLC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3375059 }, /* unc_cha_tor_occupancy.io_pcirdcur\000uncore_cha\000uncore cache\000TOR Occupancy : PCIRdCurs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc8f3ff04\000\00001\000TOR Occupancy : PCIRdCurs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3375873 }, /* unc_cha_tor_occupancy.io_rfo\000uncore_cha\000uncore cache\000TOR Occupancy : RFOs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xc803ff04\000\00001\000TOR Occupancy : RFOs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3376649 }, /* unc_cha_tor_occupancy.io_wbmtoi\000uncore_cha\000uncore cache\000TOR Occupancy : WbMtoIs issued by IO Devices. Unit: uncore_cha \000event=0x36,umask=0xcc23ff04\000\00001\000TOR Occupancy : WbMtoIs issued by IO Devices : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3378406 }, /* unc_cha_tor_occupancy.irq_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - iA. Unit: uncore_cha \000event=0x36,umask=0x1\000\00001\000TOR Occupancy : IRQ - iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From an iA Core\000 */
{ 3379078 }, /* unc_cha_tor_occupancy.irq_non_ia\000uncore_cha\000uncore cache\000TOR Occupancy : IRQ - Non iA. Unit: uncore_cha \000event=0x36,umask=0x10\000\00001\000TOR Occupancy : IRQ - Non iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3379739 }, /* unc_cha_tor_occupancy.isoc\000uncore_cha\000uncore cache\000TOR Occupancy : Just ISOC. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just ISOC : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3380354 }, /* unc_cha_tor_occupancy.loc_all\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA and IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff05\000\00001\000TOR Occupancy : All from Local iA and IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests\000 */
{ 3381316 }, /* unc_cha_tor_occupancy.loc_ia\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local iA. Unit: uncore_cha \000event=0x36,umask=0xc000ff01\000\00001\000TOR Occupancy : All from Local iA : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally initiated requests from iA Cores\000 */
{ 3382096 }, /* unc_cha_tor_occupancy.loc_io\000uncore_cha\000uncore cache\000TOR Occupancy : All from Local IO. Unit: uncore_cha \000event=0x36,umask=0xc000ff04\000\00001\000TOR Occupancy : All from Local IO : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : All locally generated IO traffic\000 */
{ 3382852 }, /* unc_cha_tor_occupancy.local_tgt\000uncore_cha\000uncore cache\000TOR Occupancy : Just Local Targets. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Local Targets : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3383513 }, /* unc_cha_tor_occupancy.match_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3384326 }, /* unc_cha_tor_occupancy.miss\000uncore_cha\000uncore cache\000TOR Occupancy : Just Misses. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just Misses : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3385702 }, /* unc_cha_tor_occupancy.mmcfg\000uncore_cha\000uncore cache\000TOR Occupancy : MMCFG Access. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : MMCFG Access : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3386609 }, /* unc_cha_tor_occupancy.nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3387242 }, /* unc_cha_tor_occupancy.noncoh\000uncore_cha\000uncore cache\000TOR Occupancy : Just NonCoherent. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NonCoherent : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3387889 }, /* unc_cha_tor_occupancy.not_nearmem\000uncore_cha\000uncore cache\000TOR Occupancy : Just NotNearMem. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Just NotNearMem : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3389154 }, /* unc_cha_tor_occupancy.premorph_opc\000uncore_cha\000uncore cache\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field. Unit: uncore_cha \000event=0x36\000\00001\000TOR Occupancy : Match the PreMorphed Opcode in b[29:19] of the extended umask field : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3390017 }, /* unc_cha_tor_occupancy.prq\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - IOSF. Unit: uncore_cha \000event=0x36,umask=0x4\000\00001\000TOR Occupancy : PRQ - IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts. : From a PCIe Device\000 */
{ 3390945 }, /* unc_cha_tor_occupancy.prq_non_iosf\000uncore_cha\000uncore cache\000TOR Occupancy : PRQ - Non IOSF. Unit: uncore_cha \000event=0x36,umask=0x20\000\00001\000TOR Occupancy : PRQ - Non IOSF : For each cycle, this event accumulates the number of valid entries in the TOR that match qualifications specified by the subevent.     Does not include addressless requests such as locks and interrupts\000 */
{ 3393924 }, /* unc_cha_txr_horz_ads_used.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - All. Unit: uncore_cha \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3394464 }, /* unc_cha_txr_horz_ads_used.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_cha \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3394983 }, /* unc_cha_txr_horz_ads_used.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3395506 }, /* unc_cha_txr_horz_ads_used.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - All. Unit: uncore_cha \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3396046 }, /* unc_cha_txr_horz_ads_used.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_cha \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396565 }, /* unc_cha_txr_horz_ads_used.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_cha \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3396852 }, /* unc_cha_txr_horz_bypass.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_cha \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3397381 }, /* unc_cha_txr_horz_bypass.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_cha \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3397889 }, /* unc_cha_txr_horz_bypass.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398172 }, /* unc_cha_txr_horz_bypass.ak\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AK. Unit: uncore_cha \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398652 }, /* unc_cha_txr_horz_bypass.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3398939 }, /* unc_cha_txr_horz_bypass.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_cha \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 3399468 }, /* unc_cha_txr_horz_bypass.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_cha \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3399976 }, /* unc_cha_txr_horz_bypass.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_cha \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400259 }, /* unc_cha_txr_horz_bypass.iv\000uncore_cha\000uncore cache\000CMS Horizontal Bypass Used : IV. Unit: uncore_cha \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 3400739 }, /* unc_cha_txr_horz_cycles_full.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_cha \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3401446 }, /* unc_cha_txr_horz_cycles_full.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_cha \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402132 }, /* unc_cha_txr_horz_cycles_full.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3402512 }, /* unc_cha_txr_horz_cycles_full.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_cha \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403170 }, /* unc_cha_txr_horz_cycles_full.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3403554 }, /* unc_cha_txr_horz_cycles_full.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_cha \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3404261 }, /* unc_cha_txr_horz_cycles_full.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_cha \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3404947 }, /* unc_cha_txr_horz_cycles_full.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_cha \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405327 }, /* unc_cha_txr_horz_cycles_full.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_cha \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3405985 }, /* unc_cha_txr_horz_cycles_ne.ad_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_cha \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3406713 }, /* unc_cha_txr_horz_cycles_ne.ad_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_cha \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407420 }, /* unc_cha_txr_horz_cycles_ne.ad_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3407813 }, /* unc_cha_txr_horz_cycles_ne.ak\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_cha \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408492 }, /* unc_cha_txr_horz_cycles_ne.akc_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3408889 }, /* unc_cha_txr_horz_cycles_ne.bl_all\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_cha \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3409617 }, /* unc_cha_txr_horz_cycles_ne.bl_crd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_cha \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410324 }, /* unc_cha_txr_horz_cycles_ne.bl_uncrd\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_cha \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3410717 }, /* unc_cha_txr_horz_cycles_ne.iv\000uncore_cha\000uncore cache\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_cha \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3411396 }, /* unc_cha_txr_horz_inserts.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_cha \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3412076 }, /* unc_cha_txr_horz_inserts.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_cha \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3412735 }, /* unc_cha_txr_horz_inserts.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413095 }, /* unc_cha_txr_horz_inserts.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AK. Unit: uncore_cha \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3413726 }, /* unc_cha_txr_horz_inserts.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3414090 }, /* unc_cha_txr_horz_inserts.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_cha \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3414770 }, /* unc_cha_txr_horz_inserts.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_cha \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415429 }, /* unc_cha_txr_horz_inserts.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_cha \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3415789 }, /* unc_cha_txr_horz_inserts.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Inserts : IV. Unit: uncore_cha \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3416420 }, /* unc_cha_txr_horz_nack.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_cha \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 3416899 }, /* unc_cha_txr_horz_nack.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_cha \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417358 }, /* unc_cha_txr_horz_nack.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3417617 }, /* unc_cha_txr_horz_nack.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AK. Unit: uncore_cha \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418048 }, /* unc_cha_txr_horz_nack.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3418311 }, /* unc_cha_txr_horz_nack.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_cha \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 3418790 }, /* unc_cha_txr_horz_nack.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_cha \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419249 }, /* unc_cha_txr_horz_nack.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_cha \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419508 }, /* unc_cha_txr_horz_nack.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress NACKs : IV. Unit: uncore_cha \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 3419939 }, /* unc_cha_txr_horz_occupancy.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_cha \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3420615 }, /* unc_cha_txr_horz_occupancy.ad_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_cha \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421270 }, /* unc_cha_txr_horz_occupancy.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3421629 }, /* unc_cha_txr_horz_occupancy.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_cha \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422256 }, /* unc_cha_txr_horz_occupancy.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3422619 }, /* unc_cha_txr_horz_occupancy.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_cha \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 3423295 }, /* unc_cha_txr_horz_occupancy.bl_crd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_cha \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3423950 }, /* unc_cha_txr_horz_occupancy.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_cha \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424309 }, /* unc_cha_txr_horz_occupancy.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_cha \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 3424936 }, /* unc_cha_txr_horz_starved.ad_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 3425668 }, /* unc_cha_txr_horz_starved.ad_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426061 }, /* unc_cha_txr_horz_starved.ak\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_cha \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3426745 }, /* unc_cha_txr_horz_starved.akc_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3427142 }, /* unc_cha_txr_horz_starved.bl_all\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 3427874 }, /* unc_cha_txr_horz_starved.bl_uncrd\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_cha \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428267 }, /* unc_cha_txr_horz_starved.iv\000uncore_cha\000uncore cache\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_cha \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 3428951 }, /* unc_cha_txr_vert_ads_used.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3429457 }, /* unc_cha_txr_vert_ads_used.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430432 }, /* unc_cha_txr_vert_ads_used.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3430938 }, /* unc_cha_txr_vert_ads_used.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 3431446 }, /* unc_cha_txr_vert_bypass.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3431932 }, /* unc_cha_txr_vert_bypass.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432420 }, /* unc_cha_txr_vert_bypass.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3432906 }, /* unc_cha_txr_vert_bypass.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433394 }, /* unc_cha_txr_vert_bypass.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_cha \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3433880 }, /* unc_cha_txr_vert_bypass.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434577 }, /* unc_cha_txr_vert_bypass.iv_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_cha \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3434840 }, /* unc_cha_txr_vert_bypass_1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_cha \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3435108 }, /* unc_cha_txr_vert_bypass_1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_cha \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 3438262 }, /* unc_cha_txr_vert_cycles_full0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3438761 }, /* unc_cha_txr_vert_cycles_full0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3439229 }, /* unc_cha_txr_vert_cycles_full0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3439710 }, /* unc_cha_txr_vert_cycles_full0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3440132 }, /* unc_cha_txr_vert_cycles_full0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3440629 }, /* unc_cha_txr_vert_cycles_full0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_cha \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3441120 }, /* unc_cha_txr_vert_cycles_full0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_cha \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3441589 }, /* unc_cha_txr_vert_cycles_full1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_cha \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3442091 }, /* unc_cha_txr_vert_cycles_full1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_cha \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3445489 }, /* unc_cha_txr_vert_cycles_ne0.ad_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3445997 }, /* unc_cha_txr_vert_cycles_ne0.ad_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3446474 }, /* unc_cha_txr_vert_cycles_ne0.ak_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3446964 }, /* unc_cha_txr_vert_cycles_ne0.ak_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3447395 }, /* unc_cha_txr_vert_cycles_ne0.bl_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3447901 }, /* unc_cha_txr_vert_cycles_ne0.bl_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_cha \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3448401 }, /* unc_cha_txr_vert_cycles_ne0.iv_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_cha \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3448879 }, /* unc_cha_txr_vert_cycles_ne1.akc_ag0\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_cha \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3449390 }, /* unc_cha_txr_vert_cycles_ne1.akc_ag1\000uncore_cha\000uncore cache\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_cha \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3452629 }, /* unc_cha_txr_vert_inserts0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3453095 }, /* unc_cha_txr_vert_inserts0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3453530 }, /* unc_cha_txr_vert_inserts0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3453978 }, /* unc_cha_txr_vert_inserts0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3454367 }, /* unc_cha_txr_vert_inserts0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3454831 }, /* unc_cha_txr_vert_inserts0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_cha \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3455289 }, /* unc_cha_txr_vert_inserts0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_cha \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3455725 }, /* unc_cha_txr_vert_inserts1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_cha \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3456194 }, /* unc_cha_txr_vert_inserts1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_cha \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3458041 }, /* unc_cha_txr_vert_nack0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458287 }, /* unc_cha_txr_vert_nack0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458534 }, /* unc_cha_txr_vert_nack0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3458780 }, /* unc_cha_txr_vert_nack0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459027 }, /* unc_cha_txr_vert_nack0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_cha \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459273 }, /* unc_cha_txr_vert_nack0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_cha \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459520 }, /* unc_cha_txr_vert_nack0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : IV. Unit: uncore_cha \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459746 }, /* unc_cha_txr_vert_nack1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_cha \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3459995 }, /* unc_cha_txr_vert_nack1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_cha \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 3463039 }, /* unc_cha_txr_vert_occupancy0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3463510 }, /* unc_cha_txr_vert_occupancy0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 3463950 }, /* unc_cha_txr_vert_occupancy0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3464403 }, /* unc_cha_txr_vert_occupancy0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 3464797 }, /* unc_cha_txr_vert_occupancy0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 3465266 }, /* unc_cha_txr_vert_occupancy0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_cha \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 3465729 }, /* unc_cha_txr_vert_occupancy0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_cha \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 3466170 }, /* unc_cha_txr_vert_occupancy1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_cha \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 3466644 }, /* unc_cha_txr_vert_occupancy1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_cha \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 3469252 }, /* unc_cha_txr_vert_starved0.ad_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3469621 }, /* unc_cha_txr_vert_starved0.ad_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3469991 }, /* unc_cha_txr_vert_starved0.ak_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3470360 }, /* unc_cha_txr_vert_starved0.ak_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3470730 }, /* unc_cha_txr_vert_starved0.bl_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_cha \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471099 }, /* unc_cha_txr_vert_starved0.bl_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_cha \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471469 }, /* unc_cha_txr_vert_starved0.iv_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_cha \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3471818 }, /* unc_cha_txr_vert_starved1.akc_ag0\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472190 }, /* unc_cha_txr_vert_starved1.akc_ag1\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_cha \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3472562 }, /* unc_cha_txr_vert_starved1.tgc\000uncore_cha\000uncore cache\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_cha \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 3485328 }, /* unc_cha_vert_ring_ad_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3487111 }, /* unc_cha_vert_ring_ad_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3488889 }, /* unc_cha_vert_ring_ad_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3490666 }, /* unc_cha_vert_ring_ad_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3492438 }, /* unc_cha_vert_ring_ak_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3494221 }, /* unc_cha_vert_ring_ak_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3495999 }, /* unc_cha_vert_ring_ak_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3497776 }, /* unc_cha_vert_ring_ak_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3499548 }, /* unc_cha_vert_ring_akc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3500469 }, /* unc_cha_vert_ring_akc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3501387 }, /* unc_cha_vert_ring_akc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3502304 }, /* unc_cha_vert_ring_akc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3503218 }, /* unc_cha_vert_ring_bl_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Even. Unit: uncore_cha \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3504997 }, /* unc_cha_vert_ring_bl_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_cha \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3506771 }, /* unc_cha_vert_ring_bl_in_use.up_even\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Even. Unit: uncore_cha \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3508544 }, /* unc_cha_vert_ring_bl_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_cha \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3510312 }, /* unc_cha_vert_ring_iv_in_use.dn\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Down. Unit: uncore_cha \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3511448 }, /* unc_cha_vert_ring_iv_in_use.up\000uncore_cha\000uncore cache\000Vertical IV Ring in Use : Up. Unit: uncore_cha \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 3512578 }, /* unc_cha_vert_ring_tgc_in_use.dn_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_cha \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3513499 }, /* unc_cha_vert_ring_tgc_in_use.dn_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_cha \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3514417 }, /* unc_cha_vert_ring_tgc_in_use.up_even\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_cha \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3515334 }, /* unc_cha_vert_ring_tgc_in_use.up_odd\000uncore_cha\000uncore cache\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_cha \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 3516248 }, /* unc_cha_wb_push_mtoi.llc\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to LLC. Unit: uncore_cha \000event=0x56,umask=0x1\000\00001\000WbPushMtoI : Pushed to LLC : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was able to push WbPushMToI to LLC\000 */
{ 3516797 }, /* unc_cha_wb_push_mtoi.mem\000uncore_cha\000uncore cache\000WbPushMtoI : Pushed to Memory. Unit: uncore_cha \000event=0x56,umask=0x2\000\00001\000WbPushMtoI : Pushed to Memory : Counts the number of times when the CHA was received WbPushMtoI : Counts the number of times when the CHA was unable to push WbPushMToI to LLC (hence pushed it to MEM)\000 */
{ 3519063 }, /* unc_cha_write_no_credits.mc0\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC0. Unit: uncore_cha \000event=0x5a,umask=0x1\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC0 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 0 only\000 */
{ 3521670 }, /* unc_cha_write_no_credits.mc1\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC1. Unit: uncore_cha \000event=0x5a,umask=0x2\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC1 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 1 only\000 */
{ 3519918 }, /* unc_cha_write_no_credits.mc10\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC10. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC10 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 10 only\000 */
{ 3520356 }, /* unc_cha_write_no_credits.mc11\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC11. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC11 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 11 only\000 */
{ 3520794 }, /* unc_cha_write_no_credits.mc12\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC12. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC12 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 12 only\000 */
{ 3521232 }, /* unc_cha_write_no_credits.mc13\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC13. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC13 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 13 only\000 */
{ 3522525 }, /* unc_cha_write_no_credits.mc2\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC2. Unit: uncore_cha \000event=0x5a,umask=0x4\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC2 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 2 only\000 */
{ 3522969 }, /* unc_cha_write_no_credits.mc3\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC3. Unit: uncore_cha \000event=0x5a,umask=0x8\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC3 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 3 only\000 */
{ 3523413 }, /* unc_cha_write_no_credits.mc4\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC4. Unit: uncore_cha \000event=0x5a,umask=0x10\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC4 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 4 only\000 */
{ 3523858 }, /* unc_cha_write_no_credits.mc5\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC5. Unit: uncore_cha \000event=0x5a,umask=0x20\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC5 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 5 only\000 */
{ 3524303 }, /* unc_cha_write_no_credits.mc6\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC6. Unit: uncore_cha \000event=0x5a,umask=0x40\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC6 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 6 only\000 */
{ 3524748 }, /* unc_cha_write_no_credits.mc7\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC7. Unit: uncore_cha \000event=0x5a,umask=0x80\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC7 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 7 only\000 */
{ 3525193 }, /* unc_cha_write_no_credits.mc8\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC8. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC8 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 8 only\000 */
{ 3525627 }, /* unc_cha_write_no_credits.mc9\000uncore_cha\000uncore cache\000CHA iMC CHNx WRITE Credits Empty : MC9. Unit: uncore_cha \000event=0x5a\000\00001\000CHA iMC CHNx WRITE Credits Empty : MC9 : Counts the number of times when there are no credits available for sending WRITEs from the CHA into the iMC.  In order to send WRITEs into the memory controller, the HA must first acquire a credit for the iMC's BL Ingress queue. : Filter for memory controller 9 only\000 */
{ 3526061 }, /* unc_cha_xpt_pref.drop0_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x8\000\00001\000XPT Prefetches : Dropped (on 0?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526320 }, /* unc_cha_xpt_pref.drop0_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 0?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x4\000\00001\000XPT Prefetches : Dropped (on 0?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3526581 }, /* unc_cha_xpt_pref.drop1_conflict\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - Conflict. Unit: uncore_cha \000event=0x6f,umask=0x80\000\00001\000XPT Prefetches : Dropped (on 1?) - Conflict : Number of XPT prefetches dropped due to AD CMS write port contention\000 */
{ 3526841 }, /* unc_cha_xpt_pref.drop1_nocrd\000uncore_cha\000uncore cache\000XPT Prefetches : Dropped (on 1?) - No Credits. Unit: uncore_cha \000event=0x6f,umask=0x40\000\00001\000XPT Prefetches : Dropped (on 1?) - No Credits : Number of XPT prefetches dropped due to lack of XPT AD egress credits\000 */
{ 3527103 }, /* unc_cha_xpt_pref.sent0\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 0?). Unit: uncore_cha \000event=0x6f,umask=0x1\000\00001\000XPT Prefetches : Sent (on 0?) : Number of XPT prefetches sent\000 */
{ 3527286 }, /* unc_cha_xpt_pref.sent1\000uncore_cha\000uncore cache\000XPT Prefetches : Sent (on 1?). Unit: uncore_cha \000event=0x6f,umask=0x10\000\00001\000XPT Prefetches : Sent (on 1?) : Number of XPT prefetches sent\000 */
{ 3870998 }, /* unc_i_cache_total_occupancy.any\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Any Source. Unit: uncore_irp \000event=0xf,umask=0x1\000\00001\000Total Write Cache Occupancy : Any Source : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events. : Tracks all requests from any source port\000 */
{ 3872442 }, /* unc_i_cache_total_occupancy.iv_q\000uncore_irp\000uncore interconnect\000Total Write Cache Occupancy : Snoops. Unit: uncore_irp \000event=0xf,umask=0x2\000\00001\000Total Write Cache Occupancy : Snoops : Accumulates the number of reads and writes that are outstanding in the uncore in each cycle.  This is effectively the sum of the READ_OCCUPANCY and WRITE_OCCUPANCY events\000 */
{ 3873110 }, /* unc_i_cache_total_occupancy.mem\000uncore_irp\000uncore interconnect\000Total IRP occupancy of inbound read and write requests to coherent memory. Unit: uncore_irp \000event=0xf,umask=0x4\000\00001\000Total IRP occupancy of inbound read and write requests to coherent memory.  This is effectively the sum of read occupancy and write occupancy\000 */
{ 3876876 }, /* unc_i_clockticks\000uncore_irp\000uncore interconnect\000Clockticks of the IO coherency tracker (IRP). Unit: uncore_irp \000event=0x1\000\00001\000\000 */
{ 3877246 }, /* unc_i_coherent_ops.clflush\000uncore_irp\000uncore interconnect\000Coherent Ops : CLFlush. Unit: uncore_irp \000event=0x10,umask=0x80\000\00001\000Coherent Ops : CLFlush : Counts the number of coherency related operations servied by the IRP\000 */
{ 3879579 }, /* unc_i_coherent_ops.pcitom\000uncore_irp\000uncore interconnect\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline. Unit: uncore_irp \000event=0x10,umask=0x10\000\00001\000PCIITOM request issued by the IRP unit to the mesh with the intention of writing a full cacheline to coherent memory, without a RFO.  PCIITOM is a speculative Invalidate to Modified command that requests ownership of the cacheline and does not move data from the mesh to IRP cache\000 */
{ 3880245 }, /* unc_i_coherent_ops.rfo\000uncore_irp\000uncore interconnect\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline. Unit: uncore_irp \000event=0x10,umask=0x8\000\00001\000RFO request issued by the IRP unit to the mesh with the intention of writing a partial cacheline to coherent memory.  RFO is a Read For Ownership command that requests ownership of the cacheline and moves data from the mesh to IRP cache\000 */
{ 3880677 }, /* unc_i_coherent_ops.wbmtoi\000uncore_irp\000uncore interconnect\000Coherent Ops : WbMtoI. Unit: uncore_irp \000event=0x10,umask=0x40\000\00001\000Coherent Ops : WbMtoI : Counts the number of coherency related operations servied by the IRP\000 */
{ 3881278 }, /* unc_i_faf_full\000uncore_irp\000uncore interconnect\000FAF RF full. Unit: uncore_irp \000event=0x17\000\00001\000\000 */
{ 3881484 }, /* unc_i_faf_inserts\000uncore_irp\000uncore interconnect\000Inbound read requests received by the IRP and inserted into the FAF queue. Unit: uncore_irp \000event=0x18\000\00001\000Inbound read requests to coherent memory, received by the IRP and inserted into the Fire and Forget queue (FAF), a queue used for processing inbound reads in the IRP\000 */
{ 3881907 }, /* unc_i_faf_occupancy\000uncore_irp\000uncore interconnect\000Occupancy of the IRP FAF queue. Unit: uncore_irp \000event=0x19\000\00001\000Occupancy of the IRP Fire and Forget (FAF) queue, a queue used for processing inbound reads in the IRP\000 */
{ 3882126 }, /* unc_i_faf_transactions\000uncore_irp\000uncore interconnect\000FAF allocation -- sent to ADQ. Unit: uncore_irp \000event=0x16\000\00001\000\000 */
{ 3882245 }, /* unc_i_irp_all.evicts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x4\000\00001\000\000 */
{ 3882382 }, /* unc_i_irp_all.inbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Inbound (p2p + faf + cset). Unit: uncore_irp \000event=0x20,umask=0x1\000\00001\000\000 */
{ 3882674 }, /* unc_i_irp_all.outbound_inserts\000uncore_irp\000uncore interconnect\000: All Inserts Outbound (BL, AK, Snoops). Unit: uncore_irp \000event=0x20,umask=0x2\000\00001\000\000 */
{ 3882966 }, /* unc_i_misc0.2nd_atomic_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Atomic Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x10\000\00001\000\000 */
{ 3883580 }, /* unc_i_misc0.2nd_rd_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Read Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x4\000\00001\000\000 */
{ 3884171 }, /* unc_i_misc0.2nd_wr_insert\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Cache Inserts of Write Transactions as Secondary. Unit: uncore_irp \000event=0x1e,umask=0x8\000\00001\000\000 */
{ 3884766 }, /* unc_i_misc0.fast_rej\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Rejects. Unit: uncore_irp \000event=0x1e,umask=0x2\000\00001\000\000 */
{ 3885218 }, /* unc_i_misc0.fast_req\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Requests. Unit: uncore_irp \000event=0x1e,umask=0x1\000\00001\000\000 */
{ 3885674 }, /* unc_i_misc0.fast_xfer\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Fastpath Transfers From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x20\000\00001\000\000 */
{ 3886244 }, /* unc_i_misc0.pf_ack_hint\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Prefetch Ack Hints From Primary to Secondary. Unit: uncore_irp \000event=0x1e,umask=0x40\000\00001\000\000 */
{ 3887083 }, /* unc_i_misc0.slowpath_fwpf_no_prf\000uncore_irp\000uncore interconnect\000Counts Timeouts - Set 0 : Slow path fwpf didn't find prefetch. Unit: uncore_irp \000event=0x1e,umask=0x80\000\00001\000\000 */
{ 3887536 }, /* unc_i_misc1.lost_fwd\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Lost Forward. Unit: uncore_irp \000event=0x1f,umask=0x10\000\00001\000Misc Events - Set 1 : Lost Forward : Snoop pulled away ownership before a write was committed\000 */
{ 3888161 }, /* unc_i_misc1.sec_rcvd_invld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Invalid. Unit: uncore_irp \000event=0x1f,umask=0x20\000\00001\000Misc Events - Set 1 : Received Invalid : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3888836 }, /* unc_i_misc1.sec_rcvd_vld\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Received Valid. Unit: uncore_irp \000event=0x1f,umask=0x40\000\00001\000Misc Events - Set 1 : Received Valid : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3889485 }, /* unc_i_misc1.slow_e\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of E Line. Unit: uncore_irp \000event=0x1f,umask=0x4\000\00001\000Misc Events - Set 1 : Slow Transfer of E Line : Secondary received a transfer that did have sufficient MESI state\000 */
{ 3890149 }, /* unc_i_misc1.slow_i\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of I Line. Unit: uncore_irp \000event=0x1f,umask=0x1\000\00001\000Misc Events - Set 1 : Slow Transfer of I Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3890819 }, /* unc_i_misc1.slow_m\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of M Line. Unit: uncore_irp \000event=0x1f,umask=0x8\000\00001\000Misc Events - Set 1 : Slow Transfer of M Line : Snoop took cacheline ownership before write from data was committed\000 */
{ 3891489 }, /* unc_i_misc1.slow_s\000uncore_irp\000uncore interconnect\000Misc Events - Set 1 : Slow Transfer of S Line. Unit: uncore_irp \000event=0x1f,umask=0x2\000\00001\000Misc Events - Set 1 : Slow Transfer of S Line : Secondary received a transfer that did not have sufficient MESI state\000 */
{ 3892165 }, /* unc_i_p2p_inserts\000uncore_irp\000uncore interconnect\000P2P Requests. Unit: uncore_irp \000event=0x14\000\00001\000P2P Requests : P2P requests from the ITC\000 */
{ 3892549 }, /* unc_i_p2p_occupancy\000uncore_irp\000uncore interconnect\000P2P Occupancy. Unit: uncore_irp \000event=0x15\000\00001\000P2P Occupancy : P2P B & S Queue Occupancy\000 */
{ 3892690 }, /* unc_i_p2p_transactions.cmpl\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P completions. Unit: uncore_irp \000event=0x13,umask=0x8\000\00001\000\000 */
{ 3892967 }, /* unc_i_p2p_transactions.loc\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local only. Unit: uncore_irp \000event=0x13,umask=0x40\000\00001\000\000 */
{ 3893252 }, /* unc_i_p2p_transactions.loc_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if local and target matches. Unit: uncore_irp \000event=0x13,umask=0x80\000\00001\000\000 */
{ 3893593 }, /* unc_i_p2p_transactions.msg\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Message. Unit: uncore_irp \000event=0x13,umask=0x4\000\00001\000\000 */
{ 3893860 }, /* unc_i_p2p_transactions.rd\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P reads. Unit: uncore_irp \000event=0x13,umask=0x1\000\00001\000\000 */
{ 3894121 }, /* unc_i_p2p_transactions.rem\000uncore_irp\000uncore interconnect\000P2P Transactions : Match if remote only. Unit: uncore_irp \000event=0x13,umask=0x10\000\00001\000\000 */
{ 3894408 }, /* unc_i_p2p_transactions.rem_and_tgt_match\000uncore_irp\000uncore interconnect\000P2P Transactions : match if remote and target matches. Unit: uncore_irp \000event=0x13,umask=0x20\000\00001\000\000 */
{ 3894751 }, /* unc_i_p2p_transactions.wr\000uncore_irp\000uncore interconnect\000P2P Transactions : P2P Writes. Unit: uncore_irp \000event=0x13,umask=0x2\000\00001\000\000 */
{ 3900346 }, /* unc_i_snoop_resp.all_hit\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M, E, S or I line in the IIO. Unit: uncore_irp \000event=0x12,umask=0x7e\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M, E, S or I line in the IIO\000 */
{ 3900612 }, /* unc_i_snoop_resp.all_hit_es\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit E or S line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x74\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit E or S line in the IIO cache\000 */
{ 3900881 }, /* unc_i_snoop_resp.all_hit_i\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit I line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x72\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit I line in the IIO cache\000 */
{ 3901139 }, /* unc_i_snoop_resp.all_hit_m\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that hit M line in the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x78\000\00001\000Responses to snoops of any type (code, data, invalidate) that hit M line in the IIO cache\000 */
{ 3901397 }, /* unc_i_snoop_resp.all_miss\000uncore_irp\000uncore interconnect\000Responses to snoops of any type that miss the IIO cache. Unit: uncore_irp \000event=0x12,umask=0x71\000\00001\000Responses to snoops of any type (code, data, invalidate) that miss the IIO cache\000 */
{ 3901636 }, /* unc_i_snoop_resp.hit_es\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit E or S. Unit: uncore_irp \000event=0x12,umask=0x4\000\00001\000\000 */
{ 3902049 }, /* unc_i_snoop_resp.hit_i\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit I. Unit: uncore_irp \000event=0x12,umask=0x2\000\00001\000\000 */
{ 3902439 }, /* unc_i_snoop_resp.hit_m\000uncore_irp\000uncore interconnect\000Snoop Responses : Hit M. Unit: uncore_irp \000event=0x12,umask=0x8\000\00001\000\000 */
{ 3902829 }, /* unc_i_snoop_resp.miss\000uncore_irp\000uncore interconnect\000Snoop Responses : Miss. Unit: uncore_irp \000event=0x12,umask=0x1\000\00001\000\000 */
{ 3903212 }, /* unc_i_snoop_resp.snpcode\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpCode. Unit: uncore_irp \000event=0x12,umask=0x10\000\00001\000\000 */
{ 3903619 }, /* unc_i_snoop_resp.snpdata\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpData. Unit: uncore_irp \000event=0x12,umask=0x20\000\00001\000\000 */
{ 3904026 }, /* unc_i_snoop_resp.snpinv\000uncore_irp\000uncore interconnect\000Snoop Responses : SnpInv. Unit: uncore_irp \000event=0x12,umask=0x40\000\00001\000\000 */
{ 3906074 }, /* unc_i_transactions.atomic\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Atomic. Unit: uncore_irp \000event=0x11,umask=0x10\000\00001\000Inbound Transaction Count : Atomic : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of atomic transactions\000 */
{ 3907592 }, /* unc_i_transactions.other\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Other. Unit: uncore_irp \000event=0x11,umask=0x20\000\00001\000Inbound Transaction Count : Other : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Tracks the number of 'other' kinds of transactions\000 */
{ 3914035 }, /* unc_i_transactions.wr_pref\000uncore_irp\000uncore interconnect\000Inbound write (fast path) requests received by the IRP. Unit: uncore_irp \000event=0x11,umask=0x8\000\00001\000Inbound write (fast path) requests to coherent memory, received by the IRP resulting in write ownership requests issued by IRP to the mesh\000 */
{ 3914331 }, /* unc_i_transactions.writes\000uncore_irp\000uncore interconnect\000Inbound Transaction Count : Writes. Unit: uncore_irp \000event=0x11,umask=0x2\000\00001\000Inbound Transaction Count : Writes : Counts the number of Inbound transactions from the IRP to the Uncore.  This can be filtered based on request type in addition to the source queue.  Note the special filtering equation.  We do OR-reduction on the request type.  If the SOURCE bit is set, then we also do AND qualification based on the source portID. : Trackes only write requests.  Each write request should have a prefetch, so there is no need to explicitly track these requests.  For writes that are tickled and have to retry, the counter will be incremented for each retry\000 */
{ 3918099 }, /* unc_i_txc_ak_inserts\000uncore_irp\000uncore interconnect\000AK Egress Allocations. Unit: uncore_irp \000event=0xb\000\00001\000\000 */
{ 3918207 }, /* unc_i_txc_bl_drs_cycles_full\000uncore_irp\000uncore interconnect\000BL DRS Egress Cycles Full. Unit: uncore_irp \000event=0x5\000\00001\000\000 */
{ 3918327 }, /* unc_i_txc_bl_drs_inserts\000uncore_irp\000uncore interconnect\000BL DRS Egress Inserts. Unit: uncore_irp \000event=0x2\000\00001\000\000 */
{ 3918439 }, /* unc_i_txc_bl_drs_occupancy\000uncore_irp\000uncore interconnect\000BL DRS Egress Occupancy. Unit: uncore_irp \000event=0x8\000\00001\000\000 */
{ 3918555 }, /* unc_i_txc_bl_ncb_cycles_full\000uncore_irp\000uncore interconnect\000BL NCB Egress Cycles Full. Unit: uncore_irp \000event=0x6\000\00001\000\000 */
{ 3918675 }, /* unc_i_txc_bl_ncb_inserts\000uncore_irp\000uncore interconnect\000BL NCB Egress Inserts. Unit: uncore_irp \000event=0x3\000\00001\000\000 */
{ 3918787 }, /* unc_i_txc_bl_ncb_occupancy\000uncore_irp\000uncore interconnect\000BL NCB Egress Occupancy. Unit: uncore_irp \000event=0x9\000\00001\000\000 */
{ 3918903 }, /* unc_i_txc_bl_ncs_cycles_full\000uncore_irp\000uncore interconnect\000BL NCS Egress Cycles Full. Unit: uncore_irp \000event=0x7\000\00001\000\000 */
{ 3919023 }, /* unc_i_txc_bl_ncs_inserts\000uncore_irp\000uncore interconnect\000BL NCS Egress Inserts. Unit: uncore_irp \000event=0x4\000\00001\000\000 */
{ 3919135 }, /* unc_i_txc_bl_ncs_occupancy\000uncore_irp\000uncore interconnect\000BL NCS Egress Occupancy. Unit: uncore_irp \000event=0xa\000\00001\000\000 */
{ 3919251 }, /* unc_i_txr2_ad01_stall_credit_cycles\000uncore_irp\000uncore interconnect\000UNC_I_TxR2_AD01_STALL_CREDIT_CYCLES. Unit: uncore_irp \000event=0x1c\000\00001\000: Counts the number times when it is not possible to issue a request to the M2PCIe because there are no Egress Credits available on AD0, A1 or AD0&AD1 both. Stalls on both AD0 and AD1 will count as 2\000 */
{ 3919924 }, /* unc_i_txr2_ad0_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD0 Egress Credits Stalls. Unit: uncore_irp \000event=0x1a\000\00001\000No AD0 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD0 Egress Credits available\000 */
{ 3920215 }, /* unc_i_txr2_ad1_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No AD1 Egress Credits Stalls. Unit: uncore_irp \000event=0x1b\000\00001\000No AD1 Egress Credits Stalls : Counts the number times when it is not possible to issue a request to the M2PCIe because there are no AD1 Egress Credits available\000 */
{ 3921013 }, /* unc_i_txr2_bl_stall_credit_cycles\000uncore_irp\000uncore interconnect\000No BL Egress Credit Stalls. Unit: uncore_irp \000event=0x1d\000\00001\000No BL Egress Credit Stalls : Counts the number times when it is not possible to issue data to the R2PCIe because there are no BL Egress Credits available\000 */
{ 3923058 }, /* unc_i_txs_data_inserts_ncb\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xd\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3923457 }, /* unc_i_txs_data_inserts_ncs\000uncore_irp\000uncore interconnect\000Outbound Read Requests. Unit: uncore_irp \000event=0xe\000\00001\000Outbound Read Requests : Counts the number of requests issued to the switch (towards the devices)\000 */
{ 3924019 }, /* unc_i_txs_request_occupancy\000uncore_irp\000uncore interconnect\000Outbound Request Queue Occupancy. Unit: uncore_irp \000event=0xc\000\00001\000Outbound Request Queue Occupancy : Accumulates the number of outstanding outbound requests from the IRP to the switch (towards the devices).  This can be used in conjunction with the allocations event in order to calculate average latency of outbound requests\000 */
{ 4331486 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4331772 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332058 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332344 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332630 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4332917 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333204 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333491 }, /* unc_m2m_ag0_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4333778 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334067 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4334353 }, /* unc_m2m_ag0_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4336033 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336320 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336607 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4336894 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337181 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337469 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4337757 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338045 }, /* unc_m2m_ag0_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338333 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338623 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4338910 }, /* unc_m2m_ag0_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4340591 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4340877 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341163 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341449 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4341735 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342022 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342309 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342596 }, /* unc_m2m_ag0_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4342883 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343172 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4343458 }, /* unc_m2m_ag0_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4345138 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345425 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345712 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4345999 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346286 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346574 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4346862 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347150 }, /* unc_m2m_ag0_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347438 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4347728 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4348015 }, /* unc_m2m_ag0_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4349696 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4349982 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350268 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350554 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4350840 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351127 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351414 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2m \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351701 }, /* unc_m2m_ag1_ad_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2m \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4351988 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352277 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4352563 }, /* unc_m2m_ag1_ad_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4354243 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354530 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4354817 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355104 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355391 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355679 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4355967 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356255 }, /* unc_m2m_ag1_ad_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356543 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4356833 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4357120 }, /* unc_m2m_ag1_ad_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4357407 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2m \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4357693 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2m \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4357979 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2m \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358265 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2m \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358551 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4358838 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359125 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2m \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359412 }, /* unc_m2m_ag1_bl_crd_acquired0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2m \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359699 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2m \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4359988 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2m \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4360274 }, /* unc_m2m_ag1_bl_crd_acquired1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2m \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4361954 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr0\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2m \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362241 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr1\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2m \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362528 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr2\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2m \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4362815 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr3\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2m \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363102 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr4\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2m \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363390 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr5\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2m \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363678 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr6\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2m \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4363966 }, /* unc_m2m_ag1_bl_crd_occupancy0.tgr7\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2m \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364254 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr10\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2m \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364544 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr8\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2m \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4364831 }, /* unc_m2m_ag1_bl_crd_occupancy1.tgr9\000uncore_m2m\000uncore interconnect\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2m \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4366536 }, /* unc_m2m_bypass_m2m_egress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x22,umask=0x2\000\00001\000\000 */
{ 4366939 }, /* unc_m2m_bypass_m2m_egress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x22,umask=0x1\000\00001\000\000 */
{ 4367206 }, /* unc_m2m_bypass_m2m_ingress.not_taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Not Taken. Unit: uncore_m2m \000event=0x21,umask=0x2\000\00001\000\000 */
{ 4367491 }, /* unc_m2m_bypass_m2m_ingress.taken\000uncore_m2m\000uncore interconnect\000M2M to iMC Bypass : Taken. Unit: uncore_m2m \000event=0x21,umask=0x1\000\00001\000\000 */
{ 4367760 }, /* unc_m2m_clockticks\000uncore_m2m\000uncore interconnect\000Clockticks of the mesh to memory (M2M). Unit: uncore_m2m \000event=0\000\00001\000\000 */
{ 4368117 }, /* unc_m2m_cms_clockticks\000uncore_m2m\000uncore interconnect\000CMS Clockticks. Unit: uncore_m2m \000event=0xc0\000\00001\000\000 */
{ 4369061 }, /* unc_m2m_direct2core_not_taken_dirstate\000uncore_m2m\000uncore interconnect\000Cycles when direct to core mode, which bypasses the CHA, was disabled. Unit: uncore_m2m \000event=0x24\000\00001\000\000 */
{ 4369413 }, /* unc_m2m_direct2core_not_taken_notforked\000uncore_m2m\000uncore interconnect\000UNC_M2M_DIRECT2CORE_NOT_TAKEN_NOTFORKED. Unit: uncore_m2m \000event=0x60\000\00001\000\000 */
{ 4370156 }, /* unc_m2m_direct2core_txn_override\000uncore_m2m\000uncore interconnect\000Number of reads in which direct to core transaction was overridden. Unit: uncore_m2m \000event=0x25\000\00001\000\000 */
{ 4392599 }, /* unc_m2m_distress_asserted.dpt_local\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Local. Unit: uncore_m2m \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 4392925 }, /* unc_m2m_distress_asserted.dpt_nonlocal\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Remote. Unit: uncore_m2m \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 4393255 }, /* unc_m2m_distress_asserted.dpt_stall_iv\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2m \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 4393622 }, /* unc_m2m_distress_asserted.dpt_stall_nocrd\000uncore_m2m\000uncore interconnect\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2m \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 4394002 }, /* unc_m2m_distress_asserted.horz\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Horizontal. Unit: uncore_m2m \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4395111 }, /* unc_m2m_distress_asserted.vert\000uncore_m2m\000uncore interconnect\000Distress signal asserted : Vertical. Unit: uncore_m2m \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4395691 }, /* unc_m2m_egress_ordering.iv_snoopgo_dn\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2m \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4396579 }, /* unc_m2m_egress_ordering.iv_snoopgo_up\000uncore_m2m\000uncore interconnect\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2m \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4397989 }, /* unc_m2m_horz_ring_ad_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4399798 }, /* unc_m2m_horz_ring_ad_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4401602 }, /* unc_m2m_horz_ring_ad_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4403416 }, /* unc_m2m_horz_ring_ad_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4405225 }, /* unc_m2m_horz_ring_ak_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4407030 }, /* unc_m2m_horz_ring_ak_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4408830 }, /* unc_m2m_horz_ring_ak_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4410640 }, /* unc_m2m_horz_ring_ak_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4412445 }, /* unc_m2m_horz_ring_akc_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2m \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4413379 }, /* unc_m2m_horz_ring_akc_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4414310 }, /* unc_m2m_horz_ring_akc_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2m \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4415247 }, /* unc_m2m_horz_ring_akc_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2m \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4416181 }, /* unc_m2m_horz_ring_bl_in_use.left_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2m \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4417988 }, /* unc_m2m_horz_ring_bl_in_use.left_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4419790 }, /* unc_m2m_horz_ring_bl_in_use.right_even\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2m \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4421602 }, /* unc_m2m_horz_ring_bl_in_use.right_odd\000uncore_m2m\000uncore interconnect\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2m \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4423409 }, /* unc_m2m_horz_ring_iv_in_use.left\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Left. Unit: uncore_m2m \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4424573 }, /* unc_m2m_horz_ring_iv_in_use.right\000uncore_m2m\000uncore interconnect\000Horizontal IV Ring in Use : Right. Unit: uncore_m2m \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4425892 }, /* unc_m2m_imc_reads.all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x704\000\00001\000\000 */
{ 4426664 }, /* unc_m2m_imc_reads.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x104\000\00001\000\000 */
{ 4426997 }, /* unc_m2m_imc_reads.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x140\000\00001\000\000 */
{ 4427287 }, /* unc_m2m_imc_reads.ch0_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x102\000\00001\000\000 */
{ 4427577 }, /* unc_m2m_imc_reads.ch0_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch0. Unit: uncore_m2m \000event=0x37,umask=0x101\000\00001\000\000 */
{ 4429233 }, /* unc_m2m_imc_reads.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : All, regardless of priority. - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x204\000\00001\000\000 */
{ 4429566 }, /* unc_m2m_imc_reads.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x240\000\00001\000\000 */
{ 4429856 }, /* unc_m2m_imc_reads.ch1_isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x202\000\00001\000\000 */
{ 4430146 }, /* unc_m2m_imc_reads.ch1_normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - Ch1. Unit: uncore_m2m \000event=0x37,umask=0x201\000\00001\000\000 */
{ 4431668 }, /* unc_m2m_imc_reads.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x740\000\00001\000\000 */
{ 4432119 }, /* unc_m2m_imc_reads.isoch\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Critical Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x702\000\00001\000\000 */
{ 4432549 }, /* unc_m2m_imc_reads.normal\000uncore_m2m\000uncore interconnect\000M2M Reads Issued to iMC : Normal Priority - All Channels. Unit: uncore_m2m \000event=0x37,umask=0x701\000\00001\000\000 */
{ 4434658 }, /* unc_m2m_imc_writes.all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c10\000\00001\000\000 */
{ 4435127 }, /* unc_m2m_imc_writes.ch0_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x410\000\00001\000\000 */
{ 4435559 }, /* unc_m2m_imc_writes.ch0_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4435699 }, /* unc_m2m_imc_writes.ch0_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x401\000\00001\000\000 */
{ 4436030 }, /* unc_m2m_imc_writes.ch0_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x404\000\00001\000\000 */
{ 4436588 }, /* unc_m2m_imc_writes.ch0_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch0. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4436859 }, /* unc_m2m_imc_writes.ch0_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x402\000\00001\000\000 */
{ 4437197 }, /* unc_m2m_imc_writes.ch0_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch0. Unit: uncore_m2m \000event=0x38,umask=0x408\000\00001\000\000 */
{ 4438913 }, /* unc_m2m_imc_writes.ch1_all\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : All Writes - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x810\000\00001\000\000 */
{ 4439175 }, /* unc_m2m_imc_writes.ch1_from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4439486 }, /* unc_m2m_imc_writes.ch1_full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x801\000\00001\000\000 */
{ 4439780 }, /* unc_m2m_imc_writes.ch1_full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x804\000\00001\000\000 */
{ 4440192 }, /* unc_m2m_imc_writes.ch1_ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - Ch1. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4440463 }, /* unc_m2m_imc_writes.ch1_partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x802\000\00001\000\000 */
{ 4440931 }, /* unc_m2m_imc_writes.ch1_partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - Ch1. Unit: uncore_m2m \000event=0x38,umask=0x808\000\00001\000\000 */
{ 4442316 }, /* unc_m2m_imc_writes.from_tgr\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : From TGR - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4442760 }, /* unc_m2m_imc_writes.full\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Full Line Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c01\000\00001\000\000 */
{ 4443211 }, /* unc_m2m_imc_writes.full_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Full Line - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c04\000\00001\000\000 */
{ 4443940 }, /* unc_m2m_imc_writes.ni_miss\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Non-Inclusive Miss - All Channels. Unit: uncore_m2m \000event=0x38\000\00001\000\000 */
{ 4444221 }, /* unc_m2m_imc_writes.partial\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : Partial Non-ISOCH - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c02\000\00001\000\000 */
{ 4444957 }, /* unc_m2m_imc_writes.partial_isoch\000uncore_m2m\000uncore interconnect\000M2M Writes Issued to iMC : ISOCH Partial - All Channels. Unit: uncore_m2m \000event=0x38,umask=0x1c08\000\00001\000\000 */
{ 4446407 }, /* unc_m2m_mirr_wrq_inserts\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts. Unit: uncore_m2m \000event=0x64\000\00001\000\000 */
{ 4446520 }, /* unc_m2m_mirr_wrq_occupancy\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x65\000\00001\000\000 */
{ 4446637 }, /* unc_m2m_misc_external.mbe_inst0\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2m \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 4446830 }, /* unc_m2m_misc_external.mbe_inst1\000uncore_m2m\000uncore interconnect\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2m \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 4447023 }, /* unc_m2m_pkt_match.mc\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : MC Match. Unit: uncore_m2m \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 4447296 }, /* unc_m2m_pkt_match.mesh\000uncore_m2m\000uncore interconnect\000Number Packet Header Matches : Mesh Match. Unit: uncore_m2m \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 4448697 }, /* unc_m2m_prefcam_cis_drops\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_CIS_DROPS. Unit: uncore_m2m \000event=0x73\000\00001\000\000 */
{ 4448815 }, /* unc_m2m_prefcam_cycles_full.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : All Channels. Unit: uncore_m2m \000event=0x6b,umask=0x7\000\00001\000\000 */
{ 4448965 }, /* unc_m2m_prefcam_cycles_full.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x6b,umask=0x1\000\00001\000\000 */
{ 4449110 }, /* unc_m2m_prefcam_cycles_full.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x6b,umask=0x2\000\00001\000\000 */
{ 4449519 }, /* unc_m2m_prefcam_cycles_ne.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : All Channels. Unit: uncore_m2m \000event=0x6c,umask=0x7\000\00001\000\000 */
{ 4449672 }, /* unc_m2m_prefcam_cycles_ne.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x6c,umask=0x1\000\00001\000\000 */
{ 4449820 }, /* unc_m2m_prefcam_cycles_ne.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x6c,umask=0x2\000\00001\000\000 */
{ 4450238 }, /* unc_m2m_prefcam_deallocs.ch0_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x1\000\00001\000\000 */
{ 4450377 }, /* unc_m2m_prefcam_deallocs.ch0_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x2\000\00001\000\000 */
{ 4450516 }, /* unc_m2m_prefcam_deallocs.ch0_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x4\000\00001\000\000 */
{ 4450654 }, /* unc_m2m_prefcam_deallocs.ch0_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x8\000\00001\000\000 */
{ 4450793 }, /* unc_m2m_prefcam_deallocs.ch1_hita0_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x10\000\00001\000\000 */
{ 4450933 }, /* unc_m2m_prefcam_deallocs.ch1_hita1_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x20\000\00001\000\000 */
{ 4451073 }, /* unc_m2m_prefcam_deallocs.ch1_miss_inval\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x40\000\00001\000\000 */
{ 4451212 }, /* unc_m2m_prefcam_deallocs.ch1_rsp_pdreset\000uncore_m2m\000uncore interconnect\000Prefetch CAM Deallocs. Unit: uncore_m2m \000event=0x6e,umask=0x80\000\00001\000\000 */
{ 4452154 }, /* unc_m2m_prefcam_demand_drops.ch0_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 0. Unit: uncore_m2m \000event=0x6f,umask=0x1\000\00001\000\000 */
{ 4452728 }, /* unc_m2m_prefcam_demand_drops.ch1_xpt\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - Ch 1. Unit: uncore_m2m \000event=0x6f,umask=0x4\000\00001\000\000 */
{ 4453638 }, /* unc_m2m_prefcam_demand_drops.xpt_allch\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped : XPT - All Channels. Unit: uncore_m2m \000event=0x6f,umask=0x15\000\00001\000\000 */
{ 4453938 }, /* unc_m2m_prefcam_demand_merge.ch0_xpt\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - Ch 0. Unit: uncore_m2m \000event=0x74,umask=0x1\000\00001\000\000 */
{ 4454101 }, /* unc_m2m_prefcam_demand_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 0. Unit: uncore_m2m \000event=0x74,umask=0x1\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 0\000 */
{ 4454327 }, /* unc_m2m_prefcam_demand_merge.ch1_xpt\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - Ch 1. Unit: uncore_m2m \000event=0x74,umask=0x4\000\00001\000\000 */
{ 4454490 }, /* unc_m2m_prefcam_demand_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x74,umask=0x4\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 1\000 */
{ 4454716 }, /* unc_m2m_prefcam_demand_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- Ch 2. Unit: uncore_m2m \000event=0x74,umask=0x10\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - Ch 2\000 */
{ 4455215 }, /* unc_m2m_prefcam_demand_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT - All Channels. Unit: uncore_m2m \000event=0x74,umask=0x15\000\00001\000\000 */
{ 4455389 }, /* unc_m2m_prefcam_demand_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Merged with CAMed Prefetches : XPT & UPI- All Channels. Unit: uncore_m2m \000event=0x74,umask=0x15\000\00001\000Demands Merged with CAMed Prefetches : XPT & UPI - All Channels\000 */
{ 4455634 }, /* unc_m2m_prefcam_demand_no_merge.ch0_xpt\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - Ch 0. Unit: uncore_m2m \000event=0x75,umask=0x1\000\00001\000\000 */
{ 4455804 }, /* unc_m2m_prefcam_demand_no_merge.ch0_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 0. Unit: uncore_m2m \000event=0x75,umask=0x1\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 0\000 */
{ 4456041 }, /* unc_m2m_prefcam_demand_no_merge.ch1_xpt\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - Ch 1. Unit: uncore_m2m \000event=0x75,umask=0x4\000\00001\000\000 */
{ 4456211 }, /* unc_m2m_prefcam_demand_no_merge.ch1_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 1. Unit: uncore_m2m \000event=0x75,umask=0x4\000\00001\000Demands Not Merged with CAMed Prefetches : XPT & UPI- Ch 1\000 */
{ 4456448 }, /* unc_m2m_prefcam_demand_no_merge.ch2_xptupi\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - Ch 2. Unit: uncore_m2m \000event=0x75,umask=0x10\000\00001\000\000 */
{ 4457110 }, /* unc_m2m_prefcam_demand_no_merge.xpt_allch\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT - All Channels. Unit: uncore_m2m \000event=0x75,umask=0x15\000\00001\000\000 */
{ 4457291 }, /* unc_m2m_prefcam_demand_no_merge.xptupi_allch\000uncore_m2m\000uncore interconnect\000Demands Not Merged with CAMed Prefetches : XPT & UPI - All Channels. Unit: uncore_m2m \000event=0x75,umask=0x15\000\00001\000\000 */
{ 4457895 }, /* unc_m2m_prefcam_drop_reasons_ch0.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x10\000\00001\000\000 */
{ 4458056 }, /* unc_m2m_prefcam_drop_reasons_ch0.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x2\000\00001\000\000 */
{ 4458221 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x20\000\00001\000\000 */
{ 4458379 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x40\000\00001\000\000 */
{ 4458539 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x4\000\00001\000\000 */
{ 4458697 }, /* unc_m2m_prefcam_drop_reasons_ch0.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x1\000\00001\000\000 */
{ 4458859 }, /* unc_m2m_prefcam_drop_reasons_ch0.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000 */
{ 4459006 }, /* unc_m2m_prefcam_drop_reasons_ch0.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x8\000\00001\000\000 */
{ 4459310 }, /* unc_m2m_prefcam_drop_reasons_ch0.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70,umask=0x80\000\00001\000\000 */
{ 4459468 }, /* unc_m2m_prefcam_drop_reasons_ch0.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch0 - Reasons. Unit: uncore_m2m \000event=0x70\000\00001\000\000 */
{ 4459616 }, /* unc_m2m_prefcam_drop_reasons_ch1.errorblk_rxc\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x10\000\00001\000\000 */
{ 4459777 }, /* unc_m2m_prefcam_drop_reasons_ch1.not_pf_sad_region\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x2\000\00001\000\000 */
{ 4459942 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_ad_crd\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x20\000\00001\000\000 */
{ 4460100 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_cam_full\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x40\000\00001\000\000 */
{ 4460260 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_cam_hit\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x4\000\00001\000\000 */
{ 4460418 }, /* unc_m2m_prefcam_drop_reasons_ch1.pf_secure_drop\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x1\000\00001\000\000 */
{ 4460580 }, /* unc_m2m_prefcam_drop_reasons_ch1.rpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000 */
{ 4460727 }, /* unc_m2m_prefcam_drop_reasons_ch1.stop_b2b\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x8\000\00001\000\000 */
{ 4461031 }, /* unc_m2m_prefcam_drop_reasons_ch1.wpq_proxy\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71,umask=0x80\000\00001\000\000 */
{ 4461189 }, /* unc_m2m_prefcam_drop_reasons_ch1.xpt_thresh\000uncore_m2m\000uncore interconnect\000Data Prefetches Dropped Ch1 - Reasons. Unit: uncore_m2m \000event=0x71\000\00001\000\000 */
{ 4463484 }, /* unc_m2m_prefcam_inserts.ch0_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 0. Unit: uncore_m2m \000event=0x6d,umask=0x1\000\00001\000\000 */
{ 4464052 }, /* unc_m2m_prefcam_inserts.ch1_xpt\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - Ch 1. Unit: uncore_m2m \000event=0x6d,umask=0x4\000\00001\000\000 */
{ 4464977 }, /* unc_m2m_prefcam_inserts.xpt_allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Inserts : XPT - All Channels. Unit: uncore_m2m \000event=0x6d,umask=0x15\000\00001\000\000 */
{ 4465619 }, /* unc_m2m_prefcam_occupancy.allch\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : All Channels. Unit: uncore_m2m \000event=0x6a,umask=0x7\000\00001\000\000 */
{ 4465906 }, /* unc_m2m_prefcam_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 0. Unit: uncore_m2m \000event=0x6a,umask=0x1\000\00001\000\000 */
{ 4466188 }, /* unc_m2m_prefcam_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Prefetch CAM Occupancy : Channel 1. Unit: uncore_m2m \000event=0x6a,umask=0x2\000\00001\000\000 */
{ 4466585 }, /* unc_m2m_prefcam_resp_miss.allch\000uncore_m2m\000uncore interconnect\000: All Channels. Unit: uncore_m2m \000event=0x76,umask=0x7\000\00001\000\000 */
{ 4466947 }, /* unc_m2m_prefcam_resp_miss.ch0\000uncore_m2m\000uncore interconnect\000: Channel 0. Unit: uncore_m2m \000event=0x76,umask=0x1\000\00001\000\000 */
{ 4467183 }, /* unc_m2m_prefcam_resp_miss.ch1\000uncore_m2m\000uncore interconnect\000: Channel 1. Unit: uncore_m2m \000event=0x76,umask=0x2\000\00001\000\000 */
{ 4467419 }, /* unc_m2m_prefcam_rxc_cycles_ne\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_CYCLES_NE. Unit: uncore_m2m \000event=0x79\000\00001\000\000 */
{ 4467701 }, /* unc_m2m_prefcam_rxc_deallocs.1lm_posted\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.1LM_POSTED. Unit: uncore_m2m \000event=0x7a,umask=0x2\000\00001\000\000 */
{ 4467999 }, /* unc_m2m_prefcam_rxc_deallocs.cis\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.CIS. Unit: uncore_m2m \000event=0x7a,umask=0x8\000\00001\000\000 */
{ 4468637 }, /* unc_m2m_prefcam_rxc_deallocs.squashed\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_DEALLOCS.SQUASHED. Unit: uncore_m2m \000event=0x7a,umask=0x1\000\00001\000\000 */
{ 4468789 }, /* unc_m2m_prefcam_rxc_inserts\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_INSERTS. Unit: uncore_m2m \000event=0x78\000\00001\000\000 */
{ 4469052 }, /* unc_m2m_prefcam_rxc_occupancy\000uncore_m2m\000uncore interconnect\000UNC_M2M_PREFCAM_RxC_OCCUPANCY. Unit: uncore_m2m \000event=0x77\000\00001\000\000 */
{ 4469178 }, /* unc_m2m_ring_bounces_horz.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2m \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4469724 }, /* unc_m2m_ring_bounces_horz.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2m \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470270 }, /* unc_m2m_ring_bounces_horz.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2m \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4470816 }, /* unc_m2m_ring_bounces_horz.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2m \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4471362 }, /* unc_m2m_ring_bounces_vert.ad\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2m \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4471898 }, /* unc_m2m_ring_bounces_vert.ak\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2m \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472500 }, /* unc_m2m_ring_bounces_vert.akc\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. Unit: uncore_m2m \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4472785 }, /* unc_m2m_ring_bounces_vert.bl\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2m \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473381 }, /* unc_m2m_ring_bounces_vert.iv\000uncore_m2m\000uncore interconnect\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2m \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4473993 }, /* unc_m2m_ring_sink_starved_horz.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2m \000event=0xad,umask=0x1\000\00001\000\000 */
{ 4474292 }, /* unc_m2m_ring_sink_starved_horz.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2m \000event=0xad,umask=0x2\000\00001\000\000 */
{ 4474591 }, /* unc_m2m_ring_sink_starved_horz.ak_ag1\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2m \000event=0xad,umask=0x20\000\00001\000\000 */
{ 4474950 }, /* unc_m2m_ring_sink_starved_horz.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2m \000event=0xad,umask=0x4\000\00001\000\000 */
{ 4475249 }, /* unc_m2m_ring_sink_starved_horz.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2m \000event=0xad,umask=0x8\000\00001\000\000 */
{ 4475548 }, /* unc_m2m_ring_sink_starved_vert.ad\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2m \000event=0xab,umask=0x1\000\00001\000\000 */
{ 4475843 }, /* unc_m2m_ring_sink_starved_vert.ak\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2m \000event=0xab,umask=0x2\000\00001\000\000 */
{ 4476182 }, /* unc_m2m_ring_sink_starved_vert.akc\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring. Unit: uncore_m2m \000event=0xab,umask=0x10\000\00001\000\000 */
{ 4476327 }, /* unc_m2m_ring_sink_starved_vert.bl\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2m \000event=0xab,umask=0x4\000\00001\000\000 */
{ 4476662 }, /* unc_m2m_ring_sink_starved_vert.iv\000uncore_m2m\000uncore interconnect\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2m \000event=0xab,umask=0x8\000\00001\000\000 */
{ 4477112 }, /* unc_m2m_ring_src_thrtl\000uncore_m2m\000uncore interconnect\000Source Throttle. Unit: uncore_m2m \000event=0xae\000\00001\000\000 */
{ 4478804 }, /* unc_m2m_rpq_no_reg_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x43,umask=0x1\000\00001\000\000 */
{ 4478961 }, /* unc_m2m_rpq_no_reg_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x43,umask=0x2\000\00001\000\000 */
{ 4479743 }, /* unc_m2m_rpq_no_spec_crd.ch0\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4479901 }, /* unc_m2m_rpq_no_spec_crd.ch1\000uncore_m2m\000uncore interconnect\000M2M to iMC RPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4480217 }, /* unc_m2m_rxc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x4\000\00001\000\000 */
{ 4480336 }, /* unc_m2m_rxc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x3\000\00001\000\000 */
{ 4480614 }, /* unc_m2m_rxc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x1\000\00001\000\000 */
{ 4481030 }, /* unc_m2m_rxc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x2\000\00001\000\000 */
{ 4481274 }, /* unc_m2m_rxc_ad_pref_occupancy\000uncore_m2m\000uncore interconnect\000AD Ingress (from CMS) Occupancy - Prefetches. Unit: uncore_m2m \000event=0x77\000\00001\000\000 */
{ 4481415 }, /* unc_m2m_rxc_ak_wr_cmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x5c\000\00001\000\000 */
{ 4481534 }, /* unc_m2m_rxc_bl_cycles_full\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Full. Unit: uncore_m2m \000event=0x8\000\00001\000\000 */
{ 4481653 }, /* unc_m2m_rxc_bl_cycles_ne\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Not Empty. Unit: uncore_m2m \000event=0x7\000\00001\000\000 */
{ 4481775 }, /* unc_m2m_rxc_bl_inserts\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Allocations. Unit: uncore_m2m \000event=0x5\000\00001\000\000 */
{ 4481897 }, /* unc_m2m_rxc_bl_occupancy\000uncore_m2m\000uncore interconnect\000BL Ingress (from CMS) Occupancy. Unit: uncore_m2m \000event=0x6\000\00001\000\000 */
{ 4482019 }, /* unc_m2m_rxr_busy_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4482876 }, /* unc_m2m_rxr_busy_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4483713 }, /* unc_m2m_rxr_busy_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4484163 }, /* unc_m2m_rxr_busy_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4485020 }, /* unc_m2m_rxr_busy_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4485857 }, /* unc_m2m_rxr_busy_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4486307 }, /* unc_m2m_rxr_bypass.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2m \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4486744 }, /* unc_m2m_rxr_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4487161 }, /* unc_m2m_rxr_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4487398 }, /* unc_m2m_rxr_bypass.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AK. Unit: uncore_m2m \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 4487787 }, /* unc_m2m_rxr_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4488028 }, /* unc_m2m_rxr_bypass.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2m \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4488465 }, /* unc_m2m_rxr_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2m \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4488882 }, /* unc_m2m_rxr_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2m \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4489119 }, /* unc_m2m_rxr_bypass.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Bypass : IV. Unit: uncore_m2m \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 4489508 }, /* unc_m2m_rxr_crd_starved.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4490388 }, /* unc_m2m_rxr_crd_starved.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4491247 }, /* unc_m2m_rxr_crd_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4491708 }, /* unc_m2m_rxr_crd_starved.ak\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : AK. Unit: uncore_m2m \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4492539 }, /* unc_m2m_rxr_crd_starved.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4493419 }, /* unc_m2m_rxr_crd_starved.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4494278 }, /* unc_m2m_rxr_crd_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4494739 }, /* unc_m2m_rxr_crd_starved.ifv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2m \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4495595 }, /* unc_m2m_rxr_crd_starved.iv\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation : IV. Unit: uncore_m2m \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496426 }, /* unc_m2m_rxr_crd_starved_1\000uncore_m2m\000uncore interconnect\000Transgress Injection Starvation. Unit: uncore_m2m \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4496834 }, /* unc_m2m_rxr_inserts.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2m \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4497416 }, /* unc_m2m_rxr_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4497978 }, /* unc_m2m_rxr_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498290 }, /* unc_m2m_rxr_inserts.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AK. Unit: uncore_m2m \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4498824 }, /* unc_m2m_rxr_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4499140 }, /* unc_m2m_rxr_inserts.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2m \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4499722 }, /* unc_m2m_rxr_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2m \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500284 }, /* unc_m2m_rxr_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2m \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4500596 }, /* unc_m2m_rxr_inserts.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Allocations : IV. Unit: uncore_m2m \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4501130 }, /* unc_m2m_rxr_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2m \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4501726 }, /* unc_m2m_rxr_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502302 }, /* unc_m2m_rxr_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4502620 }, /* unc_m2m_rxr_occupancy.ak\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AK. Unit: uncore_m2m \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503168 }, /* unc_m2m_rxr_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4503490 }, /* unc_m2m_rxr_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2m \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4504086 }, /* unc_m2m_rxr_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504662 }, /* unc_m2m_rxr_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4504980 }, /* unc_m2m_rxr_occupancy.iv\000uncore_m2m\000uncore interconnect\000Transgress Ingress Occupancy : IV. Unit: uncore_m2m \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4506522 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4506880 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507238 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507596 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4507954 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4508313 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4508672 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509031 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509390 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4509748 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510106 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510464 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4510822 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511181 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511540 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4511899 }, /* unc_m2m_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512258 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512616 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4512974 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4513332 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4513690 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514049 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514408 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4514767 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515126 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2m \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515484 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2m \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4515842 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2m \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516200 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2m \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516558 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2m \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4516917 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2m \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517276 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2m \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517635 }, /* unc_m2m_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2m \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4517994 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4518355 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4518713 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519071 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519434 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4519794 }, /* unc_m2m_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520154 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520517 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4520877 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521237 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2m \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521600 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2m \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4521960 }, /* unc_m2m_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2m\000uncore interconnect\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2m \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4532786 }, /* unc_m2m_tgr_ad_credits\000uncore_m2m\000uncore interconnect\000Number AD Ingress Credits. Unit: uncore_m2m \000event=0x41\000\00001\000\000 */
{ 4533016 }, /* unc_m2m_tgr_bl_credits\000uncore_m2m\000uncore interconnect\000Number BL Ingress Credits. Unit: uncore_m2m \000event=0x42\000\00001\000\000 */
{ 4533974 }, /* unc_m2m_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4534107 }, /* unc_m2m_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4534507 }, /* unc_m2m_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x49,umask=0x1\000\00001\000\000 */
{ 4534904 }, /* unc_m2m_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x49,umask=0x2\000\00001\000\000 */
{ 4535430 }, /* unc_m2m_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4535566 }, /* unc_m2m_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4535974 }, /* unc_m2m_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4536381 }, /* unc_m2m_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4537046 }, /* unc_m2m_txc_ad_credit_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credits Occupancy. Unit: uncore_m2m \000event=0xe\000\00001\000\000 */
{ 4537180 }, /* unc_m2m_txc_ad_credits_acquired\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Credit Acquired. Unit: uncore_m2m \000event=0xd\000\00001\000\000 */
{ 4537312 }, /* unc_m2m_txc_ad_cycles_full\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Full. Unit: uncore_m2m \000event=0xc\000\00001\000\000 */
{ 4537428 }, /* unc_m2m_txc_ad_cycles_ne\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0xb\000\00001\000\000 */
{ 4537547 }, /* unc_m2m_txc_ad_inserts\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x9\000\00001\000\000 */
{ 4537666 }, /* unc_m2m_txc_ad_no_credit_cycles\000uncore_m2m\000uncore interconnect\000Cycles with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0xf\000\00001\000\000 */
{ 4537805 }, /* unc_m2m_txc_ad_no_credit_stalled\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AD Egress (to CMS) Credits. Unit: uncore_m2m \000event=0x10\000\00001\000\000 */
{ 4537954 }, /* unc_m2m_txc_ad_occupancy\000uncore_m2m\000uncore interconnect\000AD Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0xa\000\00001\000\000 */
{ 4538073 }, /* unc_m2m_txc_ak.crd_cbo\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : CRD Transactions to Cbo. Unit: uncore_m2m \000event=0x39,umask=0x2\000\00001\000\000 */
{ 4538388 }, /* unc_m2m_txc_ak.ndr\000uncore_m2m\000uncore interconnect\000Outbound Ring Transactions on AK : NDR Transactions. Unit: uncore_m2m \000event=0x39,umask=0x1\000\00001\000\000 */
{ 4539040 }, /* unc_m2m_txc_ak_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1d,umask=0x1\000\00001\000\000 */
{ 4539397 }, /* unc_m2m_txc_ak_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1d,umask=0x2\000\00001\000\000 */
{ 4539752 }, /* unc_m2m_txc_ak_cycles_full.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x14,umask=0x3\000\00001\000\000 */
{ 4540025 }, /* unc_m2m_txc_ak_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4540350 }, /* unc_m2m_txc_ak_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4540673 }, /* unc_m2m_txc_ak_cycles_full.rdcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4540962 }, /* unc_m2m_txc_ak_cycles_full.rdcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x88\000\00001\000\000 */
{ 4541253 }, /* unc_m2m_txc_ak_cycles_full.wrcmp0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x20\000\00001\000\000 */
{ 4541546 }, /* unc_m2m_txc_ak_cycles_full.wrcmp1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0xa0\000\00001\000\000 */
{ 4541839 }, /* unc_m2m_txc_ak_cycles_full.wrcrd0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4542131 }, /* unc_m2m_txc_ak_cycles_full.wrcrd1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Full. Unit: uncore_m2m \000event=0x14,umask=0x90\000\00001\000\000 */
{ 4542423 }, /* unc_m2m_txc_ak_cycles_ne.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x13,umask=0x3\000\00001\000\000 */
{ 4542702 }, /* unc_m2m_txc_ak_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x13,umask=0x1\000\00001\000\000 */
{ 4543033 }, /* unc_m2m_txc_ak_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x13,umask=0x2\000\00001\000\000 */
{ 4543362 }, /* unc_m2m_txc_ak_cycles_ne.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x8\000\00001\000\000 */
{ 4543655 }, /* unc_m2m_txc_ak_cycles_ne.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x20\000\00001\000\000 */
{ 4543952 }, /* unc_m2m_txc_ak_cycles_ne.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Not Empty. Unit: uncore_m2m \000event=0x13,umask=0x10\000\00001\000\000 */
{ 4544248 }, /* unc_m2m_txc_ak_inserts.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x11,umask=0x3\000\00001\000\000 */
{ 4544527 }, /* unc_m2m_txc_ak_inserts.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x11,umask=0x1\000\00001\000\000 */
{ 4544858 }, /* unc_m2m_txc_ak_inserts.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x11,umask=0x2\000\00001\000\000 */
{ 4545187 }, /* unc_m2m_txc_ak_inserts.pref_rd_cam_hit\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x40\000\00001\000\000 */
{ 4545504 }, /* unc_m2m_txc_ak_inserts.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x8\000\00001\000\000 */
{ 4545797 }, /* unc_m2m_txc_ak_inserts.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x20\000\00001\000\000 */
{ 4546094 }, /* unc_m2m_txc_ak_inserts.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Allocations. Unit: uncore_m2m \000event=0x11,umask=0x10\000\00001\000\000 */
{ 4546390 }, /* unc_m2m_txc_ak_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1f,umask=0x1\000\00001\000\000 */
{ 4546761 }, /* unc_m2m_txc_ak_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1f,umask=0x2\000\00001\000\000 */
{ 4547130 }, /* unc_m2m_txc_ak_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x20,umask=0x1\000\00001\000\000 */
{ 4547519 }, /* unc_m2m_txc_ak_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No AK Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x20,umask=0x2\000\00001\000\000 */
{ 4547906 }, /* unc_m2m_txc_ak_occupancy.all\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : All. Unit: uncore_m2m \000event=0x12,umask=0x3\000\00001\000\000 */
{ 4548185 }, /* unc_m2m_txc_ak_occupancy.cms0\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x12,umask=0x1\000\00001\000\000 */
{ 4548516 }, /* unc_m2m_txc_ak_occupancy.cms1\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x12,umask=0x2\000\00001\000\000 */
{ 4548845 }, /* unc_m2m_txc_ak_occupancy.rdcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x8\000\00001\000\000 */
{ 4549138 }, /* unc_m2m_txc_ak_occupancy.wrcmp\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x20\000\00001\000\000 */
{ 4549435 }, /* unc_m2m_txc_ak_occupancy.wrcrd\000uncore_m2m\000uncore interconnect\000AK Egress (to CMS) Occupancy. Unit: uncore_m2m \000event=0x12,umask=0x10\000\00001\000\000 */
{ 4549993 }, /* unc_m2m_txc_akc_credits\000uncore_m2m\000uncore interconnect\000AKC Credits. Unit: uncore_m2m \000event=0x5f\000\00001\000\000 */
{ 4550095 }, /* unc_m2m_txc_bl.drs_cache\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Cache. Unit: uncore_m2m \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4550408 }, /* unc_m2m_txc_bl.drs_core\000uncore_m2m\000uncore interconnect\000Outbound DRS Ring Transactions to Cache : Data to Core. Unit: uncore_m2m \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4551381 }, /* unc_m2m_txc_bl_credits_acquired.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4551738 }, /* unc_m2m_txc_bl_credits_acquired.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Credit Acquired : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4552093 }, /* unc_m2m_txc_bl_cycles_full.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : All. Unit: uncore_m2m \000event=0x18,umask=0x3\000\00001\000\000 */
{ 4552366 }, /* unc_m2m_txc_bl_cycles_full.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4552691 }, /* unc_m2m_txc_bl_cycles_full.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Full : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4553014 }, /* unc_m2m_txc_bl_cycles_ne.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : All. Unit: uncore_m2m \000event=0x17,umask=0x3\000\00001\000\000 */
{ 4553293 }, /* unc_m2m_txc_bl_cycles_ne.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4553624 }, /* unc_m2m_txc_bl_cycles_ne.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Not Empty : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4553953 }, /* unc_m2m_txc_bl_inserts.all\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : All. Unit: uncore_m2m \000event=0x15,umask=0x3\000\00001\000\000 */
{ 4554232 }, /* unc_m2m_txc_bl_inserts.cms0\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4554563 }, /* unc_m2m_txc_bl_inserts.cms1\000uncore_m2m\000uncore interconnect\000BL Egress (to CMS) Allocations : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4554892 }, /* unc_m2m_txc_bl_no_credit_cycles.cms0\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1b,umask=0x1\000\00001\000\000 */
{ 4555263 }, /* unc_m2m_txc_bl_no_credit_cycles.cms1\000uncore_m2m\000uncore interconnect\000Cycles with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1b,umask=0x2\000\00001\000\000 */
{ 4555632 }, /* unc_m2m_txc_bl_no_credit_stalled.cms0\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Near Side. Unit: uncore_m2m \000event=0x1c,umask=0x1\000\00001\000\000 */
{ 4556021 }, /* unc_m2m_txc_bl_no_credit_stalled.cms1\000uncore_m2m\000uncore interconnect\000Cycles Stalled with No BL Egress (to CMS) Credits : Common Mesh Stop - Far Side. Unit: uncore_m2m \000event=0x1c,umask=0x2\000\00001\000\000 */
{ 4556876 }, /* unc_m2m_txr_horz_ads_used.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2m \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4557430 }, /* unc_m2m_txr_horz_ads_used.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4557963 }, /* unc_m2m_txr_horz_ads_used.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4558500 }, /* unc_m2m_txr_horz_ads_used.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2m \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4559054 }, /* unc_m2m_txr_horz_ads_used.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2m \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559587 }, /* unc_m2m_txr_horz_ads_used.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4559881 }, /* unc_m2m_txr_horz_bypass.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2m \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4560424 }, /* unc_m2m_txr_horz_bypass.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4560946 }, /* unc_m2m_txr_horz_bypass.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561236 }, /* unc_m2m_txr_horz_bypass.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2m \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4561730 }, /* unc_m2m_txr_horz_bypass.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4562024 }, /* unc_m2m_txr_horz_bypass.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2m \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4562567 }, /* unc_m2m_txr_horz_bypass.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2m \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563089 }, /* unc_m2m_txr_horz_bypass.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2m \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563379 }, /* unc_m2m_txr_horz_bypass.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2m \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4563873 }, /* unc_m2m_txr_horz_cycles_full.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2m \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4564594 }, /* unc_m2m_txr_horz_cycles_full.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4565294 }, /* unc_m2m_txr_horz_cycles_full.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4565681 }, /* unc_m2m_txr_horz_cycles_full.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2m \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566353 }, /* unc_m2m_txr_horz_cycles_full.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4566744 }, /* unc_m2m_txr_horz_cycles_full.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2m \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4567465 }, /* unc_m2m_txr_horz_cycles_full.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2m \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568165 }, /* unc_m2m_txr_horz_cycles_full.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2m \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4568552 }, /* unc_m2m_txr_horz_cycles_full.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2m \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4569224 }, /* unc_m2m_txr_horz_cycles_ne.ad_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2m \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4569966 }, /* unc_m2m_txr_horz_cycles_ne.ad_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4570687 }, /* unc_m2m_txr_horz_cycles_ne.ad_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571087 }, /* unc_m2m_txr_horz_cycles_ne.ak\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2m \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4571780 }, /* unc_m2m_txr_horz_cycles_ne.akc_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4572184 }, /* unc_m2m_txr_horz_cycles_ne.bl_all\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2m \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4572926 }, /* unc_m2m_txr_horz_cycles_ne.bl_crd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2m \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4573647 }, /* unc_m2m_txr_horz_cycles_ne.bl_uncrd\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2m \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574047 }, /* unc_m2m_txr_horz_cycles_ne.iv\000uncore_m2m\000uncore interconnect\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2m \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4574740 }, /* unc_m2m_txr_horz_inserts.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2m \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4575434 }, /* unc_m2m_txr_horz_inserts.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576107 }, /* unc_m2m_txr_horz_inserts.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4576474 }, /* unc_m2m_txr_horz_inserts.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2m \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577119 }, /* unc_m2m_txr_horz_inserts.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4577490 }, /* unc_m2m_txr_horz_inserts.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2m \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4578184 }, /* unc_m2m_txr_horz_inserts.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2m \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4578857 }, /* unc_m2m_txr_horz_inserts.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2m \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579224 }, /* unc_m2m_txr_horz_inserts.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2m \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4579869 }, /* unc_m2m_txr_horz_nack.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2m \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4580362 }, /* unc_m2m_txr_horz_nack.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4580835 }, /* unc_m2m_txr_horz_nack.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581101 }, /* unc_m2m_txr_horz_nack.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2m \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581546 }, /* unc_m2m_txr_horz_nack.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4581816 }, /* unc_m2m_txr_horz_nack.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2m \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4582309 }, /* unc_m2m_txr_horz_nack.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2m \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4582782 }, /* unc_m2m_txr_horz_nack.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2m \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583048 }, /* unc_m2m_txr_horz_nack.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2m \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4583493 }, /* unc_m2m_txr_horz_occupancy.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2m \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4584183 }, /* unc_m2m_txr_horz_occupancy.ad_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4584852 }, /* unc_m2m_txr_horz_occupancy.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585218 }, /* unc_m2m_txr_horz_occupancy.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2m \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4585859 }, /* unc_m2m_txr_horz_occupancy.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4586229 }, /* unc_m2m_txr_horz_occupancy.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2m \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4586919 }, /* unc_m2m_txr_horz_occupancy.bl_crd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2m \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587588 }, /* unc_m2m_txr_horz_occupancy.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2m \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4587954 }, /* unc_m2m_txr_horz_occupancy.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2m \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4588595 }, /* unc_m2m_txr_horz_starved.ad_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4589341 }, /* unc_m2m_txr_horz_starved.ad_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4589741 }, /* unc_m2m_txr_horz_starved.ak\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2m \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590439 }, /* unc_m2m_txr_horz_starved.akc_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4590843 }, /* unc_m2m_txr_horz_starved.bl_all\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4591589 }, /* unc_m2m_txr_horz_starved.bl_uncrd\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2m \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4591989 }, /* unc_m2m_txr_horz_starved.iv\000uncore_m2m\000uncore interconnect\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4592687 }, /* unc_m2m_txr_vert_ads_used.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4593207 }, /* unc_m2m_txr_vert_ads_used.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594210 }, /* unc_m2m_txr_vert_ads_used.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4594730 }, /* unc_m2m_txr_vert_ads_used.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4595252 }, /* unc_m2m_txr_vert_bypass.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4595752 }, /* unc_m2m_txr_vert_bypass.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596254 }, /* unc_m2m_txr_vert_bypass.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4596754 }, /* unc_m2m_txr_vert_bypass.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597256 }, /* unc_m2m_txr_vert_bypass.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2m \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4597756 }, /* unc_m2m_txr_vert_bypass.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598474 }, /* unc_m2m_txr_vert_bypass.iv_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2m \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4598744 }, /* unc_m2m_txr_vert_bypass_1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2m \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4599019 }, /* unc_m2m_txr_vert_bypass_1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2m \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4602229 }, /* unc_m2m_txr_vert_cycles_full0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4602735 }, /* unc_m2m_txr_vert_cycles_full0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4603210 }, /* unc_m2m_txr_vert_cycles_full0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4603698 }, /* unc_m2m_txr_vert_cycles_full0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4604127 }, /* unc_m2m_txr_vert_cycles_full0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4604631 }, /* unc_m2m_txr_vert_cycles_full0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2m \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4605129 }, /* unc_m2m_txr_vert_cycles_full0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2m \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4605605 }, /* unc_m2m_txr_vert_cycles_full1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2m \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4606114 }, /* unc_m2m_txr_vert_cycles_full1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2m \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4609568 }, /* unc_m2m_txr_vert_cycles_ne0.ad_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4610083 }, /* unc_m2m_txr_vert_cycles_ne0.ad_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4610567 }, /* unc_m2m_txr_vert_cycles_ne0.ak_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4611064 }, /* unc_m2m_txr_vert_cycles_ne0.ak_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4611502 }, /* unc_m2m_txr_vert_cycles_ne0.bl_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4612015 }, /* unc_m2m_txr_vert_cycles_ne0.bl_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2m \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4612522 }, /* unc_m2m_txr_vert_cycles_ne0.iv_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2m \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4613007 }, /* unc_m2m_txr_vert_cycles_ne1.akc_ag0\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2m \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4613525 }, /* unc_m2m_txr_vert_cycles_ne1.akc_ag1\000uncore_m2m\000uncore interconnect\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2m \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4616820 }, /* unc_m2m_txr_vert_inserts0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4617293 }, /* unc_m2m_txr_vert_inserts0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4617735 }, /* unc_m2m_txr_vert_inserts0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4618190 }, /* unc_m2m_txr_vert_inserts0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4618586 }, /* unc_m2m_txr_vert_inserts0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4619057 }, /* unc_m2m_txr_vert_inserts0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2m \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4619522 }, /* unc_m2m_txr_vert_inserts0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2m \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4619965 }, /* unc_m2m_txr_vert_inserts1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2m \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4620441 }, /* unc_m2m_txr_vert_inserts1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2m \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4622344 }, /* unc_m2m_txr_vert_nack0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622597 }, /* unc_m2m_txr_vert_nack0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4622851 }, /* unc_m2m_txr_vert_nack0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623104 }, /* unc_m2m_txr_vert_nack0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623358 }, /* unc_m2m_txr_vert_nack0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2m \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623611 }, /* unc_m2m_txr_vert_nack0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2m \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4623865 }, /* unc_m2m_txr_vert_nack0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2m \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624098 }, /* unc_m2m_txr_vert_nack1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2m \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4624354 }, /* unc_m2m_txr_vert_nack1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2m \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4627454 }, /* unc_m2m_txr_vert_occupancy0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4627932 }, /* unc_m2m_txr_vert_occupancy0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4628379 }, /* unc_m2m_txr_vert_occupancy0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4628839 }, /* unc_m2m_txr_vert_occupancy0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4629240 }, /* unc_m2m_txr_vert_occupancy0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4629716 }, /* unc_m2m_txr_vert_occupancy0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2m \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4630186 }, /* unc_m2m_txr_vert_occupancy0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2m \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4630634 }, /* unc_m2m_txr_vert_occupancy1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2m \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4631115 }, /* unc_m2m_txr_vert_occupancy1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2m \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4633779 }, /* unc_m2m_txr_vert_starved0.ad_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634155 }, /* unc_m2m_txr_vert_starved0.ad_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634532 }, /* unc_m2m_txr_vert_starved0.ak_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4634908 }, /* unc_m2m_txr_vert_starved0.ak_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4635285 }, /* unc_m2m_txr_vert_starved0.bl_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2m \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4635661 }, /* unc_m2m_txr_vert_starved0.bl_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2m \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636038 }, /* unc_m2m_txr_vert_starved0.iv_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2m \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636394 }, /* unc_m2m_txr_vert_starved1.akc_ag0\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4636773 }, /* unc_m2m_txr_vert_starved1.akc_ag1\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2m \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4637152 }, /* unc_m2m_txr_vert_starved1.tgc\000uncore_m2m\000uncore interconnect\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2m \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4637527 }, /* unc_m2m_vert_ring_ad_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4639324 }, /* unc_m2m_vert_ring_ad_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4641116 }, /* unc_m2m_vert_ring_ad_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4642907 }, /* unc_m2m_vert_ring_ad_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4644693 }, /* unc_m2m_vert_ring_ak_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4646490 }, /* unc_m2m_vert_ring_ak_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4648282 }, /* unc_m2m_vert_ring_ak_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4650073 }, /* unc_m2m_vert_ring_ak_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4651859 }, /* unc_m2m_vert_ring_akc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4652787 }, /* unc_m2m_vert_ring_akc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4653712 }, /* unc_m2m_vert_ring_akc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4654636 }, /* unc_m2m_vert_ring_akc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4655557 }, /* unc_m2m_vert_ring_bl_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2m \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4657350 }, /* unc_m2m_vert_ring_bl_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4659138 }, /* unc_m2m_vert_ring_bl_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2m \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4660925 }, /* unc_m2m_vert_ring_bl_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2m \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4662707 }, /* unc_m2m_vert_ring_iv_in_use.dn\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Down. Unit: uncore_m2m \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4663857 }, /* unc_m2m_vert_ring_iv_in_use.up\000uncore_m2m\000uncore interconnect\000Vertical IV Ring in Use : Up. Unit: uncore_m2m \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4665001 }, /* unc_m2m_vert_ring_tgc_in_use.dn_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2m \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4665929 }, /* unc_m2m_vert_ring_tgc_in_use.dn_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4666854 }, /* unc_m2m_vert_ring_tgc_in_use.up_even\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2m \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4667778 }, /* unc_m2m_vert_ring_tgc_in_use.up_odd\000uncore_m2m\000uncore interconnect\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2m \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4670388 }, /* unc_m2m_wpq_flush.ch0\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 0. Unit: uncore_m2m \000event=0x58,umask=0x1\000\00001\000\000 */
{ 4670628 }, /* unc_m2m_wpq_flush.ch1\000uncore_m2m\000uncore interconnect\000WPQ Flush : Channel 1. Unit: uncore_m2m \000event=0x58,umask=0x2\000\00001\000\000 */
{ 4671024 }, /* unc_m2m_wpq_no_reg_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 0. Unit: uncore_m2m \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 4671336 }, /* unc_m2m_wpq_no_reg_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 1. Unit: uncore_m2m \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 4671492 }, /* unc_m2m_wpq_no_reg_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Regular : Channel 2. Unit: uncore_m2m \000event=0x4d,umask=0x4\000\00001\000\000 */
{ 4672273 }, /* unc_m2m_wpq_no_spec_crd.chn0\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 0. Unit: uncore_m2m \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 4672587 }, /* unc_m2m_wpq_no_spec_crd.chn1\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 1. Unit: uncore_m2m \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 4672744 }, /* unc_m2m_wpq_no_spec_crd.chn2\000uncore_m2m\000uncore interconnect\000M2M->iMC WPQ Cycles w/Credits - Special : Channel 2. Unit: uncore_m2m \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 4672901 }, /* unc_m2m_wr_tracker_full.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 0. Unit: uncore_m2m \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4673043 }, /* unc_m2m_wr_tracker_full.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Channel 1. Unit: uncore_m2m \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4673327 }, /* unc_m2m_wr_tracker_full.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Full : Mirror. Unit: uncore_m2m \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 4673608 }, /* unc_m2m_wr_tracker_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 0. Unit: uncore_m2m \000event=0x56,umask=0x1\000\00001\000\000 */
{ 4673890 }, /* unc_m2m_wr_tracker_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Inserts : Channel 1. Unit: uncore_m2m \000event=0x56,umask=0x2\000\00001\000\000 */
{ 4674317 }, /* unc_m2m_wr_tracker_ne.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 0. Unit: uncore_m2m \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4674607 }, /* unc_m2m_wr_tracker_ne.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Channel 1. Unit: uncore_m2m \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4675040 }, /* unc_m2m_wr_tracker_ne.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty : Mirror. Unit: uncore_m2m \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 4675324 }, /* unc_m2m_wr_tracker_ne.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x10\000\00001\000\000 */
{ 4675605 }, /* unc_m2m_wr_tracker_ne.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Cycles Not Empty. Unit: uncore_m2m \000event=0x4b,umask=0x20\000\00001\000\000 */
{ 4675906 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x63,umask=0x1\000\00001\000\000 */
{ 4676230 }, /* unc_m2m_wr_tracker_nonposted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x63,umask=0x2\000\00001\000\000 */
{ 4676720 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x62,umask=0x1\000\00001\000\000 */
{ 4677052 }, /* unc_m2m_wr_tracker_nonposted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Non-Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x62,umask=0x2\000\00001\000\000 */
{ 4677384 }, /* unc_m2m_wr_tracker_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 0. Unit: uncore_m2m \000event=0x55,umask=0x1\000\00001\000\000 */
{ 4677529 }, /* unc_m2m_wr_tracker_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Channel 1. Unit: uncore_m2m \000event=0x55,umask=0x2\000\00001\000\000 */
{ 4677819 }, /* unc_m2m_wr_tracker_occupancy.mirr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy : Mirror. Unit: uncore_m2m \000event=0x55,umask=0x8\000\00001\000\000 */
{ 4677962 }, /* unc_m2m_wr_tracker_occupancy.mirr_nontgr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x10\000\00001\000\000 */
{ 4678104 }, /* unc_m2m_wr_tracker_occupancy.mirr_pwr\000uncore_m2m\000uncore interconnect\000Write Tracker Occupancy. Unit: uncore_m2m \000event=0x55,umask=0x20\000\00001\000\000 */
{ 4678398 }, /* unc_m2m_wr_tracker_posted_inserts.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 0. Unit: uncore_m2m \000event=0x5e,umask=0x1\000\00001\000\000 */
{ 4678708 }, /* unc_m2m_wr_tracker_posted_inserts.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Inserts : Channel 1. Unit: uncore_m2m \000event=0x5e,umask=0x2\000\00001\000\000 */
{ 4679177 }, /* unc_m2m_wr_tracker_posted_occupancy.ch0\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 0. Unit: uncore_m2m \000event=0x5d,umask=0x1\000\00001\000\000 */
{ 4679495 }, /* unc_m2m_wr_tracker_posted_occupancy.ch1\000uncore_m2m\000uncore interconnect\000Write Tracker Posted Occupancy : Channel 1. Unit: uncore_m2m \000event=0x5d,umask=0x2\000\00001\000\000 */
{ 6073363 }, /* unc_u_clockticks\000uncore_ubox\000uncore interconnect\000Clockticks in the UBOX using a dedicated 48-bit Fixed Counter. Unit: uncore_ubox \000event=0xff\000\00001\000\000 */
{ 6073690 }, /* unc_u_event_msg.doorbell_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : Doorbell. Unit: uncore_ubox \000event=0x42,umask=0x8\000\00001\000\000 */
{ 6074265 }, /* unc_u_event_msg.int_prio\000uncore_ubox\000uncore interconnect\000Message Received : Interrupt. Unit: uncore_ubox \000event=0x42,umask=0x10\000\00001\000Message Received : Interrupt : Interrupts\000 */
{ 6074870 }, /* unc_u_event_msg.ipi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : IPI. Unit: uncore_ubox \000event=0x42,umask=0x4\000\00001\000Message Received : IPI : Inter Processor Interrupts\000 */
{ 6075510 }, /* unc_u_event_msg.msi_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : MSI. Unit: uncore_ubox \000event=0x42,umask=0x2\000\00001\000Message Received : MSI : Message Signaled Interrupts - interrupts sent by devices (including PCIe via IOxAPIC) (Socket Mode only)\000 */
{ 6076306 }, /* unc_u_event_msg.vlw_rcvd\000uncore_ubox\000uncore interconnect\000Message Received : VLW. Unit: uncore_ubox \000event=0x42,umask=0x1\000\00001\000Message Received : VLW : Virtual Logical Wire (legacy) message were received from Uncore\000 */
{ 6077892 }, /* unc_u_lock_cycles\000uncore_ubox\000uncore interconnect\000IDI Lock/SplitLock Cycles. Unit: uncore_ubox \000event=0x44\000\00001\000IDI Lock/SplitLock Cycles : Number of times an IDI Lock/SplitLock sequence was started\000 */
{ 6078260 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x1\000\00001\000\000 */
{ 6078414 }, /* unc_u_m2u_misc1.rxc_cycles_ne_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.RxC_CYCLES_NE_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x2\000\00001\000\000 */
{ 6078876 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCB. Unit: uncore_ubox \000event=0x4d,umask=0x10\000\00001\000\000 */
{ 6079041 }, /* unc_u_m2u_misc1.txc_cycles_crd_ovf_cbo_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC1.TxC_CYCLES_CRD_OVF_CBO_NCS. Unit: uncore_ubox \000event=0x4d,umask=0x20\000\00001\000\000 */
{ 6079536 }, /* unc_u_m2u_misc2.rxc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x2\000\00001\000\000 */
{ 6079686 }, /* unc_u_m2u_misc2.rxc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.RxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x1\000\00001\000\000 */
{ 6079834 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncb\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCB. Unit: uncore_ubox \000event=0x4e,umask=0x4\000\00001\000\000 */
{ 6079998 }, /* unc_u_m2u_misc2.txc_cycles_crd_ovf_vn0_ncs\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_CRD_OVF_VN0_NCS. Unit: uncore_ubox \000event=0x4e,umask=0x8\000\00001\000\000 */
{ 6080162 }, /* unc_u_m2u_misc2.txc_cycles_empty_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AK. Unit: uncore_ubox \000event=0x4e,umask=0x20\000\00001\000\000 */
{ 6080313 }, /* unc_u_m2u_misc2.txc_cycles_empty_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_AKC. Unit: uncore_ubox \000event=0x4e,umask=0x40\000\00001\000\000 */
{ 6080466 }, /* unc_u_m2u_misc2.txc_cycles_empty_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_EMPTY_BL. Unit: uncore_ubox \000event=0x4e,umask=0x10\000\00001\000\000 */
{ 6080617 }, /* unc_u_m2u_misc2.txc_cycles_full_bl\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC2.TxC_CYCLES_FULL_BL. Unit: uncore_ubox \000event=0x4e,umask=0x80\000\00001\000\000 */
{ 6080766 }, /* unc_u_m2u_misc3.txc_cycles_full_ak\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AK. Unit: uncore_ubox \000event=0x4f,umask=0x1\000\00001\000\000 */
{ 6080914 }, /* unc_u_m2u_misc3.txc_cycles_full_akc\000uncore_ubox\000uncore interconnect\000UNC_U_M2U_MISC3.TxC_CYCLES_FULL_AKC. Unit: uncore_ubox \000event=0x4f,umask=0x2\000\00001\000\000 */
{ 6081763 }, /* unc_u_phold_cycles.assert_to_ack\000uncore_ubox\000uncore interconnect\000Cycles PHOLD Assert to Ack : Assert to ACK. Unit: uncore_ubox \000event=0x45,umask=0x1\000\00001\000Cycles PHOLD Assert to Ack : Assert to ACK : PHOLD cycles\000 */
{ 6082332 }, /* unc_u_racu_drng.pftch_buf_empty\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.PFTCH_BUF_EMPTY. Unit: uncore_ubox \000event=0x4c,umask=0x4\000\00001\000\000 */
{ 6082474 }, /* unc_u_racu_drng.rdrand\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDRAND. Unit: uncore_ubox \000event=0x4c,umask=0x1\000\00001\000\000 */
{ 6082598 }, /* unc_u_racu_drng.rdseed\000uncore_ubox\000uncore interconnect\000UNC_U_RACU_DRNG.RDSEED. Unit: uncore_ubox \000event=0x4c,umask=0x2\000\00001\000\000 */
{ 6083007 }, /* unc_u_racu_requests\000uncore_ubox\000uncore interconnect\000RACU Request. Unit: uncore_ubox \000event=0x46\000\00001\000RACU Request : Number outstanding register requests within message channel tracker\000 */
{ 1217336 }, /* llc_misses.pcie_read\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4,ch_mask=0x1f\000\000014Bytes\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 1219302 }, /* llc_misses.pcie_write\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1,ch_mask=0x1f\000\000014Bytes\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3924647 }, /* unc_iio_bandwidth_in.part0_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x20\000\00001\000\000 */
{ 3924873 }, /* unc_iio_bandwidth_in.part1_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x21\000\00001\000\000 */
{ 3925099 }, /* unc_iio_bandwidth_in.part2_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x22\000\00001\000\000 */
{ 3925325 }, /* unc_iio_bandwidth_in.part3_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x23\000\00001\000\000 */
{ 3925551 }, /* unc_iio_bandwidth_in.part4_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x24\000\00001\000\000 */
{ 3925777 }, /* unc_iio_bandwidth_in.part5_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x25\000\00001\000\000 */
{ 3926003 }, /* unc_iio_bandwidth_in.part6_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x26\000\00001\000\000 */
{ 3926229 }, /* unc_iio_bandwidth_in.part7_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for every 32 bytes of data sent from the IO agent to the SOC. Unit: uncore_iio_free_running \000event=0xff,umask=0x27\000\00001\000\000 */
{ 3928905 }, /* unc_iio_clockticks\000uncore_iio\000uncore io\000Clockticks of the integrated IO (IIO) traffic controller. Unit: uncore_iio \000event=0x1\000\00001\000\000 */
{ 3929193 }, /* unc_iio_clockticks_freerun\000uncore_iio_free_running\000uncore io\000Free running counter that increments for IIO clocktick. Unit: uncore_iio_free_running \000event=0xff,umask=0x10\000\00001\000Free running counter that increments for integrated IO (IIO) traffic controller clockticks\000 */
{ 3929633 }, /* unc_iio_comp_buf_inserts.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts : All Ports. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x04,umask=0x3\000\00001\000\000 */
{ 3929999 }, /* unc_iio_comp_buf_inserts.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0-7. Unit: uncore_iio \000event=0xc2,ch_mask=0xff,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0-7\000 */
{ 3930900 }, /* unc_iio_comp_buf_inserts.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 0. Unit: uncore_iio \000event=0xc2,ch_mask=0x01,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3931829 }, /* unc_iio_comp_buf_inserts.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 1. Unit: uncore_iio \000event=0xc2,ch_mask=0x02,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000 */
{ 3932758 }, /* unc_iio_comp_buf_inserts.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 2. Unit: uncore_iio \000event=0xc2,ch_mask=0x04,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000 */
{ 3933687 }, /* unc_iio_comp_buf_inserts.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 3. Unit: uncore_iio \000event=0xc2,ch_mask=0x08,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000 */
{ 3934616 }, /* unc_iio_comp_buf_inserts.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 4. Unit: uncore_iio \000event=0xc2,ch_mask=0x10,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000 */
{ 3935354 }, /* unc_iio_comp_buf_inserts.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 5. Unit: uncore_iio \000event=0xc2,ch_mask=0x20,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000 */
{ 3936092 }, /* unc_iio_comp_buf_inserts.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 6. Unit: uncore_iio \000event=0xc2,ch_mask=0x40,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000 */
{ 3936830 }, /* unc_iio_comp_buf_inserts.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Inserts of completions with data: Part 7. Unit: uncore_iio \000event=0xc2,ch_mask=0x80,fc_mask=0x04,umask=0x3\000\00001\000PCIe Completion Buffer Inserts of completions with data : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000 */
{ 3937839 }, /* unc_iio_comp_buf_occupancy.cmpd.all\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000 */
{ 3938067 }, /* unc_iio_comp_buf_occupancy.cmpd.all_parts\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0-7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0xff\000\00001\000PCIe Completion Buffer Occupancy : Part 0-7\000 */
{ 3938933 }, /* unc_iio_comp_buf_occupancy.cmpd.part0\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 0. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x1\000\00001\000PCIe Completion Buffer Occupancy : Part 0 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3939661 }, /* unc_iio_comp_buf_occupancy.cmpd.part1\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 1. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x2\000\00001\000PCIe Completion Buffer Occupancy : Part 1 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 1\000 */
{ 3940424 }, /* unc_iio_comp_buf_occupancy.cmpd.part2\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 2. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x4\000\00001\000PCIe Completion Buffer Occupancy : Part 2 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 2\000 */
{ 3941152 }, /* unc_iio_comp_buf_occupancy.cmpd.part3\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 3. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x8\000\00001\000PCIe Completion Buffer Occupancy : Part 3 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 3\000 */
{ 3941948 }, /* unc_iio_comp_buf_occupancy.cmpd.part4\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 4. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x10\000\00001\000PCIe Completion Buffer Occupancy : Part 4 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 4\000 */
{ 3942494 }, /* unc_iio_comp_buf_occupancy.cmpd.part5\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 5. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x20\000\00001\000PCIe Completion Buffer Occupancy : Part 5 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 5\000 */
{ 3943075 }, /* unc_iio_comp_buf_occupancy.cmpd.part6\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 6. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x40\000\00001\000PCIe Completion Buffer Occupancy : Part 6 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 6\000 */
{ 3943621 }, /* unc_iio_comp_buf_occupancy.cmpd.part7\000uncore_iio\000uncore io\000PCIe Completion Buffer Occupancy of completions with data : Part 7. Unit: uncore_iio \000event=0xd5,fc_mask=0x04,umask=0x80\000\00001\000PCIe Completion Buffer Occupancy : Part 7 : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 7\000 */
{ 3943956 }, /* unc_iio_data_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3944369 }, /* unc_iio_data_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3944782 }, /* unc_iio_data_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3945673 }, /* unc_iio_data_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3946421 }, /* unc_iio_data_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3947239 }, /* unc_iio_data_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3947987 }, /* unc_iio_data_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3948490 }, /* unc_iio_data_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3948918 }, /* unc_iio_data_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3949381 }, /* unc_iio_data_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested by the CPU : Core reading from Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3950409 }, /* unc_iio_data_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3950819 }, /* unc_iio_data_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3951229 }, /* unc_iio_data_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3952116 }, /* unc_iio_data_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3952860 }, /* unc_iio_data_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3953674 }, /* unc_iio_data_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3954418 }, /* unc_iio_data_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3954918 }, /* unc_iio_data_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3955343 }, /* unc_iio_data_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3955803 }, /* unc_iio_data_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested by the CPU : Core writing to Card's PCICFG space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3956826 }, /* unc_iio_data_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3957230 }, /* unc_iio_data_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3957634 }, /* unc_iio_data_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3958511 }, /* unc_iio_data_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3959245 }, /* unc_iio_data_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3960049 }, /* unc_iio_data_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3960783 }, /* unc_iio_data_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3961277 }, /* unc_iio_data_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3961696 }, /* unc_iio_data_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3962150 }, /* unc_iio_data_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested by the CPU : Core reading from Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3963159 }, /* unc_iio_data_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3963560 }, /* unc_iio_data_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3963961 }, /* unc_iio_data_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3964834 }, /* unc_iio_data_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3965564 }, /* unc_iio_data_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3966364 }, /* unc_iio_data_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3967094 }, /* unc_iio_data_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3967585 }, /* unc_iio_data_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3968001 }, /* unc_iio_data_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3968452 }, /* unc_iio_data_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Data requested by the CPU : Core writing to Card's IO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3969649 }, /* unc_iio_data_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3970093 }, /* unc_iio_data_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3970537 }, /* unc_iio_data_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3972248 }, /* unc_iio_data_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3973705 }, /* unc_iio_data_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3975247 }, /* unc_iio_data_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3977205 }, /* unc_iio_data_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3978168 }, /* unc_iio_data_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3979091 }, /* unc_iio_data_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3980014 }, /* unc_iio_data_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested by the CPU : Core reporting completion of Card read from Core DRAM : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3981261 }, /* unc_iio_data_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3982070 }, /* unc_iio_data_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3982879 }, /* unc_iio_data_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3984545 }, /* unc_iio_data_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3985957 }, /* unc_iio_data_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3987455 }, /* unc_iio_data_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 3988871 }, /* unc_iio_data_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 3989854 }, /* unc_iio_data_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 3990694 }, /* unc_iio_data_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 3991604 }, /* unc_iio_data_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested by the CPU : Core writing to Card's MMIO space : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 3993036 }, /* unc_iio_data_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 3993490 }, /* unc_iio_data_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 3993944 }, /* unc_iio_data_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 3995763 }, /* unc_iio_data_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 3997328 }, /* unc_iio_data_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 3998978 }, /* unc_iio_data_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4001092 }, /* unc_iio_data_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4002113 }, /* unc_iio_data_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4003094 }, /* unc_iio_data_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4004075 }, /* unc_iio_data_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested by the CPU : Another card (different IIO stack) reading from this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4005184 }, /* unc_iio_data_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4005635 }, /* unc_iio_data_req_by_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4006086 }, /* unc_iio_data_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4007904 }, /* unc_iio_data_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4009467 }, /* unc_iio_data_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4011115 }, /* unc_iio_data_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4013223 }, /* unc_iio_data_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4014238 }, /* unc_iio_data_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4015213 }, /* unc_iio_data_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4016188 }, /* unc_iio_data_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc0,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested by the CPU : Another card (different IIO stack) writing to this card. : Number of DWs (4 bytes) requested by the main die.  Includes all requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4017292 }, /* unc_iio_data_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4017695 }, /* unc_iio_data_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4018098 }, /* unc_iio_data_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4018962 }, /* unc_iio_data_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4019683 }, /* unc_iio_data_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4020474 }, /* unc_iio_data_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4021195 }, /* unc_iio_data_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4021688 }, /* unc_iio_data_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4022106 }, /* unc_iio_data_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4022559 }, /* unc_iio_data_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Data requested of the CPU : Atomic requests targeting DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4025455 }, /* unc_iio_data_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4025890 }, /* unc_iio_data_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4026852 }, /* unc_iio_data_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4027829 }, /* unc_iio_data_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4028766 }, /* unc_iio_data_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4029703 }, /* unc_iio_data_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4030680 }, /* unc_iio_data_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4031657 }, /* unc_iio_data_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4032594 }, /* unc_iio_data_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4033531 }, /* unc_iio_data_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Data requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Data requested of the CPU : CmpD - device sending completion to CPU request : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4034173 }, /* unc_iio_data_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4034569 }, /* unc_iio_data_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4036079 }, /* unc_iio_data_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4037954 }, /* unc_iio_data_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4039736 }, /* unc_iio_data_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4041542 }, /* unc_iio_data_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000PCI Express bandwidth reading at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4042819 }, /* unc_iio_data_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4043710 }, /* unc_iio_data_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4044561 }, /* unc_iio_data_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4045412 }, /* unc_iio_data_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4046568 }, /* unc_iio_data_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4046961 }, /* unc_iio_data_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4048466 }, /* unc_iio_data_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 0. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4050337 }, /* unc_iio_data_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 1. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4052115 }, /* unc_iio_data_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 2. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4053917 }, /* unc_iio_data_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000PCI Express bandwidth writing at IIO, part 3. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4055189 }, /* unc_iio_data_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4056074 }, /* unc_iio_data_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4056919 }, /* unc_iio_data_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4057764 }, /* unc_iio_data_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Four byte data request of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4058722 }, /* unc_iio_data_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4059078 }, /* unc_iio_data_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4059434 }, /* unc_iio_data_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4060226 }, /* unc_iio_data_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4060875 }, /* unc_iio_data_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4061594 }, /* unc_iio_data_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4062243 }, /* unc_iio_data_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4062689 }, /* unc_iio_data_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4063060 }, /* unc_iio_data_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4063466 }, /* unc_iio_data_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Messages. Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Data requested of the CPU : Messages : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4064353 }, /* unc_iio_data_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4064810 }, /* unc_iio_data_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4065267 }, /* unc_iio_data_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4066474 }, /* unc_iio_data_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4067495 }, /* unc_iio_data_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4068566 }, /* unc_iio_data_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4069590 }, /* unc_iio_data_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4070137 }, /* unc_iio_data_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4070609 }, /* unc_iio_data_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4071116 }, /* unc_iio_data_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Data requested of the CPU : Card reading from another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4072210 }, /* unc_iio_data_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4072664 }, /* unc_iio_data_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4073118 }, /* unc_iio_data_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4074852 }, /* unc_iio_data_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4076332 }, /* unc_iio_data_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4077897 }, /* unc_iio_data_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4079920 }, /* unc_iio_data_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4080935 }, /* unc_iio_data_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4081910 }, /* unc_iio_data_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4082885 }, /* unc_iio_data_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Data requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x83,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Data requested of the CPU : Card writing to another Card (same or different stack) : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4084330 }, /* unc_iio_inbound_arb_req.data\000uncore_iio\000uncore io\000Incoming arbitration requests : Passing data to be written. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests : Passing data to be written : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4085027 }, /* unc_iio_inbound_arb_req.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing final read or write of line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests : Issuing final read or write of line : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4085709 }, /* unc_iio_inbound_arb_req.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests : Processing response from IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests : Processing response from IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086351 }, /* unc_iio_inbound_arb_req.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests : Issuing to IOMMU. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests : Issuing to IOMMU : How often different queues (e.g. channel / fc) ask to send request into pipeline\000 */
{ 4086998 }, /* unc_iio_inbound_arb_req.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests : Request Ownership. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests : Request Ownership : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4087657 }, /* unc_iio_inbound_arb_req.wr\000uncore_iio\000uncore io\000Incoming arbitration requests : Writing line. Unit: uncore_iio \000event=0x86,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests : Writing line : How often different queues (e.g. channel / fc) ask to send request into pipeline : Only for posted requests\000 */
{ 4088356 }, /* unc_iio_inbound_arb_won.data\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Passing data to be written. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000Incoming arbitration requests granted : Passing data to be written : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4089107 }, /* unc_iio_inbound_arb_won.final_rd_wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing final read or write of line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Incoming arbitration requests granted : Issuing final read or write of line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4089843 }, /* unc_iio_inbound_arb_won.iommu_hit\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Processing response from IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Incoming arbitration requests granted : Processing response from IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4090539 }, /* unc_iio_inbound_arb_won.iommu_req\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Issuing to IOMMU. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Incoming arbitration requests granted : Issuing to IOMMU : How often different queues (e.g. channel / fc) are allowed to send request into pipeline\000 */
{ 4091234 }, /* unc_iio_inbound_arb_won.req_own\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Request Ownership. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000Incoming arbitration requests granted : Request Ownership : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4091941 }, /* unc_iio_inbound_arb_won.wr\000uncore_iio\000uncore io\000Incoming arbitration requests granted : Writing line. Unit: uncore_iio \000event=0x87,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000Incoming arbitration requests granted : Writing line : How often different queues (e.g. channel / fc) are allowed to send request into pipeline : Only for posted requests\000 */
{ 4092284 }, /* unc_iio_iommu0.1g_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 1G Page. Unit: uncore_iio \000event=0x40,umask=0x10\000\00001\000: IOTLB Hits to a 1G Page : Counts if a transaction to a 1G page, on its first lookup, hits the IOTLB\000 */
{ 4092501 }, /* unc_iio_iommu0.2m_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 2M Page. Unit: uncore_iio \000event=0x40,umask=0x8\000\00001\000: IOTLB Hits to a 2M Page : Counts if a transaction to a 2M page, on its first lookup, hits the IOTLB\000 */
{ 4092717 }, /* unc_iio_iommu0.4k_hits\000uncore_iio\000uncore io\000: IOTLB Hits to a 4K Page. Unit: uncore_iio \000event=0x40,umask=0x4\000\00001\000: IOTLB Hits to a 4K Page : Counts if a transaction to a 4K page, on its first lookup, hits the IOTLB\000 */
{ 4092933 }, /* unc_iio_iommu0.all_lookups\000uncore_iio\000uncore io\000: IOTLB lookups all. Unit: uncore_iio \000event=0x40,umask=0x2\000\00001\000: IOTLB lookups all : Some transactions have to look up IOTLB multiple times.  Counts every time a request looks up IOTLB\000 */
{ 4093388 }, /* unc_iio_iommu0.ctxt_cache_hits\000uncore_iio\000uncore io\000: Context cache hits. Unit: uncore_iio \000event=0x40,umask=0x80\000\00001\000: Context cache hits : Counts each time a first look up of the transaction hits the RCC\000 */
{ 4093818 }, /* unc_iio_iommu0.ctxt_cache_lookups\000uncore_iio\000uncore io\000: Context cache lookups. Unit: uncore_iio \000event=0x40,umask=0x40\000\00001\000: Context cache lookups : Counts each time a transaction looks up root context cache\000 */
{ 4094286 }, /* unc_iio_iommu0.first_lookups\000uncore_iio\000uncore io\000: IOTLB lookups first. Unit: uncore_iio \000event=0x40,umask=0x1\000\00001\000: IOTLB lookups first : Some transactions have to look up IOTLB multiple times.  Counts the first time a request looks up IOTLB\000 */
{ 4094530 }, /* unc_iio_iommu0.misses\000uncore_iio\000uncore io\000: IOTLB Fills (same as IOTLB miss). Unit: uncore_iio \000event=0x40,umask=0x20\000\00001\000: IOTLB Fills (same as IOTLB miss) : When a transaction misses IOTLB, it does a page walk to look up memory and bring in the relevant page translation. Counts when this page translation is written to IOTLB\000 */
{ 4095199 }, /* unc_iio_iommu1.cyc_pwt_full\000uncore_iio\000uncore io\000: Cycles PWT full. Unit: uncore_iio \000event=0x41,umask=0x80\000\00001\000: Cycles PWT full : Counts cycles the IOMMU has reached its maximum limit for outstanding page walks\000 */
{ 4095412 }, /* unc_iio_iommu1.num_mem_accesses\000uncore_iio\000uncore io\000: IOMMU memory access. Unit: uncore_iio \000event=0x41,umask=0x40\000\00001\000: IOMMU memory access : IOMMU sends out memory fetches when it misses the cache look up which is indicated by this signal.  M2IOSF only uses low priority channel\000 */
{ 4095976 }, /* unc_iio_iommu1.pwc_1g_hits\000uncore_iio\000uncore io\000: PWC Hit to a 1G page. Unit: uncore_iio \000event=0x41,umask=0x8\000\00001\000: PWC Hit to a 1G page : Counts each time a transaction's first look up hits the SLPWC at the 1G level\000 */
{ 4096639 }, /* unc_iio_iommu1.pwc_2m_hits\000uncore_iio\000uncore io\000: PWC Hit to a 2M page. Unit: uncore_iio \000event=0x41,umask=0x4\000\00001\000: PWC Hit to a 2M page : Counts each time a transaction's first look up hits the SLPWC at the 2M level\000 */
{ 4097075 }, /* unc_iio_iommu1.pwc_4k_hits\000uncore_iio\000uncore io\000: PWC Hit to a 4K page. Unit: uncore_iio \000event=0x41,umask=0x2\000\00001\000: PWC Hit to a 4K page : Counts each time a transaction's first look up hits the SLPWC at the 4K level\000 */
{ 4097513 }, /* unc_iio_iommu1.pwc_512g_hits\000uncore_iio\000uncore io\000: PWT Hit to a 256T page. Unit: uncore_iio \000event=0x41,umask=0x10\000\00001\000: PWT Hit to a 256T page : Counts each time a transaction's first look up hits the SLPWC at the 512G level\000 */
{ 4097740 }, /* unc_iio_iommu1.pwc_cache_fills\000uncore_iio\000uncore io\000: PageWalk cache fill. Unit: uncore_iio \000event=0x41,umask=0x20\000\00001\000: PageWalk cache fill : When a transaction misses SLPWC, it does a page walk to look up memory and bring in the relevant page translation. When this page translation is written to SLPWC, ObsPwcFillValid_nnnH is asserted\000 */
{ 4098079 }, /* unc_iio_iommu1.pwt_cache_lookups\000uncore_iio\000uncore io\000: PageWalk cache lookup. Unit: uncore_iio \000event=0x41,umask=0x1\000\00001\000: PageWalk cache lookup : Counts each time a transaction looks up second level page walk cache\000 */
{ 4098961 }, /* unc_iio_iommu3.int_cache_hits\000uncore_iio\000uncore io\000: Interrupt Entry cache hit. Unit: uncore_iio \000event=0x43,umask=0x80\000\00001\000: Interrupt Entry cache hit : Counts each time a transaction's first look up hits the IEC\000 */
{ 4099175 }, /* unc_iio_iommu3.int_cache_lookups\000uncore_iio\000uncore io\000: Interrupt Entry cache lookup. Unit: uncore_iio \000event=0x43,umask=0x40\000\00001\000: Interrupt Entry cache lookup : Counts the number of transaction looks up that interrupt remapping cache\000 */
{ 4099411 }, /* unc_iio_iommu3.num_ctxt_cache_inval_device\000uncore_iio\000uncore io\000: Device-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x20\000\00001\000: Device-selective Context cache invalidation cycles : Counts number of Device selective context cache invalidation events\000 */
{ 4099696 }, /* unc_iio_iommu3.num_ctxt_cache_inval_domain\000uncore_iio\000uncore io\000: Domain-selective Context cache invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x10\000\00001\000: Domain-selective Context cache invalidation cycles : Counts number of Domain selective context cache invalidation events\000 */
{ 4099981 }, /* unc_iio_iommu3.num_ctxt_cache_inval_gbl\000uncore_iio\000uncore io\000: Context cache global invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x8\000\00001\000: Context cache global invalidation cycles : Counts number of Context Cache global invalidation events\000 */
{ 4100232 }, /* unc_iio_iommu3.num_inval_domain\000uncore_iio\000uncore io\000: Domain-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x2\000\00001\000: Domain-selective IOTLB invalidation cycles : Counts number of Domain selective invalidation events\000 */
{ 4100475 }, /* unc_iio_iommu3.num_inval_gbl\000uncore_iio\000uncore io\000: Global IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x1\000\00001\000: Global IOTLB invalidation cycles : Indicates that IOMMU is doing global invalidation\000 */
{ 4100691 }, /* unc_iio_iommu3.num_inval_page\000uncore_iio\000uncore io\000: Page-selective IOTLB invalidation cycles. Unit: uncore_iio \000event=0x43,umask=0x4\000\00001\000: Page-selective IOTLB invalidation cycles : Counts number of Page-selective within Domain Invalidation events\000 */
{ 4101748 }, /* unc_iio_mask_match_and.bus0\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x1\000\00001\000AND Mask/match for debug bus : Non-PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4102428 }, /* unc_iio_mask_match_and.bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x8\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4103167 }, /* unc_iio_mask_match_and.bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x4\000\00001\000AND Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4103874 }, /* unc_iio_mask_match_and.bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x2\000\00001\000AND Mask/match for debug bus : PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4104553 }, /* unc_iio_mask_match_and.not_bus0_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x2,umask=0x10\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if all bits specified by mask match\000 */
{ 4105322 }, /* unc_iio_mask_match_and.not_bus0_not_bus1\000uncore_iio\000uncore io\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x2,umask=0x20\000\00001\000AND Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if all bits specified by mask match\000 */
{ 4106020 }, /* unc_iio_mask_match_or.bus0\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x1\000\00001\000OR Mask/match for debug bus : Non-PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4106692 }, /* unc_iio_mask_match_or.bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x8\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4107423 }, /* unc_iio_mask_match_or.bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x4\000\00001\000OR Mask/match for debug bus : Non-PCIE bus and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4108122 }, /* unc_iio_mask_match_or.bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x2\000\00001\000OR Mask/match for debug bus : PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4108793 }, /* unc_iio_mask_match_or.not_bus0_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus. Unit: uncore_iio \000event=0x3,umask=0x10\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and PCIE bus : Asserted if any bits specified by mask match\000 */
{ 4109554 }, /* unc_iio_mask_match_or.not_bus0_not_bus1\000uncore_iio\000uncore io\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus). Unit: uncore_iio \000event=0x3,umask=0x20\000\00001\000OR Mask/match for debug bus : !(Non-PCIE bus) and !(PCIE bus) : Asserted if any bits specified by mask match\000 */
{ 4110128 }, /* unc_iio_nothing\000uncore_iio\000uncore io\000Counting disabled. Unit: uncore_iio \000event=0x80\000\00001\000\000 */
{ 4110218 }, /* unc_iio_num_oustanding_req_from_cpu.to_io\000uncore_iio\000uncore io\000Occupancy of outbound request queue : To device. Unit: uncore_iio \000event=0xc5,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Occupancy of outbound request queue : To device : Counts number of outbound requests/completions IIO is currently processing\000 */
{ 4110524 }, /* unc_iio_num_outstanding_req_of_cpu.data\000uncore_iio\000uncore io\000: Passing data to be written. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000: Passing data to be written : Only for posted requests\000 */
{ 4110741 }, /* unc_iio_num_outstanding_req_of_cpu.final_rd_wr\000uncore_iio\000uncore io\000: Issuing final read or write of line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000 */
{ 4110918 }, /* unc_iio_num_outstanding_req_of_cpu.iommu_hit\000uncore_iio\000uncore io\000: Processing response from IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000 */
{ 4111088 }, /* unc_iio_num_outstanding_req_of_cpu.iommu_req\000uncore_iio\000uncore io\000: Issuing to IOMMU. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4111244 }, /* unc_iio_num_outstanding_req_of_cpu.req_own\000uncore_iio\000uncore io\000: Request Ownership. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000: Request Ownership : Only for posted requests\000 */
{ 4111445 }, /* unc_iio_num_outstanding_req_of_cpu.wr\000uncore_iio\000uncore io\000: Writing line. Unit: uncore_iio \000event=0x88,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000: Writing line : Only for posted requests\000 */
{ 4111632 }, /* unc_iio_num_req_from_cpu.irp\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From IRP. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests sent to PCIe from main die : From IRP : Captures Posted/Non-posted allocations from IRP. i.e. either non-confined P2P traffic or from the CPU\000 */
{ 4111964 }, /* unc_iio_num_req_from_cpu.itc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : From ITC. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests sent to PCIe from main die : From ITC : Confined P2P\000 */
{ 4112207 }, /* unc_iio_num_req_from_cpu.prealloc\000uncore_iio\000uncore io\000Number requests sent to PCIe from main die : Completion allocations. Unit: uncore_iio \000event=0xc2,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4112401 }, /* unc_iio_num_req_of_cpu.all.drop\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : Drop request. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000Number requests PCIe makes of the main die : Drop request : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU. : Packet error detected, must be dropped\000 */
{ 4113191 }, /* unc_iio_num_req_of_cpu.commit.all\000uncore_iio\000uncore io\000Number requests PCIe makes of the main die : All. Unit: uncore_iio \000event=0x85,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000Number requests PCIe makes of the main die : All : Counts full PCIe requests before they're broken into a series of cache-line size requests as measured by DATA_REQ_OF_CPU and TXN_REQ_OF_CPU\000 */
{ 4113733 }, /* unc_iio_num_req_of_cpu_by_tgt.abort\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Abort. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x80\000\00001\000\000 */
{ 4114099 }, /* unc_iio_num_req_of_cpu_by_tgt.confined_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Confined P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x40\000\00001\000\000 */
{ 4114471 }, /* unc_iio_num_req_of_cpu_by_tgt.loc_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Local P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000\000 */
{ 4114833 }, /* unc_iio_num_req_of_cpu_by_tgt.mcast\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Multi-cast. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000\000 */
{ 4115187 }, /* unc_iio_num_req_of_cpu_by_tgt.mem\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Memory. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000\000 */
{ 4115534 }, /* unc_iio_num_req_of_cpu_by_tgt.msgb\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : MsgB. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000\000 */
{ 4115890 }, /* unc_iio_num_req_of_cpu_by_tgt.rem_p2p\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Remote P2P. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000\000 */
{ 4116246 }, /* unc_iio_num_req_of_cpu_by_tgt.ubox\000uncore_iio\000uncore io\000Num requests sent by PCIe - by target : Ubox. Unit: uncore_iio \000event=0x8e,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000\000 */
{ 4116576 }, /* unc_iio_num_tgt_matched_req_of_cpu\000uncore_iio\000uncore io\000ITC address map 1. Unit: uncore_iio \000event=0x8f\000\00001\000\000 */
{ 4117113 }, /* unc_iio_outbound_cl_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound cacheline requests issued : 64B requests issued to device. Unit: uncore_iio \000event=0xd0,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound cacheline requests issued : 64B requests issued to device : Each outbound cacheline granular request may need to make multiple passes through the pipeline.  Each time a cacheline completes all its passes it advances line\000 */
{ 4117880 }, /* unc_iio_outbound_tlp_reqs_issued.to_io\000uncore_iio\000uncore io\000Outbound TLP (transaction layer packet) requests issued : To device. Unit: uncore_iio \000event=0xd1,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000Outbound TLP (transaction layer packet) requests issued : To device : Each time an outbound completes all its passes it advances the pointer\000 */
{ 4137426 }, /* unc_iio_pwt_occupancy\000uncore_iio\000uncore io\000PWT occupancy. Unit: uncore_iio \000event=0x42\000\00001\000PWT occupancy : Indicates how many page walks are outstanding at any point in time\000 */
{ 4137600 }, /* unc_iio_req_from_pcie_cl_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Passing data to be written. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - cacheline complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4138769 }, /* unc_iio_req_from_pcie_cl_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - cacheline complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line\000 */
{ 4139640 }, /* unc_iio_req_from_pcie_cl_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Request Ownership. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - cacheline complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4140513 }, /* unc_iio_req_from_pcie_cl_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - cacheline complete : Writing line. Unit: uncore_iio \000event=0x91,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - cacheline complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes all its passes (e.g. finishes posting writes to all multi-cast targets) it advances line : Only for posted requests\000 */
{ 4141376 }, /* unc_iio_req_from_pcie_cmpl.data\000uncore_iio\000uncore io\000PCIe Request complete : Passing data to be written. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4141941 }, /* unc_iio_req_from_pcie_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4142787 }, /* unc_iio_req_from_pcie_cmpl.iommu_hit\000uncore_iio\000uncore io\000PCIe Request complete : Processing response from IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x2\000\00001\000PCIe Request complete : Processing response from IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4143542 }, /* unc_iio_req_from_pcie_cmpl.iommu_req\000uncore_iio\000uncore io\000PCIe Request complete : Issuing to IOMMU. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x1\000\00001\000PCIe Request complete : Issuing to IOMMU : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer\000 */
{ 4144328 }, /* unc_iio_req_from_pcie_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request complete : Request Ownership. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4145130 }, /* unc_iio_req_from_pcie_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request complete : Writing line. Unit: uncore_iio \000event=0x92,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a single PCIe request completes all its cacheline granular requests, it advances pointer. : Only for posted requests\000 */
{ 4146269 }, /* unc_iio_req_from_pcie_pass_cmpl.data\000uncore_iio\000uncore io\000PCIe Request - pass complete : Passing data to be written. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x20\000\00001\000PCIe Request - pass complete : Passing data to be written : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4147462 }, /* unc_iio_req_from_pcie_pass_cmpl.final_rd_wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Issuing final read or write of line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x8\000\00001\000PCIe Request - pass complete : Issuing final read or write of line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state\000 */
{ 4148645 }, /* unc_iio_req_from_pcie_pass_cmpl.req_own\000uncore_iio\000uncore io\000PCIe Request - pass complete : Request Ownership. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x4\000\00001\000PCIe Request - pass complete : Request Ownership : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4149800 }, /* unc_iio_req_from_pcie_pass_cmpl.wr\000uncore_iio\000uncore io\000PCIe Request - pass complete : Writing line. Unit: uncore_iio \000event=0x90,ch_mask=0xFF,fc_mask=0x07,umask=0x10\000\00001\000PCIe Request - pass complete : Writing line : Each PCIe request is broken down into a series of cacheline granular requests and each cacheline size request may need to make multiple passes through the pipeline (e.g. for posted interrupts or multi-cast).   Each time a cacheline completes a single pass (e.g. posts a write to single multi-cast target) it advances state : Only for posted requests\000 */
{ 4150562 }, /* unc_iio_symbol_times\000uncore_iio\000uncore io\000Symbol Times on Link. Unit: uncore_iio \000event=0x82\000\00001\000Symbol Times on Link : Gen1 - increment once every 4nS, Gen2 - increment once every 2nS, Gen3 - increment once every 1nS\000 */
{ 4166576 }, /* unc_iio_txn_req_by_cpu.cfg_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4166988 }, /* unc_iio_txn_req_by_cpu.cfg_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4167400 }, /* unc_iio_txn_req_by_cpu.cfg_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4168309 }, /* unc_iio_txn_req_by_cpu.cfg_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4169075 }, /* unc_iio_txn_req_by_cpu.cfg_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4169911 }, /* unc_iio_txn_req_by_cpu.cfg_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4170677 }, /* unc_iio_txn_req_by_cpu.cfg_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4171179 }, /* unc_iio_txn_req_by_cpu.cfg_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4171606 }, /* unc_iio_txn_req_by_cpu.cfg_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4172068 }, /* unc_iio_txn_req_by_cpu.cfg_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested by the CPU : Core reading from Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4173133 }, /* unc_iio_txn_req_by_cpu.cfg_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4173542 }, /* unc_iio_txn_req_by_cpu.cfg_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4173951 }, /* unc_iio_txn_req_by_cpu.cfg_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4174856 }, /* unc_iio_txn_req_by_cpu.cfg_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4175618 }, /* unc_iio_txn_req_by_cpu.cfg_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4176450 }, /* unc_iio_txn_req_by_cpu.cfg_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4177212 }, /* unc_iio_txn_req_by_cpu.cfg_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4177711 }, /* unc_iio_txn_req_by_cpu.cfg_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4178135 }, /* unc_iio_txn_req_by_cpu.cfg_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4178594 }, /* unc_iio_txn_req_by_cpu.cfg_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested by the CPU : Core writing to Card's PCICFG space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4179654 }, /* unc_iio_txn_req_by_cpu.io_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4180057 }, /* unc_iio_txn_req_by_cpu.io_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4180460 }, /* unc_iio_txn_req_by_cpu.io_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4181355 }, /* unc_iio_txn_req_by_cpu.io_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4182107 }, /* unc_iio_txn_req_by_cpu.io_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4182929 }, /* unc_iio_txn_req_by_cpu.io_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4183681 }, /* unc_iio_txn_req_by_cpu.io_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4184174 }, /* unc_iio_txn_req_by_cpu.io_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4184592 }, /* unc_iio_txn_req_by_cpu.io_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4185045 }, /* unc_iio_txn_req_by_cpu.io_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested by the CPU : Core reading from Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4186091 }, /* unc_iio_txn_req_by_cpu.io_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4186491 }, /* unc_iio_txn_req_by_cpu.io_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4186891 }, /* unc_iio_txn_req_by_cpu.io_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4187782 }, /* unc_iio_txn_req_by_cpu.io_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4188530 }, /* unc_iio_txn_req_by_cpu.io_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4189348 }, /* unc_iio_txn_req_by_cpu.io_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4190096 }, /* unc_iio_txn_req_by_cpu.io_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4190586 }, /* unc_iio_txn_req_by_cpu.io_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4191001 }, /* unc_iio_txn_req_by_cpu.io_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4191451 }, /* unc_iio_txn_req_by_cpu.io_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's IO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x20\000\00001\000Number Transactions requested by the CPU : Core writing to Card's IO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4192492 }, /* unc_iio_txn_req_by_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4192899 }, /* unc_iio_txn_req_by_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4193306 }, /* unc_iio_txn_req_by_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4195023 }, /* unc_iio_txn_req_by_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4196486 }, /* unc_iio_txn_req_by_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4198034 }, /* unc_iio_txn_req_by_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4199501 }, /* unc_iio_txn_req_by_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4200488 }, /* unc_iio_txn_req_by_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4201332 }, /* unc_iio_txn_req_by_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4202246 }, /* unc_iio_txn_req_by_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core reading from Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested by the CPU : Core reading from Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4203722 }, /* unc_iio_txn_req_by_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4204126 }, /* unc_iio_txn_req_by_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4204530 }, /* unc_iio_txn_req_by_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4206244 }, /* unc_iio_txn_req_by_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4207704 }, /* unc_iio_txn_req_by_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4209249 }, /* unc_iio_txn_req_by_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4210713 }, /* unc_iio_txn_req_by_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4211694 }, /* unc_iio_txn_req_by_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4212532 }, /* unc_iio_txn_req_by_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4213440 }, /* unc_iio_txn_req_by_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Core writing to Card's MMIO space. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested by the CPU : Core writing to Card's MMIO space : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4214908 }, /* unc_iio_txn_req_by_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 0\000 */
{ 4215361 }, /* unc_iio_txn_req_by_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4215814 }, /* unc_iio_txn_req_by_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4217136 }, /* unc_iio_txn_req_by_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4218272 }, /* unc_iio_txn_req_by_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4219458 }, /* unc_iio_txn_req_by_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4220598 }, /* unc_iio_txn_req_by_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4221141 }, /* unc_iio_txn_req_by_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4221609 }, /* unc_iio_txn_req_by_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4222112 }, /* unc_iio_txn_req_by_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) reading from this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4223258 }, /* unc_iio_txn_req_by_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : IOMMU - Type 1\000 */
{ 4224256 }, /* unc_iio_txn_req_by_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4226049 }, /* unc_iio_txn_req_by_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4227691 }, /* unc_iio_txn_req_by_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4229348 }, /* unc_iio_txn_req_by_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4231034 }, /* unc_iio_txn_req_by_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4232047 }, /* unc_iio_txn_req_by_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4233020 }, /* unc_iio_txn_req_by_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4233993 }, /* unc_iio_txn_req_by_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. Unit: uncore_iio \000event=0xc1,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested by the CPU : Another card (different IIO stack) writing to this card. : Also known as Outbound.  Number of requests initiated by the main die, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4235134 }, /* unc_iio_txn_req_of_cpu.atomic.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4235540 }, /* unc_iio_txn_req_of_cpu.atomic.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4235946 }, /* unc_iio_txn_req_of_cpu.atomic.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4236840 }, /* unc_iio_txn_req_of_cpu.atomic.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4237591 }, /* unc_iio_txn_req_of_cpu.atomic.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4238412 }, /* unc_iio_txn_req_of_cpu.atomic.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4239163 }, /* unc_iio_txn_req_of_cpu.atomic.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4239659 }, /* unc_iio_txn_req_of_cpu.atomic.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4240080 }, /* unc_iio_txn_req_of_cpu.atomic.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4240536 }, /* unc_iio_txn_req_of_cpu.atomic.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Atomic requests targeting DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x10\000\00001\000Number Transactions requested of the CPU : Atomic requests targeting DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4243068 }, /* unc_iio_txn_req_of_cpu.cmpd.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4243506 }, /* unc_iio_txn_req_of_cpu.cmpd.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4244474 }, /* unc_iio_txn_req_of_cpu.cmpd.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4245457 }, /* unc_iio_txn_req_of_cpu.cmpd.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4246400 }, /* unc_iio_txn_req_of_cpu.cmpd.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4247343 }, /* unc_iio_txn_req_of_cpu.cmpd.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4248326 }, /* unc_iio_txn_req_of_cpu.cmpd.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4249309 }, /* unc_iio_txn_req_of_cpu.cmpd.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4250252 }, /* unc_iio_txn_req_of_cpu.cmpd.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4251195 }, /* unc_iio_txn_req_of_cpu.cmpd.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x80\000\00001\000Number Transactions requested of the CPU : CmpD - device sending completion to CPU request : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4251648 }, /* unc_iio_txn_req_of_cpu.mem_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4252039 }, /* unc_iio_txn_req_of_cpu.mem_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4252430 }, /* unc_iio_txn_req_of_cpu.mem_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4254075 }, /* unc_iio_txn_req_of_cpu.mem_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4255468 }, /* unc_iio_txn_req_of_cpu.mem_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4256944 }, /* unc_iio_txn_req_of_cpu.mem_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4258815 }, /* unc_iio_txn_req_of_cpu.mem_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4259704 }, /* unc_iio_txn_req_of_cpu.mem_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4260553 }, /* unc_iio_txn_req_of_cpu.mem_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4261402 }, /* unc_iio_txn_req_of_cpu.mem_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x4\000\00001\000Number Transactions requested of the CPU : Card reading from DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4262414 }, /* unc_iio_txn_req_of_cpu.mem_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4262802 }, /* unc_iio_txn_req_of_cpu.mem_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4263190 }, /* unc_iio_txn_req_of_cpu.mem_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4264832 }, /* unc_iio_txn_req_of_cpu.mem_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4266220 }, /* unc_iio_txn_req_of_cpu.mem_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4267693 }, /* unc_iio_txn_req_of_cpu.mem_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4269558 }, /* unc_iio_txn_req_of_cpu.mem_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4270441 }, /* unc_iio_txn_req_of_cpu.mem_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4271284 }, /* unc_iio_txn_req_of_cpu.mem_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4272127 }, /* unc_iio_txn_req_of_cpu.mem_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to DRAM. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x1\000\00001\000Number Transactions requested of the CPU : Card writing to DRAM : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4273134 }, /* unc_iio_txn_req_of_cpu.msg.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4273493 }, /* unc_iio_txn_req_of_cpu.msg.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4273852 }, /* unc_iio_txn_req_of_cpu.msg.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4274674 }, /* unc_iio_txn_req_of_cpu.msg.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4275353 }, /* unc_iio_txn_req_of_cpu.msg.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4276102 }, /* unc_iio_txn_req_of_cpu.msg.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4276781 }, /* unc_iio_txn_req_of_cpu.msg.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4277230 }, /* unc_iio_txn_req_of_cpu.msg.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4277604 }, /* unc_iio_txn_req_of_cpu.msg.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4278013 }, /* unc_iio_txn_req_of_cpu.msg.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Messages. Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x40\000\00001\000Number Transactions requested of the CPU : Messages : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4278957 }, /* unc_iio_txn_req_of_cpu.peer_read.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4279417 }, /* unc_iio_txn_req_of_cpu.peer_read.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4279877 }, /* unc_iio_txn_req_of_cpu.peer_read.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4281119 }, /* unc_iio_txn_req_of_cpu.peer_read.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4282175 }, /* unc_iio_txn_req_of_cpu.peer_read.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4283281 }, /* unc_iio_txn_req_of_cpu.peer_read.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4284340 }, /* unc_iio_txn_req_of_cpu.peer_read.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4284890 }, /* unc_iio_txn_req_of_cpu.peer_read.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4285365 }, /* unc_iio_txn_req_of_cpu.peer_read.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4285875 }, /* unc_iio_txn_req_of_cpu.peer_read.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x8\000\00001\000Number Transactions requested of the CPU : Card reading from another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4287026 }, /* unc_iio_txn_req_of_cpu.peer_write.iommu0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x100,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 0\000 */
{ 4287483 }, /* unc_iio_txn_req_of_cpu.peer_write.iommu1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x200,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : IOMMU - Type 1\000 */
{ 4288489 }, /* unc_iio_txn_req_of_cpu.peer_write.part0\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x01,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\000 */
{ 4290213 }, /* unc_iio_txn_req_of_cpu.peer_write.part1\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x02,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 1\000 */
{ 4291785 }, /* unc_iio_txn_req_of_cpu.peer_write.part2\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x04,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 2/3, Or x4 card is plugged in to slot 2\000 */
{ 4293373 }, /* unc_iio_txn_req_of_cpu.peer_write.part3\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x08,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 3\000 */
{ 4294990 }, /* unc_iio_txn_req_of_cpu.peer_write.part4\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x10,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 4/5/6/7, Or x8 card plugged in to Lane 4/5, Or x4 card is plugged in to slot 4\000 */
{ 4296011 }, /* unc_iio_txn_req_of_cpu.peer_write.part5\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x20,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 5\000 */
{ 4296992 }, /* unc_iio_txn_req_of_cpu.peer_write.part6\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x40,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x8 card plugged in to Lane 6/7, Or x4 card is plugged in to slot 6\000 */
{ 4297973 }, /* unc_iio_txn_req_of_cpu.peer_write.part7\000uncore_iio\000uncore io\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack). Unit: uncore_iio \000event=0x84,ch_mask=0x80,fc_mask=0x07,umask=0x2\000\00001\000Number Transactions requested of the CPU : Card writing to another Card (same or different stack) : Also known as Inbound.  Number of 64B cache line requests initiated by the Card, including reads and writes. : x4 card is plugged in to slot 7\000 */
{ 4681598 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x80,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4681880 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x80,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682162 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x80,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682444 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x80,umask=0x8\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4682726 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x80,umask=0x10\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683009 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x80,umask=0x20\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683292 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x80,umask=0x40\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683575 }, /* unc_m2p_ag0_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x80,umask=0x80\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4683858 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x81,umask=0x4\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684143 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x81,umask=0x1\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684425 }, /* unc_m2p_ag0_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x81,umask=0x2\000\00001\000CMS Agent0 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 0 AD credits acquired in a given cycle, per transgress\000 */
{ 4684707 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x82,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4684990 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x82,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685273 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x82,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685556 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x82,umask=0x8\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4685839 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x82,umask=0x10\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686123 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x82,umask=0x20\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686407 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x82,umask=0x40\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686691 }, /* unc_m2p_ag0_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x82,umask=0x80\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4686975 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x83,umask=0x4\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687261 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x83,umask=0x1\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687544 }, /* unc_m2p_ag0_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x83,umask=0x2\000\00001\000CMS Agent0 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 AD credits in use in a given cycle, per transgress\000 */
{ 4687827 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x88,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688109 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x88,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688391 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x88,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688673 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x88,umask=0x8\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4688955 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x88,umask=0x10\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689238 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x88,umask=0x20\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689521 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x88,umask=0x40\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 6 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4689804 }, /* unc_m2p_ag0_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x88,umask=0x80\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 7 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690087 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x89,umask=0x4\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690372 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x89,umask=0x1\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690654 }, /* unc_m2p_ag0_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x89,umask=0x2\000\00001\000CMS Agent0 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 0 BL credits acquired in a given cycle, per transgress\000 */
{ 4690936 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8a,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691219 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8a,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691502 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8a,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4691785 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8a,umask=0x8\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692068 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8a,umask=0x10\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692352 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8a,umask=0x20\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692636 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8a,umask=0x40\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4692920 }, /* unc_m2p_ag0_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8a,umask=0x80\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693204 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8b,umask=0x4\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693490 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8b,umask=0x1\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4693773 }, /* unc_m2p_ag0_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent0 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8b,umask=0x2\000\00001\000CMS Agent0 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 0 BL credits in use in a given cycle, per transgress\000 */
{ 4694056 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x84,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 0 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694338 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x84,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 1 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694620 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x84,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 2 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4694902 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x84,umask=0x8\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 3 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695184 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x84,umask=0x10\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 4 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695467 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x84,umask=0x20\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 5 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4695750 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 6. Unit: uncore_m2pcie \000event=0x84,umask=0x40\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 6 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696033 }, /* unc_m2p_ag1_ad_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 7. Unit: uncore_m2pcie \000event=0x84,umask=0x80\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 7 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696316 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x85,umask=0x4\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 10 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696601 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x85,umask=0x1\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 8 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4696883 }, /* unc_m2p_ag1_ad_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x85,umask=0x2\000\00001\000CMS Agent1 AD Credits Acquired : For Transgress 9 : Number of CMS Agent 1 AD credits acquired in a given cycle, per transgress\000 */
{ 4697165 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x86,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4697448 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x86,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4697731 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x86,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698014 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x86,umask=0x8\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698297 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x86,umask=0x10\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698581 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x86,umask=0x20\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4698865 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x86,umask=0x40\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699149 }, /* unc_m2p_ag1_ad_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x86,umask=0x80\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699433 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x87,umask=0x4\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4699719 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x87,umask=0x1\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4700002 }, /* unc_m2p_ag1_ad_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 AD Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x87,umask=0x2\000\00001\000CMS Agent1 AD Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 AD credits in use in a given cycle, per transgress\000 */
{ 4700285 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 0. Unit: uncore_m2pcie \000event=0x8c,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 0 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4700567 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 1. Unit: uncore_m2pcie \000event=0x8c,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 1 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4700849 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 2. Unit: uncore_m2pcie \000event=0x8c,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 2 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701131 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 3. Unit: uncore_m2pcie \000event=0x8c,umask=0x8\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 3 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701413 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x10\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701696 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x20\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4701979 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 4. Unit: uncore_m2pcie \000event=0x8c,umask=0x40\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 4 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702262 }, /* unc_m2p_ag1_bl_crd_acquired0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 5. Unit: uncore_m2pcie \000event=0x8c,umask=0x80\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 5 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702545 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 10. Unit: uncore_m2pcie \000event=0x8d,umask=0x4\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 10 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4702830 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 8. Unit: uncore_m2pcie \000event=0x8d,umask=0x1\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 8 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4703112 }, /* unc_m2p_ag1_bl_crd_acquired1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Acquired : For Transgress 9. Unit: uncore_m2pcie \000event=0x8d,umask=0x2\000\00001\000CMS Agent1 BL Credits Acquired : For Transgress 9 : Number of CMS Agent 1 BL credits acquired in a given cycle, per transgress\000 */
{ 4703394 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr0\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 0. Unit: uncore_m2pcie \000event=0x8e,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 0 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4703677 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr1\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 1. Unit: uncore_m2pcie \000event=0x8e,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 1 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4703960 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr2\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 2. Unit: uncore_m2pcie \000event=0x8e,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 2 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704243 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr3\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 3. Unit: uncore_m2pcie \000event=0x8e,umask=0x8\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 3 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704526 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr4\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 4. Unit: uncore_m2pcie \000event=0x8e,umask=0x10\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 4 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4704810 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr5\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 5. Unit: uncore_m2pcie \000event=0x8e,umask=0x20\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 5 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705094 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr6\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 6. Unit: uncore_m2pcie \000event=0x8e,umask=0x40\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 6 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705378 }, /* unc_m2p_ag1_bl_crd_occupancy0.tgr7\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 7. Unit: uncore_m2pcie \000event=0x8e,umask=0x80\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 7 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705662 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr10\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 10. Unit: uncore_m2pcie \000event=0x8f,umask=0x4\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 10 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4705948 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr8\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 8. Unit: uncore_m2pcie \000event=0x8f,umask=0x1\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 8 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4706231 }, /* unc_m2p_ag1_bl_crd_occupancy1.tgr9\000uncore_m2pcie\000uncore io\000CMS Agent1 BL Credits Occupancy : For Transgress 9. Unit: uncore_m2pcie \000event=0x8f,umask=0x2\000\00001\000CMS Agent1 BL Credits Occupancy : For Transgress 9 : Number of CMS Agent 1 BL credits in use in a given cycle, per transgress\000 */
{ 4706925 }, /* unc_m2p_clockticks\000uncore_m2pcie\000uncore io\000Clockticks of the mesh to PCI (M2P). Unit: uncore_m2pcie \000event=0x1\000\00001\000\000 */
{ 4707189 }, /* unc_m2p_cms_clockticks\000uncore_m2pcie\000uncore io\000CMS Clockticks. Unit: uncore_m2pcie \000event=0xc0\000\00001\000\000 */
{ 4707289 }, /* unc_m2p_distress_asserted.dpt_local\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Local. Unit: uncore_m2pcie \000event=0xaf,umask=0x4\000\00001\000Distress signal asserted : DPT Local : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle triggered by this tile\000 */
{ 4707611 }, /* unc_m2p_distress_asserted.dpt_nonlocal\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Remote. Unit: uncore_m2pcie \000event=0xaf,umask=0x8\000\00001\000Distress signal asserted : DPT Remote : Counts the number of cycles either the local or incoming distress signals are asserted. : Dynamic Prefetch Throttle received by this tile\000 */
{ 4707937 }, /* unc_m2p_distress_asserted.dpt_stall_iv\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled - IV. Unit: uncore_m2pcie \000event=0xaf,umask=0x40\000\00001\000Distress signal asserted : DPT Stalled - IV : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while regular IVs were received, causing DPT to be stalled\000 */
{ 4708300 }, /* unc_m2p_distress_asserted.dpt_stall_nocrd\000uncore_m2pcie\000uncore io\000Distress signal asserted : DPT Stalled -  No Credit. Unit: uncore_m2pcie \000event=0xaf,umask=0x80\000\00001\000Distress signal asserted : DPT Stalled -  No Credit : Counts the number of cycles either the local or incoming distress signals are asserted. : DPT occurred while credit not available causing DPT to be stalled\000 */
{ 4708676 }, /* unc_m2p_distress_asserted.horz\000uncore_m2pcie\000uncore io\000Distress signal asserted : Horizontal. Unit: uncore_m2pcie \000event=0xaf,umask=0x2\000\00001\000Distress signal asserted : Horizontal : Counts the number of cycles either the local or incoming distress signals are asserted. : If TGR egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4709773 }, /* unc_m2p_distress_asserted.vert\000uncore_m2pcie\000uncore io\000Distress signal asserted : Vertical. Unit: uncore_m2pcie \000event=0xaf,umask=0x1\000\00001\000Distress signal asserted : Vertical : Counts the number of cycles either the local or incoming distress signals are asserted. : If IRQ egress is full, then agents will throttle outgoing AD IDI transactions\000 */
{ 4714289 }, /* unc_m2p_egress_ordering.iv_snoopgo_dn\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Down. Unit: uncore_m2pcie \000event=0xba,umask=0x4\000\00001\000Egress Blocking due to Ordering requirements : Down : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4714597 }, /* unc_m2p_egress_ordering.iv_snoopgo_up\000uncore_m2pcie\000uncore io\000Egress Blocking due to Ordering requirements : Up. Unit: uncore_m2pcie \000event=0xba,umask=0x1\000\00001\000Egress Blocking due to Ordering requirements : Up : Counts number of cycles IV was blocked in the TGR Egress due to SNP/GO Ordering requirements\000 */
{ 4714901 }, /* unc_m2p_horz_ring_ad_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x1\000\00001\000Horizontal AD Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4715824 }, /* unc_m2p_horz_ring_ad_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x2\000\00001\000Horizontal AD Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4716744 }, /* unc_m2p_horz_ring_ad_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb6,umask=0x4\000\00001\000Horizontal AD Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4717670 }, /* unc_m2p_horz_ring_ad_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AD Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb6,umask=0x8\000\00001\000Horizontal AD Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4718593 }, /* unc_m2p_horz_ring_ak_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4719514 }, /* unc_m2p_horz_ring_ak_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4720432 }, /* unc_m2p_horz_ring_ak_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xb7,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4721356 }, /* unc_m2p_horz_ring_ak_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb7,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4722277 }, /* unc_m2p_horz_ring_akc_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x1\000\00001\000Horizontal AK Ring In Use : Left and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4723207 }, /* unc_m2p_horz_ring_akc_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Left and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x2\000\00001\000Horizontal AK Ring In Use : Left and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4724134 }, /* unc_m2p_horz_ring_akc_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Even. Unit: uncore_m2pcie \000event=0xbb,umask=0x4\000\00001\000Horizontal AK Ring In Use : Right and Even : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4725067 }, /* unc_m2p_horz_ring_akc_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal AK Ring In Use : Right and Odd. Unit: uncore_m2pcie \000event=0xbb,umask=0x8\000\00001\000Horizontal AK Ring In Use : Right and Odd : Counts the number of cycles that the Horizontal AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4725997 }, /* unc_m2p_horz_ring_bl_in_use.left_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x1\000\00001\000Horizontal BL Ring in Use : Left and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4726919 }, /* unc_m2p_horz_ring_bl_in_use.left_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Left and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x2\000\00001\000Horizontal BL Ring in Use : Left and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4727838 }, /* unc_m2p_horz_ring_bl_in_use.right_even\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Even. Unit: uncore_m2pcie \000event=0xb8,umask=0x4\000\00001\000Horizontal BL Ring in Use : Right and Even : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4728763 }, /* unc_m2p_horz_ring_bl_in_use.right_odd\000uncore_m2pcie\000uncore io\000Horizontal BL Ring in Use : Right and Odd. Unit: uncore_m2pcie \000event=0xb8,umask=0x8\000\00001\000Horizontal BL Ring in Use : Right and Odd : Counts the number of cycles that the Horizontal BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4729685 }, /* unc_m2p_horz_ring_iv_in_use.left\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Left. Unit: uncore_m2pcie \000event=0xb9,umask=0x1\000\00001\000Horizontal IV Ring in Use : Left : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4730281 }, /* unc_m2p_horz_ring_iv_in_use.right\000uncore_m2pcie\000uncore io\000Horizontal IV Ring in Use : Right. Unit: uncore_m2pcie \000event=0xb9,umask=0x4\000\00001\000Horizontal IV Ring in Use : Right : Counts the number of cycles that the Horizontal IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4730880 }, /* unc_m2p_iio_credits_acquired.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x1\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4731581 }, /* unc_m2p_iio_credits_acquired.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : DRS. Unit: uncore_m2pcie \000event=0x33,umask=0x2\000\00001\000M2PCIe IIO Credit Acquired : DRS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4732282 }, /* unc_m2p_iio_credits_acquired.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x4\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4732983 }, /* unc_m2p_iio_credits_acquired.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCB. Unit: uncore_m2pcie \000event=0x33,umask=0x8\000\00001\000M2PCIe IIO Credit Acquired : NCB : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4733684 }, /* unc_m2p_iio_credits_acquired.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x10\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4734386 }, /* unc_m2p_iio_credits_acquired.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credit Acquired : NCS. Unit: uncore_m2pcie \000event=0x33,umask=0x20\000\00001\000M2PCIe IIO Credit Acquired : NCS : Counts the number of credits that are acquired in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4735088 }, /* unc_m2p_iio_credits_reject.drs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : DRS. Unit: uncore_m2pcie \000event=0x34,umask=0x8\000\00001\000M2PCIe IIO Failed to Acquire a Credit : DRS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the DRS message class\000 */
{ 4735684 }, /* unc_m2p_iio_credits_reject.ncb\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCB. Unit: uncore_m2pcie \000event=0x34,umask=0x10\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCB : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCB message class\000 */
{ 4736281 }, /* unc_m2p_iio_credits_reject.ncs\000uncore_m2pcie\000uncore io\000M2PCIe IIO Failed to Acquire a Credit : NCS. Unit: uncore_m2pcie \000event=0x34,umask=0x20\000\00001\000M2PCIe IIO Failed to Acquire a Credit : NCS : Counts the number of times that a request pending in the BL Ingress attempted to acquire either a NCB or NCS credit to transmit into the IIO, but was rejected because no credits were available.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits to the IIO for the NCS message class\000 */
{ 4736878 }, /* unc_m2p_iio_credits_used.drs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x1\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4737607 }, /* unc_m2p_iio_credits_used.drs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : DRS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x2\000\00001\000M2PCIe IIO Credits in Use : DRS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the DRS message class\000 */
{ 4738336 }, /* unc_m2p_iio_credits_used.ncb_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x4\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739065 }, /* unc_m2p_iio_credits_used.ncb_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCB to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x8\000\00001\000M2PCIe IIO Credits in Use : NCB to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCB message class\000 */
{ 4739794 }, /* unc_m2p_iio_credits_used.ncs_0\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 0. Unit: uncore_m2pcie \000event=0x32,umask=0x10\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 0 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credits for transfer through CMS Port 0 to the IIO for the NCS message class\000 */
{ 4740524 }, /* unc_m2p_iio_credits_used.ncs_1\000uncore_m2pcie\000uncore io\000M2PCIe IIO Credits in Use : NCS to CMS Port 1. Unit: uncore_m2pcie \000event=0x32,umask=0x20\000\00001\000M2PCIe IIO Credits in Use : NCS to CMS Port 1 : Counts the number of cycles when one or more credits in the M2PCIe agent for sending transactions into the IIO on either NCB or NCS are in use.  Transactions from the BL ring going into the IIO Agent must first acquire a credit.  These credits are for either the NCB or NCS message classes.  NCB, or non-coherent bypass messages are used to transmit data without coherency (and are common).  NCS is used for reads to PCIe (and should be used sparingly). : Credit for transfer through CMS Port 0s to the IIO for the NCS message class\000 */
{ 4742091 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x1\000\00001\000\000 */
{ 4742262 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x2\000\00001\000\000 */
{ 4742433 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x4\000\00001\000\000 */
{ 4742604 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x8\000\00001\000\000 */
{ 4742775 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x10\000\00001\000\000 */
{ 4742947 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x20\000\00001\000\000 */
{ 4743119 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x46,umask=0x40\000\00001\000\000 */
{ 4743291 }, /* unc_m2p_local_ded_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x46,umask=0x80\000\00001\000\000 */
{ 4743463 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x1\000\00001\000\000 */
{ 4743634 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x2\000\00001\000\000 */
{ 4743805 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x47,umask=0x4\000\00001\000\000 */
{ 4743976 }, /* unc_m2p_local_ded_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Dedicated P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x47,umask=0x8\000\00001\000\000 */
{ 4744147 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x1\000\00001\000\000 */
{ 4744322 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x2\000\00001\000\000 */
{ 4744497 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x4\000\00001\000\000 */
{ 4744672 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x8\000\00001\000\000 */
{ 4744847 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000 */
{ 4745023 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000 */
{ 4745199 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x19,umask=0x10\000\00001\000\000 */
{ 4745551 }, /* unc_m2p_local_p2p_ded_returned_0.ms2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x19,umask=0x20\000\00001\000\000 */
{ 4745903 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x1\000\00001\000\000 */
{ 4746078 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x2\000\00001\000\000 */
{ 4746253 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x1a,umask=0x4\000\00001\000\000 */
{ 4746428 }, /* unc_m2p_local_p2p_ded_returned_1.ms2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local P2P Dedicated Credits Returned - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x1a,umask=0x8\000\00001\000\000 */
{ 4746603 }, /* unc_m2p_local_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x17,umask=0x1\000\00001\000\000 */
{ 4746758 }, /* unc_m2p_local_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x17,umask=0x2\000\00001\000\000 */
{ 4746913 }, /* unc_m2p_local_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Local P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x17,umask=0x4\000\00001\000\000 */
{ 4747068 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x44,umask=0x1\000\00001\000\000 */
{ 4747241 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x44,umask=0x2\000\00001\000\000 */
{ 4747414 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x44,umask=0x4\000\00001\000\000 */
{ 4747587 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_3\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent3. Unit: uncore_m2pcie \000event=0x44,umask=0x8\000\00001\000\000 */
{ 4747760 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_4\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent4. Unit: uncore_m2pcie \000event=0x44,umask=0x10\000\00001\000\000 */
{ 4747934 }, /* unc_m2p_local_shar_p2p_crd_returned.agent_5\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Returned to credit ring : Agent5. Unit: uncore_m2pcie \000event=0x44,umask=0x20\000\00001\000\000 */
{ 4748108 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x1\000\00001\000\000 */
{ 4748277 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x2\000\00001\000\000 */
{ 4748446 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x4\000\00001\000\000 */
{ 4748615 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x8\000\00001\000\000 */
{ 4748784 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x10\000\00001\000\000 */
{ 4748954 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x20\000\00001\000\000 */
{ 4749124 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x40,umask=0x40\000\00001\000\000 */
{ 4749294 }, /* unc_m2p_local_shar_p2p_crd_taken_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x40,umask=0x80\000\00001\000\000 */
{ 4749464 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x1\000\00001\000\000 */
{ 4749633 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x2\000\00001\000\000 */
{ 4749802 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x41,umask=0x4\000\00001\000\000 */
{ 4749971 }, /* unc_m2p_local_shar_p2p_crd_taken_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Local Shared P2P Credit Taken - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x41,umask=0x8\000\00001\000\000 */
{ 4750140 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x1\000\00001\000\000 */
{ 4750313 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf0_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF0 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x2\000\00001\000\000 */
{ 4750486 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x4\000\00001\000\000 */
{ 4750659 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf1_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF1 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x8\000\00001\000\000 */
{ 4750832 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x10\000\00001\000\000 */
{ 4751006 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf2_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF2 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x20\000\00001\000\000 */
{ 4751180 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCB. Unit: uncore_m2pcie \000event=0x4a,umask=0x40\000\00001\000\000 */
{ 4751354 }, /* unc_m2p_local_shar_p2p_crd_wait_0.m2iosf3_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 0 : M2IOSF3 - NCS. Unit: uncore_m2pcie \000event=0x4a,umask=0x80\000\00001\000\000 */
{ 4751528 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x1\000\00001\000\000 */
{ 4751701 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf4_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF4 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x2\000\00001\000\000 */
{ 4751874 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncb\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCB. Unit: uncore_m2pcie \000event=0x4b,umask=0x4\000\00001\000\000 */
{ 4752047 }, /* unc_m2p_local_shar_p2p_crd_wait_1.m2iosf5_ncs\000uncore_m2pcie\000uncore io\000Waiting on Local Shared P2P Credit - 1 : M2IOSF5 - NCS. Unit: uncore_m2pcie \000event=0x4b,umask=0x8\000\00001\000\000 */
{ 4752220 }, /* unc_m2p_misc_external.mbe_inst0\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI0. Unit: uncore_m2pcie \000event=0xe6,umask=0x1\000\00001\000\000 */
{ 4752409 }, /* unc_m2p_misc_external.mbe_inst1\000uncore_m2pcie\000uncore io\000Miscellaneous Events (mostly from MS2IDI) : Number of cycles MBE is high for MS2IDI1. Unit: uncore_m2pcie \000event=0xe6,umask=0x2\000\00001\000\000 */
{ 4752598 }, /* unc_m2p_p2p_crd_occupancy.all\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : All. Unit: uncore_m2pcie \000event=0x14,umask=0x10\000\00001\000\000 */
{ 4752728 }, /* unc_m2p_p2p_crd_occupancy.local_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x1\000\00001\000\000 */
{ 4752869 }, /* unc_m2p_p2p_crd_occupancy.local_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Local NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x2\000\00001\000\000 */
{ 4753010 }, /* unc_m2p_p2p_crd_occupancy.remote_ncb\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCB. Unit: uncore_m2pcie \000event=0x14,umask=0x4\000\00001\000\000 */
{ 4753153 }, /* unc_m2p_p2p_crd_occupancy.remote_ncs\000uncore_m2pcie\000uncore io\000P2P Credit Occupancy : Remote NCS. Unit: uncore_m2pcie \000event=0x14,umask=0x8\000\00001\000\000 */
{ 4753296 }, /* unc_m2p_p2p_ded_received.all\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : All. Unit: uncore_m2pcie \000event=0x16,umask=0x10\000\00001\000\000 */
{ 4753431 }, /* unc_m2p_p2p_ded_received.local_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x1\000\00001\000\000 */
{ 4753577 }, /* unc_m2p_p2p_ded_received.local_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Local NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x2\000\00001\000\000 */
{ 4753723 }, /* unc_m2p_p2p_ded_received.remote_ncb\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCB. Unit: uncore_m2pcie \000event=0x16,umask=0x4\000\00001\000\000 */
{ 4753871 }, /* unc_m2p_p2p_ded_received.remote_ncs\000uncore_m2pcie\000uncore io\000Dedicated Credits Received : Remote NCS. Unit: uncore_m2pcie \000event=0x16,umask=0x8\000\00001\000\000 */
{ 4754019 }, /* unc_m2p_p2p_shar_received.all\000uncore_m2pcie\000uncore io\000Shared Credits  Received : All. Unit: uncore_m2pcie \000event=0x15,umask=0x10\000\00001\000\000 */
{ 4754153 }, /* unc_m2p_p2p_shar_received.local_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x1\000\00001\000\000 */
{ 4754298 }, /* unc_m2p_p2p_shar_received.local_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Local NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x2\000\00001\000\000 */
{ 4754443 }, /* unc_m2p_p2p_shar_received.remote_ncb\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCB. Unit: uncore_m2pcie \000event=0x15,umask=0x4\000\00001\000\000 */
{ 4754590 }, /* unc_m2p_p2p_shar_received.remote_ncs\000uncore_m2pcie\000uncore io\000Shared Credits  Received : Remote NCS. Unit: uncore_m2pcie \000event=0x15,umask=0x8\000\00001\000\000 */
{ 4757228 }, /* unc_m2p_remote_p2p_shar_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent0. Unit: uncore_m2pcie \000event=0x18,umask=0x1\000\00001\000\000 */
{ 4757385 }, /* unc_m2p_remote_p2p_shar_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent1. Unit: uncore_m2pcie \000event=0x18,umask=0x2\000\00001\000\000 */
{ 4757542 }, /* unc_m2p_remote_p2p_shar_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote P2P Shared Credits Returned : Agent2. Unit: uncore_m2pcie \000event=0x18,umask=0x4\000\00001\000\000 */
{ 4757699 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_0\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent0. Unit: uncore_m2pcie \000event=0x45,umask=0x1\000\00001\000\000 */
{ 4757874 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_1\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent1. Unit: uncore_m2pcie \000event=0x45,umask=0x2\000\00001\000\000 */
{ 4758049 }, /* unc_m2p_remote_shar_p2p_crd_returned.agent_2\000uncore_m2pcie\000uncore io\000Remote Shared P2P Credit Returned to credit ring : Agent2. Unit: uncore_m2pcie \000event=0x45,umask=0x4\000\00001\000\000 */
{ 4761234 }, /* unc_m2p_ring_bounces_horz.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AD. Unit: uncore_m2pcie \000event=0xac,umask=0x1\000\00001\000Messages that bounced on the Horizontal Ring. : AD : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4761530 }, /* unc_m2p_ring_bounces_horz.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : AK. Unit: uncore_m2pcie \000event=0xac,umask=0x2\000\00001\000Messages that bounced on the Horizontal Ring. : AK : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4761826 }, /* unc_m2p_ring_bounces_horz.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : BL. Unit: uncore_m2pcie \000event=0xac,umask=0x4\000\00001\000Messages that bounced on the Horizontal Ring. : BL : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4762122 }, /* unc_m2p_ring_bounces_horz.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Horizontal Ring. : IV. Unit: uncore_m2pcie \000event=0xac,umask=0x8\000\00001\000Messages that bounced on the Horizontal Ring. : IV : Number of cycles incoming messages from the Horizontal ring that were bounced, by ring type\000 */
{ 4762418 }, /* unc_m2p_ring_bounces_vert.ad\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : AD. Unit: uncore_m2pcie \000event=0xaa,umask=0x1\000\00001\000Messages that bounced on the Vertical Ring. : AD : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4762708 }, /* unc_m2p_ring_bounces_vert.ak\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x2\000\00001\000Messages that bounced on the Vertical Ring. : Acknowledgements to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763042 }, /* unc_m2p_ring_bounces_vert.akc\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. Unit: uncore_m2pcie \000event=0xaa,umask=0x10\000\00001\000Messages that bounced on the Vertical Ring. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763323 }, /* unc_m2p_ring_bounces_vert.bl\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Data Responses to core. Unit: uncore_m2pcie \000event=0xaa,umask=0x4\000\00001\000Messages that bounced on the Vertical Ring. : Data Responses to core : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763653 }, /* unc_m2p_ring_bounces_vert.iv\000uncore_m2pcie\000uncore io\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xaa,umask=0x8\000\00001\000Messages that bounced on the Vertical Ring. : Snoops of processor's cache. : Number of cycles incoming messages from the Vertical ring that were bounced, by ring type\000 */
{ 4763994 }, /* unc_m2p_ring_sink_starved_horz.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AD. Unit: uncore_m2pcie \000event=0xad,umask=0x1\000\00001\000\000 */
{ 4764140 }, /* unc_m2p_ring_sink_starved_horz.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : AK. Unit: uncore_m2pcie \000event=0xad,umask=0x2\000\00001\000\000 */
{ 4764286 }, /* unc_m2p_ring_sink_starved_horz.ak_ag1\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : Acknowledgements to Agent 1. Unit: uncore_m2pcie \000event=0xad,umask=0x20\000\00001\000\000 */
{ 4764462 }, /* unc_m2p_ring_sink_starved_horz.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : BL. Unit: uncore_m2pcie \000event=0xad,umask=0x4\000\00001\000\000 */
{ 4764608 }, /* unc_m2p_ring_sink_starved_horz.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Horizontal Ring : IV. Unit: uncore_m2pcie \000event=0xad,umask=0x8\000\00001\000\000 */
{ 4764754 }, /* unc_m2p_ring_sink_starved_vert.ad\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : AD. Unit: uncore_m2pcie \000event=0xab,umask=0x1\000\00001\000\000 */
{ 4764898 }, /* unc_m2p_ring_sink_starved_vert.ak\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Acknowledgements to core. Unit: uncore_m2pcie \000event=0xab,umask=0x2\000\00001\000\000 */
{ 4765064 }, /* unc_m2p_ring_sink_starved_vert.akc\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring. Unit: uncore_m2pcie \000event=0xab,umask=0x10\000\00001\000\000 */
{ 4765205 }, /* unc_m2p_ring_sink_starved_vert.bl\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Data Responses to core. Unit: uncore_m2pcie \000event=0xab,umask=0x4\000\00001\000\000 */
{ 4765369 }, /* unc_m2p_ring_sink_starved_vert.iv\000uncore_m2pcie\000uncore io\000Sink Starvation on Vertical Ring : Snoops of processor's cache. Unit: uncore_m2pcie \000event=0xab,umask=0x8\000\00001\000\000 */
{ 4765538 }, /* unc_m2p_ring_src_thrtl\000uncore_m2pcie\000uncore io\000Source Throttle. Unit: uncore_m2pcie \000event=0xae\000\00001\000\000 */
{ 4765639 }, /* unc_m2p_rxc_cycles_ne.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x80\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4765888 }, /* unc_m2p_rxc_cycles_ne.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x1\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766140 }, /* unc_m2p_rxc_cycles_ne.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x2\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766392 }, /* unc_m2p_rxc_cycles_ne.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x4\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766644 }, /* unc_m2p_rxc_cycles_ne.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x20\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4766897 }, /* unc_m2p_rxc_cycles_ne.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Cycles Not Empty. Unit: uncore_m2pcie \000event=0x10,umask=0x40\000\00001\000Ingress (from CMS) Queue Cycles Not Empty : Counts the number of cycles when the M2PCIe Ingress is not empty\000 */
{ 4767655 }, /* unc_m2p_rxc_inserts.all\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x80\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768017 }, /* unc_m2p_rxc_inserts.cha_idi\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x1\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768382 }, /* unc_m2p_rxc_inserts.cha_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x2\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4768747 }, /* unc_m2p_rxc_inserts.cha_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x4\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769112 }, /* unc_m2p_rxc_inserts.iio_ncb\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x20\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4769478 }, /* unc_m2p_rxc_inserts.iio_ncs\000uncore_m2pcie\000uncore io\000Ingress (from CMS) Queue Inserts. Unit: uncore_m2pcie \000event=0x11,umask=0x40\000\00001\000Ingress (from CMS) Queue Inserts : Counts the number of entries inserted into the M2PCIe Ingress Queue.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue latency\000 */
{ 4770575 }, /* unc_m2p_rxr_busy_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4771037 }, /* unc_m2p_rxr_busy_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4771478 }, /* unc_m2p_rxr_busy_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4771924 }, /* unc_m2p_rxr_busy_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe5,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority : All == Credited + Uncredited\000 */
{ 4772386 }, /* unc_m2p_rxr_busy_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe5,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4772827 }, /* unc_m2p_rxr_busy_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe5,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, because a message from the other queue has higher priority\000 */
{ 4773273 }, /* unc_m2p_rxr_bypass.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x11\000\00001\000Transgress Ingress Bypass : AD - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4773522 }, /* unc_m2p_rxr_bypass.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x10\000\00001\000Transgress Ingress Bypass : AD - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4773750 }, /* unc_m2p_rxr_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x1\000\00001\000Transgress Ingress Bypass : AD - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4773983 }, /* unc_m2p_rxr_bypass.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AK. Unit: uncore_m2pcie \000event=0xe2,umask=0x2\000\00001\000Transgress Ingress Bypass : AK : Number of packets bypassing the CMS Ingress\000 */
{ 4774184 }, /* unc_m2p_rxr_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x80\000\00001\000Transgress Ingress Bypass : AKC - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4774421 }, /* unc_m2p_rxr_bypass.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - All. Unit: uncore_m2pcie \000event=0xe2,umask=0x44\000\00001\000Transgress Ingress Bypass : BL - All : Number of packets bypassing the CMS Ingress : All == Credited + Uncredited\000 */
{ 4774670 }, /* unc_m2p_rxr_bypass.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Credited. Unit: uncore_m2pcie \000event=0xe2,umask=0x40\000\00001\000Transgress Ingress Bypass : BL - Credited : Number of packets bypassing the CMS Ingress\000 */
{ 4774898 }, /* unc_m2p_rxr_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe2,umask=0x4\000\00001\000Transgress Ingress Bypass : BL - Uncredited : Number of packets bypassing the CMS Ingress\000 */
{ 4775131 }, /* unc_m2p_rxr_bypass.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Bypass : IV. Unit: uncore_m2pcie \000event=0xe2,umask=0x8\000\00001\000Transgress Ingress Bypass : IV : Number of packets bypassing the CMS Ingress\000 */
{ 4775332 }, /* unc_m2p_rxr_crd_starved.ad_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x11\000\00001\000Transgress Injection Starvation : AD - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4775806 }, /* unc_m2p_rxr_crd_starved.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x10\000\00001\000Transgress Injection Starvation : AD - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4776258 }, /* unc_m2p_rxr_crd_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x1\000\00001\000Transgress Injection Starvation : AD - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4776715 }, /* unc_m2p_rxr_crd_starved.ak\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xe3,umask=0x2\000\00001\000Transgress Injection Starvation : AK : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4777140 }, /* unc_m2p_rxr_crd_starved.bl_all\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xe3,umask=0x44\000\00001\000Transgress Injection Starvation : BL - All : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit. : All == Credited + Uncredited\000 */
{ 4777614 }, /* unc_m2p_rxr_crd_starved.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x40\000\00001\000Transgress Injection Starvation : BL - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778066 }, /* unc_m2p_rxr_crd_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe3,umask=0x4\000\00001\000Transgress Injection Starvation : BL - Uncredited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778523 }, /* unc_m2p_rxr_crd_starved.ifv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IFV - Credited. Unit: uncore_m2pcie \000event=0xe3,umask=0x80\000\00001\000Transgress Injection Starvation : IFV - Credited : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4778974 }, /* unc_m2p_rxr_crd_starved.iv\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xe3,umask=0x8\000\00001\000Transgress Injection Starvation : IV : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4779399 }, /* unc_m2p_rxr_crd_starved_1\000uncore_m2pcie\000uncore io\000Transgress Injection Starvation. Unit: uncore_m2pcie \000event=0xe4\000\00001\000Transgress Injection Starvation : Counts cycles under injection starvation mode.  This starvation is triggered when the CMS Ingress cannot send a transaction onto the mesh for a long period of time.  In this case, the Ingress is unable to forward to the Egress due to a lack of credit\000 */
{ 4779803 }, /* unc_m2p_rxr_inserts.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x11\000\00001\000Transgress Ingress Allocations : AD - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4780127 }, /* unc_m2p_rxr_inserts.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x10\000\00001\000Transgress Ingress Allocations : AD - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4780430 }, /* unc_m2p_rxr_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x1\000\00001\000Transgress Ingress Allocations : AD - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4780738 }, /* unc_m2p_rxr_inserts.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AK. Unit: uncore_m2pcie \000event=0xe1,umask=0x2\000\00001\000Transgress Ingress Allocations : AK : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781014 }, /* unc_m2p_rxr_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x80\000\00001\000Transgress Ingress Allocations : AKC - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781326 }, /* unc_m2p_rxr_inserts.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - All. Unit: uncore_m2pcie \000event=0xe1,umask=0x44\000\00001\000Transgress Ingress Allocations : BL - All : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4781650 }, /* unc_m2p_rxr_inserts.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Credited. Unit: uncore_m2pcie \000event=0xe1,umask=0x40\000\00001\000Transgress Ingress Allocations : BL - Credited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4781953 }, /* unc_m2p_rxr_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe1,umask=0x4\000\00001\000Transgress Ingress Allocations : BL - Uncredited : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4782261 }, /* unc_m2p_rxr_inserts.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Allocations : IV. Unit: uncore_m2pcie \000event=0xe1,umask=0x8\000\00001\000Transgress Ingress Allocations : IV : Number of allocations into the CMS Ingress  The Ingress is used to queue up requests received from the mesh\000 */
{ 4782537 }, /* unc_m2p_rxr_occupancy.ad_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x11\000\00001\000Transgress Ingress Occupancy : AD - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4782867 }, /* unc_m2p_rxr_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x10\000\00001\000Transgress Ingress Occupancy : AD - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783176 }, /* unc_m2p_rxr_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x1\000\00001\000Transgress Ingress Occupancy : AD - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783490 }, /* unc_m2p_rxr_occupancy.ak\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AK. Unit: uncore_m2pcie \000event=0xe0,umask=0x2\000\00001\000Transgress Ingress Occupancy : AK : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4783772 }, /* unc_m2p_rxr_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x80\000\00001\000Transgress Ingress Occupancy : AKC - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4784090 }, /* unc_m2p_rxr_occupancy.bl_all\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xe0,umask=0x44\000\00001\000Transgress Ingress Occupancy : BL - All : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh : All == Credited + Uncredited\000 */
{ 4784420 }, /* unc_m2p_rxr_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xe0,umask=0x20\000\00001\000Transgress Ingress Occupancy : BL - Credited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4784729 }, /* unc_m2p_rxr_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xe0,umask=0x4\000\00001\000Transgress Ingress Occupancy : BL - Uncredited : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4785043 }, /* unc_m2p_rxr_occupancy.iv\000uncore_m2pcie\000uncore io\000Transgress Ingress Occupancy : IV. Unit: uncore_m2pcie \000event=0xe0,umask=0x8\000\00001\000Transgress Ingress Occupancy : IV : Occupancy event for the Ingress buffers in the CMS  The Ingress is used to queue up requests received from the mesh\000 */
{ 4785325 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd0,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4785679 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd0,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786033 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd0,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786387 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd0,umask=0x8\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4786741 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd0,umask=0x10\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787096 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd0,umask=0x20\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787451 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd0,umask=0x40\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4787806 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd0,umask=0x80\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788161 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd2,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 0 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788515 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd2,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 1 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4788869 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd2,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 2 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789223 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd2,umask=0x8\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 3 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789577 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd2,umask=0x10\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 4 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4789932 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd2,umask=0x20\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 5 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790287 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd2,umask=0x40\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 6 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790642 }, /* unc_m2p_stall0_no_txr_horz_crd_ad_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd2,umask=0x80\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 7 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4790997 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd4,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4791351 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd4,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4791705 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd4,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792059 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd4,umask=0x8\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792413 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd4,umask=0x10\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4792768 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd4,umask=0x20\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793123 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd4,umask=0x40\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793478 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag0.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd4,umask=0x80\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4793833 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr0\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 0. Unit: uncore_m2pcie \000event=0xd6,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 0 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794187 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr1\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 1. Unit: uncore_m2pcie \000event=0xd6,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 1 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794541 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr2\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 2. Unit: uncore_m2pcie \000event=0xd6,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 2 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4794895 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr3\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 3. Unit: uncore_m2pcie \000event=0xd6,umask=0x8\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 3 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795249 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr4\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 4. Unit: uncore_m2pcie \000event=0xd6,umask=0x10\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 4 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795604 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr5\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 5. Unit: uncore_m2pcie \000event=0xd6,umask=0x20\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 5 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4795959 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr6\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 6. Unit: uncore_m2pcie \000event=0xd6,umask=0x40\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 6 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4796314 }, /* unc_m2p_stall0_no_txr_horz_crd_bl_ag1.tgr7\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 7. Unit: uncore_m2pcie \000event=0xd6,umask=0x80\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 7 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4796669 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd1,umask=0x4\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797026 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd1,umask=0x1\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797380 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag0.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd1,umask=0x2\000\00001\000Stall on No AD Agent0 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4797734 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd3,umask=0x4\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 10 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798093 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd3,umask=0x1\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 8 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798449 }, /* unc_m2p_stall1_no_txr_horz_crd_ad_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No AD Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd3,umask=0x2\000\00001\000Stall on No AD Agent1 Transgress Credits : For Transgress 9 : Number of cycles the AD Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4798805 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd5,umask=0x4\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799164 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd5,umask=0x1\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799520 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag0_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent0 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd5,umask=0x2\000\00001\000Stall on No BL Agent0 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 0 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4799876 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr10\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 10. Unit: uncore_m2pcie \000event=0xd7,umask=0x4\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 10 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4800235 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr8\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 8. Unit: uncore_m2pcie \000event=0xd7,umask=0x1\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 8 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4800591 }, /* unc_m2p_stall1_no_txr_horz_crd_bl_ag1_1.tgr9\000uncore_m2pcie\000uncore io\000Stall on No BL Agent1 Transgress Credits : For Transgress 9. Unit: uncore_m2pcie \000event=0xd7,umask=0x2\000\00001\000Stall on No BL Agent1 Transgress Credits : For Transgress 9 : Number of cycles the BL Agent 1 Egress Buffer is stalled waiting for a TGR credit to become available, per transgress\000 */
{ 4801067 }, /* unc_m2p_txc_credits.prq\000uncore_m2pcie\000uncore io\000UNC_M2P_TxC_CREDITS.PRQ. Unit: uncore_m2pcie \000event=0x2d,umask=0x1\000\00001\000\000 */
{ 4801187 }, /* unc_m2p_txc_cycles_full.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x1\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4801490 }, /* unc_m2p_txc_cycles_full.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x10\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4801794 }, /* unc_m2p_txc_cycles_full.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x2\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802097 }, /* unc_m2p_txc_cycles_full.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x20\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802401 }, /* unc_m2p_txc_cycles_full.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x4\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4802704 }, /* unc_m2p_txc_cycles_full.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Full. Unit: uncore_m2pcie \000event=0x25,umask=0x40\000\00001\000Egress (to CMS) Cycles Full : Counts the number of cycles when the M2PCIe Egress is full.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent\000 */
{ 4804326 }, /* unc_m2p_txc_cycles_ne.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x1\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4804855 }, /* unc_m2p_txc_cycles_ne.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x10\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4805385 }, /* unc_m2p_txc_cycles_ne.ak_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x2\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4805914 }, /* unc_m2p_txc_cycles_ne.ak_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x20\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4806444 }, /* unc_m2p_txc_cycles_ne.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x4\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4806973 }, /* unc_m2p_txc_cycles_ne.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Cycles Not Empty. Unit: uncore_m2pcie \000event=0x23,umask=0x40\000\00001\000Egress (to CMS) Cycles Not Empty : Counts the number of cycles when the M2PCIe Egress is not empty.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy.  Multiple egress buffers can be tracked at a given time using multiple counters\000 */
{ 4809737 }, /* unc_m2p_txc_inserts.ad_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x1\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4810184 }, /* unc_m2p_txc_inserts.ad_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x10\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4810632 }, /* unc_m2p_txc_inserts.ak_crd_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x8\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811083 }, /* unc_m2p_txc_inserts.ak_crd_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x80\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811535 }, /* unc_m2p_txc_inserts.bl_0\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x4\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4811982 }, /* unc_m2p_txc_inserts.bl_1\000uncore_m2pcie\000uncore io\000Egress (to CMS) Ingress. Unit: uncore_m2pcie \000event=0x24,umask=0x40\000\00001\000Egress (to CMS) Ingress : Counts the number of number of messages inserted into the  the M2PCIe Egress queue.  This tracks messages for one of the two CMS ports that are used by the M2PCIe agent.  This can be used in conjunction with the M2PCIe Ingress Occupancy Accumulator event in order to calculate average queue occupancy\000 */
{ 4812430 }, /* unc_m2p_txr_horz_ads_used.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x11\000\00001\000CMS Horizontal ADS Used : AD - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4812737 }, /* unc_m2p_txr_horz_ads_used.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x10\000\00001\000CMS Horizontal ADS Used : AD - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813022 }, /* unc_m2p_txr_horz_ads_used.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x1\000\00001\000CMS Horizontal ADS Used : AD - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813312 }, /* unc_m2p_txr_horz_ads_used.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - All. Unit: uncore_m2pcie \000event=0xa6,umask=0x44\000\00001\000CMS Horizontal ADS Used : BL - All : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4813619 }, /* unc_m2p_txr_horz_ads_used.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa6,umask=0x40\000\00001\000CMS Horizontal ADS Used : BL - Credited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4813904 }, /* unc_m2p_txr_horz_ads_used.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal ADS Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa6,umask=0x4\000\00001\000CMS Horizontal ADS Used : BL - Uncredited : Number of packets using the Horizontal Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4814194 }, /* unc_m2p_txr_horz_bypass.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x11\000\00001\000CMS Horizontal Bypass Used : AD - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4814497 }, /* unc_m2p_txr_horz_bypass.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x10\000\00001\000CMS Horizontal Bypass Used : AD - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4814778 }, /* unc_m2p_txr_horz_bypass.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x1\000\00001\000CMS Horizontal Bypass Used : AD - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815064 }, /* unc_m2p_txr_horz_bypass.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AK. Unit: uncore_m2pcie \000event=0xa7,umask=0x2\000\00001\000CMS Horizontal Bypass Used : AK : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815318 }, /* unc_m2p_txr_horz_bypass.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x80\000\00001\000CMS Horizontal Bypass Used : AKC - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4815608 }, /* unc_m2p_txr_horz_bypass.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - All. Unit: uncore_m2pcie \000event=0xa7,umask=0x44\000\00001\000CMS Horizontal Bypass Used : BL - All : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent. : All == Credited + Uncredited\000 */
{ 4815911 }, /* unc_m2p_txr_horz_bypass.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Credited. Unit: uncore_m2pcie \000event=0xa7,umask=0x40\000\00001\000CMS Horizontal Bypass Used : BL - Credited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816192 }, /* unc_m2p_txr_horz_bypass.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa7,umask=0x4\000\00001\000CMS Horizontal Bypass Used : BL - Uncredited : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816478 }, /* unc_m2p_txr_horz_bypass.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Bypass Used : IV. Unit: uncore_m2pcie \000event=0xa7,umask=0x8\000\00001\000CMS Horizontal Bypass Used : IV : Number of packets bypassing the Horizontal Egress, broken down by ring type and CMS Agent\000 */
{ 4816732 }, /* unc_m2p_txr_horz_cycles_full.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4817132 }, /* unc_m2p_txr_horz_cycles_full.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4817510 }, /* unc_m2p_txr_horz_cycles_full.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4817893 }, /* unc_m2p_txr_horz_cycles_full.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AK. Unit: uncore_m2pcie \000event=0xa2,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AK : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4818244 }, /* unc_m2p_txr_horz_cycles_full.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Full : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4818631 }, /* unc_m2p_txr_horz_cycles_full.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - All. Unit: uncore_m2pcie \000event=0xa2,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4819031 }, /* unc_m2p_txr_horz_cycles_full.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited. Unit: uncore_m2pcie \000event=0xa2,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4819409 }, /* unc_m2p_txr_horz_cycles_full.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa2,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Full : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4819792 }, /* unc_m2p_txr_horz_cycles_full.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Full : IV. Unit: uncore_m2pcie \000event=0xa2,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Full : IV : Cycles the Transgress buffers in the Common Mesh Stop are Full.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4820143 }, /* unc_m2p_txr_horz_cycles_ne.ad_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x11\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4820556 }, /* unc_m2p_txr_horz_cycles_ne.ad_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x10\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4820947 }, /* unc_m2p_txr_horz_cycles_ne.ad_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x1\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AD - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4821343 }, /* unc_m2p_txr_horz_cycles_ne.ak\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AK. Unit: uncore_m2pcie \000event=0xa3,umask=0x2\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AK : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4821707 }, /* unc_m2p_txr_horz_cycles_ne.akc_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x80\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : AKC - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4822107 }, /* unc_m2p_txr_horz_cycles_ne.bl_all\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All. Unit: uncore_m2pcie \000event=0xa3,umask=0x44\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - All : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4822520 }, /* unc_m2p_txr_horz_cycles_ne.bl_crd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited. Unit: uncore_m2pcie \000event=0xa3,umask=0x40\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Credited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4822911 }, /* unc_m2p_txr_horz_cycles_ne.bl_uncrd\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa3,umask=0x4\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : BL - Uncredited : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4823307 }, /* unc_m2p_txr_horz_cycles_ne.iv\000uncore_m2pcie\000uncore io\000Cycles CMS Horizontal Egress Queue is Not Empty : IV. Unit: uncore_m2pcie \000event=0xa3,umask=0x8\000\00001\000Cycles CMS Horizontal Egress Queue is Not Empty : IV : Cycles the Transgress buffers in the Common Mesh Stop are Not-Empty.  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4823671 }, /* unc_m2p_txr_horz_inserts.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x11\000\00001\000CMS Horizontal Egress Inserts : AD - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4824051 }, /* unc_m2p_txr_horz_inserts.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x10\000\00001\000CMS Horizontal Egress Inserts : AD - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4824409 }, /* unc_m2p_txr_horz_inserts.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x1\000\00001\000CMS Horizontal Egress Inserts : AD - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4824772 }, /* unc_m2p_txr_horz_inserts.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AK. Unit: uncore_m2pcie \000event=0xa1,umask=0x2\000\00001\000CMS Horizontal Egress Inserts : AK : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4825103 }, /* unc_m2p_txr_horz_inserts.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x80\000\00001\000CMS Horizontal Egress Inserts : AKC - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4825470 }, /* unc_m2p_txr_horz_inserts.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - All. Unit: uncore_m2pcie \000event=0xa1,umask=0x44\000\00001\000CMS Horizontal Egress Inserts : BL - All : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4825850 }, /* unc_m2p_txr_horz_inserts.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Credited. Unit: uncore_m2pcie \000event=0xa1,umask=0x40\000\00001\000CMS Horizontal Egress Inserts : BL - Credited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826208 }, /* unc_m2p_txr_horz_inserts.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa1,umask=0x4\000\00001\000CMS Horizontal Egress Inserts : BL - Uncredited : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826571 }, /* unc_m2p_txr_horz_inserts.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Inserts : IV. Unit: uncore_m2pcie \000event=0xa1,umask=0x8\000\00001\000CMS Horizontal Egress Inserts : IV : Number of allocations into the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4826902 }, /* unc_m2p_txr_horz_nack.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x11\000\00001\000CMS Horizontal Egress NACKs : AD - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4827180 }, /* unc_m2p_txr_horz_nack.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x10\000\00001\000CMS Horizontal Egress NACKs : AD - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827437 }, /* unc_m2p_txr_horz_nack.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x1\000\00001\000CMS Horizontal Egress NACKs : AD - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827699 }, /* unc_m2p_txr_horz_nack.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AK. Unit: uncore_m2pcie \000event=0xa4,umask=0x2\000\00001\000CMS Horizontal Egress NACKs : AK : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4827929 }, /* unc_m2p_txr_horz_nack.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x80\000\00001\000CMS Horizontal Egress NACKs : AKC - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828195 }, /* unc_m2p_txr_horz_nack.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - All. Unit: uncore_m2pcie \000event=0xa4,umask=0x44\000\00001\000CMS Horizontal Egress NACKs : BL - All : Counts number of Egress packets NACK'ed on to the Horizontal Ring : All == Credited + Uncredited\000 */
{ 4828473 }, /* unc_m2p_txr_horz_nack.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Credited. Unit: uncore_m2pcie \000event=0xa4,umask=0x40\000\00001\000CMS Horizontal Egress NACKs : BL - Credited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828730 }, /* unc_m2p_txr_horz_nack.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa4,umask=0x4\000\00001\000CMS Horizontal Egress NACKs : BL - Uncredited : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4828992 }, /* unc_m2p_txr_horz_nack.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress NACKs : IV. Unit: uncore_m2pcie \000event=0xa4,umask=0x8\000\00001\000CMS Horizontal Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Horizontal Ring\000 */
{ 4829222 }, /* unc_m2p_txr_horz_occupancy.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x11\000\00001\000CMS Horizontal Egress Occupancy : AD - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4829601 }, /* unc_m2p_txr_horz_occupancy.ad_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x10\000\00001\000CMS Horizontal Egress Occupancy : AD - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4829958 }, /* unc_m2p_txr_horz_occupancy.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x1\000\00001\000CMS Horizontal Egress Occupancy : AD - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4830320 }, /* unc_m2p_txr_horz_occupancy.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AK. Unit: uncore_m2pcie \000event=0xa0,umask=0x2\000\00001\000CMS Horizontal Egress Occupancy : AK : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4830650 }, /* unc_m2p_txr_horz_occupancy.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x80\000\00001\000CMS Horizontal Egress Occupancy : AKC - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4831016 }, /* unc_m2p_txr_horz_occupancy.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - All. Unit: uncore_m2pcie \000event=0xa0,umask=0x44\000\00001\000CMS Horizontal Egress Occupancy : BL - All : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh. : All == Credited + Uncredited\000 */
{ 4831395 }, /* unc_m2p_txr_horz_occupancy.bl_crd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Credited. Unit: uncore_m2pcie \000event=0xa0,umask=0x40\000\00001\000CMS Horizontal Egress Occupancy : BL - Credited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4831752 }, /* unc_m2p_txr_horz_occupancy.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa0,umask=0x4\000\00001\000CMS Horizontal Egress Occupancy : BL - Uncredited : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4832114 }, /* unc_m2p_txr_horz_occupancy.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Occupancy : IV. Unit: uncore_m2pcie \000event=0xa0,umask=0x8\000\00001\000CMS Horizontal Egress Occupancy : IV : Occupancy event for the Transgress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Horizontal Ring on the Mesh\000 */
{ 4832444 }, /* unc_m2p_txr_horz_starved.ad_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4832856 }, /* unc_m2p_txr_horz_starved.ad_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AD - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x1\000\00001\000CMS Horizontal Egress Injection Starvation : AD - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4833252 }, /* unc_m2p_txr_horz_starved.ak\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AK. Unit: uncore_m2pcie \000event=0xa5,umask=0x2\000\00001\000CMS Horizontal Egress Injection Starvation : AK : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4833616 }, /* unc_m2p_txr_horz_starved.akc_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x80\000\00001\000CMS Horizontal Egress Injection Starvation : AKC - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4834016 }, /* unc_m2p_txr_horz_starved.bl_all\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - All. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - All : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time. : All == Credited + Uncredited\000 */
{ 4834428 }, /* unc_m2p_txr_horz_starved.bl_uncrd\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : BL - Uncredited. Unit: uncore_m2pcie \000event=0xa5,umask=0x4\000\00001\000CMS Horizontal Egress Injection Starvation : BL - Uncredited : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4834824 }, /* unc_m2p_txr_horz_starved.iv\000uncore_m2pcie\000uncore io\000CMS Horizontal Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0xa5,umask=0x8\000\00001\000CMS Horizontal Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Transgress buffer cannot send a transaction onto the Horizontal ring for a long period of time\000 */
{ 4835188 }, /* unc_m2p_txr_vert_ads_used.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4835464 }, /* unc_m2p_txr_vert_ads_used.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4835741 }, /* unc_m2p_txr_vert_ads_used.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9c,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4836017 }, /* unc_m2p_txr_vert_ads_used.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9c,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets using the Vertical Anti-Deadlock Slot, broken down by ring type and CMS Agent\000 */
{ 4836294 }, /* unc_m2p_txr_vert_bypass.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x1\000\00001\000CMS Vertical ADS Used : AD - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4836560 }, /* unc_m2p_txr_vert_bypass.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x10\000\00001\000CMS Vertical ADS Used : AD - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4836827 }, /* unc_m2p_txr_vert_bypass.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x2\000\00001\000CMS Vertical ADS Used : AK - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837093 }, /* unc_m2p_txr_vert_bypass.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x20\000\00001\000CMS Vertical ADS Used : AK - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837360 }, /* unc_m2p_txr_vert_bypass.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9d,umask=0x4\000\00001\000CMS Vertical ADS Used : BL - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837626 }, /* unc_m2p_txr_vert_bypass.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x40\000\00001\000CMS Vertical ADS Used : BL - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4837893 }, /* unc_m2p_txr_vert_bypass.iv_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : IV - Agent 1. Unit: uncore_m2pcie \000event=0x9d,umask=0x8\000\00001\000CMS Vertical ADS Used : IV - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838159 }, /* unc_m2p_txr_vert_bypass_1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9e,umask=0x1\000\00001\000CMS Vertical ADS Used : AKC - Agent 0 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838430 }, /* unc_m2p_txr_vert_bypass_1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical ADS Used : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9e,umask=0x2\000\00001\000CMS Vertical ADS Used : AKC - Agent 1 : Number of packets bypassing the Vertical Egress, broken down by ring type and CMS Agent\000 */
{ 4838701 }, /* unc_m2p_txr_vert_cycles_full0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4839203 }, /* unc_m2p_txr_vert_cycles_full0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4839674 }, /* unc_m2p_txr_vert_cycles_full0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4840158 }, /* unc_m2p_txr_vert_cycles_full0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4840583 }, /* unc_m2p_txr_vert_cycles_full0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4841083 }, /* unc_m2p_txr_vert_cycles_full0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1. Unit: uncore_m2pcie \000event=0x94,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Full : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4841577 }, /* unc_m2p_txr_vert_cycles_full0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0. Unit: uncore_m2pcie \000event=0x94,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Full : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4842049 }, /* unc_m2p_txr_vert_cycles_full1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x95,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4842554 }, /* unc_m2p_txr_vert_cycles_full1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x95,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Full : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Full.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4843041 }, /* unc_m2p_txr_vert_cycles_ne0.ad_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4843552 }, /* unc_m2p_txr_vert_cycles_ne0.ad_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x10\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AD - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4844032 }, /* unc_m2p_txr_vert_cycles_ne0.ak_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4844525 }, /* unc_m2p_txr_vert_cycles_ne0.ak_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x20\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AK - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4844959 }, /* unc_m2p_txr_vert_cycles_ne0.bl_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x4\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4845468 }, /* unc_m2p_txr_vert_cycles_ne0.bl_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1. Unit: uncore_m2pcie \000event=0x96,umask=0x40\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : BL - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4845971 }, /* unc_m2p_txr_vert_cycles_ne0.iv_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0. Unit: uncore_m2pcie \000event=0x96,umask=0x8\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : IV - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4846452 }, /* unc_m2p_txr_vert_cycles_ne1.akc_ag0\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x97,umask=0x1\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 0 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4846966 }, /* unc_m2p_txr_vert_cycles_ne1.akc_ag1\000uncore_m2pcie\000uncore io\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x97,umask=0x2\000\00001\000Cycles CMS Vertical Egress Queue Is Not Empty : AKC - Agent 1 : Number of cycles the Common Mesh Stop Egress was Not Empty.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4847462 }, /* unc_m2p_txr_vert_inserts0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x1\000\00001\000CMS Vert Egress Allocations : AD - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4847931 }, /* unc_m2p_txr_vert_inserts0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AD - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x10\000\00001\000CMS Vert Egress Allocations : AD - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4848369 }, /* unc_m2p_txr_vert_inserts0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x2\000\00001\000CMS Vert Egress Allocations : AK - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4848820 }, /* unc_m2p_txr_vert_inserts0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AK - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x20\000\00001\000CMS Vert Egress Allocations : AK - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4849212 }, /* unc_m2p_txr_vert_inserts0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x4\000\00001\000CMS Vert Egress Allocations : BL - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4849679 }, /* unc_m2p_txr_vert_inserts0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : BL - Agent 1. Unit: uncore_m2pcie \000event=0x92,umask=0x40\000\00001\000CMS Vert Egress Allocations : BL - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4850140 }, /* unc_m2p_txr_vert_inserts0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : IV - Agent 0. Unit: uncore_m2pcie \000event=0x92,umask=0x8\000\00001\000CMS Vert Egress Allocations : IV - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4850579 }, /* unc_m2p_txr_vert_inserts1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x93,umask=0x1\000\00001\000CMS Vert Egress Allocations : AKC - Agent 0 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4851051 }, /* unc_m2p_txr_vert_inserts1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Allocations : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x93,umask=0x2\000\00001\000CMS Vert Egress Allocations : AKC - Agent 1 : Number of allocations into the Common Mesh Stop Egress.  The Egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4851505 }, /* unc_m2p_txr_vert_nack0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AD - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4851754 }, /* unc_m2p_txr_vert_nack0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AD - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x10\000\00001\000CMS Vertical Egress NACKs : AD - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852004 }, /* unc_m2p_txr_vert_nack0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AK - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852253 }, /* unc_m2p_txr_vert_nack0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AK - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x20\000\00001\000CMS Vertical Egress NACKs : AK - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852503 }, /* unc_m2p_txr_vert_nack0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 0. Unit: uncore_m2pcie \000event=0x98,umask=0x4\000\00001\000CMS Vertical Egress NACKs : BL - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4852752 }, /* unc_m2p_txr_vert_nack0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : BL - Agent 1. Unit: uncore_m2pcie \000event=0x98,umask=0x40\000\00001\000CMS Vertical Egress NACKs : BL - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853002 }, /* unc_m2p_txr_vert_nack0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : IV. Unit: uncore_m2pcie \000event=0x98,umask=0x8\000\00001\000CMS Vertical Egress NACKs : IV : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853231 }, /* unc_m2p_txr_vert_nack1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x99,umask=0x1\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 0 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853483 }, /* unc_m2p_txr_vert_nack1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress NACKs : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x99,umask=0x2\000\00001\000CMS Vertical Egress NACKs : AKC - Agent 1 : Counts number of Egress packets NACK'ed on to the Vertical Ring\000 */
{ 4853735 }, /* unc_m2p_txr_vert_occupancy0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AD - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4854209 }, /* unc_m2p_txr_vert_occupancy0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AD - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x10\000\00001\000CMS Vert Egress Occupancy : AD - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AD ring.  This is commonly used for outbound requests\000 */
{ 4854652 }, /* unc_m2p_txr_vert_occupancy0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AK - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4855108 }, /* unc_m2p_txr_vert_occupancy0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AK - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x20\000\00001\000CMS Vert Egress Occupancy : AK - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the AK ring\000 */
{ 4855505 }, /* unc_m2p_txr_vert_occupancy0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x4\000\00001\000CMS Vert Egress Occupancy : BL - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the BL ring.  This is commonly used to send data from the cache to various destinations\000 */
{ 4855977 }, /* unc_m2p_txr_vert_occupancy0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : BL - Agent 1. Unit: uncore_m2pcie \000event=0x90,umask=0x40\000\00001\000CMS Vert Egress Occupancy : BL - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 1 destined for the BL ring.  This is commonly used for transferring writeback data to the cache\000 */
{ 4856443 }, /* unc_m2p_txr_vert_occupancy0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : IV - Agent 0. Unit: uncore_m2pcie \000event=0x90,umask=0x8\000\00001\000CMS Vert Egress Occupancy : IV - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the IV ring.  This is commonly used for snoops to the cores\000 */
{ 4856887 }, /* unc_m2p_txr_vert_occupancy1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x91,umask=0x1\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 0 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AD ring.  Some example include outbound requests, snoop requests, and snoop responses\000 */
{ 4857364 }, /* unc_m2p_txr_vert_occupancy1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vert Egress Occupancy : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x91,umask=0x2\000\00001\000CMS Vert Egress Occupancy : AKC - Agent 1 : Occupancy event for the Egress buffers in the Common Mesh Stop  The egress is used to queue up requests destined for the Vertical Ring on the Mesh. : Ring transactions from Agent 0 destined for the AK ring.  This is commonly used for credit returns and GO responses\000 */
{ 4857823 }, /* unc_m2p_txr_vert_starved0.ad_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858195 }, /* unc_m2p_txr_vert_starved0.ad_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AD - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x10\000\00001\000CMS Vertical Egress Injection Starvation : AD - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858568 }, /* unc_m2p_txr_vert_starved0.ak_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4858940 }, /* unc_m2p_txr_vert_starved0.ak_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AK - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x20\000\00001\000CMS Vertical Egress Injection Starvation : AK - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4859313 }, /* unc_m2p_txr_vert_starved0.bl_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 0. Unit: uncore_m2pcie \000event=0x9a,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4859685 }, /* unc_m2p_txr_vert_starved0.bl_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : BL - Agent 1. Unit: uncore_m2pcie \000event=0x9a,umask=0x40\000\00001\000CMS Vertical Egress Injection Starvation : BL - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860058 }, /* unc_m2p_txr_vert_starved0.iv_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : IV. Unit: uncore_m2pcie \000event=0x9a,umask=0x8\000\00001\000CMS Vertical Egress Injection Starvation : IV : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860410 }, /* unc_m2p_txr_vert_starved1.akc_ag0\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x1\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4860785 }, /* unc_m2p_txr_vert_starved1.akc_ag1\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 1. Unit: uncore_m2pcie \000event=0x9b,umask=0x2\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 1 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4861160 }, /* unc_m2p_txr_vert_starved1.tgc\000uncore_m2pcie\000uncore io\000CMS Vertical Egress Injection Starvation : AKC - Agent 0. Unit: uncore_m2pcie \000event=0x9b,umask=0x4\000\00001\000CMS Vertical Egress Injection Starvation : AKC - Agent 0 : Counts injection starvation.  This starvation is triggered when the CMS Egress cannot send a transaction onto the Vertical ring for a long period of time\000 */
{ 4861531 }, /* unc_m2p_vert_ring_ad_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x4\000\00001\000Vertical AD Ring In Use : Down and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4862447 }, /* unc_m2p_vert_ring_ad_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x8\000\00001\000Vertical AD Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4863360 }, /* unc_m2p_vert_ring_ad_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb0,umask=0x1\000\00001\000Vertical AD Ring In Use : Up and Even : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4864272 }, /* unc_m2p_vert_ring_ad_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AD Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb0,umask=0x2\000\00001\000Vertical AD Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AD ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  We really have two rings  -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4865181 }, /* unc_m2p_vert_ring_ak_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x4\000\00001\000Vertical AK Ring In Use : Down and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4866097 }, /* unc_m2p_vert_ring_ak_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x8\000\00001\000Vertical AK Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4867010 }, /* unc_m2p_vert_ring_ak_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb1,umask=0x1\000\00001\000Vertical AK Ring In Use : Up and Even : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4867922 }, /* unc_m2p_vert_ring_ak_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AK Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb1,umask=0x2\000\00001\000Vertical AK Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AK ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4868831 }, /* unc_m2p_vert_ring_akc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x4\000\00001\000Vertical AKC Ring In Use : Down and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4869755 }, /* unc_m2p_vert_ring_akc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x8\000\00001\000Vertical AKC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4870676 }, /* unc_m2p_vert_ring_akc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb4,umask=0x1\000\00001\000Vertical AKC Ring In Use : Up and Even : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4871596 }, /* unc_m2p_vert_ring_akc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical AKC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb4,umask=0x2\000\00001\000Vertical AKC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical AKC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4872513 }, /* unc_m2p_vert_ring_bl_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x4\000\00001\000Vertical BL Ring in Use : Down and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4873427 }, /* unc_m2p_vert_ring_bl_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x8\000\00001\000Vertical BL Ring in Use : Down and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4874338 }, /* unc_m2p_vert_ring_bl_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Even. Unit: uncore_m2pcie \000event=0xb2,umask=0x1\000\00001\000Vertical BL Ring in Use : Up and Even : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4875248 }, /* unc_m2p_vert_ring_bl_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical BL Ring in Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb2,umask=0x2\000\00001\000Vertical BL Ring in Use : Up and Odd : Counts the number of cycles that the Vertical BL ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from  the ring stop.We really have two rings -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4876155 }, /* unc_m2p_vert_ring_iv_in_use.dn\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Down. Unit: uncore_m2pcie \000event=0xb3,umask=0x4\000\00001\000Vertical IV Ring in Use : Down : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4876743 }, /* unc_m2p_vert_ring_iv_in_use.up\000uncore_m2pcie\000uncore io\000Vertical IV Ring in Use : Up. Unit: uncore_m2pcie \000event=0xb3,umask=0x1\000\00001\000Vertical IV Ring in Use : Up : Counts the number of cycles that the Vertical IV ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.  There is only 1 IV ring.  Therefore, if one wants to monitor the Even ring, they should select both UP_EVEN and DN_EVEN.  To monitor the Odd ring, they should select both UP_ODD and DN_ODD\000 */
{ 4877327 }, /* unc_m2p_vert_ring_tgc_in_use.dn_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x4\000\00001\000Vertical TGC Ring In Use : Down and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4878251 }, /* unc_m2p_vert_ring_tgc_in_use.dn_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Down and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x8\000\00001\000Vertical TGC Ring In Use : Down and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4879172 }, /* unc_m2p_vert_ring_tgc_in_use.up_even\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Even. Unit: uncore_m2pcie \000event=0xb5,umask=0x1\000\00001\000Vertical TGC Ring In Use : Up and Even : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 4880092 }, /* unc_m2p_vert_ring_tgc_in_use.up_odd\000uncore_m2pcie\000uncore io\000Vertical TGC Ring In Use : Up and Odd. Unit: uncore_m2pcie \000event=0xb5,umask=0x2\000\00001\000Vertical TGC Ring In Use : Up and Odd : Counts the number of cycles that the Vertical TGC ring is being used at this ring stop.  This includes when packets are passing by and when packets are being sunk, but does not include when packets are being sent from the ring stop.We really have two rings in JKT -- a clockwise ring and a counter-clockwise ring.  On the left side of the ring, the UP direction is on the clockwise ring and DN is on the counter-clockwise ring.  On the right side of the ring, this is reversed.  The first half of the CBos are on the left side of the ring, and the 2nd half are on the right side of the ring.  In other words (for example), in a 4c part, Cbo 0 UP AD is NOT the same ring as CBo 2 UP AD because they are on opposite sides of the ring\000 */
{ 1210794 }, /* llc_misses.mem_read\000uncore_imc\000uncore memory\000read requests to memory controller. Derived from unc_m_cas_count.rd. Unit: uncore_imc \000event=0x4,umask=0xf\000\0000164Bytes\000Counts the total number of DRAM Read CAS commands, w/ and w/o auto-pre, issued on this channel.  This includes underfills\000 */
{ 1211079 }, /* llc_misses.mem_write\000uncore_imc\000uncore memory\000write requests to memory controller. Derived from unc_m_cas_count.wr. Unit: uncore_imc \000event=0x4,umask=0x30\000\0000164Bytes\000Counts the total number of DRAM Write CAS commands issued, w/ and w/o auto-pre, on this channel\000 */
{ 5374991 }, /* unc_m_act_count.all\000uncore_imc\000uncore memory\000DRAM Activate Count : All Activates. Unit: uncore_imc \000event=0x1,umask=0xb\000\00001\000DRAM Activate Count : All Activates : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5375460 }, /* unc_m_act_count.byp\000uncore_imc\000uncore memory\000DRAM Activate Count : Activate due to Bypass. Unit: uncore_imc \000event=0x1,umask=0x8\000\00001\000DRAM Activate Count : Activate due to Bypass : Counts the number of DRAM Activate commands sent on this channel.  Activate commands are issued to open up a page on the DRAM devices so that it can be read or written to with a CAS.  One can calculate the number of Page Misses by subtracting the number of Page Miss precharges from the number of Activates\000 */
{ 5379676 }, /* unc_m_cas_count.all\000uncore_imc\000uncore memory\000All DRAM CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x3f\000\00001\000Counts the total number of DRAM CAS commands issued on this channel\000 */
{ 5381681 }, /* unc_m_cas_count.rd\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (including underfills). Unit: uncore_imc \000event=0x4,umask=0xf\000\00001\000Counts the total number of DRAM Read CAS commands, w/ and w/o auto-pre, issued on this channel.  This includes underfills\000 */
{ 5382954 }, /* unc_m_cas_count.rd_pre_reg\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre. Unit: uncore_imc \000event=0x4,umask=0x2\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS commands w/auto-pre : DRAM RD_CAS and WR_CAS Commands : Counts the total number or DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with explicit Precharge.  AutoPre is only used in systems that are using closed page policy.  We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5383751 }, /* unc_m_cas_count.rd_pre_underfill\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. Unit: uncore_imc \000event=0x4,umask=0x8\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5384755 }, /* unc_m_cas_count.rd_reg\000uncore_imc\000uncore memory\000All DRAM read CAS commands issued (does not include underfills). Unit: uncore_imc \000event=0x4,umask=0x1\000\00001\000Counts the total number of DRAM Read CAS commands issued on this channel.  This includes both regular RD CAS commands as well as those with implicit Precharge.   We do not filter based on major mode, as RD_CAS is not issued during WMM (with the exception of underfills)\000 */
{ 5388088 }, /* unc_m_cas_count.rd_underfill\000uncore_imc\000uncore memory\000DRAM underfill read CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x4\000\00001\000Counts the total of DRAM Read CAS commands issued due to an underfill\000 */
{ 5389276 }, /* unc_m_cas_count.wr\000uncore_imc\000uncore memory\000All DRAM write CAS commands issued. Unit: uncore_imc \000event=0x4,umask=0x30\000\00001\000Counts the total number of DRAM Write CAS commands issued, w/ and w/o auto-pre, on this channel\000 */
{ 5390418 }, /* unc_m_cas_count.wr_nonpre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre. Unit: uncore_imc \000event=0x4,umask=0x10\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/o auto-pre : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5390952 }, /* unc_m_cas_count.wr_pre\000uncore_imc\000uncore memory\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre. Unit: uncore_imc \000event=0x4,umask=0x20\000\00001\000DRAM RD_CAS and WR_CAS Commands. : DRAM WR_CAS commands w/ auto-pre : DRAM RD_CAS and WR_CAS Commands\000 */
{ 5394824 }, /* unc_m_clockticks\000uncore_imc\000uncore memory\000Memory controller clock ticks. Unit: uncore_imc \000event=0\000\00001\000Clockticks of the integrated memory controller (IMC)\000 */
{ 5395549 }, /* unc_m_clockticks_freerun\000uncore_imc_free_running\000uncore memory\000Free running counter that increments for the Memory Controller. Unit: uncore_imc_free_running \000event=0xff,umask=0x10\000\00001\000\000 */
{ 5397214 }, /* unc_m_dram_pre_all\000uncore_imc\000uncore memory\000DRAM Precharge All Commands. Unit: uncore_imc \000event=0x44\000\00001\000DRAM Precharge All Commands : Counts the number of times that the precharge all command was sent\000 */
{ 5397589 }, /* unc_m_dram_refresh.high\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x4\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5397948 }, /* unc_m_dram_refresh.opportunistic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x1\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5398154 }, /* unc_m_dram_refresh.panic\000uncore_imc\000uncore memory\000Number of DRAM Refreshes Issued. Unit: uncore_imc \000event=0x45,umask=0x2\000\00001\000Number of DRAM Refreshes Issued : Counts the number of refreshes issued\000 */
{ 5399174 }, /* unc_m_hclockticks\000uncore_imc\000uncore memory\000Half clockticks for IMC. Unit: uncore_imc \000event=0xff\000\00001\000\000 */
{ 5403217 }, /* unc_m_parity_errors\000uncore_imc\000uncore memory\000UNC_M_PARITY_ERRORS. Unit: uncore_imc \000event=0x2c\000\00001\000\000 */
{ 5403317 }, /* unc_m_pcls.rd\000uncore_imc\000uncore memory\000UNC_M_PCLS.RD. Unit: uncore_imc \000event=0xa0,umask=0x1\000\00001\000\000 */
{ 5403513 }, /* unc_m_pcls.total\000uncore_imc\000uncore memory\000UNC_M_PCLS.TOTAL. Unit: uncore_imc \000event=0xa0,umask=0x4\000\00001\000\000 */
{ 5403721 }, /* unc_m_pcls.wr\000uncore_imc\000uncore memory\000UNC_M_PCLS.WR. Unit: uncore_imc \000event=0xa0,umask=0x2\000\00001\000\000 */
{ 5418105 }, /* unc_m_power_channel_ppd\000uncore_imc\000uncore memory\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000event=0x85\000\00001\000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000 */
{ 5418958 }, /* unc_m_power_cke_cycles.low_0\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x1\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5419790 }, /* unc_m_power_cke_cycles.low_1\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x2\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5420622 }, /* unc_m_power_cke_cycles.low_2\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x4\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5421454 }, /* unc_m_power_cke_cycles.low_3\000uncore_imc\000uncore memory\000CKE_ON_CYCLES by Rank : DIMM ID. Unit: uncore_imc \000event=0x47,umask=0x8\000\00001\000CKE_ON_CYCLES by Rank : DIMM ID : Number of cycles spent in CKE ON mode.  The filter allows you to select a rank to monitor.  If multiple ranks are in CKE ON mode at one time, the counter will ONLY increment by one rather than doing accumulation.  Multiple counters will need to be used to track multiple ranks simultaneously.  There is no distinction between the different CKE modes (APD, PPDS, PPDF).  This can be determined based on the system programming.  These events should commonly be used with Invert to get the number of cycles in power saving mode.  Edge Detect is also useful here.  Make sure that you do NOT use Invert with Edge Detect (this just confuses the system and is not necessary)\000 */
{ 5428666 }, /* unc_m_power_crit_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5429254 }, /* unc_m_power_crit_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x86,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5431394 }, /* unc_m_power_self_refresh\000uncore_imc\000uncore memory\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000event=0x43\000\00001\000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000 */
{ 5436769 }, /* unc_m_power_throttle_cycles.slot0\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x1\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1. : Thermal throttling is performed per DIMM.  We support 3 DIMMs per channel.  This ID allows us to filter by ID\000 */
{ 5437352 }, /* unc_m_power_throttle_cycles.slot1\000uncore_imc\000uncore memory\000Throttle Cycles for Rank 0. Unit: uncore_imc \000event=0x46,umask=0x2\000\00001\000Throttle Cycles for Rank 0 : Counts the number of cycles while the iMC is being throttled by either thermal constraints or by the PCU throttling.  It is not possible to distinguish between the two.  This can be filtered by rank.  If multiple ranks are selected and are being throttled at the same time, the counter will only increment by 1\000 */
{ 5437822 }, /* unc_m_pre_count.all\000uncore_imc\000uncore memory\000DRAM Precharge commands. Unit: uncore_imc \000event=0x2,umask=0x1c\000\00001\000DRAM Precharge commands. : Counts the number of DRAM Precharge commands sent on this channel\000 */
{ 5440584 }, /* unc_m_pre_count.page_miss\000uncore_imc\000uncore memory\000Pre-charges due to page misses. Unit: uncore_imc \000event=0x2,umask=0xc\000\00001\000DRAM Precharge commands. : Precharge due to page miss : Counts the number of DRAM Precharge commands sent on this channel. : Pages Misses are due to precharges from bank scheduler (rd/wr requests)\000 */
{ 5440906 }, /* unc_m_pre_count.pgt\000uncore_imc\000uncore memory\000DRAM Precharge commands. : Precharge due to page table. Unit: uncore_imc \000event=0x2,umask=0x10\000\00001\000DRAM Precharge commands. : Precharge due to page table : Counts the number of DRAM Precharge commands sent on this channel. : Precharges from Page Table\000 */
{ 5442688 }, /* unc_m_pre_count.rd\000uncore_imc\000uncore memory\000Pre-charge for reads. Unit: uncore_imc \000event=0x2,umask=0x4\000\00001\000DRAM Precharge commands. : Precharge due to read : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from read bank scheduler\000 */
{ 5444977 }, /* unc_m_pre_count.wr\000uncore_imc\000uncore memory\000Pre-charge for writes. Unit: uncore_imc \000event=0x2,umask=0x8\000\00001\000DRAM Precharge commands. : Precharge due to write : Counts the number of DRAM Precharge commands sent on this channel. : Precharge from write bank scheduler\000 */
{ 5501292 }, /* unc_m_rdb_full\000uncore_imc\000uncore memory\000Read Data Buffer Full. Unit: uncore_imc \000event=0x19\000\00001\000\000 */
{ 5501821 }, /* unc_m_rdb_inserts\000uncore_imc\000uncore memory\000Read Data Buffer Inserts. Unit: uncore_imc \000event=0x17\000\00001\000\000 */
{ 5502577 }, /* unc_m_rdb_not_empty\000uncore_imc\000uncore memory\000Read Data Buffer Not Empty. Unit: uncore_imc \000event=0x18\000\00001\000\000 */
{ 5502851 }, /* unc_m_rdb_occupancy\000uncore_imc\000uncore memory\000Read Data Buffer Occupancy. Unit: uncore_imc \000event=0x1a\000\00001\000\000 */
{ 5503589 }, /* unc_m_rpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x12\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5504258 }, /* unc_m_rpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Full Cycles. Unit: uncore_imc \000event=0x15\000\00001\000Read Pending Queue Full Cycles : Counts the number of cycles when the Read Pending Queue is full.  When the RPQ is full, the HA will not be able to issue any additional read requests into the iMC.  This count should be similar count in the HA which tracks the number of cycles that the HA has no RPQ credits, just somewhat smaller to account for the credit return overhead.  We generally do not expect to see RPQ become full except for potentially during Write Major Mode or while running with slow DRAM.  This event only tracks non-ISOC queue entries\000 */
{ 5504927 }, /* unc_m_rpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x1\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5505763 }, /* unc_m_rpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Not Empty. Unit: uncore_imc \000event=0x11,umask=0x2\000\00001\000Read Pending Queue Not Empty : Counts the number of cycles that the Read Pending Queue is not empty.  This can then be used to calculate the average occupancy (in conjunction with the Read Pending Queue Occupancy count).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This filter is to be used in conjunction with the occupancy filter so that one can correctly track the average occupancies for schedulable entries and scheduled requests\000 */
{ 5507389 }, /* unc_m_rpq_inserts.pch0\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x1\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5507980 }, /* unc_m_rpq_inserts.pch1\000uncore_imc\000uncore memory\000Read Pending Queue Allocations. Unit: uncore_imc \000event=0x10,umask=0x2\000\00001\000Read Pending Queue Allocations : Counts the number of allocations into the Read Pending Queue.  This queue is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after the CAS command has been issued to memory.  This includes both ISOCH and non-ISOCH requests\000 */
{ 5511146 }, /* unc_m_rpq_occupancy_pch0\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x80\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5511864 }, /* unc_m_rpq_occupancy_pch1\000uncore_imc\000uncore memory\000Read Pending Queue Occupancy. Unit: uncore_imc \000event=0x81\000\00001\000Read Pending Queue Occupancy : Accumulates the occupancies of the Read Pending Queue each cycle.  This can then be used to calculate both the average occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The RPQ is used to schedule reads out to the memory controller and to track the requests.  Requests allocate into the RPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC. They deallocate after the CAS command has been issued to memory\000 */
{ 5535905 }, /* unc_m_wpq_cycles_full_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x22\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5536401 }, /* unc_m_wpq_cycles_full_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Full Cycles. Unit: uncore_imc \000event=0x16\000\00001\000Write Pending Queue Full Cycles : Counts the number of cycles when the Write Pending Queue is full.  When the WPQ is full, the HA will not be able to issue any additional write requests into the iMC.  This count should be similar count in the CHA which tracks the number of cycles that the CHA has no WPQ credits, just somewhat smaller to account for the credit return overhead\000 */
{ 5536897 }, /* unc_m_wpq_cycles_ne.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x1\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5537871 }, /* unc_m_wpq_cycles_ne.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Not Empty. Unit: uncore_imc \000event=0x21,umask=0x2\000\00001\000Write Pending Queue Not Empty : Counts the number of cycles that the Write Pending Queue is not empty.  This can then be used to calculate the average queue occupancy (in conjunction with the WPQ Occupancy Accumulation count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies\000 */
{ 5541626 }, /* unc_m_wpq_inserts.pch0\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x1\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5542390 }, /* unc_m_wpq_inserts.pch1\000uncore_imc\000uncore memory\000Write Pending Queue Allocations. Unit: uncore_imc \000event=0x20,umask=0x2\000\00001\000Write Pending Queue Allocations : Counts the number of allocations into the Write Pending Queue.  This can then be used to calculate the average queuing latency (in conjunction with the WPQ occupancy count).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the CHA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC\000 */
{ 5548167 }, /* unc_m_wpq_occupancy_pch0\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x82\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5549641 }, /* unc_m_wpq_occupancy_pch1\000uncore_imc\000uncore memory\000Write Pending Queue Occupancy. Unit: uncore_imc \000event=0x83\000\00001\000Write Pending Queue Occupancy : Accumulates the occupancies of the Write Pending Queue each cycle.  This can then be used to calculate both the average queue occupancy (in conjunction with the number of cycles not empty) and the average latency (in conjunction with the number of allocations).  The WPQ is used to schedule write out to the memory controller and to track the writes.  Requests allocate into the WPQ soon after they enter the memory controller, and need credits for an entry in this buffer before being sent from the HA to the iMC.  They deallocate after being issued to DRAM.  Write requests themselves are able to complete (from the perspective of the rest of the system) as soon they have posted to the iMC.  This is not to be confused with actually performing the write to DRAM.  Therefore, the average latency for this queue is actually not useful for deconstruction intermediate write latencies.  So, we provide filtering based on if the request has posted or not.  By using the not posted filter, we can track how long writes spent in the iMC before completions were sent to the HA.  The posted filter, on the other hand, provides information about how much queueing is actually happening in the iMC for writes before they are actually issued to memory.  High average occupancies will generally coincide with high write major mode counts\000 */
{ 5551115 }, /* unc_m_wpq_read_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5551801 }, /* unc_m_wpq_read_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x23,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5553803 }, /* unc_m_wpq_write_hit.pch0\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x1\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5554490 }, /* unc_m_wpq_write_hit.pch1\000uncore_imc\000uncore memory\000Write Pending Queue CAM Match. Unit: uncore_imc \000event=0x24,umask=0x2\000\00001\000Write Pending Queue CAM Match : Counts the number of times a request hits in the WPQ (write-pending queue).  The iMC allows writes and reads to pass up other writes to different addresses.  Before a read or a write is issued, it will first CAM the WPQ to see if there is a write pending to that address.  When reads hit, they are able to directly pull their data from the WPQ instead of going to memory.  Writes that hit will overwrite the existing data.  Partial writes that hit will not need to do underfill reads and will simply update their relevant sections\000 */
{ 5641437 }, /* unc_p_clockticks\000uncore_pcu\000uncore power\000Clockticks of the power control unit (PCU). Unit: uncore_pcu \000event=0\000\00001\000\000 */
{ 5650924 }, /* unc_p_core_transition_cycles\000uncore_pcu\000uncore power\000UNC_P_CORE_TRANSITION_CYCLES. Unit: uncore_pcu \000event=0x60\000\00001\000\000 */
{ 5656346 }, /* unc_p_demotions\000uncore_pcu\000uncore power\000UNC_P_DEMOTIONS. Unit: uncore_pcu \000event=0x30\000\00001\000\000 */
{ 5663972 }, /* unc_p_fivr_ps_ps0_cycles\000uncore_pcu\000uncore power\000Phase Shed 0 Cycles. Unit: uncore_pcu \000event=0x75\000\00001\000Phase Shed 0 Cycles : Cycles spent in phase-shedding power state 0\000 */
{ 5664290 }, /* unc_p_fivr_ps_ps1_cycles\000uncore_pcu\000uncore power\000Phase Shed 1 Cycles. Unit: uncore_pcu \000event=0x76\000\00001\000Phase Shed 1 Cycles : Cycles spent in phase-shedding power state 1\000 */
{ 5664608 }, /* unc_p_fivr_ps_ps2_cycles\000uncore_pcu\000uncore power\000Phase Shed 2 Cycles. Unit: uncore_pcu \000event=0x77\000\00001\000Phase Shed 2 Cycles : Cycles spent in phase-shedding power state 2\000 */
{ 5664926 }, /* unc_p_fivr_ps_ps3_cycles\000uncore_pcu\000uncore power\000Phase Shed 3 Cycles. Unit: uncore_pcu \000event=0x78\000\00001\000Phase Shed 3 Cycles : Cycles spent in phase-shedding power state 3\000 */
{ 5667556 }, /* unc_p_freq_clip_avx256\000uncore_pcu\000uncore power\000AVX256 Frequency Clipping. Unit: uncore_pcu \000event=0x49\000\00001\000\000 */
{ 5667664 }, /* unc_p_freq_clip_avx512\000uncore_pcu\000uncore power\000AVX512 Frequency Clipping. Unit: uncore_pcu \000event=0x4a\000\00001\000\000 */
{ 5668479 }, /* unc_p_freq_max_limit_thermal_cycles\000uncore_pcu\000uncore power\000Thermal Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x4\000\00001\000Thermal Strongest Upper Limit Cycles : Number of cycles any frequency is reduced due to a thermal limit.  Count only if throttling is occurring\000 */
{ 5669130 }, /* unc_p_freq_max_power_cycles\000uncore_pcu\000uncore power\000Power Strongest Upper Limit Cycles. Unit: uncore_pcu \000event=0x5\000\00001\000Power Strongest Upper Limit Cycles : Counts the number of cycles when power is the upper limit on frequency\000 */
{ 5670854 }, /* unc_p_freq_min_io_p_cycles\000uncore_pcu\000uncore power\000IO P Limit Strongest Lower Limit Cycles. Unit: uncore_pcu \000event=0x73\000\00001\000IO P Limit Strongest Lower Limit Cycles : Counts the number of cycles when IO P Limit is preventing us from dropping the frequency lower.  This algorithm monitors the needs to the IO subsystem on both local and remote sockets and will maintain a frequency high enough to maintain good IO BW.  This is necessary for when all the IA cores on a socket are idle but a user still would like to maintain high IO Bandwidth\000 */
{ 5673412 }, /* unc_p_freq_trans_cycles\000uncore_pcu\000uncore power\000Cycles spent changing Frequency. Unit: uncore_pcu \000event=0x74\000\00001\000Cycles spent changing Frequency : Counts the number of cycles when the system is changing frequency.  This can not be filtered by thread ID.  One can also use it with the occupancy counter that monitors number of threads in C0 to estimate the performance impact that frequency transitions had on the system\000 */
{ 5674248 }, /* unc_p_memory_phase_shedding_cycles\000uncore_pcu\000uncore power\000Memory Phase Shedding Cycles. Unit: uncore_pcu \000event=0x2f\000\00001\000Memory Phase Shedding Cycles : Counts the number of cycles that the PCU has triggered memory phase shedding.  This is a mode that can be run in the iMC physicals that saves power at the expense of additional latency\000 */
{ 5676034 }, /* unc_p_pkg_residency_c0_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C0. Unit: uncore_pcu \000event=0x2a\000\00001\000Package C State Residency - C0 : Counts the number of cycles when the package was in C0.  This event can be used in conjunction with edge detect to count C0 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677059 }, /* unc_p_pkg_residency_c2e_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C2E. Unit: uncore_pcu \000event=0x2b\000\00001\000Package C State Residency - C2E : Counts the number of cycles when the package was in C2E.  This event can be used in conjunction with edge detect to count C2E entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5677753 }, /* unc_p_pkg_residency_c3_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C3. Unit: uncore_pcu \000event=0x2c\000\00001\000Package C State Residency - C3 : Counts the number of cycles when the package was in C3.  This event can be used in conjunction with edge detect to count C3 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5678442 }, /* unc_p_pkg_residency_c6_cycles\000uncore_pcu\000uncore power\000Package C State Residency - C6. Unit: uncore_pcu \000event=0x2d\000\00001\000Package C State Residency - C6 : Counts the number of cycles when the package was in C6.  This event can be used in conjunction with edge detect to count C6 entrances (or exits using invert).  Residency events do not include transition times\000 */
{ 5679127 }, /* unc_p_pmax_throttled_cycles\000uncore_pcu\000uncore power\000UNC_P_PMAX_THROTTLED_CYCLES. Unit: uncore_pcu \000event=0x6\000\00001\000\000 */
{ 5679355 }, /* unc_p_power_state_occupancy.cores_c0\000uncore_pcu\000uncore power\000Number of cores in C-State : C0 and C1. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C0 and C1 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5680610 }, /* unc_p_power_state_occupancy.cores_c3\000uncore_pcu\000uncore power\000Number of cores in C-State : C3. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C3 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5681844 }, /* unc_p_power_state_occupancy.cores_c6\000uncore_pcu\000uncore power\000Number of cores in C-State : C6 and C7. Unit: uncore_pcu \000event=0x80\000\00001\000Number of cores in C-State : C6 and C7 : This is an occupancy event that tracks the number of cores that are in the chosen C-State.  It can be used by itself to get the average number of cores in that C-state with thresholding to generate histograms, or with other PCU events and occupancy triggering to capture other details\000 */
{ 5684699 }, /* unc_p_prochot_external_cycles\000uncore_pcu\000uncore power\000External Prochot. Unit: uncore_pcu \000event=0xa\000\00001\000External Prochot : Counts the number of cycles that we are in external PROCHOT mode.  This mode is triggered when a sensor off the die determines that something off-die (like DRAM) is too hot and must throttle to avoid damaging the chip\000 */
{ 5685335 }, /* unc_p_prochot_internal_cycles\000uncore_pcu\000uncore power\000Internal Prochot. Unit: uncore_pcu \000event=0x9\000\00001\000Internal Prochot : Counts the number of cycles that we are in Internal PROCHOT mode.  This mode is triggered when a sensor on the die determines that we are too hot and must throttle to avoid damaging the chip\000 */
{ 5686051 }, /* unc_p_total_transition_cycles\000uncore_pcu\000uncore power\000Total Core C State Transition Cycles. Unit: uncore_pcu \000event=0x72\000\00001\000Total Core C State Transition Cycles : Number of cycles spent performing core C state transitions across all cores\000 */
{ 5688171 }, /* unc_p_vr_hot_cycles\000uncore_pcu\000uncore power\000VR Hot. Unit: uncore_pcu \000event=0x42\000\00001\000VR Hot : Number of cycles that a CPU SVID VR is hot.  Does not cover DRAM VRs\000 */
{ 788975 }, /* dtlb_load_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to loads that miss the PDE (Page Directory Entry) cache\000event=0x8,period=200003,umask=0x80\000\00000\000\000 */
{ 789543 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to a demand load that did not start a page walk. Account for all page sizes. Will result in a DTLB write from STLB\000event=0x8,period=200003,umask=0x20\000\00000\000\000 */
{ 794124 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to any page size\000event=0x8,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size. Includes page walks that page fault\000 */
{ 797270 }, /* dtlb_load_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 1G page\000event=0x8,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1GB pages. Includes page walks that page fault\000 */
{ 799932 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 2M or 4M page\000event=0x8,period=200003,umask=0x4\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages. Includes page walks that page fault\000 */
{ 803279 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to load DTLB misses to a 4K page\000event=0x8,period=200003,umask=0x2\000\00000\000Counts the number of page walks completed due to loads (including SW prefetches) whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages. Includes page walks that page fault\000 */
{ 807481 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle\000event=0x8,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for demand loads every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 811352 }, /* dtlb_store_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to stores that miss the PDE (Page Directory Entry) cache\000event=0x49,period=2000003,umask=0x80\000\00000\000\000 */
{ 811787 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to stores that did not start a page walk. Account for all pages sizes. Will result in a DTLB write from STLB\000event=0x49,period=2000003,umask=0x20\000\00000\000\000 */
{ 816529 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to any page size\000event=0x49,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 819410 }, /* dtlb_store_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 1G page\000event=0x49,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000 */
{ 822046 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 2M or 4M page\000event=0x49,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000 */
{ 825196 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to store DTLB misses to a 4K page\000event=0x49,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to stores whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000 */
{ 829372 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle\000event=0x49,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for stores every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk). Includes EPT-walk intervals\000 */
{ 831616 }, /* ept.epde_hit\000\000virtual memory\000Counts the number of Extended Page Directory Entry hits\000event=0x4f,period=2000003,umask=0x1\000\00000\000Counts the number of Extended Page Directory Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 831940 }, /* ept.epde_miss\000\000virtual memory\000Counts the number of Extended Page Directory Entry misses\000event=0x4f,period=2000003,umask=0x2\000\00000\000Counts the number Extended Page Directory Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 832266 }, /* ept.epdpe_hit\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry hits\000event=0x4f,period=2000003,umask=0x4\000\00000\000Counts the number Extended Page Directory Pointer Entry hits.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 832604 }, /* ept.epdpe_miss\000\000virtual memory\000Counts the number of Extended Page Directory Pointer Entry misses\000event=0x4f,period=2000003,umask=0x8\000\00000\000Counts the number Extended Page Directory Pointer Entry misses.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 834140 }, /* ept.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle\000event=0x4f,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an Extended Page table walk including GTLB hits per cycle.  The Extended Page Directory cache is used by Virtual Machine operating systems while the guest operating systems use the standard TLB caches\000 */
{ 1077182 }, /* itlb.fills\000\000virtual memory\000Counts the number of times there was an ITLB miss and a new translation was filled into the ITLB\000event=0x81,period=200003,umask=0x4\000\00000\000Counts the number of times the machine was unable to find a translation in the Instruction Translation Lookaside Buffer (ITLB) and a new translation was filled into the ITLB. The event is speculative in nature, but will not count translations (page walks) that are begun and not finished, or translations that are finished but not filled into the ITLB\000 */
{ 1081713 }, /* itlb_misses.pde_cache_miss\000\000virtual memory\000Counts the number of page walks due to an instruction fetch that miss the PDE (Page Directory Entry) cache\000event=0x85,period=2000003,umask=0x80\000\00000\000\000 */
{ 1082122 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Counts the number of first level TLB misses but second level hits due to an instruction fetch that did not start a page walk. Account for all pages sizes. Will result in an ITLB write from STLB\000event=0x85,period=2000003,umask=0x20\000\00000\000\000 */
{ 1086987 }, /* itlb_misses.walk_completed\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to any page size\000event=0x85,period=200003,umask=0xe\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to any page size.  Includes page walks that page fault\000 */
{ 1089323 }, /* itlb_misses.walk_completed_1g\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 1G page\000event=0x85,period=200003,umask=0x8\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 1G pages.  Includes page walks that page fault\000 */
{ 1091825 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 2M or 4M page\000event=0x85,period=2000003,umask=0x4\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 2M or 4M pages.  Includes page walks that page fault\000 */
{ 1094631 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Counts the number of page walks completed due to instruction fetch misses to a 4K page\000event=0x85,period=2000003,umask=0x2\000\00000\000Counts the number of page walks completed due to instruction fetches whose address translations missed in all Translation Lookaside Buffer (TLB) levels and were mapped to 4K pages.  Includes page walks that page fault\000 */
{ 1097075 }, /* itlb_misses.walk_pending\000\000virtual memory\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle\000event=0x85,period=200003,umask=0x10\000\00000\000Counts the number of page walks outstanding in the page miss handler (PMH) for instruction fetches every cycle.  A page walk is outstanding from start till PMH becomes idle again (ready to serve next walk)\000 */
{ 1193599 }, /* ld_blocks.dtlb_miss\000\000virtual memory\000Counts the number of retired loads that are blocked due to a first level TLB miss (Precise event)\000event=0x3,period=1000003,umask=0x8\000\00000\000\000 */
{ 1393706 }, /* mem_uops_retired.dtlb_miss\000\000virtual memory\000Counts the number of memory uops retired that missed in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x13\000\00000\000\000 */
{ 1394557 }, /* mem_uops_retired.dtlb_miss_loads\000\000virtual memory\000Counts the number of load uops retired that miss in the second Level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x11\000\00000\000\000 */
{ 1395271 }, /* mem_uops_retired.dtlb_miss_stores\000\000virtual memory\000Counts the number of store uops retired that miss in the second level TLB  Supports address when precise (Precise event)\000event=0xd0,period=200003,umask=0x12\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_metrics__snowridgex[] = {
{ 6171955 }, /* uncore_iio\000LLC_MISSES.PCIE_READ\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_READ.PART3\000\000PCI Express bandwidth reading at IIO. Derived from unc_iio_data_req_of_cpu.mem_read.part0. Unit: uncore_iio \000Data requested of the CPU : Card reading from DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\0004Bytes\000\000\000\00000 */
{ 6173345 }, /* uncore_iio\000LLC_MISSES.PCIE_WRITE\000\000UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART0 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART1 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART2 + UNC_IIO_DATA_REQ_OF_CPU.MEM_WRITE.PART3\000\000PCI Express bandwidth writing at IIO. Derived from unc_iio_data_req_of_cpu.mem_write.part0. Unit: uncore_iio \000Data requested of the CPU : Card writing to DRAM : Number of DWs (4 bytes) the card requests of the main die.    Includes all requests initiated by the Card, including reads and writes. : x16 card plugged in to Lane 0/1/2/3, Or x8 card plugged in to Lane 0/1, Or x4 card is plugged in to slot 0\0004Bytes\000\000\000\00000 */
{ 6175012 }, /* uncore_imc\000power_channel_ppd\000\000UNC_M_POWER_CHANNEL_PPD / UNC_M_CLOCKTICKS * 100\000\000Cycles where DRAM ranks are in power down (CKE) mode. Unit: uncore_imc \000Channel PPD Cycles : Number of cycles when all the ranks in the channel are in PPD mode.  If IBT=off is enabled, then this can be used to count those cycles.  If it is not enabled, then this can count the number of cycles when that could have been taken advantage of\000\000\000\000\00000 */
{ 6175909 }, /* uncore_imc\000power_self_refresh\000\000UNC_M_POWER_SELF_REFRESH / UNC_M_CLOCKTICKS * 100\000\000Cycles Memory is in self refresh power mode. Unit: uncore_imc \000Clock-Enabled Self-Refresh : Counts the number of cycles when the iMC is in self-refresh and the iMC still has a clock.  This happens in some package C-states.  For example, the PCU may ask the iMC to enter self-refresh even though some of the cores are still processing.  One use of this is for Monroe technology.  Self-refresh is required during package C3 and C6, but there is no clock in the iMC at this time, so it is not possible to count these cases\000\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__tigerlake[] = {
{ 1100860 }, /* l1d.replacement\000\000cache\000Counts the number of cache lines replaced in L1 data cache\000event=0x51,period=100003,umask=0x1\000\00000\000Counts L1D data line replacements including opportunistic replacements, and replacements that require stall-for-replace or block-for-replace\000 */
{ 1105377 }, /* l1d_pend_miss.fb_full\000\000cache\000Number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,period=1000003,umask=0x2\000\00000\000Counts number of cycles a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1106609 }, /* l1d_pend_miss.fb_full_periods\000\000cache\000Number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability\000event=0x48,cmask=1,edge=1,period=1000003,umask=0x2\000\00000\000Counts number of phases a demand request has waited due to L1D Fill Buffer (FB) unavailability. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1107376 }, /* l1d_pend_miss.l2_stall\000\000cache\000Number of cycles a demand request has waited due to L1D due to lack of L2 resources\000event=0x48,period=1000003,umask=0x4\000\00000\000Counts number of cycles a demand request has waited due to L1D due to lack of L2 resources. Demand requests include cacheable/uncacheable demand load, store, lock or SW prefetch accesses\000 */
{ 1110782 }, /* l1d_pend_miss.pending\000\000cache\000Number of L1D misses that are outstanding\000event=0x48,period=1000003,umask=0x1\000\00000\000Counts number of L1D misses that are outstanding in each cycle, that is each cycle the number of Fill Buffers (FB) outstanding required by Demand Reads. FB either is held by demand loads, or it is held by non-demand loads and gets hit at least once by demand. The valid outstanding interval is defined until the FB deallocation by one of the following ways: from FB allocation, if FB is allocated by demand from the demand Hit FB, if it is allocated by hardware or software prefetch. Note: In the L1D, a Demand Read contains cacheable or noncacheable demand loads, including ones causing cache-line splits and reads due to page walks resulted from any request type\000 */
{ 1112359 }, /* l1d_pend_miss.pending_cycles\000\000cache\000Cycles with L1D load Misses outstanding\000event=0x48,cmask=1,period=1000003,umask=0x1\000\00000\000Counts duration of L1D miss outstanding in cycles\000 */
{ 1128709 }, /* l2_lines_in.all\000\000cache\000L2 cache lines filling L2\000event=0xf1,period=100003,umask=0x1f\000\00000\000Counts the number of L2 cache lines filling the L2. Counting does not cover rejects\000 */
{ 1134424 }, /* l2_lines_out.non_silent\000\000cache\000Modified cache lines that are evicted by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x2\000\00000\000Counts the number of lines that are evicted by L2 cache when triggered by an L2 cache fill. Those lines are in Modified state. Modified lines are written back to L3\000 */
{ 1136984 }, /* l2_lines_out.silent\000\000cache\000Non-modified cache lines that are silently dropped by L2 cache when triggered by an L2 cache fill\000event=0xf2,period=200003,umask=0x1\000\00000\000Counts the number of lines that are silently dropped by L2 cache when triggered by an L2 cache fill. These lines are typically in Shared or Exclusive state. A non-threaded event\000 */
{ 1157315 }, /* l2_rqsts.all_code_rd\000\000cache\000L2 code requests\000event=0x24,period=200003,umask=0xe4\000\00000\000Counts the total number of L2 code requests\000 */
{ 1157738 }, /* l2_rqsts.all_demand_data_rd\000\000cache\000Demand Data Read access L2 cache\000event=0x24,period=200003,umask=0xe1\000\00000\000Counts Demand Data Read requests accessing the L2 cache. These requests may hit or miss L2 cache. True-miss exclude misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1162195 }, /* l2_rqsts.all_rfo\000\000cache\000RFO requests to L2 cache\000event=0x24,period=200003,umask=0xe2\000\00000\000Counts the total number of RFO (read for ownership) requests to L2 cache. L2 RFO requests include both L1D demand RFO misses as well as L1D RFO prefetches\000 */
{ 1163258 }, /* l2_rqsts.code_rd_hit\000\000cache\000L2 cache hits when fetching instructions, code reads\000event=0x24,period=200003,umask=0xc4\000\00000\000Counts L2 cache hits when fetching instructions, code reads\000 */
{ 1164220 }, /* l2_rqsts.code_rd_miss\000\000cache\000L2 cache misses when fetching instructions\000event=0x24,period=200003,umask=0x24\000\00000\000Counts L2 cache misses when fetching instructions\000 */
{ 1165401 }, /* l2_rqsts.demand_data_rd_hit\000\000cache\000Demand Data Read requests that hit L2 cache\000event=0x24,period=200003,umask=0xc1\000\00000\000Counts the number of demand Data Read requests initiated by load instructions that hit L2 cache\000 */
{ 1166073 }, /* l2_rqsts.demand_data_rd_miss\000\000cache\000Demand Data Read miss L2 cache\000event=0x24,period=200003,umask=0x21\000\00000\000Counts demand Data Read requests with true-miss in the L2 cache. True-miss excludes misses that were merged with ongoing L2 misses. An access is counted once\000 */
{ 1169888 }, /* l2_rqsts.miss\000\000cache\000Read requests with true-miss in L2 cache\000event=0x24,period=200003,umask=0x3f\000\00000\000Counts read requests of any type with true-miss in the L2 cache. True-miss excludes L2 misses that were merged with ongoing L2 misses\000 */
{ 1173117 }, /* l2_rqsts.references\000\000cache\000All accesses to L2 cache\000event=0x24,period=200003,umask=0xff\000\00000\000Counts all requests that were hit or true misses in L2 cache. True-miss excludes misses that were merged with ongoing L2 misses\000 */
{ 1174052 }, /* l2_rqsts.rfo_hit\000\000cache\000RFO requests that hit L2 cache\000event=0x24,period=200003,umask=0xc2\000\00000\000Counts the RFO (Read-for-Ownership) requests that hit L2 cache\000 */
{ 1174725 }, /* l2_rqsts.rfo_miss\000\000cache\000RFO requests that miss L2 cache\000event=0x24,period=200003,umask=0x22\000\00000\000Counts the RFO (Read-for-Ownership) requests that miss L2 cache\000 */
{ 1177137 }, /* l2_rqsts.swpf_hit\000\000cache\000SW prefetch requests that hit L2 cache\000event=0x24,period=200003,umask=0xc8\000\00000\000Counts Software prefetch requests that hit the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1177638 }, /* l2_rqsts.swpf_miss\000\000cache\000SW prefetch requests that miss L2 cache\000event=0x24,period=200003,umask=0x28\000\00000\000Counts Software prefetch requests that miss the L2 cache. Accounts for PREFETCHNTA and PREFETCHT0/1/2 instructions when FB is not full\000 */
{ 1182357 }, /* l2_trans.l2_wb\000\000cache\000L2 writebacks that access L2 cache\000event=0xf0,period=200003,umask=0x40\000\00000\000Counts L2 writebacks that access L2 cache\000 */
{ 1245649 }, /* lock_cycles.cache_lock_duration\000\000cache\000Cycles when L1D is locked\000event=0x63,period=2000003,umask=0x2\000\00000\000This event counts the number of cycles when the L1D is locked. It is a superset of the 0x1 mask (BUS_LOCK_CLOCKS.BUS_LOCK_DURATION)\000 */
{ 1248149 }, /* longest_lat_cache.miss\000\000cache\000Core-originated cacheable requests that missed L3  (Except hardware prefetches to the L3)\000event=0x2e,period=100003,umask=0x41\000\00000\000Counts core-originated cacheable requests that miss the L3 cache (Longest Latency cache). Requests include data and code reads, Reads-for-Ownership (RFOs), speculative accesses and hardware prefetches to the L1 and L2.  It does not include hardware prefetches to the L3, and may not count other types of requests to the L3\000 */
{ 1310313 }, /* mem_inst_retired.all_loads\000\000cache\000Retired load instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x81\000\00000\000Counts all retired load instructions. This event accounts for SW prefetch instructions of PREFETCHNTA or PREFETCHT0/1/2 or PREFETCHW  Supports address when precise (Precise event)\000 */
{ 1311322 }, /* mem_inst_retired.all_stores\000\000cache\000Retired store instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x82\000\00000\000Counts all retired store instructions  Supports address when precise (Precise event)\000 */
{ 1312052 }, /* mem_inst_retired.any\000\000cache\000All retired memory instructions  Supports address when precise (Precise event)\000event=0xd0,period=1000003,umask=0x83\000\00000\000Counts all retired memory instructions - loads and stores  Supports address when precise (Precise event)\000 */
{ 1315394 }, /* mem_inst_retired.lock_loads\000\000cache\000Retired load instructions with locked access  Supports address when precise (Precise event)\000event=0xd0,period=100007,umask=0x21\000\00000\000Counts retired load instructions with locked access  Supports address when precise (Precise event)\000 */
{ 1316119 }, /* mem_inst_retired.split_loads\000\000cache\000Retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x41\000\00000\000Counts retired load instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1316758 }, /* mem_inst_retired.split_stores\000\000cache\000Retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x42\000\00000\000Counts retired store instructions that split across a cacheline boundary  Supports address when precise (Precise event)\000 */
{ 1318042 }, /* mem_inst_retired.stlb_miss_loads\000\000cache\000Retired load instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x11\000\00000\000Number of retired load instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1318673 }, /* mem_inst_retired.stlb_miss_stores\000\000cache\000Retired store instructions that miss the STLB  Supports address when precise (Precise event)\000event=0xd0,period=100003,umask=0x12\000\00000\000Number of retired store instructions that (start a) miss in the 2nd-level TLB (STLB)  Supports address when precise (Precise event)\000 */
{ 1320337 }, /* mem_load_l3_hit_retired.xsnp_fwd\000\000cache\000Snoop hit a modified(HITM) or clean line(HIT_W_FWD) in another on-pkg core which forwarded the data back due to a retired load instruction  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x4\000\00000\000Counts retired load instructions where a cross-core snoop hit in another cores caches on this socket, the data was forwarded back to the requesting core as the data was modified (SNOOP_HITM) or the L3 did not have the data(SNOOP_HIT_WITH_FWD)  Supports address when precise (Precise event)\000 */
{ 1324093 }, /* mem_load_l3_hit_retired.xsnp_miss\000\000cache\000Retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x1\000\00000\000Counts the retired load instructions whose data sources were L3 hit and cross-core snoop missed in on-pkg core cache  Supports address when precise (Precise event)\000 */
{ 1325292 }, /* mem_load_l3_hit_retired.xsnp_no_fwd\000\000cache\000Snoop hit without forwarding in another on-pkg core due to a retired load instruction, data was supplied by the L3  Supports address when precise (Precise event)\000event=0xd2,period=20011,umask=0x2\000\00000\000Counts retired load instructions in which the L3 supplied the data and a cross-core snoop hit in another cores caches on this socket but that other core did not forward the data back (SNOOP_HIT_NO_FWD)  Supports address when precise (Precise event)\000 */
{ 1326535 }, /* mem_load_l3_hit_retired.xsnp_none\000\000cache\000Retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000event=0xd2,period=100003,umask=0x8\000\00000\000Counts retired load instructions whose data sources were hits in L3 without snoops required  Supports address when precise (Precise event)\000 */
{ 1330690 }, /* mem_load_misc_retired.uc\000\000cache\000Retired instructions with at least 1 uncacheable load or lock  Supports address when precise (Precise event)\000event=0xd4,period=100007,umask=0x4\000\00000\000Retired instructions with at least one load to uncacheable memory-type, or at least one cache-line split locked access  Supports address when precise (Precise event)\000 */
{ 1332237 }, /* mem_load_retired.fb_hit\000\000cache\000Number of completed demand load requests that missed the L1, but hit the FB(fill buffer), because a preceding miss to the same cacheline initiated the line to be brought into L1, but data is not yet ready in L1  Supports address when precise (Precise event)\000event=0xd1,period=100007,umask=0x40\000\00000\000Counts retired load instructions with at least one uop was load missed in L1 but hit FB (Fill Buffers) due to preceding miss to the same cache line with data not ready  Supports address when precise (Precise event)\000 */
{ 1333977 }, /* mem_load_retired.l1_hit\000\000cache\000Retired load instructions with L1 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=1000003,umask=0x1\000\00000\000Counts retired load instructions with at least one uop that hit in the L1 data cache. This event includes all SW prefetches and lock instructions regardless of the data source  Supports address when precise (Precise event)\000 */
{ 1335514 }, /* mem_load_retired.l1_miss\000\000cache\000Retired load instructions missed L1 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x8\000\00000\000Counts retired load instructions with at least one uop that missed in the L1 cache  Supports address when precise (Precise event)\000 */
{ 1336567 }, /* mem_load_retired.l2_hit\000\000cache\000Retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=200003,umask=0x2\000\00000\000Counts retired load instructions with L2 cache hits as data sources  Supports address when precise (Precise event)\000 */
{ 1337424 }, /* mem_load_retired.l2_miss\000\000cache\000Retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x10\000\00000\000Counts retired load instructions missed L2 cache as data sources  Supports address when precise (Precise event)\000 */
{ 1338416 }, /* mem_load_retired.l3_hit\000\000cache\000Retired load instructions with L3 cache hits as data sources  Supports address when precise (Precise event)\000event=0xd1,period=100021,umask=0x4\000\00000\000Counts retired load instructions with at least one uop that hit in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1339662 }, /* mem_load_retired.l3_miss\000\000cache\000Retired load instructions missed L3 cache as data sources  Supports address when precise (Precise event)\000event=0xd1,period=50021,umask=0x20\000\00000\000Counts retired load instructions with at least one uop that missed in the L3 cache  Supports address when precise (Precise event)\000 */
{ 1547696 }, /* ocr.demand_data_rd.l3_hit.snoop_hit_with_fwd\000\000cache\000OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x8003C0001\000\00000\000\000 */
{ 1548626 }, /* ocr.demand_data_rd.l3_hit.snoop_hitm\000\000cache\000Counts demand data reads that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0001\000\00000\000\000 */
{ 1577226 }, /* ocr.demand_rfo.l3_hit.snoop_hitm\000\000cache\000Counts demand reads for ownership (RFO) requests and software prefetches for exclusive ownership (PREFETCHW) that hit a cacheline in the L3 where a snoop hit in another cores caches, data forwarding is required as the data is modified\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10003C0002\000\00000\000\000 */
{ 1744883 }, /* offcore_requests.all_data_rd\000\000cache\000Demand and prefetch data reads\000event=0xb0,period=100003,umask=0x8\000\00000\000Counts the demand and prefetch data reads. All Core Data Reads include cacheable 'Demands' and L2 prefetchers (not L3 prefetchers). Counting also covers reads due to page walks resulted from any request type\000 */
{ 1745789 }, /* offcore_requests.all_requests\000\000cache\000Any memory transaction that reached the SQ\000event=0xb0,period=100003,umask=0x80\000\00000\000Counts memory transactions reached the super queue including requests initiated by the core, all L3 prefetches, page walks, etc.\000 */
{ 1750002 }, /* offcore_requests.demand_data_rd\000\000cache\000Demand Data Read requests sent to uncore\000event=0xb0,period=100003,umask=0x1\000\00000\000Counts the Demand Data Read requests sent to uncore. Use it in conjunction with OFFCORE_REQUESTS_OUTSTANDING to determine average latency in the uncore\000 */
{ 1751131 }, /* offcore_requests.demand_rfo\000\000cache\000Demand RFO requests including regular RFOs, locks, ItoM\000event=0xb0,period=100003,umask=0x4\000\00000\000Counts the demand RFO (read for ownership) requests including regular RFOs, locks, ItoM\000 */
{ 1755879 }, /* offcore_requests_outstanding.all_data_rd\000\000cache\000Offcore outstanding cacheable Core Data Read transactions in SuperQueue (SQ), queue to uncore\000event=0x60,period=1000003,umask=0x8\000\00000\000Counts the number of offcore outstanding cacheable Core Data Read transactions in the super queue every cycle. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1758782 }, /* offcore_requests_outstanding.cycles_with_data_rd\000\000cache\000Cycles when offcore outstanding cacheable Core Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=1000003,umask=0x8\000\00000\000Counts cycles when offcore outstanding cacheable Core Data Read transactions are present in the super queue. A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation). See corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1763371 }, /* offcore_requests_outstanding.cycles_with_demand_data_rd\000\000cache\000Cycles when offcore outstanding Demand Data Read transactions are present in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=2000003,umask=0x1\000\00000\000Counts cycles when offcore outstanding Demand Data Read transactions are present in the super queue (SQ). A transaction is considered to be in the Offcore outstanding state between L2 miss and transaction completion sent to requestor (SQ de-allocation)\000 */
{ 1765309 }, /* offcore_requests_outstanding.cycles_with_demand_rfo\000\000cache\000Cycles with offcore outstanding demand rfo reads transactions in SuperQueue (SQ), queue to uncore\000event=0x60,cmask=1,period=1000003,umask=0x4\000\00000\000Counts the number of offcore outstanding demand rfo Reads transactions in the super queue every cycle. The 'Offcore outstanding' state of the transaction lasts from the L2 miss until the sending transaction completion to requestor (SQ deallocation). See the corresponding Umask under OFFCORE_REQUESTS\000 */
{ 1771982 }, /* offcore_requests_outstanding.demand_data_rd\000\000cache\000Demand Data Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x1\000\00000\000Counts the number of off-core outstanding Demand Data Read transactions every cycle. A transaction is considered to be in the Off-core outstanding state between L2 cache miss and data-return to the core\000 */
{ 1776411 }, /* offcore_requests_outstanding.demand_data_rd_ge_6\000\000cache\000Cycles with at least 6 offcore outstanding Demand Data Read transactions in uncore queue\000event=0x60,cmask=6,period=2000003,umask=0x1\000\00000\000\000 */
{ 1778347 }, /* offcore_requests_outstanding.demand_rfo\000\000cache\000Store Read transactions pending for off-core. Highly correlated\000event=0x60,period=1000003,umask=0x4\000\00000\000Counts the number of off-core outstanding read-for-ownership (RFO) store transactions every cycle. An RFO transaction is considered to be in the Off-core outstanding state between L2 cache miss and transaction completion\000 */
{ 2530749 }, /* sq_misc.bus_lock\000\000cache\000Counts bus locks, accounts for cache line split locks and UC locks\000event=0xf4,period=100003,umask=0x10\000\00000\000Counts the more expensive bus lock needed to enforce cache coherency for certain memory accesses that need to be done atomically.  Can be created by issuing an atomic instruction (via the LOCK prefix) which causes a cache line split or accesses uncacheable memory\000 */
{ 2532432 }, /* sq_misc.sq_full\000\000cache\000Cycles the superQ cannot take any more entries\000event=0xf4,period=100003,umask=0x4\000\00000\000Counts the cycles for which the thread is active and the superQ cannot take any more entries\000 */
{ 2537136 }, /* sw_prefetch_access.nta\000\000cache\000Number of PREFETCHNTA instructions executed\000event=0x32,period=100003,umask=0x1\000\00000\000Counts the number of PREFETCHNTA instructions executed\000 */
{ 2537780 }, /* sw_prefetch_access.prefetchw\000\000cache\000Number of PREFETCHW instructions executed\000event=0x32,period=100003,umask=0x8\000\00000\000Counts the number of PREFETCHW instructions executed\000 */
{ 2538434 }, /* sw_prefetch_access.t0\000\000cache\000Number of PREFETCHT0 instructions executed\000event=0x32,period=100003,umask=0x2\000\00000\000Counts the number of PREFETCHT0 instructions executed\000 */
{ 2539067 }, /* sw_prefetch_access.t1_t2\000\000cache\000Number of PREFETCHT1 or PREFETCHT2 instructions executed\000event=0x32,period=100003,umask=0x4\000\00000\000Counts the number of PREFETCHT1 or PREFETCHT2 instructions executed\000 */
{ 472289 }, /* assists.fp\000\000floating point\000Counts all microcode FP assists\000event=0xc1,period=100003,umask=0x2\000\00000\000Counts all microcode Floating Point assists\000 */
{ 854349 }, /* fp_arith_inst_retired.128b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x4\000\00000\000Number of SSE/AVX computational 128-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 860385 }, /* fp_arith_inst_retired.128b_packed_single\000\000floating point\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x8\000\00000\000Number of SSE/AVX computational 128-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 862608 }, /* fp_arith_inst_retired.256b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x10\000\00000\000Number of SSE/AVX computational 256-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 4 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 866643 }, /* fp_arith_inst_retired.256b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x20\000\00000\000Number of SSE/AVX computational 256-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RCP DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 872056 }, /* fp_arith_inst_retired.4_flops\000\000floating point\000Number of SSE/AVX computational 128-bit packed single and 256-bit packed double precision FP instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and packed double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x18\000\00000\000Number of SSE/AVX computational 128-bit packed single precision and 256-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 2 or/and 4 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point and packed double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX RCP14 RSQRT14 SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 875751 }, /* fp_arith_inst_retired.512b_packed_double\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x40\000\00000\000Number of SSE/AVX computational 512-bit packed double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 878977 }, /* fp_arith_inst_retired.512b_packed_single\000\000floating point\000Counts number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x80\000\00000\000Number of SSE/AVX computational 512-bit packed single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 16 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT14 RCP14 FM(N)ADD/SUB. FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 883416 }, /* fp_arith_inst_retired.8_flops\000\000floating point\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  FP instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, 1 for each element.  Applies to SSE* and AVX* packed single precision and double precision FP instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x60\000\00000\000Number of SSE/AVX computational 256-bit packed single precision and 512-bit packed double precision  floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 8 computation operations, one for each element.  Applies to SSE* and AVX* packed single precision and double precision floating-point instructions: ADD SUB HADD HSUB SUBADD MUL DIV MIN MAX SQRT RSQRT RSQRT14 RCP RCP14 DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 886310 }, /* fp_arith_inst_retired.scalar\000\000floating point\000Number of SSE/AVX computational scalar floating-point instructions retired; some instructions will count twice as noted below.  Applies to SSE* and AVX* scalar, double and single precision floating-point: ADD SUB MUL DIV MIN MAX RCP14 RSQRT14 RANGE SQRT DPP FM(N)ADD/SUB.  DPP and FM(N)ADD/SUB instructions count twice as they perform multiple calculations per element\000event=0xc7,period=1000003,umask=0x3\000\00000\000Number of SSE/AVX computational scalar single precision and double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 890230 }, /* fp_arith_inst_retired.scalar_double\000\000floating point\000Counts number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x1\000\00000\000Number of SSE/AVX computational scalar double precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar double precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 893916 }, /* fp_arith_inst_retired.scalar_single\000\000floating point\000Counts number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element\000event=0xc7,period=100003,umask=0x2\000\00000\000Number of SSE/AVX computational scalar single precision floating-point instructions retired; some instructions will count twice as noted below.  Each count represents 1 computational operation. Applies to SSE* and AVX* scalar single precision floating-point instructions: ADD SUB MUL DIV MIN MAX SQRT RSQRT RCP FM(N)ADD/SUB.  FM(N)ADD/SUB instructions count twice as they perform 2 calculations per element. The DAZ and FTZ flags in the MXCSR register need to be set when using these events\000 */
{ 898444 }, /* fp_arith_inst_retired.vector\000\000floating point\000Number of any Vector retired FP arithmetic instructions\000event=0xc7,period=1000003,umask=0xfc\000\00000\000\000 */
{ 476303 }, /* baclears.any\000\000frontend\000Counts the total number when the front end is resteered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end\000event=0xe6,period=100003,umask=0x1\000\00000\000Counts the number of times the front-end is resteered when it finds a branch instruction in a fetch line. This occurs for the first time a branch instruction is fetched or when the branch is not tracked by the BPU (Branch Prediction Unit) anymore\000 */
{ 775692 }, /* decode.lcp\000\000frontend\000Stalls caused by changing prefix length of the instruction. [This event is alias to ILD_STALL.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to ILD_STALL.LCP]\000 */
{ 781964 }, /* dsb2mite_switches.count\000\000frontend\000Decode Stream Buffer (DSB)-to-MITE transitions count\000event=0xab,cmask=1,edge=1,period=100003,umask=0x2\000\00000\000Counts the number of Decode Stream Buffer (DSB a.k.a. Uop Cache)-to-MITE speculative transitions\000 */
{ 782565 }, /* dsb2mite_switches.penalty_cycles\000\000frontend\000DSB-to-MITE switch true penalty cycles\000event=0xab,period=100003,umask=0x2\000\00000\000Decode Stream Buffer (DSB) is a Uop-cache that holds translations of previously fetched instructions that were decoded by the legacy x86 decode pipeline (MITE). This event counts fetch penalty cycles when a transition occurs from DSB to MITE\000 */
{ 940752 }, /* frontend_retired.any_dsb_miss\000\000frontend\000Retired Instructions who experienced DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x1\000\00000\000Counts retired Instructions that experienced DSB (Decode stream buffer i.e. the decoded instruction-cache) miss (Precise event)\000 */
{ 941341 }, /* frontend_retired.dsb_miss\000\000frontend\000Retired Instructions who experienced a critical DSB miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x11\000\00000\000Number of retired Instructions that experienced a critical DSB (Decode stream buffer i.e. the decoded instruction-cache) miss. Critical means stalls were exposed to the back-end as a result of the DSB miss (Precise event)\000 */
{ 942134 }, /* frontend_retired.itlb_miss\000\000frontend\000Retired Instructions who experienced iTLB true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x14\000\00000\000Counts retired Instructions that experienced iTLB (Instruction TLB) true miss (Precise event)\000 */
{ 943187 }, /* frontend_retired.l1i_miss\000\000frontend\000Retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x12\000\00000\000Counts retired Instructions who experienced Instruction L1 Cache true miss (Precise event)\000 */
{ 944203 }, /* frontend_retired.l2_miss\000\000frontend\000Retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x13\000\00000\000Counts retired Instructions who experienced Instruction L2 Cache true miss (Precise event)\000 */
{ 949857 }, /* frontend_retired.latency_ge_1\000\000frontend\000Retired instructions after front-end starvation of at least 1 cycle (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500106\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 1 cycle which was not interrupted by a back-end stall (Precise event)\000 */
{ 945210 }, /* frontend_retired.latency_ge_128\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x508006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 128 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 947605 }, /* frontend_retired.latency_ge_16\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 16 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x501006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 16 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 953608 }, /* frontend_retired.latency_ge_2\000\000frontend\000Retired instructions after front-end starvation of at least 2 cycles (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500206\000\00000\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of at least 2 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 951670 }, /* frontend_retired.latency_ge_256\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x510006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 256 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 955425 }, /* frontend_retired.latency_ge_2_bubbles_ge_1\000\000frontend\000Retired instructions that are fetched after an interval where the front-end had at least 1 bubble-slot for a period of 2 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x100206\000\00000\000Counts retired instructions that are delivered to the back-end after the front-end had at least 1 bubble-slot for a period of 2 cycles. A bubble-slot is an empty issue-pipeline slot while there was no RAT stall (Precise event)\000 */
{ 958117 }, /* frontend_retired.latency_ge_32\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 32 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x502006\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 32 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 960274 }, /* frontend_retired.latency_ge_4\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500406\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 4 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 962471 }, /* frontend_retired.latency_ge_512\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x520006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 512 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 964690 }, /* frontend_retired.latency_ge_64\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x504006\000\00000\000Counts retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 64 cycles which was not interrupted by a back-end stall (Precise event)\000 */
{ 967070 }, /* frontend_retired.latency_ge_8\000\000frontend\000Retired instructions that are fetched after an interval where the front-end delivered no uops for a period of 8 cycles which was not interrupted by a back-end stall (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x500806\000\00000\000Counts retired instructions that are delivered to the back-end after a front-end stall of at least 8 cycles. During this period the front-end delivered no uops (Precise event)\000 */
{ 969606 }, /* frontend_retired.stlb_miss\000\000frontend\000Retired Instructions who experienced STLB (2nd level TLB) true miss (Precise event)\000event=0xc6,period=100007,umask=0x1,frontend=0x15\000\00000\000Counts retired Instructions that experienced STLB (2nd level TLB) true miss (Precise event)\000 */
{ 992514 }, /* icache_16b.ifdata_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_DATA.STALLS]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_DATA.STALLS]\000 */
{ 993172 }, /* icache_64b.iftag_hit\000\000frontend\000Instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x1\000\00000\000Counts instruction fetch tag lookups that hit in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 993710 }, /* icache_64b.iftag_miss\000\000frontend\000Instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity\000event=0x83,period=200003,umask=0x2\000\00000\000Counts instruction fetch tag lookups that miss in the instruction cache (L1I). Counts at 64-byte cache-line granularity. Accounts for both cacheable and uncacheable accesses\000 */
{ 994253 }, /* icache_64b.iftag_stall\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_TAG.STALLS]\000 */
{ 994901 }, /* icache_data.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache miss. [This event is alias to ICACHE_16B.IFDATA_STALL]\000event=0x80,period=500009,umask=0x4\000\00000\000Counts cycles where a code line fetch is stalled due to an L1 instruction cache miss. The legacy decode pipeline works at a 16 Byte granularity. [This event is alias to ICACHE_16B.IFDATA_STALL]\000 */
{ 996232 }, /* icache_tag.stalls\000\000frontend\000Cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000event=0x83,period=200003,umask=0x4\000\00000\000Counts cycles where a code fetch is stalled due to L1 instruction cache tag miss. [This event is alias to ICACHE_64B.IFTAG_STALL]\000 */
{ 1003938 }, /* idq.dsb_cycles_any\000\000frontend\000Cycles Decode Stream Buffer (DSB) is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x8\000\00000\000Counts the number of cycles uops were delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1004475 }, /* idq.dsb_cycles_ok\000\000frontend\000Cycles DSB is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x8\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1006310 }, /* idq.dsb_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000event=0x79,period=2000003,umask=0x8\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the Decode Stream Buffer (DSB) path\000 */
{ 1010161 }, /* idq.mite_cycles_any\000\000frontend\000Cycles MITE is delivering any Uop\000event=0x79,cmask=1,period=2000003,umask=0x4\000\00000\000Counts the number of cycles uops were delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1010842 }, /* idq.mite_cycles_ok\000\000frontend\000Cycles MITE is delivering optimal number of Uops\000event=0x79,cmask=5,period=2000003,umask=0x4\000\00000\000Counts the number of cycles where optimal number of uops was delivered to the Instruction Decode Queue (IDQ) from the MITE (legacy decode pipeline) path. During these cycles uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1012316 }, /* idq.mite_uops\000\000frontend\000Uops delivered to Instruction Decode Queue (IDQ) from MITE path\000event=0x79,period=2000003,umask=0x4\000\00000\000Counts the number of uops delivered to Instruction Decode Queue (IDQ) from the MITE path. This also means that uops are not being delivered from the Decode Stream Buffer (DSB)\000 */
{ 1017043 }, /* idq.ms_cycles_any\000\000frontend\000Cycles when uops are being delivered to IDQ while MS is busy\000event=0x79,cmask=1,period=2000003,umask=0x30\000\00000\000Counts cycles during which uops are being delivered to Instruction Decode Queue (IDQ) while the Microcode Sequencer (MS) is busy. Uops maybe initiated by Decode Stream Buffer (DSB) or MITE\000 */
{ 1024432 }, /* idq.ms_switches\000\000frontend\000Number of switches from DSB or MITE to the MS\000event=0x79,cmask=1,edge=1,period=100003,umask=0x30\000\00000\000Number of switches from DSB (Decode Stream Buffer) or MITE (legacy decode pipeline) to the Microcode Sequencer\000 */
{ 1025109 }, /* idq.ms_uops\000\000frontend\000Uops delivered to IDQ while MS is busy\000event=0x79,period=100003,umask=0x30\000\00000\000Counts the total number of uops delivered by the Microcode Sequencer (MS). Any instruction over 4 uops will be delivered by the MS. Some instructions such as transcendentals may additionally generate uops from the MS\000 */
{ 1029922 }, /* idq_uops_not_delivered.core\000\000frontend\000Uops not delivered by IDQ when backend of the machine is not stalled\000event=0x9c,period=1000003,umask=0x1\000\00000\000Counts the number of uops not delivered to by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1035288 }, /* idq_uops_not_delivered.cycles_0_uops_deliv.core\000\000frontend\000Cycles when no uops are not delivered by the IDQ when backend of the machine is not stalled\000event=0x9c,cmask=5,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when no uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 1036953 }, /* idq_uops_not_delivered.cycles_fe_was_ok\000\000frontend\000Cycles when optimal number of uops was delivered to the back-end when the back-end is not stalled\000event=0x9c,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts the number of cycles when the optimal number of uops were delivered by the Instruction Decode Queue (IDQ) to the back-end of the pipeline when there was no back-end stalls. This event counts for one SMT thread in a given cycle\000 */
{ 757545 }, /* cycle_activity.stalls_l3_miss\000\000memory\000Execution stalls while L3 cache miss demand load is outstanding\000event=0xa3,cmask=6,period=1000003,umask=0x6\000\00000\000\000 */
{ 1296966 }, /* machine_clears.memory_ordering\000\000memory\000Number of machine clears due to memory ordering conflicts\000event=0xc3,period=100003,umask=0x2\000\00000\000Counts the number of Machine Clears detected dye to memory ordering. Memory Ordering Machine Clears may apply when a memory read may not conform to the memory ordering rules of the x86 architecture\000 */
{ 1369035 }, /* mem_trans_retired.load_latency_gt_128\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=1009,umask=0x1,ldlat=0x80\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 128 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1370983 }, /* mem_trans_retired.load_latency_gt_16\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=20011,umask=0x1,ldlat=0x10\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 16 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1372921 }, /* mem_trans_retired.load_latency_gt_256\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=503,umask=0x1,ldlat=0x100\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 256 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1374869 }, /* mem_trans_retired.load_latency_gt_32\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100007,umask=0x1,ldlat=0x20\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 32 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1376813 }, /* mem_trans_retired.load_latency_gt_4\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=100003,umask=0x1,ldlat=0x4\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 4 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1378739 }, /* mem_trans_retired.load_latency_gt_512\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=101,umask=0x1,ldlat=0x200\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 512 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1380687 }, /* mem_trans_retired.load_latency_gt_64\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=2003,umask=0x1,ldlat=0x40\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 64 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1382619 }, /* mem_trans_retired.load_latency_gt_8\000\000memory\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles  Supports address when precise (Must be precise)\000event=0xcd,period=50021,umask=0x1,ldlat=0x8\000\00000\000Counts randomly selected loads when the latency from first dispatch to completion is greater than 8 cycles.  Reported latency may be longer than just the memory latency  Supports address when precise (Must be precise)\000 */
{ 1752561 }, /* offcore_requests.l3_miss_demand_data_rd\000\000memory\000Demand Data Read requests who miss L3 cache\000event=0xb0,period=100003,umask=0x10\000\00000\000Demand Data Read requests who miss L3 cache\000 */
{ 2515210 }, /* rtm_retired.aborted\000\000memory\000Number of times an RTM execution aborted\000event=0xc9,period=100003,umask=0x4\000\00000\000Counts the number of times RTM abort was triggered\000 */
{ 2515369 }, /* rtm_retired.aborted_events\000\000memory\000Number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000event=0xc9,period=100003,umask=0x80\000\00000\000Counts the number of times an RTM execution aborted due to none of the previous 4 categories (e.g. interrupt)\000 */
{ 2515927 }, /* rtm_retired.aborted_mem\000\000memory\000Number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000event=0xc9,period=100003,umask=0x8\000\00000\000Counts the number of times an RTM execution aborted due to various memory events (e.g. read/write capacity and conflicts)\000 */
{ 2516525 }, /* rtm_retired.aborted_memtype\000\000memory\000Number of times an RTM execution aborted due to incompatible memory type\000event=0xc9,period=100003,umask=0x40\000\00000\000Counts the number of times an RTM execution aborted due to incompatible memory type\000 */
{ 2519396 }, /* rtm_retired.aborted_unfriendly\000\000memory\000Number of times an RTM execution aborted due to HLE-unfriendly instructions\000event=0xc9,period=100003,umask=0x20\000\00000\000Counts the number of times an RTM execution aborted due to HLE-unfriendly instructions\000 */
{ 2520011 }, /* rtm_retired.commit\000\000memory\000Number of times an RTM execution successfully committed\000event=0xc9,period=100003,umask=0x2\000\00000\000Counts the number of times RTM commit succeeded\000 */
{ 2520465 }, /* rtm_retired.start\000\000memory\000Number of times an RTM execution started\000event=0xc9,period=100003,umask=0x1\000\00000\000Counts the number of times we entered an RTM region. Does not count nested transactions\000 */
{ 2572419 }, /* tx_exec.misc2\000\000memory\000Counts the number of times a class of instructions that may cause a transactional abort was executed inside a transactional region\000event=0x5d,period=100003,umask=0x2\000\00000\000Counts Unfriendly TSX abort triggered by a vzeroupper instruction\000 */
{ 2573092 }, /* tx_exec.misc3\000\000memory\000Number of times an instruction execution caused the transactional nest count supported to be exceeded\000event=0x5d,period=100003,umask=0x4\000\00000\000Counts Unfriendly TSX abort triggered by a nest count that is too deep\000 */
{ 2574300 }, /* tx_mem.abort_capacity_read\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional reads\000event=0x54,period=100003,umask=0x80\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional reads\000 */
{ 2575085 }, /* tx_mem.abort_capacity_write\000\000memory\000Speculatively counts the number of TSX aborts due to a data capacity limitation for transactional writes\000event=0x54,period=100003,umask=0x2\000\00000\000Speculatively counts the number of Transactional Synchronization Extensions (TSX) aborts due to a data capacity limitation for transactional writes\000 */
{ 2575579 }, /* tx_mem.abort_conflict\000\000memory\000Number of times a transactional abort was signaled due to a data conflict on a transactionally accessed address\000event=0x54,period=100003,umask=0x1\000\00000\000Counts the number of times a TSX line had a cache conflict\000 */
{ 572304 }, /* core_power.lvl0_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the Non-AVX turbo schedule\000event=0x28,period=200003,umask=0x7\000\00000\000Counts Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000 */
{ 573029 }, /* core_power.lvl1_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX2 turbo schedule\000event=0x28,period=200003,umask=0x18\000\00000\000Counts Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000 */
{ 573765 }, /* core_power.lvl2_turbo_license\000\000other\000Core cycles where the core was running in a manner where Turbo may be clipped to the AVX512 turbo schedule\000event=0x28,period=200003,umask=0x20\000\00000\000Core cycles where the core was running with power-delivery for license level 2 (introduced in Skylake Server microarchtecture).  This includes high current AVX 512-bit instructions\000 */
{ 1738564 }, /* ocr.streaming_wr.any_response\000\000other\000Counts streaming stores that have any type of response\000event=0xb7,period=100003,umask=0x1,offcore_rsp=0x10800\000\00000\000\000 */
{ 468280 }, /* arith.divider_active\000\000pipeline\000Cycles when divide unit is busy executing divide or square root operations\000event=0x14,cmask=1,period=1000003,umask=0x9\000\00000\000Counts cycles when divide unit is busy executing divide or square root operations. Accounts for integer and floating-point operations\000 */
{ 471702 }, /* assists.any\000\000pipeline\000Number of occurrences where a microcode assist is invoked by hardware\000event=0xc1,period=100003,umask=0x7\000\00000\000Counts the number of occurrences where a microcode assist is invoked by hardware Examples include AD (page Access Dirty), FP and AVX related assists\000 */
{ 496863 }, /* br_inst_retired.all_branches\000\000pipeline\000All branch instructions retired (Precise event)\000event=0xc4,period=400009\000\00000\000Counts all branch instructions retired (Precise event)\000 */
{ 502931 }, /* br_inst_retired.cond\000\000pipeline\000Conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x11\000\00000\000Counts conditional branch instructions retired (Precise event)\000 */
{ 504333 }, /* br_inst_retired.cond_ntaken\000\000pipeline\000Not taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x10\000\00000\000Counts not taken branch instructions retired (Precise event)\000 */
{ 504924 }, /* br_inst_retired.cond_taken\000\000pipeline\000Taken conditional branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x1\000\00000\000Counts taken conditional branch instructions retired (Precise event)\000 */
{ 508295 }, /* br_inst_retired.far_branch\000\000pipeline\000Far branch instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x40\000\00000\000Counts far branch instructions retired (Precise event)\000 */
{ 511305 }, /* br_inst_retired.indirect\000\000pipeline\000Indirect near branch instructions retired (excluding returns) (Precise event)\000event=0xc4,period=100003,umask=0x80\000\00000\000Counts near indirect branch instructions retired excluding returns. TSX abort is an indirect branch (Precise event)\000 */
{ 515219 }, /* br_inst_retired.near_call\000\000pipeline\000Direct and indirect near call instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x2\000\00000\000Counts both direct and indirect near call instructions retired (Precise event)\000 */
{ 517928 }, /* br_inst_retired.near_return\000\000pipeline\000Return instructions retired (Precise event)\000event=0xc4,period=100007,umask=0x8\000\00000\000Counts return instructions retired (Precise event)\000 */
{ 519163 }, /* br_inst_retired.near_taken\000\000pipeline\000Taken branch instructions retired (Precise event)\000event=0xc4,period=400009,umask=0x20\000\00000\000Counts taken branch instructions retired (Precise event)\000 */
{ 535753 }, /* br_misp_retired.all_branches\000\000pipeline\000All mispredicted branch instructions retired (Precise event)\000event=0xc5,period=50021\000\00000\000Counts all the retired branch instructions that were mispredicted by the processor. A branch misprediction occurs when the processor incorrectly predicts the destination of the branch.  When the misprediction is discovered at execution, all the instructions executed in the wrong (speculative) path must be discarded, and the processor must start fetching from the correct path (Precise event)\000 */
{ 542758 }, /* br_misp_retired.cond\000\000pipeline\000Mispredicted conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x11\000\00000\000Counts mispredicted conditional branch instructions retired (Precise event)\000 */
{ 544064 }, /* br_misp_retired.cond_ntaken\000\000pipeline\000Mispredicted non-taken conditional branch instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x10\000\00000\000Counts the number of conditional branch instructions retired that were mispredicted and the branch direction was not taken (Precise event)\000 */
{ 545483 }, /* br_misp_retired.cond_taken\000\000pipeline\000number of branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x1\000\00000\000Counts taken conditional mispredicted branch instructions retired (Precise event)\000 */
{ 548979 }, /* br_misp_retired.indirect\000\000pipeline\000All miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000event=0xc5,period=50021,umask=0x80\000\00000\000Counts all miss-predicted indirect branch instructions retired (excluding RETs. TSX aborts is considered indirect branch) (Precise event)\000 */
{ 550538 }, /* br_misp_retired.indirect_call\000\000pipeline\000Mispredicted indirect CALL instructions retired (Precise event)\000event=0xc5,period=50021,umask=0x2\000\00000\000Counts retired mispredicted indirect (near taken) CALL instructions, including both register and memory indirect (Precise event)\000 */
{ 555535 }, /* br_misp_retired.near_taken\000\000pipeline\000Number of near branch instructions retired that were mispredicted and taken (Precise event)\000event=0xc5,period=50021,umask=0x20\000\00000\000Counts number of near branch instructions retired that were mispredicted and taken (Precise event)\000 */
{ 560471 }, /* br_misp_retired.ret\000\000pipeline\000This event counts the number of mispredicted ret instructions retired. Non PEBS (Precise event)\000event=0xc5,period=50021,umask=0x8\000\00000\000This is a non-precise version (that is, does not use PEBS) of the event that counts mispredicted return instructions retired (Precise event)\000 */
{ 616704 }, /* cpu_clk_unhalted.distributed\000\000pipeline\000Cycle counts are evenly distributed between active threads in the Core\000event=0xec,period=2000003,umask=0x2\000\00000\000This event distributes cycle counts between active hyperthreads, i.e., those in C0.  A hyperthread becomes inactive when it executes the HLT or MWAIT instructions.  If all other hyperthreads are inactive (or disabled or do not exist), all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 617767 }, /* cpu_clk_unhalted.one_thread_active\000\000pipeline\000Core crystal clock cycles when this thread is unhalted and the other thread is halted\000event=0x3c,period=25003,umask=0x2\000\00000\000Counts Core crystal clock cycles when current thread is unhalted and the other thread is halted\000 */
{ 621045 }, /* cpu_clk_unhalted.ref_distributed\000\000pipeline\000Core crystal clock cycles. Cycle counts are evenly distributed between active threads in the Core\000event=0x3c,period=2000003,umask=0x8\000\00000\000This event distributes Core crystal clock cycle counts between active hyperthreads, i.e., those in C0 sleep-state. A hyperthread becomes inactive when it executes the HLT or MWAIT instructions. If one thread is active in a core, all counts are attributed to this hyperthread. To obtain the full count when the Core is active, sum the counts from each hyperthread\000 */
{ 626122 }, /* cpu_clk_unhalted.ref_tsc\000\000pipeline\000Reference cycles when the core is not in halt state\000event=0,period=2000003,umask=0x3\000\00000\000Counts the number of reference cycles when the core is not in a halt state. The core enters the halt state when it is running the HLT instruction or the MWAIT instruction. This event is not affected by core frequency changes (for example, P states, TM2 transitions) but has the same incrementing frequency as the time stamp counter. This event can approximate elapsed time while the core was not in a halt state. This event has a constant ratio with the CPU_CLK_UNHALTED.REF_XCLK event. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events. Note: On all current platforms this event stops counting during 'throttling (TM)' states duty off periods the processor is 'halted'.  The counter update is done at a lower clock rate then the core clock the overflow status bit for this counter may appear 'sticky'.  After the counter has overflowed and software clears the overflow status bit and resets the counter to less than MAX. The reset value to the counter is not clocked immediately so the overflow status bit will flip 'high (1)' and generate another PMI (if enabled) after which the reset value gets clocked into the counter. Therefore, software will get the interrupt, read the overflow status bit '1 for bit 34 while the counter value is less than MAX. Software should ignore this case\000 */
{ 638164 }, /* cpu_clk_unhalted.ref_xclk\000\000pipeline\000Core crystal clock cycles when the thread is unhalted\000event=0x3c,period=25003,umask=0x1\000\00000\000Counts core crystal clock cycles when the thread is unhalted\000 */
{ 640556 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Core cycles when the thread is not in halt state\000event=0x3c,period=2000003\000\00000\000Counts the number of core cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. This event is a component in many key event ratios. The core frequency may change from time to time due to transitions associated with Enhanced Intel SpeedStep Technology or TM2. For this reason this event may have a changing ratio with regards to time. When the core frequency is constant, this event can approximate elapsed time while the core was not in the halt state. It is counted on a dedicated fixed counter, leaving the eight programmable counters available for other events\000 */
{ 647675 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Thread cycles when thread is not in halt state\000event=0x3c,period=2000003\000\00000\000This is an architectural event that counts the number of thread cycles while the thread is not in a halt state. The thread enters the halt state when it is running the HLT instruction. The core frequency may change from time to time due to power or thermal throttling. For this reason, this event may have a changing ratio with regards to wall clock time\000 */
{ 748732 }, /* cycle_activity.cycles_l1d_miss\000\000pipeline\000Cycles while L1 cache miss demand load is outstanding\000event=0xa3,cmask=8,period=1000003,umask=0x8\000\00000\000\000 */
{ 750161 }, /* cycle_activity.cycles_l2_miss\000\000pipeline\000Cycles while L2 cache miss demand load is outstanding\000event=0xa3,cmask=1,period=1000003,umask=0x1\000\00000\000\000 */
{ 752892 }, /* cycle_activity.cycles_mem_any\000\000pipeline\000Cycles while memory subsystem has an outstanding load\000event=0xa3,cmask=16,period=1000003,umask=0x10\000\00000\000\000 */
{ 754470 }, /* cycle_activity.stalls_l1d_miss\000\000pipeline\000Execution stalls while L1 cache miss demand load is outstanding\000event=0xa3,cmask=12,period=1000003,umask=0xc\000\00000\000\000 */
{ 755810 }, /* cycle_activity.stalls_l2_miss\000\000pipeline\000Execution stalls while L2 cache miss demand load is outstanding\000event=0xa3,cmask=5,period=1000003,umask=0x5\000\00000\000\000 */
{ 758739 }, /* cycle_activity.stalls_mem_any\000\000pipeline\000Execution stalls while memory subsystem has an outstanding load\000event=0xa3,cmask=20,period=1000003,umask=0x14\000\00000\000\000 */
{ 759202 }, /* cycle_activity.stalls_total\000\000pipeline\000Total execution stalls\000event=0xa3,cmask=4,period=1000003,umask=0x4\000\00000\000\000 */
{ 844835 }, /* exe_activity.1_ports_util\000\000pipeline\000Cycles total of 1 uop is executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x2\000\00000\000Counts cycles during which a total of 1 uop was executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845408 }, /* exe_activity.2_ports_util\000\000pipeline\000Cycles total of 2 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x4\000\00000\000Counts cycles during which a total of 2 uops were executed on all ports and Reservation Station (RS) was not empty\000 */
{ 845989 }, /* exe_activity.3_ports_util\000\000pipeline\000Cycles total of 3 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x8\000\00000\000Cycles total of 3 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 846524 }, /* exe_activity.4_ports_util\000\000pipeline\000Cycles total of 4 uops are executed on all ports and Reservation Station was not empty\000event=0xa6,period=2000003,umask=0x10\000\00000\000Cycles total of 4 uops are executed on all ports and Reservation Station (RS) was not empty\000 */
{ 847061 }, /* exe_activity.bound_on_loads\000\000pipeline\000Cycles when the memory subsystem has an outstanding load. Increments by 4 for every such cycle\000event=0xa6,cmask=5,period=2000003,umask=0x21\000\00000\000Counts cycles when the memory subsystem has an outstanding load. Increments by 4 for every such cycle\000 */
{ 847674 }, /* exe_activity.bound_on_stores\000\000pipeline\000Cycles where the Store Buffer was full and no loads caused an execution stall\000event=0xa6,cmask=2,period=1000003,umask=0x40\000\00000\000Counts cycles where the Store Buffer was full and no loads caused an execution stall\000 */
{ 848345 }, /* exe_activity.exe_bound_0_ports\000\000pipeline\000Cycles no uop executed while RS was not empty, the SB was not full and there was no outstanding load\000event=0xa6,period=1000003,umask=0x80\000\00000\000Number of cycles total of 0 uops executed on all ports, Reservation Station (RS) was not empty, the Store Buffer (SB) was not full and there was no outstanding load\000 */
{ 1041607 }, /* ild_stall.lcp\000\000pipeline\000Stalls caused by changing prefix length of the instruction. [This event is alias to DECODE.LCP]\000event=0x87,period=500009,umask=0x1\000\00000\000Counts cycles that the Instruction Length decoder (ILD) stalls occurred due to dynamically changing prefix length of the decoded instruction (by operand size prefix instruction 0x66, address size prefix instruction 0x67 or REX.W for Intel64). Count is proportional to the number of prefixes in a 16B-line. This may result in a three-cycle penalty for each LCP (Length changing prefix) in a 16-byte chunk. [This event is alias to DECODE.LCP]\000 */
{ 1043299 }, /* inst_decoded.decoders\000\000pipeline\000Instruction decoders utilized in a cycle\000event=0x55,period=2000003,umask=0x1\000\00000\000Number of decoders utilized in a cycle when the MITE (legacy decode pipeline) fetches instructions\000 */
{ 1049915 }, /* inst_retired.any\000\000pipeline\000Number of instructions retired. Fixed Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1055337 }, /* inst_retired.any_p\000\000pipeline\000Number of instructions retired. General Counter - architectural event (Precise event)\000event=0xc0,period=2000003\000\00000\000Counts the number of X86 instructions retired - an Architectural PerfMon event. Counting continues during hardware interrupts, traps, and inside interrupt handlers. Notes: INST_RETIRED.ANY is counted by a designated fixed counter freeing up programmable counters to count other events. INST_RETIRED.ANY_P is counted by a programmable counter (Precise event)\000 */
{ 1058121 }, /* inst_retired.nop\000\000pipeline\000Retired NOP instructions (Precise event)\000event=0xc0,period=2000003,umask=0x2\000\00000\000Counts all retired NOP or ENDBR32/64 instructions (Precise event)\000 */
{ 1060581 }, /* inst_retired.prec_dist\000\000pipeline\000Precise instruction retired event with a reduced effect of PEBS shadow in IP distribution (Precise event)\000event=0,period=2000003,umask=0x1\000\00000\000A version of INST_RETIRED that allows for a more unbiased distribution of samples across instructions retired. It utilizes the Precise Distribution of Instructions Retired (PDIR) feature to mitigate some bias in how retired instructions get sampled. Use on Fixed Counter 0 (Precise event)\000 */
{ 1064821 }, /* int_misc.all_recovery_cycles\000\000pipeline\000Cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000event=0xd,cmask=1,period=2000003,umask=0x3\000\00000\000Counts cycles the Backend cluster is recovering after a miss-speculation or a Store Buffer or Load Buffer drain stall\000 */
{ 1065804 }, /* int_misc.clear_resteer_cycles\000\000pipeline\000Counts cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000event=0xd,period=500009,umask=0x80\000\00000\000Cycles after recovery from a branch misprediction or machine clear till the first uop is issued from the resteered path\000 */
{ 1067113 }, /* int_misc.clears_count\000\000pipeline\000Clears speculative count\000event=0xd,cmask=1,edge=1,period=500009,umask=0x1\000\00000\000Counts the number of speculative clears due to any type of branch misprediction or machine clears\000 */
{ 1069580 }, /* int_misc.recovery_cycles\000\000pipeline\000Core cycles the allocator was stalled due to recovery from earlier clear event for this thread\000event=0xd,period=500009,umask=0x1\000\00000\000Counts core cycles when the Resource allocator was stalled due to recovery from an earlier branch misprediction or machine clear event\000 */
{ 1072919 }, /* int_misc.uop_dropping\000\000pipeline\000TMA slots where uops got dropped\000event=0xd,period=1000003,umask=0x10\000\00000\000Estimated number of Top-down Microarchitecture Analysis slots that got dropped due to non front-end reasons\000 */
{ 1194117 }, /* ld_blocks.no_sr\000\000pipeline\000The number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000event=0x3,period=100003,umask=0x8\000\00000\000Counts the number of times that split load operations are temporarily blocked because all resources for handling the split accesses are in use\000 */
{ 1198619 }, /* ld_blocks.store_forward\000\000pipeline\000Loads blocked due to overlapping with a preceding store that cannot be forwarded\000event=0x3,period=100003,umask=0x2\000\00000\000Counts the number of times where store forwarding was prevented for a load operation. The most common case is a load blocked due to the address of memory access (partially) overlapping with a preceding uncompleted store. Note: See the table of not supported store forwards in the Optimization Guide\000 */
{ 1202459 }, /* ld_blocks_partial.address_alias\000\000pipeline\000False dependencies in MOB due to partial compare on address\000event=0x7,period=100003,umask=0x1\000\00000\000Counts the number of times a load got blocked due to false dependencies in MOB due to partial compare on address\000 */
{ 1231173 }, /* load_hit_prefetch.swpf\000\000pipeline\000Counts the number of demand load dispatches that hit L1D fill buffer (FB) allocated for software prefetch\000event=0x4c,period=100003,umask=0x1\000\00000\000Counts all not software-prefetch load dispatches that hit the fill buffer (FB) allocated for the software prefetch. It can also be incremented by some lock instructions. So it should only be used with profiling so that the locks can be excluded by ASM (Assembly File) inspection of the nearby instructions\000 */
{ 1283964 }, /* lsd.cycles_active\000\000pipeline\000Cycles Uops delivered by the LSD, but didn't come from the decoder\000event=0xa8,cmask=1,period=2000003,umask=0x1\000\00000\000Counts the cycles when at least one uop is delivered by the LSD (Loop-stream detector)\000 */
{ 1285110 }, /* lsd.cycles_ok\000\000pipeline\000Cycles optimal number of Uops delivered by the LSD, but did not come from the decoder\000event=0xa8,cmask=5,period=2000003,umask=0x1\000\00000\000Counts the cycles when optimal number of uops is delivered by the LSD (Loop-stream detector)\000 */
{ 1286007 }, /* lsd.uops\000\000pipeline\000Number of Uops delivered by the LSD\000event=0xa8,period=2000003,umask=0x1\000\00000\000Counts the number of uops delivered to the back-end by the LSD(Loop Stream Detector)\000 */
{ 1288826 }, /* machine_clears.count\000\000pipeline\000Number of machine clears (nukes) of any type\000event=0xc3,cmask=1,edge=1,period=100003,umask=0x1\000\00000\000Counts the number of machine clears (nukes) of any type\000 */
{ 1301466 }, /* machine_clears.smc\000\000pipeline\000Self-modifying code (SMC) detected\000event=0xc3,period=100003,umask=0x4\000\00000\000Counts self-modifying code (SMC) detected, which causes a machine clear\000 */
{ 1431434 }, /* misc_retired.lbr_inserts\000\000pipeline\000Increments whenever there is an update to the LBR array\000event=0xcc,period=100003,umask=0x20\000\00000\000Increments when an entry is added to the Last Branch Record (LBR) array (or removed from the array in case of RETURNs in call stack mode). The event requires LBR enable via IA32_DEBUGCTL MSR and branch type selection via MSR_LBR_SELECT\000 */
{ 1432509 }, /* misc_retired.pause_inst\000\000pipeline\000Number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000event=0xcc,period=100003,umask=0x40\000\00000\000Counts number of retired PAUSE instructions. This event is not supported on first SKL and KBL products\000 */
{ 2504245 }, /* resource_stalls.sb\000\000pipeline\000Cycles stalled due to no store buffers available. (not including draining form sync)\000event=0xa2,period=100003,umask=0x8\000\00000\000Counts allocation stall cycles caused by the store buffer (SB) being full. This counts cycles that the pipeline back-end blocked uop delivery from the front-end\000 */
{ 2506218 }, /* resource_stalls.scoreboard\000\000pipeline\000Counts cycles where the pipeline is stalled due to serializing operations\000event=0xa2,period=100003,umask=0x2\000\00000\000\000 */
{ 2510439 }, /* rs_events.empty_cycles\000\000pipeline\000Cycles when Reservation Station (RS) is empty for the thread\000event=0x5e,period=1000003,umask=0x1\000\00000\000Counts cycles during which the reservation station (RS) is empty for this logical processor. This is usually caused when the front-end pipeline runs into stravation periods (e.g. branch mispredictions or i-cache misses)\000 */
{ 2513050 }, /* rs_events.empty_end\000\000pipeline\000Counts end of periods where the Reservation Station (RS) was empty\000event=0x5e,cmask=1,edge=1,inv=1,period=100003,umask=0x1\000\00000\000Counts end of periods where the Reservation Station (RS) was empty. Could be useful to closely sample on front-end latency issues (see the FRONTEND_RETIRED event of designated precise events)\000 */
{ 2543188 }, /* topdown.backend_bound_slots\000\000pipeline\000TMA slots where no uops were being issued due to lack of back-end resources\000event=0xa4,period=10000003,umask=0x2\000\00000\000Counts the number of Top-down Microarchitecture Analysis (TMA) method's  slots where no micro-operations were being issued from front-end to back-end of the machine due to lack of back-end resources\000 */
{ 2546876 }, /* topdown.br_mispredict_slots\000\000pipeline\000TMA slots wasted due to incorrect speculation by branch mispredictions\000event=0xa4,period=10000003,umask=0x8\000\00000\000Number of TMA slots that were wasted due to incorrect speculation by branch mispredictions. This event estimates number of operations that were issued but not retired from the speculative path as well as the out-of-order engine recovery past a branch misprediction\000 */
{ 2548410 }, /* topdown.slots\000\000pipeline\000TMA slots available for an unhalted logical processor. Fixed counter - architectural event\000event=0,period=10000003,umask=0x4\000\00000\000Number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method (TMA). The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core. Software can use this event as the denominator for the top-level metrics of the TMA method. This architectural event is counted on a designated fixed counter (Fixed Counter 3)\000 */
{ 2549699 }, /* topdown.slots_p\000\000pipeline\000TMA slots available for an unhalted logical processor. General counter - architectural event\000event=0xa4,period=10000003,umask=0x1\000\00000\000Counts the number of available slots for an unhalted logical processor. The event increments by machine-width of the narrowest pipeline as employed by the Top-down Microarchitecture Analysis method. The count is distributed among unhalted logical processors (hyper-threads) who share the same physical core\000 */
{ 6178334 }, /* uops_decoded.dec0\000\000pipeline\000Number of uops decoded out of instructions exclusively fetched by decoder 0\000event=0x56,period=1000003,umask=0x1\000\00000\000Uops exclusively fetched by decoder 0\000 */
{ 6179516 }, /* uops_dispatched.port_0\000\000pipeline\000Number of uops executed on port 0\000event=0xa1,period=2000003,umask=0x1\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 0\000 */
{ 6180060 }, /* uops_dispatched.port_1\000\000pipeline\000Number of uops executed on port 1\000event=0xa1,period=2000003,umask=0x2\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 1\000 */
{ 6180604 }, /* uops_dispatched.port_2_3\000\000pipeline\000Number of uops executed on port 2 and 3\000event=0xa1,period=2000003,umask=0x4\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 2 and 3\000 */
{ 6181215 }, /* uops_dispatched.port_4_9\000\000pipeline\000Number of uops executed on port 4 and 9\000event=0xa1,period=2000003,umask=0x10\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 5 and 9\000 */
{ 6181807 }, /* uops_dispatched.port_5\000\000pipeline\000Number of uops executed on port 5\000event=0xa1,period=2000003,umask=0x20\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 5\000 */
{ 6182390 }, /* uops_dispatched.port_6\000\000pipeline\000Number of uops executed on port 6\000event=0xa1,period=2000003,umask=0x40\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to port 6\000 */
{ 6182937 }, /* uops_dispatched.port_7_8\000\000pipeline\000Number of uops executed on port 7 and 8\000event=0xa1,period=2000003,umask=0x80\000\00000\000Counts, on the per-thread basis, cycles during which at least one uop is dispatched from the Reservation Station (RS) to ports 7 and 8\000 */
{ 6193009 }, /* uops_executed.core\000\000pipeline\000Number of uops executed on the core\000event=0xb1,period=2000003,umask=0x2\000\00000\000Counts the number of uops executed from any thread\000 */
{ 6194148 }, /* uops_executed.core_cycles_ge_1\000\000pipeline\000Cycles at least 1 micro-op is executed from any thread on physical core\000event=0xb1,cmask=1,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 1 micro-op is executed from any thread on physical core\000 */
{ 6195247 }, /* uops_executed.core_cycles_ge_2\000\000pipeline\000Cycles at least 2 micro-op is executed from any thread on physical core\000event=0xb1,cmask=2,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 2 micro-ops are executed from any thread on physical core\000 */
{ 6196350 }, /* uops_executed.core_cycles_ge_3\000\000pipeline\000Cycles at least 3 micro-op is executed from any thread on physical core\000event=0xb1,cmask=3,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 3 micro-ops are executed from any thread on physical core\000 */
{ 6197453 }, /* uops_executed.core_cycles_ge_4\000\000pipeline\000Cycles at least 4 micro-op is executed from any thread on physical core\000event=0xb1,cmask=4,period=2000003,umask=0x2\000\00000\000Counts cycles when at least 4 micro-ops are executed from any thread on physical core\000 */
{ 6200004 }, /* uops_executed.cycles_ge_1\000\000pipeline\000Cycles where at least 1 uop was executed per-thread\000event=0xb1,cmask=1,period=2000003,umask=0x1\000\00000\000Cycles where at least 1 uop was executed per-thread\000 */
{ 6201055 }, /* uops_executed.cycles_ge_2\000\000pipeline\000Cycles where at least 2 uops were executed per-thread\000event=0xb1,cmask=2,period=2000003,umask=0x1\000\00000\000Cycles where at least 2 uops were executed per-thread\000 */
{ 6202126 }, /* uops_executed.cycles_ge_3\000\000pipeline\000Cycles where at least 3 uops were executed per-thread\000event=0xb1,cmask=3,period=2000003,umask=0x1\000\00000\000Cycles where at least 3 uops were executed per-thread\000 */
{ 6203199 }, /* uops_executed.cycles_ge_4\000\000pipeline\000Cycles where at least 4 uops were executed per-thread\000event=0xb1,cmask=4,period=2000003,umask=0x1\000\00000\000Cycles where at least 4 uops were executed per-thread\000 */
{ 6205355 }, /* uops_executed.stall_cycles\000\000pipeline\000Counts number of cycles no uops were dispatched to be executed on this thread\000event=0xb1,cmask=1,inv=1,period=2000003,umask=0x1\000\00000\000Counts cycles during which no uops were dispatched from the Reservation Station (RS) per thread\000 */
{ 6207380 }, /* uops_executed.thread\000\000pipeline\000Counts the number of uops to be executed per-thread each cycle\000event=0xb1,period=2000003,umask=0x1\000\00000\000\000 */
{ 6207675 }, /* uops_executed.x87\000\000pipeline\000Counts the number of x87 uops dispatched\000event=0xb1,period=2000003,umask=0x10\000\00000\000Counts the number of x87 uops executed\000 */
{ 6213867 }, /* uops_issued.any\000\000pipeline\000Uops that RAT issues to RS\000event=0xe,period=2000003,umask=0x1\000\00000\000Counts the number of uops that the Resource Allocation Table (RAT) issues to the Reservation Station (RS)\000 */
{ 6219243 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles when RAT does not issue Uops to RS for the thread\000event=0xe,cmask=1,inv=1,period=1000003,umask=0x1\000\00000\000Counts cycles during which the Resource Allocation Table (RAT) does not issue any Uops to the reservation station (RS) for the current thread\000 */
{ 6221646 }, /* uops_issued.vector_width_mismatch\000\000pipeline\000Uops inserted at issue-stage in order to preserve upper bits of vector registers\000event=0xe,period=100003,umask=0x2\000\00000\000Counts the number of Blend Uops issued by the Resource Allocation Table (RAT) to the reservation station (RS) in order to preserve upper bits of vector registers. Starting with the Skylake microarchitecture, these Blend uops are needed since every Intel SSE instruction executed in Dirty Upper State needs to preserve bits 128-255 of the destination register. For more information, refer to Mixing Intel AVX and Intel SSE Code section of the Optimization Guide\000 */
{ 6236200 }, /* uops_retired.slots\000\000pipeline\000Retirement slots used\000event=0xc2,period=2000003,umask=0x2\000\00000\000Counts the retirement slots used each cycle\000 */
{ 6238210 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles without actually retired uops\000event=0xc2,cmask=1,inv=1,period=1000003,umask=0x2\000\00000\000This event counts cycles without actually retired uops\000 */
{ 6239807 }, /* uops_retired.total_cycles\000\000pipeline\000Cycles with less than 10 actually retired uops\000event=0xc2,cmask=10,inv=1,period=1000003,umask=0x2\000\00000\000Counts the number of cycles using always true condition (uops_ret < 16) applied to non PEBS uops retired event\000 */
{ 2582722 }, /* unc_arb_coh_trk_requests.all\000uncore_arb\000uncore interconnect\000UNC_ARB_COH_TRK_REQUESTS.ALL. Unit: uncore_arb \000event=0x84,umask=0x1\000\00001\000\000 */
{ 2583135 }, /* unc_arb_dat_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle counts number of any coherent request at memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2583633 }, /* unc_arb_dat_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle counts number of coherent reads pending on data return from memory controller that were issued by any core. Unit: uncore_arb \000event=0x85,umask=0x2\000\00001\000\000 */
{ 2583852 }, /* unc_arb_dat_requests.rd\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_REQ_TRK_REQUEST.DRD. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2584025 }, /* unc_arb_ifa_occupancy.all\000uncore_arb\000uncore interconnect\000This event is deprecated. Refer to new event UNC_ARB_DAT_OCCUPANCY.ALL. Unit: uncore_arb \000event=0x85,umask=0x1\000\00001\000\000 */
{ 2584198 }, /* unc_arb_req_trk_occupancy.drd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_OCCUPANCY.RD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2584862 }, /* unc_arb_req_trk_request.drd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_TRK_REQUESTS.RD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 2585566 }, /* unc_arb_trk_occupancy.all\000uncore_arb\000uncore interconnect\000Each cycle count number of all outgoing valid entries in ReqTrk. Such entry is defined as valid from it's allocation in ReqTrk till deallocation. Accounts for Coherent and non-coherent traffic. Unit: uncore_arb \000event=0x80,umask=0x1\000\00001\000\000 */
{ 2588966 }, /* unc_arb_trk_occupancy.rd\000uncore_arb\000uncore interconnect\000Each cycle count number of 'valid' coherent Data Read entries . Such entry is defined as valid when it is allocated till deallocation. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_OCCUPANCY.DRD]. Unit: uncore_arb \000event=0x80,umask=0x2\000\00001\000\000 */
{ 2590229 }, /* unc_arb_trk_requests.all\000uncore_arb\000uncore interconnect\000UNC_ARB_TRK_REQUESTS.ALL. Unit: uncore_arb \000event=0x81,umask=0x1\000\00001\000\000 */
{ 2591214 }, /* unc_arb_trk_requests.rd\000uncore_arb\000uncore interconnect\000Number of all coherent Data Read entries. Doesn't include prefetches [This event is alias to UNC_ARB_REQ_TRK_REQUEST.DRD]. Unit: uncore_arb \000event=0x81,umask=0x2\000\00001\000\000 */
{ 5608784 }, /* unc_mc0_rdcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every read (RdCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x20\000\00001\000\000 */
{ 5609058 }, /* unc_mc0_total_reqcount_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every 64B read and write request entering the Memory Controller to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x10\000\00001\000\000 */
{ 5610808 }, /* unc_mc0_wrcas_count_freerun\000uncore_imc_free_running_0\000uncore memory\000Counts every write (WrCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_0 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 5611754 }, /* unc_mc1_rdcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every read (RdCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x20\000\00001\000\000 */
{ 5612028 }, /* unc_mc1_total_reqcount_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every 64B read and write request entering the Memory Controller to DRAM (sum of all channels). Each write request counts as a new request incrementing this counter. However, same cache line write requests (both full and partial) are combined to a single 64 byte data transfer to DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x10\000\00001\000\000 */
{ 5613778 }, /* unc_mc1_wrcas_count_freerun\000uncore_imc_free_running_1\000uncore memory\000Counts every write (WrCAS) issued by the Memory Controller to DRAM (sum of all channels). All requests result in 64 byte data transfers from DRAM. Unit: uncore_imc_free_running_1 \000event=0xff,umask=0x30\000\00001\000\000 */
{ 3540688 }, /* unc_clock.socket\000uncore_clock\000uncore other\000UNC_CLOCK.SOCKET. Unit: uncore_clock \000event=0xff\000\00001\000\000 */
{ 791106 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000Loads that miss the DTLB and hit the STLB\000event=0x8,period=100003,umask=0x20\000\00000\000Counts loads that miss the DTLB (Data TLB) and hit the STLB (Second level TLB)\000 */
{ 793108 }, /* dtlb_load_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a demand load\000event=0x8,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a demand load\000 */
{ 795790 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000Load miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x8,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data loads. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 802110 }, /* dtlb_load_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data load to a 2M/4M page\000event=0x8,period=100003,umask=0x4\000\00000\000Counts completed page walks  (2M/4M sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 805386 }, /* dtlb_load_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data load to a 4K page\000event=0x8,period=100003,umask=0x2\000\00000\000Counts completed page walks  (4K sizes) caused by demand data loads. This implies address translations missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 808161 }, /* dtlb_load_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a demand load in the PMH each cycle\000event=0x8,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a demand load in the PMH (Page Miss Handler) each cycle\000 */
{ 813152 }, /* dtlb_store_misses.stlb_hit\000\000virtual memory\000Stores that miss the DTLB and hit the STLB\000event=0x49,period=100003,umask=0x20\000\00000\000Counts stores that miss the DTLB (Data TLB) and hit the STLB (2nd Level TLB)\000 */
{ 815445 }, /* dtlb_store_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for a store\000event=0x49,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a store\000 */
{ 818072 }, /* dtlb_store_misses.walk_completed\000\000virtual memory\000Store misses in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x49,period=100003,umask=0xe\000\00000\000Counts completed page walks  (all page sizes) caused by demand data stores. This implies it missed in the DTLB and further levels of TLB. The page walk can end with or without a fault\000 */
{ 823856 }, /* dtlb_store_misses.walk_completed_2m_4m\000\000virtual memory\000Page walks completed due to a demand data store to a 2M/4M page\000event=0x49,period=100003,umask=0x4\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 2M/4M pages.  The page walks can end with or without a page fault\000 */
{ 826949 }, /* dtlb_store_misses.walk_completed_4k\000\000virtual memory\000Page walks completed due to a demand data store to a 4K page\000event=0x49,period=100003,umask=0x2\000\00000\000Counts page walks completed due to demand data stores whose address translations missed in the TLB and were mapped to 4K pages.  The page walks can end with or without a page fault\000 */
{ 830031 }, /* dtlb_store_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for a store in the PMH each cycle\000event=0x49,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for a store in the PMH (Page Miss Handler) each cycle\000 */
{ 1082642 }, /* itlb_misses.stlb_hit\000\000virtual memory\000Instruction fetch requests that miss the ITLB and hit the STLB\000event=0x85,period=100003,umask=0x20\000\00000\000Counts instruction fetch requests that miss the ITLB (Instruction TLB) and hit the STLB (Second-level TLB)\000 */
{ 1085650 }, /* itlb_misses.walk_active\000\000virtual memory\000Cycles when at least one PMH is busy with a page walk for code (instruction fetch) request\000event=0x85,cmask=1,period=100003,umask=0x10\000\00000\000Counts cycles when at least one PMH (Page Miss Handler) is busy with a page walk for a code (instruction fetch) request\000 */
{ 1086630 }, /* itlb_misses.walk_completed\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (All page sizes)\000event=0x85,period=100003,umask=0xe\000\00000\000Counts completed page walks (all page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1091469 }, /* itlb_misses.walk_completed_2m_4m\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (2M/4M)\000event=0x85,period=100003,umask=0x4\000\00000\000Counts completed page walks (2M/4M page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1094284 }, /* itlb_misses.walk_completed_4k\000\000virtual memory\000Code miss in all TLB levels causes a page walk that completes. (4K)\000event=0x85,period=100003,umask=0x2\000\00000\000Counts completed page walks (4K page sizes) caused by a code fetch. This implies it missed in the ITLB (Instruction TLB) and further levels of TLB. The page walk can end with or without a fault\000 */
{ 1097779 }, /* itlb_misses.walk_pending\000\000virtual memory\000Number of page walks outstanding for an outstanding code request in the PMH each cycle\000event=0x85,period=100003,umask=0x10\000\00000\000Counts the number of page walks outstanding for an outstanding code (instruction fetch) request in the PMH (Page Miss Handler) each cycle\000 */
{ 2540313 }, /* tlb_flush.dtlb_thread\000\000virtual memory\000DTLB flush attempts of the thread-specific entries\000event=0xbd,period=100007,umask=0x1\000\00000\000Counts the number of DTLB flush attempts of the thread-specific entries\000 */
{ 2541294 }, /* tlb_flush.stlb_any\000\000virtual memory\000STLB flush attempts\000event=0xbd,period=100007,umask=0x20\000\00000\000Counts the number of any STLB flush attempts (such as entire, VPID, PCID, InvPage, CR3 write, etc.)\000 */
};

static const struct compact_pmu_event pmu_metrics__tigerlake[] = {
{ 3582 }, /* \000C10_Pkg_Residency\000Power\000cstate_pkg@c10\\-residency@ / TSC\000\000C10 residency percent per package\000\000100%\000\000\000\00000 */
{ 3786 }, /* \000C2_Pkg_Residency\000Power\000cstate_pkg@c2\\-residency@ / TSC\000\000C2 residency percent per package\000\000100%\000\000\000\00000 */
{ 3987 }, /* \000C3_Pkg_Residency\000Power\000cstate_pkg@c3\\-residency@ / TSC\000\000C3 residency percent per package\000\000100%\000\000\000\00000 */
{ 4088 }, /* \000C6_Core_Residency\000Power\000cstate_core@c6\\-residency@ / TSC\000\000C6 residency percent per core\000\000100%\000\000\000\00000 */
{ 4188 }, /* \000C6_Pkg_Residency\000Power\000cstate_pkg@c6\\-residency@ / TSC\000\000C6 residency percent per package\000\000100%\000\000\000\00000 */
{ 4289 }, /* \000C7_Core_Residency\000Power\000cstate_core@c7\\-residency@ / TSC\000\000C7 residency percent per core\000\000100%\000\000\000\00000 */
{ 4389 }, /* \000C7_Pkg_Residency\000Power\000cstate_pkg@c7\\-residency@ / TSC\000\000C7 residency percent per package\000\000100%\000\000\000\00000 */
{ 4490 }, /* \000C8_Pkg_Residency\000Power\000cstate_pkg@c8\\-residency@ / TSC\000\000C8 residency percent per package\000\000100%\000\000\000\00000 */
{ 4591 }, /* \000C9_Pkg_Residency\000Power\000cstate_pkg@c9\\-residency@ / TSC\000\000C9 residency percent per package\000\000100%\000\000\000\00000 */
{ 48515 }, /* \000smi_cycles\000smi\000((msr@aperf@ - cycles) / msr@aperf@ if msr@smi@ > 0 else 0)\000smi_cycles > 0.1\000Percentage of cycles spent in System Management Interrupts\000\000100%\000\000\000\00000 */
{ 48678 }, /* \000smi_num\000smi\000msr@smi@\000\000Number of SMI interrupts\000\0001SMI#\000\000\000\00000 */
{ 49378 }, /* \000tma_4k_aliasing\000TopdownL4;tma_L4_group;tma_l1_bound_group\000LD_BLOCKS_PARTIAL.ADDRESS_ALIAS / tma_info_thread_clks\000tma_4k_aliasing > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset\000This metric estimates how often memory load accesses were aliased by preceding stores (in program order) with a 4K address offset. False match is possible; which incur a few cycles load re-issue. However; the short re-issue duration is often hidden by the out-of-order core and HW optimizations; hence a user may safely ignore a high value of this metric unless it manages to propagate up into parent nodes of the hierarchy (e.g. to L1_Bound)\000100%\000\000\000\00000 */
{ 50452 }, /* \000tma_alu_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_0 + UOPS_DISPATCHED.PORT_1 + UOPS_DISPATCHED.PORT_5 + UOPS_DISPATCHED.PORT_6) / (4 * tma_info_core_core_clks)\000tma_alu_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution ports for ALU operations\000\000100%\000\000\000\00000 */
{ 53706 }, /* \000tma_assists\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000100 * ASSISTS.ANY / tma_info_thread_slots\000tma_assists > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists\000This metric estimates fraction of slots the CPU retired uops delivered by the Microcode_Sequencer as a result of Assists. Assists are long sequences of uops that are required in certain corner-cases for operations that cannot be handled natively by the execution pipeline. For example; when working with very small floating point values (so-called Denormals); the FP units are not set up to perform these operations natively. Instead; a sequence of instructions to perform the computation on the Denormals is injected into the pipeline. Since these microcode sequences might be dozens of uops long; Assists can be extremely deleterious to performance and they can be avoided in many cases. Sample with: ASSISTS.ANY\000100%\000\000\000\00000 */
{ 59207 }, /* \000tma_backend_bound\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-be\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 5 * cpu@INT_MISC.RECOVERY_CYCLES\\,cmask\\=1\\,edge@ / tma_info_thread_slots\000tma_backend_bound > 0.2\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend\000This category represents fraction of slots where no uops are being delivered due to a lack of required resources for accepting new uops in the Backend. Backend is the portion of the processor core where the out-of-order scheduler dispatches ready uops into their respective execution units; and once completed these uops get retired according to program order. For example; stalls due to data-cache misses or stalls due to the divider unit being overloaded are both categorized under Backend Bound. Backend Bound is further divided into two main categories: Memory Bound and Core Bound. Sample with: TOPDOWN.BACKEND_BOUND_SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 64724 }, /* \000tma_bad_speculation\000Default;TmaL1;TopdownL1;tma_L1_group\000max(1 - (tma_frontend_bound + tma_backend_bound + tma_retiring), 0)\000tma_bad_speculation > 0.15\000This category represents fraction of slots wasted due to incorrect speculations\000This category represents fraction of slots wasted due to incorrect speculations. This include slots used to issue uops that do not eventually get retired and slots for which the issue-pipeline was blocked due to recovery from earlier incorrect speculation. For example; wasted work due to miss-predicted branches are categorized under Bad Speculation category. Incorrect data speculation followed by Memory Ordering Nukes is another example\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 68110 }, /* \000tma_branch_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * BR_INST_RETIRED.ALL_BRANCHES / (tma_retiring * tma_info_thread_slots)\000tma_branch_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring branch instructions\000\000100%\000\000\000\00000 */
{ 69335 }, /* \000tma_branch_mispredicts\000BadSpec;BrMispredicts;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * tma_bad_speculation\000tma_branch_mispredicts > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction\000This metric represents fraction of slots the CPU has wasted due to Branch Misprediction.  These slots are either wasted by uops fetched from an incorrectly speculated program path; or stalls when the out-of-order part of the machine needs to recover its state from a speculative path. Sample with: BR_MISP_RETIRED.ALL_BRANCHES. Related metrics: tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000100%\000\000TopdownL2\000\00000 */
{ 73983 }, /* \000tma_branch_resteers\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group\000INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks + tma_unknown_branches\000tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers. Branch Resteers estimates the Frontend delay in fetching operations from corrected path; following all sorts of miss-predicted branches. For example; branchy code with lots of miss-predictions might get categorized under Branch Resteers. Note the value of this node may overlap with its siblings. Sample with: BR_MISP_RETIRED.ALL_BRANCHES\000100%\000\000\000\00000 */
{ 75737 }, /* \000tma_cisc\000TopdownL4;tma_L4_group;tma_microcode_sequencer_group\000max(0, tma_microcode_sequencer - tma_assists)\000tma_cisc > 0.1 & (tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1)\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction\000This metric estimates fraction of cycles the CPU retired uops originated from CISC (complex instruction set computer) instruction. A CISC instruction has multiple uops that are required to perform the instruction's functionality as in the case of read-modify-write as an example. Since these instructions require multiple uops they may or may not imply sub-optimal use of machine resources\000100%\000\000\000\00000 */
{ 77173 }, /* \000tma_clears_resteers\000BadSpec;MachineClears;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueMC\000(1 - BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT)) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_clears_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Machine Clears. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches\000100%\000\000\000\00000 */
{ 86309 }, /* \000tma_contested_accesses\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\000(49 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) + 48 * tma_info_system_average_frequency * MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_contested_accesses > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to contested accesses. Contested accesses occur when data written by one Logical Processor are read by another Logical Processor on a different Physical Core. Examples of contested accesses include synchronizations such as locks; true data sharing such as modified locked variables; and false sharing. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD;MEM_LOAD_L3_HIT_RETIRED.XSNP_MISS. Related metrics: tma_data_sharing, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 98081 }, /* \000tma_core_bound\000Backend;Compute;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000max(0, tma_backend_bound - tma_memory_bound)\000tma_core_bound > 0.1 & tma_backend_bound > 0.2\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck\000This metric represents fraction of slots where Core non-memory issues were of a bottleneck.  Shortage in hardware compute resources; or dependencies in software's instructions are both categorized under Core Bound. Hence it may indicate the machine ran out of an out-of-order resource; certain execution units are overloaded or dependencies in program's data- or instruction-flow are limiting the performance (e.g. FP-chained long-latency arithmetic operations)\000100%\000\000TopdownL2\000\00000 */
{ 111165 }, /* \000tma_data_sharing\000Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_l3_bound_group\00048 * tma_info_system_average_frequency * (MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD + MEM_LOAD_L3_HIT_RETIRED.XSNP_FWD * (1 - OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM / (OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HITM + OCR.DEMAND_DATA_RD.L3_HIT.SNOOP_HIT_WITH_FWD))) * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_data_sharing > 0.05 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses\000This metric estimates fraction of cycles while the memory subsystem was handling synchronizations due to data-sharing accesses. Data shared by multiple Logical Processors (even just read shared) may cause increased access latency due to cache coherency. Excessive data sharing can drastically harm multithreaded performance. Sample with: MEM_LOAD_L3_HIT_RETIRED.XSNP_NO_FWD. Related metrics: tma_contested_accesses, tma_false_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00001 */
{ 114219 }, /* \000tma_decoder0_alone\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_issueD0;tma_mite_group\000(cpu@INST_DECODED.DECODERS\\,cmask\\=1@ - cpu@INST_DECODED.DECODERS\\,cmask\\=2@) / tma_info_core_core_clks / 2\000tma_decoder0_alone > 0.1 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where decoder-0 was the only active decoder\000This metric represents fraction of cycles where decoder-0 was the only active decoder. Related metrics: tma_few_uops_instructions\000100%\000\000\000\00000 */
{ 116146 }, /* \000tma_divider\000TopdownL3;tma_L3_group;tma_core_bound_group\000ARITH.DIVIDER_ACTIVE / tma_info_thread_clks\000tma_divider > 0.2 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric represents fraction of cycles where the Divider unit was active\000This metric represents fraction of cycles where the Divider unit was active. Divide and square root instructions are performed by the Divider unit and can take considerably longer latency than integer or Floating Point addition; subtraction; or multiplication. Sample with: ARITH.DIVIDER_ACTIVE\000100%\000\000\000\00000 */
{ 122993 }, /* \000tma_dram_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000CYCLE_ACTIVITY.STALLS_L3_MISS / tma_info_thread_clks + (CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks - tma_l2_bound\000tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads\000This metric estimates how often the CPU was stalled on accesses to external memory (DRAM) by loads. Better caching can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_MISS_PS\000100%\000\000\000\00001 */
{ 124667 }, /* \000tma_dsb\000DSB;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.DSB_CYCLES_ANY - IDQ.DSB_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_dsb > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline\000This metric represents Core fraction of cycles in which CPU was likely limited due to DSB (decoded uop cache) fetch pipeline.  For example; inefficient utilization of the DSB cache structure or bank conflict when reading from it; are categorized here\000100%\000\000\000\00000 */
{ 127727 }, /* \000tma_dsb_switches\000DSBmiss;FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000DSB2MITE_SWITCHES.PENALTY_CYCLES / tma_info_thread_clks\000tma_dsb_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines\000This metric represents fraction of cycles the CPU was stalled due to switches from DSB to MITE pipelines. The DSB (decoded i-cache) is a Uop Cache where the front-end directly delivers Uops (micro operations) avoiding heavy x86 decoding. The DSB pipeline has shorter latency and delivered higher bandwidth than the MITE (legacy instruction decode pipeline). Switching between the two pipelines can cause penalties hence this metric measures the exposed penalty. Sample with: FRONTEND_RETIRED.DSB_MISS_PS. Related metrics: tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000\000\00000 */
{ 134887 }, /* \000tma_dtlb_load\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_l1_bound_group\000min(7 * cpu@DTLB_LOAD_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_LOAD_MISSES.WALK_ACTIVE, max(CYCLE_ACTIVITY.CYCLES_MEM_ANY - CYCLE_ACTIVITY.CYCLES_L1D_MISS, 0)) / tma_info_thread_clks\000tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses\000This metric roughly estimates the fraction of cycles where the Data TLB (DTLB) was missed by load accesses. TLBs (Translation Look-aside Buffers) are processor caches for recently used entries out of the Page Tables that are used to map virtual- to physical-addresses by the operating system. This metric approximates the potential delay of demand loads missing the first-level data TLB (assuming worst case scenario with back to back misses to different pages). This includes hitting in the second-level TLB (STLB) as well as performing a hardware page walk on an STLB miss. Sample with: MEM_INST_RETIRED.STLB_MISS_LOADS_PS. Related metrics: tma_dtlb_store, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 139263 }, /* \000tma_dtlb_store\000MemoryTLB;TopdownL4;tma_L4_group;tma_issueTLB;tma_store_bound_group\000(7 * cpu@DTLB_STORE_MISSES.STLB_HIT\\,cmask\\=1@ + DTLB_STORE_MISSES.WALK_ACTIVE) / tma_info_core_core_clks\000tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses\000This metric roughly estimates the fraction of cycles spent handling first-level data TLB store misses.  As with ordinary data caching; focus on improving data locality and reducing working-set size to reduce DTLB overhead.  Additionally; consider using profile-guided optimization (PGO) to collocate frequently-used data on the same page.  Try using larger page sizes for large amounts of frequently-used data. Sample with: MEM_INST_RETIRED.STLB_MISS_STORES_PS. Related metrics: tma_dtlb_load, tma_info_bottleneck_memory_data_tlbs\000100%\000\000\000\00000 */
{ 149292 }, /* \000tma_false_sharing\000DataSharing;Offcore;Snoop;TopdownL4;tma_L4_group;tma_issueSyncxn;tma_store_bound_group\00054 * tma_info_system_average_frequency * OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM / tma_info_thread_clks\000tma_false_sharing > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing\000This metric roughly estimates how often CPU was handling synchronizations due to False Sharing. False Sharing is a multithreading hiccup; where multiple Logical Processors contend on different data-elements mapped into the same cache line. Sample with: OCR.DEMAND_RFO.L3_HIT.SNOOP_HITM. Related metrics: tma_contested_accesses, tma_data_sharing, tma_machine_clears, tma_remote_cache\000100%\000\000\000\00000 */
{ 153696 }, /* \000tma_fb_full\000MemoryBW;TopdownL4;tma_L4_group;tma_issueBW;tma_issueSL;tma_issueSmSt;tma_l1_bound_group\000L1D_PEND_MISS.FB_FULL / tma_info_thread_clks\000tma_fb_full > 0.3\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed\000This metric does a *rough estimation* of how often L1D Fill Buffer unavailability limited additional L1D miss memory access requests to proceed. The higher the metric value; the deeper the memory hierarchy level the misses are satisfied from (metric values >1 are valid). Often it hints on approaching bandwidth limits (to L2 cache; L3 cache or external memory). Related metrics: tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full, tma_store_latency, tma_streaming_stores\000100%\000\000\000\00000 */
{ 158121 }, /* \000tma_fetch_bandwidth\000FetchBW;Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group;tma_issueFB\000max(0, tma_frontend_bound - tma_fetch_latency)\000tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues\000This metric represents fraction of slots the CPU was stalled due to Frontend bandwidth issues.  For example; inefficiencies at the instruction decoders; or restrictions for caching in the DSB (decoded uops cache) are categorized under Fetch Bandwidth. In such cases; the Frontend typically delivers suboptimal amount of uops to the Backend. Sample with: FRONTEND_RETIRED.LATENCY_GE_2_BUBBLES_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_1_PS;FRONTEND_RETIRED.LATENCY_GE_2_PS. Related metrics: tma_dsb_switches, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000100%\000\000TopdownL2\000\00000 */
{ 163606 }, /* \000tma_fetch_latency\000Frontend;TmaL2;TopdownL2;tma_L2_group;tma_frontend_bound_group\000(5 * IDQ_UOPS_NOT_DELIVERED.CYCLES_0_UOPS_DELIV.CORE - INT_MISC.UOP_DROPPING) / tma_info_thread_slots\000tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues\000This metric represents fraction of slots the CPU was stalled due to Frontend latency issues.  For example; instruction-cache misses; iTLB misses or fetch stalls after a branch misprediction are categorized under Frontend Latency. In such cases; the Frontend eventually delivers no uops for some period. Sample with: FRONTEND_RETIRED.LATENCY_GE_16_PS;FRONTEND_RETIRED.LATENCY_GE_8_PS\000100%\000\000TopdownL2\000\00000 */
{ 167347 }, /* \000tma_few_uops_instructions\000TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueD0\000tma_heavy_operations - tma_microcode_sequencer\000tma_few_uops_instructions > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops\000This metric represents fraction of slots where the CPU was retiring instructions that that are decoder into two or up to ([SNB+] four; [ADL+] five) uops. This highly-correlates with the number of uops in such instructions. Related metrics: tma_decoder0_alone\000100%\000\000\000\00000 */
{ 169632 }, /* \000tma_fp_arith\000HPC;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_x87_use + tma_fp_scalar + tma_fp_vector\000tma_fp_arith > 0.2 & tma_light_operations > 0.6\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired)\000This metric represents overall arithmetic floating-point (FP) operations fraction the CPU has executed (retired). Note this metric's value may exceed its parent due to use of \"Uops\" CountDomain and FMA double-counting\000100%\000\000\000\00001 */
{ 172771 }, /* \000tma_fp_scalar\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_scalar > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired\000This metric approximates arithmetic floating-point (FP) scalar uops fraction the CPU has retired. May overcount due to FMA double counting. Related metrics: tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 177787 }, /* \000tma_fp_vector\000Compute;Flops;TopdownL4;tma_L4_group;tma_fp_arith_group;tma_issue2P\000cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@ / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths\000This metric approximates arithmetic floating-point (FP) vector uops fraction the CPU has retired aggregated across all vector widths. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 180064 }, /* \000tma_fp_vector_128b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_128b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 128-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 182343 }, /* \000tma_fp_vector_256b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_256b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 256-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 184622 }, /* \000tma_fp_vector_512b\000Compute;Flops;TopdownL5;tma_L5_group;tma_fp_vector_group;tma_issue2P\000(FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / (tma_retiring * tma_info_thread_slots)\000tma_fp_vector_512b > 0.1 & (tma_fp_vector > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6))\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors\000This metric approximates arithmetic FP vector uops fraction the CPU has retired for 512-bit wide vectors. May overcount due to FMA double counting. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_port_0, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 186270 }, /* \000tma_frontend_bound\000Default;PGO;TmaL1;TopdownL1;tma_L1_group\000topdown\\-fe\\-bound / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) - INT_MISC.UOP_DROPPING / tma_info_thread_slots\000tma_frontend_bound > 0.15\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend\000This category represents fraction of slots where the processor's Frontend undersupplies its Backend. Frontend denotes the first part of the processor core responsible to fetch operations that are executed later on by the Backend part. Within the Frontend; a branch predictor predicts the next address to fetch; cache-lines are fetched from the memory subsystem; parsed into instructions; and lastly decoded into micro-operations (uops). Ideally the Frontend can issue Pipeline_Width uops every cycle to the Backend. Frontend Bound denotes unutilized issue-slots when there is no Backend stall; i.e. bubbles where Frontend delivered no uops while Backend could have accepted them. For example; stalls due to instruction-cache misses would be categorized under Frontend Bound. Sample with: FRONTEND_RETIRED.LATENCY_GE_4_PS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 192366 }, /* \000tma_heavy_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000tma_microcode_sequencer + tma_retiring * (UOPS_DECODED.DEC0 - cpu@UOPS_DECODED.DEC0\\,cmask\\=1@) / IDQ.MITE_UOPS\000tma_heavy_operations > 0.1\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences\000This metric represents fraction of slots where the CPU was retiring heavy-weight operations -- instructions that require two or more uops or micro-coded sequences. This highly-correlates with the uop length of these instructions/sequences\000100%\000\000TopdownL2\000\00000 */
{ 195231 }, /* \000tma_icache_misses\000BigFoot;FetchLat;IcMiss;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_16B.IFDATA_STALL / tma_info_thread_clks\000tma_icache_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses\000This metric represents fraction of cycles the CPU was stalled due to instruction cache misses. Sample with: FRONTEND_RETIRED.L2_MISS_PS;FRONTEND_RETIRED.L1I_MISS_PS\000100%\000\000\000\00000 */
{ 197105 }, /* \000tma_info_bad_spec_branch_misprediction_cost\000Bad;BrMispredicts;tma_issueBM\000(tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) * tma_info_thread_slots / BR_MISP_RETIRED.ALL_BRANCHES\000\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear)\000Branch Misprediction Cost: Fraction of TMA slots wasted per non-speculative branch misprediction (retired JEClear). Related metrics: tma_branch_mispredicts, tma_info_bottleneck_mispredictions, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 198371 }, /* \000tma_info_bad_spec_ipmisp_cond_ntaken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_NTAKEN\000tma_info_bad_spec_ipmisp_cond_ntaken < 200\000Instructions per retired mispredicts for conditional non-taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198640 }, /* \000tma_info_bad_spec_ipmisp_cond_taken\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.COND_TAKEN\000tma_info_bad_spec_ipmisp_cond_taken < 200\000Instructions per retired mispredicts for conditional taken branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 198902 }, /* \000tma_info_bad_spec_ipmisp_indirect\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.INDIRECT\000tma_info_bad_spec_ipmisp_indirect < 1e3\000Instructions per retired mispredicts for indirect CALL or JMP branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199501 }, /* \000tma_info_bad_spec_ipmisp_ret\000Bad;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.RET\000tma_info_bad_spec_ipmisp_ret < 500\000Instructions per retired mispredicts for return branches (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 199731 }, /* \000tma_info_bad_spec_ipmispredict\000Bad;BadSpec;BrMispredicts\000INST_RETIRED.ANY / BR_MISP_RETIRED.ALL_BRANCHES\000tma_info_bad_spec_ipmispredict < 200\000Number of Instructions per non-speculative Branch Misprediction (JEClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 200246 }, /* \000tma_info_botlnk_l0_core_bound_likely\000Cor;SMT\000(100 * (1 - tma_core_bound / tma_ports_utilization if tma_core_bound < tma_ports_utilization else 1) if tma_info_system_smt_2t_utilization > 0.5 else 0)\000tma_info_botlnk_l0_core_bound_likely > 0.5\000Probability of Core Bound bottleneck hidden by SMT-profiling artifacts\000\000\000\000\000\00001 */
{ 200566 }, /* \000tma_info_botlnk_l2_dsb_misses\000DSBmiss;Fed;tma_issueFB\000100 * (tma_fetch_latency * tma_dsb_switches / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches) + tma_fetch_bandwidth * tma_mite / (tma_dsb + tma_lsd + tma_mite))\000tma_info_botlnk_l2_dsb_misses > 10\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck\000Total pipeline cost of DSB (uop cache) misses - subset of the Instruction_Fetch_BW Bottleneck. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00001 */
{ 201806 }, /* \000tma_info_botlnk_l2_ic_misses\000Fed;FetchLat;IcMiss;tma_issueFL\000100 * (tma_fetch_latency * tma_icache_misses / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_botlnk_l2_ic_misses > 5\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck\000Total pipeline cost of Instruction Cache misses - subset of the Big_Code Bottleneck. Related metrics: \000\000\000\000\00000 */
{ 202249 }, /* \000tma_info_bottleneck_big_code\000BigFoot;Fed;Frontend;IcMiss;MemoryTLB;tma_issueBC\000100 * tma_fetch_latency * (tma_itlb_misses + tma_icache_misses + tma_unknown_branches) / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)\000tma_info_bottleneck_big_code > 20\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses)\000Total pipeline cost of instruction fetch related bottlenecks by large code footprint programs (i-side cache; TLB and BTB misses). Related metrics: tma_info_bottleneck_branching_overhead\000\000\000\000\00001 */
{ 202880 }, /* \000tma_info_bottleneck_branching_overhead\000Ret;tma_issueBC\000100 * ((BR_INST_RETIRED.COND + 3 * BR_INST_RETIRED.NEAR_CALL + (BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL)) / tma_info_thread_slots)\000tma_info_bottleneck_branching_overhead > 10\000Total pipeline cost of branch related instructions (used for program control-flow including function calls)\000Total pipeline cost of branch related instructions (used for program control-flow including function calls). Related metrics: tma_info_bottleneck_big_code\000\000\000\000\00000 */
{ 204014 }, /* \000tma_info_bottleneck_instruction_fetch_bw\000Fed;FetchBW;Frontend\000100 * (tma_frontend_bound - tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches)) - tma_info_bottleneck_big_code\000tma_info_bottleneck_instruction_fetch_bw > 20\000Total pipeline cost of instruction fetch bandwidth related bottlenecks\000\000\000\000\000\00001 */
{ 207397 }, /* \000tma_info_bottleneck_memory_bandwidth\000Mem;MemoryBW;Offcore;tma_issueBW\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_bandwidth / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_sq_full / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full))) + tma_l1_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_fb_full / (tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk))\000tma_info_bottleneck_memory_bandwidth > 20\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks\000Total pipeline cost of (external) Memory Bandwidth related bottlenecks. Related metrics: tma_fb_full, tma_info_system_dram_bw_use, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 211900 }, /* \000tma_info_bottleneck_memory_data_tlbs\000Mem;MemoryTLB;Offcore;tma_issueTLB\000100 * tma_memory_bound * (tma_l1_bound / max(tma_memory_bound, tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_load / max(tma_l1_bound, tma_4k_aliasing + tma_dtlb_load + tma_fb_full + tma_lock_latency + tma_split_loads + tma_store_fwd_blk)) + tma_store_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_dtlb_store / (tma_dtlb_store + tma_false_sharing + tma_split_stores + tma_store_latency + tma_streaming_stores)))\000tma_info_bottleneck_memory_data_tlbs > 20\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs)\000Total pipeline cost of Memory Address Translation related bottlenecks (data-side TLBs). Related metrics: tma_dtlb_load, tma_dtlb_store\000\000\000\000\00001 */
{ 214466 }, /* \000tma_info_bottleneck_memory_latency\000Mem;MemoryLat;Offcore;tma_issueLat\000100 * tma_memory_bound * (tma_dram_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_mem_latency / (tma_mem_bandwidth + tma_mem_latency)) + tma_l3_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound) * (tma_l3_hit_latency / (tma_contested_accesses + tma_data_sharing + tma_l3_hit_latency + tma_sq_full)) + tma_l2_bound / (tma_dram_bound + tma_l1_bound + tma_l2_bound + tma_l3_bound + tma_store_bound))\000tma_info_bottleneck_memory_latency > 20\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches)\000Total pipeline cost of Memory Latency related bottlenecks (external memory and off-core caches). Related metrics: tma_l3_hit_latency, tma_mem_latency\000\000\000\000\00001 */
{ 215311 }, /* \000tma_info_bottleneck_mispredictions\000Bad;BadSpec;BrMispredicts;tma_issueBM\000100 * (tma_branch_mispredicts + tma_fetch_latency * tma_mispredicts_resteers / (tma_branch_resteers + tma_dsb_switches + tma_icache_misses + tma_itlb_misses + tma_lcp + tma_ms_switches))\000tma_info_bottleneck_mispredictions > 20\000Total pipeline cost of Branch Misprediction related bottlenecks\000Total pipeline cost of Branch Misprediction related bottlenecks. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_mispredicts_resteers\000\000\000\000\00001 */
{ 215858 }, /* \000tma_info_branches_callret\000Bad;Branches\000(BR_INST_RETIRED.NEAR_CALL + BR_INST_RETIRED.NEAR_RETURN) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are CALL or RET\000\000\000\000\000\00000 */
{ 216037 }, /* \000tma_info_branches_cond_nt\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_NTAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are non-taken conditionals\000\000\000\000\000\00000 */
{ 216577 }, /* \000tma_info_branches_cond_tk\000Bad;Branches;CodeGen;PGO\000BR_INST_RETIRED.COND_TAKEN / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are taken conditionals\000\000\000\000\000\00000 */
{ 217012 }, /* \000tma_info_branches_jump\000Bad;Branches\000(BR_INST_RETIRED.NEAR_TAKEN - BR_INST_RETIRED.COND_TAKEN - 2 * BR_INST_RETIRED.NEAR_CALL) / BR_INST_RETIRED.ALL_BRANCHES\000\000Fraction of branches that are unconditional (direct or indirect) jumps\000\000\000\000\000\00000 */
{ 217249 }, /* \000tma_info_branches_other_branches\000Bad;Branches\0001 - (tma_info_branches_cond_nt + tma_info_branches_cond_tk + tma_info_branches_callret + tma_info_branches_jump)\000\000Fraction of branches of other types (not individually covered by other metrics in Info.Branches group)\000\000\000\000\000\00000 */
{ 217937 }, /* \000tma_info_core_core_clks\000SMT\000CPU_CLK_UNHALTED.DISTRIBUTED\000\000Core actual clocks when any Logical Processor is active on the Physical Core\000\000\000\000\000\00000 */
{ 218080 }, /* \000tma_info_core_coreipc\000Ret;SMT;TmaL1;tma_L1_group\000INST_RETIRED.ANY / tma_info_core_core_clks\000\000Instructions Per Cycle across hyper-threads (per physical core)\000\000\000\000\000\00000 */
{ 219831 }, /* \000tma_info_core_flopc\000Flops;Ret\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / tma_info_core_core_clks\000\000Floating Point Operations Per Cycle\000\000\000\000\000\00001 */
{ 222547 }, /* \000tma_info_core_fp_arith_utilization\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@) / (2 * tma_info_core_core_clks)\000\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width)\000Actual per-core usage of the Floating Point non-X87 execution units (regardless of precision or vector-width). Values > 1 are possible due to ([BDW+] Fused-Multiply Add (FMA) counting - common; [ADL+] use all of ADD/MUL/FMA in Scalar or 128/256-bit vectors - less common)\000\000\000\000\00001 */
{ 223808 }, /* \000tma_info_core_ilp\000Backend;Cor;Pipeline;PortsUtil\000UOPS_EXECUTED.THREAD / (UOPS_EXECUTED.CORE_CYCLES_GE_1 / 2 if #SMT_on else UOPS_EXECUTED.CORE_CYCLES_GE_1)\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-core\000\000\000\000\000\00000 */
{ 226105 }, /* \000tma_info_frontend_dsb_coverage\000DSB;Fed;FetchBW;tma_issueFB\000IDQ.DSB_UOPS / UOPS_ISSUED.ANY\000tma_info_frontend_dsb_coverage < 0.7 & tma_info_thread_ipc / 5 > 0.35\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache)\000Fraction of Uops delivered by the DSB (aka Decoded ICache; or Uop Cache). Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_inst_mix_iptb, tma_lcp\000\000\000\000\00000 */
{ 227202 }, /* \000tma_info_frontend_dsb_switch_cost\000DSBmiss\000DSB2MITE_SWITCHES.PENALTY_CYCLES / cpu@DSB2MITE_SWITCHES.PENALTY_CYCLES\\,cmask\\=1\\,edge@\000\000Average number of cycles of a switch from the DSB fetch-unit to MITE fetch unit - see DSB_Switches tree node for details\000\000\000\000\000\00000 */
{ 227463 }, /* \000tma_info_frontend_fetch_upc\000Fed;FetchBW\000UOPS_ISSUED.ANY / cpu@UOPS_ISSUED.ANY\\,cmask\\=1@\000\000Average number of Uops issued by front-end when it issued something\000\000\000\000\000\00000 */
{ 227819 }, /* \000tma_info_frontend_icache_miss_latency\000Fed;FetchLat;IcMiss\000ICACHE_16B.IFDATA_STALL / cpu@ICACHE_16B.IFDATA_STALL\\,cmask\\=1\\,edge@\000\000Average Latency for L1 instruction cache misses\000\000\000\000\000\00000 */
{ 228700 }, /* \000tma_info_frontend_ipdsb_miss_ret\000DSBmiss;Fed\000INST_RETIRED.ANY / FRONTEND_RETIRED.ANY_DSB_MISS\000tma_info_frontend_ipdsb_miss_ret < 50\000Instructions per non-speculative DSB miss (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 228926 }, /* \000tma_info_frontend_ipunknown_branch\000Fed\000tma_info_inst_mix_instructions / BACLEARS.ANY\000\000Instructions per speculative Unknown Branch Misprediction (BAClear) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 229132 }, /* \000tma_info_frontend_l2mpki_code\000IcMiss\0001e3 * FRONTEND_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229285 }, /* \000tma_info_frontend_l2mpki_code_all\000IcMiss\0001e3 * L2_RQSTS.CODE_RD_MISS / INST_RETIRED.ANY\000\000L2 cache speculative code cacheline misses per kilo instruction\000\000\000\000\000\00000 */
{ 229446 }, /* \000tma_info_frontend_lsd_coverage\000Fed;LSD\000LSD.UOPS / UOPS_ISSUED.ANY\000\000Fraction of Uops delivered by the LSD (Loop Stream Detector; aka Loop Cache)\000\000\000\000\000\00000 */
{ 229598 }, /* \000tma_info_inst_mix_bptkbranch\000Branches;Fed;PGO\000BR_INST_RETIRED.ALL_BRANCHES / BR_INST_RETIRED.NEAR_TAKEN\000\000Branch instructions per taken branch\000\000\000\000\000\00000 */
{ 230331 }, /* \000tma_info_inst_mix_instructions\000Summary;TmaL1;tma_L1_group\000INST_RETIRED.ANY\000\000Total number of retired Instructions\000Total number of retired Instructions. Sample with: INST_RETIRED.PREC_DIST\000\000\000\000\00000 */
{ 232323 }, /* \000tma_info_inst_mix_iparith\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + cpu@FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE\\,umask\\=0xfc@)\000tma_info_inst_mix_iparith < 10\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic instruction (lower number means higher occurrence rate). May undercount due to FMA double counting. Approximated prior to BDW\000\000\000\000\00000 */
{ 234529 }, /* \000tma_info_inst_mix_iparith_avx128\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx128 < 10\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX/SSE 128-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 235475 }, /* \000tma_info_inst_mix_iparith_avx256\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.256B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx256 < 10\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX* 256-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236413 }, /* \000tma_info_inst_mix_iparith_avx512\000Flops;FpVector;InsType\000INST_RETIRED.ANY / (FP_ARITH_INST_RETIRED.512B_PACKED_DOUBLE + FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_iparith_avx512 < 10\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic AVX 512-bit instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 236860 }, /* \000tma_info_inst_mix_iparith_scalar_dp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_DOUBLE\000tma_info_inst_mix_iparith_scalar_dp < 10\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Double-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237287 }, /* \000tma_info_inst_mix_iparith_scalar_sp\000Flops;FpScalar;InsType\000INST_RETIRED.ANY / FP_ARITH_INST_RETIRED.SCALAR_SINGLE\000tma_info_inst_mix_iparith_scalar_sp < 10\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate)\000Instructions per FP Arithmetic Scalar Single-Precision instruction (lower number means higher occurrence rate). May undercount due to FMA double counting\000\000\000\000\00000 */
{ 237714 }, /* \000tma_info_inst_mix_ipbranch\000Branches;Fed;InsType\000INST_RETIRED.ANY / BR_INST_RETIRED.ALL_BRANCHES\000tma_info_inst_mix_ipbranch < 8\000Instructions per Branch (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 238069 }, /* \000tma_info_inst_mix_ipcall\000Branches;Fed;PGO\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_CALL\000tma_info_inst_mix_ipcall < 200\000Instructions per (near) call (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 239974 }, /* \000tma_info_inst_mix_ipflop\000Flops;InsType\000INST_RETIRED.ANY / (cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE)\000tma_info_inst_mix_ipflop < 10\000Instructions per Floating Point (FP) Operation (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 240649 }, /* \000tma_info_inst_mix_ipload\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_LOADS\000tma_info_inst_mix_ipload < 3\000Instructions per Load (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 241925 }, /* \000tma_info_inst_mix_ipstore\000InsType\000INST_RETIRED.ANY / MEM_INST_RETIRED.ALL_STORES\000tma_info_inst_mix_ipstore < 8\000Instructions per Store (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242403 }, /* \000tma_info_inst_mix_ipswpf\000Prefetches\000INST_RETIRED.ANY / cpu@SW_PREFETCH_ACCESS.T0\\,umask\\=0xF@\000tma_info_inst_mix_ipswpf < 100\000Instructions per Software prefetch instruction (of any type: NTA/T0/T1/T2/Prefetch) (lower number means higher occurrence rate)\000\000\000\000\000\00000 */
{ 242664 }, /* \000tma_info_inst_mix_iptb\000Branches;Fed;FetchBW;Frontend;PGO;tma_issueFB\000INST_RETIRED.ANY / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_inst_mix_iptb < 11\000Instruction per taken branch\000Instruction per taken branch. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_lcp\000\000\000\000\00000 */
{ 244767 }, /* \000tma_info_memory_core_l1d_cache_fill_bw\000Mem;MemoryBW\00064 * L1D.REPLACEMENT / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 244940 }, /* \000tma_info_memory_core_l2_cache_fill_bw\000Mem;MemoryBW\00064 * L2_LINES_IN.ALL / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245579 }, /* \000tma_info_memory_core_l3_cache_access_bw\000Mem;MemoryBW;Offcore\00064 * OFFCORE_REQUESTS.ALL_REQUESTS / 1e9 / duration_time\000\000Average per-core data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 245772 }, /* \000tma_info_memory_core_l3_cache_fill_bw\000Mem;MemoryBW\00064 * LONGEST_LAT_CACHE.MISS / 1e9 / duration_time\000\000Average per-core data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 246370 }, /* \000tma_info_memory_fb_hpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.FB_HIT / INST_RETIRED.ANY\000\000Fill Buffer (FB) hits per kilo instructions for retired demand loads (L1D misses that merge into ongoing miss-handling entries)\000\000\000\000\000\00000 */
{ 246596 }, /* \000tma_info_memory_l1mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L1_MISS / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 246931 }, /* \000tma_info_memory_l1mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.ALL_DEMAND_DATA_RD / INST_RETIRED.ANY\000\000L1 cache true misses per kilo instruction for all demand loads (including speculative)\000\000\000\000\000\00000 */
{ 247124 }, /* \000tma_info_memory_l2hpki_all\000CacheMisses;Mem\0001e3 * (L2_RQSTS.REFERENCES - L2_RQSTS.MISS) / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 247320 }, /* \000tma_info_memory_l2hpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_HIT / INST_RETIRED.ANY\000\000L2 cache hits per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 247507 }, /* \000tma_info_memory_l2mpki\000Backend;CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L2_MISS / INST_RETIRED.ANY\000\000L2 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 248167 }, /* \000tma_info_memory_l2mpki_all\000CacheMisses;Mem;Offcore\0001e3 * L2_RQSTS.MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all request types (including speculative)\000\000\000\000\000\00000 */
{ 248363 }, /* \000tma_info_memory_l2mpki_load\000CacheMisses;Mem\0001e3 * L2_RQSTS.DEMAND_DATA_RD_MISS / INST_RETIRED.ANY\000\000L2 cache ([RKL+] true) misses per kilo instruction for all demand loads  (including speculative)\000\000\000\000\000\00000 */
{ 248567 }, /* \000tma_info_memory_l3mpki\000CacheMisses;Mem\0001e3 * MEM_LOAD_RETIRED.L3_MISS / INST_RETIRED.ANY\000\000L3 cache true misses per kilo instruction for retired demand loads\000\000\000\000\000\00000 */
{ 249073 }, /* \000tma_info_memory_load_miss_real_latency\000Mem;MemoryBound;MemoryLat\000L1D_PEND_MISS.PENDING / (MEM_LOAD_RETIRED.L1_MISS + MEM_LOAD_RETIRED.FB_HIT)\000\000Actual Average Latency for L1 data-cache miss demand load operations (in core cycles)\000\000\000\000\000\00000 */
{ 249900 }, /* \000tma_info_memory_mlp\000Mem;MemoryBW;MemoryBound\000L1D_PEND_MISS.PENDING / L1D_PEND_MISS.PENDING_CYCLES\000\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss\000Memory-Level-Parallelism (average number of L1 miss demand load when there is at least one such miss. Per-Logical Processor)\000\000\000\000\00000 */
{ 250564 }, /* \000tma_info_memory_oro_data_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD / OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD\000\000Average Parallel L2 cache miss data reads\000\000\000\000\000\00000 */
{ 250757 }, /* \000tma_info_memory_oro_load_l2_miss_latency\000Memory_Lat;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / OFFCORE_REQUESTS.DEMAND_DATA_RD\000\000Average Latency for L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251156 }, /* \000tma_info_memory_oro_load_l2_mlp\000Memory_BW;Offcore\000OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD / cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,cmask\\=1@\000\000Average Parallel L2 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251574 }, /* \000tma_info_memory_oro_load_l3_miss_latency\000Memory_Lat;Offcore\000cpu@OFFCORE_REQUESTS_OUTSTANDING.DEMAND_DATA_RD\\,umask\\=0x10@ / OFFCORE_REQUESTS.L3_MISS_DEMAND_DATA_RD\000\000Average Latency for L3 cache miss demand Loads\000\000\000\000\000\00000 */
{ 251794 }, /* \000tma_info_memory_thread_l1d_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l1d_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L1 data cache [GB / sec]\000\000\000\000\000\00000 */
{ 251970 }, /* \000tma_info_memory_thread_l2_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l2_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L2 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252284 }, /* \000tma_info_memory_thread_l3_cache_access_bw_1t\000Mem;MemoryBW;Offcore\000tma_info_memory_core_l3_cache_access_bw\000\000Average per-thread data access bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252467 }, /* \000tma_info_memory_thread_l3_cache_fill_bw_1t\000Mem;MemoryBW\000tma_info_memory_core_l3_cache_fill_bw\000\000Average per-thread data fill bandwidth to the L3 cache [GB / sec]\000\000\000\000\000\00000 */
{ 252636 }, /* \000tma_info_memory_tlb_code_stlb_mpki\000Fed;MemoryTLB\0001e3 * ITLB_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) code speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 252866 }, /* \000tma_info_memory_tlb_load_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_LOAD_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data load speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 254261 }, /* \000tma_info_memory_tlb_page_walks_utilization\000Mem;MemoryTLB\000(ITLB_MISSES.WALK_PENDING + DTLB_LOAD_MISSES.WALK_PENDING + DTLB_STORE_MISSES.WALK_PENDING) / (2 * tma_info_core_core_clks)\000tma_info_memory_tlb_page_walks_utilization > 0.5\000Utilization of the core's Page Walker(s) serving STLB misses triggered by instruction/Load/Store accesses\000\000\000\000\000\00000 */
{ 255439 }, /* \000tma_info_memory_tlb_store_stlb_mpki\000Mem;MemoryTLB\0001e3 * DTLB_STORE_MISSES.WALK_COMPLETED / INST_RETIRED.ANY\000\000STLB (2nd level TLB) data store speculative misses per kilo instruction (misses of any page-size that complete the page walk)\000\000\000\000\000\00000 */
{ 255682 }, /* \000tma_info_pipeline_execute\000Cor;Pipeline;PortsUtil;SMT\000UOPS_EXECUTED.THREAD / cpu@UOPS_EXECUTED.THREAD\\,cmask\\=1@\000\000Instruction-Level-Parallelism (average number of uops executed when there is execution) per-thread\000\000\000\000\000\00000 */
{ 256405 }, /* \000tma_info_pipeline_retire\000Pipeline;Ret\000tma_retiring * tma_info_thread_slots / cpu@UOPS_RETIRED.SLOTS\\,cmask\\=1@\000\000Average number of Uops retired in cycles where at least one uop has retired\000\000\000\000\000\00001 */
{ 256830 }, /* \000tma_info_system_average_frequency\000Power;Summary\000tma_info_system_turbo_utilization * TSC / 1e9 / duration_time\000\000Measured Average Frequency for unhalted processors [GHz]\000\000\000\000\000\00000 */
{ 257006 }, /* \000tma_info_system_cpu_utilization\000HPC;Summary\000CPU_CLK_UNHALTED.REF_TSC / TSC\000\000Average CPU Utilization\000\000\000\000\000\00000 */
{ 259341 }, /* \000tma_info_system_dram_bw_use\000HPC;Mem;MemoryBW;SoC;tma_issueBW\00064 * (arb@event\\=0x81\\,umask\\=0x1@ + arb@event\\=0x84\\,umask\\=0x1@) / 1e6 / duration_time / 1e3\000\000Average external Memory Bandwidth Use for reads and writes [GB / sec]\000Average external Memory Bandwidth Use for reads and writes [GB / sec]. Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_mem_bandwidth, tma_sq_full\000\000\000\000\00000 */
{ 262284 }, /* \000tma_info_system_gflops\000Cor;Flops;HPC\000(cpu@FP_ARITH_INST_RETIRED.SCALAR_SINGLE\\,umask\\=0x03@ + 2 * FP_ARITH_INST_RETIRED.128B_PACKED_DOUBLE + 4 * cpu@FP_ARITH_INST_RETIRED.128B_PACKED_SINGLE\\,umask\\=0x18@ + 8 * cpu@FP_ARITH_INST_RETIRED.256B_PACKED_SINGLE\\,umask\\=0x60@ + 16 * FP_ARITH_INST_RETIRED.512B_PACKED_SINGLE) / 1e9 / duration_time\000\000Giga Floating Point Operations Per Second\000Giga Floating Point Operations Per Second. Aggregate across all supported options of: FP precisions, scalar and vector instructions, vector-width and AMX engine\000\000\000\000\00000 */
{ 264229 }, /* \000tma_info_system_ipfarbranch\000Branches;OS\000INST_RETIRED.ANY / BR_INST_RETIRED.FAR_BRANCH:u\000tma_info_system_ipfarbranch < 1e6\000Instructions per Far Branch ( Far Branches apply upon transition from application to operating system, handling interrupts, exceptions) [lower number means higher occurrence rate]\000\000\000\000\000\00000 */
{ 264539 }, /* \000tma_info_system_kernel_cpi\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / INST_RETIRED.ANY_P:k\000\000Cycles Per Instruction for the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 264694 }, /* \000tma_info_system_kernel_utilization\000OS\000CPU_CLK_UNHALTED.THREAD_P:k / CPU_CLK_UNHALTED.THREAD\000tma_info_system_kernel_utilization > 0.05\000Fraction of cycles spent in the Operating System (OS) Kernel mode\000\000\000\000\000\00000 */
{ 266184 }, /* \000tma_info_system_mem_parallel_reads\000Mem;MemoryBW;SoC\000UNC_ARB_DAT_OCCUPANCY.RD / UNC_ARB_DAT_OCCUPANCY.RD@cmask\\=1@\000\000Average number of parallel data read requests to external memory\000Average number of parallel data read requests to external memory. Accounts for demand loads and L1/L2 prefetches\000\000\000\000\00000 */
{ 269302 }, /* \000tma_info_system_mem_read_latency\000Mem;MemoryLat;SoC\000(UNC_ARB_TRK_OCCUPANCY.RD + UNC_ARB_DAT_OCCUPANCY.RD) / UNC_ARB_TRK_REQUESTS.RD\000\000Average latency of data read request to external memory (in nanoseconds)\000Average latency of data read request to external memory (in nanoseconds). Accounts for demand loads and L1/L2 prefetches. ([RKL+]memory-controller only)\000\000\000\000\00000 */
{ 271130 }, /* \000tma_info_system_mem_request_latency\000Mem;SoC\000(UNC_ARB_TRK_OCCUPANCY.ALL + UNC_ARB_DAT_OCCUPANCY.RD) / arb@event\\=0x81\\,umask\\=0x1@\000\000Average latency of all requests to external memory (in Uncore cycles)\000\000\000\000\000\00000 */
{ 272373 }, /* \000tma_info_system_power_license0_utilization\000Power\000CORE_POWER.LVL0_TURBO_LICENSE / tma_info_core_core_clks\000\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0\000Fraction of Core cycles where the core was running with power-delivery for baseline license level 0.  This includes non-AVX codes, SSE, AVX 128-bit, and low-current AVX 256-bit codes\000\000\000\000\00000 */
{ 273292 }, /* \000tma_info_system_power_license1_utilization\000Power\000CORE_POWER.LVL1_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license1_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 1\000Fraction of Core cycles where the core was running with power-delivery for license level 1.  This includes high current AVX 256-bit instructions as well as low current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274252 }, /* \000tma_info_system_power_license2_utilization\000Power\000CORE_POWER.LVL2_TURBO_LICENSE / tma_info_core_core_clks\000tma_info_system_power_license2_utilization > 0.5\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX)\000Fraction of Core cycles where the core was running with power-delivery for license level 2 (introduced in SKX).  This includes high current AVX 512-bit instructions\000\000\000\000\00000 */
{ 274904 }, /* \000tma_info_system_smt_2t_utilization\000SMT\000(1 - CPU_CLK_UNHALTED.ONE_THREAD_ACTIVE / CPU_CLK_UNHALTED.REF_DISTRIBUTED if #SMT_on else 0)\000\000Fraction of cycles where both hardware Logical Processors were active\000\000\000\000\000\00000 */
{ 275899 }, /* \000tma_info_system_turbo_utilization\000Power\000tma_info_thread_clks / CPU_CLK_UNHALTED.REF_TSC\000\000Average Frequency Utilization relative nominal frequency\000\000\000\000\000\00000 */
{ 276244 }, /* \000tma_info_thread_clks\000Pipeline\000CPU_CLK_UNHALTED.THREAD\000\000Per-Logical Processor actual clocks when the Logical Processor is active\000\000\000\000\000\00000 */
{ 276380 }, /* \000tma_info_thread_cpi\000Mem;Pipeline\0001 / tma_info_thread_ipc\000\000Cycles Per Instruction (per Logical Processor)\000\000\000\000\000\00000 */
{ 276774 }, /* \000tma_info_thread_execute_per_issue\000Cor;Pipeline\000UOPS_EXECUTED.THREAD / UOPS_ISSUED.ANY\000\000The ratio of Executed- by Issued-Uops\000The ratio of Executed- by Issued-Uops. Ratio > 1 suggests high rate of uop micro-fusions. Ratio < 1 suggest high rate of \"execute\" at rename stage\000\000\000\000\00000 */
{ 277053 }, /* \000tma_info_thread_ipc\000Ret;Summary\000INST_RETIRED.ANY / tma_info_thread_clks\000\000Instructions Per Cycle (per Logical Processor)\000\000\000\000\000\00000 */
{ 277349 }, /* \000tma_info_thread_slots\000TmaL1;tma_L1_group\000TOPDOWN.SLOTS\000\000Total issue-pipeline slots (per-Physical Core till ICL; per-Logical Processor ICL onward)\000\000\000\000\000\00000 */
{ 277503 }, /* \000tma_info_thread_slots_utilization\000SMT;TmaL1;tma_L1_group\000(tma_info_thread_slots / (TOPDOWN.SLOTS / 2) if #SMT_on else 1)\000\000Fraction of Physical Core issue-slots utilized by this Logical Processor\000\000\000\000\000\00000 */
{ 277851 }, /* \000tma_info_thread_uoppi\000Pipeline;Ret;Retire\000tma_retiring * tma_info_thread_slots / INST_RETIRED.ANY\000tma_info_thread_uoppi > 1.05\000Uops Per Instruction\000\000\000\000\000\00000 */
{ 278166 }, /* \000tma_info_thread_uptb\000Branches;Fed;FetchBW\000tma_retiring * tma_info_thread_slots / BR_INST_RETIRED.NEAR_TAKEN\000tma_info_thread_uptb < 7.5\000Instruction per taken branch\000\000\000\000\000\00000 */
{ 283405 }, /* \000tma_itlb_misses\000BigFoot;FetchLat;MemoryTLB;TopdownL3;tma_L3_group;tma_fetch_latency_group\000ICACHE_64B.IFTAG_STALL / tma_info_thread_clks\000tma_itlb_misses > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses\000This metric represents fraction of cycles the CPU was stalled due to Instruction TLB (ITLB) misses. Sample with: FRONTEND_RETIRED.STLB_MISS_PS;FRONTEND_RETIRED.ITLB_MISS_PS\000100%\000\000\000\00000 */
{ 284668 }, /* \000tma_l1_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_issueL1;tma_issueMC;tma_memory_bound_group\000max((CYCLE_ACTIVITY.STALLS_MEM_ANY - CYCLE_ACTIVITY.STALLS_L1D_MISS) / tma_info_thread_clks, 0)\000tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache\000This metric estimates how often the CPU was stalled without loads missing the L1 data cache.  The L1 data cache typically has the shortest latency.  However; in certain cases like loads blocked on older stores; a load might suffer due to high latency even though it is being satisfied by the L1. Another example is loads who miss in the TLB. These cases are characterized by execution unit stalls; while some non-completed demand load lives in the machine without having that demand load missing the L1 cache. Sample with: MEM_LOAD_RETIRED.L1_HIT_PS;MEM_LOAD_RETIRED.FB_HIT_PS. Related metrics: tma_clears_resteers, tma_machine_clears, tma_microcode_sequencer, tma_ms_switches, tma_ports_utilized_1\000100%\000\000\000\00000 */
{ 291636 }, /* \000tma_l2_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) / (MEM_LOAD_RETIRED.L2_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS) + L1D_PEND_MISS.FB_FULL_PERIODS) * ((CYCLE_ACTIVITY.STALLS_L1D_MISS - CYCLE_ACTIVITY.STALLS_L2_MISS) / tma_info_thread_clks)\000tma_l2_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads\000This metric estimates how often the CPU was stalled due to L2 cache accesses by loads.  Avoiding cache misses (i.e. L1 misses/L2 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L2_HIT_PS\000100%\000\000\000\00001 */
{ 293573 }, /* \000tma_l3_bound\000CacheMisses;MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000(CYCLE_ACTIVITY.STALLS_L2_MISS - CYCLE_ACTIVITY.STALLS_L3_MISS) / tma_info_thread_clks\000tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core\000This metric estimates how often the CPU was stalled due to loads accesses to L3 cache or contended with a sibling Core.  Avoiding cache misses (i.e. L2 misses/L3 hits) can improve the latency and increase performance. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS\000100%\000\000\000\00000 */
{ 299800 }, /* \000tma_l3_hit_latency\000MemoryLat;TopdownL4;tma_L4_group;tma_issueLat;tma_l3_bound_group\00017.5 * tma_info_system_average_frequency * MEM_LOAD_RETIRED.L3_HIT * (1 + MEM_LOAD_RETIRED.FB_HIT / MEM_LOAD_RETIRED.L1_MISS / 2) / tma_info_thread_clks\000tma_l3_hit_latency > 0.1 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited)\000This metric represents fraction of cycles with demand load accesses that hit the L3 cache under unloaded scenarios (possibly L3 latency limited).  Avoiding private cache misses (i.e. L2 misses/L3 hits) will improve the latency; reduce contention with sibling physical cores and increase performance.  Note the value of this node may overlap with its siblings. Sample with: MEM_LOAD_RETIRED.L3_HIT_PS. Related metrics: tma_info_bottleneck_memory_latency, tma_mem_latency\000100%\000\000\000\00000 */
{ 311046 }, /* \000tma_lcp\000FetchLat;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueFB\000ILD_STALL.LCP / tma_info_thread_clks\000tma_lcp > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs)\000This metric represents fraction of cycles CPU was stalled due to Length Changing Prefixes (LCPs). Using proper compiler flags or Intel Compiler by default will certainly avoid this. #Link: Optimization Guide about LCP BKMs. Related metrics: tma_dsb_switches, tma_fetch_bandwidth, tma_info_botlnk_l2_dsb_misses, tma_info_frontend_dsb_coverage, tma_info_inst_mix_iptb\000100%\000\000\000\00000 */
{ 314141 }, /* \000tma_light_operations\000Retire;TmaL2;TopdownL2;tma_L2_group;tma_retiring_group\000max(0, tma_retiring - tma_heavy_operations)\000tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation)\000This metric represents fraction of slots where the CPU was retiring light-weight operations -- instructions that require no more than one uop (micro-operation). This correlates with total number of instructions used by the program. A uops-per-instruction (see UopPI metric) ratio of 1 or less should be expected for decently optimized software running on Intel Core/Xeon products. While this often indicates efficient X86 instructions were executed; high value does not necessarily mean better performance cannot be achieved. Sample with: INST_RETIRED.PREC_DIST\000100%\000\000TopdownL2\000\00000 */
{ 317952 }, /* \000tma_load_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000UOPS_DISPATCHED.PORT_2_3 / (2 * tma_info_core_core_clks)\000tma_load_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Load operations. Sample with: UOPS_DISPATCHED.PORT_2_3\000100%\000\000\000\00000 */
{ 318802 }, /* \000tma_load_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000tma_dtlb_load - tma_load_stlb_miss\000tma_load_stlb_hit > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the (first level) DTLB was missed by load accesses, that later on hit in second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 319600 }, /* \000tma_load_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_load_group\000DTLB_LOAD_MISSES.WALK_ACTIVE / tma_info_thread_clks\000tma_load_stlb_miss > 0.05 & (tma_dtlb_load > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the Second-level TLB (STLB) was missed by load accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 325792 }, /* \000tma_lock_latency\000Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_l1_bound_group\000(16 * max(0, MEM_INST_RETIRED.LOCK_LOADS - L2_RQSTS.ALL_RFO) + MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES * (10 * L2_RQSTS.RFO_HIT + min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO))) / tma_info_thread_clks\000tma_lock_latency > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations\000This metric represents fraction of cycles the CPU spent handling cache misses due to lock operations. Due to the microarchitecture handling of locks; they are classified as L1_Bound regardless of what memory source satisfied them. Sample with: MEM_INST_RETIRED.LOCK_LOADS_PS. Related metrics: tma_store_latency\000100%\000\000\000\00001 */
{ 328183 }, /* \000tma_lsd\000FetchBW;LSD;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(LSD.CYCLES_ACTIVE - LSD.CYCLES_OK) / tma_info_core_core_clks / 2\000tma_lsd > 0.15 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit\000This metric represents Core fraction of cycles in which CPU was likely limited due to LSD (Loop Stream Detector) unit.  LSD typically does well sustaining Uop supply. However; in some rare cases; optimal uop-delivery could not be reached for small loops whose size (in terms of number of uops) does not suit well the LSD structure\000100%\000\000\000\00000 */
{ 329816 }, /* \000tma_machine_clears\000BadSpec;MachineClears;TmaL2;TopdownL2;tma_L2_group;tma_bad_speculation_group;tma_issueMC;tma_issueSyncxn\000max(0, tma_bad_speculation - tma_branch_mispredicts)\000tma_machine_clears > 0.1 & tma_bad_speculation > 0.15\000This metric represents fraction of slots the CPU has wasted due to Machine Clears\000This metric represents fraction of slots the CPU has wasted due to Machine Clears.  These slots are either wasted by uops fetched prior to the clear; or stalls the out-of-order portion of the machine needs to recover its state after the clear. For example; this can happen due to memory ordering Nukes (e.g. Memory Disambiguation) or Self-Modifying-Code (SMC) nukes. Sample with: MACHINE_CLEARS.COUNT. Related metrics: tma_clears_resteers, tma_contested_accesses, tma_data_sharing, tma_false_sharing, tma_l1_bound, tma_microcode_sequencer, tma_ms_switches, tma_remote_cache\000100%\000\000TopdownL2\000\00000 */
{ 333270 }, /* \000tma_mem_bandwidth\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueBW\000min(CPU_CLK_UNHALTED.THREAD, cpu@OFFCORE_REQUESTS_OUTSTANDING.ALL_DATA_RD\\,cmask\\=4@) / tma_info_thread_clks\000tma_mem_bandwidth > 0.2 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM)\000This metric estimates fraction of cycles where the core's performance was likely hurt due to approaching bandwidth limits of external memory (DRAM).  The underlying heuristic assumes that a similar off-core traffic is generated by all IA cores. This metric does not aggregate non-data-read requests by this logical processor; requests from other IA Logical Processors/Physical Cores/sockets; or other non-IA devices like GPU; hence the maximum external memory bandwidth limits may or may not be approached when this metric is flagged (see Uncore counters for that). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_sq_full\000100%\000\000\000\00000 */
{ 338387 }, /* \000tma_mem_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_dram_bound_group;tma_issueLat\000min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DATA_RD) / tma_info_thread_clks - tma_mem_bandwidth\000tma_mem_latency > 0.1 & (tma_dram_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM)\000This metric estimates fraction of cycles where the performance was likely hurt due to latency from external memory (DRAM).  This metric does not aggregate requests from other Logical Processors/Physical Cores/sockets (see Uncore counters for that). Related metrics: tma_info_bottleneck_memory_latency, tma_l3_hit_latency\000100%\000\000\000\00000 */
{ 342540 }, /* \000tma_memory_bound\000Backend;TmaL2;TopdownL2;tma_L2_group;tma_backend_bound_group\000(CYCLE_ACTIVITY.STALLS_MEM_ANY + EXE_ACTIVITY.BOUND_ON_STORES) / (CYCLE_ACTIVITY.STALLS_TOTAL + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) + EXE_ACTIVITY.BOUND_ON_STORES) * tma_backend_bound\000tma_memory_bound > 0.2 & tma_backend_bound > 0.2\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck\000This metric represents fraction of slots the Memory subsystem within the Backend was a bottleneck.  Memory Bound estimates fraction of slots where pipeline is likely stalled due to demand load or store instructions. This accounts mainly for (1) non-completed in-flight memory demand loads which coincides with execution units starvation; in addition to (2) cases where stores could impose backpressure on the pipeline when many of them get buffered at the same time (less common out of the two)\000100%\000\000TopdownL2\000\00000 */
{ 348825 }, /* \000tma_memory_operations\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * MEM_INST_RETIRED.ANY / INST_RETIRED.ANY\000tma_memory_operations > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring memory operations -- uops for memory load or store accesses\000\000100%\000\000\000\00001 */
{ 352279 }, /* \000tma_microcode_sequencer\000MicroSeq;TopdownL3;tma_L3_group;tma_heavy_operations_group;tma_issueMC;tma_issueMS\000tma_retiring * tma_info_thread_slots / UOPS_ISSUED.ANY * IDQ.MS_UOPS / tma_info_thread_slots\000tma_microcode_sequencer > 0.05 & tma_heavy_operations > 0.1\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit\000This metric represents fraction of slots the CPU was retiring uops fetched by the Microcode Sequencer (MS) unit.  The MS is used for CISC instructions not supported by the default decoders (like repeat move strings; or CPUID); or by microcode assists used to address some operation modes (like in Floating Point assists). These cases can often be avoided. Sample with: IDQ.MS_UOPS. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_ms_switches\000100%\000\000\000\00000 */
{ 354628 }, /* \000tma_mispredicts_resteers\000BadSpec;BrMispredicts;TopdownL4;tma_L4_group;tma_branch_resteers_group;tma_issueBM\000BR_MISP_RETIRED.ALL_BRANCHES / (BR_MISP_RETIRED.ALL_BRANCHES + MACHINE_CLEARS.COUNT) * INT_MISC.CLEAR_RESTEER_CYCLES / tma_info_thread_clks\000tma_mispredicts_resteers > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage\000This metric represents fraction of cycles the CPU was stalled due to Branch Resteers as a result of Branch Misprediction at execution stage. Sample with: INT_MISC.CLEAR_RESTEER_CYCLES. Related metrics: tma_branch_mispredicts, tma_info_bad_spec_branch_misprediction_cost, tma_info_bottleneck_mispredictions\000100%\000\000\000\00000 */
{ 357790 }, /* \000tma_mite\000DSBmiss;FetchBW;TopdownL3;tma_L3_group;tma_fetch_bandwidth_group\000(IDQ.MITE_CYCLES_ANY - IDQ.MITE_CYCLES_OK) / tma_info_core_core_clks / 2\000tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline)\000This metric represents Core fraction of cycles in which CPU was likely limited due to the MITE pipeline (the legacy decode pipeline). This pipeline is used for code that was not pre-cached in the DSB or LSD. For example; inefficiencies due to asymmetric decoders; use of long immediate or LCP can manifest as MITE fetch bandwidth bottleneck. Sample with: FRONTEND_RETIRED.ANY_DSB_MISS\000100%\000\000\000\00000 */
{ 359354 }, /* \000tma_mite_4wide\000DSBmiss;FetchBW;TopdownL4;tma_L4_group;tma_mite_group\000(cpu@IDQ.MITE_UOPS\\,cmask\\=4@ - cpu@IDQ.MITE_UOPS\\,cmask\\=5@) / tma_info_thread_clks\000tma_mite_4wide > 0.05 & (tma_mite > 0.1 & (tma_fetch_bandwidth > 0.1 & tma_frontend_bound > 0.15 & tma_info_thread_ipc / 5 > 0.35))\000This metric represents fraction of cycles where (only) 4 uops were delivered by the MITE pipeline\000\000100%\000\000\000\00000 */
{ 360262 }, /* \000tma_mixing_vectors\000TopdownL5;tma_L5_group;tma_issueMV;tma_ports_utilized_0_group\000UOPS_ISSUED.VECTOR_WIDTH_MISMATCH / UOPS_ISSUED.ANY\000tma_mixing_vectors > 0.05\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued\000The Mixing_Vectors metric gives the percentage of injected blend uops out of all uops issued. Usually a Mixing_Vectors over 5% is worth investigating. Read more in Appendix B1 of the Optimizations Guide for this topic. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 362006 }, /* \000tma_ms_switches\000FetchLat;MicroSeq;TopdownL3;tma_L3_group;tma_fetch_latency_group;tma_issueMC;tma_issueMS;tma_issueMV;tma_issueSO\0003 * IDQ.MS_SWITCHES / tma_info_thread_clks\000tma_ms_switches > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS)\000This metric estimates the fraction of cycles when the CPU was stalled due to switches of uop delivery to the Microcode Sequencer (MS). Commonly used instructions are optimized for delivery by the DSB (decoded i-cache) or MITE (legacy instruction decode) pipelines. Certain operations cannot be handled natively by the execution pipeline; and must be performed by microcode (small programs injected into the execution stream). Switching to the MS too often can negatively impact performance. The MS is designated to deliver long uop flows required by CISC instructions like CPUID; or uncommon conditions like Floating Point Assists when dealing with Denormals. Sample with: IDQ.MS_SWITCHES. Related metrics: tma_clears_resteers, tma_l1_bound, tma_machine_clears, tma_microcode_sequencer, tma_mixing_vectors, tma_serializing_operation\000100%\000\000\000\00000 */
{ 366608 }, /* \000tma_nop_instructions\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000tma_light_operations * INST_RETIRED.NOP / (tma_retiring * tma_info_thread_slots)\000tma_nop_instructions > 0.1 & tma_light_operations > 0.6\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions\000This metric represents fraction of slots where the CPU was retiring NOP (no op) instructions. Compilers often use NOPs for certain address alignments - e.g. start address of a function or loop body. Sample with: INST_RETIRED.NOP\000100%\000\000\000\00000 */
{ 369076 }, /* \000tma_other_light_ops\000Pipeline;TopdownL3;tma_L3_group;tma_light_operations_group\000max(0, tma_light_operations - (tma_fp_arith + tma_memory_operations + tma_branch_instructions + tma_nop_instructions))\000tma_other_light_ops > 0.3 & tma_light_operations > 0.6\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes\000This metric represents the remaining light uops fraction the CPU has executed - remaining means not covered by other sibling nodes. May undercount due to FMA double counting\000100%\000\000\000\00001 */
{ 377934 }, /* \000tma_port_0\000Compute;TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_0 / tma_info_core_core_clks\000tma_port_0 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 0 ([SNB+] ALU; [HSW+] ALU and 2nd branch). Sample with: UOPS_DISPATCHED.PORT_0. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_1, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 380965 }, /* \000tma_port_1\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_1 / tma_info_core_core_clks\000tma_port_1 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 1 (ALU). Sample with: UOPS_DISPATCHED.PORT_1. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_5, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 385354 }, /* \000tma_port_5\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_5 / tma_info_core_core_clks\000tma_port_5 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 5 ([SNB+] Branches and ALU; [HSW+] ALU). Sample with: UOPS_DISPATCHED.PORT_5. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_6, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 388354 }, /* \000tma_port_6\000TopdownL6;tma_L6_group;tma_alu_op_utilization_group;tma_issue2P\000UOPS_DISPATCHED.PORT_6 / tma_info_core_core_clks\000tma_port_6 > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU)\000This metric represents Core fraction of cycles CPU dispatched uops on execution port 6 ([HSW+]Primary Branch and simple ALU). Sample with: UOPS_DISPATCHED.PORT_6. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_ports_utilized_2\000100%\000\000\000\00000 */
{ 392550 }, /* \000tma_ports_utilization\000PortsUtil;TopdownL3;tma_L3_group;tma_core_bound_group\000((cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) + (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL)) / tma_info_thread_clks if ARITH.DIVIDER_ACTIVE < CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY else (EXE_ACTIVITY.1_PORTS_UTIL + tma_retiring * EXE_ACTIVITY.2_PORTS_UTIL) / tma_info_thread_clks)\000tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related)\000This metric estimates fraction of cycles the CPU performance was potentially limited due to Core computation issues (non divider-related).  Two distinct categories can be attributed into this metric: (1) heavy data-dependency among contiguous instructions would manifest in this metric - such cases are often referred to as low Instruction Level Parallelism (ILP). (2) Contention on some hardware execution unit other than Divider. For example; when there are too many multiply operations\000100%\000\000\000\00000 */
{ 402317 }, /* \000tma_ports_utilized_0\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000cpu@EXE_ACTIVITY.3_PORTS_UTIL\\,umask\\=0x80@ / tma_info_thread_clks + tma_serializing_operation * (CYCLE_ACTIVITY.STALLS_TOTAL - CYCLE_ACTIVITY.STALLS_MEM_ANY) / tma_info_thread_clks\000tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed no uops on any execution port (Logical Processor cycles since ICL, Physical Core cycles otherwise). Long-latency instructions like divides may contribute to this metric\000100%\000\000\000\00000 */
{ 408697 }, /* \000tma_ports_utilized_1\000PortsUtil;TopdownL4;tma_L4_group;tma_issueL1;tma_ports_utilization_group\000EXE_ACTIVITY.1_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_1 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles where the CPU executed total of 1 uop per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). This can be due to heavy data-dependency among software instructions; or over oversubscribing a particular hardware resource. In some other cases with high 1_Port_Utilized and L1_Bound; this metric can point to L1 data-cache latency bottleneck that may not necessarily manifest with complete execution starvation (due to the short L1 latency e.g. walking a linked list) - looking at the assembly can be helpful. Sample with: EXE_ACTIVITY.1_PORTS_UTIL. Related metrics: tma_l1_bound\000100%\000\000\000\00000 */
{ 416142 }, /* \000tma_ports_utilized_2\000PortsUtil;TopdownL4;tma_L4_group;tma_issue2P;tma_ports_utilization_group\000EXE_ACTIVITY.2_PORTS_UTIL / tma_info_thread_clks\000tma_ports_utilized_2 > 0.15 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 2 uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise).  Loop Vectorization -most compilers feature auto-Vectorization options today- reduces pressure on the execution ports as multiple elements are calculated with same uop. Sample with: EXE_ACTIVITY.2_PORTS_UTIL. Related metrics: tma_fp_scalar, tma_fp_vector, tma_fp_vector_128b, tma_fp_vector_256b, tma_fp_vector_512b, tma_port_0, tma_port_1, tma_port_5, tma_port_6\000100%\000\000\000\00000 */
{ 419352 }, /* \000tma_ports_utilized_3m\000PortsUtil;TopdownL4;tma_L4_group;tma_ports_utilization_group\000UOPS_EXECUTED.CYCLES_GE_3 / tma_info_thread_clks\000tma_ports_utilized_3m > 0.7 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise)\000This metric represents fraction of cycles CPU executed total of 3 or more uops per cycle on all execution ports (Logical Processor cycles since ICL, Physical Core cycles otherwise). Sample with: UOPS_EXECUTED.CYCLES_GE_3\000100%\000\000\000\00000 */
{ 432289 }, /* \000tma_retiring\000Default;TmaL1;TopdownL1;tma_L1_group\000topdown\\-retiring / (topdown\\-fe\\-bound + topdown\\-bad\\-spec + topdown\\-retiring + topdown\\-be\\-bound) + 0 * tma_info_thread_slots\000tma_retiring > 0.7 | tma_heavy_operations > 0.1\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired\000This category represents fraction of slots utilized by useful work i.e. issued uops that eventually get retired. Ideally; all pipeline slots would be attributed to the Retiring category.  Retiring of 100% would indicate the maximum Pipeline_Width throughput was achieved.  Maximizing Retiring typically increases the Instructions-per-cycle (see IPC metric). Note that a high Retiring value does not necessary mean there is no room for more performance.  For example; Heavy-operations or Microcode Assists are categorized under Retiring. They often indicate suboptimal performance and can often be optimized or avoided. Sample with: UOPS_RETIRED.SLOTS\000100%\000\000TopdownL1;Default\000TopdownL1\00000 */
{ 436702 }, /* \000tma_serializing_operation\000PortsUtil;TopdownL5;tma_L5_group;tma_issueSO;tma_ports_utilized_0_group\000RESOURCE_STALLS.SCOREBOARD / tma_info_thread_clks\000tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2)))\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations\000This metric represents fraction of cycles the CPU issue-pipeline was stalled due to serializing operations. Instructions like CPUID; WRMSR or LFENCE serialize the out-of-order execution which may limit performance. Sample with: RESOURCE_STALLS.SCOREBOARD. Related metrics: tma_ms_switches\000100%\000\000\000\00000 */
{ 437735 }, /* \000tma_slow_pause\000TopdownL6;tma_L6_group;tma_serializing_operation_group\000140 * MISC_RETIRED.PAUSE_INST / tma_info_thread_clks\000tma_slow_pause > 0.05 & (tma_serializing_operation > 0.1 & (tma_ports_utilized_0 > 0.2 & (tma_ports_utilization > 0.15 & (tma_core_bound > 0.1 & tma_backend_bound > 0.2))))\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions\000This metric represents fraction of cycles the CPU was stalled due to PAUSE Instructions. Sample with: MISC_RETIRED.PAUSE_INST\000100%\000\000\000\00000 */
{ 440531 }, /* \000tma_split_loads\000TopdownL4;tma_L4_group;tma_l1_bound_group\000tma_info_memory_load_miss_real_latency * LD_BLOCKS.NO_SR / tma_info_thread_clks\000tma_split_loads > 0.2 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary\000This metric estimates fraction of cycles handling memory load split accesses - load that cross 64-byte cache line boundary. Sample with: MEM_INST_RETIRED.SPLIT_LOADS_PS\000100%\000\000\000\00000 */
{ 443681 }, /* \000tma_split_stores\000TopdownL4;tma_L4_group;tma_issueSpSt;tma_store_bound_group\000MEM_INST_RETIRED.SPLIT_STORES / tma_info_core_core_clks\000tma_split_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric represents rate of split store accesses\000This metric represents rate of split store accesses.  Consider aligning your data to the 64-byte cache line granularity. Sample with: MEM_INST_RETIRED.SPLIT_STORES_PS. Related metrics: tma_port_4\000100%\000\000\000\00000 */
{ 446331 }, /* \000tma_sq_full\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueBW;tma_l3_bound_group\000L1D_PEND_MISS.L2_STALL / tma_info_thread_clks\000tma_sq_full > 0.3 & (tma_l3_bound > 0.05 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors)\000This metric measures fraction of cycles where the Super Queue (SQ) was full taking into account all request-types and both hardware SMT threads (Logical Processors). Related metrics: tma_fb_full, tma_info_bottleneck_memory_bandwidth, tma_info_system_dram_bw_use, tma_mem_bandwidth\000100%\000\000\000\00000 */
{ 447783 }, /* \000tma_store_bound\000MemoryBound;TmaL3mem;TopdownL3;tma_L3_group;tma_memory_bound_group\000EXE_ACTIVITY.BOUND_ON_STORES / tma_info_thread_clks\000tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write\000This metric estimates how often CPU was stalled  due to RFO store memory accesses; RFO store issue a read-for-ownership request before the write. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should RFO stores be a bottleneck. Sample with: MEM_INST_RETIRED.ALL_STORES_PS\000100%\000\000\000\00000 */
{ 450251 }, /* \000tma_store_fwd_blk\000TopdownL4;tma_L4_group;tma_l1_bound_group\00013 * LD_BLOCKS.STORE_FORWARD / tma_info_thread_clks\000tma_store_fwd_blk > 0.1 & (tma_l1_bound > 0.1 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores\000This metric roughly estimates fraction of cycles when the memory subsystem had loads blocked since they could not forward data from earlier (in program order) overlapping stores. To streamline memory operations in the pipeline; a load can avoid waiting for memory if a prior in-flight store is writing the data that the load wants to read (store forwarding process). However; in some cases the load may be blocked for a significant time pending the store forward. For example; when the prior store is writing a smaller region than the load is reading\000100%\000\000\000\00000 */
{ 451466 }, /* \000tma_store_latency\000MemoryLat;Offcore;TopdownL4;tma_L4_group;tma_issueRFO;tma_issueSL;tma_store_bound_group\000(L2_RQSTS.RFO_HIT * 10 * (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) + (1 - MEM_INST_RETIRED.LOCK_LOADS / MEM_INST_RETIRED.ALL_STORES) * min(CPU_CLK_UNHALTED.THREAD, OFFCORE_REQUESTS_OUTSTANDING.CYCLES_WITH_DEMAND_RFO)) / tma_info_thread_clks\000tma_store_latency > 0.1 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates fraction of cycles the CPU spent handling L1D store misses\000This metric estimates fraction of cycles the CPU spent handling L1D store misses. Store accesses usually less impact out-of-order core performance; however; holding resources for longer time can lead into undesired implications (e.g. contention on L1D fill-buffer entries - see FB_Full). Related metrics: tma_fb_full, tma_lock_latency\000100%\000\000\000\00000 */
{ 455967 }, /* \000tma_store_op_utilization\000TopdownL5;tma_L5_group;tma_ports_utilized_3m_group\000(UOPS_DISPATCHED.PORT_4_9 + UOPS_DISPATCHED.PORT_7_8) / (4 * tma_info_core_core_clks)\000tma_store_op_utilization > 0.6\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations\000This metric represents Core fraction of cycles CPU dispatched uops on execution port for Store operations. Sample with: UOPS_DISPATCHED.PORT_7_8\000100%\000\000\000\00000 */
{ 457124 }, /* \000tma_store_stlb_hit\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000tma_dtlb_store - tma_store_stlb_miss\000tma_store_stlb_hit > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric roughly estimates the fraction of cycles where the TLB was missed by store accesses, hitting in the second-level TLB (STLB)\000\000100%\000\000\000\00000 */
{ 457513 }, /* \000tma_store_stlb_miss\000MemoryTLB;TopdownL5;tma_L5_group;tma_dtlb_store_group\000DTLB_STORE_MISSES.WALK_ACTIVE / tma_info_core_core_clks\000tma_store_stlb_miss > 0.05 & (tma_dtlb_store > 0.05 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2)))\000This metric estimates the fraction of cycles where the STLB was missed by store accesses, performing a hardware page walk\000\000100%\000\000\000\00000 */
{ 457909 }, /* \000tma_streaming_stores\000MemoryBW;Offcore;TopdownL4;tma_L4_group;tma_issueSmSt;tma_store_bound_group\0009 * OCR.STREAMING_WR.ANY_RESPONSE / tma_info_thread_clks\000tma_streaming_stores > 0.2 & (tma_store_bound > 0.2 & (tma_memory_bound > 0.2 & tma_backend_bound > 0.2))\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores\000This metric estimates how often CPU was stalled  due to Streaming store memory accesses; Streaming store optimize out a read request required by RFO stores. Even though store accesses do not typically stall out-of-order CPUs; there are few cases where stores can lead to actual stalls. This metric will be flagged should Streaming stores be a bottleneck. Sample with: OCR.STREAMING_WR.ANY_RESPONSE. Related metrics: tma_fb_full\000100%\000\000\000\00000 */
{ 458764 }, /* \000tma_unknown_branches\000BigFoot;FetchLat;TopdownL4;tma_L4_group;tma_branch_resteers_group\00010 * BACLEARS.ANY / tma_info_thread_clks\000tma_unknown_branches > 0.05 & (tma_branch_resteers > 0.05 & (tma_fetch_latency > 0.1 & tma_frontend_bound > 0.15))\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears\000This metric represents fraction of cycles the CPU was stalled due to new branch address clears. These are fetched branches the Branch Prediction Unit was unable to recognize (e.g. first time the branch is fetched or hitting BTB capacity limit). Sample with: BACLEARS.ANY\000100%\000\000\000\00000 */
{ 464004 }, /* \000tma_x87_use\000Compute;TopdownL4;tma_L4_group;tma_fp_arith_group\000tma_retiring * UOPS_EXECUTED.X87 / UOPS_EXECUTED.THREAD\000tma_x87_use > 0.1 & (tma_fp_arith > 0.2 & tma_light_operations > 0.6)\000This metric serves as an approximation of legacy x87 usage\000This metric serves as an approximation of legacy x87 usage. It accounts for instructions beyond X87 FP arithmetic operations; hence may be used as a thermometer to avoid X87 high usage and preferably upgrade to modern ISA. See Tip under Tuning Hint\000100%\000\000\000\00000 */
{ 464639 }, /* \000tsx_aborted_cycles\000transaction\000(max(cycles\\-t - cycles\\-ct, 0) / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles in aborted transactions\000\000100%\000\000\000\00000 */
{ 464801 }, /* \000tsx_cycles_per_elision\000transaction\000(cycles\\-t / el\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of elisions\000\0001cycles / elision\000\000\000\00000 */
{ 464989 }, /* \000tsx_cycles_per_transaction\000transaction\000(cycles\\-t / tx\\-start if has_event(cycles\\-t) else 0)\000\000Number of cycles within a transaction divided by the number of transactions\000\0001cycles / transaction\000\000\000\00000 */
{ 465189 }, /* \000tsx_transactional_cycles\000transaction\000(cycles\\-t / cycles if has_event(cycles\\-t) else 0)\000\000Percentage of cycles within a transaction region\000\000100%\000\000\000\00000 */
};

static const struct compact_pmu_event pmu_events__westmereep_dp[] = {
{ 571421 }, /* cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000 */
{ 571509 }, /* cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000 */
{ 1100466 }, /* l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000 */
{ 1100562 }, /* l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000 */
{ 1100662 }, /* l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000 */
{ 1100773 }, /* l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104580 }, /* l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000 */
{ 1113958 }, /* l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000 */
{ 1114052 }, /* l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000 */
{ 1114152 }, /* l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000 */
{ 1114262 }, /* l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000 */
{ 1114358 }, /* l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000 */
{ 1114463 }, /* l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000 */
{ 1114559 }, /* l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000 */
{ 1114645 }, /* l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000 */
{ 1121826 }, /* l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000 */
{ 1121913 }, /* l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000 */
{ 1122021 }, /* l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000 */
{ 1122138 }, /* l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000 */
{ 1122246 }, /* l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000 */
{ 1122343 }, /* l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000 */
{ 1122451 }, /* l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1122560 }, /* l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000 */
{ 1122682 }, /* l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000 */
{ 1122791 }, /* l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000 */
{ 1122890 }, /* l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000 */
{ 1129684 }, /* l2_lines_in.any\000\000cache\000L2 lines allocated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000 */
{ 1130213 }, /* l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000 */
{ 1131206 }, /* l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000 */
{ 1131570 }, /* l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000 */
{ 1132175 }, /* l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000 */
{ 1132697 }, /* l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000 */
{ 1135641 }, /* l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000 */
{ 1135755 }, /* l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000 */
{ 1167724 }, /* l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000 */
{ 1167818 }, /* l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000 */
{ 1167915 }, /* l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000 */
{ 1168737 }, /* l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000 */
{ 1168813 }, /* l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000 */
{ 1168892 }, /* l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000 */
{ 1168966 }, /* l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000 */
{ 1172018 }, /* l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1172105 }, /* l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000 */
{ 1172195 }, /* l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000 */
{ 1172443 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000 */
{ 1173756 }, /* l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000 */
{ 1174646 }, /* l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000 */
{ 1175586 }, /* l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000 */
{ 1183427 }, /* l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000 */
{ 1183515 }, /* l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000 */
{ 1183605 }, /* l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000 */
{ 1183709 }, /* l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000 */
{ 1183813 }, /* l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000 */
{ 1183902 }, /* l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000 */
{ 1183999 }, /* l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000 */
{ 1184086 }, /* l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000 */
{ 1184856 }, /* l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000 */
{ 1184957 }, /* l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000 */
{ 1185066 }, /* l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000 */
{ 1185176 }, /* l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000 */
{ 1185277 }, /* l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000 */
{ 1185368 }, /* l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000 */
{ 1185469 }, /* l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000 */
{ 1185577 }, /* l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000 */
{ 1185686 }, /* l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000 */
{ 1185786 }, /* l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000 */
{ 1185876 }, /* l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000 */
{ 1249469 }, /* longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000 */
{ 1253301 }, /* longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1312836 }, /* mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000 */
{ 1312997 }, /* mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000 */
{ 1313161 }, /* mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000 */
{ 1313488 }, /* mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000 */
{ 1313323 }, /* mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000 */
{ 1313649 }, /* mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000 */
{ 1313812 }, /* mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000 */
{ 1314139 }, /* mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000 */
{ 1313974 }, /* mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000 */
{ 1314463 }, /* mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000 */
{ 1314299 }, /* mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000 */
{ 1314621 }, /* mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000 */
{ 1314783 }, /* mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000 */
{ 1315107 }, /* mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000 */
{ 1314943 }, /* mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000 */
{ 1315265 }, /* mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1319310 }, /* mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000 */
{ 1333824 }, /* mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000 */
{ 1336151 }, /* mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1336860 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000 */
{ 1340299 }, /* mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000 */
{ 1340426 }, /* mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000 */
{ 1341515 }, /* mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000 */
{ 1747290 }, /* offcore_requests.any\000\000cache\000All offcore requests\000event=0xb0,period=100000,umask=0x80\000\00000\000\000 */
{ 1747101 }, /* offcore_requests.any.read\000\000cache\000Offcore read requests\000event=0xb0,period=100000,umask=0x8\000\00000\000\000 */
{ 1747196 }, /* offcore_requests.any.rfo\000\000cache\000Offcore RFO requests\000event=0xb0,period=100000,umask=0x10\000\00000\000\000 */
{ 1748025 }, /* offcore_requests.demand.read_code\000\000cache\000Offcore demand code read requests\000event=0xb0,period=100000,umask=0x2\000\00000\000\000 */
{ 1748140 }, /* offcore_requests.demand.read_data\000\000cache\000Offcore demand data read requests\000event=0xb0,period=100000,umask=0x1\000\00000\000\000 */
{ 1748255 }, /* offcore_requests.demand.rfo\000\000cache\000Offcore demand RFO requests\000event=0xb0,period=100000,umask=0x4\000\00000\000\000 */
{ 1752159 }, /* offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000 */
{ 1757706 }, /* offcore_requests_outstanding.any.read\000\000cache\000Outstanding offcore reads\000event=0x60,period=2000000,umask=0x8\000\00000\000\000 */
{ 1757818 }, /* offcore_requests_outstanding.any.read_not_empty\000\000cache\000Cycles offcore reads busy\000event=0x60,cmask=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 1769044 }, /* offcore_requests_outstanding.demand.read_code\000\000cache\000Outstanding offcore demand code reads\000event=0x60,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769176 }, /* offcore_requests_outstanding.demand.read_code_not_empty\000\000cache\000Cycles offcore demand code read busy\000event=0x60,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769325 }, /* offcore_requests_outstanding.demand.read_data\000\000cache\000Outstanding offcore demand data reads\000event=0x60,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769457 }, /* offcore_requests_outstanding.demand.read_data_not_empty\000\000cache\000Cycles offcore demand data read busy\000event=0x60,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769606 }, /* offcore_requests_outstanding.demand.rfo\000\000cache\000Outstanding offcore demand RFOs\000event=0x60,period=2000000,umask=0x4\000\00000\000\000 */
{ 1769726 }, /* offcore_requests_outstanding.demand.rfo_not_empty\000\000cache\000Cycles offcore demand RFOs busy\000event=0x60,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 1780856 }, /* offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000 */
{ 1920805 }, /* offcore_response.any_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5011\000\00000\000\000 */
{ 1921165 }, /* offcore_response.any_data.any_cache_dram\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f11\000\00000\000\000 */
{ 1922080 }, /* offcore_response.any_data.any_location\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff11\000\00000\000\000 */
{ 1922396 }, /* offcore_response.any_data.io_csr_mmio\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000 */
{ 1922736 }, /* offcore_response.any_data.llc_hit_no_other_core\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000 */
{ 1923090 }, /* offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000 */
{ 1923449 }, /* offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000 */
{ 1923770 }, /* offcore_response.any_data.local_cache\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000 */
{ 1924552 }, /* offcore_response.any_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000 */
{ 1925720 }, /* offcore_response.any_data.remote_cache_hitm\000\000cache\000REQUEST = ANY_DATA read and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000 */
{ 1936630 }, /* offcore_response.any_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5044\000\00000\000\000 */
{ 1936991 }, /* offcore_response.any_ifetch.any_cache_dram\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f44\000\00000\000\000 */
{ 1937909 }, /* offcore_response.any_ifetch.any_location\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff44\000\00000\000\000 */
{ 1938226 }, /* offcore_response.any_ifetch.io_csr_mmio\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000 */
{ 1938567 }, /* offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000 */
{ 1938922 }, /* offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000 */
{ 1939282 }, /* offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000 */
{ 1939604 }, /* offcore_response.any_ifetch.local_cache\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000 */
{ 1940393 }, /* offcore_response.any_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000 */
{ 1941569 }, /* offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000REQUEST = ANY IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000 */
{ 1960009 }, /* offcore_response.any_request.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x50ff\000\00000\000\000 */
{ 1960371 }, /* offcore_response.any_request.any_cache_dram\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7fff\000\00000\000\000 */
{ 1961292 }, /* offcore_response.any_request.any_location\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xffff\000\00000\000\000 */
{ 1963286 }, /* offcore_response.any_request.io_csr_mmio\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80ff\000\00000\000\000 */
{ 1969943 }, /* offcore_response.any_request.llc_hit_no_other_core\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1ff\000\00000\000\000 */
{ 1970299 }, /* offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2ff\000\00000\000\000 */
{ 1970660 }, /* offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4ff\000\00000\000\000 */
{ 1971266 }, /* offcore_response.any_request.local_cache\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7ff\000\00000\000\000 */
{ 1972053 }, /* offcore_response.any_request.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10ff\000\00000\000\000 */
{ 1974559 }, /* offcore_response.any_request.remote_cache_hitm\000\000cache\000REQUEST = ANY_REQUEST and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8ff\000\00000\000\000 */
{ 1975187 }, /* offcore_response.any_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5022\000\00000\000\000 */
{ 1975541 }, /* offcore_response.any_rfo.any_cache_dram\000\000cache\000REQUEST = ANY RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f22\000\00000\000\000 */
{ 1976438 }, /* offcore_response.any_rfo.any_location\000\000cache\000REQUEST = ANY RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff22\000\00000\000\000 */
{ 1978156 }, /* offcore_response.any_rfo.io_csr_mmio\000\000cache\000REQUEST = ANY RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000 */
{ 1985897 }, /* offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000 */
{ 1986245 }, /* offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000 */
{ 1986598 }, /* offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = ANY RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000 */
{ 1986913 }, /* offcore_response.any_rfo.local_cache\000\000cache\000REQUEST = ANY RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000 */
{ 1987692 }, /* offcore_response.any_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = ANY RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000 */
{ 1990310 }, /* offcore_response.any_rfo.remote_cache_hitm\000\000cache\000REQUEST = ANY RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000 */
{ 1997958 }, /* offcore_response.corewb.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5008\000\00000\000\000 */
{ 1998298 }, /* offcore_response.corewb.any_cache_dram\000\000cache\000REQUEST = CORE_WB and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f08\000\00000\000\000 */
{ 1999173 }, /* offcore_response.corewb.any_location\000\000cache\000REQUEST = CORE_WB and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff08\000\00000\000\000 */
{ 2000407 }, /* offcore_response.corewb.io_csr_mmio\000\000cache\000REQUEST = CORE_WB and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000 */
{ 2008049 }, /* offcore_response.corewb.llc_hit_no_other_core\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000 */
{ 2008215 }, /* offcore_response.corewb.llc_hit_other_core_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x208\000\00000\000\000 */
{ 2008554 }, /* offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000REQUEST = CORE_WB and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000 */
{ 2008855 }, /* offcore_response.corewb.local_cache\000\000cache\000REQUEST = CORE_WB and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000 */
{ 2009581 }, /* offcore_response.corewb.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = CORE_WB and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000 */
{ 2011227 }, /* offcore_response.corewb.remote_cache_hitm\000\000cache\000REQUEST = CORE_WB and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000 */
{ 2012963 }, /* offcore_response.data_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5077\000\00000\000\000 */
{ 2013343 }, /* offcore_response.data_ifetch.any_cache_dram\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f77\000\00000\000\000 */
{ 2014318 }, /* offcore_response.data_ifetch.any_location\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff77\000\00000\000\000 */
{ 2014654 }, /* offcore_response.data_ifetch.io_csr_mmio\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000 */
{ 2015014 }, /* offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000 */
{ 2015388 }, /* offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000 */
{ 2015767 }, /* offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000 */
{ 2016108 }, /* offcore_response.data_ifetch.local_cache\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000 */
{ 2016967 }, /* offcore_response.data_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000 */
{ 2018232 }, /* offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000REQUEST = DATA_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000 */
{ 2018896 }, /* offcore_response.data_in.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5033\000\00000\000\000 */
{ 2019252 }, /* offcore_response.data_in.any_cache_dram\000\000cache\000REQUEST = DATA_IN and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f33\000\00000\000\000 */
{ 2020192 }, /* offcore_response.data_in.any_location\000\000cache\000REQUEST = DATA_IN and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff33\000\00000\000\000 */
{ 2020680 }, /* offcore_response.data_in.io_csr_mmio\000\000cache\000REQUEST = DATA_IN and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000 */
{ 2021034 }, /* offcore_response.data_in.llc_hit_no_other_core\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000 */
{ 2021402 }, /* offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000 */
{ 2021775 }, /* offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000REQUEST = DATA_IN and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000 */
{ 2022099 }, /* offcore_response.data_in.local_cache\000\000cache\000REQUEST = DATA_IN and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000 */
{ 2022924 }, /* offcore_response.data_in.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DATA_IN and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000 */
{ 2024118 }, /* offcore_response.data_in.remote_cache_hitm\000\000cache\000REQUEST = DATA_IN and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000 */
{ 2072042 }, /* offcore_response.demand_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5003\000\00000\000\000 */
{ 2072416 }, /* offcore_response.demand_data.any_cache_dram\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f03\000\00000\000\000 */
{ 2073373 }, /* offcore_response.demand_data.any_location\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff03\000\00000\000\000 */
{ 2073703 }, /* offcore_response.demand_data.io_csr_mmio\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000 */
{ 2074057 }, /* offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000 */
{ 2074425 }, /* offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000 */
{ 2074798 }, /* offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000 */
{ 2075133 }, /* offcore_response.demand_data.local_cache\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000 */
{ 2075968 }, /* offcore_response.demand_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000 */
{ 2077203 }, /* offcore_response.demand_data.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_DATA and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000 */
{ 2077855 }, /* offcore_response.demand_data_rd.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5001\000\00000\000\000 */
{ 2078235 }, /* offcore_response.demand_data_rd.any_cache_dram\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f01\000\00000\000\000 */
{ 2079210 }, /* offcore_response.demand_data_rd.any_location\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff01\000\00000\000\000 */
{ 2081829 }, /* offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000 */
{ 2118279 }, /* offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000 */
{ 2118653 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000 */
{ 2119032 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000 */
{ 2121192 }, /* offcore_response.demand_data_rd.local_cache\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000 */
{ 2122033 }, /* offcore_response.demand_data_rd.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000 */
{ 2126257 }, /* offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_DATA_RD and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000 */
{ 2129888 }, /* offcore_response.demand_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5004\000\00000\000\000 */
{ 2130265 }, /* offcore_response.demand_ifetch.any_cache_dram\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f04\000\00000\000\000 */
{ 2131231 }, /* offcore_response.demand_ifetch.any_location\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff04\000\00000\000\000 */
{ 2131564 }, /* offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000 */
{ 2131921 }, /* offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000 */
{ 2132292 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000 */
{ 2132668 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000 */
{ 2133201 }, /* offcore_response.demand_ifetch.local_cache\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000 */
{ 2134036 }, /* offcore_response.demand_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000 */
{ 2135274 }, /* offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000 */
{ 2135932 }, /* offcore_response.demand_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5002\000\00000\000\000 */
{ 2136302 }, /* offcore_response.demand_rfo.any_cache_dram\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f02\000\00000\000\000 */
{ 2137247 }, /* offcore_response.demand_rfo.any_location\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff02\000\00000\000\000 */
{ 2139638 }, /* offcore_response.demand_rfo.io_csr_mmio\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000 */
{ 2177377 }, /* offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000 */
{ 2177741 }, /* offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000 */
{ 2178110 }, /* offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000 */
{ 2179500 }, /* offcore_response.demand_rfo.local_cache\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000 */
{ 2180325 }, /* offcore_response.demand_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000 */
{ 2184542 }, /* offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000REQUEST = DEMAND_RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000 */
{ 2194357 }, /* offcore_response.other.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = OTHER and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5080\000\00000\000\000 */
{ 2194707 }, /* offcore_response.other.any_cache_dram\000\000cache\000REQUEST = OTHER and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f80\000\00000\000\000 */
{ 2195592 }, /* offcore_response.other.any_location\000\000cache\000REQUEST = OTHER and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff80\000\00000\000\000 */
{ 2196510 }, /* offcore_response.other.io_csr_mmio\000\000cache\000REQUEST = OTHER and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000 */
{ 2219051 }, /* offcore_response.other.llc_hit_no_other_core\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000 */
{ 2219395 }, /* offcore_response.other.llc_hit_other_core_hit\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000 */
{ 2219744 }, /* offcore_response.other.llc_hit_other_core_hitm\000\000cache\000REQUEST = OTHER and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000 */
{ 2220055 }, /* offcore_response.other.local_cache\000\000cache\000REQUEST = OTHER and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000 */
{ 2220526 }, /* offcore_response.other.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = OTHER and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000 */
{ 2222896 }, /* offcore_response.other.remote_cache_hitm\000\000cache\000REQUEST = OTHER and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000 */
{ 2240920 }, /* offcore_response.pf_data.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5050\000\00000\000\000 */
{ 2241452 }, /* offcore_response.pf_data.any_cache_dram\000\000cache\000REQUEST = PF_DATA and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f50\000\00000\000\000 */
{ 2242828 }, /* offcore_response.pf_data.any_location\000\000cache\000REQUEST = PF_DATA and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff50\000\00000\000\000 */
{ 2243318 }, /* offcore_response.pf_data.io_csr_mmio\000\000cache\000REQUEST = PF_DATA and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8050\000\00000\000\000 */
{ 2243858 }, /* offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x150\000\00000\000\000 */
{ 2244407 }, /* offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x250\000\00000\000\000 */
{ 2244964 }, /* offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_DATA and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x450\000\00000\000\000 */
{ 2245443 }, /* offcore_response.pf_data.local_cache\000\000cache\000REQUEST = PF_DATA and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x750\000\00000\000\000 */
{ 2246262 }, /* offcore_response.pf_data.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1050\000\00000\000\000 */
{ 2247967 }, /* offcore_response.pf_data.remote_cache_hitm\000\000cache\000REQUEST = PF_DATA and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x850\000\00000\000\000 */
{ 2248599 }, /* offcore_response.pf_data_rd.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5010\000\00000\000\000 */
{ 2248969 }, /* offcore_response.pf_data_rd.any_cache_dram\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f10\000\00000\000\000 */
{ 2249914 }, /* offcore_response.pf_data_rd.any_location\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff10\000\00000\000\000 */
{ 2250240 }, /* offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000 */
{ 2250590 }, /* offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000 */
{ 2250954 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000 */
{ 2251323 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000 */
{ 2251843 }, /* offcore_response.pf_data_rd.local_cache\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000 */
{ 2252668 }, /* offcore_response.pf_data_rd.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000 */
{ 2253889 }, /* offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000REQUEST = PF_DATA_RD and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000 */
{ 2254533 }, /* offcore_response.pf_ifetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5040\000\00000\000\000 */
{ 2254897 }, /* offcore_response.pf_ifetch.any_cache_dram\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f40\000\00000\000\000 */
{ 2255824 }, /* offcore_response.pf_ifetch.any_location\000\000cache\000REQUEST = PF_RFO and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff40\000\00000\000\000 */
{ 2256296 }, /* offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000REQUEST = PF_RFO and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000 */
{ 2256640 }, /* offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000 */
{ 2256998 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000 */
{ 2257361 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_RFO and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000 */
{ 2257870 }, /* offcore_response.pf_ifetch.local_cache\000\000cache\000REQUEST = PF_RFO and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000 */
{ 2258686 }, /* offcore_response.pf_ifetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_RFO and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000 */
{ 2259892 }, /* offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000REQUEST = PF_RFO and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000 */
{ 2430570 }, /* offcore_response.pf_rfo.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5020\000\00000\000\000 */
{ 2430933 }, /* offcore_response.pf_rfo.any_cache_dram\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f20\000\00000\000\000 */
{ 2431857 }, /* offcore_response.pf_rfo.any_location\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff20\000\00000\000\000 */
{ 2432176 }, /* offcore_response.pf_rfo.io_csr_mmio\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000 */
{ 2432519 }, /* offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000 */
{ 2432876 }, /* offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000 */
{ 2433238 }, /* offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000 */
{ 2433562 }, /* offcore_response.pf_rfo.local_cache\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000 */
{ 2434374 }, /* offcore_response.pf_rfo.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000 */
{ 2435575 }, /* offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000REQUEST = PF_IFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000 */
{ 2440485 }, /* offcore_response.prefetch.all_local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = ALL_LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5070\000\00000\000\000 */
{ 2440847 }, /* offcore_response.prefetch.any_cache_dram\000\000cache\000REQUEST = PREFETCH and RESPONSE = ANY_CACHE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7f70\000\00000\000\000 */
{ 2441768 }, /* offcore_response.prefetch.any_location\000\000cache\000REQUEST = PREFETCH and RESPONSE = ANY_LOCATION\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xff70\000\00000\000\000 */
{ 2442086 }, /* offcore_response.prefetch.io_csr_mmio\000\000cache\000REQUEST = PREFETCH and RESPONSE = IO_CSR_MMIO\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000 */
{ 2442428 }, /* offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_NO_OTHER_CORE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000 */
{ 2442784 }, /* offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000 */
{ 2443145 }, /* offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000REQUEST = PREFETCH and RESPONSE = LLC_HIT_OTHER_CORE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000 */
{ 2443468 }, /* offcore_response.prefetch.local_cache\000\000cache\000REQUEST = PREFETCH and RESPONSE = LOCAL_CACHE\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000 */
{ 2444273 }, /* offcore_response.prefetch.local_dram_and_remote_cache_hit\000\000cache\000REQUEST = PREFETCH and RESPONSE = LOCAL_DRAM AND REMOTE_CACHE_HIT\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000 */
{ 2445466 }, /* offcore_response.prefetch.remote_cache_hitm\000\000cache\000REQUEST = PREFETCH and RESPONSE = REMOTE_CACHE_HITM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000 */
{ 2531564 }, /* sq_misc.lru_hints\000\000cache\000Super Queue LRU hints sent to LLC\000event=0xf4,period=2000000,umask=0x4\000\00000\000\000 */
{ 2532073 }, /* sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000 */
{ 2536735 }, /* store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000 */
{ 2536845 }, /* store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000 */
{ 901660 }, /* fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000 */
{ 902741 }, /* fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000 */
{ 902880 }, /* fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000 */
{ 905570 }, /* fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 905656 }, /* fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000 */
{ 905760 }, /* fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000 */
{ 905885 }, /* fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000 */
{ 905986 }, /* fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000 */
{ 906093 }, /* fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000 */
{ 907996 }, /* fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000 */
{ 908121 }, /* fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 910502 }, /* fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000 */
{ 910623 }, /* fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000 */
{ 910751 }, /* fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524990 }, /* simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000 */
{ 2525101 }, /* simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000 */
{ 2525227 }, /* simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000 */
{ 2525352 }, /* simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000 */
{ 2525473 }, /* simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000 */
{ 2525593 }, /* simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000 */
{ 2525721 }, /* simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000 */
{ 2525836 }, /* simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000 */
{ 2525945 }, /* simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000 */
{ 2526069 }, /* simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000 */
{ 2526192 }, /* simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000 */
{ 2526318 }, /* simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000 */
{ 2526436 }, /* simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000 */
{ 2526562 }, /* simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000 */
{ 1302909 }, /* macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000 */
{ 1303001 }, /* macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000 */
{ 2571312 }, /* two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000 */
{ 1429691 }, /* misalign_mem_ref.store\000\000memory\000Misaligned store references\000event=0x5,period=200000,umask=0x2\000\00000\000\000 */
{ 1921469 }, /* offcore_response.any_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3011\000\00000\000\000 */
{ 1921794 }, /* offcore_response.any_data.any_llc_miss\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf811\000\00000\000\000 */
{ 1924747 }, /* offcore_response.any_data.other_local_dram\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000 */
{ 1926188 }, /* offcore_response.any_data.remote_dram\000\000memory\000REQUEST = ANY_DATA read and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000 */
{ 1937296 }, /* offcore_response.any_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3044\000\00000\000\000 */
{ 1937622 }, /* offcore_response.any_ifetch.any_llc_miss\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf844\000\00000\000\000 */
{ 1940587 }, /* offcore_response.any_ifetch.other_local_dram\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000 */
{ 1942040 }, /* offcore_response.any_ifetch.remote_dram\000\000memory\000REQUEST = ANY IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000 */
{ 1960677 }, /* offcore_response.any_request.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x30ff\000\00000\000\000 */
{ 1961004 }, /* offcore_response.any_request.any_llc_miss\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf8ff\000\00000\000\000 */
{ 1972823 }, /* offcore_response.any_request.other_local_dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40ff\000\00000\000\000 */
{ 1975030 }, /* offcore_response.any_request.remote_dram\000\000memory\000REQUEST = ANY_REQUEST and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20ff\000\00000\000\000 */
{ 1975839 }, /* offcore_response.any_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = ANY RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3022\000\00000\000\000 */
{ 1976158 }, /* offcore_response.any_rfo.any_llc_miss\000\000memory\000REQUEST = ANY RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf822\000\00000\000\000 */
{ 1988520 }, /* offcore_response.any_rfo.other_local_dram\000\000memory\000REQUEST = ANY RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000 */
{ 1990773 }, /* offcore_response.any_rfo.remote_dram\000\000memory\000REQUEST = ANY RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000 */
{ 1998582 }, /* offcore_response.corewb.any_dram_and_remote_fwd\000\000memory\000REQUEST = CORE_WB and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3008\000\00000\000\000 */
{ 1998897 }, /* offcore_response.corewb.any_llc_miss\000\000memory\000REQUEST = CORE_WB and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf808\000\00000\000\000 */
{ 2009768 }, /* offcore_response.corewb.other_local_dram\000\000memory\000REQUEST = CORE_WB and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000 */
{ 2011663 }, /* offcore_response.corewb.remote_dram\000\000memory\000REQUEST = CORE_WB and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000 */
{ 2013667 }, /* offcore_response.data_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3077\000\00000\000\000 */
{ 2014012 }, /* offcore_response.data_ifetch.any_llc_miss\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf877\000\00000\000\000 */
{ 2017163 }, /* offcore_response.data_ifetch.other_local_dram\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000 */
{ 2018739 }, /* offcore_response.data_ifetch.remote_dram\000\000memory\000REQUEST = DATA_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000 */
{ 2019555 }, /* offcore_response.data_in.any_dram_and_remote_fwd\000\000memory\000REQUEST = DATA_IN and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3033\000\00000\000\000 */
{ 2019885 }, /* offcore_response.data_in.any_llc_miss\000\000memory\000REQUEST = DATA_IN and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf833\000\00000\000\000 */
{ 2023112 }, /* offcore_response.data_in.other_local_dram\000\000memory\000REQUEST = DATA_IN and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000 */
{ 2024625 }, /* offcore_response.data_in.remote_dram\000\000memory\000REQUEST = DATA_IN and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000 */
{ 2072734 }, /* offcore_response.demand_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3003\000\00000\000\000 */
{ 2073073 }, /* offcore_response.demand_data.any_llc_miss\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf803\000\00000\000\000 */
{ 2076164 }, /* offcore_response.demand_data.other_local_dram\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000 */
{ 2077698 }, /* offcore_response.demand_data.remote_dram\000\000memory\000REQUEST = DEMAND_DATA and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000 */
{ 2078559 }, /* offcore_response.demand_data_rd.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3001\000\00000\000\000 */
{ 2078904 }, /* offcore_response.demand_data_rd.any_llc_miss\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf801\000\00000\000\000 */
{ 2122929 }, /* offcore_response.demand_data_rd.other_local_dram\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000 */
{ 2126758 }, /* offcore_response.demand_data_rd.remote_dram\000\000memory\000REQUEST = DEMAND_DATA_RD and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000 */
{ 2130586 }, /* offcore_response.demand_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3004\000\00000\000\000 */
{ 2130928 }, /* offcore_response.demand_ifetch.any_llc_miss\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf804\000\00000\000\000 */
{ 2134236 }, /* offcore_response.demand_ifetch.other_local_dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000 */
{ 2135771 }, /* offcore_response.demand_ifetch.remote_dram\000\000memory\000REQUEST = DEMAND_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000 */
{ 2136616 }, /* offcore_response.demand_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3002\000\00000\000\000 */
{ 2136951 }, /* offcore_response.demand_rfo.any_llc_miss\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf802\000\00000\000\000 */
{ 2181141 }, /* offcore_response.demand_rfo.other_local_dram\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000 */
{ 2185031 }, /* offcore_response.demand_rfo.remote_dram\000\000memory\000REQUEST = DEMAND_RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000 */
{ 2195001 }, /* offcore_response.other.any_dram_and_remote_fwd\000\000memory\000REQUEST = OTHER and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3080\000\00000\000\000 */
{ 2195316 }, /* offcore_response.other.any_llc_miss\000\000memory\000REQUEST = OTHER and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf880\000\00000\000\000 */
{ 2220898 }, /* offcore_response.other.other_local_dram\000\000memory\000REQUEST = OTHER and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4080\000\00000\000\000 */
{ 2223355 }, /* offcore_response.other.remote_dram\000\000memory\000REQUEST = OTHER and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000 */
{ 2241914 }, /* offcore_response.pf_data.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_DATA and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3050\000\00000\000\000 */
{ 2242399 }, /* offcore_response.pf_data.any_llc_miss\000\000memory\000REQUEST = PF_DATA and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf850\000\00000\000\000 */
{ 2246450 }, /* offcore_response.pf_data.other_local_dram\000\000memory\000REQUEST = PF_DATA and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4050\000\00000\000\000 */
{ 2248450 }, /* offcore_response.pf_data.remote_dram\000\000memory\000REQUEST = PF_DATA and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2050\000\00000\000\000 */
{ 2249283 }, /* offcore_response.pf_data_rd.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3010\000\00000\000\000 */
{ 2249618 }, /* offcore_response.pf_data_rd.any_llc_miss\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf810\000\00000\000\000 */
{ 2252862 }, /* offcore_response.pf_data_rd.other_local_dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000 */
{ 2254378 }, /* offcore_response.pf_data_rd.remote_dram\000\000memory\000REQUEST = PF_DATA_RD and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000 */
{ 2255205 }, /* offcore_response.pf_ifetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_RFO and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3040\000\00000\000\000 */
{ 2255534 }, /* offcore_response.pf_ifetch.any_llc_miss\000\000memory\000REQUEST = PF_RFO and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf840\000\00000\000\000 */
{ 2258875 }, /* offcore_response.pf_ifetch.other_local_dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000 */
{ 2260374 }, /* offcore_response.pf_ifetch.remote_dram\000\000memory\000REQUEST = PF_RFO and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000 */
{ 2431240 }, /* offcore_response.pf_rfo.any_dram_and_remote_fwd\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3020\000\00000\000\000 */
{ 2431568 }, /* offcore_response.pf_rfo.any_llc_miss\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf820\000\00000\000\000 */
{ 2434563 }, /* offcore_response.pf_rfo.other_local_dram\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000 */
{ 2436055 }, /* offcore_response.pf_rfo.remote_dram\000\000memory\000REQUEST = PF_IFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000 */
{ 2441153 }, /* offcore_response.prefetch.any_dram_and_remote_fwd\000\000memory\000REQUEST = PREFETCH and RESPONSE = ANY_DRAM AND REMOTE_FWD\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3070\000\00000\000\000 */
{ 2441480 }, /* offcore_response.prefetch.any_llc_miss\000\000memory\000REQUEST = PREFETCH and RESPONSE = ANY_LLC_MISS\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xf870\000\00000\000\000 */
{ 2444463 }, /* offcore_response.prefetch.other_local_dram\000\000memory\000REQUEST = PREFETCH and RESPONSE = OTHER_LOCAL_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000 */
{ 2445943 }, /* offcore_response.prefetch.remote_dram\000\000memory\000REQUEST = PREFETCH and RESPONSE = REMOTE_DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000 */
{ 835049 }, /* es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000 */
{ 1075635 }, /* io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114741 }, /* l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000 */
{ 1114843 }, /* l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114927 }, /* l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000 */
{ 1115015 }, /* l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000 */
{ 1189817 }, /* large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1228602 }, /* load_block.overlap_store\000\000other\000Loads that partially overlap an earlier store\000event=0x3,period=200000,umask=0x2\000\00000\000\000 */
{ 1228719 }, /* load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000 */
{ 1228806 }, /* load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000 */
{ 1228902 }, /* load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1229004 }, /* load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000 */
{ 2476952 }, /* partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000 */
{ 2521171 }, /* sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000 */
{ 2521260 }, /* seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000 */
{ 2528735 }, /* snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000 */
{ 2528831 }, /* snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000 */
{ 2528929 }, /* snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000 */
{ 2529217 }, /* snoopq_requests.code\000\000other\000Snoop code requests\000event=0xb4,period=100000,umask=0x4\000\00000\000\000 */
{ 2529305 }, /* snoopq_requests.data\000\000other\000Snoop data requests\000event=0xb4,period=100000,umask=0x1\000\00000\000\000 */
{ 2529393 }, /* snoopq_requests.invalidate\000\000other\000Snoop invalidate requests\000event=0xb4,period=100000,umask=0x2\000\00000\000\000 */
{ 2529493 }, /* snoopq_requests_outstanding.code\000\000other\000Outstanding snoop code requests\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529606 }, /* snoopq_requests_outstanding.code_not_empty\000\000other\000Cycles snoop code requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529739 }, /* snoopq_requests_outstanding.data\000\000other\000Outstanding snoop data requests\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529852 }, /* snoopq_requests_outstanding.data_not_empty\000\000other\000Cycles snoop data requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529985 }, /* snoopq_requests_outstanding.invalidate\000\000other\000Outstanding snoop invalidate requests\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530110 }, /* snoopq_requests_outstanding.invalidate_not_empty\000\000other\000Cycles snoop invalidate requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530255 }, /* sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000 */
{ 467271 }, /* arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 467371 }, /* arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 471330 }, /* arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000 */
{ 473654 }, /* baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000 */
{ 473765 }, /* baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 473868 }, /* baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000 */
{ 487276 }, /* bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000 */
{ 487380 }, /* bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000 */
{ 487482 }, /* bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 491001 }, /* br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000 */
{ 491098 }, /* br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000 */
{ 491207 }, /* br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000 */
{ 491309 }, /* br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000 */
{ 491426 }, /* br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000 */
{ 491540 }, /* br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000 */
{ 491656 }, /* br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000 */
{ 491753 }, /* br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000 */
{ 492324 }, /* br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000 */
{ 492432 }, /* br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000 */
{ 498319 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000 */
{ 506620 }, /* br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000 */
{ 515982 }, /* br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000 */
{ 530639 }, /* br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000 */
{ 530737 }, /* br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000 */
{ 530847 }, /* br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000 */
{ 530961 }, /* br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000 */
{ 531333 }, /* br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000 */
{ 531459 }, /* br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000 */
{ 531587 }, /* br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000 */
{ 531696 }, /* br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000 */
{ 532460 }, /* br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000 */
{ 532571 }, /* br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000 */
{ 538916 }, /* br_misp_retired.all_branches\000\000pipeline\000Mispredicted retired branch instructions (Precise Event)\000event=0xc5,period=20000,umask=0x4\000\00000\000\000 */
{ 547126 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional retired branches (Precise Event)\000event=0xc5,period=20000,umask=0x1\000\00000\000\000 */
{ 554975 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000 */
{ 620914 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 622158 }, /* cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000 */
{ 643775 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000 */
{ 647207 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000 */
{ 649803 }, /* cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000 */
{ 1040461 }, /* ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000 */
{ 1040570 }, /* ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000 */
{ 1040907 }, /* ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 1042997 }, /* ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 1043097 }, /* ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000 */
{ 1043183 }, /* inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000 */
{ 1043960 }, /* inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000 */
{ 1044092 }, /* inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000 */
{ 1047147 }, /* inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053554 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1057737 }, /* inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000 */
{ 1063146 }, /* inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1063652 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1064586 }, /* inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000 */
{ 1231057 }, /* load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000 */
{ 1283188 }, /* lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1285888 }, /* lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1286788 }, /* lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000 */
{ 1289354 }, /* machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000 */
{ 1293852 }, /* machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000 */
{ 1300312 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000 */
{ 2483994 }, /* rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000 */
{ 2484081 }, /* rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2484167 }, /* rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2484269 }, /* rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2484373 }, /* rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2501064 }, /* resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2502029 }, /* resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000 */
{ 2502398 }, /* resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2502656 }, /* resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000 */
{ 2502894 }, /* resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000 */
{ 2503359 }, /* resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000 */
{ 2504132 }, /* resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2506545 }, /* resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2536082 }, /* ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000 */
{ 2536212 }, /* ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000 */
{ 2536342 }, /* ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000 */
{ 2536472 }, /* ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000 */
{ 2536602 }, /* ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000 */
{ 6178001 }, /* uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178955 }, /* uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6179066 }, /* uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6179169 }, /* uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6179294 }, /* uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6193659 }, /* uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6193804 }, /* uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199088 }, /* uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199380 }, /* uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199692 }, /* uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199843 }, /* uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6204390 }, /* uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6204143 }, /* uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204248 }, /* uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204485 }, /* uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6204580 }, /* uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000 */
{ 6204696 }, /* uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6204815 }, /* uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6204934 }, /* uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000 */
{ 6205054 }, /* uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000 */
{ 6213590 }, /* uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216019 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216805 }, /* uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6217626 }, /* uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000 */
{ 6219127 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6225258 }, /* uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6227775 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000 */
{ 6231023 }, /* uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000 */
{ 6233951 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000 */
{ 6238074 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6240810 }, /* uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 787008 }, /* dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000 */
{ 787632 }, /* dtlb_load_misses.large_walk_completed\000\000virtual memory\000DTLB load miss large page walks\000event=0x8,period=200000,umask=0x80\000\00000\000\000 */
{ 789416 }, /* dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000 */
{ 789810 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000 */
{ 794527 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000 */
{ 806100 }, /* dtlb_load_misses.walk_cycles\000\000virtual memory\000DTLB load miss page walk cycles\000event=0x8,period=200000,umask=0x4\000\00000\000\000 */
{ 809538 }, /* dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000 */
{ 809622 }, /* dtlb_misses.large_walk_completed\000\000virtual memory\000DTLB miss large page walks\000event=0x49,period=200000,umask=0x80\000\00000\000\000 */
{ 809935 }, /* dtlb_misses.pde_miss\000\000virtual memory\000DTLB misses caused by low part of address\000event=0x49,period=200000,umask=0x20\000\00000\000\000 */
{ 810055 }, /* dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000 */
{ 810178 }, /* dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000 */
{ 810282 }, /* dtlb_misses.walk_cycles\000\000virtual memory\000DTLB miss page walk cycles\000event=0x49,period=2000000,umask=0x4\000\00000\000\000 */
{ 833736 }, /* ept.walk_cycles\000\000virtual memory\000Extended Page Table walk cycles\000event=0x4f,period=2000000,umask=0x10\000\00000\000\000 */
{ 1079563 }, /* itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000 */
{ 1079644 }, /* itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000 */
{ 1079777 }, /* itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000 */
{ 1080091 }, /* itlb_misses.large_walk_completed\000\000virtual memory\000ITLB miss large page walks\000event=0x85,period=200000,umask=0x80\000\00000\000\000 */
{ 1087383 }, /* itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000 */
{ 1095723 }, /* itlb_misses.walk_cycles\000\000virtual memory\000ITLB miss page walk cycles\000event=0x85,period=2000000,umask=0x4\000\00000\000\000 */
{ 1331956 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000 */
{ 1368683 }, /* mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__westmereep_sp[] = {
{ 571421 }, /* cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000 */
{ 571509 }, /* cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000 */
{ 1100466 }, /* l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000 */
{ 1100562 }, /* l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000 */
{ 1100662 }, /* l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000 */
{ 1100773 }, /* l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104580 }, /* l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000 */
{ 1113958 }, /* l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000 */
{ 1114052 }, /* l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000 */
{ 1114152 }, /* l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000 */
{ 1114262 }, /* l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000 */
{ 1114358 }, /* l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000 */
{ 1114463 }, /* l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000 */
{ 1114559 }, /* l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000 */
{ 1114645 }, /* l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000 */
{ 1121826 }, /* l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000 */
{ 1121913 }, /* l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000 */
{ 1122021 }, /* l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000 */
{ 1122138 }, /* l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000 */
{ 1122246 }, /* l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000 */
{ 1122343 }, /* l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000 */
{ 1122451 }, /* l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1122560 }, /* l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000 */
{ 1122682 }, /* l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000 */
{ 1122791 }, /* l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000 */
{ 1122890 }, /* l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000 */
{ 1129601 }, /* l2_lines_in.any\000\000cache\000L2 lines alloacated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000 */
{ 1130213 }, /* l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000 */
{ 1131206 }, /* l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000 */
{ 1131570 }, /* l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000 */
{ 1132175 }, /* l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000 */
{ 1132697 }, /* l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000 */
{ 1135641 }, /* l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000 */
{ 1135755 }, /* l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000 */
{ 1167724 }, /* l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000 */
{ 1167818 }, /* l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000 */
{ 1167915 }, /* l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000 */
{ 1168737 }, /* l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000 */
{ 1168813 }, /* l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000 */
{ 1168892 }, /* l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000 */
{ 1168966 }, /* l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000 */
{ 1172018 }, /* l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1172105 }, /* l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000 */
{ 1172195 }, /* l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000 */
{ 1172443 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000 */
{ 1173756 }, /* l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000 */
{ 1174646 }, /* l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000 */
{ 1175586 }, /* l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000 */
{ 1183427 }, /* l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000 */
{ 1183515 }, /* l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000 */
{ 1183605 }, /* l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000 */
{ 1183709 }, /* l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000 */
{ 1183813 }, /* l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000 */
{ 1183902 }, /* l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000 */
{ 1183999 }, /* l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000 */
{ 1184086 }, /* l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000 */
{ 1184856 }, /* l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000 */
{ 1184957 }, /* l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000 */
{ 1185066 }, /* l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000 */
{ 1185176 }, /* l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000 */
{ 1185277 }, /* l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000 */
{ 1185368 }, /* l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000 */
{ 1185469 }, /* l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000 */
{ 1185577 }, /* l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000 */
{ 1185686 }, /* l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000 */
{ 1185786 }, /* l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000 */
{ 1185876 }, /* l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000 */
{ 1249469 }, /* longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000 */
{ 1253301 }, /* longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1312836 }, /* mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000 */
{ 1312997 }, /* mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000 */
{ 1313161 }, /* mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000 */
{ 1313488 }, /* mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000 */
{ 1313323 }, /* mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000 */
{ 1313649 }, /* mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000 */
{ 1313812 }, /* mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000 */
{ 1314139 }, /* mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000 */
{ 1313974 }, /* mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000 */
{ 1314463 }, /* mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000 */
{ 1314299 }, /* mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000 */
{ 1314621 }, /* mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000 */
{ 1314783 }, /* mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000 */
{ 1315107 }, /* mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000 */
{ 1314943 }, /* mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000 */
{ 1315265 }, /* mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1319310 }, /* mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000 */
{ 1333824 }, /* mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000 */
{ 1336151 }, /* mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1336860 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000 */
{ 1340299 }, /* mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000 */
{ 1340426 }, /* mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000 */
{ 1341515 }, /* mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000 */
{ 1385990 }, /* mem_uncore_retired.local_dram\000\000cache\000Load instructions retired with a data source of local DRAM or locally homed remote hitm (Precise Event)\000event=0xf,period=10000,umask=0x10\000\00000\000\000 */
{ 1386689 }, /* mem_uncore_retired.other_core_l2_hitm\000\000cache\000Load instructions retired that HIT modified data in sibling core (Precise Event)\000event=0xf,period=40000,umask=0x2\000\00000\000\000 */
{ 1386853 }, /* mem_uncore_retired.remote_cache_local_home_hit\000\000cache\000Load instructions retired remote cache HIT data source (Precise Event)\000event=0xf,period=20000,umask=0x8\000\00000\000\000 */
{ 1387181 }, /* mem_uncore_retired.remote_dram\000\000cache\000Load instructions retired remote DRAM and remote home-remote cache HITM (Precise Event)\000event=0xf,period=10000,umask=0x20\000\00000\000\000 */
{ 1387493 }, /* mem_uncore_retired.uncacheable\000\000cache\000Load instructions retired IO (Precise Event)\000event=0xf,period=4000,umask=0x80\000\00000\000\000 */
{ 1747290 }, /* offcore_requests.any\000\000cache\000All offcore requests\000event=0xb0,period=100000,umask=0x80\000\00000\000\000 */
{ 1747101 }, /* offcore_requests.any.read\000\000cache\000Offcore read requests\000event=0xb0,period=100000,umask=0x8\000\00000\000\000 */
{ 1747196 }, /* offcore_requests.any.rfo\000\000cache\000Offcore RFO requests\000event=0xb0,period=100000,umask=0x10\000\00000\000\000 */
{ 1748025 }, /* offcore_requests.demand.read_code\000\000cache\000Offcore demand code read requests\000event=0xb0,period=100000,umask=0x2\000\00000\000\000 */
{ 1748140 }, /* offcore_requests.demand.read_data\000\000cache\000Offcore demand data read requests\000event=0xb0,period=100000,umask=0x1\000\00000\000\000 */
{ 1748255 }, /* offcore_requests.demand.rfo\000\000cache\000Offcore demand RFO requests\000event=0xb0,period=100000,umask=0x4\000\00000\000\000 */
{ 1752159 }, /* offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000 */
{ 1752907 }, /* offcore_requests.uncached_mem\000\000cache\000Offcore uncached memory accesses\000event=0xb0,period=100000,umask=0x20\000\00000\000\000 */
{ 1757706 }, /* offcore_requests_outstanding.any.read\000\000cache\000Outstanding offcore reads\000event=0x60,period=2000000,umask=0x8\000\00000\000\000 */
{ 1757818 }, /* offcore_requests_outstanding.any.read_not_empty\000\000cache\000Cycles offcore reads busy\000event=0x60,cmask=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 1769044 }, /* offcore_requests_outstanding.demand.read_code\000\000cache\000Outstanding offcore demand code reads\000event=0x60,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769176 }, /* offcore_requests_outstanding.demand.read_code_not_empty\000\000cache\000Cycles offcore demand code read busy\000event=0x60,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769325 }, /* offcore_requests_outstanding.demand.read_data\000\000cache\000Outstanding offcore demand data reads\000event=0x60,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769457 }, /* offcore_requests_outstanding.demand.read_data_not_empty\000\000cache\000Cycles offcore demand data read busy\000event=0x60,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769606 }, /* offcore_requests_outstanding.demand.rfo\000\000cache\000Outstanding offcore demand RFOs\000event=0x60,period=2000000,umask=0x4\000\00000\000\000 */
{ 1769726 }, /* offcore_requests_outstanding.demand.rfo_not_empty\000\000cache\000Cycles offcore demand RFOs busy\000event=0x60,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 1780856 }, /* offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000 */
{ 1921008 }, /* offcore_response.any_data.any_cache_dram\000\000cache\000Offcore data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F11\000\00000\000\000 */
{ 1921952 }, /* offcore_response.any_data.any_location\000\000cache\000All offcore data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF11\000\00000\000\000 */
{ 1922237 }, /* offcore_response.any_data.io_csr_mmio\000\000cache\000Offcore data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000 */
{ 1922551 }, /* offcore_response.any_data.llc_hit_no_other_core\000\000cache\000Offcore data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000 */
{ 1922910 }, /* offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000Offcore data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000 */
{ 1923266 }, /* offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000Offcore data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000 */
{ 1923627 }, /* offcore_response.any_data.local_cache\000\000cache\000Offcore data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000 */
{ 1923924 }, /* offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2711\000\00000\000\000 */
{ 1924913 }, /* offcore_response.any_data.remote_cache\000\000cache\000Offcore data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1811\000\00000\000\000 */
{ 1925237 }, /* offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5811\000\00000\000\000 */
{ 1925409 }, /* offcore_response.any_data.remote_cache_hit\000\000cache\000Offcore data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000 */
{ 1925564 }, /* offcore_response.any_data.remote_cache_hitm\000\000cache\000Offcore data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000 */
{ 1936832 }, /* offcore_response.any_ifetch.any_cache_dram\000\000cache\000Offcore code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F44\000\00000\000\000 */
{ 1937779 }, /* offcore_response.any_ifetch.any_location\000\000cache\000All offcore code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF44\000\00000\000\000 */
{ 1938065 }, /* offcore_response.any_ifetch.io_csr_mmio\000\000cache\000Offcore code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000 */
{ 1938380 }, /* offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000 */
{ 1938740 }, /* offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000 */
{ 1939097 }, /* offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000 */
{ 1939459 }, /* offcore_response.any_ifetch.local_cache\000\000cache\000Offcore code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000 */
{ 1939757 }, /* offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2744\000\00000\000\000 */
{ 1940752 }, /* offcore_response.any_ifetch.remote_cache\000\000cache\000Offcore code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1844\000\00000\000\000 */
{ 1941080 }, /* offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5844\000\00000\000\000 */
{ 1941254 }, /* offcore_response.any_ifetch.remote_cache_hit\000\000cache\000Offcore code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000 */
{ 1941411 }, /* offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000Offcore code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000 */
{ 1960213 }, /* offcore_response.any_request.any_cache_dram\000\000cache\000Offcore requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FFF\000\00000\000\000 */
{ 1961163 }, /* offcore_response.any_request.any_location\000\000cache\000All offcore requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFFFF\000\00000\000\000 */
{ 1963126 }, /* offcore_response.any_request.io_csr_mmio\000\000cache\000Offcore requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80FF\000\00000\000\000 */
{ 1969757 }, /* offcore_response.any_request.llc_hit_no_other_core\000\000cache\000Offcore requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1FF\000\00000\000\000 */
{ 1970118 }, /* offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000Offcore requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2FF\000\00000\000\000 */
{ 1970476 }, /* offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000Offcore requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4FF\000\00000\000\000 */
{ 1971122 }, /* offcore_response.any_request.local_cache\000\000cache\000Offcore requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FF\000\00000\000\000 */
{ 1971421 }, /* offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x27FF\000\00000\000\000 */
{ 1973747 }, /* offcore_response.any_request.remote_cache\000\000cache\000Offcore requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x18FF\000\00000\000\000 */
{ 1974073 }, /* offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x58FF\000\00000\000\000 */
{ 1974246 }, /* offcore_response.any_request.remote_cache_hit\000\000cache\000Offcore requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10FF\000\00000\000\000 */
{ 1974402 }, /* offcore_response.any_request.remote_cache_hitm\000\000cache\000Offcore requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8FF\000\00000\000\000 */
{ 1975383 }, /* offcore_response.any_rfo.any_cache_dram\000\000cache\000Offcore RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F22\000\00000\000\000 */
{ 1976309 }, /* offcore_response.any_rfo.any_location\000\000cache\000All offcore RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF22\000\00000\000\000 */
{ 1977996 }, /* offcore_response.any_rfo.io_csr_mmio\000\000cache\000Offcore RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000 */
{ 1985711 }, /* offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000Offcore RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000 */
{ 1986064 }, /* offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000Offcore RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000 */
{ 1986414 }, /* offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000 */
{ 1986769 }, /* offcore_response.any_rfo.local_cache\000\000cache\000Offcore RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000 */
{ 1987060 }, /* offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2722\000\00000\000\000 */
{ 1989498 }, /* offcore_response.any_rfo.remote_cache\000\000cache\000Offcore RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1822\000\00000\000\000 */
{ 1989824 }, /* offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5822\000\00000\000\000 */
{ 1989997 }, /* offcore_response.any_rfo.remote_cache_hit\000\000cache\000Offcore RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000 */
{ 1990153 }, /* offcore_response.any_rfo.remote_cache_hitm\000\000cache\000Offcore RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000 */
{ 1998153 }, /* offcore_response.corewb.any_cache_dram\000\000cache\000Offcore writebacks to any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F08\000\00000\000\000 */
{ 1999047 }, /* offcore_response.corewb.any_location\000\000cache\000All offcore writebacks\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF08\000\00000\000\000 */
{ 2000260 }, /* offcore_response.corewb.io_csr_mmio\000\000cache\000Offcore writebacks to the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000 */
{ 2007876 }, /* offcore_response.corewb.llc_hit_no_other_core\000\000cache\000Offcore writebacks to the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000 */
{ 2008383 }, /* offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000Offcore writebacks to the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000 */
{ 2008724 }, /* offcore_response.corewb.local_cache\000\000cache\000Offcore writebacks to the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000 */
{ 2009001 }, /* offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2708\000\00000\000\000 */
{ 2010460 }, /* offcore_response.corewb.remote_cache\000\000cache\000Offcore writebacks to a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1808\000\00000\000\000 */
{ 2010760 }, /* offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5808\000\00000\000\000 */
{ 2010920 }, /* offcore_response.corewb.remote_cache_hit\000\000cache\000Offcore writebacks that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000 */
{ 2011073 }, /* offcore_response.corewb.remote_cache_hitm\000\000cache\000Offcore writebacks that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000 */
{ 2013167 }, /* offcore_response.data_ifetch.any_cache_dram\000\000cache\000Offcore code or data read requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F77\000\00000\000\000 */
{ 2014171 }, /* offcore_response.data_ifetch.any_location\000\000cache\000All offcore code or data read requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF77\000\00000\000\000 */
{ 2014476 }, /* offcore_response.data_ifetch.io_csr_mmio\000\000cache\000Offcore code or data read requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000 */
{ 2014810 }, /* offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code or data read requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000 */
{ 2015189 }, /* offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code or data read requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000 */
{ 2015565 }, /* offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code or data read requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000 */
{ 2015946 }, /* offcore_response.data_ifetch.local_cache\000\000cache\000Offcore code or data read requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000 */
{ 2016263 }, /* offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2777\000\00000\000\000 */
{ 2017330 }, /* offcore_response.data_ifetch.remote_cache\000\000cache\000Offcore code or data read requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1877\000\00000\000\000 */
{ 2017692 }, /* offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5877\000\00000\000\000 */
{ 2017883 }, /* offcore_response.data_ifetch.remote_cache_hit\000\000cache\000Offcore code or data read requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000 */
{ 2018057 }, /* offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000Offcore code or data read requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000 */
{ 2019092 }, /* offcore_response.data_in.any_cache_dram\000\000cache\000Offcore request = all data, response = any cache_dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F33\000\00000\000\000 */
{ 2020036 }, /* offcore_response.data_in.any_location\000\000cache\000Offcore request = all data, response = any location\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF33\000\00000\000\000 */
{ 2020500 }, /* offcore_response.data_in.io_csr_mmio\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000 */
{ 2020828 }, /* offcore_response.data_in.llc_hit_no_other_core\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000 */
{ 2021201 }, /* offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000 */
{ 2021571 }, /* offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000 */
{ 2021946 }, /* offcore_response.data_in.local_cache\000\000cache\000Offcore request = all data, response = local cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000 */
{ 2022246 }, /* offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2733\000\00000\000\000 */
{ 2023271 }, /* offcore_response.data_in.remote_cache\000\000cache\000Offcore request = all data, response = remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1833\000\00000\000\000 */
{ 2023596 }, /* offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5833\000\00000\000\000 */
{ 2023765 }, /* offcore_response.data_in.remote_cache_hit\000\000cache\000Offcore data reads, RFOs, and prefetches that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000 */
{ 2023941 }, /* offcore_response.data_in.remote_cache_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000 */
{ 2072246 }, /* offcore_response.demand_data.any_cache_dram\000\000cache\000Offcore demand data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F03\000\00000\000\000 */
{ 2073232 }, /* offcore_response.demand_data.any_location\000\000cache\000All offcore demand data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF03\000\00000\000\000 */
{ 2073531 }, /* offcore_response.demand_data.io_csr_mmio\000\000cache\000Offcore demand data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000 */
{ 2073859 }, /* offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000Offcore demand data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000 */
{ 2074232 }, /* offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000Offcore demand data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000 */
{ 2074602 }, /* offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000Offcore demand data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000 */
{ 2074977 }, /* offcore_response.demand_data.local_cache\000\000cache\000Offcore demand data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000 */
{ 2075288 }, /* offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2703\000\00000\000\000 */
{ 2076331 }, /* offcore_response.demand_data.remote_cache\000\000cache\000Offcore demand data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1803\000\00000\000\000 */
{ 2076681 }, /* offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5803\000\00000\000\000 */
{ 2076866 }, /* offcore_response.demand_data.remote_cache_hit\000\000cache\000Offcore demand data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000 */
{ 2077034 }, /* offcore_response.demand_data.remote_cache_hitm\000\000cache\000Offcore demand data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000 */
{ 2078065 }, /* offcore_response.demand_data_rd.any_cache_dram\000\000cache\000Offcore demand data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F01\000\00000\000\000 */
{ 2079069 }, /* offcore_response.demand_data_rd.any_location\000\000cache\000All offcore demand data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF01\000\00000\000\000 */
{ 2081657 }, /* offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000Offcore demand data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000 */
{ 2118081 }, /* offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000Offcore demand data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000 */
{ 2118460 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore demand data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000 */
{ 2118836 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore demand data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000 */
{ 2121036 }, /* offcore_response.demand_data_rd.local_cache\000\000cache\000Offcore demand data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000 */
{ 2121353 }, /* offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2701\000\00000\000\000 */
{ 2125385 }, /* offcore_response.demand_data_rd.remote_cache\000\000cache\000Offcore demand data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1801\000\00000\000\000 */
{ 2125735 }, /* offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5801\000\00000\000\000 */
{ 2125920 }, /* offcore_response.demand_data_rd.remote_cache_hit\000\000cache\000Offcore demand data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000 */
{ 2126088 }, /* offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000Offcore demand data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000 */
{ 2130096 }, /* offcore_response.demand_ifetch.any_cache_dram\000\000cache\000Offcore demand code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F04\000\00000\000\000 */
{ 2131091 }, /* offcore_response.demand_ifetch.any_location\000\000cache\000All offcore demand code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF04\000\00000\000\000 */
{ 2131393 }, /* offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000Offcore demand code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000 */
{ 2131724 }, /* offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000Offcore demand code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000 */
{ 2132100 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore demand code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000 */
{ 2132473 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore demand code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000 */
{ 2133046 }, /* offcore_response.demand_ifetch.local_cache\000\000cache\000Offcore demand code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000 */
{ 2133360 }, /* offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2704\000\00000\000\000 */
{ 2134407 }, /* offcore_response.demand_ifetch.remote_cache\000\000cache\000Offcore demand code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1804\000\00000\000\000 */
{ 2134755 }, /* offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5804\000\00000\000\000 */
{ 2134939 }, /* offcore_response.demand_ifetch.remote_cache_hit\000\000cache\000Offcore demand code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000 */
{ 2135106 }, /* offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000Offcore demand code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000 */
{ 2136134 }, /* offcore_response.demand_rfo.any_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F02\000\00000\000\000 */
{ 2137108 }, /* offcore_response.demand_rfo.any_location\000\000cache\000All offcore demand RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF02\000\00000\000\000 */
{ 2139468 }, /* offcore_response.demand_rfo.io_csr_mmio\000\000cache\000Offcore demand RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000 */
{ 2177181 }, /* offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000Offcore demand RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000 */
{ 2177550 }, /* offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000Offcore demand RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000 */
{ 2177916 }, /* offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore demand RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000 */
{ 2179346 }, /* offcore_response.demand_rfo.local_cache\000\000cache\000Offcore demand RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000 */
{ 2179653 }, /* offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2702\000\00000\000\000 */
{ 2183680 }, /* offcore_response.demand_rfo.remote_cache\000\000cache\000Offcore demand RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1802\000\00000\000\000 */
{ 2184026 }, /* offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5802\000\00000\000\000 */
{ 2184209 }, /* offcore_response.demand_rfo.remote_cache_hit\000\000cache\000Offcore demand RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000 */
{ 2184375 }, /* offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000Offcore demand RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000 */
{ 2194549 }, /* offcore_response.other.any_cache_dram\000\000cache\000Offcore other requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F80\000\00000\000\000 */
{ 2195463 }, /* offcore_response.other.any_location\000\000cache\000All offcore other requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF80\000\00000\000\000 */
{ 2196350 }, /* offcore_response.other.io_csr_mmio\000\000cache\000Offcore other requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000 */
{ 2218865 }, /* offcore_response.other.llc_hit_no_other_core\000\000cache\000Offcore other requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000 */
{ 2219214 }, /* offcore_response.other.llc_hit_other_core_hit\000\000cache\000Offcore other requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000 */
{ 2219560 }, /* offcore_response.other.llc_hit_other_core_hitm\000\000cache\000Offcore other requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000 */
{ 2219911 }, /* offcore_response.other.local_cache\000\000cache\000Offcore other requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000 */
{ 2220198 }, /* offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2780\000\00000\000\000 */
{ 2222084 }, /* offcore_response.other.remote_cache\000\000cache\000Offcore other requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1880\000\00000\000\000 */
{ 2222410 }, /* offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5880\000\00000\000\000 */
{ 2222583 }, /* offcore_response.other.remote_cache_hit\000\000cache\000Offcore other requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000 */
{ 2222739 }, /* offcore_response.other.remote_cache_hitm\000\000cache\000Offcore other requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000 */
{ 2241284 }, /* offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F50\000\00000\000\000 */
{ 2242689 }, /* offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF50\000\00000\000\000 */
{ 2243148 }, /* offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8050\000\00000\000\000 */
{ 2243662 }, /* offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x150\000\00000\000\000 */
{ 2244216 }, /* offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x250\000\00000\000\000 */
{ 2244770 }, /* offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x450\000\00000\000\000 */
{ 2245289 }, /* offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x750\000\00000\000\000 */
{ 2245590 }, /* offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2750\000\00000\000\000 */
{ 2246772 }, /* offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1850\000\00000\000\000 */
{ 2247118 }, /* offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5850\000\00000\000\000 */
{ 2247467 }, /* offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1050\000\00000\000\000 */
{ 2247800 }, /* offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x850\000\00000\000\000 */
{ 2248801 }, /* offcore_response.pf_data_rd.any_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F10\000\00000\000\000 */
{ 2249775 }, /* offcore_response.pf_data_rd.any_location\000\000cache\000All offcore prefetch data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF10\000\00000\000\000 */
{ 2250070 }, /* offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000Offcore prefetch data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000 */
{ 2250394 }, /* offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000Offcore prefetch data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000 */
{ 2250763 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000 */
{ 2251129 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000 */
{ 2251689 }, /* offcore_response.pf_data_rd.local_cache\000\000cache\000Offcore prefetch data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000 */
{ 2251996 }, /* offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2710\000\00000\000\000 */
{ 2253027 }, /* offcore_response.pf_data_rd.remote_cache\000\000cache\000Offcore prefetch data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1810\000\00000\000\000 */
{ 2253373 }, /* offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5810\000\00000\000\000 */
{ 2253556 }, /* offcore_response.pf_data_rd.remote_cache_hit\000\000cache\000Offcore prefetch data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000 */
{ 2253722 }, /* offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000Offcore prefetch data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000 */
{ 2254730 }, /* offcore_response.pf_ifetch.any_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F40\000\00000\000\000 */
{ 2255686 }, /* offcore_response.pf_ifetch.any_location\000\000cache\000All offcore prefetch code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF40\000\00000\000\000 */
{ 2256127 }, /* offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000Offcore prefetch code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000 */
{ 2256445 }, /* offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000 */
{ 2256808 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000 */
{ 2257168 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000 */
{ 2257717 }, /* offcore_response.pf_ifetch.local_cache\000\000cache\000Offcore prefetch code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000 */
{ 2258018 }, /* offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2740\000\00000\000\000 */
{ 2259035 }, /* offcore_response.pf_ifetch.remote_cache\000\000cache\000Offcore prefetch code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1840\000\00000\000\000 */
{ 2259379 }, /* offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5840\000\00000\000\000 */
{ 2259561 }, /* offcore_response.pf_ifetch.remote_cache_hit\000\000cache\000Offcore prefetch code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000 */
{ 2259726 }, /* offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000Offcore prefetch code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000 */
{ 2430767 }, /* offcore_response.pf_rfo.any_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F20\000\00000\000\000 */
{ 2431720 }, /* offcore_response.pf_rfo.any_location\000\000cache\000All offcore prefetch RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF20\000\00000\000\000 */
{ 2432008 }, /* offcore_response.pf_rfo.io_csr_mmio\000\000cache\000Offcore prefetch RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000 */
{ 2432325 }, /* offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000 */
{ 2432687 }, /* offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000 */
{ 2433046 }, /* offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000 */
{ 2433410 }, /* offcore_response.pf_rfo.local_cache\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000 */
{ 2433710 }, /* offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2720\000\00000\000\000 */
{ 2434723 }, /* offcore_response.pf_rfo.remote_cache\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1820\000\00000\000\000 */
{ 2435065 }, /* offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5820\000\00000\000\000 */
{ 2435246 }, /* offcore_response.pf_rfo.remote_cache_hit\000\000cache\000Offcore prefetch RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000 */
{ 2435410 }, /* offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000Offcore prefetch RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000 */
{ 2440683 }, /* offcore_response.prefetch.any_cache_dram\000\000cache\000Offcore prefetch requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F70\000\00000\000\000 */
{ 2441633 }, /* offcore_response.prefetch.any_location\000\000cache\000All offcore prefetch requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF70\000\00000\000\000 */
{ 2441920 }, /* offcore_response.prefetch.io_csr_mmio\000\000cache\000Offcore prefetch requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000 */
{ 2442236 }, /* offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000 */
{ 2442597 }, /* offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000 */
{ 2442955 }, /* offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000 */
{ 2443318 }, /* offcore_response.prefetch.local_cache\000\000cache\000Offcore prefetch requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000 */
{ 2443617 }, /* offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2770\000\00000\000\000 */
{ 2444624 }, /* offcore_response.prefetch.remote_cache\000\000cache\000Offcore prefetch requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1870\000\00000\000\000 */
{ 2444962 }, /* offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x5870\000\00000\000\000 */
{ 2445141 }, /* offcore_response.prefetch.remote_cache_hit\000\000cache\000Offcore prefetch requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000 */
{ 2445303 }, /* offcore_response.prefetch.remote_cache_hitm\000\000cache\000Offcore prefetch requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000 */
{ 2531564 }, /* sq_misc.lru_hints\000\000cache\000Super Queue LRU hints sent to LLC\000event=0xf4,period=2000000,umask=0x4\000\00000\000\000 */
{ 2532073 }, /* sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000 */
{ 2536735 }, /* store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000 */
{ 2536845 }, /* store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000 */
{ 901660 }, /* fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000 */
{ 902741 }, /* fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000 */
{ 902880 }, /* fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000 */
{ 905570 }, /* fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 905656 }, /* fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000 */
{ 905760 }, /* fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000 */
{ 905885 }, /* fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000 */
{ 905986 }, /* fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000 */
{ 906093 }, /* fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000 */
{ 907996 }, /* fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000 */
{ 908121 }, /* fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 910502 }, /* fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000 */
{ 910623 }, /* fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000 */
{ 910751 }, /* fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524990 }, /* simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000 */
{ 2525101 }, /* simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000 */
{ 2525227 }, /* simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000 */
{ 2525352 }, /* simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000 */
{ 2525473 }, /* simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000 */
{ 2525593 }, /* simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000 */
{ 2525721 }, /* simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000 */
{ 2525836 }, /* simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000 */
{ 2525945 }, /* simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000 */
{ 2526069 }, /* simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000 */
{ 2526192 }, /* simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000 */
{ 2526318 }, /* simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000 */
{ 2526436 }, /* simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000 */
{ 2526562 }, /* simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000 */
{ 1302909 }, /* macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000 */
{ 1303001 }, /* macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000 */
{ 2571312 }, /* two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000 */
{ 1921326 }, /* offcore_response.any_data.any_dram\000\000memory\000Offcore data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6011\000\00000\000\000 */
{ 1921649 }, /* offcore_response.any_data.any_llc_miss\000\000memory\000Offcore data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF811\000\00000\000\000 */
{ 1924250 }, /* offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000 */
{ 1926037 }, /* offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000 */
{ 1937151 }, /* offcore_response.any_ifetch.any_dram\000\000memory\000Offcore code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6044\000\00000\000\000 */
{ 1937475 }, /* offcore_response.any_ifetch.any_llc_miss\000\000memory\000Offcore code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF844\000\00000\000\000 */
{ 1940087 }, /* offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000 */
{ 1941887 }, /* offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000 */
{ 1960533 }, /* offcore_response.any_request.any_dram\000\000memory\000Offcore requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x60FF\000\00000\000\000 */
{ 1960858 }, /* offcore_response.any_request.any_llc_miss\000\000memory\000Offcore requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF8FF\000\00000\000\000 */
{ 1971749 }, /* offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000 */
{ 1974878 }, /* offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000 */
{ 1975695 }, /* offcore_response.any_rfo.any_dram\000\000memory\000Offcore RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6022\000\00000\000\000 */
{ 1976012 }, /* offcore_response.any_rfo.any_llc_miss\000\000memory\000Offcore RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF822\000\00000\000\000 */
{ 1987388 }, /* offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000 */
{ 1990621 }, /* offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000 */
{ 1998451 }, /* offcore_response.corewb.any_dram\000\000memory\000Offcore writebacks to any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6008\000\00000\000\000 */
{ 1998754 }, /* offcore_response.corewb.any_llc_miss\000\000memory\000Offcore writebacks that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF808\000\00000\000\000 */
{ 2009303 }, /* offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000 */
{ 2011524 }, /* offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000 */
{ 2013505 }, /* offcore_response.data_ifetch.any_dram\000\000memory\000Offcore code or data read requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6077\000\00000\000\000 */
{ 2013848 }, /* offcore_response.data_ifetch.any_llc_miss\000\000memory\000Offcore code or data read requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF877\000\00000\000\000 */
{ 2016627 }, /* offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000 */
{ 2018569 }, /* offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000 */
{ 2019406 }, /* offcore_response.data_in.any_dram\000\000memory\000Offcore request = all data, response = any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6033\000\00000\000\000 */
{ 2019728 }, /* offcore_response.data_in.any_llc_miss\000\000memory\000Offcore request = all data, response = any LLC miss\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF833\000\00000\000\000 */
{ 2022580 }, /* offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000 */
{ 2024451 }, /* offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000 */
{ 2072578 }, /* offcore_response.demand_data.any_dram\000\000memory\000Offcore demand data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6003\000\00000\000\000 */
{ 2072915 }, /* offcore_response.demand_data.any_llc_miss\000\000memory\000Offcore demand data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF803\000\00000\000\000 */
{ 2075640 }, /* offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000 */
{ 2077534 }, /* offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000 */
{ 2078403 }, /* offcore_response.demand_data_rd.any_dram\000\000memory\000Offcore demand data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6001\000\00000\000\000 */
{ 2078746 }, /* offcore_response.demand_data_rd.any_llc_miss\000\000memory\000Offcore demand data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF801\000\00000\000\000 */
{ 2121705 }, /* offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000 */
{ 2126594 }, /* offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000 */
{ 2130431 }, /* offcore_response.demand_ifetch.any_dram\000\000memory\000Offcore demand code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6004\000\00000\000\000 */
{ 2130771 }, /* offcore_response.demand_ifetch.any_llc_miss\000\000memory\000Offcore demand code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF804\000\00000\000\000 */
{ 2133710 }, /* offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000 */
{ 2135608 }, /* offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000 */
{ 2136462 }, /* offcore_response.demand_rfo.any_dram\000\000memory\000Offcore demand RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6002\000\00000\000\000 */
{ 2136795 }, /* offcore_response.demand_rfo.any_llc_miss\000\000memory\000Offcore demand RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF802\000\00000\000\000 */
{ 2180001 }, /* offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000 */
{ 2184869 }, /* offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000 */
{ 2194857 }, /* offcore_response.other.any_dram\000\000memory\000Offcore other requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6080\000\00000\000\000 */
{ 2195170 }, /* offcore_response.other.any_llc_miss\000\000memory\000Offcore other requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF880\000\00000\000\000 */
{ 2223203 }, /* offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4080\000\00000\000\000 */
{ 2241760 }, /* offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6050\000\00000\000\000 */
{ 2242243 }, /* offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF850\000\00000\000\000 */
{ 2245938 }, /* offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2050\000\00000\000\000 */
{ 2248288 }, /* offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4050\000\00000\000\000 */
{ 2249129 }, /* offcore_response.pf_data_rd.any_dram\000\000memory\000Offcore prefetch data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6010\000\00000\000\000 */
{ 2249462 }, /* offcore_response.pf_data_rd.any_llc_miss\000\000memory\000Offcore prefetch data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF810\000\00000\000\000 */
{ 2252344 }, /* offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000 */
{ 2254216 }, /* offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000 */
{ 2255052 }, /* offcore_response.pf_ifetch.any_dram\000\000memory\000Offcore prefetch code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6040\000\00000\000\000 */
{ 2255379 }, /* offcore_response.pf_ifetch.any_llc_miss\000\000memory\000Offcore prefetch code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF840\000\00000\000\000 */
{ 2258364 }, /* offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000 */
{ 2260213 }, /* offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000 */
{ 2431088 }, /* offcore_response.pf_rfo.any_dram\000\000memory\000Offcore prefetch RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6020\000\00000\000\000 */
{ 2431414 }, /* offcore_response.pf_rfo.any_llc_miss\000\000memory\000Offcore prefetch RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF820\000\00000\000\000 */
{ 2434054 }, /* offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000 */
{ 2435895 }, /* offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000 */
{ 2441003 }, /* offcore_response.prefetch.any_dram\000\000memory\000Offcore prefetch requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6070\000\00000\000\000 */
{ 2441328 }, /* offcore_response.prefetch.any_llc_miss\000\000memory\000Offcore prefetch requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF870\000\00000\000\000 */
{ 2443957 }, /* offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000 */
{ 2445785 }, /* offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000 */
{ 835049 }, /* es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000 */
{ 1075635 }, /* io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114741 }, /* l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000 */
{ 1114843 }, /* l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114927 }, /* l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000 */
{ 1115015 }, /* l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000 */
{ 1189817 }, /* large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1228602 }, /* load_block.overlap_store\000\000other\000Loads that partially overlap an earlier store\000event=0x3,period=200000,umask=0x2\000\00000\000\000 */
{ 1228719 }, /* load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000 */
{ 1228806 }, /* load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000 */
{ 1228902 }, /* load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1229004 }, /* load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000 */
{ 2476952 }, /* partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000 */
{ 2521171 }, /* sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000 */
{ 2521260 }, /* seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000 */
{ 2528735 }, /* snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000 */
{ 2528831 }, /* snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000 */
{ 2528929 }, /* snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000 */
{ 2529217 }, /* snoopq_requests.code\000\000other\000Snoop code requests\000event=0xb4,period=100000,umask=0x4\000\00000\000\000 */
{ 2529305 }, /* snoopq_requests.data\000\000other\000Snoop data requests\000event=0xb4,period=100000,umask=0x1\000\00000\000\000 */
{ 2529393 }, /* snoopq_requests.invalidate\000\000other\000Snoop invalidate requests\000event=0xb4,period=100000,umask=0x2\000\00000\000\000 */
{ 2529493 }, /* snoopq_requests_outstanding.code\000\000other\000Outstanding snoop code requests\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529606 }, /* snoopq_requests_outstanding.code_not_empty\000\000other\000Cycles snoop code requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529739 }, /* snoopq_requests_outstanding.data\000\000other\000Outstanding snoop data requests\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529852 }, /* snoopq_requests_outstanding.data_not_empty\000\000other\000Cycles snoop data requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529985 }, /* snoopq_requests_outstanding.invalidate\000\000other\000Outstanding snoop invalidate requests\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530110 }, /* snoopq_requests_outstanding.invalidate_not_empty\000\000other\000Cycles snoop invalidate requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530255 }, /* sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000 */
{ 467271 }, /* arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 467371 }, /* arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 471330 }, /* arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000 */
{ 473654 }, /* baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000 */
{ 473765 }, /* baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 473868 }, /* baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000 */
{ 487276 }, /* bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000 */
{ 487380 }, /* bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000 */
{ 487482 }, /* bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 491001 }, /* br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000 */
{ 491098 }, /* br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000 */
{ 491207 }, /* br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000 */
{ 491309 }, /* br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000 */
{ 491426 }, /* br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000 */
{ 491540 }, /* br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000 */
{ 491656 }, /* br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000 */
{ 491753 }, /* br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000 */
{ 492324 }, /* br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000 */
{ 492432 }, /* br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000 */
{ 498319 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000 */
{ 506620 }, /* br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000 */
{ 515982 }, /* br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000 */
{ 530639 }, /* br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000 */
{ 530737 }, /* br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000 */
{ 530847 }, /* br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000 */
{ 530961 }, /* br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000 */
{ 531333 }, /* br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000 */
{ 531459 }, /* br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000 */
{ 531587 }, /* br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000 */
{ 531696 }, /* br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000 */
{ 532460 }, /* br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000 */
{ 532571 }, /* br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000 */
{ 538916 }, /* br_misp_retired.all_branches\000\000pipeline\000Mispredicted retired branch instructions (Precise Event)\000event=0xc5,period=20000,umask=0x4\000\00000\000\000 */
{ 547126 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional retired branches (Precise Event)\000event=0xc5,period=20000,umask=0x1\000\00000\000\000 */
{ 554975 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000 */
{ 620914 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 622158 }, /* cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000 */
{ 643775 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000 */
{ 647207 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000 */
{ 649803 }, /* cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000 */
{ 1040461 }, /* ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000 */
{ 1040570 }, /* ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000 */
{ 1040907 }, /* ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 1042997 }, /* ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 1043097 }, /* ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000 */
{ 1043183 }, /* inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000 */
{ 1043960 }, /* inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000 */
{ 1044092 }, /* inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000 */
{ 1047147 }, /* inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053554 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1057737 }, /* inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000 */
{ 1063146 }, /* inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1063652 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1064586 }, /* inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000 */
{ 1231057 }, /* load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000 */
{ 1283188 }, /* lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1285888 }, /* lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1286788 }, /* lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000 */
{ 1289354 }, /* machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000 */
{ 1293852 }, /* machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000 */
{ 1300312 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000 */
{ 2483994 }, /* rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000 */
{ 2484081 }, /* rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2484167 }, /* rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2484269 }, /* rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2484373 }, /* rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2501064 }, /* resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2502029 }, /* resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000 */
{ 2502398 }, /* resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2502656 }, /* resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000 */
{ 2502894 }, /* resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000 */
{ 2503359 }, /* resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000 */
{ 2504132 }, /* resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2506545 }, /* resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2536082 }, /* ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000 */
{ 2536212 }, /* ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000 */
{ 2536342 }, /* ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000 */
{ 2536472 }, /* ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000 */
{ 2536602 }, /* ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000 */
{ 6178001 }, /* uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178955 }, /* uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6179066 }, /* uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6179169 }, /* uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6179294 }, /* uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6193659 }, /* uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6193804 }, /* uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199088 }, /* uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199380 }, /* uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199692 }, /* uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199843 }, /* uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6204390 }, /* uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6204143 }, /* uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204248 }, /* uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204485 }, /* uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6204580 }, /* uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000 */
{ 6204696 }, /* uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6204815 }, /* uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6204934 }, /* uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000 */
{ 6205054 }, /* uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000 */
{ 6213590 }, /* uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216019 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216805 }, /* uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6217626 }, /* uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000 */
{ 6219127 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6225258 }, /* uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6227775 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000 */
{ 6231023 }, /* uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000 */
{ 6233951 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000 */
{ 6238074 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6240810 }, /* uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 787008 }, /* dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000 */
{ 789416 }, /* dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000 */
{ 789810 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000 */
{ 794527 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000 */
{ 806100 }, /* dtlb_load_misses.walk_cycles\000\000virtual memory\000DTLB load miss page walk cycles\000event=0x8,period=200000,umask=0x4\000\00000\000\000 */
{ 809538 }, /* dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000 */
{ 809622 }, /* dtlb_misses.large_walk_completed\000\000virtual memory\000DTLB miss large page walks\000event=0x49,period=200000,umask=0x80\000\00000\000\000 */
{ 810055 }, /* dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000 */
{ 810178 }, /* dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000 */
{ 810282 }, /* dtlb_misses.walk_cycles\000\000virtual memory\000DTLB miss page walk cycles\000event=0x49,period=2000000,umask=0x4\000\00000\000\000 */
{ 833736 }, /* ept.walk_cycles\000\000virtual memory\000Extended Page Table walk cycles\000event=0x4f,period=2000000,umask=0x10\000\00000\000\000 */
{ 1079563 }, /* itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000 */
{ 1079644 }, /* itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000 */
{ 1079777 }, /* itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000 */
{ 1087383 }, /* itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000 */
{ 1095723 }, /* itlb_misses.walk_cycles\000\000virtual memory\000ITLB miss page walk cycles\000event=0x85,period=2000000,umask=0x4\000\00000\000\000 */
{ 1331956 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000 */
{ 1368683 }, /* mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
};

static const struct compact_pmu_event pmu_events__westmereex[] = {
{ 571421 }, /* cache_lock_cycles.l1d\000\000cache\000Cycles L1D locked\000event=0x63,period=2000000,umask=0x2\000\00000\000\000 */
{ 571509 }, /* cache_lock_cycles.l1d_l2\000\000cache\000Cycles L1D and L2 locked\000event=0x63,period=2000000,umask=0x1\000\00000\000\000 */
{ 1100466 }, /* l1d.m_evict\000\000cache\000L1D cache lines replaced in M state\000event=0x51,period=2000000,umask=0x4\000\00000\000\000 */
{ 1100562 }, /* l1d.m_repl\000\000cache\000L1D cache lines allocated in the M state\000event=0x51,period=2000000,umask=0x2\000\00000\000\000 */
{ 1100662 }, /* l1d.m_snoop_evict\000\000cache\000L1D snoop eviction of cache lines in M state\000event=0x51,period=2000000,umask=0x8\000\00000\000\000 */
{ 1100773 }, /* l1d.repl\000\000cache\000L1 data cache lines allocated\000event=0x51,period=2000000,umask=0x1\000\00000\000\000 */
{ 1104580 }, /* l1d_cache_prefetch_lock_fb_hit\000\000cache\000L1D prefetch load lock accepted in fill buffer\000event=0x52,period=2000000,umask=0x1\000\00000\000\000 */
{ 1113958 }, /* l1d_prefetch.miss\000\000cache\000L1D hardware prefetch misses\000event=0x4e,period=200000,umask=0x2\000\00000\000\000 */
{ 1114052 }, /* l1d_prefetch.requests\000\000cache\000L1D hardware prefetch requests\000event=0x4e,period=200000,umask=0x1\000\00000\000\000 */
{ 1114152 }, /* l1d_prefetch.triggers\000\000cache\000L1D hardware prefetch requests triggered\000event=0x4e,period=200000,umask=0x4\000\00000\000\000 */
{ 1114262 }, /* l1d_wb_l2.e_state\000\000cache\000L1 writebacks to L2 in E state\000event=0x28,period=100000,umask=0x4\000\00000\000\000 */
{ 1114358 }, /* l1d_wb_l2.i_state\000\000cache\000L1 writebacks to L2 in I state (misses)\000event=0x28,period=100000,umask=0x1\000\00000\000\000 */
{ 1114463 }, /* l1d_wb_l2.m_state\000\000cache\000L1 writebacks to L2 in M state\000event=0x28,period=100000,umask=0x8\000\00000\000\000 */
{ 1114559 }, /* l1d_wb_l2.mesi\000\000cache\000All L1 writebacks to L2\000event=0x28,period=100000,umask=0xf\000\00000\000\000 */
{ 1114645 }, /* l1d_wb_l2.s_state\000\000cache\000L1 writebacks to L2 in S state\000event=0x28,period=100000,umask=0x2\000\00000\000\000 */
{ 1121826 }, /* l2_data_rqsts.any\000\000cache\000All L2 data requests\000event=0x26,period=200000,umask=0xff\000\00000\000\000 */
{ 1121913 }, /* l2_data_rqsts.demand.e_state\000\000cache\000L2 data demand loads in E state\000event=0x26,period=200000,umask=0x4\000\00000\000\000 */
{ 1122021 }, /* l2_data_rqsts.demand.i_state\000\000cache\000L2 data demand loads in I state (misses)\000event=0x26,period=200000,umask=0x1\000\00000\000\000 */
{ 1122138 }, /* l2_data_rqsts.demand.m_state\000\000cache\000L2 data demand loads in M state\000event=0x26,period=200000,umask=0x8\000\00000\000\000 */
{ 1122246 }, /* l2_data_rqsts.demand.mesi\000\000cache\000L2 data demand requests\000event=0x26,period=200000,umask=0xf\000\00000\000\000 */
{ 1122343 }, /* l2_data_rqsts.demand.s_state\000\000cache\000L2 data demand loads in S state\000event=0x26,period=200000,umask=0x2\000\00000\000\000 */
{ 1122451 }, /* l2_data_rqsts.prefetch.e_state\000\000cache\000L2 data prefetches in E state\000event=0x26,period=200000,umask=0x40\000\00000\000\000 */
{ 1122560 }, /* l2_data_rqsts.prefetch.i_state\000\000cache\000L2 data prefetches in the I state (misses)\000event=0x26,period=200000,umask=0x10\000\00000\000\000 */
{ 1122682 }, /* l2_data_rqsts.prefetch.m_state\000\000cache\000L2 data prefetches in M state\000event=0x26,period=200000,umask=0x80\000\00000\000\000 */
{ 1122791 }, /* l2_data_rqsts.prefetch.mesi\000\000cache\000All L2 data prefetches\000event=0x26,period=200000,umask=0xf0\000\00000\000\000 */
{ 1122890 }, /* l2_data_rqsts.prefetch.s_state\000\000cache\000L2 data prefetches in the S state\000event=0x26,period=200000,umask=0x20\000\00000\000\000 */
{ 1129601 }, /* l2_lines_in.any\000\000cache\000L2 lines alloacated\000event=0xf1,period=100000,umask=0x7\000\00000\000\000 */
{ 1130213 }, /* l2_lines_in.e_state\000\000cache\000L2 lines allocated in the E state\000event=0xf1,period=100000,umask=0x4\000\00000\000\000 */
{ 1131206 }, /* l2_lines_in.s_state\000\000cache\000L2 lines allocated in the S state\000event=0xf1,period=100000,umask=0x2\000\00000\000\000 */
{ 1131570 }, /* l2_lines_out.any\000\000cache\000L2 lines evicted\000event=0xf2,period=100000,umask=0xf\000\00000\000\000 */
{ 1132175 }, /* l2_lines_out.demand_clean\000\000cache\000L2 lines evicted by a demand request\000event=0xf2,period=100000,umask=0x1\000\00000\000\000 */
{ 1132697 }, /* l2_lines_out.demand_dirty\000\000cache\000L2 modified lines evicted by a demand request\000event=0xf2,period=100000,umask=0x2\000\00000\000\000 */
{ 1135641 }, /* l2_lines_out.prefetch_clean\000\000cache\000L2 lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x4\000\00000\000\000 */
{ 1135755 }, /* l2_lines_out.prefetch_dirty\000\000cache\000L2 modified lines evicted by a prefetch request\000event=0xf2,period=100000,umask=0x8\000\00000\000\000 */
{ 1167724 }, /* l2_rqsts.ifetch_hit\000\000cache\000L2 instruction fetch hits\000event=0x24,period=200000,umask=0x10\000\00000\000\000 */
{ 1167818 }, /* l2_rqsts.ifetch_miss\000\000cache\000L2 instruction fetch misses\000event=0x24,period=200000,umask=0x20\000\00000\000\000 */
{ 1167915 }, /* l2_rqsts.ifetches\000\000cache\000L2 instruction fetches\000event=0x24,period=200000,umask=0x30\000\00000\000\000 */
{ 1168737 }, /* l2_rqsts.ld_hit\000\000cache\000L2 load hits\000event=0x24,period=200000,umask=0x1\000\00000\000\000 */
{ 1168813 }, /* l2_rqsts.ld_miss\000\000cache\000L2 load misses\000event=0x24,period=200000,umask=0x2\000\00000\000\000 */
{ 1168892 }, /* l2_rqsts.loads\000\000cache\000L2 requests\000event=0x24,period=200000,umask=0x3\000\00000\000\000 */
{ 1168966 }, /* l2_rqsts.miss\000\000cache\000All L2 misses\000event=0x24,period=200000,umask=0xaa\000\00000\000\000 */
{ 1172018 }, /* l2_rqsts.prefetch_hit\000\000cache\000L2 prefetch hits\000event=0x24,period=200000,umask=0x40\000\00000\000\000 */
{ 1172105 }, /* l2_rqsts.prefetch_miss\000\000cache\000L2 prefetch misses\000event=0x24,period=200000,umask=0x80\000\00000\000\000 */
{ 1172195 }, /* l2_rqsts.prefetches\000\000cache\000All L2 prefetches\000event=0x24,period=200000,umask=0xc0\000\00000\000\000 */
{ 1172443 }, /* l2_rqsts.references\000\000cache\000All L2 requests\000event=0x24,period=200000,umask=0xff\000\00000\000\000 */
{ 1173756 }, /* l2_rqsts.rfo_hit\000\000cache\000L2 RFO hits\000event=0x24,period=200000,umask=0x4\000\00000\000\000 */
{ 1174646 }, /* l2_rqsts.rfo_miss\000\000cache\000L2 RFO misses\000event=0x24,period=200000,umask=0x8\000\00000\000\000 */
{ 1175586 }, /* l2_rqsts.rfos\000\000cache\000L2 RFO requests\000event=0x24,period=200000,umask=0xc\000\00000\000\000 */
{ 1183427 }, /* l2_transactions.any\000\000cache\000All L2 transactions\000event=0xf0,period=200000,umask=0x80\000\00000\000\000 */
{ 1183515 }, /* l2_transactions.fill\000\000cache\000L2 fill transactions\000event=0xf0,period=200000,umask=0x20\000\00000\000\000 */
{ 1183605 }, /* l2_transactions.ifetch\000\000cache\000L2 instruction fetch transactions\000event=0xf0,period=200000,umask=0x4\000\00000\000\000 */
{ 1183709 }, /* l2_transactions.l1d_wb\000\000cache\000L1D writeback to L2 transactions\000event=0xf0,period=200000,umask=0x10\000\00000\000\000 */
{ 1183813 }, /* l2_transactions.load\000\000cache\000L2 Load transactions\000event=0xf0,period=200000,umask=0x1\000\00000\000\000 */
{ 1183902 }, /* l2_transactions.prefetch\000\000cache\000L2 prefetch transactions\000event=0xf0,period=200000,umask=0x8\000\00000\000\000 */
{ 1183999 }, /* l2_transactions.rfo\000\000cache\000L2 RFO transactions\000event=0xf0,period=200000,umask=0x2\000\00000\000\000 */
{ 1184086 }, /* l2_transactions.wb\000\000cache\000L2 writeback to LLC transactions\000event=0xf0,period=200000,umask=0x40\000\00000\000\000 */
{ 1184856 }, /* l2_write.lock.e_state\000\000cache\000L2 demand lock RFOs in E state\000event=0x27,period=100000,umask=0x40\000\00000\000\000 */
{ 1184957 }, /* l2_write.lock.hit\000\000cache\000All demand L2 lock RFOs that hit the cache\000event=0x27,period=100000,umask=0xe0\000\00000\000\000 */
{ 1185066 }, /* l2_write.lock.i_state\000\000cache\000L2 demand lock RFOs in I state (misses)\000event=0x27,period=100000,umask=0x10\000\00000\000\000 */
{ 1185176 }, /* l2_write.lock.m_state\000\000cache\000L2 demand lock RFOs in M state\000event=0x27,period=100000,umask=0x80\000\00000\000\000 */
{ 1185277 }, /* l2_write.lock.mesi\000\000cache\000All demand L2 lock RFOs\000event=0x27,period=100000,umask=0xf0\000\00000\000\000 */
{ 1185368 }, /* l2_write.lock.s_state\000\000cache\000L2 demand lock RFOs in S state\000event=0x27,period=100000,umask=0x20\000\00000\000\000 */
{ 1185469 }, /* l2_write.rfo.hit\000\000cache\000All L2 demand store RFOs that hit the cache\000event=0x27,period=100000,umask=0xe\000\00000\000\000 */
{ 1185577 }, /* l2_write.rfo.i_state\000\000cache\000L2 demand store RFOs in I state (misses)\000event=0x27,period=100000,umask=0x1\000\00000\000\000 */
{ 1185686 }, /* l2_write.rfo.m_state\000\000cache\000L2 demand store RFOs in M state\000event=0x27,period=100000,umask=0x8\000\00000\000\000 */
{ 1185786 }, /* l2_write.rfo.mesi\000\000cache\000All L2 demand store RFOs\000event=0x27,period=100000,umask=0xf\000\00000\000\000 */
{ 1185876 }, /* l2_write.rfo.s_state\000\000cache\000L2 demand store RFOs in S state\000event=0x27,period=100000,umask=0x2\000\00000\000\000 */
{ 1249469 }, /* longest_lat_cache.miss\000\000cache\000Longest latency cache miss\000event=0x2e,period=100000,umask=0x41\000\00000\000\000 */
{ 1253301 }, /* longest_lat_cache.reference\000\000cache\000Longest latency cache reference\000event=0x2e,period=200000,umask=0x4f\000\00000\000\000 */
{ 1312836 }, /* mem_inst_retired.latency_above_threshold_0\000\000cache\000Memory instructions retired above 0 clocks (Precise Event)\000event=0xb,period=2000000,umask=0x10,ldlat=None\000\00000\000\000 */
{ 1312997 }, /* mem_inst_retired.latency_above_threshold_1024\000\000cache\000Memory instructions retired above 1024 clocks (Precise Event)\000event=0xb,period=100,umask=0x10,ldlat=0x400\000\00000\000\000 */
{ 1313161 }, /* mem_inst_retired.latency_above_threshold_128\000\000cache\000Memory instructions retired above 128 clocks (Precise Event)\000event=0xb,period=1000,umask=0x10,ldlat=0x80\000\00000\000\000 */
{ 1313488 }, /* mem_inst_retired.latency_above_threshold_16\000\000cache\000Memory instructions retired above 16 clocks (Precise Event)\000event=0xb,period=10000,umask=0x10,ldlat=0x10\000\00000\000\000 */
{ 1313323 }, /* mem_inst_retired.latency_above_threshold_16384\000\000cache\000Memory instructions retired above 16384 clocks (Precise Event)\000event=0xb,period=5,umask=0x10,ldlat=0x4000\000\00000\000\000 */
{ 1313649 }, /* mem_inst_retired.latency_above_threshold_2048\000\000cache\000Memory instructions retired above 2048 clocks (Precise Event)\000event=0xb,period=50,umask=0x10,ldlat=0x800\000\00000\000\000 */
{ 1313812 }, /* mem_inst_retired.latency_above_threshold_256\000\000cache\000Memory instructions retired above 256 clocks (Precise Event)\000event=0xb,period=500,umask=0x10,ldlat=0x100\000\00000\000\000 */
{ 1314139 }, /* mem_inst_retired.latency_above_threshold_32\000\000cache\000Memory instructions retired above 32 clocks (Precise Event)\000event=0xb,period=5000,umask=0x10,ldlat=0x20\000\00000\000\000 */
{ 1313974 }, /* mem_inst_retired.latency_above_threshold_32768\000\000cache\000Memory instructions retired above 32768 clocks (Precise Event)\000event=0xb,period=3,umask=0x10,ldlat=0x8000\000\00000\000\000 */
{ 1314463 }, /* mem_inst_retired.latency_above_threshold_4\000\000cache\000Memory instructions retired above 4 clocks (Precise Event)\000event=0xb,period=50000,umask=0x10,ldlat=0x4\000\00000\000\000 */
{ 1314299 }, /* mem_inst_retired.latency_above_threshold_4096\000\000cache\000Memory instructions retired above 4096 clocks (Precise Event)\000event=0xb,period=20,umask=0x10,ldlat=0x1000\000\00000\000\000 */
{ 1314621 }, /* mem_inst_retired.latency_above_threshold_512\000\000cache\000Memory instructions retired above 512 clocks (Precise Event)\000event=0xb,period=200,umask=0x10,ldlat=0x200\000\00000\000\000 */
{ 1314783 }, /* mem_inst_retired.latency_above_threshold_64\000\000cache\000Memory instructions retired above 64 clocks (Precise Event)\000event=0xb,period=2000,umask=0x10,ldlat=0x40\000\00000\000\000 */
{ 1315107 }, /* mem_inst_retired.latency_above_threshold_8\000\000cache\000Memory instructions retired above 8 clocks (Precise Event)\000event=0xb,period=20000,umask=0x10,ldlat=0x8\000\00000\000\000 */
{ 1314943 }, /* mem_inst_retired.latency_above_threshold_8192\000\000cache\000Memory instructions retired above 8192 clocks (Precise Event)\000event=0xb,period=10,umask=0x10,ldlat=0x2000\000\00000\000\000 */
{ 1315265 }, /* mem_inst_retired.loads\000\000cache\000Instructions retired which contains a load (Precise Event)\000event=0xb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1319310 }, /* mem_inst_retired.stores\000\000cache\000Instructions retired which contains a store (Precise Event)\000event=0xb,period=2000000,umask=0x2\000\00000\000\000 */
{ 1333824 }, /* mem_load_retired.hit_lfb\000\000cache\000Retired loads that miss L1D and hit an previously allocated LFB (Precise Event)\000event=0xcb,period=200000,umask=0x40\000\00000\000\000 */
{ 1336151 }, /* mem_load_retired.l1d_hit\000\000cache\000Retired loads that hit the L1 data cache (Precise Event)\000event=0xcb,period=2000000,umask=0x1\000\00000\000\000 */
{ 1336860 }, /* mem_load_retired.l2_hit\000\000cache\000Retired loads that hit the L2 cache (Precise Event)\000event=0xcb,period=200000,umask=0x2\000\00000\000\000 */
{ 1340299 }, /* mem_load_retired.llc_miss\000\000cache\000Retired loads that miss the LLC cache (Precise Event)\000event=0xcb,period=10000,umask=0x10\000\00000\000\000 */
{ 1340426 }, /* mem_load_retired.llc_unshared_hit\000\000cache\000Retired loads that hit valid versions in the LLC cache (Precise Event)\000event=0xcb,period=40000,umask=0x4\000\00000\000\000 */
{ 1341515 }, /* mem_load_retired.other_core_l2_hit_hitm\000\000cache\000Retired loads that hit sibling core's L2 in modified or unmodified states (Precise Event)\000event=0xcb,period=40000,umask=0x8\000\00000\000\000 */
{ 1386350 }, /* mem_uncore_retired.local_dram_and_remote_cache_hit\000\000cache\000Load instructions retired local dram and remote cache HIT data sources (Precise Event)\000event=0xf,period=20000,umask=0x8\000\00000\000\000 */
{ 1386533 }, /* mem_uncore_retired.local_hitm\000\000cache\000Load instructions retired that HIT modified data in sibling core (Precise Event)\000event=0xf,period=40000,umask=0x2\000\00000\000\000 */
{ 1387181 }, /* mem_uncore_retired.remote_dram\000\000cache\000Load instructions retired remote DRAM and remote home-remote cache HITM (Precise Event)\000event=0xf,period=10000,umask=0x20\000\00000\000\000 */
{ 1387346 }, /* mem_uncore_retired.remote_hitm\000\000cache\000Retired loads that hit remote socket in modified state (Precise Event)\000event=0xf,period=40000,umask=0x4\000\00000\000\000 */
{ 1387493 }, /* mem_uncore_retired.uncacheable\000\000cache\000Load instructions retired IO (Precise Event)\000event=0xf,period=4000,umask=0x80\000\00000\000\000 */
{ 1747290 }, /* offcore_requests.any\000\000cache\000All offcore requests\000event=0xb0,period=100000,umask=0x80\000\00000\000\000 */
{ 1747101 }, /* offcore_requests.any.read\000\000cache\000Offcore read requests\000event=0xb0,period=100000,umask=0x8\000\00000\000\000 */
{ 1747196 }, /* offcore_requests.any.rfo\000\000cache\000Offcore RFO requests\000event=0xb0,period=100000,umask=0x10\000\00000\000\000 */
{ 1748025 }, /* offcore_requests.demand.read_code\000\000cache\000Offcore demand code read requests\000event=0xb0,period=100000,umask=0x2\000\00000\000\000 */
{ 1748140 }, /* offcore_requests.demand.read_data\000\000cache\000Offcore demand data read requests\000event=0xb0,period=100000,umask=0x1\000\00000\000\000 */
{ 1748255 }, /* offcore_requests.demand.rfo\000\000cache\000Offcore demand RFO requests\000event=0xb0,period=100000,umask=0x4\000\00000\000\000 */
{ 1752159 }, /* offcore_requests.l1d_writeback\000\000cache\000Offcore L1 data cache writebacks\000event=0xb0,period=100000,umask=0x40\000\00000\000\000 */
{ 1757706 }, /* offcore_requests_outstanding.any.read\000\000cache\000Outstanding offcore reads\000event=0x60,period=2000000,umask=0x8\000\00000\000\000 */
{ 1757818 }, /* offcore_requests_outstanding.any.read_not_empty\000\000cache\000Cycles offcore reads busy\000event=0x60,cmask=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 1769044 }, /* offcore_requests_outstanding.demand.read_code\000\000cache\000Outstanding offcore demand code reads\000event=0x60,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769176 }, /* offcore_requests_outstanding.demand.read_code_not_empty\000\000cache\000Cycles offcore demand code read busy\000event=0x60,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 1769325 }, /* offcore_requests_outstanding.demand.read_data\000\000cache\000Outstanding offcore demand data reads\000event=0x60,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769457 }, /* offcore_requests_outstanding.demand.read_data_not_empty\000\000cache\000Cycles offcore demand data read busy\000event=0x60,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1769606 }, /* offcore_requests_outstanding.demand.rfo\000\000cache\000Outstanding offcore demand RFOs\000event=0x60,period=2000000,umask=0x4\000\00000\000\000 */
{ 1769726 }, /* offcore_requests_outstanding.demand.rfo_not_empty\000\000cache\000Cycles offcore demand RFOs busy\000event=0x60,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 1780856 }, /* offcore_requests_sq_full\000\000cache\000Offcore requests blocked due to Super Queue full\000event=0xb2,period=100000,umask=0x1\000\00000\000\000 */
{ 1921008 }, /* offcore_response.any_data.any_cache_dram\000\000cache\000Offcore data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F11\000\00000\000\000 */
{ 1921952 }, /* offcore_response.any_data.any_location\000\000cache\000All offcore data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF11\000\00000\000\000 */
{ 1922237 }, /* offcore_response.any_data.io_csr_mmio\000\000cache\000Offcore data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8011\000\00000\000\000 */
{ 1922551 }, /* offcore_response.any_data.llc_hit_no_other_core\000\000cache\000Offcore data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x111\000\00000\000\000 */
{ 1922910 }, /* offcore_response.any_data.llc_hit_other_core_hit\000\000cache\000Offcore data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x211\000\00000\000\000 */
{ 1923266 }, /* offcore_response.any_data.llc_hit_other_core_hitm\000\000cache\000Offcore data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x411\000\00000\000\000 */
{ 1923627 }, /* offcore_response.any_data.local_cache\000\000cache\000Offcore data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x711\000\00000\000\000 */
{ 1924087 }, /* offcore_response.any_data.local_cache_dram\000\000cache\000Offcore data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4711\000\00000\000\000 */
{ 1924913 }, /* offcore_response.any_data.remote_cache\000\000cache\000Offcore data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1811\000\00000\000\000 */
{ 1925065 }, /* offcore_response.any_data.remote_cache_dram\000\000cache\000Offcore data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3811\000\00000\000\000 */
{ 1925409 }, /* offcore_response.any_data.remote_cache_hit\000\000cache\000Offcore data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1011\000\00000\000\000 */
{ 1925564 }, /* offcore_response.any_data.remote_cache_hitm\000\000cache\000Offcore data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x811\000\00000\000\000 */
{ 1936832 }, /* offcore_response.any_ifetch.any_cache_dram\000\000cache\000Offcore code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F44\000\00000\000\000 */
{ 1937779 }, /* offcore_response.any_ifetch.any_location\000\000cache\000All offcore code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF44\000\00000\000\000 */
{ 1938065 }, /* offcore_response.any_ifetch.io_csr_mmio\000\000cache\000Offcore code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8044\000\00000\000\000 */
{ 1938380 }, /* offcore_response.any_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x144\000\00000\000\000 */
{ 1938740 }, /* offcore_response.any_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x244\000\00000\000\000 */
{ 1939097 }, /* offcore_response.any_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x444\000\00000\000\000 */
{ 1939459 }, /* offcore_response.any_ifetch.local_cache\000\000cache\000Offcore code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x744\000\00000\000\000 */
{ 1939922 }, /* offcore_response.any_ifetch.local_cache_dram\000\000cache\000Offcore code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4744\000\00000\000\000 */
{ 1940752 }, /* offcore_response.any_ifetch.remote_cache\000\000cache\000Offcore code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1844\000\00000\000\000 */
{ 1940906 }, /* offcore_response.any_ifetch.remote_cache_dram\000\000cache\000Offcore code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3844\000\00000\000\000 */
{ 1941254 }, /* offcore_response.any_ifetch.remote_cache_hit\000\000cache\000Offcore code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1044\000\00000\000\000 */
{ 1941411 }, /* offcore_response.any_ifetch.remote_cache_hitm\000\000cache\000Offcore code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x844\000\00000\000\000 */
{ 1960213 }, /* offcore_response.any_request.any_cache_dram\000\000cache\000Offcore requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FFF\000\00000\000\000 */
{ 1961163 }, /* offcore_response.any_request.any_location\000\000cache\000All offcore requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFFFF\000\00000\000\000 */
{ 1963126 }, /* offcore_response.any_request.io_csr_mmio\000\000cache\000Offcore requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x80FF\000\00000\000\000 */
{ 1969757 }, /* offcore_response.any_request.llc_hit_no_other_core\000\000cache\000Offcore requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1FF\000\00000\000\000 */
{ 1970118 }, /* offcore_response.any_request.llc_hit_other_core_hit\000\000cache\000Offcore requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2FF\000\00000\000\000 */
{ 1970476 }, /* offcore_response.any_request.llc_hit_other_core_hitm\000\000cache\000Offcore requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4FF\000\00000\000\000 */
{ 1971122 }, /* offcore_response.any_request.local_cache\000\000cache\000Offcore requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7FF\000\00000\000\000 */
{ 1971585 }, /* offcore_response.any_request.local_cache_dram\000\000cache\000Offcore requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x47FF\000\00000\000\000 */
{ 1973747 }, /* offcore_response.any_request.remote_cache\000\000cache\000Offcore requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x18FF\000\00000\000\000 */
{ 1973900 }, /* offcore_response.any_request.remote_cache_dram\000\000cache\000Offcore requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x38FF\000\00000\000\000 */
{ 1974246 }, /* offcore_response.any_request.remote_cache_hit\000\000cache\000Offcore requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x10FF\000\00000\000\000 */
{ 1974402 }, /* offcore_response.any_request.remote_cache_hitm\000\000cache\000Offcore requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8FF\000\00000\000\000 */
{ 1975383 }, /* offcore_response.any_rfo.any_cache_dram\000\000cache\000Offcore RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F22\000\00000\000\000 */
{ 1976309 }, /* offcore_response.any_rfo.any_location\000\000cache\000All offcore RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF22\000\00000\000\000 */
{ 1977996 }, /* offcore_response.any_rfo.io_csr_mmio\000\000cache\000Offcore RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8022\000\00000\000\000 */
{ 1985711 }, /* offcore_response.any_rfo.llc_hit_no_other_core\000\000cache\000Offcore RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x122\000\00000\000\000 */
{ 1986064 }, /* offcore_response.any_rfo.llc_hit_other_core_hit\000\000cache\000Offcore RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x222\000\00000\000\000 */
{ 1986414 }, /* offcore_response.any_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x422\000\00000\000\000 */
{ 1986769 }, /* offcore_response.any_rfo.local_cache\000\000cache\000Offcore RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x722\000\00000\000\000 */
{ 1987224 }, /* offcore_response.any_rfo.local_cache_dram\000\000cache\000Offcore RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4722\000\00000\000\000 */
{ 1989498 }, /* offcore_response.any_rfo.remote_cache\000\000cache\000Offcore RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1822\000\00000\000\000 */
{ 1989651 }, /* offcore_response.any_rfo.remote_cache_dram\000\000cache\000Offcore RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3822\000\00000\000\000 */
{ 1989997 }, /* offcore_response.any_rfo.remote_cache_hit\000\000cache\000Offcore RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1022\000\00000\000\000 */
{ 1990153 }, /* offcore_response.any_rfo.remote_cache_hitm\000\000cache\000Offcore RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x822\000\00000\000\000 */
{ 1998153 }, /* offcore_response.corewb.any_cache_dram\000\000cache\000Offcore writebacks to any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F08\000\00000\000\000 */
{ 1999047 }, /* offcore_response.corewb.any_location\000\000cache\000All offcore writebacks\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF08\000\00000\000\000 */
{ 2000260 }, /* offcore_response.corewb.io_csr_mmio\000\000cache\000Offcore writebacks to the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8008\000\00000\000\000 */
{ 2007876 }, /* offcore_response.corewb.llc_hit_no_other_core\000\000cache\000Offcore writebacks to the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x108\000\00000\000\000 */
{ 2008383 }, /* offcore_response.corewb.llc_hit_other_core_hitm\000\000cache\000Offcore writebacks to the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x408\000\00000\000\000 */
{ 2008724 }, /* offcore_response.corewb.local_cache\000\000cache\000Offcore writebacks to the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x708\000\00000\000\000 */
{ 2009152 }, /* offcore_response.corewb.local_cache_dram\000\000cache\000Offcore writebacks to the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4708\000\00000\000\000 */
{ 2010460 }, /* offcore_response.corewb.remote_cache\000\000cache\000Offcore writebacks to a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1808\000\00000\000\000 */
{ 2010600 }, /* offcore_response.corewb.remote_cache_dram\000\000cache\000Offcore writebacks to a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3808\000\00000\000\000 */
{ 2010920 }, /* offcore_response.corewb.remote_cache_hit\000\000cache\000Offcore writebacks that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1008\000\00000\000\000 */
{ 2011073 }, /* offcore_response.corewb.remote_cache_hitm\000\000cache\000Offcore writebacks that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x808\000\00000\000\000 */
{ 2013167 }, /* offcore_response.data_ifetch.any_cache_dram\000\000cache\000Offcore code or data read requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F77\000\00000\000\000 */
{ 2014171 }, /* offcore_response.data_ifetch.any_location\000\000cache\000All offcore code or data read requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF77\000\00000\000\000 */
{ 2014476 }, /* offcore_response.data_ifetch.io_csr_mmio\000\000cache\000Offcore code or data read requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8077\000\00000\000\000 */
{ 2014810 }, /* offcore_response.data_ifetch.llc_hit_no_other_core\000\000cache\000Offcore code or data read requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x177\000\00000\000\000 */
{ 2015189 }, /* offcore_response.data_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore code or data read requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x277\000\00000\000\000 */
{ 2015565 }, /* offcore_response.data_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore code or data read requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x477\000\00000\000\000 */
{ 2015946 }, /* offcore_response.data_ifetch.local_cache\000\000cache\000Offcore code or data read requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x777\000\00000\000\000 */
{ 2016445 }, /* offcore_response.data_ifetch.local_cache_dram\000\000cache\000Offcore code or data read requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4777\000\00000\000\000 */
{ 2017330 }, /* offcore_response.data_ifetch.remote_cache\000\000cache\000Offcore code or data read requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1877\000\00000\000\000 */
{ 2017501 }, /* offcore_response.data_ifetch.remote_cache_dram\000\000cache\000Offcore code or data read requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3877\000\00000\000\000 */
{ 2017883 }, /* offcore_response.data_ifetch.remote_cache_hit\000\000cache\000Offcore code or data read requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1077\000\00000\000\000 */
{ 2018057 }, /* offcore_response.data_ifetch.remote_cache_hitm\000\000cache\000Offcore code or data read requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x877\000\00000\000\000 */
{ 2019092 }, /* offcore_response.data_in.any_cache_dram\000\000cache\000Offcore request = all data, response = any cache_dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F33\000\00000\000\000 */
{ 2020036 }, /* offcore_response.data_in.any_location\000\000cache\000Offcore request = all data, response = any location\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF33\000\00000\000\000 */
{ 2020500 }, /* offcore_response.data_in.io_csr_mmio\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8033\000\00000\000\000 */
{ 2020828 }, /* offcore_response.data_in.llc_hit_no_other_core\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x133\000\00000\000\000 */
{ 2021201 }, /* offcore_response.data_in.llc_hit_other_core_hit\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x233\000\00000\000\000 */
{ 2021571 }, /* offcore_response.data_in.llc_hit_other_core_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x433\000\00000\000\000 */
{ 2021946 }, /* offcore_response.data_in.local_cache\000\000cache\000Offcore request = all data, response = local cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x733\000\00000\000\000 */
{ 2022413 }, /* offcore_response.data_in.local_cache_dram\000\000cache\000Offcore request = all data, response = local cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4733\000\00000\000\000 */
{ 2023271 }, /* offcore_response.data_in.remote_cache\000\000cache\000Offcore request = all data, response = remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1833\000\00000\000\000 */
{ 2023427 }, /* offcore_response.data_in.remote_cache_dram\000\000cache\000Offcore request = all data, response = remote cache or dram\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3833\000\00000\000\000 */
{ 2023765 }, /* offcore_response.data_in.remote_cache_hit\000\000cache\000Offcore data reads, RFOs, and prefetches that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1033\000\00000\000\000 */
{ 2023941 }, /* offcore_response.data_in.remote_cache_hitm\000\000cache\000Offcore data reads, RFOs, and prefetches that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x833\000\00000\000\000 */
{ 2072246 }, /* offcore_response.demand_data.any_cache_dram\000\000cache\000Offcore demand data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F03\000\00000\000\000 */
{ 2073232 }, /* offcore_response.demand_data.any_location\000\000cache\000All offcore demand data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF03\000\00000\000\000 */
{ 2073531 }, /* offcore_response.demand_data.io_csr_mmio\000\000cache\000Offcore demand data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8003\000\00000\000\000 */
{ 2073859 }, /* offcore_response.demand_data.llc_hit_no_other_core\000\000cache\000Offcore demand data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x103\000\00000\000\000 */
{ 2074232 }, /* offcore_response.demand_data.llc_hit_other_core_hit\000\000cache\000Offcore demand data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x203\000\00000\000\000 */
{ 2074602 }, /* offcore_response.demand_data.llc_hit_other_core_hitm\000\000cache\000Offcore demand data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x403\000\00000\000\000 */
{ 2074977 }, /* offcore_response.demand_data.local_cache\000\000cache\000Offcore demand data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x703\000\00000\000\000 */
{ 2075464 }, /* offcore_response.demand_data.local_cache_dram\000\000cache\000Offcore demand data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4703\000\00000\000\000 */
{ 2076331 }, /* offcore_response.demand_data.remote_cache\000\000cache\000Offcore demand data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1803\000\00000\000\000 */
{ 2076496 }, /* offcore_response.demand_data.remote_cache_dram\000\000cache\000Offcore demand data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3803\000\00000\000\000 */
{ 2076866 }, /* offcore_response.demand_data.remote_cache_hit\000\000cache\000Offcore demand data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1003\000\00000\000\000 */
{ 2077034 }, /* offcore_response.demand_data.remote_cache_hitm\000\000cache\000Offcore demand data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x803\000\00000\000\000 */
{ 2078065 }, /* offcore_response.demand_data_rd.any_cache_dram\000\000cache\000Offcore demand data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F01\000\00000\000\000 */
{ 2079069 }, /* offcore_response.demand_data_rd.any_location\000\000cache\000All offcore demand data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF01\000\00000\000\000 */
{ 2081657 }, /* offcore_response.demand_data_rd.io_csr_mmio\000\000cache\000Offcore demand data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8001\000\00000\000\000 */
{ 2118081 }, /* offcore_response.demand_data_rd.llc_hit_no_other_core\000\000cache\000Offcore demand data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x101\000\00000\000\000 */
{ 2118460 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore demand data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x201\000\00000\000\000 */
{ 2118836 }, /* offcore_response.demand_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore demand data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x401\000\00000\000\000 */
{ 2121036 }, /* offcore_response.demand_data_rd.local_cache\000\000cache\000Offcore demand data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x701\000\00000\000\000 */
{ 2121529 }, /* offcore_response.demand_data_rd.local_cache_dram\000\000cache\000Offcore demand data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4701\000\00000\000\000 */
{ 2125385 }, /* offcore_response.demand_data_rd.remote_cache\000\000cache\000Offcore demand data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1801\000\00000\000\000 */
{ 2125550 }, /* offcore_response.demand_data_rd.remote_cache_dram\000\000cache\000Offcore demand data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3801\000\00000\000\000 */
{ 2125920 }, /* offcore_response.demand_data_rd.remote_cache_hit\000\000cache\000Offcore demand data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1001\000\00000\000\000 */
{ 2126088 }, /* offcore_response.demand_data_rd.remote_cache_hitm\000\000cache\000Offcore demand data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x801\000\00000\000\000 */
{ 2130096 }, /* offcore_response.demand_ifetch.any_cache_dram\000\000cache\000Offcore demand code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F04\000\00000\000\000 */
{ 2131091 }, /* offcore_response.demand_ifetch.any_location\000\000cache\000All offcore demand code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF04\000\00000\000\000 */
{ 2131393 }, /* offcore_response.demand_ifetch.io_csr_mmio\000\000cache\000Offcore demand code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8004\000\00000\000\000 */
{ 2131724 }, /* offcore_response.demand_ifetch.llc_hit_no_other_core\000\000cache\000Offcore demand code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x104\000\00000\000\000 */
{ 2132100 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore demand code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x204\000\00000\000\000 */
{ 2132473 }, /* offcore_response.demand_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore demand code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x404\000\00000\000\000 */
{ 2133046 }, /* offcore_response.demand_ifetch.local_cache\000\000cache\000Offcore demand code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x704\000\00000\000\000 */
{ 2133535 }, /* offcore_response.demand_ifetch.local_cache_dram\000\000cache\000Offcore demand code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4704\000\00000\000\000 */
{ 2134407 }, /* offcore_response.demand_ifetch.remote_cache\000\000cache\000Offcore demand code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1804\000\00000\000\000 */
{ 2134571 }, /* offcore_response.demand_ifetch.remote_cache_dram\000\000cache\000Offcore demand code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3804\000\00000\000\000 */
{ 2134939 }, /* offcore_response.demand_ifetch.remote_cache_hit\000\000cache\000Offcore demand code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1004\000\00000\000\000 */
{ 2135106 }, /* offcore_response.demand_ifetch.remote_cache_hitm\000\000cache\000Offcore demand code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x804\000\00000\000\000 */
{ 2136134 }, /* offcore_response.demand_rfo.any_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F02\000\00000\000\000 */
{ 2137108 }, /* offcore_response.demand_rfo.any_location\000\000cache\000All offcore demand RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF02\000\00000\000\000 */
{ 2139468 }, /* offcore_response.demand_rfo.io_csr_mmio\000\000cache\000Offcore demand RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8002\000\00000\000\000 */
{ 2177181 }, /* offcore_response.demand_rfo.llc_hit_no_other_core\000\000cache\000Offcore demand RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x102\000\00000\000\000 */
{ 2177550 }, /* offcore_response.demand_rfo.llc_hit_other_core_hit\000\000cache\000Offcore demand RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x202\000\00000\000\000 */
{ 2177916 }, /* offcore_response.demand_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore demand RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x402\000\00000\000\000 */
{ 2179346 }, /* offcore_response.demand_rfo.local_cache\000\000cache\000Offcore demand RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x702\000\00000\000\000 */
{ 2179827 }, /* offcore_response.demand_rfo.local_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4702\000\00000\000\000 */
{ 2183680 }, /* offcore_response.demand_rfo.remote_cache\000\000cache\000Offcore demand RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1802\000\00000\000\000 */
{ 2183843 }, /* offcore_response.demand_rfo.remote_cache_dram\000\000cache\000Offcore demand RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3802\000\00000\000\000 */
{ 2184209 }, /* offcore_response.demand_rfo.remote_cache_hit\000\000cache\000Offcore demand RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1002\000\00000\000\000 */
{ 2184375 }, /* offcore_response.demand_rfo.remote_cache_hitm\000\000cache\000Offcore demand RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x802\000\00000\000\000 */
{ 2194549 }, /* offcore_response.other.any_cache_dram\000\000cache\000Offcore other requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F80\000\00000\000\000 */
{ 2195463 }, /* offcore_response.other.any_location\000\000cache\000All offcore other requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF80\000\00000\000\000 */
{ 2196350 }, /* offcore_response.other.io_csr_mmio\000\000cache\000Offcore other requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8080\000\00000\000\000 */
{ 2218865 }, /* offcore_response.other.llc_hit_no_other_core\000\000cache\000Offcore other requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x180\000\00000\000\000 */
{ 2219214 }, /* offcore_response.other.llc_hit_other_core_hit\000\000cache\000Offcore other requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x280\000\00000\000\000 */
{ 2219560 }, /* offcore_response.other.llc_hit_other_core_hitm\000\000cache\000Offcore other requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x480\000\00000\000\000 */
{ 2219911 }, /* offcore_response.other.local_cache\000\000cache\000Offcore other requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x780\000\00000\000\000 */
{ 2220362 }, /* offcore_response.other.local_cache_dram\000\000cache\000Offcore other requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4780\000\00000\000\000 */
{ 2222084 }, /* offcore_response.other.remote_cache\000\000cache\000Offcore other requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1880\000\00000\000\000 */
{ 2222237 }, /* offcore_response.other.remote_cache_dram\000\000cache\000Offcore other requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3880\000\00000\000\000 */
{ 2222583 }, /* offcore_response.other.remote_cache_hit\000\000cache\000Offcore other requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1080\000\00000\000\000 */
{ 2222739 }, /* offcore_response.other.remote_cache_hitm\000\000cache\000Offcore other requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x880\000\00000\000\000 */
{ 2241116 }, /* offcore_response.pf_data.any_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F30\000\00000\000\000 */
{ 2242550 }, /* offcore_response.pf_data.any_location\000\000cache\000All offcore prefetch data requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF30\000\00000\000\000 */
{ 2242978 }, /* offcore_response.pf_data.io_csr_mmio\000\000cache\000Offcore prefetch data requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8030\000\00000\000\000 */
{ 2243466 }, /* offcore_response.pf_data.llc_hit_no_other_core\000\000cache\000Offcore prefetch data requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x130\000\00000\000\000 */
{ 2244025 }, /* offcore_response.pf_data.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x230\000\00000\000\000 */
{ 2244576 }, /* offcore_response.pf_data.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x430\000\00000\000\000 */
{ 2245135 }, /* offcore_response.pf_data.local_cache\000\000cache\000Offcore prefetch data requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x730\000\00000\000\000 */
{ 2245764 }, /* offcore_response.pf_data.local_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4730\000\00000\000\000 */
{ 2246609 }, /* offcore_response.pf_data.remote_cache\000\000cache\000Offcore prefetch data requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1830\000\00000\000\000 */
{ 2246935 }, /* offcore_response.pf_data.remote_cache_dram\000\000cache\000Offcore prefetch data requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3830\000\00000\000\000 */
{ 2247301 }, /* offcore_response.pf_data.remote_cache_hit\000\000cache\000Offcore prefetch data requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1030\000\00000\000\000 */
{ 2247633 }, /* offcore_response.pf_data.remote_cache_hitm\000\000cache\000Offcore prefetch data requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x830\000\00000\000\000 */
{ 2248801 }, /* offcore_response.pf_data_rd.any_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F10\000\00000\000\000 */
{ 2249775 }, /* offcore_response.pf_data_rd.any_location\000\000cache\000All offcore prefetch data reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF10\000\00000\000\000 */
{ 2250070 }, /* offcore_response.pf_data_rd.io_csr_mmio\000\000cache\000Offcore prefetch data reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8010\000\00000\000\000 */
{ 2250394 }, /* offcore_response.pf_data_rd.llc_hit_no_other_core\000\000cache\000Offcore prefetch data reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x110\000\00000\000\000 */
{ 2250763 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hit\000\000cache\000Offcore prefetch data reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x210\000\00000\000\000 */
{ 2251129 }, /* offcore_response.pf_data_rd.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch data reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x410\000\00000\000\000 */
{ 2251689 }, /* offcore_response.pf_data_rd.local_cache\000\000cache\000Offcore prefetch data reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x710\000\00000\000\000 */
{ 2252170 }, /* offcore_response.pf_data_rd.local_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4710\000\00000\000\000 */
{ 2253027 }, /* offcore_response.pf_data_rd.remote_cache\000\000cache\000Offcore prefetch data reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1810\000\00000\000\000 */
{ 2253190 }, /* offcore_response.pf_data_rd.remote_cache_dram\000\000cache\000Offcore prefetch data reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3810\000\00000\000\000 */
{ 2253556 }, /* offcore_response.pf_data_rd.remote_cache_hit\000\000cache\000Offcore prefetch data reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1010\000\00000\000\000 */
{ 2253722 }, /* offcore_response.pf_data_rd.remote_cache_hitm\000\000cache\000Offcore prefetch data reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x810\000\00000\000\000 */
{ 2254730 }, /* offcore_response.pf_ifetch.any_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F40\000\00000\000\000 */
{ 2255686 }, /* offcore_response.pf_ifetch.any_location\000\000cache\000All offcore prefetch code reads\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF40\000\00000\000\000 */
{ 2256127 }, /* offcore_response.pf_ifetch.io_csr_mmio\000\000cache\000Offcore prefetch code reads satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8040\000\00000\000\000 */
{ 2256445 }, /* offcore_response.pf_ifetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch code reads satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x140\000\00000\000\000 */
{ 2256808 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch code reads satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x240\000\00000\000\000 */
{ 2257168 }, /* offcore_response.pf_ifetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch code reads satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x440\000\00000\000\000 */
{ 2257717 }, /* offcore_response.pf_ifetch.local_cache\000\000cache\000Offcore prefetch code reads satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x740\000\00000\000\000 */
{ 2258191 }, /* offcore_response.pf_ifetch.local_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4740\000\00000\000\000 */
{ 2259035 }, /* offcore_response.pf_ifetch.remote_cache\000\000cache\000Offcore prefetch code reads satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1840\000\00000\000\000 */
{ 2259197 }, /* offcore_response.pf_ifetch.remote_cache_dram\000\000cache\000Offcore prefetch code reads satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3840\000\00000\000\000 */
{ 2259561 }, /* offcore_response.pf_ifetch.remote_cache_hit\000\000cache\000Offcore prefetch code reads that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1040\000\00000\000\000 */
{ 2259726 }, /* offcore_response.pf_ifetch.remote_cache_hitm\000\000cache\000Offcore prefetch code reads that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x840\000\00000\000\000 */
{ 2430767 }, /* offcore_response.pf_rfo.any_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F20\000\00000\000\000 */
{ 2431720 }, /* offcore_response.pf_rfo.any_location\000\000cache\000All offcore prefetch RFO requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF20\000\00000\000\000 */
{ 2432008 }, /* offcore_response.pf_rfo.io_csr_mmio\000\000cache\000Offcore prefetch RFO requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8020\000\00000\000\000 */
{ 2432325 }, /* offcore_response.pf_rfo.llc_hit_no_other_core\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x120\000\00000\000\000 */
{ 2432687 }, /* offcore_response.pf_rfo.llc_hit_other_core_hit\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x220\000\00000\000\000 */
{ 2433046 }, /* offcore_response.pf_rfo.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x420\000\00000\000\000 */
{ 2433410 }, /* offcore_response.pf_rfo.local_cache\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x720\000\00000\000\000 */
{ 2433882 }, /* offcore_response.pf_rfo.local_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4720\000\00000\000\000 */
{ 2434723 }, /* offcore_response.pf_rfo.remote_cache\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1820\000\00000\000\000 */
{ 2434884 }, /* offcore_response.pf_rfo.remote_cache_dram\000\000cache\000Offcore prefetch RFO requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3820\000\00000\000\000 */
{ 2435246 }, /* offcore_response.pf_rfo.remote_cache_hit\000\000cache\000Offcore prefetch RFO requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1020\000\00000\000\000 */
{ 2435410 }, /* offcore_response.pf_rfo.remote_cache_hitm\000\000cache\000Offcore prefetch RFO requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x820\000\00000\000\000 */
{ 2440683 }, /* offcore_response.prefetch.any_cache_dram\000\000cache\000Offcore prefetch requests satisfied by any cache or DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x7F70\000\00000\000\000 */
{ 2441633 }, /* offcore_response.prefetch.any_location\000\000cache\000All offcore prefetch requests\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xFF70\000\00000\000\000 */
{ 2441920 }, /* offcore_response.prefetch.io_csr_mmio\000\000cache\000Offcore prefetch requests satisfied by the IO, CSR, MMIO unit\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x8070\000\00000\000\000 */
{ 2442236 }, /* offcore_response.prefetch.llc_hit_no_other_core\000\000cache\000Offcore prefetch requests satisfied by the LLC and not found in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x170\000\00000\000\000 */
{ 2442597 }, /* offcore_response.prefetch.llc_hit_other_core_hit\000\000cache\000Offcore prefetch requests satisfied by the LLC and HIT in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x270\000\00000\000\000 */
{ 2442955 }, /* offcore_response.prefetch.llc_hit_other_core_hitm\000\000cache\000Offcore prefetch requests satisfied by the LLC  and HITM in a sibling core\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x470\000\00000\000\000 */
{ 2443318 }, /* offcore_response.prefetch.local_cache\000\000cache\000Offcore prefetch requests satisfied by the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x770\000\00000\000\000 */
{ 2443787 }, /* offcore_response.prefetch.local_cache_dram\000\000cache\000Offcore prefetch requests satisfied by the LLC or local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4770\000\00000\000\000 */
{ 2444624 }, /* offcore_response.prefetch.remote_cache\000\000cache\000Offcore prefetch requests satisfied by a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1870\000\00000\000\000 */
{ 2444783 }, /* offcore_response.prefetch.remote_cache_dram\000\000cache\000Offcore prefetch requests satisfied by a remote cache or remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x3870\000\00000\000\000 */
{ 2445141 }, /* offcore_response.prefetch.remote_cache_hit\000\000cache\000Offcore prefetch requests that HIT in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x1070\000\00000\000\000 */
{ 2445303 }, /* offcore_response.prefetch.remote_cache_hitm\000\000cache\000Offcore prefetch requests that HITM in a remote cache\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x870\000\00000\000\000 */
{ 2531564 }, /* sq_misc.lru_hints\000\000cache\000Super Queue LRU hints sent to LLC\000event=0xf4,period=2000000,umask=0x4\000\00000\000\000 */
{ 2532073 }, /* sq_misc.split_lock\000\000cache\000Super Queue lock splits across a cache line\000event=0xf4,period=2000000,umask=0x10\000\00000\000\000 */
{ 2536735 }, /* store_blocks.at_ret\000\000cache\000Loads delayed with at-Retirement block code\000event=0x6,period=200000,umask=0x4\000\00000\000\000 */
{ 2536845 }, /* store_blocks.l1d_block\000\000cache\000Cacheable loads delayed with L1D block code\000event=0x6,period=200000,umask=0x8\000\00000\000\000 */
{ 901660 }, /* fp_assist.all\000\000floating point\000X87 Floating point assists (Precise Event)\000event=0xf7,period=20000,umask=0x1\000\00000\000\000 */
{ 902741 }, /* fp_assist.input\000\000floating point\000X87 Floating poiint assists for invalid input value (Precise Event)\000event=0xf7,period=20000,umask=0x4\000\00000\000\000 */
{ 902880 }, /* fp_assist.output\000\000floating point\000X87 Floating point assists for invalid output value (Precise Event)\000event=0xf7,period=20000,umask=0x2\000\00000\000\000 */
{ 905570 }, /* fp_comp_ops_exe.mmx\000\000floating point\000MMX Uops\000event=0x10,period=2000000,umask=0x2\000\00000\000\000 */
{ 905656 }, /* fp_comp_ops_exe.sse2_integer\000\000floating point\000SSE2 integer Uops\000event=0x10,period=2000000,umask=0x8\000\00000\000\000 */
{ 905760 }, /* fp_comp_ops_exe.sse_double_precision\000\000floating point\000SSE* FP double precision Uops\000event=0x10,period=2000000,umask=0x80\000\00000\000\000 */
{ 905885 }, /* fp_comp_ops_exe.sse_fp\000\000floating point\000SSE and SSE2 FP Uops\000event=0x10,period=2000000,umask=0x4\000\00000\000\000 */
{ 905986 }, /* fp_comp_ops_exe.sse_fp_packed\000\000floating point\000SSE FP packed Uops\000event=0x10,period=2000000,umask=0x10\000\00000\000\000 */
{ 906093 }, /* fp_comp_ops_exe.sse_fp_scalar\000\000floating point\000SSE FP scalar Uops\000event=0x10,period=2000000,umask=0x20\000\00000\000\000 */
{ 907996 }, /* fp_comp_ops_exe.sse_single_precision\000\000floating point\000SSE* FP single precision Uops\000event=0x10,period=2000000,umask=0x40\000\00000\000\000 */
{ 908121 }, /* fp_comp_ops_exe.x87\000\000floating point\000Computational floating-point operations executed\000event=0x10,period=2000000,umask=0x1\000\00000\000\000 */
{ 910502 }, /* fp_mmx_trans.any\000\000floating point\000All Floating Point to and from MMX transitions\000event=0xcc,period=2000000,umask=0x3\000\00000\000\000 */
{ 910623 }, /* fp_mmx_trans.to_fp\000\000floating point\000Transitions from MMX to Floating Point instructions\000event=0xcc,period=2000000,umask=0x1\000\00000\000\000 */
{ 910751 }, /* fp_mmx_trans.to_mmx\000\000floating point\000Transitions from Floating Point to MMX instructions\000event=0xcc,period=2000000,umask=0x2\000\00000\000\000 */
{ 2524990 }, /* simd_int_128.pack\000\000floating point\000128 bit SIMD integer pack operations\000event=0x12,period=200000,umask=0x4\000\00000\000\000 */
{ 2525101 }, /* simd_int_128.packed_arith\000\000floating point\000128 bit SIMD integer arithmetic operations\000event=0x12,period=200000,umask=0x20\000\00000\000\000 */
{ 2525227 }, /* simd_int_128.packed_logical\000\000floating point\000128 bit SIMD integer logical operations\000event=0x12,period=200000,umask=0x10\000\00000\000\000 */
{ 2525352 }, /* simd_int_128.packed_mpy\000\000floating point\000128 bit SIMD integer multiply operations\000event=0x12,period=200000,umask=0x1\000\00000\000\000 */
{ 2525473 }, /* simd_int_128.packed_shift\000\000floating point\000128 bit SIMD integer shift operations\000event=0x12,period=200000,umask=0x2\000\00000\000\000 */
{ 2525593 }, /* simd_int_128.shuffle_move\000\000floating point\000128 bit SIMD integer shuffle/move operations\000event=0x12,period=200000,umask=0x40\000\00000\000\000 */
{ 2525721 }, /* simd_int_128.unpack\000\000floating point\000128 bit SIMD integer unpack operations\000event=0x12,period=200000,umask=0x8\000\00000\000\000 */
{ 2525836 }, /* simd_int_64.pack\000\000floating point\000SIMD integer 64 bit pack operations\000event=0xfd,period=200000,umask=0x4\000\00000\000\000 */
{ 2525945 }, /* simd_int_64.packed_arith\000\000floating point\000SIMD integer 64 bit arithmetic operations\000event=0xfd,period=200000,umask=0x20\000\00000\000\000 */
{ 2526069 }, /* simd_int_64.packed_logical\000\000floating point\000SIMD integer 64 bit logical operations\000event=0xfd,period=200000,umask=0x10\000\00000\000\000 */
{ 2526192 }, /* simd_int_64.packed_mpy\000\000floating point\000SIMD integer 64 bit packed multiply operations\000event=0xfd,period=200000,umask=0x1\000\00000\000\000 */
{ 2526318 }, /* simd_int_64.packed_shift\000\000floating point\000SIMD integer 64 bit shift operations\000event=0xfd,period=200000,umask=0x2\000\00000\000\000 */
{ 2526436 }, /* simd_int_64.shuffle_move\000\000floating point\000SIMD integer 64 bit shuffle/move operations\000event=0xfd,period=200000,umask=0x40\000\00000\000\000 */
{ 2526562 }, /* simd_int_64.unpack\000\000floating point\000SIMD integer 64 bit unpack operations\000event=0xfd,period=200000,umask=0x8\000\00000\000\000 */
{ 1302909 }, /* macro_insts.decoded\000\000frontend\000Instructions decoded\000event=0xd0,period=2000000,umask=0x1\000\00000\000\000 */
{ 1303001 }, /* macro_insts.fusions_decoded\000\000frontend\000Macro-fused instructions decoded\000event=0xa6,period=2000000,umask=0x1\000\00000\000\000 */
{ 2571312 }, /* two_uop_insts_decoded\000\000frontend\000Two Uop instructions decoded\000event=0x19,period=2000000,umask=0x1\000\00000\000\000 */
{ 1429691 }, /* misalign_mem_ref.store\000\000memory\000Misaligned store references\000event=0x5,period=200000,umask=0x2\000\00000\000\000 */
{ 1921326 }, /* offcore_response.any_data.any_dram\000\000memory\000Offcore data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6011\000\00000\000\000 */
{ 1921649 }, /* offcore_response.any_data.any_llc_miss\000\000memory\000Offcore data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF811\000\00000\000\000 */
{ 1924401 }, /* offcore_response.any_data.local_dram\000\000memory\000Offcore data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4011\000\00000\000\000 */
{ 1925886 }, /* offcore_response.any_data.remote_dram\000\000memory\000Offcore data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2011\000\00000\000\000 */
{ 1937151 }, /* offcore_response.any_ifetch.any_dram\000\000memory\000Offcore code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6044\000\00000\000\000 */
{ 1937475 }, /* offcore_response.any_ifetch.any_llc_miss\000\000memory\000Offcore code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF844\000\00000\000\000 */
{ 1940240 }, /* offcore_response.any_ifetch.local_dram\000\000memory\000Offcore code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4044\000\00000\000\000 */
{ 1941734 }, /* offcore_response.any_ifetch.remote_dram\000\000memory\000Offcore code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2044\000\00000\000\000 */
{ 1960533 }, /* offcore_response.any_request.any_dram\000\000memory\000Offcore requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x60FF\000\00000\000\000 */
{ 1960858 }, /* offcore_response.any_request.any_llc_miss\000\000memory\000Offcore requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF8FF\000\00000\000\000 */
{ 1971901 }, /* offcore_response.any_request.local_dram\000\000memory\000Offcore requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x40FF\000\00000\000\000 */
{ 1974726 }, /* offcore_response.any_request.remote_dram\000\000memory\000Offcore requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x20FF\000\00000\000\000 */
{ 1975695 }, /* offcore_response.any_rfo.any_dram\000\000memory\000Offcore RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6022\000\00000\000\000 */
{ 1976012 }, /* offcore_response.any_rfo.any_llc_miss\000\000memory\000Offcore RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF822\000\00000\000\000 */
{ 1987540 }, /* offcore_response.any_rfo.local_dram\000\000memory\000Offcore RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4022\000\00000\000\000 */
{ 1990469 }, /* offcore_response.any_rfo.remote_dram\000\000memory\000Offcore RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2022\000\00000\000\000 */
{ 1998451 }, /* offcore_response.corewb.any_dram\000\000memory\000Offcore writebacks to any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6008\000\00000\000\000 */
{ 1998754 }, /* offcore_response.corewb.any_llc_miss\000\000memory\000Offcore writebacks that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF808\000\00000\000\000 */
{ 2009442 }, /* offcore_response.corewb.local_dram\000\000memory\000Offcore writebacks to the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4008\000\00000\000\000 */
{ 2011385 }, /* offcore_response.corewb.remote_dram\000\000memory\000Offcore writebacks to a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2008\000\00000\000\000 */
{ 2013505 }, /* offcore_response.data_ifetch.any_dram\000\000memory\000Offcore code or data read requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6077\000\00000\000\000 */
{ 2013848 }, /* offcore_response.data_ifetch.any_llc_miss\000\000memory\000Offcore code or data read requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF877\000\00000\000\000 */
{ 2016797 }, /* offcore_response.data_ifetch.local_dram\000\000memory\000Offcore code or data read requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4077\000\00000\000\000 */
{ 2018399 }, /* offcore_response.data_ifetch.remote_dram\000\000memory\000Offcore code or data read requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2077\000\00000\000\000 */
{ 2019406 }, /* offcore_response.data_in.any_dram\000\000memory\000Offcore request = all data, response = any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6033\000\00000\000\000 */
{ 2019728 }, /* offcore_response.data_in.any_llc_miss\000\000memory\000Offcore request = all data, response = any LLC miss\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF833\000\00000\000\000 */
{ 2022752 }, /* offcore_response.data_in.local_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4033\000\00000\000\000 */
{ 2024277 }, /* offcore_response.data_in.remote_dram\000\000memory\000Offcore data reads, RFOs, and prefetches satisfied by the remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2033\000\00000\000\000 */
{ 2072578 }, /* offcore_response.demand_data.any_dram\000\000memory\000Offcore demand data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6003\000\00000\000\000 */
{ 2072915 }, /* offcore_response.demand_data.any_llc_miss\000\000memory\000Offcore demand data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF803\000\00000\000\000 */
{ 2075804 }, /* offcore_response.demand_data.local_dram\000\000memory\000Offcore demand data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4003\000\00000\000\000 */
{ 2077370 }, /* offcore_response.demand_data.remote_dram\000\000memory\000Offcore demand data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2003\000\00000\000\000 */
{ 2078403 }, /* offcore_response.demand_data_rd.any_dram\000\000memory\000Offcore demand data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6001\000\00000\000\000 */
{ 2078746 }, /* offcore_response.demand_data_rd.any_llc_miss\000\000memory\000Offcore demand data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF801\000\00000\000\000 */
{ 2121869 }, /* offcore_response.demand_data_rd.local_dram\000\000memory\000Offcore demand data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4001\000\00000\000\000 */
{ 2126430 }, /* offcore_response.demand_data_rd.remote_dram\000\000memory\000Offcore demand data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2001\000\00000\000\000 */
{ 2130431 }, /* offcore_response.demand_ifetch.any_dram\000\000memory\000Offcore demand code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6004\000\00000\000\000 */
{ 2130771 }, /* offcore_response.demand_ifetch.any_llc_miss\000\000memory\000Offcore demand code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF804\000\00000\000\000 */
{ 2133873 }, /* offcore_response.demand_ifetch.local_dram\000\000memory\000Offcore demand code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4004\000\00000\000\000 */
{ 2135445 }, /* offcore_response.demand_ifetch.remote_dram\000\000memory\000Offcore demand code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2004\000\00000\000\000 */
{ 2136462 }, /* offcore_response.demand_rfo.any_dram\000\000memory\000Offcore demand RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6002\000\00000\000\000 */
{ 2136795 }, /* offcore_response.demand_rfo.any_llc_miss\000\000memory\000Offcore demand RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF802\000\00000\000\000 */
{ 2180163 }, /* offcore_response.demand_rfo.local_dram\000\000memory\000Offcore demand RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4002\000\00000\000\000 */
{ 2184707 }, /* offcore_response.demand_rfo.remote_dram\000\000memory\000Offcore demand RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2002\000\00000\000\000 */
{ 2194857 }, /* offcore_response.other.any_dram\000\000memory\000Offcore other requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6080\000\00000\000\000 */
{ 2195170 }, /* offcore_response.other.any_llc_miss\000\000memory\000Offcore other requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF880\000\00000\000\000 */
{ 2223051 }, /* offcore_response.other.remote_dram\000\000memory\000Offcore other requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2080\000\00000\000\000 */
{ 2241606 }, /* offcore_response.pf_data.any_dram\000\000memory\000Offcore prefetch data requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6030\000\00000\000\000 */
{ 2242087 }, /* offcore_response.pf_data.any_llc_miss\000\000memory\000Offcore prefetch data requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF830\000\00000\000\000 */
{ 2246100 }, /* offcore_response.pf_data.local_dram\000\000memory\000Offcore prefetch data requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4030\000\00000\000\000 */
{ 2248126 }, /* offcore_response.pf_data.remote_dram\000\000memory\000Offcore prefetch data requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2030\000\00000\000\000 */
{ 2249129 }, /* offcore_response.pf_data_rd.any_dram\000\000memory\000Offcore prefetch data reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6010\000\00000\000\000 */
{ 2249462 }, /* offcore_response.pf_data_rd.any_llc_miss\000\000memory\000Offcore prefetch data reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF810\000\00000\000\000 */
{ 2252506 }, /* offcore_response.pf_data_rd.local_dram\000\000memory\000Offcore prefetch data reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4010\000\00000\000\000 */
{ 2254054 }, /* offcore_response.pf_data_rd.remote_dram\000\000memory\000Offcore prefetch data reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2010\000\00000\000\000 */
{ 2255052 }, /* offcore_response.pf_ifetch.any_dram\000\000memory\000Offcore prefetch code reads satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6040\000\00000\000\000 */
{ 2255379 }, /* offcore_response.pf_ifetch.any_llc_miss\000\000memory\000Offcore prefetch code reads that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF840\000\00000\000\000 */
{ 2258525 }, /* offcore_response.pf_ifetch.local_dram\000\000memory\000Offcore prefetch code reads satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4040\000\00000\000\000 */
{ 2260052 }, /* offcore_response.pf_ifetch.remote_dram\000\000memory\000Offcore prefetch code reads satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2040\000\00000\000\000 */
{ 2431088 }, /* offcore_response.pf_rfo.any_dram\000\000memory\000Offcore prefetch RFO requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6020\000\00000\000\000 */
{ 2431414 }, /* offcore_response.pf_rfo.any_llc_miss\000\000memory\000Offcore prefetch RFO requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF820\000\00000\000\000 */
{ 2434214 }, /* offcore_response.pf_rfo.local_dram\000\000memory\000Offcore prefetch RFO requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4020\000\00000\000\000 */
{ 2435735 }, /* offcore_response.pf_rfo.remote_dram\000\000memory\000Offcore prefetch RFO requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2020\000\00000\000\000 */
{ 2441003 }, /* offcore_response.prefetch.any_dram\000\000memory\000Offcore prefetch requests satisfied by any DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x6070\000\00000\000\000 */
{ 2441328 }, /* offcore_response.prefetch.any_llc_miss\000\000memory\000Offcore prefetch requests that missed the LLC\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0xF870\000\00000\000\000 */
{ 2444115 }, /* offcore_response.prefetch.local_dram\000\000memory\000Offcore prefetch requests satisfied by the local DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x4070\000\00000\000\000 */
{ 2445627 }, /* offcore_response.prefetch.remote_dram\000\000memory\000Offcore prefetch requests satisfied by a remote DRAM\000event=0xb7,period=100000,umask=0x1,offcore_rsp=0x2070\000\00000\000\000 */
{ 835049 }, /* es_reg_renames\000\000other\000ES segment renames\000event=0xd5,period=2000000,umask=0x1\000\00000\000\000 */
{ 1075635 }, /* io_transactions\000\000other\000I/O transactions\000event=0x6c,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114741 }, /* l1i.cycles_stalled\000\000other\000L1I instruction fetch stall cycles\000event=0x80,period=2000000,umask=0x4\000\00000\000\000 */
{ 1114843 }, /* l1i.hits\000\000other\000L1I instruction fetch hits\000event=0x80,period=2000000,umask=0x1\000\00000\000\000 */
{ 1114927 }, /* l1i.misses\000\000other\000L1I instruction fetch misses\000event=0x80,period=2000000,umask=0x2\000\00000\000\000 */
{ 1115015 }, /* l1i.reads\000\000other\000L1I Instruction fetches\000event=0x80,period=2000000,umask=0x3\000\00000\000\000 */
{ 1189817 }, /* large_itlb.hit\000\000other\000Large ITLB hit\000event=0x82,period=200000,umask=0x1\000\00000\000\000 */
{ 1228602 }, /* load_block.overlap_store\000\000other\000Loads that partially overlap an earlier store\000event=0x3,period=200000,umask=0x2\000\00000\000\000 */
{ 1228719 }, /* load_dispatch.any\000\000other\000All loads dispatched\000event=0x13,period=2000000,umask=0x7\000\00000\000\000 */
{ 1228806 }, /* load_dispatch.mob\000\000other\000Loads dispatched from the MOB\000event=0x13,period=2000000,umask=0x4\000\00000\000\000 */
{ 1228902 }, /* load_dispatch.rs\000\000other\000Loads dispatched that bypass the MOB\000event=0x13,period=2000000,umask=0x1\000\00000\000\000 */
{ 1229004 }, /* load_dispatch.rs_delayed\000\000other\000Loads dispatched from stage 305\000event=0x13,period=2000000,umask=0x2\000\00000\000\000 */
{ 2476952 }, /* partial_address_alias\000\000other\000False dependencies due to partial address aliasing\000event=0x7,period=200000,umask=0x1\000\00000\000\000 */
{ 2521171 }, /* sb_drain.any\000\000other\000All Store buffer stall cycles\000event=0x4,period=200000,umask=0x7\000\00000\000\000 */
{ 2521260 }, /* seg_rename_stalls\000\000other\000Segment rename stall cycles\000event=0xd4,period=2000000,umask=0x1\000\00000\000\000 */
{ 2528735 }, /* snoop_response.hit\000\000other\000Thread responded HIT to snoop\000event=0xb8,period=100000,umask=0x1\000\00000\000\000 */
{ 2528831 }, /* snoop_response.hite\000\000other\000Thread responded HITE to snoop\000event=0xb8,period=100000,umask=0x2\000\00000\000\000 */
{ 2528929 }, /* snoop_response.hitm\000\000other\000Thread responded HITM to snoop\000event=0xb8,period=100000,umask=0x4\000\00000\000\000 */
{ 2529217 }, /* snoopq_requests.code\000\000other\000Snoop code requests\000event=0xb4,period=100000,umask=0x4\000\00000\000\000 */
{ 2529305 }, /* snoopq_requests.data\000\000other\000Snoop data requests\000event=0xb4,period=100000,umask=0x1\000\00000\000\000 */
{ 2529393 }, /* snoopq_requests.invalidate\000\000other\000Snoop invalidate requests\000event=0xb4,period=100000,umask=0x2\000\00000\000\000 */
{ 2529493 }, /* snoopq_requests_outstanding.code\000\000other\000Outstanding snoop code requests\000event=0xb3,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529606 }, /* snoopq_requests_outstanding.code_not_empty\000\000other\000Cycles snoop code requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 2529739 }, /* snoopq_requests_outstanding.data\000\000other\000Outstanding snoop data requests\000event=0xb3,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529852 }, /* snoopq_requests_outstanding.data_not_empty\000\000other\000Cycles snoop data requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 2529985 }, /* snoopq_requests_outstanding.invalidate\000\000other\000Outstanding snoop invalidate requests\000event=0xb3,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530110 }, /* snoopq_requests_outstanding.invalidate_not_empty\000\000other\000Cycles snoop invalidate requests queued\000event=0xb3,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 2530255 }, /* sq_full_stall_cycles\000\000other\000Super Queue full stall cycles\000event=0xf6,period=2000000,umask=0x1\000\00000\000\000 */
{ 467271 }, /* arith.cycles_div_busy\000\000pipeline\000Cycles the divider is busy\000event=0x14,period=2000000,umask=0x1\000\00000\000\000 */
{ 467371 }, /* arith.div\000\000pipeline\000Divide Operations executed\000event=0x14,cmask=1,edge=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 471330 }, /* arith.mul\000\000pipeline\000Multiply operations executed\000event=0x14,period=2000000,umask=0x2\000\00000\000\000 */
{ 473654 }, /* baclear.bad_target\000\000pipeline\000BACLEAR asserted with bad target address\000event=0xe6,period=2000000,umask=0x2\000\00000\000\000 */
{ 473765 }, /* baclear.clear\000\000pipeline\000BACLEAR asserted, regardless of cause\000event=0xe6,period=2000000,umask=0x1\000\00000\000\000 */
{ 473868 }, /* baclear_force_iq\000\000pipeline\000Instruction queue forced BACLEAR\000event=0xa7,period=2000000,umask=0x1\000\00000\000\000 */
{ 487276 }, /* bpu_clears.early\000\000pipeline\000Early Branch Prediciton Unit clears\000event=0xe8,period=2000000,umask=0x1\000\00000\000\000 */
{ 487380 }, /* bpu_clears.late\000\000pipeline\000Late Branch Prediction Unit clears\000event=0xe8,period=2000000,umask=0x2\000\00000\000\000 */
{ 487482 }, /* bpu_missed_call_ret\000\000pipeline\000Branch prediction unit missed call or return\000event=0xe5,period=2000000,umask=0x1\000\00000\000\000 */
{ 487598 }, /* br_inst_decoded\000\000pipeline\000Branch instructions decoded\000event=0xe0,period=2000000,umask=0x1\000\00000\000\000 */
{ 491001 }, /* br_inst_exec.any\000\000pipeline\000Branch instructions executed\000event=0x88,period=200000,umask=0x7f\000\00000\000\000 */
{ 491098 }, /* br_inst_exec.cond\000\000pipeline\000Conditional branch instructions executed\000event=0x88,period=200000,umask=0x1\000\00000\000\000 */
{ 491207 }, /* br_inst_exec.direct\000\000pipeline\000Unconditional branches executed\000event=0x88,period=200000,umask=0x2\000\00000\000\000 */
{ 491309 }, /* br_inst_exec.direct_near_call\000\000pipeline\000Unconditional call branches executed\000event=0x88,period=20000,umask=0x10\000\00000\000\000 */
{ 491426 }, /* br_inst_exec.indirect_near_call\000\000pipeline\000Indirect call branches executed\000event=0x88,period=20000,umask=0x20\000\00000\000\000 */
{ 491540 }, /* br_inst_exec.indirect_non_call\000\000pipeline\000Indirect non call branches executed\000event=0x88,period=20000,umask=0x4\000\00000\000\000 */
{ 491656 }, /* br_inst_exec.near_calls\000\000pipeline\000Call branches executed\000event=0x88,period=20000,umask=0x30\000\00000\000\000 */
{ 491753 }, /* br_inst_exec.non_calls\000\000pipeline\000All non call branches executed\000event=0x88,period=200000,umask=0x7\000\00000\000\000 */
{ 492324 }, /* br_inst_exec.return_near\000\000pipeline\000Indirect return branches executed\000event=0x88,period=20000,umask=0x8\000\00000\000\000 */
{ 492432 }, /* br_inst_exec.taken\000\000pipeline\000Taken branches executed\000event=0x88,period=200000,umask=0x40\000\00000\000\000 */
{ 498319 }, /* br_inst_retired.all_branches\000\000pipeline\000Retired branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x4\000\00000\000\000 */
{ 506620 }, /* br_inst_retired.conditional\000\000pipeline\000Retired conditional branch instructions (Precise Event)\000event=0xc4,period=200000,umask=0x1\000\00000\000\000 */
{ 515982 }, /* br_inst_retired.near_call\000\000pipeline\000Retired near call instructions (Precise Event)\000event=0xc4,period=20000,umask=0x2\000\00000\000\000 */
{ 530639 }, /* br_misp_exec.any\000\000pipeline\000Mispredicted branches executed\000event=0x89,period=20000,umask=0x7f\000\00000\000\000 */
{ 530737 }, /* br_misp_exec.cond\000\000pipeline\000Mispredicted conditional branches executed\000event=0x89,period=20000,umask=0x1\000\00000\000\000 */
{ 530847 }, /* br_misp_exec.direct\000\000pipeline\000Mispredicted unconditional branches executed\000event=0x89,period=20000,umask=0x2\000\00000\000\000 */
{ 530961 }, /* br_misp_exec.direct_near_call\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=2000,umask=0x10\000\00000\000\000 */
{ 531333 }, /* br_misp_exec.indirect_near_call\000\000pipeline\000Mispredicted indirect call branches executed\000event=0x89,period=2000,umask=0x20\000\00000\000\000 */
{ 531459 }, /* br_misp_exec.indirect_non_call\000\000pipeline\000Mispredicted indirect non call branches executed\000event=0x89,period=2000,umask=0x4\000\00000\000\000 */
{ 531587 }, /* br_misp_exec.near_calls\000\000pipeline\000Mispredicted call branches executed\000event=0x89,period=2000,umask=0x30\000\00000\000\000 */
{ 531696 }, /* br_misp_exec.non_calls\000\000pipeline\000Mispredicted non call branches executed\000event=0x89,period=20000,umask=0x7\000\00000\000\000 */
{ 532460 }, /* br_misp_exec.return_near\000\000pipeline\000Mispredicted return branches executed\000event=0x89,period=2000,umask=0x8\000\00000\000\000 */
{ 532571 }, /* br_misp_exec.taken\000\000pipeline\000Mispredicted taken branches executed\000event=0x89,period=20000,umask=0x40\000\00000\000\000 */
{ 538916 }, /* br_misp_retired.all_branches\000\000pipeline\000Mispredicted retired branch instructions (Precise Event)\000event=0xc5,period=20000,umask=0x4\000\00000\000\000 */
{ 547126 }, /* br_misp_retired.conditional\000\000pipeline\000Mispredicted conditional retired branches (Precise Event)\000event=0xc5,period=20000,umask=0x1\000\00000\000\000 */
{ 554975 }, /* br_misp_retired.near_call\000\000pipeline\000Mispredicted near retired calls (Precise Event)\000event=0xc5,period=2000,umask=0x2\000\00000\000\000 */
{ 620914 }, /* cpu_clk_unhalted.ref\000\000pipeline\000Reference cycles when thread is not halted (fixed counter)\000event=0x0,umask=0x03,period=2000003\000\00000\000\000 */
{ 622158 }, /* cpu_clk_unhalted.ref_p\000\000pipeline\000Reference base clock (133 Mhz) cycles when thread is not halted (programmable counter)\000event=0x3c,period=100000,umask=0x1\000\00000\000\000 */
{ 643775 }, /* cpu_clk_unhalted.thread\000\000pipeline\000Cycles when thread is not halted (fixed counter)\000event=0x3c,period=2000003\000\00000\000\000 */
{ 647207 }, /* cpu_clk_unhalted.thread_p\000\000pipeline\000Cycles when thread is not halted (programmable counter)\000event=0x3c,period=2000000\000\00000\000\000 */
{ 649803 }, /* cpu_clk_unhalted.total_cycles\000\000pipeline\000Total CPU cycles\000event=0x3c,cmask=2,inv=1,period=2000000\000\00000\000\000 */
{ 1040461 }, /* ild_stall.any\000\000pipeline\000Any Instruction Length Decoder stall cycles\000event=0x87,period=2000000,umask=0xf\000\00000\000\000 */
{ 1040570 }, /* ild_stall.iq_full\000\000pipeline\000Instruction Queue full stall cycles\000event=0x87,period=2000000,umask=0x4\000\00000\000\000 */
{ 1040907 }, /* ild_stall.lcp\000\000pipeline\000Length Change Prefix stall cycles\000event=0x87,period=2000000,umask=0x1\000\00000\000\000 */
{ 1042997 }, /* ild_stall.mru\000\000pipeline\000Stall cycles due to BPU MRU bypass\000event=0x87,period=2000000,umask=0x2\000\00000\000\000 */
{ 1043097 }, /* ild_stall.regen\000\000pipeline\000Regen stall cycles\000event=0x87,period=2000000,umask=0x8\000\00000\000\000 */
{ 1043183 }, /* inst_decoded.dec0\000\000pipeline\000Instructions that must be decoded by decoder 0\000event=0x18,period=2000000,umask=0x1\000\00000\000\000 */
{ 1043960 }, /* inst_queue_write_cycles\000\000pipeline\000Cycles instructions are written to the instruction queue\000event=0x1e,period=2000000,umask=0x1\000\00000\000\000 */
{ 1044092 }, /* inst_queue_writes\000\000pipeline\000Instructions written to instruction queue\000event=0x17,period=2000000,umask=0x1\000\00000\000\000 */
{ 1047147 }, /* inst_retired.any\000\000pipeline\000Instructions retired (fixed counter)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1053554 }, /* inst_retired.any_p\000\000pipeline\000Instructions retired (Programmable counter and Precise Event) (Precise event)\000event=0xc0,period=2000003\000\00000\000\000 */
{ 1057737 }, /* inst_retired.mmx\000\000pipeline\000Retired MMX instructions (Precise Event)\000event=0xc0,period=2000000,umask=0x4\000\00000\000\000 */
{ 1063146 }, /* inst_retired.total_cycles\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1063652 }, /* inst_retired.total_cycles_ps\000\000pipeline\000Total cycles (Precise Event)\000event=0xc0,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1064586 }, /* inst_retired.x87\000\000pipeline\000Retired floating-point operations (Precise Event)\000event=0xc0,period=2000000,umask=0x2\000\00000\000\000 */
{ 1231057 }, /* load_hit_pre\000\000pipeline\000Load operations conflicting with software prefetches\000event=0x4c,period=200000,umask=0x1\000\00000\000\000 */
{ 1283188 }, /* lsd.active\000\000pipeline\000Cycles when uops were delivered by the LSD\000event=0xa8,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1285888 }, /* lsd.inactive\000\000pipeline\000Cycles no uops were delivered by the LSD\000event=0xa8,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 1286788 }, /* lsd_overflow\000\000pipeline\000Loops that can't stream from the instruction queue\000event=0x20,period=2000000,umask=0x1\000\00000\000\000 */
{ 1289354 }, /* machine_clears.cycles\000\000pipeline\000Cycles machine clear asserted\000event=0xc3,period=20000,umask=0x1\000\00000\000\000 */
{ 1293852 }, /* machine_clears.mem_order\000\000pipeline\000Execution pipeline restart due to Memory ordering conflicts\000event=0xc3,period=20000,umask=0x2\000\00000\000\000 */
{ 1300312 }, /* machine_clears.smc\000\000pipeline\000Self-Modifying Code detected\000event=0xc3,period=20000,umask=0x4\000\00000\000\000 */
{ 2483994 }, /* rat_stalls.any\000\000pipeline\000All RAT stall cycles\000event=0xd2,period=2000000,umask=0xf\000\00000\000\000 */
{ 2484081 }, /* rat_stalls.flags\000\000pipeline\000Flag stall cycles\000event=0xd2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2484167 }, /* rat_stalls.registers\000\000pipeline\000Partial register stall cycles\000event=0xd2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2484269 }, /* rat_stalls.rob_read_port\000\000pipeline\000ROB read port stalls cycles\000event=0xd2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2484373 }, /* rat_stalls.scoreboard\000\000pipeline\000Scoreboard stall cycles\000event=0xd2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2501064 }, /* resource_stalls.any\000\000pipeline\000Resource related stall cycles\000event=0xa2,period=2000000,umask=0x1\000\00000\000\000 */
{ 2502029 }, /* resource_stalls.fpcw\000\000pipeline\000FPU control word write stall cycles\000event=0xa2,period=2000000,umask=0x20\000\00000\000\000 */
{ 2502398 }, /* resource_stalls.load\000\000pipeline\000Load buffer stall cycles\000event=0xa2,period=2000000,umask=0x2\000\00000\000\000 */
{ 2502656 }, /* resource_stalls.mxcsr\000\000pipeline\000MXCSR rename stall cycles\000event=0xa2,period=2000000,umask=0x40\000\00000\000\000 */
{ 2502894 }, /* resource_stalls.other\000\000pipeline\000Other Resource related stall cycles\000event=0xa2,period=2000000,umask=0x80\000\00000\000\000 */
{ 2503359 }, /* resource_stalls.rob_full\000\000pipeline\000ROB full stall cycles\000event=0xa2,period=2000000,umask=0x10\000\00000\000\000 */
{ 2504132 }, /* resource_stalls.rs_full\000\000pipeline\000Reservation Station full stall cycles\000event=0xa2,period=2000000,umask=0x4\000\00000\000\000 */
{ 2506545 }, /* resource_stalls.store\000\000pipeline\000Store buffer stall cycles\000event=0xa2,period=2000000,umask=0x8\000\00000\000\000 */
{ 2536082 }, /* ssex_uops_retired.packed_double\000\000pipeline\000SIMD Packed-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x4\000\00000\000\000 */
{ 2536212 }, /* ssex_uops_retired.packed_single\000\000pipeline\000SIMD Packed-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x1\000\00000\000\000 */
{ 2536342 }, /* ssex_uops_retired.scalar_double\000\000pipeline\000SIMD Scalar-Double Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x8\000\00000\000\000 */
{ 2536472 }, /* ssex_uops_retired.scalar_single\000\000pipeline\000SIMD Scalar-Single Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x2\000\00000\000\000 */
{ 2536602 }, /* ssex_uops_retired.vector_integer\000\000pipeline\000SIMD Vector Integer Uops retired (Precise Event)\000event=0xc7,period=200000,umask=0x10\000\00000\000\000 */
{ 6178001 }, /* uop_unfusion\000\000pipeline\000Uop unfusions due to FP exceptions\000event=0xdb,period=2000000,umask=0x1\000\00000\000\000 */
{ 6178955 }, /* uops_decoded.esp_folding\000\000pipeline\000Stack pointer instructions decoded\000event=0xd1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6179066 }, /* uops_decoded.esp_sync\000\000pipeline\000Stack pointer sync operations\000event=0xd1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6179169 }, /* uops_decoded.ms_cycles_active\000\000pipeline\000Uops decoded by Microcode Sequencer\000event=0xd1,cmask=1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6179294 }, /* uops_decoded.stall_cycles\000\000pipeline\000Cycles no Uops are decoded\000event=0xd1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6193659 }, /* uops_executed.core_active_cycles\000\000pipeline\000Cycles Uops executed on any port (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6193804 }, /* uops_executed.core_active_cycles_no_port5\000\000pipeline\000Cycles Uops executed on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199237 }, /* uops_executed.core_stall_count\000\000pipeline\000Uops executed on any port (core count)\000event=0xb1,cmask=1,edge=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199539 }, /* uops_executed.core_stall_count_no_port5\000\000pipeline\000Uops executed on ports 0-4 (core count)\000event=0xb1,cmask=1,edge=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6199692 }, /* uops_executed.core_stall_cycles\000\000pipeline\000Cycles no Uops issued on any port (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x3f\000\00000\000\000 */
{ 6199843 }, /* uops_executed.core_stall_cycles_no_port5\000\000pipeline\000Cycles no Uops issued on ports 0-4 (core count)\000event=0xb1,any=1,cmask=1,inv=1,period=2000000,umask=0x1f\000\00000\000\000 */
{ 6204390 }, /* uops_executed.port0\000\000pipeline\000Uops executed on port 0\000event=0xb1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6204143 }, /* uops_executed.port015\000\000pipeline\000Uops issued on ports 0, 1 or 5\000event=0xb1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204248 }, /* uops_executed.port015_stall_cycles\000\000pipeline\000Cycles no Uops issued on ports 0, 1 or 5\000event=0xb1,cmask=1,inv=1,period=2000000,umask=0x40\000\00000\000\000 */
{ 6204485 }, /* uops_executed.port1\000\000pipeline\000Uops executed on port 1\000event=0xb1,period=2000000,umask=0x2\000\00000\000\000 */
{ 6204580 }, /* uops_executed.port234_core\000\000pipeline\000Uops issued on ports 2, 3 or 4\000event=0xb1,any=1,period=2000000,umask=0x80\000\00000\000\000 */
{ 6204696 }, /* uops_executed.port2_core\000\000pipeline\000Uops executed on port 2 (core count)\000event=0xb1,any=1,period=2000000,umask=0x4\000\00000\000\000 */
{ 6204815 }, /* uops_executed.port3_core\000\000pipeline\000Uops executed on port 3 (core count)\000event=0xb1,any=1,period=2000000,umask=0x8\000\00000\000\000 */
{ 6204934 }, /* uops_executed.port4_core\000\000pipeline\000Uops executed on port 4 (core count)\000event=0xb1,any=1,period=2000000,umask=0x10\000\00000\000\000 */
{ 6205054 }, /* uops_executed.port5\000\000pipeline\000Uops executed on port 5\000event=0xb1,period=2000000,umask=0x20\000\00000\000\000 */
{ 6213590 }, /* uops_issued.any\000\000pipeline\000Uops issued\000event=0xe,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216019 }, /* uops_issued.core_stall_cycles\000\000pipeline\000Cycles no Uops were issued on any thread\000event=0xe,any=1,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6216805 }, /* uops_issued.cycles_all_threads\000\000pipeline\000Cycles Uops were issued on either thread\000event=0xe,any=1,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6217626 }, /* uops_issued.fused\000\000pipeline\000Fused Uops issued\000event=0xe,period=2000000,umask=0x2\000\00000\000\000 */
{ 6219127 }, /* uops_issued.stall_cycles\000\000pipeline\000Cycles no Uops were issued\000event=0xe,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6225258 }, /* uops_retired.active_cycles\000\000pipeline\000Cycles Uops are being retired (Precise event)\000event=0xc2,cmask=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6227775 }, /* uops_retired.any\000\000pipeline\000Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x1\000\00000\000\000 */
{ 6231023 }, /* uops_retired.macro_fused\000\000pipeline\000Macro-fused Uops retired (Precise Event)\000event=0xc2,period=2000000,umask=0x4\000\00000\000\000 */
{ 6233951 }, /* uops_retired.retire_slots\000\000pipeline\000Retirement slots used (Precise Event)\000event=0xc2,period=2000000,umask=0x2\000\00000\000\000 */
{ 6238074 }, /* uops_retired.stall_cycles\000\000pipeline\000Cycles Uops are not retiring (Precise Event)\000event=0xc2,cmask=1,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 6240810 }, /* uops_retired.total_cycles\000\000pipeline\000Total cycles using precise uop retired event (Precise Event)\000event=0xc2,cmask=16,inv=1,period=2000000,umask=0x1\000\00000\000\000 */
{ 787008 }, /* dtlb_load_misses.any\000\000virtual memory\000DTLB load misses\000event=0x8,period=200000,umask=0x1\000\00000\000\000 */
{ 787632 }, /* dtlb_load_misses.large_walk_completed\000\000virtual memory\000DTLB load miss large page walks\000event=0x8,period=200000,umask=0x80\000\00000\000\000 */
{ 789416 }, /* dtlb_load_misses.pde_miss\000\000virtual memory\000DTLB load miss caused by low part of address\000event=0x8,period=200000,umask=0x20\000\00000\000\000 */
{ 789810 }, /* dtlb_load_misses.stlb_hit\000\000virtual memory\000DTLB second level hit\000event=0x8,period=2000000,umask=0x10\000\00000\000\000 */
{ 794527 }, /* dtlb_load_misses.walk_completed\000\000virtual memory\000DTLB load miss page walks complete\000event=0x8,period=200000,umask=0x2\000\00000\000\000 */
{ 806100 }, /* dtlb_load_misses.walk_cycles\000\000virtual memory\000DTLB load miss page walk cycles\000event=0x8,period=200000,umask=0x4\000\00000\000\000 */
{ 809538 }, /* dtlb_misses.any\000\000virtual memory\000DTLB misses\000event=0x49,period=200000,umask=0x1\000\00000\000\000 */
{ 809622 }, /* dtlb_misses.large_walk_completed\000\000virtual memory\000DTLB miss large page walks\000event=0x49,period=200000,umask=0x80\000\00000\000\000 */
{ 809739 }, /* dtlb_misses.pde_miss\000\000virtual memory\000DTLB misses caused by low part of address. Count also includes 2M page references because 2M pages do not use the PDE\000event=0x49,period=200000,umask=0x20\000\00000\000\000 */
{ 810055 }, /* dtlb_misses.stlb_hit\000\000virtual memory\000DTLB first level misses but second level hit\000event=0x49,period=200000,umask=0x10\000\00000\000\000 */
{ 810178 }, /* dtlb_misses.walk_completed\000\000virtual memory\000DTLB miss page walks\000event=0x49,period=200000,umask=0x2\000\00000\000\000 */
{ 810282 }, /* dtlb_misses.walk_cycles\000\000virtual memory\000DTLB miss page walk cycles\000event=0x49,period=2000000,umask=0x4\000\00000\000\000 */
{ 833736 }, /* ept.walk_cycles\000\000virtual memory\000Extended Page Table walk cycles\000event=0x4f,period=2000000,umask=0x10\000\00000\000\000 */
{ 1079563 }, /* itlb_flush\000\000virtual memory\000ITLB flushes\000event=0xae,period=2000000,umask=0x1\000\00000\000\000 */
{ 1079644 }, /* itlb_miss_retired\000\000virtual memory\000Retired instructions that missed the ITLB (Precise Event)\000event=0xc8,period=200000,umask=0x20\000\00000\000\000 */
{ 1079777 }, /* itlb_misses.any\000\000virtual memory\000ITLB miss\000event=0x85,period=200000,umask=0x1\000\00000\000\000 */
{ 1080091 }, /* itlb_misses.large_walk_completed\000\000virtual memory\000ITLB miss large page walks\000event=0x85,period=200000,umask=0x80\000\00000\000\000 */
{ 1087383 }, /* itlb_misses.walk_completed\000\000virtual memory\000ITLB miss page walks\000event=0x85,period=200000,umask=0x2\000\00000\000\000 */
{ 1095723 }, /* itlb_misses.walk_cycles\000\000virtual memory\000ITLB miss page walk cycles\000event=0x85,period=2000000,umask=0x4\000\00000\000\000 */
{ 1331956 }, /* mem_load_retired.dtlb_miss\000\000virtual memory\000Retired loads that miss the DTLB (Precise Event)\000event=0xcb,period=200000,umask=0x80\000\00000\000\000 */
{ 1368683 }, /* mem_store_retired.dtlb_miss\000\000virtual memory\000Retired stores that miss the DTLB (Precise Event)\000event=0xc,period=200000,umask=0x1\000\00000\000\000 */
};


/* Struct used to make the PMU event table implementation opaque to callers. */
struct pmu_events_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/* Struct used to make the PMU metric table implementation opaque to callers. */
struct pmu_metrics_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/*
 * Map a CPU to its table of PMU events. The CPU is identified by the
 * cpuid field, which is an arch-specific identifier for the CPU.
 * The identifier specified in tools/perf/pmu-events/arch/xxx/mapfile
 * must match the get_cpuid_str() in tools/perf/arch/xxx/util/header.c)
 *
 * The  cpuid can contain any character other than the comma.
 */
struct pmu_events_map {
        const char *arch;
        const char *cpuid;
        struct pmu_events_table event_table;
        struct pmu_metrics_table metric_table;
};

/*
 * Global table mapping each known CPU for the architecture to its
 * table of PMU events.
 */
const struct pmu_events_map pmu_events_map[] = {
{
	.arch = "testarch",
	.cpuid = "testcpu",
	.event_table = {
		.entries = pmu_events__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_events__test_soc_cpu),
	},
	.metric_table = {
		.entries = pmu_metrics__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_metrics__test_soc_cpu),
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(97|9A|B7|BA|BF)",
	.event_table = {
		.entries = pmu_events__alderlake,
		.length = ARRAY_SIZE(pmu_events__alderlake)
	},
	.metric_table = {
		.entries = pmu_metrics__alderlake,
		.length = ARRAY_SIZE(pmu_metrics__alderlake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-BE",
	.event_table = {
		.entries = pmu_events__alderlaken,
		.length = ARRAY_SIZE(pmu_events__alderlaken)
	},
	.metric_table = {
		.entries = pmu_metrics__alderlaken,
		.length = ARRAY_SIZE(pmu_metrics__alderlaken)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(1C|26|27|35|36)",
	.event_table = {
		.entries = pmu_events__bonnell,
		.length = ARRAY_SIZE(pmu_events__bonnell)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(3D|47)",
	.event_table = {
		.entries = pmu_events__broadwell,
		.length = ARRAY_SIZE(pmu_events__broadwell)
	},
	.metric_table = {
		.entries = pmu_metrics__broadwell,
		.length = ARRAY_SIZE(pmu_metrics__broadwell)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-56",
	.event_table = {
		.entries = pmu_events__broadwellde,
		.length = ARRAY_SIZE(pmu_events__broadwellde)
	},
	.metric_table = {
		.entries = pmu_metrics__broadwellde,
		.length = ARRAY_SIZE(pmu_metrics__broadwellde)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-4F",
	.event_table = {
		.entries = pmu_events__broadwellx,
		.length = ARRAY_SIZE(pmu_events__broadwellx)
	},
	.metric_table = {
		.entries = pmu_metrics__broadwellx,
		.length = ARRAY_SIZE(pmu_metrics__broadwellx)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-55-[56789ABCDEF]",
	.event_table = {
		.entries = pmu_events__cascadelakex,
		.length = ARRAY_SIZE(pmu_events__cascadelakex)
	},
	.metric_table = {
		.entries = pmu_metrics__cascadelakex,
		.length = ARRAY_SIZE(pmu_metrics__cascadelakex)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-9[6C]",
	.event_table = {
		.entries = pmu_events__elkhartlake,
		.length = ARRAY_SIZE(pmu_events__elkhartlake)
	},
	.metric_table = {
		.entries = pmu_metrics__elkhartlake,
		.length = ARRAY_SIZE(pmu_metrics__elkhartlake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-5[CF]",
	.event_table = {
		.entries = pmu_events__goldmont,
		.length = ARRAY_SIZE(pmu_events__goldmont)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-7A",
	.event_table = {
		.entries = pmu_events__goldmontplus,
		.length = ARRAY_SIZE(pmu_events__goldmontplus)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-B6",
	.event_table = {
		.entries = pmu_events__grandridge,
		.length = ARRAY_SIZE(pmu_events__grandridge)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-A[DE]",
	.event_table = {
		.entries = pmu_events__graniterapids,
		.length = ARRAY_SIZE(pmu_events__graniterapids)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(3C|45|46)",
	.event_table = {
		.entries = pmu_events__haswell,
		.length = ARRAY_SIZE(pmu_events__haswell)
	},
	.metric_table = {
		.entries = pmu_metrics__haswell,
		.length = ARRAY_SIZE(pmu_metrics__haswell)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-3F",
	.event_table = {
		.entries = pmu_events__haswellx,
		.length = ARRAY_SIZE(pmu_events__haswellx)
	},
	.metric_table = {
		.entries = pmu_metrics__haswellx,
		.length = ARRAY_SIZE(pmu_metrics__haswellx)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-7[DE]",
	.event_table = {
		.entries = pmu_events__icelake,
		.length = ARRAY_SIZE(pmu_events__icelake)
	},
	.metric_table = {
		.entries = pmu_metrics__icelake,
		.length = ARRAY_SIZE(pmu_metrics__icelake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-6[AC]",
	.event_table = {
		.entries = pmu_events__icelakex,
		.length = ARRAY_SIZE(pmu_events__icelakex)
	},
	.metric_table = {
		.entries = pmu_metrics__icelakex,
		.length = ARRAY_SIZE(pmu_metrics__icelakex)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-3A",
	.event_table = {
		.entries = pmu_events__ivybridge,
		.length = ARRAY_SIZE(pmu_events__ivybridge)
	},
	.metric_table = {
		.entries = pmu_metrics__ivybridge,
		.length = ARRAY_SIZE(pmu_metrics__ivybridge)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-3E",
	.event_table = {
		.entries = pmu_events__ivytown,
		.length = ARRAY_SIZE(pmu_events__ivytown)
	},
	.metric_table = {
		.entries = pmu_metrics__ivytown,
		.length = ARRAY_SIZE(pmu_metrics__ivytown)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-2D",
	.event_table = {
		.entries = pmu_events__jaketown,
		.length = ARRAY_SIZE(pmu_events__jaketown)
	},
	.metric_table = {
		.entries = pmu_metrics__jaketown,
		.length = ARRAY_SIZE(pmu_metrics__jaketown)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(57|85)",
	.event_table = {
		.entries = pmu_events__knightslanding,
		.length = ARRAY_SIZE(pmu_events__knightslanding)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-A[AC]",
	.event_table = {
		.entries = pmu_events__meteorlake,
		.length = ARRAY_SIZE(pmu_events__meteorlake)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-1[AEF]",
	.event_table = {
		.entries = pmu_events__nehalemep,
		.length = ARRAY_SIZE(pmu_events__nehalemep)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-2E",
	.event_table = {
		.entries = pmu_events__nehalemex,
		.length = ARRAY_SIZE(pmu_events__nehalemex)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-A7",
	.event_table = {
		.entries = pmu_events__rocketlake,
		.length = ARRAY_SIZE(pmu_events__rocketlake)
	},
	.metric_table = {
		.entries = pmu_metrics__rocketlake,
		.length = ARRAY_SIZE(pmu_metrics__rocketlake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-2A",
	.event_table = {
		.entries = pmu_events__sandybridge,
		.length = ARRAY_SIZE(pmu_events__sandybridge)
	},
	.metric_table = {
		.entries = pmu_metrics__sandybridge,
		.length = ARRAY_SIZE(pmu_metrics__sandybridge)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(8F|CF)",
	.event_table = {
		.entries = pmu_events__sapphirerapids,
		.length = ARRAY_SIZE(pmu_events__sapphirerapids)
	},
	.metric_table = {
		.entries = pmu_metrics__sapphirerapids,
		.length = ARRAY_SIZE(pmu_metrics__sapphirerapids)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-AF",
	.event_table = {
		.entries = pmu_events__sierraforest,
		.length = ARRAY_SIZE(pmu_events__sierraforest)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(37|4A|4C|4D|5A)",
	.event_table = {
		.entries = pmu_events__silvermont,
		.length = ARRAY_SIZE(pmu_events__silvermont)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-(4E|5E|8E|9E|A5|A6)",
	.event_table = {
		.entries = pmu_events__skylake,
		.length = ARRAY_SIZE(pmu_events__skylake)
	},
	.metric_table = {
		.entries = pmu_metrics__skylake,
		.length = ARRAY_SIZE(pmu_metrics__skylake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-55-[01234]",
	.event_table = {
		.entries = pmu_events__skylakex,
		.length = ARRAY_SIZE(pmu_events__skylakex)
	},
	.metric_table = {
		.entries = pmu_metrics__skylakex,
		.length = ARRAY_SIZE(pmu_metrics__skylakex)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-86",
	.event_table = {
		.entries = pmu_events__snowridgex,
		.length = ARRAY_SIZE(pmu_events__snowridgex)
	},
	.metric_table = {
		.entries = pmu_metrics__snowridgex,
		.length = ARRAY_SIZE(pmu_metrics__snowridgex)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-8[CD]",
	.event_table = {
		.entries = pmu_events__tigerlake,
		.length = ARRAY_SIZE(pmu_events__tigerlake)
	},
	.metric_table = {
		.entries = pmu_metrics__tigerlake,
		.length = ARRAY_SIZE(pmu_metrics__tigerlake)
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-2C",
	.event_table = {
		.entries = pmu_events__westmereep_dp,
		.length = ARRAY_SIZE(pmu_events__westmereep_dp)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-25",
	.event_table = {
		.entries = pmu_events__westmereep_sp,
		.length = ARRAY_SIZE(pmu_events__westmereep_sp)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "GenuineIntel-6-2F",
	.event_table = {
		.entries = pmu_events__westmereex,
		.length = ARRAY_SIZE(pmu_events__westmereex)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "x86",
	.cpuid = "AuthenticAMD-23-([12][0-9A-F]|[0-9A-F])",
	.event_table = {
		.entries = pmu_events__amdzen1,
		.length = ARRAY_SIZE(pmu_events__amdzen1)
	},
	.metric_table = {
		.entries = pmu_metrics__amdzen1,
		.length = ARRAY_SIZE(pmu_metrics__amdzen1)
	}
},
{
	.arch = "x86",
	.cpuid = "AuthenticAMD-23-[[:xdigit:]]+",
	.event_table = {
		.entries = pmu_events__amdzen2,
		.length = ARRAY_SIZE(pmu_events__amdzen2)
	},
	.metric_table = {
		.entries = pmu_metrics__amdzen2,
		.length = ARRAY_SIZE(pmu_metrics__amdzen2)
	}
},
{
	.arch = "x86",
	.cpuid = "AuthenticAMD-25-([245][[:xdigit:]]|[[:xdigit:]])",
	.event_table = {
		.entries = pmu_events__amdzen3,
		.length = ARRAY_SIZE(pmu_events__amdzen3)
	},
	.metric_table = {
		.entries = pmu_metrics__amdzen3,
		.length = ARRAY_SIZE(pmu_metrics__amdzen3)
	}
},
{
	.arch = "x86",
	.cpuid = "AuthenticAMD-25-[[:xdigit:]]+",
	.event_table = {
		.entries = pmu_events__amdzen4,
		.length = ARRAY_SIZE(pmu_events__amdzen4)
	},
	.metric_table = {
		.entries = pmu_metrics__amdzen4,
		.length = ARRAY_SIZE(pmu_metrics__amdzen4)
	}
},
{
	.arch = 0,
	.cpuid = 0,
	.event_table = { 0, 0 },
	.metric_table = { 0, 0 },
}
};

struct pmu_sys_events {
	const char *name;
	struct pmu_events_table event_table;
	struct pmu_metrics_table metric_table;
};

static const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.event_table = {
			.entries = pmu_events__test_soc_sys,
			.length = ARRAY_SIZE(pmu_events__test_soc_sys)
		},
		.name = "pmu_events__test_soc_sys",
	},
	{
		.event_table = { 0, 0 },
		.metric_table = { 0, 0 },
	},
};

static void decompress_event(int offset, struct pmu_event *pe)
{
	const char *p = &big_c_string[offset];

	pe->name = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->pmu = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->topic = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->event = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->deprecated = *p - '0';
	p++;
	pe->perpkg = *p - '0';
	p++;
	pe->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->long_desc = (*p == '\0' ? NULL : p);
}

static void decompress_metric(int offset, struct pmu_metric *pm)
{
	const char *p = &big_c_string[offset];

	pm->pmu = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_expr = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_threshold = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->long_desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metricgroup_no_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->default_metricgroup_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->aggr_mode = *p - '0';
	p++;
	pm->event_grouping = *p - '0';
}

int pmu_events_table_for_each_event(const struct pmu_events_table *table,
                                    pmu_event_iter_fn fn,
                                    void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_event pe;
                int ret;

                decompress_event(table->entries[i].offset, &pe);
                if (!pe.name)
                        continue;
                ret = fn(&pe, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_metrics_table_for_each_metric(const struct pmu_metrics_table *table,
                                     pmu_metric_iter_fn fn,
                                     void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_metric pm;
                int ret;

                decompress_metric(table->entries[i].offset, &pm);
                if (!pm.metric_expr)
                        continue;
                ret = fn(&pm, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *perf_pmu__find_events_table(struct perf_pmu *pmu)
{
        const struct pmu_events_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->event_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_metrics_table *perf_pmu__find_metrics_table(struct perf_pmu *pmu)
{
        const struct pmu_metrics_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->metric_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_events_table *find_core_events_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *find_core_metrics_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->metric_table;
        }
        return NULL;
}

int pmu_for_each_core_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_core_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *find_sys_events_table(const char *name)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                if (!strcmp(tables->name, name))
                        return &tables->event_table;
        }
        return NULL;
}

int pmu_for_each_sys_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_sys_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

static const int metricgroups[][2] = {
	{ 0, 161 }, /* Backend\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 8, 161 }, /* BadSpec\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 16, 161 }, /* Bad\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 20, 161 }, /* BigFoot\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 28, 161 }, /* BrMispredicts\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 42, 161 }, /* Branches\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 51, 161 }, /* CacheMisses\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 63, 161 }, /* CodeGen\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 71, 161 }, /* Compute\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 79, 161 }, /* Cor\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 83, 161 }, /* DSB\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 87, 161 }, /* DSBmiss\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 95, 161 }, /* DataSharing\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 107, 161 }, /* Fed\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 111, 161 }, /* FetchBW\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 119, 161 }, /* FetchLat\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 128, 161 }, /* Flops\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 134, 161 }, /* FpScalar\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 143, 161 }, /* FpVector\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 152, 161 }, /* Frontend\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 231, 161 }, /* HPC\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 235, 161 }, /* IcMiss\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 242, 161 }, /* InsType\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 250, 161 }, /* IntVector\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 260, 161 }, /* IoBW\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 265, 161 }, /* L2Evicts\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 1286314, 161 }, /* LSD\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 274, 161 }, /* MachineClears\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 288, 161 }, /* Mem\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 292, 161 }, /* MemoryBW\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 301, 161 }, /* MemoryBound\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 313, 161 }, /* MemoryLat\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 323, 161 }, /* MemoryTLB\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 333, 161 }, /* Memory_BW\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 343, 161 }, /* Memory_Lat\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3265, 161 }, /* MicroSeq\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3274, 161 }, /* OS\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3277, 161 }, /* Offcore\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3285, 161 }, /* PGO\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3289, 161 }, /* Pipeline\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3298, 161 }, /* PortsUtil\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3308, 161 }, /* Power\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3314, 161 }, /* Prefetches\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3325, 161 }, /* Ret\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3329, 161 }, /* Retire\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3336, 161 }, /* SMT\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3340, 161 }, /* Server\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3347, 161 }, /* Snoop\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3353, 161 }, /* SoC\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3357, 161 }, /* Summary\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3365, 161 }, /* TmaL1\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3371, 161 }, /* TmaL2\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3377, 161 }, /* TmaL3mem\000 => Grouping from Top-down Microarchitecture Analysis Metrics spreadsheet\000 */
	{ 3386, 2280 }, /* TopdownL1\000 => Metrics for top-down breakdown at level 1\000 */
	{ 3396, 2322 }, /* TopdownL2\000 => Metrics for top-down breakdown at level 2\000 */
	{ 3406, 2364 }, /* TopdownL3\000 => Metrics for top-down breakdown at level 3\000 */
	{ 3416, 2406 }, /* TopdownL4\000 => Metrics for top-down breakdown at level 4\000 */
	{ 3426, 2448 }, /* TopdownL5\000 => Metrics for top-down breakdown at level 5\000 */
	{ 3436, 2490 }, /* TopdownL6\000 => Metrics for top-down breakdown at level 6\000 */
	{ 2541971, 2280 }, /* tma_L1_group\000 => Metrics for top-down breakdown at level 1\000 */
	{ 2541984, 2322 }, /* tma_L2_group\000 => Metrics for top-down breakdown at level 2\000 */
	{ 2541997, 2364 }, /* tma_L3_group\000 => Metrics for top-down breakdown at level 3\000 */
	{ 2542010, 2406 }, /* tma_L4_group\000 => Metrics for top-down breakdown at level 4\000 */
	{ 2542023, 2448 }, /* tma_L5_group\000 => Metrics for top-down breakdown at level 5\000 */
	{ 2542036, 2490 }, /* tma_L6_group\000 => Metrics for top-down breakdown at level 6\000 */
	{ 2542049, 354 }, /* tma_alu_op_utilization_group\000 => Metrics contributing to tma_alu_op_utilization category\000 */
	{ 2542078, 410 }, /* tma_assists_group\000 => Metrics contributing to tma_assists category\000 */
	{ 2542096, 506 }, /* tma_backend_bound_aux_group\000 => Metrics contributing to tma_backend_bound_aux category\000 */
	{ 2542124, 455 }, /* tma_backend_bound_group\000 => Metrics contributing to tma_backend_bound category\000 */
	{ 2542148, 561 }, /* tma_bad_speculation_group\000 => Metrics contributing to tma_bad_speculation category\000 */
	{ 2542174, 614 }, /* tma_base_group\000 => Metrics contributing to tma_base category\000 */
	{ 2542189, 656 }, /* tma_branch_resteers_group\000 => Metrics contributing to tma_branch_resteers category\000 */
	{ 2542215, 709 }, /* tma_core_bound_group\000 => Metrics contributing to tma_core_bound category\000 */
	{ 2542236, 757 }, /* tma_dram_bound_group\000 => Metrics contributing to tma_dram_bound category\000 */
	{ 2542257, 805 }, /* tma_dtlb_load_group\000 => Metrics contributing to tma_dtlb_load category\000 */
	{ 2542277, 852 }, /* tma_dtlb_store_group\000 => Metrics contributing to tma_dtlb_store category\000 */
	{ 2542298, 900 }, /* tma_fetch_bandwidth_group\000 => Metrics contributing to tma_fetch_bandwidth category\000 */
	{ 2542324, 953 }, /* tma_fetch_latency_group\000 => Metrics contributing to tma_fetch_latency category\000 */
	{ 2542348, 1004 }, /* tma_fp_arith_group\000 => Metrics contributing to tma_fp_arith category\000 */
	{ 2542367, 1050 }, /* tma_fp_vector_group\000 => Metrics contributing to tma_fp_vector category\000 */
	{ 2542387, 1097 }, /* tma_frontend_bound_group\000 => Metrics contributing to tma_frontend_bound category\000 */
	{ 2542412, 1149 }, /* tma_heavy_operations_group\000 => Metrics contributing to tma_heavy_operations category\000 */
	{ 2542439, 1203 }, /* tma_int_operations_group\000 => Metrics contributing to tma_int_operations category\000 */
	{ 2542464, 2532 }, /* tma_issue2P\000 => Metrics related by the issue $issue2P\000 */
	{ 2542476, 2570 }, /* tma_issueBC\000 => Metrics related by the issue $issueBC\000 */
	{ 2542488, 2608 }, /* tma_issueBM\000 => Metrics related by the issue $issueBM\000 */
	{ 2542500, 2646 }, /* tma_issueBW\000 => Metrics related by the issue $issueBW\000 */
	{ 2542512, 2684 }, /* tma_issueD0\000 => Metrics related by the issue $issueD0\000 */
	{ 2542524, 2722 }, /* tma_issueFB\000 => Metrics related by the issue $issueFB\000 */
	{ 2542536, 2760 }, /* tma_issueFL\000 => Metrics related by the issue $issueFL\000 */
	{ 2542548, 2798 }, /* tma_issueL1\000 => Metrics related by the issue $issueL1\000 */
	{ 2542560, 2836 }, /* tma_issueLat\000 => Metrics related by the issue $issueLat\000 */
	{ 2542573, 2875 }, /* tma_issueMC\000 => Metrics related by the issue $issueMC\000 */
	{ 2542585, 2913 }, /* tma_issueMS\000 => Metrics related by the issue $issueMS\000 */
	{ 2542597, 2951 }, /* tma_issueMV\000 => Metrics related by the issue $issueMV\000 */
	{ 2542609, 2989 }, /* tma_issueRFO\000 => Metrics related by the issue $issueRFO\000 */
	{ 2542622, 3028 }, /* tma_issueSL\000 => Metrics related by the issue $issueSL\000 */
	{ 2542634, 3066 }, /* tma_issueSO\000 => Metrics related by the issue $issueSO\000 */
	{ 2542646, 3104 }, /* tma_issueSmSt\000 => Metrics related by the issue $issueSmSt\000 */
	{ 2542660, 3144 }, /* tma_issueSpSt\000 => Metrics related by the issue $issueSpSt\000 */
	{ 2542674, 3184 }, /* tma_issueSyncxn\000 => Metrics related by the issue $issueSyncxn\000 */
	{ 2542690, 3226 }, /* tma_issueTLB\000 => Metrics related by the issue $issueTLB\000 */
	{ 2542703, 1255 }, /* tma_l1_bound_group\000 => Metrics contributing to tma_l1_bound category\000 */
	{ 2542722, 1301 }, /* tma_l3_bound_group\000 => Metrics contributing to tma_l3_bound category\000 */
	{ 2542741, 1347 }, /* tma_light_operations_group\000 => Metrics contributing to tma_light_operations category\000 */
	{ 2542768, 1401 }, /* tma_load_op_utilization_group\000 => Metrics contributing to tma_load_op_utilization category\000 */
	{ 2542798, 1458 }, /* tma_machine_clears_group\000 => Metrics contributing to tma_machine_clears category\000 */
	{ 2542823, 1510 }, /* tma_mem_bandwidth_group\000 => Metrics contributing to tma_mem_bandwidth category\000 */
	{ 2542847, 1561 }, /* tma_mem_latency_group\000 => Metrics contributing to tma_mem_latency category\000 */
	{ 2542869, 1610 }, /* tma_mem_scheduler_group\000 => Metrics contributing to tma_mem_scheduler category\000 */
	{ 2542893, 1661 }, /* tma_memory_bound_group\000 => Metrics contributing to tma_memory_bound category\000 */
	{ 2542916, 1711 }, /* tma_microcode_sequencer_group\000 => Metrics contributing to tma_microcode_sequencer category\000 */
	{ 2542946, 1768 }, /* tma_mite_group\000 => Metrics contributing to tma_mite category\000 */
	{ 2542961, 1810 }, /* tma_nuke_group\000 => Metrics contributing to tma_nuke category\000 */
	{ 2542976, 1852 }, /* tma_ports_utilization_group\000 => Metrics contributing to tma_ports_utilization category\000 */
	{ 2543004, 1907 }, /* tma_ports_utilized_0_group\000 => Metrics contributing to tma_ports_utilized_0 category\000 */
	{ 2543031, 1961 }, /* tma_ports_utilized_3m_group\000 => Metrics contributing to tma_ports_utilized_3m category\000 */
	{ 2543059, 2016 }, /* tma_resource_bound_group\000 => Metrics contributing to tma_resource_bound category\000 */
	{ 2543084, 2068 }, /* tma_retiring_group\000 => Metrics contributing to tma_retiring category\000 */
	{ 2543103, 2114 }, /* tma_serializing_operation_group\000 => Metrics contributing to tma_serializing_operation category\000 */
	{ 2543135, 2173 }, /* tma_store_bound_group\000 => Metrics contributing to tma_store_bound category\000 */
	{ 2543157, 2222 }, /* tma_store_op_utilization_group\000 => Metrics contributing to tma_store_op_utilization category\000 */

};

const char *describe_metricgroup(const char *group)
{
        int low = 0, high = (int)ARRAY_SIZE(metricgroups) - 1;

        while (low <= high) {
                int mid = (low + high) / 2;
                const char *mgroup = &big_c_string[metricgroups[mid][0]];
                int cmp = strcmp(mgroup, group);

                if (cmp == 0) {
                        return &big_c_string[metricgroups[mid][1]];
                } else if (cmp < 0) {
                        low = mid + 1;
                } else {
                        high = mid - 1;
                }
        }
        return NULL;
}
